(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  20430197,     455910]*)
(*NotebookOutlinePosition[  20528698,     458988]*)
(*  CellTagsIndexPosition[  20513807,     458540]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
6. Numerical Solution of Linear Partial Differential \
Equations\
\>", "Title",
  CellTags->{"i:1", "c:1"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.1 The Galerkin method", "Subtitle",
  CellTags->{"i:2", "c:2"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.1.1 Introduction", "Subsubtitle",
  CellTags->"c:3"],

Cell[TextData[{
  " \tThe ",
  ButtonBox["Galerkin",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Galerkin.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " method is a numerical method for the solution of differential equations \
that is based on the ideas of eigenmode analysis. The method can be applied \
to both linear and nonlinear PDEs of any order, for which solutions are \
required in some given spatial domain. The domain can be infinite, but if it \
is finite the method is most efficient when the boundary conditions are \
continuous functions of position along the boundary, and when any edges \
formed by the intersection of the bounding surfaces form convex cusps.  For \
instance, the two-dimensional domain shown in Fig. ",
  ButtonBox["6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " can be easily treated via the Galerkin method. However,  the domain in \
Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " is considerably more difficult to deal with, because it has a concave \
cusp pointing into the domain. The reason for these restrictions will be \
discussed in the next section. "
}], "Text",
  CellTags->"i:57"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001NB000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
g`3oool00`20P80000000820P03o0?ooool0ooooP03oool00=l0oooo0P0000000`30`<00oooo0?oo
o`3o0?ooool0ooooOP3oool00=l0oooo0P00003o0?ooool0ooooP@3oool00=h0oooo00<0P8200000
00000000o`3ooond0?ooo`030<30`020P800oooo0<T0oooo003N0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooon`0?ooo`050820P0000000000000000030`<00b@3oool00=h0oooo0P0000000`20P800
oooo0?ooo`3o0?ooojh0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`370?ooo`00
g@3oool01020P800000000000030`<3o0?ooojl0oooo00<0P8200000000000000P0000000`10@400
`<300?ooo`390?ooo`00o`3ooooo0?oooi80oooo0P10@4000`20P800oooo0?ooo`3;0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooon50?ooo`030820P0000000P8200=X0oooo
003o0?ooool0ooooQ03oool400000=X0oooo003o0?ooool0ooooPP3oool00`20P800000000000002
000000030820P03oool0oooo0=P0oooo003o0?ooool0ooooP03oool00`30`<00P820000000020000
00030820P030`<00oooo0=X0oooo003o0?ooool0ooooP@3oool2000000030820P03oool0oooo0=`0
oooo003o0?ooool0ooooPP3oool00`20P800oooo0?ooo`3M0?ooo`00fP3oool20820P0030<30`03o
ool0oooo0?l0ooooo`3ooon30?ooo`00f@3oool01030`<00000000000020P83o0?ooool0ooooQ@3o
ool00=T0oooo00<0P820000000000000o`3ooooo0?ooohH0oooo003I0?ooo`030820P00000000000
0?l0ooooo`3ooon60?ooo`00f@3oool00`10@40000000000003o0?ooool0ooooQP3oool00=T0oooo
0P0000000`20P800oooo0?ooo`3o0?oooiH0oooo00<0`<3000000020P800jP3oool00=T0oooo0P00
00000`20P800oooo0?ooo`3o0?oooiD0oooo00@0@4100000000000000000jP3oool00=P0oooo00@0
P820000000000000P820o`3ooonF0?ooo`050820P0000000000000000020P800jP3oool00?l0oooo
o`3oooma0?ooo`060<30`020P800000000000010@400P820j`3oool00?l0ooooo`3oooma0?ooo`04
0410@000000000000410@>d0oooo003o0?ooool0ooooLP3oool00`20P800`<300?ooo`3]0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooomX0?ooo`030000003oool0
oooo0?L0oooo003G0?ooo`80P820o`3ooon=0?ooo`030820P0000000@4100?P0oooo003G0?ooo`80
0000o`3ooon<0?ooo`040820P000000000000820P?P0oooo003G0?ooo`800000CP3oool20820P080
000000<0@4100?ooo`3oool0o`3ooolf0?ooo`040410@000000000000410@?T0oooo003G0?ooo`80
0000C03oool700000?l0oooo>03oool3000000030820P03oool0oooo0?L0oooo003F0?ooo`030820
P0000000@41004`0oooo00<0@4100000000000000P0000020820P?L0oooo00<0P8200?ooo`3oool0
?03oool01010@400000000000010@43j0?ooo`00eP3oool2000000030820P03oool0oooo04X0oooo
00<0`<300820P030`<00nP3oool01@20P800000000000010@400P82003/0oooo00<0`<300410@000
0000n`3oool00=H0oooo0P0000000`20P800oooo0?ooo`3o0?ooodP0oooo00<0P8200410@0000000
0`00003o0?ooocT0oooo003F0?ooo`80000000<0P8200?ooo`3oool0o`3ooom:0?ooo`040820P000
000000000820P?l0oooo>@3oool00?l0oooo5`3oool01020P800@41000000010@43o0?ooo``0oooo
00<0`<300820P030`<00o`3oooli0?ooo`00o`3ooolC0?ooo`030<30`020P800000000D00000o`3o
oooo0?ooodP0oooo003o0?oooa<0oooo00H0`<3000000000000000000410@020P83o0?ooool0oooo
BP3oool00?l0oooo503oool200000?l0oooo7`3oool00`000000oooo0?ooo`3o0?ooob/0oooo003o
0?ooool0oooo=03oool01@30`<000000000000000000P8200?l0oooo:P3oool00?l0oooo1P3oool2
0820P0030<30`03oool0oooo0?l0oooo:@3oool00`30`<00@41000000003000000030410@020P800
oooo0?l0oooo9P3oool00?l0oooo0P3oool20820P0050410@0000000000000000010@400o`3oool]
0?ooo`030<30`020P800@4100080000000<0P8200?ooo`3oool0o`3ooolU0?ooo`00o`3oool10?oo
o`P00000o`3oool`0?ooo`030820P0000000oooo0240oooo00<0P8200000003oool0o`3oool30?oo
o`00o`3oool10?ooo`040820P0000000000000000080P82000<0`<300?ooo`3oool0o`3ooomC0?oo
o`<00000o`3oool30?ooo`00o`3oool20?ooo`030820P03oool0oooo0?l0ooooE`3oool01020P800
000000000030`<3o0?ooo`<0oooo003o0?ooool0ooooAP3oool00`30`<00P8200?ooo`0C0?ooo`03
0410@0000000P8200?l0oooo103oool00?l0ooooo`3ooom60?ooo`<000004P3oool00`20P8000000
0000003o0?ooo`D0oooo001m0?ooo`80000000<0`<300?ooo`3oool0E03oool2000000030820P03o
ool0oooo01L0oooo00@0P8200410@0000000P820o`3ooom>0?ooo`030<30`0000000000000800000
00<0@4100820P03oool03P3oool00`20P80000000820P03o0?ooo`D0oooo001m0?ooo`030820P000
0000P82005L0oooo0P00000E0?ooo`030<30`020P800000000D00000o`3ooom?0?ooo`030<30`020
P800@41000@000003P3oool2000000030<30`03oool0oooo0?l0oooo0`3oool007d0oooo00<0P820
00000020P800E`3oool2000001D0oooo00<0P8200000000000000`00003o0?oooe@0oooo00@0P820
0000000000000000o`3ooolF0?ooo`00O@3oool00`30`<0000000000001G0?ooo`8000005P3oool0
10000000@4100820P030`<3o0?oooeL0oooo00<0P8200<30`03oool0o`3ooolE0?ooo`00OP3oool2
000005L0oooo00<0@41000000030`<00o`3ooooo0?ooohP0oooo001n0?ooo`030410@00000000000
05H0oooo00<0P82000000020P800o`3ooooo0?ooohP0oooo001n0?ooo`030820P0000000000005H0
oooo00<0P82000000020P8001`3oool2000000030820P03oool0oooo0?l0ooooo`3oooml0?ooo`00
g@3oool00`30`<00P8200410@003000000030410@03oool0oooo0?l0ooooL@3oool2000000030820
P030`<00oooo0?l0oooo1P3oool00=`0oooo00<0@4100000000000000P0000020820P?l0ooooL`3o
ool00`30`<00@41000000003000000030820P03oool0oooo0?l0oooo0`3oool00=`0oooo00@0`<30
000000000000P820o`3ooomg0?ooo`030410@0000000000000D0000000<0P8200?ooo`3oool0o`3o
ool00=D0oooo1P00003o0?ooog`0oooo0`0000000`3oool0P8200000000400000?l0oooo0@3oool0
0=80oooo0P20P80700000?l0ooooN`3oool00`30`<000000000000030?ooo`030<30`020P8000000
00@0000000<0P8200?ooo`3oool0n`3oool00<l0oooo00<0`<300820P00000000`0000001010@400
P8200<30`030`<02000000030820P03oool0oooo0?l0ooooN03oool00`20P8000000000000060?oo
o`030<30`010@400000000<0000000<0P8200<30`03oool0n@3oool00<`0oooo00<0`<300820P000
0000100000000`20P800`<300?ooo`030?ooo`80000000<0P8200?ooo`3oool0o`3ooomh0?ooo`80
000000<0@4100?ooo`3oool01`3oool00`20P800@41000000003000000030820P03oool0oooo0?H0
oooo003;0?ooo`H0000000<0P8200?ooo`3oool01@3oool300000?l0ooooNP3oool2000000030820
P03oool0oooo00T0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3d0?ooo`00b03o
ool00`20P800@41000000004000000030820P03oool0oooo00L0oooo00<0P820000000000000EP3o
ool01020P800@41000000010@43o0?ooob00oooo0P0000000`20P800oooo0?ooo`0;0?ooo`030820
P010@400000000<0000000<0P8200?ooo`3oool0lP3oool00<D0oooo0P20P804000000030410@020
P800oooo00/0oooo00@0P820000000000000P820D@3oool00`30`<00P8200000000500000?l0oooo
803oool2000000030<30`03oool0oooo00`0oooo00<0`<300820P0000000100000000`10@400P820
0?ooo`3`0?ooo`00`P3oool20820P0@0000000<0@4100<30`03oool03`3oool300000540oooo00H0
`<3000000000000000000410@020P83o0?ooob80oooo0P00000C0?ooo`030820P010@400000000<0
000000<0P8200<30`03oool0k@3oool00840oooo00<0P82000000020P800?@3oool6000001@0oooo
0P0000000`20P800oooo0?ooo`1?0?ooo`800000o`3ooolT0?ooo`<000005P3oool600000>d0oooo
00210?ooo`030820P0000000P82003T0oooo00<0`<300820P010@400100000000`20P800oooo0?oo
o`0D0?ooo`030410@0000000P8200?l0ooooM`3oool3000001L0oooo00<0P8200410@00000000`00
00000`20P800`<300?ooo`3Y0?ooo`00P@3oool00`30`<0000000000000g0?ooo`030820P010@400
000000<0000000<0P8200?ooo`3oool05`3oool00`30`<000000000000140?ooo`030<30`03oool0
oooo0?l0oooo<03oool2000000030410@03oool0oooo01P0oooo00<0P8200000000000000`000000
0`20P800oooo0?ooo`3V0?ooo`00PP3oool2000003@0oooo00<0P8200410@00000000`0000020820
P1`0oooo00<0@410000000000000@03oool01@30`<00P820000000000000P8200?l0oooo<@3oool2
000000030820P03oool0oooo01X0oooo00<0`<300820P00000000`0000000`10@400P8200?ooo`3T
0?ooo`00PP3oool200000380oooo00<0P8200000000000001000000O0?ooo`040820P00000000000
0820P3h0oooo1@0000000`20P800oooo0?ooo`3o0?ooobl0oooo0P0000000`20P800oooo0?ooo`0M
0?ooo`H00000i03oool00880oooo0P0000000`20P800oooo0?ooo`0]0?ooo`030820P00000000000
008000000P20P8000`30`<00oooo0?ooo`0O0?ooo`80000000<0@4100?ooo`3oool0>P3oool00`20
P800000000000002000000030820P03oool0oooo0?l0oooo<@3oool2000000030820P03oool0oooo
01h0oooo00<0`<300000000000000`0000000`10@400P8200?ooo`3P0?ooo`00PP3oool00`20P800
00000000000/0?ooo`030820P00000000000008000000P20P80U0?ooo`040410@000000000000<30
`3`0oooo0P10@4000`30`<00oooo0?ooo`3o0?oooc<0oooo0P0000000`20P800oooo0?ooo`0P0?oo
o`030<30`020P800000000@0000000<0@4100<30`03oool0g@3oool00:h0oooo00<0P82000000000
00000P0000020820P2T0oooo0P0000000`10@400oooo0?ooo`3o0?ooog80oooo0P0000000`20P800
oooo0?ooo`0S0?ooo`80P8201@0000000`20P800`<300?ooo`3J0?ooo`00[03oool00`20P8000000
00000003000002d0oooo0P0000000`20P800oooo0?ooo`3o0?ooog00oooo00@0P820000000000000
P820:@3oool5000000030820P03oool0oooo0=P0oooo002Y0?ooo`030<30`010@400000000<00000
0P20P80^0?ooo`030820P0000000@4100?l0ooooLP3oool01020P800000000000020P80Z0?ooo`03
0820P0000000000000<0000000<0P8200<30`03oool0eP3oool00:H0oooo00<0`<300820P010@400
100000000`20P800oooo0?ooo`0`0?ooo`030410@0000000000002h0oooo00<0P8200?ooo`3oool0
o`3ooom00?ooo`040820P000000000000820P2d0oooo00<0P8200000000000000P0000000`10@400
P8200?ooo`3D0?ooo`00Y@3oool00`20P800000000000002000000030410@020P800oooo03<0oooo
00@0`<30000000000000@410:P3oool01@30`<00@410000000000000`<300?l0oooo@@3oool01020
P800000000000020P80_0?ooo`80P820100000000`10@400`<300?ooo`3A0?ooo`00Y03oool50000
03P0oooo0`0000000`20P800oooo0?ooo`0W0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolo0?oo
o`040820P000000000000820P380oooo1P00003A0?ooo`00X@3oool00`20P8000000000000020000
00030410@020P800oooo03P0oooo00D0`<3000000000000000000820P00V0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooom00?ooo`040820P000000000000820P3<0oooo00<0
P8200000000000000`0000000`10@400`<300?ooo`3=0?ooo`00WP3oool20820P0@0000000<0P820
0?ooo`3oool0?03oool01010@400000000000020P80T0?ooo`050410@0000000000000000020P800
o`3ooom50?ooo`80000000<0P8200?ooo`3oool0<`3oool00`30`<00P82000000004000000030820
P030`<00oooo05`0oooo00<0`<300820P030`<00J`3oool009d0oooo1@0000000`20P800oooo0?oo
o`0o0?ooo`<000009@3oool2000000030820P03oool0oooo0?l0ooooA03oool3000003P0oooo1P00
00000`20P800oooo0?ooo`1H0?ooo`D00000J`3oool009X0oooo0P20P804000000030410@030`<00
oooo0440oooo00@0P820000000000000@410903oool20820P?l0ooooA`3oool3000003X0oooo00<0
P8200000000000000`0000000`20P800`<300?ooo`1D0?ooo`L00000J`3oool009P0oooo00<0P820
0000000000000P0000000`10@400`<300?ooo`150?ooo`040820P000000000000410@?l0ooooK03o
ool00`20P80000000000000m0?ooo`030820P000000000000080000000<0@4100820P03oool0DP3o
ool00`20P80000000410@0020820P6d0oooo002E0?ooo`030820P010@400000000@0000000<0P820
0?ooo`3oool0A`3oool01@20P8000000000000000000P8200?l0ooooJ`3oool2000003l0oooo0P20
P804000000030410@030`<00oooo0<40oooo00250?ooo`80000000<0P8200?ooo`3oool02P3oool6
000004d0oooo100000000`20P800oooo0?ooo`3o0?ooofP0oooo0P0000120?ooo`H00000@@3oool2
000000030820P03oool0oooo07/0oooo00250?ooo`030820P0000000P82000T0oooo00<0P8200410
@0000000100000000`20P800oooo0?ooo`1=0?ooo`050820P0000000000000000030`<00o`3ooomY
0?ooo`800000@`3oool00`20P800000000000003000000030410@020P800oooo03X0oooo00<0P820
0410@00000000`00001m0?ooo`00Q@3oool00`20P80000000410@0060?ooo`030<30`010@4000000
00<0000000<0@4100820P03oool0D`3oool01@10@400000000000020P800`<300140oooo00<0`<30
0820P03oool0o`3ooomC0?ooo`80000000<0`<300?ooo`3oool0@P3oool00`30`<00P82000000004
000000030820P030`<00oooo03D0oooo00<0P8200000000000000P0000000`10@400P8200820P01m
0?ooo`00QP3oool2000000<0oooo00<0`<300820P0000000100000000`20P800oooo0?ooo`1F0?oo
o`060<30`0000000000000000020P800`<303P3oool01020P800000000000010@43o0?oooe<0oooo
00<0P82000000020P800A`3oool20820P0@0000000<0@4100820P030`<00=03oool2000000030820
P030`<00oooo07l0oooo00260?ooo`8000000P3oool00`20P800000000000004000005/0oooo00<0
P8200000000000000`00000<0?ooo`050820P0000000000000000020P800o`3ooomC0?ooo`030820
P0000000P82004X0oooo1P0000000`20P800oooo0?ooo`2e0?ooo`00QP3oool2000000030820P010
@400000000<0000000<0P8200?ooo`3oool0G@3oool01P10@4000000000000000000@4100<30`0T0
oooo00D0P820000000000000@4100820P03o0?oooe@0oooo00<0P82000000020P800B`3oool20820
P0@0000000<0@4100820P030`<00]03oool008H0oooo00<0@4100000000000000P0000000`10@400
P8200?ooo`1Q0?ooo`030<30`010@40000000080000000<0@4100820P03oool0103oool01@30`<00
0000000000000000@4100?l0ooooEP3oool00`30`<0000000000001>0?ooo`030820P010@4000000
00<0000000<0@4100<30`03oool07`3oool20820P900oooo00230?ooo`030<30`020P800000000<0
000000<0@4100<30`03oool0I@3oool00`20P800@41000000002000000030410@030`<00oooo00<0
oooo00<0@41000000020P800o`3ooomH0?ooo`800000D@3oool00`20P80000000000000300000003
0410@030`<00oooo01X0oooo00D0P82000000000000000000820P02?0?ooo`00Q03oool500000003
0820P03oool0oooo06L0oooo00<0P8200000000000000`00003o0?oooeh0oooo0P00001C0?ooo`03
0820P0000000000000@000006@3oool5000000030820P03oool0oooo08d0oooo00240?ooo`80P820
00@0oooo000000000000P820JP3oool00`30`<00000000000003000000030410@020P800oooo0?l0
ooooFP3oool2000000030820P03oool0oooo0580oooo00<0P8200000000000000`0000000`10@400
`<300?ooo`0C0?ooo`030820P000000000000080000000<0P8200<30`03oool0S`3oool008L0oooo
0P0000000`20P800oooo0?ooo`1Z0?ooo`030<30`010@400000000<00000o`3ooomK0?ooo`030820
P0000000000005H0oooo00<0`<300820P00000000`0000000`10@400P8200<30`00B0?ooo`030000
0010@400P82009<0oooo00270?ooo`80000000<0@4100?ooo`3oool0JP3oool00`30`<0000000000
00020820P0030<30`03oool0oooo0?l0ooooF@3oool01020P800000000000030`<1H0?ooo`030820
P010@400000000<0000000<0@4100<30`03oool0Y@3oool008L0oooo00<0P820000000000000K03o
ool2000000030820P03oool0oooo0?l0ooooG@3oool2000000030820P03oool0oooo05T0oooo1P00
00000`20P800oooo0?ooo`2R0?ooo`00M`3oool00`30`<00P8200<30`00=0?ooo`030820P0000000
000006/0oooo00<0P82000000010@4003`3oool00`30`<00P8200820P03o0?ooodh0oooo0P000000
0`20P800oooo0?ooo`1J0?ooo`030820P010@400000000<0000000<0@4100<30`03oool0X@3oool0
07H0oooo00@0@41000000000000000003@3oool01020P800000000000030`<1Y0?ooo`040410@000
000000000<30`0l0oooo00D0@41000000000000000000410@0020820P0030<30`03oool0oooo0?l0
ooooA`3oool2000000030410@03oool0oooo05d0oooo00<0P820000000000000100000000`20P800
`<300?ooo`2M0?ooo`00L`3oool00`30`<00P82000000003000000030820P03oool0oooo00`0oooo
0P0000000`20P800oooo0?ooo`1V0?ooo`040410@000000000000<30`100oooo0P20P80500000003
0820P03oool0oooo00T0oooo00<0`<300820P020P8001020P8000`30`<00oooo0?ooo`3o0?oooc@0
oooo00<0P820000000000000H@3oool00`20P800000000000004000000030820P030`<00oooo09/0
oooo001b0?ooo`030820P000000000000080000000<0P8200?ooo`3oool03P3oool2000000030820
P03oool0oooo06D0oooo00<0P8200000000000005P3oool3000000030820P03oool0oooo00T0oooo
00<0P820000000000000100000000`20P800oooo0?ooo`3o0?oooc@0oooo00@0P820000000000000
P820G`3oool;000009/0oooo001c0?ooo`80000000<0P8200<30`03oool0403oool2000000030410
@03oool0oooo06@0oooo00@0P820000000000000@4109@3oool00`10@40000000000000400000003
0820P03oool0oooo0?l0oooo=03oool01030`<00000000000020P81M0?ooo`050820P00000000000
00000010@4000P3oool00`30`<00P82000000004000000030820P030`<00oooo09L0oooo00290?oo
o`800000I@3oool01030`<00000000000010@40V0?ooo`L0P82000<0`<300?ooo`3oool0o`3ooole
0?ooo`030820P0000000000005d0oooo00@0P82000000020P800`<301P3oool00`20P800@4100000
0003000000030410@030`<00oooo0380oooo00<000000410@030`<00H03oool008T0oooo0P00001T
0?ooo`050<30`0000000000000000030`<00o`3ooomV0?ooo`80000000<0P8200?ooo`3oool0I`3o
ool00`20P800000000000003000000030410@030`<00oooo02h0oooo0`00001Q0?ooo`00R@3oool2
000000030820P03oool0oooo0640oooo0`0000000`20P800oooo0?ooo`3o0?ooofD0oooo00<0P820
00000020P800J`3oool00`20P800000000000003000000030820P03oool0oooo02/0oooo00@0P820
000000000000P820H@3oool008T0oooo00<0P82000000020P800HP3oool01020P800000000000020
P83o0?ooofP0oooo00<0P820000000000000K@3oool00`20P800000000000003000000030410@030
`<00oooo02T0oooo0`0000000`30`<00oooo0?ooo`1O0?ooo`00IP3oool00`20P80000000000000P
0?ooo`030820P0000000@4100640oooo00@0P820000000000000`<30o`3ooomZ0?ooo`80000000<0
P8200?ooo`3oool0K03oool00`30`<00P82000000004000000030410@030`<00oooo02D0oooo00@0
@410000000000000P820HP3oool006@0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0M0?ooo`030820P000000000000640oooo0P0000000`20P800oooo0?ooo`3o0?ooofT0oooo00<0
P820000000000000L@3oool7000002D0oooo0`00001S0?ooo`00H`3oool00`20P800000000000002
000000030820P030`<00oooo01h0oooo00<0`<30000000000000H03oool00`10@40000000000003o
0?ooof`0oooo00@0P820000000000000`<30CP3oool00`20P80000000?ooo`0P0?ooo`030<30`020
P800000000@0000000<0@4100<30`03oool0803oool00`30`<00@4100000001T0?ooo`00HP3oool0
1@10@4000000000000000000P82002<0oooo0P0000000`20P800oooo0?ooo`1L0?ooo`040<30`000
000000000<30`?l0ooooK03oool01030`<00000000000010@41<0?ooo`030820P010@40000000080
00008`3oool00`30`<00@41000000003000000030410@020P800oooo08D0oooo001R0?ooo`030<30
`0000000P82002D0oooo00<0P820000000000000GP3oool00`10@40000000820P03o0?ooofh0oooo
00@0@410000000000000`<30BP3oool01@10@4000000000000000000`<3002H0oooo00<0`<300820
P010@400100000000`10@400`<300?ooo`220?ooo`00RP3oool00`20P80000000000001M0?ooo`03
0820P000000000000?l0ooooK`3oool01020P800000000000020P8190?ooo`@00000:`3oool00`20
P80000000000000400000880oooo002:0?ooo`040<30`000000000000820P5`0oooo00<0@4100000
0030`<00o`3ooom`0?ooo`<00000B@3oool00`20P80000000820P00]0?ooo`030<30`020P800@410
00@0000000<0@4100<30`03oool0OP3oool008/0oooo0P0000000`20P800oooo0?ooo`1I0?ooo`80
000000<0@4100?ooo`3oool0o`3ooom`0?ooo`80000000<0`<300?ooo`3oool0N@3oool00`30`<00
@41000000004000000030820P03oool0oooo07/0oooo002;0?ooo`80000000<0@4100?ooo`3oool0
F03oool00`10@40000000000003o0?ooog<0oooo00<0@41000000010@400OP3oool00`30`<00@410
00000003000000030410@020P800oooo07T0oooo001F0?ooo`030820P0000000oooo0380oooo00<0
P820000000000000FP3oool2000000030820P03oool0oooo0?l0ooooL@3oool00`20P80000000000
00200?ooo`030820P0000000000000@00000N@3oool005@0oooo00D0P82000000000000000000<30
`00b0?ooo`030820P0000000000005T0oooo00<0@410000000000000o`3ooome0?ooo`<00000P@3o
ool00`30`<00@41000000003000000030410@020P800oooo07D0oooo001B0?ooo`030<30`0000000
00000080000000<0@4100<30`03oool0<@3oool01020P800000000000030`<1G0?ooo`030<30`000
000000000?l0ooooMP3oool01020P800000000000020P8220?ooo`030<30`020P800@41000@00000
00<0P8200<30`03oool0LP3oool00540oooo00H0P82000000000000000000820P030`<0e0?ooo`80
000000<0P8200?ooo`3oool0E@3oool00`10@40000000<30`03o0?ooogL0oooo0P0000000`10@400
oooo0?ooo`0h0?ooo`030<30`0000000`<3004P0oooo00<0`<300410@0000000100000000`20P800
oooo0?ooo`020?ooo`030820P03oool0oooo06X0oooo001B0?ooo`80000000<0P8200?ooo`3oool0
=@3oool2000000030820P03oool0oooo05D0oooo0P00003o0?ooogP0oooo0`00000i0?ooo`<00000
00<0P8200?ooo`3oool0B@3oool00`20P800000000000003000000030820P03oool0P82000800000
J`3oool00580oooo00<0P8200<30`03oool0=`3oool00`20P80000000000001F0?ooo`<00000o`3o
oomh0?ooo`040820P000000000000820P3L0oooo00D0@41000000000000000000410@01<0?ooo`03
0<30`010@400000000H0000000<0@4100?ooo`3oool0J@3oool008`0oooo00<0P820000000000000
E@3oool01020P800000000000020P83o0?ooogT0oooo0`00000e0?ooo`030<30`010@40000000080
000000<0`<300?ooo`3oool0CP3oool00`30`<00@41000000003000000030820P03oool0oooo06T0
oooo002<0?ooo`040820P000000000000<30`5@0oooo0`00003o0?ooog/0oooo0P0000000`20P800
oooo0?ooo`0b0?ooo`040410@000000000000820P5@0oooo00@0@410000000000000@4100`000000
0`20P800oooo0?ooo`1V0?ooo`00S@3oool2000000030820P03oool0oooo0580oooo0P0000000`20
P800oooo0?ooo`3o0?ooogT0oooo00<0P820000000000000=@3oool00`000000P8200?ooo`1D0?oo
o`<0000000<0P8200000000000001000001V0?ooo`00S@3oool2000000030820P03oool0oooo0540
oooo00@0P820000000000000`<30o`3ooomk0?ooo`040<30`000000000000820P8X0oooo00L0P820
000000000000@4100?ooo`30`<00P82000D00000I@3oool004D0oooo00<0P8200410@020P800A@3o
ool00`20P80000000410@01C0?ooo`80000000<0P8200?ooo`3oool0o`3ooomk0?ooo`040410@000
000000000<30`8T0oooo0`0000000`30`<00oooo0?ooo`020?ooo`040<30`020P80000000820P6D0
oooo00130?ooo`030<30`0000000000000800000A@3oool00`20P80000000000001B0?ooo`800000
00<0@4100?ooo`3oool0o`3oooml0?ooo`040<30`00000000000000008P0oooo00<0P82000000000
0000K`3oool00480oooo00<0P8200000000000000P0000170?ooo`800000DP3oool2000000030820
P03oool0oooo0?l0ooooO@3oool01020P800000000000020P8270?ooo`80000000<0P8200?ooo`3o
ool0K@3oool00400oooo00<0`<300820P00000000P0000000`20P800oooo0?ooo`160?ooo`030410
@000000000000500oooo00<0P820000000000000o`3ooon00?ooo`040<30`000000000000410@8H0
oooo0`0000000`30`<00oooo0?ooo`1]0?ooo`00@@3oool2000000030820P03oool0oooo04P0oooo
00<0P820000000000000D03oool2000000030820P03oool0oooo0?l0ooooO`3oool01020P8000000
00000020P80V0?ooo`030820P03oool0oooo05/0oooo00@0P820000000000000P8205@3oool00`30
`<0000000820P01H0?ooo`00SP3oool01020P800000000000030`<1>0?ooo`030820P00000000000
0?l0ooooP`3oool00`20P80000000000000T0?ooo`040<30`010@40000000820P5`0oooo0`00000F
0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0D`3oool008l0oooo0P0000000`20
P800oooo0?ooo`1<0?ooo`800000o`3ooon50?ooo`<000008`3oool4000005/0oooo00@0P8200000
00000000P8205`3oool6000005@0oooo002?0?ooo`80000000<0P8200?ooo`3oool0B`3oool00`30
`<0000000000003o0?ooohD0oooo00@0@410000000000000`<30803oool01@30`<00000000000000
0000@41005`0oooo00@0@410000000000000`<30603oool00`30`<00P82000000002000005@0oooo
002?0?ooo`80000000<0@4100?ooo`3oool0B`3oool00`20P80000000000003o0?ooohD0oooo00@0
`<3000000000000000007`3oool01@10@4000000000000000000`<3005`0oooo00@0`<3000000000
0000P820703oool20<30`5@0oooo002?0?ooo`030820P0000000000004d0oooo0P0000000`20P800
oooo0?ooo`3o0?oooh@0oooo00@0P820000000000000P8207P3oool01020P800000000000020P81M
0?ooo`<00000L`3oool008l0oooo00<0P820000000000000C@3oool2000000030820P03oool0oooo
0?l0ooooQ03oool01030`<00000000000010@40N0?ooo`030<30`010@400P82005d0oooo00@0P820
000000000000`<30L`3oool008l0oooo00@0`<30000000000000P820B`3oool01020P80000000000
0030`<3o0?ooohL0oooo00@0P820000000000000P820O03oool01030`<00000000000000000[0?oo
o`030<30`020P800oooo04H0oooo002@0?ooo`80000000<0P8200?ooo`3oool0B@3oool300000?l0
ooooR@3oool00`20P80000000000001l0?ooo`040410@000000000000<30`2/0oooo0`0000000`20
P800`<300?ooo`130?ooo`00T03oool2000000030820P03oool0oooo04T0oooo0P0000000`20P800
oooo0?ooo`3o0?ooohP0oooo0`00001k0?ooo`<00000:`3oool00`20P800000000000004000004<0
oooo002@0?ooo`030820P0000000000004X0oooo00@0P820000000000000P820o`3ooon:0?ooo`03
0410@0000000000007X0oooo00@0P820000000000000P820;03oool00`30`<00P820000000040000
0480oooo002A0?ooo`800000BP3oool01020P800000000000030`<3o0?ooohX0oooo00@0`<300000
00000000@410N@3oool300000300oooo00@0`<300410@0000000P820@P3oool00940oooo00<0@410
000000000000B@3oool300000?l0ooooS03oool01010@400000000000020P81g0?ooo`030820P000
0000000007L0oooo002A0?ooo`030820P0000000000004T0oooo0P0000000`20P800oooo0?ooo`3o
0?oooh/0oooo0`00000@0?ooo`0300000020P800oooo06@0oooo0P0000000`20P800oooo0?ooo`1e
0?ooo`00T@3oool01020P800000000000030`<170?ooo`040<30`000000000000820P?l0ooooS@3o
ool01020P800000000000020P80=0?ooo`050<30`010@400000000000030`<00H`3oool01020P800
000000000030`<1g0?ooo`00TP3oool2000000030820P03oool0oooo04D0oooo00<0P82000000000
0000o`3ooon?0?ooo`040<30`000000000000820P0/0oooo00D0P82000000000000000000410@01S
0?ooo`040<30`000000000000410@7P0oooo002B0?ooo`<00000A`3oool00`10@40000000000003o
0?oooi00oooo00@0@410000000000000`<30203oool01@30`<00@410000000000000@41006D0oooo
00@0@410000000000000`<30N03oool00980oooo00<0P820000000000000A`3oool200000?l0oooo
TP3oool3000000P0oooo1000001V0?ooo`<00000N@3oool00980oooo00@0P820000000000000`<30
AP3oool200000?l0ooooTP3oool01010@400000000000020P8070?ooo`040<30`0000000P8200<30
`6D0oooo00@0P820000000000000P820N@3oool009<0oooo0P0000000`20P800oooo0?ooo`140?oo
o`800000o`3ooonC0?ooo`<0000000<0`<300?ooo`3oool0K@3oool3000007X0oooo002C0?ooo`03
0820P0000000000004D0oooo00<0P82000000020P800o`3ooonD0?ooo`030410@0000000000006h0
oooo00<0P820000000000000N`3oool009@0oooo0P0000150?ooo`030820P0000000P8200?l0oooo
U03oool01020P800000000000000001]0?ooo`80000000<0P8200?ooo`3oool0N@3oool009@0oooo
0P0000000`30`<00oooo0?ooo`120?ooo`030410@0000000P8200?l0ooooU@3oool01010@4000000
00000020P81[0?ooo`040820P000000000000<30`7/0oooo002D0?ooo`030820P0000000P82004@0
oooo0P0000000`20P800oooo0?ooo`3o0?oooi@0oooo0`0000000`30`<00oooo0?ooo`1W0?ooo`04
0<30`000000000000410@7`0oooo002D0?ooo`030820P0000000@41004@0oooo0P0000000`30`<00
oooo0?ooo`3o0?oooi<0oooo00D0`<3000000000000000000410@01Y0?ooo`040410@00000000000
0<30`7`0oooo002E0?ooo`800000A03oool200000?l0ooooUP3oool5000000030820P03oool0oooo
06H0oooo0`00001m0?ooo`00U@3oool2000000030820P03oool0oooo0400oooo00<0P82000000000
0000o`3ooonD0?ooo`050820P0000000000000000020P8000P10@41X0?ooo`040820P00000000000
0820P7d0oooo002E0?ooo`030820P000000000000480oooo0`00003o0?oooi<0oooo00D0@4100000
00000000@4100<30`01[0?ooo`<00000OP3oool009D0oooo00@0P820000000000000`<30@@3oool2
000000030820P03oool0oooo0?l0ooooT03oool01010@400000000000010@41/0?ooo`030820P000
0000000007l0oooo002F0?ooo`80000000<0P8200?ooo`3oool0?`3oool2000000030820P03oool0
oooo0?l0ooooS`3oool01020P800000000000000001]0?ooo`80000000<0P8200?ooo`3oool0O@3o
ool009H0oooo0P0000000`10@400oooo0?ooo`0o0?ooo`80000000<0P8200?ooo`3oool0o`3ooon>
0?ooo`040820P000000000000410@6d0oooo00@0P820000000000000`<30O`3oool009H0oooo00<0
P820000000000000@03oool00`20P80000000000003o0?oooi00oooo00@0P820000000000000@410
K@3oool01030`<00000000000010@4200?ooo`00UP3oool01020P800000000000020P80o0?ooo`03
0820P000000000000?l0ooooS`3oool01020P800000000000000001^0?ooo`040820P00000000000
0820P800oooo002G0?ooo`80000000<0@4100?ooo`3oool0?@3oool00`20P80000000000003o0?oo
ohh0oooo00D0`<3000000000000000000<30`01^0?ooo`<00000P@3oool009L0oooo00<0P8200000
00000000?`3oool00`20P80000000000003o0?ooohd0oooo00@0P820000000000000@410K`3oool0
1020P800000000000020P8210?ooo`00V03oool2000000030820P03oool0oooo03`0oooo00<0P820
000000000000o`3ooon<0?ooo`040410@000000000000410@1<0oooo00<0@4100000003oool0FP3o
ool300000880oooo002H0?ooo`030820P0000000P82003h0oooo00<0P820000000000000o`3ooon;
0?ooo`040820P00000000000000001<0oooo0`0000000`20P800oooo0?ooo`1G0?ooo`030820P000
0000000008<0oooo002H0?ooo`030820P0000000@41003h0oooo00<0P820000000000000o`3ooon:
0?ooo`050<30`0000000000000000030`<004`3oool01030`<00000000000000001I0?ooo`030410
@0000000@41008<0oooo002I0?ooo`800000?P3oool00`20P80000000000003o0?ooohT0oooo00@0
P820000000000000@4105P3oool01010@400000000000010@41G0?ooo`040820P000000000000<30
`8<0oooo002I0?ooo`030410@0000000000003d0oooo00<0P820000000000000o`3ooon70?ooo`05
0<30`0000000000000000030`<00603oool01020P800000000000030`<1E0?ooo`040<30`0000000
00000410@8@0oooo002I0?ooo`030820P0000000000003d0oooo00<0P820000000000000o`3ooon7
0?ooo`<0000000<0P8200?ooo`3oool0603oool3000005D0oooo00@0P820000000000000P820Q03o
ool009T0oooo00@0`<30000000000000P820?03oool00`20P80000000000000B0?ooo`030820P030
`<00oooo0?l0ooooL@3oool01010@400000000000020P80K0?ooo`030<30`0000000`<3005D0oooo
00<0@410000000000000Q@3oool009X0oooo0P0000000`10@400oooo0?ooo`0j0?ooo`030820P000
000000000140oooo00@0P820000000000000`<30o`3ooom_0?ooo`050<30`0000000000000000030
`<00L`3oool01030`<00000000000010@4250?ooo`00VP3oool00`20P80000000000000l0?ooo`03
0820P000000000000100oooo00@0`<30000000000000@410o`3ooom_0?ooo`050<30`00000000000
00000030`<00M03oool01010@400000000000030`<250?ooo`00VP3oool01020P800000000000020
P80k0?ooo`030820P000000000000100oooo0`0000000`20P800oooo0?ooo`3o0?ooofd0oooo0`00
00000`20P800oooo0?ooo`1c0?ooo`<00000QP3oool009/0oooo0P0000000`20P800oooo0?ooo`0i
0?ooo`030410@0000000000000l0oooo00@0`<30000000000000@410o`3ooom_0?ooo`040410@000
000000000820P7D0oooo00<0P820000000000000Q`3oool009/0oooo00<0P820000000000000>`3o
ool3000000l0oooo00@0@410000000000000`<30o`3ooom]0?ooo`050<30`0000000000000000030
`<00MP3oool2000000030820P03oool0oooo08D0oooo002L0?ooo`80000000<0P8200?ooo`3oool0
>03oool3000000l0oooo00<0`<300000003oool0o`3ooom]0?ooo`050<30`0000000000000000030
`<00MP3oool3000008P0oooo002L0?ooo`030820P0000000000003X0oooo0`00003o0?ooogl0oooo
0`0000000`20P800oooo0?ooo`1e0?ooo`80000000<0P8200?ooo`3oool0QP3oool009`0oooo00@0
`<30000000000000P820>@3oool00`20P80000000000003o0?ooogd0oooo00D0P820000000000000
00000820P01g0?ooo`040820P000000000000820P8P0oooo002M0?ooo`<00000>@3oool00`20P800
00000000003o0?ooog`0oooo00D0@410000000000000@4100<30`00]0?ooo`040<30`010@4000000
0<30`4L0oooo0`0000290?ooo`00W@3oool01020P800000000000020P80h0?ooo`040<30`0000000
00000<30`?l0ooooNP3oool01010@400000000000010@40`0?ooo`040410@000000000000<30`4D0
oooo00@0P820000000000000P820R@3oool009h0oooo0`00000i0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooomg0?ooo`040820P0000000000000000380oooo0P0000000`20P800oooo0?ooo`130?oo
o`<00000RP3oool009h0oooo0`0000000`30`<00oooo0?ooo`0f0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooomf0?ooo`040820P000000000000410@3@0oooo0P0000000`30`<00oooo0?ooo`110?oo
o`040<30`000000000000820P8X0oooo002N0?ooo`040<30`000000000000410@3P0oooo0P000000
0`20P800oooo0?ooo`3o0?ooogD0oooo00@0@410000000000000@410=@3oool01030`<0000000000
0020P8120?ooo`030410@0000000@41008/0oooo002O0?ooo`040820P000000000000<30`3L0oooo
0P0000000`20P800oooo0?ooo`3o0?ooog@0oooo00@0@410000000000000@410=`3oool00`30`<00
@4100?ooo`110?ooo`040820P000000000000<30`8/0oooo002P0?ooo`80000000<0P8200?ooo`3o
ool0=@3oool2000000030820P03oool0oooo0?l0ooooL`3oool4000007`0oooo0`00002<0?ooo`00
X03oool00`20P80000000000000g0?ooo`80000000<0P8200?ooo`3oool0103oool00`30`<00P820
0?ooo`3o0?ooof/0oooo00@0@410000000000000@410O03oool01030`<00000000000020P82<0?oo
o`00X@3oool3000003H0oooo0P0000000`20P800oooo0?ooo`040?ooo`030410@0000000P8200?l0
ooooJP3oool01010@400000000000010@41m0?ooo`040410@000000000000<30`8`0oooo002Q0?oo
o`040820P000000000000820P3D0oooo0P0000000`20P800oooo0?ooo`030?ooo`<00000o`3ooomZ
0?ooo`040820P00000000000000007h0oooo0`00002=0?ooo`00X@3oool01030`<00000000000010
@40f0?ooo`800000103oool01030`<00000000000020P83o0?ooofP0oooo00D0`<300820P0000000
00000410@01n0?ooo`040820P000000000000820P8d0oooo002R0?ooo`030410@0000000000003H0
oooo0P0000030?ooo`040<30`000000000000410@?l0ooooJ03oool01@30`<000000000000000000
@41007l0oooo0`00002>0?ooo`00XP3oool01030`<00000000000030`<0e0?ooo`8000000`3oool0
1010@400000000000030`<3o0?ooofL0oooo00D0`<3000000000000000000<30`01o0?ooo`<00000
00<0P8200?ooo`3oool0S03oool00:<0oooo0`00000e0?ooo`800000103oool00`000000oooo0?oo
o`3o0?ooofL0oooo0`0000210?ooo`<00000S`3oool00:@0oooo0P0000000`30`<00oooo0?ooo`0b
0?ooo`80000000<0`<300?ooo`3oool0o`3ooomY0?ooo`050<30`0000000000000000030`<00BP3o
ool00`20P80000000<30`00c0?ooo`040820P000000000000820P8l0oooo002T0?ooo`030820P000
0000000003@0oooo0P0000000`20P800oooo0?ooo`3o0?ooofP0oooo00D0`<300000000000000000
0<30`01:0?ooo`050<30`0000000000000000030`<00<P3oool00`10@40000000000002@0?ooo`00
Y@3oool3000003<0oooo00<0P82000000010@400o`3ooomY0?ooo`050<30`0000000000000000030
`<00C@3oool00`10@40000000410@00a0?ooo`040<30`000000000000410@900oooo002U0?ooo`04
0820P000000000000820P380oooo00<0P820000000000000o`3ooomY0?ooo`<00000D03oool30000
0300oooo00@0P820000000000000P820T03oool00:D0oooo00@0`<300000000000000000<P3oool0
0`10@40000000820P03o0?ooofL0oooo00D0`<3000000000000000000<30`01@0?ooo`040410@000
000000000410@2l0oooo0`00002A0?ooo`00YP3oool01010@400000000000020P80_0?ooo`050<30
`0000000000000000030`<00o`3ooomV0?ooo`050410@0000000000000000030`<00DP3oool00`10
@40000000<30`00^0?ooo`030820P000000000000980oooo002W0?ooo`<0000000<0`<300?ooo`3o
ool0:`3oool01@30`<000000000000000000`<300?l0ooooIP3oool01@10@400000000000020P800
`<3008@0oooo00<0@41000000020P800TP3oool00:P0oooo0P0000000`20P800oooo0?ooo`0[0?oo
o`<0000000<0P8200?ooo`3oool0o`3ooomT0?oooc400000F@3oool2000000030820P03oool0oooo
0900oooo002X0?ooo`030<30`0000000000002`0oooo00@0@410000000000000P820o`3ooomU0?oo
od8000001`20P8000`30`<00oooo0?ooo`0o0?ooo`<00000T`3oool00:T0oooo00@0@41000000000
0000`<30:03oool01@10@4000000000000000000`<300?l0ooooD`3oool7000000030820P03oool0
oooo00T0oooo00<0P820000000000000100000000`10@400P8200820P0090820P0030410@0000000
000000@0000000<0@4100820P020P8005P20P80P000000030410@020P800P82000<0P820<@3oool0
1020P800000000000020P82C0?ooo`009`3oool00`10@40000000<30`0200?ooo`040410@0000000
00000<30`2H0oooo00D0@41000000000000000000<30`03B0?ooo`040<30`000000000000<30`6X0
oooo1`0000000`30`<00oooo0?ooo`090?ooo`L0000000<0P8200?ooo`3oool0B`3oool70820P003
0410@0000000000001<000001@20P80V0?ooo`030410@0000000000009@0oooo000X0?ooo`800000
P@3oool3000002D0oooo00D0P82000000000000000000820P03D0?ooo`030820P0000000000005L0
oooo1`00000<0?ooo`L0000000<0P8200?ooo`3oool0K@3oool00`20P80000000000000D00000003
0820P03oool0oooo01l0oooo0`00002D0?ooo`00:03oool01030`<00000000000030`<200?ooo`03
0410@0000000@41002<0oooo00@0P820000000000000@410e`3oool00`20P80000000410@01F0?oo
o`L00000303oool70820P0030<30`03oool0oooo07D0oooo1P20P8000`10@40000000000000:0000
00@0P8206@3oool01020P800000000000020P82D0?ooo`00:@3oool00`10@4000000000000200?oo
o`050<30`0000000000000000030`<007`3oool01@30`<000000000000000000@4100=T0oooo00<0
@410000000000000@@3oool00`20P800000000000005000000`0oooo1`20P82E0?ooo`<0P82000<0
00000820P010@4003@0000001010@400P8200820P020P80?0?ooo`<00000U@3oool001T0oooo00@0
`<300820P020P800`<303@3oool2000000030410@03oool0oooo07h0oooo00D0`<30000000000000
00000<30`00M0?ooo`050<30`0000000000000000030`<00c03oool01030`<00P8200820P020P80;
0?ooo`80000000<0@4100?ooo`3oool0<03oool00`30`<00P8200820P00<0?ooo`L00000?`3oool0
0`20P800`<300?ooo`1X0?ooo`040410@000000000000<30`0<0oooo1020P80;000000@0P8202@3o
ool00`30`<0000000000002F0?ooo`00603oool00`20P800000000000002000000040820P03oool0
oooo0820P080000000<0P8200?ooo`3oool01@3oool200000840oooo00D0P8200000000000000000
0820P00K0?ooo`@000002`3oool01020P800000000000020P82i0?ooo`030820P000000000000080
oooo1P00000:0?ooo`030820P000000000000380oooo00<0P820000000000000D@3oool00`20P800
00000000001Y0?ooo`040820P00000000000000000T0oooo00<0P8200000000000003@0000000`20
P800oooo0?ooo`030?ooo`030820P0000000000009H0oooo000G0?ooo`030<30`0000000000000D0
000000D0`<3000000000000000000<30`0070?ooo`030410@0000000P8200840oooo00D0P8200000
0000000000000820P00H0?ooo`050<30`010@400000000000010@4003@3oool300000;T0oooo00D0
P820000000000000oooo0410@007000000030<30`03oool0oooo00H0oooo00@0`<30000000000000
P820<P3oool200000500oooo00D0`<3000000000000000000<30`01Y0?ooo`040410@00000000000
0410@0h0oooo0`20P80:000000030410@020P800P8200080000000<0P8200?ooo`3oool0U03oool0
01L0oooo00@0@410000000000000P8200P3oool00`20P800000000000003000000P0oooo00<0P820
000000000000PP3oool01P30`<000000000000000000@4100<30`1@0oooo00<0P8200410@0000000
0P0000000`30`<00oooo0?ooo`0=0?ooo`800000^@3oool01P20P800000000000020P80000000820
P0<0oooo00D0P82000000000000000000<30`0080?ooo`<00000P`3oool01@10@400000000000020
P800`<3006/0oooo00@0P820000000000000@410503oool30820P0/00000U03oool001L0oooo0P00
00000`20P800oooo0?ooo`030?ooo`040410@00000000000000000T0oooo0P0000000`20P800oooo
0?ooo`210?ooo`060410@0000000000000000010@400P8203`3oool00`30`<00P820000000030000
00030410@020P800oooo00l0oooo0P0000000`20P800oooo0?ooo`2f0?ooo`050820P00000000000
00000020P8001@3oool01020P800000000000010@4090?ooo`80000000<0`<300?ooo`3oool0OP3o
ool01@30`<000000000000000000`<3006h0oooo00<0`<3000000010@4006P3oool40820P0<00000
00<0@4100?ooo`3oool0TP3oool001L0oooo0P0000000`20P800oooo0?ooo`030?ooo`040820P000
00000000000000T0oooo0`0000250?ooo`030820P00000000000008000003@3oool6000000030820
P03oool0oooo0100oooo00<0P82000000020P800^03oool01020P80000000000000000070?ooo`<0
00002@3oool2000000030820P03oool0oooo07l0oooo0P0000000`20P800oooo0?ooo`1^0?ooo`03
0820P03oool0oooo0;D0oooo000G0?ooo`030410@0000000000000H0oooo0`0000090?ooo`<00000
QP3oool00`20P800000000000003000000030410@020P800`<3000@0oooo0P20P8000`10@4000000
00000003000000030820P030`<00oooo0180oooo00<0P82000000010@400^03oool01020P8000000
0000000000070?ooo`040820P000000000000<30`0P0oooo0P0000000`20P800oooo0?ooo`1o0?oo
o`030820P030`<00oooo09l0oooo00<0P8200000000000000P20P8240?ooo`005`3oool01P30`<00
0000000000000000@4100<30`0<0oooo0`0000090?ooo`040820P000000000000820P8H0oooo00<0
`<300820P00000003P0000000`20P800`<300?ooo`0E0?ooo`030<30`000000000000;P0oooo00<0
P8200000000000002@3oool2000000030820P03oool0oooo00H0oooo00<0P820000000000000o`3o
oolT0?ooo`030410@0000000000000@0000000<0P8200?ooo`3oool0O`3oool001P0oooo00<0P820
00000000000010000000103oool000000000000000090?ooo`040820P000000000000820P8/0oooo
2P00003E0?ooo`030820P0000000000000T0oooo0P0000000`20P800oooo0?ooo`060?ooo`030820
P000000000000?l0oooo903oool7000000030820P03oool0oooo07l0oooo000I0?ooo`80P8202000
00090?ooo`040820P000000000000820P8d0oooo1P20P83G0?ooo`030820P0000000000000T0oooo
0P0000000`20P800oooo0?ooo`060?ooo`030820P000000000000?l0oooo9`3oool01030`<00P820
0820P020P8220?ooo`00703oool00`30`<00P8200820P004000000T0oooo00@0P820000000000000
P820o`3ooom[0?ooo`030820P0000000000000T0oooo0P0000000`20P800oooo0?ooo`060?ooo`03
0820P000000000000?l0oooo[@3oool00200oooo0`0000090?ooo`040820P000000000000820P?l0
ooooJ`3oool01020P800000000000020P8080?ooo`80000000<0P8200?ooo`3oool01P3oool00`20
P80000000000003o0?ooojd0oooo000P0?ooo`<000002@3oool01020P800000000000020P83o0?oo
of/0oooo00@0P82000000000000000001`3oool3000000T0oooo00<0P820000000000000o`3oool0
0`000000oooo0?ooo`2Z0?ooo`005`3oool20820P0030<30`03oool0oooo00@0oooo0`0000090?oo
o`040820P000000000000820P?l0ooooJ`3oool01@20P8000000000000000000`<3000H0oooo0`00
00090?ooo`030820P0000000000007H0oooo00<0P8200000003oool0Q@3oool00`20P80000000410
@02[0?ooo`005`3oool00`10@40000000410@0050?ooo`040<30`00000000000000000T0oooo0`00
003o0?ooof`0oooo00D0P82000000000000000000410@0050?ooo`040410@000000000000820P0T0
oooo0P0000000`20P800oooo0?ooo`1b0?ooo`050<30`0000000000000000030`<00Q03oool01@30
`<000000000000000000@4100:X0oooo000G0?ooo`050<30`0000000000000000010@4000P20P804
000000X0oooo0`00003o0?ooof`0oooo00H0P820000000000000oooo0410@00000030820P0<00000
00<0@4100?ooo`3oool0203oool2000000030820P03oool0oooo0740oooo00D0`<30000000000000
P8200<30`0270?ooo`050<30`0000000000000000030`<002@3oool00`10@40000000<30`02L0?oo
o`00603oool00`20P800000000000006000000030820P03oool0oooo00P0oooo0P00003o0?ooofd0
oooo00D0P820000000000000oooo0820P007000000/0oooo0P00001c0?ooo`<0000000<0P8200?oo
o`3oool0R03oool01020P800000000000020P8090?ooo`80000000<0P8200?ooo`3oool0VP3oool0
01T0oooo0P20P804000000030410@020P800oooo00T0oooo00<0P820000000000000o`3ooom]0?oo
o`030820P000000000000080oooo00<0`<300410@00000000P0000000`20P800oooo0?ooo`090?oo
o`<00000LP3oool01030`<00000000000010@42<0?ooo`030<30`020P800oooo00P0oooo00<0P820
000000000000W@3oool002/0oooo00<0@41000000020P800o`3ooom]0?ooo`030820P00000000000
0180oooo00@0`<30000000000000P820L`3oool00`20P800`<300?ooo`2G0?ooo`800000WP3oool0
02X0oooo00<0P820000000000000]`3oool20820P;@0oooo00<0P8200000000000004P3oool00`10
@40000000000003o0?ooo`h0oooo00<0P82000000020P800WP3oool002X0oooo0P0000000`20P800
oooo0?ooo`2e0?ooo`80000000<0P8200?ooo`3oool0/@3oool00`20P80000000000000B0?ooo`80
000000<0P8200?ooo`3oool0o`3oool<0?ooo`030820P0000000oooo09h0oooo000Y0?ooo`030410
@000000000000;P0oooo00<0P82000000010@400/`3oool00`20P80000000000000A0?ooo`030410
@000000000000?l0oooo3`3oool00`20P80000000?ooo`2N0?ooo`00:03oool01030`<0000000000
0030`<2h0?ooo`040<30`000000000000<30`;80oooo00<0P820000000000000403oool00`20P800
00000410@03o0?oook40oooo000W0?ooo`030<30`0000000@4100;/0oooo0P0000000`20P800oooo
0?ooo`2`0?ooo`030820P0000000000000l0oooo00<0@41000000010@400o`3ooonb0?ooo`009`3o
ool200000;d0oooo0P0000330?ooo`030820P0000000000006d0oooo0P20P83o0?oood@0oooo003V
0?ooo`80000000<0`<300?ooo`3oool0o`3oool_0?ooo`040<30`000000000000410@?l0ooooA03o
ool00>H0oooo00<0`<300820P030`<00o`3oool`0?ooo`050410@000000000000410@030`<00o`3o
oom40?ooo`00o`3ooooo0?oooaP0oooo00D0P8200410@0000000@4100820P03o0?ooodH0oooo003o
0?ooool0oooo6@3oool200000?l0ooooB03oool00?l0ooooo`3ooolI0?ooo`030820P030`<00oooo
0?l0ooooA`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?oook/0oooo00<0P8200000003oool0Y03oool00?l0ooooo`3ooonk0?ooo`<00000Y03oool0
0?l0ooooo`3ooonj0?ooo`040820P000000000000820P:@0oooo003o0?ooool0oooo^P3oool00`10
@40000000000002U0?ooo`00o`3ooooo0?oookX0oooo0`00002U0?ooo`00j`3oool00`30`<00@410
0000003o0?ooolX0oooo00<0P820000000000000YP3oool00>/0oooo00@0`<30000000000000P820
o`3oooo90?ooo`80000000<0P8200?ooo`3oool0Y03oool00>`0oooo0`00003o0?ooolX0oooo00<0
00000?ooo`3oool0Y@3oool00>`0oooo00@0P820000000000000`<30o`3ooooo0?ooog80oooo003]
0?ooo`80000000<0@4100?ooo`3oool0o`3ooooo0?ooog00oooo003^0?ooo`80000000<0`<300?oo
o`3oool0o`3ooooo0?ooofl0oooo003^0?ooo`030820P0000000P8200?l0ooooo`3oooma0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?oook<0oooo00@0`<3000000010@400`<30Z`3oool00?l0ooooo`3o
oonc0?ooo`040820P000000000000820P:/0oooo003o0?ooool0oooo/`3oool2000000030410@03o
ool0oooo0:X0oooo003o0?ooool0oooo/P3oool01020P800000000000030`<2/0?ooo`00m03oool0
0`30`<00P8200000003o0?oookX0oooo0P0000000`20P800oooo0?ooo`2[0?ooo`00m@3oool20000
00030820P03oool0oooo0?l0oooo]`3oool200000:h0oooo003e0?ooo`040820P000000000000<30
`?l0oooo]`3oool00`30`<00@4100820P02^0?ooo`00mP3oool00`10@40000000410@03o0?ooool0
ooooJ@3oool00?L0oooo0`00003o0?ooool0ooooJ03oool00?L0oooo00@0P820000000000000P820
o`3ooooo0?ooofL0oooo003g0?ooo`030<30`020P800oooo0?l0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?oooj`0oooo00<0P8200<30`03oool0/`3oool00?l0ooooo`3ooon[0?ooo`04
0820P000000000000820P;<0oooo003o0?ooool0ooooZ`3oool300000;@0oooo003o0?ooool0oooo
Z`3oool2000000030820P03oool0oooo0;80oooo003o0?ooool0ooooZP3oool01020P80000000000
0020P82d0?ooo`00o`3ooooo0?ooojX0oooo0`00002e0?ooo`00o`3ooooo0?ooojT0oooo00<0P820
000000000000]P3oool00?l0ooooo`3ooonZ0?ooo`80P820]P3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3o
oomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0
ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o
0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0
oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo
0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0oooo
o`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool0
0?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0oooo
H`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?oo
ool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3o
oooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?oo
o`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{288, 125.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 6.1 Spatial domains (shown outlined by solid lines, and \
defined by the smooth dashed curves) for which (a) one can easily apply the \
Galerkin method;  (b) difficulties arise.\
\>", "Caption",
  CellTags->"Fig. 6.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.1.2 Boundary-Value Problems", "Subsubtitle",
  CellTags->{"i:4", "c:4"}],

Cell[CellGroupData[{

Cell["Theory", "Section",
  CellTags->"c:5"],

Cell["\<\
\t  Consider a time-independent boundary-value problem in two \
dimensions, \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(\[Phi](x, y)\)\  = \ \[Rho](x, y)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is some second order linear spatial operator such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  ".  We assume for the moment that the boundary conditions are Dirichlet, \
specified on the boundary ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " of a domain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(V\)\(\ \)\)\)]],
  "such as that shown in Fig.",
  ButtonBox[" 6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\( | \_S\)\) = \(\[Phi]\_o\)(x, y)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.2)"],

Cell[TextData[{
  "for some function  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_o\)(x, y)\)]],
  ". This function must be smoothly varying on the boundary in order for the \
Galerkin method to work efficiently. "
}], "Text"],

Cell[TextData[{
  "\tThe boundary is itself determined by the intersection of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " smooth curves, each of which is defined by an equation of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0, \ n = 1,  ... , M\)]],
  ".  "
}], "NumberedEquation",
  CellTags->"(6.1.3)"],

Cell[TextData[{
  "These curves are the lines shown schematically in Fig. ",
  ButtonBox["6.1(a)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tTo solve this problem numerically via the Galerkin method, we will \
expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " in a set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " different ",
  StyleBox["basis functions",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_\[Alpha]}\)]],
  ", chosen to satisfy homogeneous Dirichlet boundary conditions:"
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_\[Alpha]\)\( | \_S\)\) = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.4)"],

Cell["\<\
We write the solution in the standard form for an eigenmode \
expansion:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\  = \ 
        u(x, y)\  + \ \[Sum]\+\[Alpha]\( c\_\[Alpha]\) \(\(v\_\[Alpha]\)(x, 
                y)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.5)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " is any (smooth) function that satisfies the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u\)\( | \_S\)\) = \[Phi]\_o\)]],
  ", and where the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  "'s are the Fourier coefficients that must be determined. In order to find \
these coefficients, we substitute Eq. ",
  ButtonBox["(6.1.5)",
    ButtonData:>"(6.1.5)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.1.1)",
    ButtonData:>"(6.1.1)",
    ButtonStyle->"Hyperlink"],
  ", yielding"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( 
                c\_\[Alpha]\) \(L\&^\) \(\(v\_\[Alpha]\)(x, y)\) = \[Rho](x, 
            y) - \(L\&^\) \(u(x, y)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.6)"],

Cell[TextData[{
  "Next, we take an inner product with respect to one of the basis functions, \
",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Beta]\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( c\_\[Alpha]\)(
            v\_\[Beta], \(L\&^\) 
              v\_\[Alpha]) = \((v\_\[Beta], \[Rho] - \(L\&^\) u)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.7)"],

Cell[TextData[{
  "So far, the method is identical to an eigenmode expansion. However,  the \
",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s need ",
  StyleBox["not",
    FontSlant->"Italic"],
  " be eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "; and they need not even form an orthogonal set. Rather, they can be any \
set of functions that we choose, provided that in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`N \[Rule] \ \[Infinity]\)]],
  " they form a complete set, and provided that they satisfy Eq. ",
  ButtonBox["(6.1.4)",
    ButtonData:>"(6.1.4)",
    ButtonStyle->"Hyperlink"],
  ". (Also, it is preferable that the functions be as analytically simple in \
form as possible. )"
}], "Text"],

Cell[TextData[{
  "\tFurthermore, the inner product used in Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " can be ",
  StyleBox["any inner product over the domain V. ",
    FontSlant->"Italic"],
  "(Again, however, the simpler the better.)"
}], "Text"],

Cell[TextData[{
  "\tFor example, one possible choice for the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s is the following: let the iterator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " equal the set of integers ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  ", and take"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(i\ j\)\)(x, 
          y) = \(\(x\^i\) \(y\^j\) \(\[CapitalPi]\_\(n = 1\)\%M\) \(\(z\_n\)(
              x, y)\)\ \ for\ i = 0\), 1,  ... , P\_x\ ; \ j = 0, 1,  ... , 
      P\_y\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.8)"],

Cell["With this choice, the total number of functions is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`N = \((P\_x + 1)\) \((P\_y + 1)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.9)"],

Cell[TextData[{
  "The product of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  "'s implies that the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "'s  are zero on the boundary surface, and the polynomial form in ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", Cell[""]}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " provides a sufficient range of variation so that in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y\)]],
  " approach infinity, the basis functions form a complete set. "
}], "Text"],

Cell["\tFor the inner product, one simple choice is", "Text",
  CellTags->"i:6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \ \[Integral]\+V\(\( f\^*\)(x, y)\)\ \(g(x, 
              y)\) \[DifferentialD]x\ \[DifferentialD]y\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.10)"],

Cell[TextData[{
  "where the integral runs over the domain ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " of the problem. One could also choose ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \ \[Integral]\+V\(\( f\^*\)(x, y)\)\ \(g(x, y)\) \(p(x, 
              y)\) \[DifferentialD]x\ \[DifferentialD]y\)]],
  " for some choice of weighting function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, y) > 0\)]],
  ". But it is preferable that ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " does not weight any one region of the domain disproportionately (unless \
there are regions of the domain where the solution is zero, or nearly zero). \
Otherwise, the solution may not converge well."
}], "Text"],

Cell[TextData[{
  "\t There is a certain art to finding good choices for the basis functions \
and the inner product. What we are looking for are choices that minimize the \
number of terms required to get a well-converged expansion for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ", and that are sufficiently simple so that inner products in Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " can be easily evaluated. In other words, we want  a small number of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s to sum to something close to the exact solution."
}], "Text"],

Cell["\<\
\t   The best way to learn how to make good choices  is  by gaining \
experience with the method. We will work through several examples in this and \
later sections. \
\>", "Text"],

Cell[TextData[{
  "\t We now solve for the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  ". To do so, we note that for different ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  "-values, Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " forms a set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  Cell[BoxData[
      FormBox["", TraditionalForm]]],
  " linear equations in the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " unknowns ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["c", Cell["\[Alpha]"]], TraditionalForm]]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \((k, l)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \((i, j)\)\)]],
  ", these equations are rewritten explicitly in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, l)\)\)]],
  ":\t \t"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(k = 0\)\%\(P\_x\)\(\[Sum]\+\(l = \
0\)\%\(P\_y\)\((v\_\(i\ j\), \(L\&^\) v\_\(k\ l\))\) 
              c\_\(k\ l\)\) = \((v\_\(i\ j\), \[Rho] - \(L\&^\) u)\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1,  ... , P\_x, \ \ \ \ j = 0, 1,  ... , 
      P\_y\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.11)"],

Cell[TextData[{
  "Since the inner products in Eq. ",
  ButtonBox["(6.1.11)",
    ButtonData:>"(6.1.11)",
    ButtonStyle->"Hyperlink"],
  " are merely some integrals that we can find once we have chosen the basis \
functions, we know everything that we need in  order to solve these ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " coupled linear equations for the  ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  "'s. "
}], "Text"],

Cell[TextData[{
  "\tFrom a theory perspective, it may be of use to note that the inner \
product ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_\[Beta], \(L\&^\) v\_\[Alpha])\)\)]],
  " is the projection of the operator ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox["L",
            "TraditionalForm"], "^"], TraditionalForm]]],
  " onto the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Beta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  ", and that this projection is just another way to represent the operator \
numerically. We can think of this inner product as a square matrix ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\[Beta]\ \[Alpha]\)\)]],
  ", so that Eq. ",
  ButtonBox["(6.1.7)",
    ButtonData:>"(6.1.7)",
    ButtonStyle->"Hyperlink"],
  " becomes the matrix equation"
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\( L\_\(\[Beta]\ \[Alpha]\)\) 
            c\_\[Alpha] = \[Rho]\&_\_\[Beta]\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(6.1.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\[Beta] = \((v\_\[Beta], \ \[Rho] - \
\(L\&^\) u)\)\)]],
  ". We need merely invert the matrix to solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  "'s: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_\[Alpha]\), "=", 
          RowBox[{
            SubscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["L",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(-1\)], 
                ")"}], \(\[Alpha]\ \[Beta]\)], \(\[Rho]\&_\_\[Beta]\)}]}], 
        TraditionalForm]]],
  ". Thus, this method has much in common with the matrix inversion methods \
that we employed in solving linear boundary-value problems in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can now see why the boundary shown in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " are more difficult to treat. The basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Alpha]\)(x, y)\)]],
  " are zero along the smooth curves ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0\)]],
  " that define the bounding surface. These curves are displayed as the \
dashed lines in the figure. Because of the shape of the cusp in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ", two of the curves penetrate into the interior of the region, and so the \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  " are all zero along these curves. Therefore, they cannot form a complete \
set, since they must be able to represent arbitrary functions within the \
domain."
}], "Text"],

Cell[TextData[{
  "\tWhile it is possible to define boundary curves ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_n\)(x, y) = 0\)]],
  " that are not smooth,  forming concave cusps as shown in Fig. ",
  ButtonBox["6.1(b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  " without continuing into the interior of the domain (using nonanalytic \
functions in the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  ": see Example 3 below), such boundary curves introduce singular behavior \
into the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Alpha]\)]],
  "'s through Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ", and therefore the functions may not behave well when acted upon by ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " . Unless the functions ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\)]],
  " are carefully chosen to minimize the singular behavior, derivatives of \
these basis functions are not well behaved, and the generalized Fourier \
series solution does not converge very well.  "
}], "Text",
  CellTags->"i:7"],

Cell[TextData[{
  "\tHowever, we will see in Example 3 that even if care is taken in choosing \
mathematical forms for the boundary curves so as to minimize the singular \
behavior, the Galerkin method still faces difficulties when concave cusps are \
present. The reason is simple: such cusps introduce rapid variation in the \
solution.  Taking Poisson's equation as an example,  we noted in Exercise \
(5)(b) of Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:43"},
    ButtonStyle->"Hyperlink"],
  " that  the electric field near the point of a concave cusp becomes \
infinite. Such rapid variation in the derivative of \[Phi] requires a \
Galerkin solution that keeps a large number of basis functions.  "
}], "Text"],

Cell[TextData[{
  "\tFor essentially the same reason, it is difficult to deal with boundary \
conditions that are discontinuous. A situation where one electrode is held at \
potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  "  and an adjacent electrode is held at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_2\)]],
  " is difficult to treat with the Galerkin method, because the discontinuous \
boundary condition causes rapid variation in the solution that requires many \
basis functions to resolve."
}], "Text"],

Cell[TextData[{
  "\t When dealing with boundary conditions of the sort that cause rapid \
variation in the solution, it is often easier to use other methods, such as \
the grid methods discussed in Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:13",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Section",
  CellTags->"c:6"],

Cell[TextData[{
  "As an example of the Galerkin method, we will solve a problem that we \
could also do analytically, so that we can compare the numerical solution \
with the exact solution. The problem is to find the solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = 0\)]],
  " in a square box with the boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\  = \ 0\)]],
  " on the edges, except along ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y = 0\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], \(\[Phi](x, 0)\)}], 
          "=", \(\(sin\)\(\ \)\(\[Pi]\)\(\ \)\(x\)\(\ \)\)}], 
        TraditionalForm]]],
  ".  The exact solution for \[Phi], found by separation of variables, is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_exact\)(x, y)\  = \ 
        sin\ \[Pi]\ x\ \(sinh\ \(\[Pi](1 - y)\)\)\/\(sinh\ \[Pi]\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.13)"],

Cell[TextData[{
  "To find the solution via the Galerkin method, we first choose functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\)\)]],
  "  according to Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
          y\^j\ \ \ \ x\ y\ \((1 - x)\) \((1 - y)\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.1"],

Cell[TextData[{
  "These functions are zero along each edge of the box. Next, we define an \
inner product. Sometimes it is more convenient to evaluate these inner \
product integrals numerically rather than analytically, but in this case, \
analytic evaluation is faster.  However, even if one performs the integrals \
analytically, it is usually  best to convert any exact numbers to approximate \
numbers using ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "so that the solutions to the equations are not too complicated:"
}], "Text"],

Cell[BoxData[
    \(norm[f_, g_]\  := \ 
      Integrate[f\ \ g, {x, 0, 1}, {y, 0, 1}]\ \  // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.2"],

Cell[TextData[{
  " (Note the use of a delayed equal sign, since the integral cannot be \
performed until ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x, y)\)]],
  " are known.) "
}], "Text"],

Cell[TextData[{
  "\tNext, we choose a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " that matches the boundary conditions:"
}], "Text"],

Cell[BoxData[
    \(\(u[x_, y_]\  = \ \((1 - y)\)\ Sin[\ Pi\ x];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.3"],

Cell[TextData[{
  "This function is indeed zero on the three sides defined by ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, \ x = 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  ", and it equals ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ \[Pi]\ x\)]],
  " on the remaining side ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt is also useful to define the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Del]\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(L[f_]\  := \ D[f, {x, 2}]\  + \ D[f, {y, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.4"],

Cell[TextData[{
  "We can now define the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(i\ j\ k\ l\) = \ \((v\_\(i\ j\), \(L\&^\) 
            v\_\(k\ l\))\)\)]],
  ","
}], "Text"],

Cell[BoxData[
    \(Lmat[i_, j_, k_, l_]\  := \ 
      norm[v[i, j, x, y], \ L[v[k, l, x, y]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.5"],

Cell[TextData[{
  "and the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\(i\ j\) = \((v\_\(i\ j\), \[Rho] - \
\(L\&^\) u)\)\)]],
  " (in this example, \[Rho]=0):"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]vec[i_, j_]\  := \ 
        norm[v[i, j, x, y], \ \(-L[u[x, y]]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.6"],

Cell[TextData[{
  "Next, we create the coupled equations for the Fourier coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  ". We will refer to these coefficients as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["k",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and we will give each equation a name, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["eq",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["i",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", so that we may refer to it later:"
}], "Text"],

Cell[BoxData[
    \(eq[i_, j_]\  := \(eq[i, j]\  = \ 
        Sum[Lmat[i, j, k, l] c[k, l], {k, 0, Px}, {l, 0, 
              Py}]\  \[Equal] \ \[Rho]vec[i, j]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.7"],

Cell[TextData[{
  "Here we made ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remember each equation. Since each equation takes some time to create, we \
only want to do it once. At this point it is useful to check that everything \
is working, so we will use a ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement that prints out each equation. We choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y = 3\)]],
  " so as to create 16 equations; see Eq. ",
  ButtonBox["(6.1.9)",
    ButtonData:>"(6.1.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:59"],

Cell[BoxData[{
    \(Px\  = \ 3; Py\  = 3;\), "\n", 
    \(\(Do[
        Print["\<eq\>", {i, j}, "\< = \>", eq[i, j]], {i, 0, Px}, {j, 0, 
          Py}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.8"],

Cell[TextData[{
  "We omit the results in order to save space. But the reader can perform the \
evaluations to confirm that everything appears to be working properly. We now \
solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(k\ l\)\)]],
  "'s using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".",
  StyleBox[" Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes arguments of the form ",
  StyleBox["Solve[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["equations",
    FontSlant->"Italic"],
  StyleBox["},{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["variables",
    FontSlant->"Italic"],
  StyleBox["}] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so we need to create a one-dimensional list of equations and another list \
of the variables. The list of equations can be created using a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command:"
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Flatten[Table[eq[i, j], {i, 0, Px}, {j, 0, Py}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.9"],

Cell[TextData[{
  " We flattened the two-dimensional table into a one-dimensional list using \
the ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, in order for the list to obey the proper syntax for ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell["\<\
\tTo create the variable list, we use another flattened \
table:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vars\  = \ Flatten[Table[c[k, l], {k, 0, Px}, {l, 0, Py}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.10"],

Cell[BoxData[
    \({c[0, 0], c[0, 1], c[0, 2], c[0, 3], c[1, 0], c[1, 1], c[1, 2], 
      c[1, 3], c[2, 0], c[2, 1], c[2, 2], c[2, 3], c[3, 0], c[3, 1], c[3, 2], 
      c[3, 3]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we solve for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(m\ n\)\)]],
  "'s:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(coefficients\  = \ \(Solve[eqns, vars]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.11"],

Cell[BoxData[
    \({c[0, 0] \[Rule] \(-6.672864966996882`\), 
      c[0, 1] \[Rule] 8.25579817335386`, 
      c[0, 2] \[Rule] \(-5.744315958913533`\), 
      c[0, 3] \[Rule] 1.9140259028223998`, 
      c[1, 0] \[Rule] \(-7.600798617306996`\), 
      c[1, 1] \[Rule] 9.477858343413233`, 
      c[1, 2] \[Rule] \(-6.673731026639963`\), 
      c[1, 3] \[Rule] 2.2473923269692193`, 
      c[2, 0] \[Rule] 7.600798617438556`, 
      c[2, 1] \[Rule] \(-9.477858344365645`\), 
      c[2, 2] \[Rule] 6.6737310286197715`, 
      c[2, 3] \[Rule] \(-2.2473923282040036`\), 
      c[3, 0] \[Rule] \(-1.5725707046178837`*^-10\), 
      c[3, 1] \[Rule] 1.1387185497220327`*^-9, 
      c[3, 2] \[Rule] \(-2.3675957234506418`*^-9\), 
      c[3, 3] \[Rule] 1.4769766960460618`*^-9}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This list of substitutions is used to construct ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[Phi]",
            "TraditionalForm"], "(", \(x, y\), ")"}], TraditionalForm]]],
  "  as follows:"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi][x_, y_]\  = \ 
        u[x, y]\  + \ Sum[c[k, l]\ v[k, l, x, y], {k, 0, Px}, {l, 0, Py}] /. 
          coefficients;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.12"],

Cell[TextData[{
  "The result is plotted in Cell ",
  ButtonBox["6.13",
    ButtonData:>"Cell 6.13",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Phi][x, y], {x, 0, 1}, {y, 0, 1}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.13"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.655 .739 .912 r
.38313 .58323 .40512 .60371 .44189 .59268 .42018 .57277 Metetra
.655 .747 .918 r
.42018 .57277 .44189 .59268 .47916 .5815 .45778 .5621 Metetra
.655 .755 .923 r
.45778 .5621 .47916 .5815 .51695 .57017 .49592 .5512 Metetra
.655 .762 .928 r
.49592 .5512 .51695 .57017 .55526 .55867 .53461 .54002 Metetra
.656 .769 .932 r
.53461 .54002 .55526 .55867 .59412 .54701 .57387 .52854 Metetra
.657 .774 .935 r
.57387 .52854 .59412 .54701 .63352 .53519 .6137 .51671 Metetra
.659 .778 .936 r
.6137 .51671 .63352 .53519 .67349 .5232 .65411 .50451 Metetra
.661 .779 .936 r
.65411 .50451 .67349 .5232 .71403 .51104 .69509 .49193 Metetra
.663 .779 .935 r
.69509 .49193 .71403 .51104 .75515 .4987 .73667 .47898 Metetra
.665 .776 .932 r
.73667 .47898 .75515 .4987 .79688 .48619 .77883 .46566 Metetra
.667 .772 .928 r
.77883 .46566 .79688 .48619 .83921 .47349 .8216 .45199 Metetra
.669 .767 .923 r
.8216 .45199 .83921 .47349 .88217 .4606 .86498 .43801 Metetra
.67 .76 .918 r
.86498 .43801 .88217 .4606 .92578 .44752 .90898 .42374 Metetra
.671 .752 .912 r
.90898 .42374 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.646 .737 .915 r
.36056 .56222 .38313 .58323 .42018 .57277 .3979 .55236 Metetra
.646 .745 .922 r
.3979 .55236 .42018 .57277 .45778 .5621 .43581 .54224 Metetra
.647 .753 .927 r
.43581 .54224 .45778 .5621 .49592 .5512 .4743 .53179 Metetra
.648 .761 .932 r
.4743 .53179 .49592 .5512 .53461 .54002 .51338 .52095 Metetra
.651 .768 .935 r
.51338 .52095 .53461 .54002 .57387 .52854 .55305 .50965 Metetra
.654 .774 .937 r
.55305 .50965 .57387 .52854 .6137 .51671 .59331 .49782 Metetra
.658 .779 .938 r
.59331 .49782 .6137 .51671 .65411 .50451 .63416 .4854 Metetra
.662 .781 .937 r
.63416 .4854 .65411 .50451 .69509 .49193 .67561 .4724 Metetra
.666 .781 .935 r
.67561 .4724 .69509 .49193 .73667 .47898 .71764 .45879 Metetra
.67 .779 .931 r
.71764 .45879 .73667 .47898 .77883 .46566 .76026 .44463 Metetra
.674 .776 .927 r
.76026 .44463 .77883 .46566 .8216 .45199 .80347 .42995 Metetra
.676 .77 .921 r
.80347 .42995 .8216 .45199 .86498 .43801 .84728 .41482 Metetra
.678 .763 .916 r
.84728 .41482 .86498 .43801 .90898 .42374 .89171 .3993 Metetra
.679 .756 .909 r
.89171 .3993 .90898 .42374 .95362 .4092 .93675 .38345 Metetra
.635 .734 .92 r
.33741 .54067 .36056 .56222 .3979 .55236 .37502 .5315 Metetra
.635 .743 .926 r
.37502 .5315 .3979 .55236 .43581 .54224 .41324 .522 Metetra
.637 .752 .932 r
.41324 .522 .43581 .54224 .4743 .53179 .45207 .51209 Metetra
.64 .761 .936 r
.45207 .51209 .4743 .53179 .51338 .52095 .49153 .50166 Metetra
.644 .77 .94 r
.49153 .50166 .51338 .52095 .55305 .50965 .53161 .49058 Metetra
.65 .777 .941 r
.53161 .49058 .55305 .50965 .59331 .49782 .57231 .47877 Metetra
.656 .782 .941 r
.57231 .47877 .59331 .49782 .63416 .4854 .61363 .46614 Metetra
.663 .785 .939 r
.61363 .46614 .63416 .4854 .67561 .4724 .65555 .45268 Metetra
.669 .786 .936 r
.65555 .45268 .67561 .4724 .71764 .45879 .69806 .43838 Metetra
.675 .785 .932 r
.69806 .43838 .71764 .45879 .76026 .44463 .74115 .4233 Metetra
.68 .781 .926 r
.74115 .4233 .76026 .44463 .80347 .42995 .78483 .40751 Metetra
.684 .775 .92 r
.78483 .40751 .80347 .42995 .84728 .41482 .82908 .39113 Metetra
.686 .768 .914 r
.82908 .39113 .84728 .41482 .89171 .3993 .87393 .37425 Metetra
.687 .76 .907 r
.87393 .37425 .89171 .3993 .93675 .38345 .91939 .35695 Metetra
.622 .73 .924 r
.31365 .51855 .33741 .54067 .37502 .5315 .35151 .51021 Metetra
.623 .741 .932 r
.35151 .51021 .37502 .5315 .41324 .522 .39002 .50149 Metetra
.625 .752 .938 r
.39002 .50149 .41324 .522 .45207 .51209 .42919 .49224 Metetra
.629 .763 .943 r
.42919 .49224 .45207 .51209 .49153 .50166 .46903 .48232 Metetra
.636 .773 .946 r
.46903 .48232 .49153 .50166 .53161 .49058 .50953 .47155 Metetra
.644 .781 .947 r
.50953 .47155 .53161 .49058 .57231 .47877 .55069 .45979 Metetra
.653 .788 .946 r
.55069 .45979 .57231 .47877 .61363 .46614 .59248 .44696 Metetra
.663 .792 .944 r
.59248 .44696 .61363 .46614 .65555 .45268 .63489 .433 Metetra
.673 .794 .939 r
.63489 .433 .65555 .45268 .69806 .43838 .6779 .41794 Metetra
.681 .792 .934 r
.6779 .41794 .69806 .43838 .74115 .4233 .72149 .40184 Metetra
.688 .788 .927 r
.72149 .40184 .74115 .4233 .78483 .40751 .76564 .38482 Metetra
.692 .782 .92 r
.76564 .38482 .78483 .40751 .82908 .39113 .81036 .36702 Metetra
.695 .774 .912 r
.81036 .36702 .82908 .39113 .87393 .37425 .85565 .3486 Metetra
.697 .765 .904 r
.85565 .3486 .87393 .37425 .91939 .35695 .90152 .32967 Metetra
.605 .725 .93 r
.28926 .49583 .31365 .51855 .35151 .51021 .32734 .48854 Metetra
.606 .738 .938 r
.32734 .48854 .35151 .51021 .39002 .50149 .36612 .48078 Metetra
.61 .751 .945 r
.36612 .48078 .39002 .50149 .42919 .49224 .40562 .47238 Metetra
.616 .764 .951 r
.40562 .47238 .42919 .49224 .46903 .48232 .44583 .46312 Metetra
.625 .777 .954 r
.44583 .46312 .46903 .48232 .50953 .47155 .48676 .45276 Metetra
.636 .788 .954 r
.48676 .45276 .50953 .47155 .55069 .45979 .52838 .44114 Metetra
.65 .796 .953 r
.52838 .44114 .55069 .45979 .59248 .44696 .57067 .42811 Metetra
.663 .802 .949 r
.57067 .42811 .59248 .44696 .63489 .433 .61361 .41363 Metetra
.676 .804 .943 r
.61361 .41363 .63489 .433 .6779 .41794 .65714 .39771 Metetra
.688 .803 .936 r
.65714 .39771 .6779 .41794 .72149 .40184 .70125 .38045 Metetra
.696 .798 .928 r
.70125 .38045 .72149 .40184 .76564 .38482 .7459 .362 Metetra
.703 .791 .919 r
.7459 .362 .76564 .38482 .81036 .36702 .7911 .34258 Metetra
.706 .782 .91 r
.7911 .34258 .81036 .36702 .85565 .3486 .83683 .32238 Metetra
.708 .771 .901 r
.83683 .32238 .85565 .3486 .90152 .32967 .88312 .30158 Metetra
.584 .718 .936 r
.2642 .4725 .28926 .49583 .32734 .48854 .30247 .46652 Metetra
.585 .734 .946 r
.30247 .46652 .32734 .48854 .36612 .48078 .3415 .46 Metetra
.589 .75 .954 r
.3415 .46 .36612 .48078 .40562 .47238 .3813 .45269 Metetra
.597 .766 .96 r
.3813 .45269 .40562 .47238 .44583 .46312 .42188 .44429 Metetra
.61 .782 .963 r
.42188 .44429 .44583 .46312 .48676 .45276 .46324 .4345 Metetra
.626 .796 .964 r
.46324 .4345 .48676 .45276 .52838 .44114 .50535 .42309 Metetra
.644 .807 .961 r
.50535 .42309 .52838 .44114 .57067 .42811 .54816 .4099 Metetra
.663 .814 .956 r
.54816 .4099 .57067 .42811 .61361 .41363 .59164 .39484 Metetra
.681 .817 .949 r
.59164 .39484 .61361 .41363 .65714 .39771 .63573 .37794 Metetra
.695 .816 .94 r
.63573 .37794 .65714 .39771 .70125 .38045 .68039 .35934 Metetra
.707 .811 .929 r
.68039 .35934 .70125 .38045 .7459 .362 .72558 .33924 Metetra
.715 .802 .919 r
.72558 .33924 .7459 .362 .7911 .34258 .77127 .31791 Metetra
.719 .79 .908 r
.77127 .31791 .7911 .34258 .83683 .32238 .81746 .29563 Metetra
.72 .778 .898 r
.81746 .29563 .83683 .32238 .88312 .30158 .86416 .27265 Metetra
.555 .708 .942 r
.23846 .44853 .2642 .4725 .30247 .46652 .27686 .44422 Metetra
.556 .727 .954 r
.27686 .44422 .30247 .46652 .3415 .46 .31609 .43929 Metetra
.561 .747 .964 r
.31609 .43929 .3415 .46 .3813 .45269 .35617 .43338 Metetra
.572 .768 .971 r
.35617 .43338 .3813 .45269 .42188 .44429 .39711 .4261 Metetra
.589 .788 .975 r
.39711 .4261 .42188 .44429 .46324 .4345 .43891 .41709 Metetra
.611 .806 .975 r
.43891 .41709 .46324 .4345 .50535 .42309 .48152 .40602 Metetra
.636 .82 .971 r
.48152 .40602 .50535 .42309 .54816 .4099 .52489 .39269 Metetra
.662 .83 .964 r
.52489 .39269 .54816 .4099 .59164 .39484 .56895 .37699 Metetra
.685 .834 .955 r
.56895 .37699 .59164 .39484 .63573 .37794 .61364 .35897 Metetra
.705 .832 .943 r
.61364 .35897 .63573 .37794 .68039 .35934 .65889 .3388 Metetra
.72 .826 .931 r
.65889 .3388 .68039 .35934 .72558 .33924 .70463 .31674 Metetra
.729 .815 .918 r
.70463 .31674 .72558 .33924 .77127 .31791 .75084 .29315 Metetra
.734 .801 .905 r
.75084 .29315 .77127 .31791 .81746 .29563 .79751 .2684 Metetra
.735 .785 .893 r
.79751 .2684 .81746 .29563 .86416 .27265 .84462 .24283 Metetra
.516 .694 .949 r
.212 .42389 .23846 .44853 .27686 .44422 .25045 .42171 Metetra
.515 .716 .963 r
.25045 .42171 .27686 .44422 .31609 .43929 .28983 .41881 Metetra
.52 .741 .975 r
.28983 .41881 .31609 .43929 .35617 .43338 .33015 .41473 Metetra
.535 .767 .983 r
.33015 .41473 .35617 .43338 .39711 .4261 .37144 .40894 Metetra
.558 .794 .987 r
.37144 .40894 .39711 .4261 .43891 .41709 .41367 .40096 Metetra
.589 .818 .987 r
.41367 .40096 .43891 .41709 .48152 .40602 .4568 .3904 Metetra
.624 .837 .982 r
.4568 .3904 .48152 .40602 .52489 .39269 .50076 .37698 Metetra
.659 .85 .973 r
.50076 .37698 .52489 .39269 .56895 .37699 .54546 .36057 Metetra
.69 .855 .961 r
.54546 .36057 .56895 .37699 .61364 .35897 .5908 .34124 Metetra
.716 .853 .947 r
.5908 .34124 .61364 .35897 .65889 .3388 .63668 .3192 Metetra
.735 .845 .932 r
.63668 .3192 .65889 .3388 .70463 .31674 .68304 .29479 Metetra
.747 .831 .916 r
.68304 .29479 .70463 .31674 .75084 .29315 .7298 .26848 Metetra
.752 .814 .901 r
.7298 .26848 .75084 .29315 .79751 .2684 .77695 .24075 Metetra
.753 .795 .887 r
.77695 .24075 .79751 .2684 .84462 .24283 .82447 .21208 Metetra
.461 .671 .954 r
.18479 .39856 .212 .42389 .25045 .42171 .2232 .3991 Metetra
.455 .697 .971 r
.2232 .3991 .25045 .42171 .28983 .41881 .26264 .39883 Metetra
.46 .728 .984 r
.26264 .39883 .28983 .41881 .33015 .41473 .30314 .39711 Metetra
.478 .761 .993 r
.30314 .39711 .33015 .41473 .37144 .40894 .34474 .39327 Metetra
.511 .796 .997 r
.34474 .39327 .37144 .40894 .41367 .40096 .38741 .38669 Metetra
.554 .829 .997 r
.38741 .38669 .41367 .40096 .4568 .3904 .43109 .37685 Metetra
.603 .856 .992 r
.43109 .37685 .4568 .3904 .50076 .37698 .47568 .36341 Metetra
.652 .874 .981 r
.47568 .36341 .50076 .37698 .54546 .36057 .52107 .34621 Metetra
.695 .881 .967 r
.52107 .34621 .54546 .36057 .5908 .34124 .56713 .32532 Metetra
.729 .879 .95 r
.56713 .32532 .5908 .34124 .63668 .3192 .61372 .30102 Metetra
.753 .868 .932 r
.61372 .30102 .63668 .3192 .68304 .29479 .66074 .27376 Metetra
.768 .85 .913 r
.66074 .27376 .68304 .29479 .7298 .26848 .70809 .24413 Metetra
.774 .829 .895 r
.70809 .24413 .7298 .26848 .77695 .24075 .75575 .21278 Metetra
.773 .805 .879 r
.75575 .21278 .77695 .24075 .82447 .21208 .80369 .18035 Metetra
.381 .634 .954 r
.1568 .3725 .18479 .39856 .2232 .3991 .19503 .37653 Metetra
.365 .663 .971 r
.19503 .37653 .2232 .3991 .26264 .39883 .23441 .37966 Metetra
.366 .699 .984 r
.23441 .37966 .26264 .39883 .30314 .39711 .27501 .38101 Metetra
.388 .742 .992 r
.27501 .38101 .30314 .39711 .34474 .39327 .31687 .37974 Metetra
.433 .789 .997 r
.31687 .37974 .34474 .39327 .38741 .38669 .35997 .37503 Metetra
.496 .835 .998 r
.35997 .37503 .38741 .38669 .43109 .37685 .40422 .36621 Metetra
.567 .874 .994 r
.40422 .36621 .43109 .37685 .47568 .36341 .4495 .35285 Metetra
.637 .9 .985 r
.4495 .35285 .47568 .36341 .52107 .34621 .49567 .33474 Metetra
.697 .912 .969 r
.49567 .33474 .52107 .34621 .56713 .32532 .54253 .31197 Metetra
.744 .909 .95 r
.54253 .31197 .56713 .32532 .61372 .30102 .58992 .2849 Metetra
.775 .895 .928 r
.58992 .2849 .61372 .30102 .66074 .27376 .63768 .25413 Metetra
.792 .873 .907 r
.63768 .25413 .66074 .27376 .70809 .24413 .68569 .22043 Metetra
.799 .846 .886 r
.68569 .22043 .70809 .24413 .75575 .21278 .73388 .18463 Metetra
.796 .816 .868 r
.73388 .18463 .75575 .21278 .80369 .18035 .78223 .14761 Metetra
.26 .572 .939 r
.128 .34568 .1568 .3725 .19503 .37653 .16585 .3542 Metetra
.225 .597 .949 r
.16585 .3542 .19503 .37653 .23441 .37966 .20501 .3617 Metetra
.217 .636 .954 r
.20501 .3617 .23441 .37966 .27501 .38101 .24559 .36708 Metetra
.243 .687 .957 r
.24559 .36708 .27501 .38101 .31687 .37974 .28764 .36918 Metetra
.305 .751 .962 r
.28764 .36918 .31687 .37974 .35997 .37503 .33114 .36697 Metetra
.396 .818 .969 r
.33114 .36697 .35997 .37503 .40422 .36621 .37599 .35957 Metetra
.502 .879 .974 r
.37599 .35957 .40422 .36621 .4495 .35285 .42204 .34642 Metetra
.605 .922 .972 r
.42204 .34642 .4495 .35285 .49567 .33474 .46908 .32725 Metetra
.693 .943 .961 r
.46908 .32725 .49567 .33474 .54253 .31197 .51687 .30218 Metetra
.758 .943 .942 r
.51687 .30218 .54253 .31197 .58992 .2849 .56517 .27169 Metetra
.799 .926 .92 r
.56517 .27169 .58992 .2849 .63768 .25413 .61378 .23656 Metetra
.821 .898 .896 r
.61378 .23656 .63768 .25413 .68569 .22043 .66252 .19777 Metetra
.827 .864 .873 r
.66252 .19777 .68569 .22043 .73388 .18463 .7113 .15647 Metetra
.822 .828 .853 r
.7113 .15647 .73388 .18463 .78223 .14761 .76008 .1138 Metetra
.079 .464 .888 r
.09834 .31807 .128 .34568 .16585 .3542 .13555 .33233 Metetra
.014 .475 .873 r
.13555 .33233 .16585 .3542 .20501 .3617 .17427 .3455 Metetra
0 .507 .853 r
.17427 .3455 .20501 .3617 .24559 .36708 .21465 .35611 Metetra
.022 .564 .842 r
.21465 .35611 .24559 .36708 .28764 .36918 .25678 .36267 Metetra
.106 .646 .848 r
.25678 .36267 .28764 .36918 .33114 .36697 .30064 .3638 Metetra
.234 .746 .871 r
.30064 .3638 .33114 .36697 .37599 .35957 .34612 .35837 Metetra
.388 .844 .9 r
.34612 .35837 .37599 .35957 .42204 .34642 .39302 .34561 Metetra
.542 .922 .922 r
.39302 .34561 .42204 .34642 .46908 .32725 .44106 .3252 Metetra
.673 .966 .928 r
.44106 .3252 .46908 .32725 .51687 .30218 .48994 .29728 Metetra
.767 .975 .919 r
.48994 .29728 .51687 .30218 .56517 .27169 .53933 .26249 Metetra
.824 .957 .9 r
.53933 .26249 .56517 .27169 .61378 .23656 .58893 .22185 Metetra
.852 .924 .878 r
.58893 .22185 .61378 .23656 .66252 .19777 .63852 .1767 Metetra
.858 .883 .855 r
.63852 .1767 .66252 .19777 .7113 .15647 .68796 .12853 Metetra
.851 .84 .834 r
.68796 .12853 .7113 .15647 .76008 .1138 .73719 .07886 Metetra
0 .29 .764 r
.0678 .28963 .09834 .31807 .13555 .33233 .10401 .31123 Metetra
0 .275 .698 r
.10401 .31123 .13555 .33233 .17427 .3455 .14196 .33173 Metetra
.289 0 0 r
.14196 .33173 .17427 .3455 .21465 .35611 .18189 .34919 Metetra
.248 0 0 r
.18189 .34919 .21465 .35611 .25678 .36267 .22392 .36163 Metetra
.146 0 0 r
.22392 .36163 .25678 .36267 .30064 .3638 .26807 .36724 Metetra
.26807 .36724 .30064 .3638 .34612 .35837 .31421 .36451 Metetra
.214 .734 .734 r
.31421 .36451 .34612 .35837 .39302 .34561 .36207 .3524 Metetra
.431 .87 .804 r
.36207 .3524 .39302 .34561 .44106 .3252 .4113 .33049 Metetra
.623 .96 .852 r
.4113 .33049 .44106 .3252 .48994 .29728 .46148 .29898 Metetra
.762 .994 .87 r
.46148 .29898 .48994 .29728 .53933 .26249 .51218 .25872 Metetra
.845 .984 .865 r
.51218 .25872 .53933 .26249 .58893 .22185 .56299 .2111 Metetra
.883 .948 .848 r
.56299 .2111 .58893 .22185 .63852 .1767 .6136 .15789 Metetra
.891 .901 .828 r
.6136 .15789 .63852 .1767 .68796 .12853 .6638 .10109 Metetra
.881 .851 .809 r
.6638 .10109 .68796 .12853 .73719 .07886 .71353 .04274 Metetra
0 .057 .546 r
.03634 .26033 .0678 .28963 .10401 .31123 .07105 .29127 Metetra
.534 0 0 r
.07105 .29127 .10401 .31123 .14196 .33173 .10779 .32124 Metetra
.537 0 0 r
.10779 .32124 .14196 .33173 .18189 .34919 .1469 .34765 Metetra
.479 0 0 r
.1469 .34765 .18189 .34919 .22392 .36163 .18859 .3679 Metetra
.37 0 0 r
.18859 .3679 .22392 .36163 .26807 .36724 .23291 .37953 Metetra
.207 0 0 r
.23291 .37953 .26807 .36724 .31421 .36451 .27971 .38051 Metetra
.27971 .38051 .31421 .36451 .36207 .3524 .32868 .36942 Metetra
.32868 .36942 .36207 .3524 .4113 .33049 .37934 .34567 Metetra
.534 .903 .716 r
.37934 .34567 .4113 .33049 .46148 .29898 .43112 .30957 Metetra
.735 .986 .781 r
.43112 .30957 .46148 .29898 .51218 .25872 .48345 .26226 Metetra
.856 .997 .806 r
.48345 .26226 .51218 .25872 .56299 .2111 .53576 .20567 Metetra
.91 .965 .804 r
.53576 .20567 .56299 .2111 .6136 .15789 .58762 .1422 Metetra
.922 .915 .792 r
.58762 .1422 .6136 .15789 .6638 .10109 .63876 .07454 Metetra
.91 .859 .778 r
.63876 .07454 .6638 .10109 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{311.938, 252.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000650001?2000`400?l00000o`00003ooooooon6
ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00oooooon6
ooooo`00oooooon6ooooo`00oooooon6ooooo`00ooooool>ooooo`Co000000?o410@ooooooooool0
LOooool00?oooooo4?ooool00ol0003oooooooooo`1cooooo`00ooooool@ooooo`03o`000?oooooo
oooo07?ooooo003ooooooa3ooooo00?o0000ooooooooool0Loooool00?oooooo4?ooool00ol0003o
ooooooooo`1cooooo`00ooooool@ooooo`03o`000?oooooooooo07?ooooo003ooooooa3ooooo00?o
0000ooooooooool0Loooool00?oooooo3_ooool00omEEEGoIVIVo`00000:ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0I_ooool00?oooooo6oooool01OmgMgOoV9RHoooooonHV9SoMgMg06Kooooo003o
oooooa_ooooo00Go410@oooooooooooooooooa0@401Vooooo`00oooooolKooooo`05o`000?oooooo
ooooooooool00000I_ooool00?oooooo6oooool01Ol0003ooooooooooooooooo000006Kooooo003o
oooooa_ooooo00Go410@oooooooooooooooooa0@401Vooooo`00oooooolEooooo`;o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg06Kooooo003ooooooa;ooooo0ol000000ooooooo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0I_ooool00?oooooo4?ooool2o`0000Cooooo0_l0001^
ooooo`00ooooool=ooooo`?o00001_ooool00ol0003oooooo`00001]ooooo`00ooooool;ooooo`;o
00002?ooool4o`0006gooooo003oooooo`Sooooo0ol00009ooooo`04o`000?oXflOo0000onSKa`;o
0000K?ooool00?oooooo1Oooool3o`000003ooooool0003ooooo00Sooooo00So0000onSKaooXflOo
0000onSKaol0003oooooo`0006_ooooo003;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Rooooo`;o00003_ooool01?l0003oj=_7onSK
aol00002onSKa`;o0000Joooool00<_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01oooooo0ol0000?ooooo`05o`000?oXflOoj=_7onSK
aol000000_oXflL00ol0003oooooo`00001Zooooo`00boooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Mooooo`;o00004Oooool00ol0003oj=_7onSKa`02
onSKa`07o`000?oXflOoj=_7onSKaol0003oooooo`00001Yooooo`00boooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Jooooo`?o00004oooool00ol0003o
j=_7onSKa`03onSKa`04o`000?oXflOoj=_7onSKa`;o0000JOooool00<_ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`06?ooool2o`000003ooooool0003o
oooo01;ooooo00?o0000onSKaooXflL01?oXflL01ol0003oj=_7onSKaooXflOo0000ooooool00000
J?ooool00<_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41005Oooool3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oj=_7onSKa`05onSKa`03
o`000?oXflOoj=_700;oj=_70_l0001Xooooo`00boooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`00000Cooooo`;o00006?ooool00ol0003oj=_7onSKa`06onSK
a`03o`000?oXflOoj=_700;oj=_700?o0000ooooool00000Ioooool00<_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT04?ooool3o`0001[ooooo00?o0000
onSKaooXflL01_oXflL00ol0003oj=_7onSKa`03onSKa`03o`000?oooooo000006Kooooo003]oooo
o`?o00007?ooool00ol0003oj=_7onSKa`07onSKa`03o`000?oXflOoj=_700Coj=_70_l0001Voooo
o`00joooool2o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oj=_7onSKa`08onSKa`03
o`000?oXflOoj=_700Coj=_700?o0000ooooool00000IOooool007oooooo0_l00002ooooo`;o0000
Hoooool3o`00023ooooo00?o0000onSKaooXflL02?oXflL00ol0003oj=_7onSKa`03onSKa`05o`00
0?oQfLoo0000ooooool00000I?ooool007oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeQoooo
o`;o00008_ooool00ol0003oj=_7onSKa`09onSKa`03o`000?oXflOoj=_700;oj=_700Co0000on7I
cooQfLoohMW?0_l0001Tooooo`00P?ooool01?oMgMgo0000oa0@4?o<c<aOooooo`?o00008oooool0
0ol0003oj=_7onSKa`0:onSKa`05o`000?oXflOoj=_7onSKaol000001?oQfLl3o`0006?ooooo0020
ooooo`04onk^k_lQ8B7o410@onk^kUgooooo0_l0000Uooooo`03o`000?oXflOoj=_700_oj=_700Co
0000onSKaooXflOo00001_oQfLl00ol0003oooooo`00001Rooooo`00P?ooool01?lQ8B7oMgMgogMg
Molb<S9Jooooo`?o000000?oooooo`000?ooool09?ooool00ol0003oj=_7onSKa`0;onSKa`04o`00
0?oXflOoj=_7o`0000OohMW?0_l0001Rooooo`00Ooooool2o`0000;ooooo0_l0001Gooooo`;o0000
1Oooool00ol0003oooooooooo`0Qooooo`03o`000?oXflOoj=_700coj=_700?o0000onSKaol00000
2OoQfLl2o`00067ooooo003Iooooo`?o0000:_ooool00ol0003oj=_7onSKa`0=onSKa`;o00002_oQ
fLl00ol0003oooooo`00001Pooooo`00eoooool2o`0002gooooo00?o0000onSKaooXflL03OoXflL0
0ol0003ohMW?on7Ic`0:on7Ic`;o0000H?ooool00=Cooooo0ol0000^ooooo`03o`000?oXflOoj=_7
00goj=_70_l0000=on7Ic`;o0000Goooool00=7ooooo0ol00002ooooo`03o`000?oooooooooo02_o
oooo00?o0000onSKaooXflL03OoXflL00ol0003ohMW?o`00000=on7Ic`03o`000?oooooo000005ko
oooo002Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c00Qooooo`;o0000<_ooool00ol0003oj=_7onSKa`0>onSKa`04o`000?oQfLoohMW?
o`0000gohMW?0_l0001Nooooo`00VOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407_ooool3o`0003Cooooo0_l0000>onSKa`05o`000?oQ
fLoohMW?on7Icol000003_oQfLl2o`0005gooooo002Iooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001cooooo0_l0000fooooo`04o`000?o/j/[ok>[:o`00
00coj=_700?o0000on7IcooQfLl00_oQfLl00ol0003ohMW?on7Ic`0;on7Ic`?o0000GOooool009Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406Oooool3
o`0003Oooooo00?o0000oncZb_o/j/X00_o/j/X00ol0003oj=_7onSKa`08onSKa`03o`000?oQfLoo
hMW?00?ohMW?00?o0000on7IcooQfLl02_oQfLl00ol0003ofMOEomWGe@02o`0000Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0003kooooo002Iooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Oooooo0_l00003ooooo`03o`00
0?oooooooooo03?ooooo00?o0000oncZb_o/j/X01?o/j/X00ol0003oj=_7onSKa`06onSKa`03o`00
0?oQfLoohMW?00CohMW?00?o0000on7IcooQfLl02OoQfLl00ol0003ofMOEomWGe@02omWGe@;o0000
2?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@0?_ooool009Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
01Kooooo0ol0000kooooo`03o`000?o/j/[ok>[:00Gok>[:00?o0000onSKaooXflL01OoXflL00ol0
003ohMW?on7Ic`04on7Ic`03o`000?oQfLoohMW?00SohMW?00?o0000omWGeOoIemD00ooIemD2o`00
00Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^03oooooo002Ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Dooooo`;o0000?Oooool0
0ol0003ok>[:oncZbP07oncZbP03o`000?oXflOoj=_700?oj=_700?o0000on7IcooQfLl01OoQfLl0
0ol0003ohMW?on7Ic`07on7Ic`03o`000?oIemGofMOE00GofMOE0_l00007ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP0nooooo`00VOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool3o`0003kooooo00?o0000oncZb_o/j/X0
2Oo/j/X01Ol0003oj=_7onSKaooXflOo000000SohMW?00?o0000on7IcooQfLl01_oQfLl00ol0003o
fMOEomWGe@06omWGe@03o`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo03gooooo002jooooo`Co0000?oooool00ol0003ok>[:oncZbP0;oncZbP03
o`000?oXflOo000000WohMW?00?o0000on7IcooQfLl01OoQfLl00ol0003ofMOEomWGe@08omWGe@;o
00001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00;So
oooo0_l00004ooooo`03o`000?oooooooooo03cooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003o
hMW?on7Ic`08on7Ic`03o`000?oQfLoohMW?00CohMW?00?o0000omWGeOoIemD02_oIemD2o`0000Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100?_ooool0
0;Gooooo0ol00014ooooo`03o`000?o/j/[ok>[:00gok>[:00?o0000on7IcooQfLl02?oQfLl00ol0
003ohMW?on7Ic`03on7Ic`03o`000?oIemGofMOE00_ofMOE00?o0000ooooool000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00/oooool2
o`0004Kooooo00?o0000oncZb_o/j/X03Oo/j/X00ol0003oi>KCo`000009on7Ic`03o`000?oQfLoo
hMW?00;ohMW?00?o0000omWGeOoIemD03OoIemD2o`0005Oooooo002`ooooo`?o0000Aoooool00ol0
003ok>[:oncZbP0=oncZbP05o`000?oTi]?oi>KConCVdol000002?oQfLl01Ol0003ohMW?on7IcooQ
fLoo0000013ofMOE00?o0000ooooool00000E_ooool00:kooooo0_l000000ooooooo0000ooooo`17
ooooo`03o`000?o/j/[ok>[:00cok>[:00?o0000onCVdooTi]<00ooTi]<00ol0003ohMW?on7Ic`05
on7Ic`04o`000?oQfLoohMW?o`0001;ofMOE00?o0000ooooool00000EOooool00:_ooooo0ol00004
ooooo`03o`000?oooooooooo04Cooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`05
onCVd`03o`000?oQfLoohMW?00CohMW?00?o0000on7Icol000004ooIemD3o`0005Gooooo002Yoooo
o`;o0000COooool00ol0003ok>[:oncZbP0<oncZbP03o`000?oTi]?oi>KC00Koi>KC00?o0000on7I
cooQfLl01?oQfLl2o`0001?ofMOE00Go0000om;Cf_l0003oooooo`00001Dooooo`00Y_ooool3o`00
04kooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`08onCVd`03o`000?oQfLoohMW?
00?ohMW?00?o0000omWGeOoIemD04OoIemD01ol0003od]?Jom;Cf_oBdm[o0000ooooool00000Dooo
ool00:Cooooo0_l0001Aooooo`03o`000?o/j/[ok>[:00_ok>[:00?o0000onCVdooTi]<02_oTi]<0
1?l0003ohMW?on7IcooQfLl2o`0001;ofMOE00?o0000om;Cf_oBdmX00ooBdmX2o`0005?ooooo001Z
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`0Pooooo`?o00000_ooool00ol0003oooooooooo`1=ooooo`03o`000?o/j/[ok>[:00_ok>[:00?o
0000onCVdooTi]<03?oTi]<00ol0003ohMW?o`000002omWGe@03o`000?oIemGofMOE00kofMOE00?o
0000om;Cf_oBdmX01?oBdmX3o`0005;ooooo001Zooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07_ooool3o`0005Cooooo00?o0000oncZb_o/j/X02oo/
j/X00ol0003oi>KConCVd`0>onCVd`05o`000?oIemGofMOEomWGeOl000003ooIemD00ol0003od]?J
om;CfP06om;CfP;o0000D_ooool006[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
7Oooool2o`0005Kooooo00?o0000oncZb_o/j/X03?o/j/X00ol0003oi>KConCVd`0=onCVd`;o0000
0ooIemD00ol0003ofMOEomWGe@0<omWGe@03o`000?oBdm[od]?J00Sod]?J0_l0001Aooooo`00J_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006oooool3o`0005So
oooo00?o0000oncZb_o/j/X02oo/j/X00ol0003oi>KConCVd`0=onCVd`04o`000?oKh][ofn;Jo`00
00;ofMOE00?o0000omWGeOoIemD02_oIemD2o`0000_od]?J00?o0000ooooool00000D?ooool006[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Wooooo0_l00000
0ooooooo0000ooooo`1Gooooo`03o`000?o/j/[ok>[:00_ok>[:00?o0000onCVdooTi]<03OoTi]<0
0ol0003ofn;Jom_RfP02om_RfP03o`000?oIemGo000000_ofMOE00?o0000om;Cf_oBdmX03?oBdmX2
o`00053ooooo001Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000F
ooooo`?o0000Foooool00ol0003ok>[:oncZbP0;oncZbP03o`000?oTi]?oi>KC00goi>KC00?o0000
om_Rf_oKh]X01?oKh]X2o`0000[ofMOE00?o0000om;Cf_oBdmX03_oBdmX2o`0004oooooo001Zoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Dooooo`;o0000GOooool2
o`0000cok>[:00?o0000onCVdooTi]<03OoTi]<00ol0003ofn;Jom_RfP06om_RfP03o`000?oIemGo
fMOE00OofMOE00?o0000om;Cf_oBdmX03ooBdmX00ol0003oooooo`00001>ooooo`00J_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool04?ooool3o`0005oooooo00Co0000
onSgcOl0003o00002Oo/j/X00ol0003oi>KConCVd`0=onCVd`03o`000?oKh][ofn;J00Oofn;J0_l0
0007omWGe@03o`000?oBdm[od]?J017od]?J0_l0001>ooooo`00SOooool2o`00067ooooo00?o0000
onSgcOoXmld00_oXmld2o`0000Kok>[:00?o0000onCVdooTi]<03OoTi]<00ol0003ofn;Jom_RfP08
om_RfP03o`000?oKh][o000000GofMOE00?o0000om;Cf_oBdmX04_oBdmX3o`0004gooooo002:oooo
o`?o00000_ooool00ol0003oooooooooo`1Mooooo`03o`000?oXmlgoj?O=00Goj?O=00?o0000oncZ
b_o/j/X00_o/j/X00ol0003oi>KConCVd`0=onCVd`03o`000?oKh][ofn;J00Wofn;J00Co0000om_R
f_oKh][o00000ooIemD00ol0003od]?Jom;CfP0Bom;CfP05o`000?o;d=ko0000ooooool00000C?oo
ool008Sooooo0_l0001Tooooo`03o`000?oXmlgoj?O=00Ooj?O=0_l000000oo/j/[o0000onCVd`0>
onCVd`03o`000?oKh][ofn;J00[ofn;J00Oo0000om_Rf_oKh][ofn;Jo`000?oIemGo000001Cod]?J
00Co0000ol_@g_o;d=kobm3N0_l0001<ooooo`00QOooool3o`0006Gooooo00?o0000onSgcOoXmld0
2_oXmld2o`0000koi>KC00?o0000om_Rf_oKh]X02ooKh]X01?l0003ofn;Jom_Rf_oKh]X2o`0001?o
d]?J0_l00005ol_@gP;o0000Boooool008;ooooo0ol0001Wooooo`03o`000?oXmlgoj?O=00_oj?O=
00?o0000on;bfOl000003?oTi]<00ol0003ofn;Jom_RfP0<om_RfP06o`000?oKh][ofn;Jo`000?oC
gMoo00004_oBdmX00ol0003obm3Nol_@gP05ol_@gP03o`000?oooooo000004[ooooo0020ooooo`;o
000000?oooooo`000?ooool0I_ooool00ol0003oj?O=onSgc@0;onSgc@05o`000?oRl]Woh_;Ion;b
fOl000002_oTi]<00ol0003ofn;Jom_RfP0=om_RfP03o`000?oKh][o000000?odmgO00?o0000om;C
f_oBdmX03_oBdmX00ol0003obm3Nol_@gP07ol_@gP;o0000B_ooool007gooooo0ol00004ooooo`03
o`000?oooooooooo06Cooooo00?o0000onSgcOoXmld02_oXmld00ol0003oh_;Ion;bf@03on;bf@;o
00001ooTi]<00ol0003ofn;Jom_RfP0>om_RfP;o00001OoCgMl00ol0003od]?Jom;CfP0;om;CfP;o
00002oo;d=h2o`0004Wooooo001kooooo`;o0000KOooool00ol0003oj?O=onSgc@0:onSgc@03o`00
0?oRl]Woh_;I00Koh_;I00?o0000onCVdooTi]<00ooTi]<00ol0003ofn;Jom_RfP0?om_RfP03o`00
0?oCgMoodmgO00GodmgO00?o0000om;Cf_oBdmX02OoBdmX00ol0003obm3Nol_@gP0;ol_@gP03o`00
0?oooooo000004Sooooo001hooooo`?o0000K_ooool00ol0003oj?O=onSgc@0:onSgc@03o`000?oR
l]Woh_;I00Soh_;I00Go0000onCVdooTi]?oi>KCo`00000@om_RfP?o00002?oCgMl00ol0003od]?J
om;CfP07om;CfP03o`000?o;d=kobm3N00gobm3N0ol00017ooooo`00?Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00009?ooool2o`00073ooooo00?o0000onSgcOoXmld0
2_oXmld00ol0003oh_;Ion;bf@0:on;bf@03o`000?oTi]?o0000013ofn;J00Co0000om?MgooCgMoo
00002?oCgMl00ol0003od]?Jom;CfP06om;CfP03o`000?o;d=kobm3N00kobm3N00?o0000ooooool0
0000Aoooool003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A4027ooooo0ol00002ooooo`03o`000?oooooooooo06cooooo00?o0000onSg
cOoXmld02_oXmld00ol0003oh_;Ion;bf@0;on;bf@;o00004?oKh]X00ol0003odmgOom?Mg`02om?M
g`03o`000?oCgMoodmgO00KodmgO00?o0000om;Cf_oBdmX00ooBdmX2o`0001;obm3N0_l00009oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0W
ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h08?ooool2
o`0007?ooooo00?o0000onSgcOoXmld02_oXmld00ol0003oh_;Ion;bf@0;on;bf@04o`000?oJk>3o
f^cPo`0000kofn;J00?o0000om?MgooCgMl00ooCgMl00ol0003odmgOom?Mg`07om?Mg`05o`000?oB
dm[od]?Jom;Cf_l000005?o;d=h3o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Xooooo`00?Oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0007Cooooo00?o0000onSgcOoXmld02_oXmld00ol0003o
h_;Ion;bf@0;on;bf@03o`000?oJk>3of^cP00;of^cP00?o0000om_Rf_oKh]X02_oKh]X00ol0003o
dmgOom?Mg`04om?Mg`03o`000?oCgMoodmgO00SodmgO00?o0000om;Cf_l000005?o;d=h01Ol0003o
aLkQo`000?oooooo000000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:Oooool0
03gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo0ol0001f
ooooo`03o`000?oXmlgoj?O=00[oj?O=00?o0000on;bfOoRl]T02ooRl]T00ol0003of^cPom[/h004
om[/h003o`000?oKh][ofn;J00Oofn;J0_l00007om?Mg`03o`000?oCgMoodmgO00SodmgO0_l0000C
ol_@gP;o00000oo5c^42o`0000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0002[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Eooooo`;o00000_ooool00ol0003oooooooooo`1dooooo`03o`000?oXmlgoj?O=00Woj?O=
00?o0000on;bfOoRl]T02ooRl]T00ol0003of^cPom[/h006om[/h003o`000?oKh][ofn;J00Gofn;J
00?o0000om?MgooCgMl01ooCgMl00ol0003odmgOom?Mg`07om?Mg`03o`000?o<f>;o000001;obm3N
00?o0000olG>hOo5c^401?o5c^42o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000kooooo0ol000000ol@413oooooooooo`0Fooooo`00?Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o0000N_ooool0
0ol0003oj?O=onSgc@09onSgc@03o`000?oRl]Woh_;I00_oh_;I00?o0000om[/h?oJk>002?oJk>00
0ol0003ofn;Jom_RfP03om_RfP03o`000?oCgMoodmgO00SodmgO00?o0000om?MgooCgMl01_oCgMl0
1Ol0003oc=SRolcHh_o<f>;o0000013obm3N00?o0000olG>hOo5c^401Oo5c^400ol0003oooooo`00
0005ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000@ooooo`03oa0@
4?nj^[[ooooo01Oooooo000mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<01;ooooo0_l0001looooo`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;bfOoR
l]T02ooRl]T00ol0003of^cPom[/h00:om[/h005o`000?oKh][ofn;Jom_Rf_l000002ooCgMl00ol0
003odmgOom?Mg`04om?Mg`;o00001Oo<f>800ol0003obm3Nol_@gP0;ol_@gP;o00002Oo5c^43o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000013ooooo00?oV9RH
oc8b<_ooool05oooool0067ooooo0ol0001mooooo`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;b
fOoRl]T02ooRl]T00ol0003of^cPom[/h00<om[/h003o`000?oKh][o000000codmgO00?o0000om?M
gooCgMl00ooCgMl00ol0003oc=SRolcHhP05olcHhP03o`000?o;d=kobm3N00[obm3N00?o0000olG>
hOo5c^402_o5c^42o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00oooooo00?ogMgMo`000?nj^[X05oooool005oooooo0_l000000ooooooo0000ooooo`1loooo
o`03o`000?oXmlgoj?O=00Woj?O=00?o0000on;bfOoRl]T02_oRl]T2o`0000oof^cP0_l0000=om?M
g`04o`000?oCgMoodmgOom?Mg`;o00002Oo<f>800ol0003obm3Nol_@gP07ol_@gP;o00003Oo5c^40
0ol0003oooooo`00000Wooooo`03oeEEEOmgMgOoA4A401Oooooo001Looooo`?o0000P?ooool00ol0
003oj?O=onSgc@09onSgc@03o`000?oRl]Woh_;I00[oh_;I00?o0000om[/h?oJk>003_oJk>001?l0
003od^GUom;UiOl0000<om?Mg`04o`000?oCgMoodmgOo`0000coc=SR00?o0000ol_@g_o;d=h01Oo;
d=h00ol0003oaLkQolG>h@0>olG>h@;o00009_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo
001Jooooo`;o0000P_ooool4o`0000Soj?O=00?o0000on;bfOoRl]T02_oRl]T00ol0003of^cPom[/
h00>om[/h003o`000?oBiNGod^GU00;od^GU00?o0000om?MgooCgMl02OoCgMl00ol0003odmgOo`00
000>olcHhP03o`000?o;d=kobm3N00?obm3N00?o0000olG>hOo5c^404?o5c^42o`0002Gooooo00Go
IVIVohN7QoooooooV9RHoeEEE@0Fooooo`00Eoooool3o`0008Cooooo00Co0000om_oc_oKolkofoo>
1Ol00002onSgc@03o`000?oRl]Woh_;I00[oh_;I00?o0000om[/h?oJk>003OoJk>02o`0000Kod^GU
00?o0000om?MgooCgMl02?oCgMl2o`0000ooc=SR00Co0000ol_@g_o;d=kobm3N0_l0000ColG>h@03
o`000?oooooo000002?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Dooooo`00
EOooool3o`0008Gooooo00?o0000om_oc_oKolh01ooKolh3o`0000_oh_;I00?o0000om[/h?oJk>00
3OoJk>000ol0003od^GUom;Ui@07om;Ui@03o`000?oCgMoodmgO00KodmgO0_l0000AolcHhP03o`00
0?o;d=ko000001KoaLkQ0_l0000Sooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool04oooool005;ooooo0ol00003ooooo`03o`000?oooooooooo087ooooo00?o0000om_oc_oKolh0
1ooKolh01?l0003of?_MomSkgOoHnmd2o`0000Soh_;I00?o0000om[/h?oJk>003OoJk>000ol0003o
d^GUom;Ui@09om;Ui@03o`000?oCgMoodmgO00?odmgO0_l000000oo<f>;o0000olcHhP0@olcHhP;o
00005oo5c^43o`0003kooooo001?ooooo`?o0000ROooool00ol0003ofoo>om_ocP07om_ocP03o`00
0?oHnmgof?_M00Cof?_M0ol00004on;bf@03o`000?oJk>3of^cP00cof^cP0_l0000=om;Ui@05o`00
0?oCgMoodmgOom?Mgol000000oo<f>800ol0003oc=SRolcHhP0>olcHhP03o`000?o6e>Go000001Go
aLkQ0_l000001?o0bn?o0000ooooool0000mooooo`00COooool2o`0008_ooooo00?o0000om_oc_oK
olh01ooKolh00ol0003of?_MomSkg@08omSkg@;o000000?oh_;Io`000?oJk>003OoJk>000ol0003o
d^GUom;Ui@0>om;Ui@03o`000?oCgMoo000000Coc=SR00?o0000olcHh_o<f>803?o<f>82o`0000?o
a]CU00?o0000olG>hOo5c^404Oo5c^400ol0003o`<_Sol3;h`02ol3;h`;o0000?Oooool002;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`?o0000S?ooool00ol0003ofoo>om_ocP07om_ocP03
o`000?oHnmgof?_M00[of?_M0ol0000=om[/h003o`000?oBiNGod^GU00ood^GU0_l00005olcHhP03
o`000?o<f>;oc=SR00_oc=SR00?o0000olKDiOo6e>D01?o6e>D00ol0003oaLkQolG>h@0>olG>h@;o
00001_o0bn<2o`0003cooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool2o`0000?o
oooo00?o0000ooooooooool0R?ooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00[o
f?_M00Co0000om;di_oBm>Kod_CV0_l0000:om[/h003o`000?oBiNGod^GU00ood^GU00Co0000ol[O
j?o:gnSo00001Oo<f>800ol0003oc=SRolcHhP08olcHhP;o00002?o6e>D00ol0003oaLkQolG>h@0;
olG>h@;o00002?o0bn<2o`0003cooooo000Rooooo`05oa0@4?ooooooooooooooool@41007_ooool3
o`0008oooooo00?o0000om_oc_oKolh01ooKolh00ol0003of?_MomSkg@0:omSkg@03o`000?oBm>Ko
d_CV00Cod_CV0_l00006om[/h0;o00004?oBiND2o`0000Cob]oX00?o0000olcHh_o<f>800_o<f>80
0ol0003oc=SRolcHhP06olcHhP;o00002oo6e>D00ol0003oaLkQolG>h@09olG>h@03o`000?o0bn?o
`<_S00Wo`<_S0_l0000kooooo`008_ooool01Ol0003ooooooooooooooooo000001cooooo0_l0002A
ooooo`03o`000?oKolkofoo>00Oofoo>00?o0000omSkgOoHnmd02_oHnmd00ol0003od_CVom;diP07
om;diP03o`000?oJk>3of^cP00;of^cP00?o0000om;UiOoBiND03ooBiND00ol0003ob]oXol[Oj005
ol[Oj005o`000?o<f>;oc=SRolcHh_l000001oo<f>800ol0003oa]CUolKDi@0;olKDi@03o`000?o5
c^7oaLkQ00OoaLkQ0_l0000=ol3;h`;o0000>_ooool002;ooooo00Go0000ooooooooooooooooo`00
000Iooooo`?o0000T_ooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00[of?_M00?o
0000om;di_oBm>H02OoBm>H2o`000003om[/h?l0003od^GU013od^GU00?o0000ol[Oj?o:gnP01oo:
gnP01?l0003oc=SRolcHh_l00005olcHhP;o00003oo6e>D00ol0003oaLkQolG>h@04olG>h@;o0000
3oo0bn<2o`0003[ooooo000Rooooo`05oa0@4?ooooooooooooooool@41005oooool2o`0000;ooooo
00?o0000ooooooooool0Soooool00ol0003ofoo>om_ocP07om_ocP03o`000?oHnmgof?_M00Wof?_M
0_l0000=om;diP?o00003ooBiND2o`0000_ob]oX00?o0000olcHh_l000001?o<f>800ol0003oa]CU
olKDi@0@olKDi@03o`000?o5c^7oaLkQ00;oaLkQ00?o0000ol3;hoo0bn<04?o0bn<2o`0003Wooooo
000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool3o`0009Kooooo00?o0000om_oc_oKolh0
1_oKolh00ol0003of?_MomSkg@09omSkg@03o`000?oBm>Kod_CV00cod_CV00Go0000olc]joo<kN_o
c>g[o`00000=om;Ui@03o`000?o:gnSob]oX00cob]oX0_l00002olcHhP;o00005?o6e>D01?l0003o
aLkQo`000?l0000Col3;h`?o0000>?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aoooo
o`?o0000V?ooool00ol0003ofoo>om_ocP06om_ocP03o`000?oHnmgof?_M00Wof?_M00?o0000om;d
i_oBm>H03?oBm>H00ol0003oc>g[olc]j`03olc]j`03o`000?oBiNGod^GU00Sod^GU0_l0000@ol[O
j003o`000?o<f>;o000001Koa]CU0_l0000Fol3;h`;o0000>?ooool003Kooooo0_l0002Jooooo`03
o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02OoHnmd00ol0003od_CVom;diP0;om;diP;o
00001oo<kN/00ol0003od^GUom;Ui@06om;Ui@03o`000?o:gnSob]oX013ob]oX0_l0000EolKDi@;o
000000?o`=3Vo`000?o0bn<05Oo0bn<3o`0003Oooooo000cooooo`?o00000_ooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02OoHnmd00ol0003od_CV
om;diP0;om;diP03o`000?o<kN_oc>g[00Soc>g[00?o0000om;UiOoBiND01?oBiND00ol0003ob]oX
ol[Oj00@ol[Oj0?o00005?o6e>D00ol0003o`=3Vol3@iP02ol3@iP03o`000?o0bn?o`<_S017o`<_S
0_l000001?nlb>Co0000ooooool0000fooooo`00<Oooool2o`0009gooooo00?o0000om_oc_oKolh0
1_oKolh00ol0003of?_MomSkg@08omSkg@;o00003OoBm>H00ol0003oc>g[olc]j`0:olc]j`04o`00
0?oBiNGod^GUom;Ui@;o00004?o:gnP3o`000004olCIjOl0003oa=WYo`00017oa]CU0_l00006ol3@
iP03o`000?o0bn?o`<_S00ko`<_S0_l00004okc8i0;o0000=_ooool002kooooo0ol0002Nooooo`03
o`000?oKolkofoo>00Kofoo>00?o0000omSkgOoHnmd02?oHnmd00ol0003od_CVom;diP0;om;diP;o
00003_o<kN/00ol0003od^GUo`00000?ol[Oj0Co00001?o4fNT00ol0003oa=WYo`00000>olKDi@;o
00002?o0d>H00ol0003o`<_Sol3;h`0<ol3;h`;o00001onlb>@2o`0003Gooooo000]ooooo`;o0000
Woooool00ol0003ofoo>om_ocP06om_ocP03o`000?oHnmgof?_M00Sof?_M00?o0000om;di_oBm>H0
2ooBm>H00ol0003oc>g[olc]j`0>olc]j`?o00003?o:gnP3o`000003ol[Oj?l0003o000000Koa=WY
00?o0000olCIjOl000003?o6e>D00ol0003o`=3Vol3@iP09ol3@iP03o`000?o0bn?o`<_S00Wo`<_S
0_l00009okc8i003o`000?oooooo000003Cooooo000]ooooo`?o0000WOooool00ol0003ofoo>om_o
cP03om_ocPKo00002?oHnmd00ol0003od_CVom;diP0;om;diP03o`000?o<kN_oc>g[00koc>g[00Go
0000olKUkOo6iNgoa^G]o`000008ol[Oj0?o00000oo:gnP00ol0003oa=WYolCIj@07olCIj@03o`00
0?o4fNWo000000Woa]CU0_l0000=ol3@iP03o`000?o0bn?o`<_S00Oo`<_S00?o0000okc8i?nlb>@0
2_nlb>@3o`0003?ooooo000/ooooo`?o000000?oooooo`000?ooool0V_ooool00ol0003ofoo>o`00
0004o`000003okclaol0003o`okN00?o`okN1Ol00002omSkg@03o`000?oBm>Kod_CV00_od_CV00?o
0000olc]joo<kN/03Oo<kN/2o`0000Goa^G]00?o0000ol[Oj?o:gnP00_o:gnP3o`0000Gob]oX00?o
0000olCIjOo4fNT02?o4fNT01?l0003oa=WYolCIjOl00006olKDi@;o00004?o0d>H00ol0003o`<_S
ol3;h`04ol3;h`;o00003_nlb>@2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Gooooo000]ooooo`;o00000_ooool00ol0003o
ooooooooo`2Fooooo`Co00001Onlo<L00ol0003o`okNol?ngP08ol?ngPCo00002_oBm>H2o`0000oo
c>g[00?o0000olKUkOo6iNd01_o6iNd4o`0000Kob]oX0_l0000<olCIj@04o`000?o4fNWoa=WYo`00
00Coa]CU00?o0000ol3@i_o0d>H04?o0d>H00ol0003o`<_Sol3;h`02ol3;h`;o00004Onlb>@2o`00
00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q01Gooooo000Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo09Cooooo00?o0000okclaonlo<L01_nlo<L00ol0003o`okN
ol?ngP08ol?ngP03o`000?o4nN_oa?W[00;oa?W[0ol00006om;diP03o`000?o<kN_oc>g[00goc>g[
0_l00007olKUk@?o000000?oa^G]o`000?o:gnP01Oo:gnP00ol0003oa=WYolCIj@0=olCIj@05o`00
0?o4fNWoa=WYo`000?o6e>D00_l0000Dol3@iP04o`000?o0bn?o0000o`0001?o_<ST0_l00008oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Gooooo000Q
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00Co0000oooooooooooo0000
U?ooool00ol0003o_?c7okcla`06okcla`03o`000?o3o]ko`okN00Oo`okN0_l00008olCij`?o0000
0_oBm>H00ol0003oc>g[olc]j`0<olc]j`;o00001_o6iNd3o`0000Goa^G]00Co0000ol[Oj?o:gnSo
b]oX0_l0000@olCIj@03o`000?o4fNWoa=WY00;o00005_o0d>H2o`0001Ko_<ST0_l00007ooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Gooooo000Qoooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0009;ooooo00?o0000okclaonlo<L01Onlo<L2o`0000Wo`okN00?o0000olCijoo4nN/02oo4
nN/3o`0000goc>g[00?o0000olKUkOo6iNd00oo6iNd3o`0000Woa^G]00?o0000ol[Oj?l000004oo4
fNT2o`000003okoDj_l0003o`=3V01?o`=3V0_l000000onkcNOo0000okc8i00Eokc8i0;o00001ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`00
8Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool2o`000003
ooooool0003ooooo08oooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP08ol?ngP03
o`000?o4nN_oa?W[00_oa?W[00Go0000ol;alOo2lO7o`_7ao`00000:olc]j`;o00000oo6iNd3o`00
00coa^G]0ol0000BolCIj@03o`000?noe>[o000000;o_mCZ00?o0000ol3@i_o0d>H04?o0d>H00ol0
003o^lgWok_=i`02ok_=i`03o`000?nlb>Co_<ST017o_<ST0_l000000onhanGo0000o`000006oooo
o`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Gooooo`008Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00002>
ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h01oo3o]h2o`0000coa?W[0_l00005
ol;al@;o00001oo<kN/00ol0003oa^G]olKUk@03o`0000goa^G]0_l00003ol3NkP03o`000?o4fNWo
a=WY00goa=WY0_l00003okoDjP04o`000?noe>[o_mCZo`0000oo`=3V0_l00006ok_=i`03o`000?nl
b>Co_<ST00ko_<ST0_l00004okS7i@;o00001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P05oooool0027ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000
2?ooool00ol0003oooooo`00002<ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h0
1oo3o]h00ol0003oa?W[olCij`0:olCij`;o00002Oo2lO42o`0000?oc>g[0_l000000oo6iNgo0000
o`00000>olKUk@;o00001_o0g^h00ol0003oa=WYolCIj@0:olCIj@;o00001Onoe>X01Ol0003o_mCZ
okoDj_noe>[o000000co`=3V0_l00009ok_=i`03o`000?nlb>Co_<ST00_o_<ST0_l00007okS7i@03
o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@41Gooooo000Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000008[ooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP06
ol?ngP;o00003?o4nN/00ol0003o`_7aol;al@0;ol;al@03o`000?o<kN_o000000?o00003_o6iNd2
o`0000Wo`=k^00?o0000olCIjOo4fNT01oo4fNT2o`0000So_mCZ00Go0000okoDj_noe>[o_mCZo`00
0009ol3@iP;o00003?nkcNL00ol0003o_<STokc8i007okc8i0?o00002OnhanD2o`0002kooooo000Q
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooo000008Oooooo0_l00006okcla`;o00002?o3o]h00ol0003oa?W[olCij`0:olCij`;o00003_o2
lO43o`0000ooa^G]0_l0000<ol3NkP03o`000?o4fNWoa=WY00Coa=WY0_l0000;okoDjP05o`000?no
e>[o_mCZokoDj_l000001_o0d>H2o`0000ko^lgW00?o0000okc8i?nlb>@01Onlb>@2o`0000go^<OU
0_l0000]ooooo`00:oooool00ol0003oooooooooo`0:ooooo`?o0000QOooool00ol0003o_?c7okcl
a`05okcla`03o`000?o3o]ko`okN00Oo`okN00?o0000olCijoo4nN/02Oo4nN/2o`0000go`_7a0ol0
0003okkXl`;o00003?o6iNd00ol0003o`=k^ol3NkP0=ol3NkP03o`000?o4fNWoa=WY00;oa=WY00?o
0000okoDj_noe>X03?noe>X01Ol0003o_mCZokoDj_noe>[o000000Co`=3V00?o0000ok_=ionkcNL0
3onkcNL00ol0003o_<STokc8i002okc8i0;o00004?nhanD00ol0003oooooooooo`0[ooooo`00:ooo
ool2o`0000cooooo0ol00023ooooo`03o`000?nlo<Oo_?c700Go_?c700?o0000ol?ng_o3o]h01_o3
o]h2o`0000_oa?W[00?o0000ol;alOo2lO402_o2lO44o`0000Oo_^Sc0_l00008olKUk@;o00004Oo0
g^h01?l0003oa=WYo`000?l0000?okoDjP03o`000?noe>[o_mCZ00;o_mCZ00Co0000ol3@i_l0003o
00004onkcNL01?l0003o_<STo`000?l0000BokS7i@;o0000;?ooool002_ooooo00?o0000oooooooo
ool03?ooool4o`00083ooooo00?o0000okclaonlo<L01Onlo<L00ol0003o`okNol?ngP06ol?ngP03
o`000?o4nN_oa?W[00Woa?W[0_l0000:ol;al@?o000000?o`_7ao`000?l000002_nnj?<00ol0003o
a^G]olKUk@03olKUk@;o00004oo0g^h2o`0001;o_mCZ00Co0000okoDj_noe>[o_mCZ0_l0000Eok_=
i`;o00005OnhanD2o`0002_ooooo000[ooooo`03o`000?oooooooooo00gooooo1?l0001nooooo`03
o`000?nlo<Oo_?c700Go_?c700Co0000ol?ng_o3o]ko`okN2?l00008olCij`;o00002Oo2lO43o`00
00;o`_7a0_l0000=okkXl`;o000000?oa^G]o`000?l000004oo0g^h2o`000003okcHk_l0003o_mCZ
01;o_mCZ0ol000000onjd>_o0000ok_=i`0Bok_=i`;o000000?o^<[Xo`000?nhanD05?nhanD2o`00
02_ooooo000Zooooo`;o00004?ooool4o`0007cooooo00?o0000okclaonlo<L00onlo<L7o`0000;o
WoGJ0_l00004ojcgk@Go00000_o4nN/00ol0003o`_7aol;al@06ol;al@?o00000oo2lO42o`00013o
_^Sc0ol0000Bol3NkP;o00001?nlf>h00ol0003o_mCZokoDjP0?okoDjP;o00001?njd>/00ol0003o
^lgWok_=i`0>ok_=i`;o00001?nhb^P00ol0003o^<OUokS7i@0CokS7i@;o0000:_ooool002[ooooo
00?o0000ooooooooool04?ooool2o`000003ohP00?l0003ooooo07Wooooo00?o0000okclaonlo<L0
1Ol00006oioefP;o00002on/mnd4o`0000Co`_7a0ol00004ol;al@;o00004?nnj?<2o`0000?o^^7c
00?o0000ol3Nk_o0g^h03Oo0g^h2o`0000Oo_=S^00?o0000okoDj_noe>X03?noe>X2o`0000;o^]3[
00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=i`0;ok_=i`;o00001onhb^P00ol0003o^<OU
okS7i@0BokS7i@?o0000:Oooool002[ooooo00?o0000ooooooooool04Oooool5o`0007Oooooo1?l0
0002ohSW]`;o00001_nOmMX00ol0003o[?O]ojcgk@09ojcgk@;o00001?nalOH4o`0000Ko`_7a00?o
0000okkXlonnj?<03_nnj?<2o`0000Ko^^7c00?o0000ol3Nk_o0g^h02_o0g^h2o`0000[o_=S^00?o
0000okoDj_noe>X02?noe>X3o`0000Go^]3[00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=
i`08ok_=i`;o00002Onhb^P00ol0003o^<OUokS7i@0?okS7i@?o000000?o]LGVo`000?l00000:Ooo
ool002[ooooo00?o0000ooooooooool04_ooool01Ol0003o04[3o`000?n8003o000007Cooooo0ol0
0003ohSW]`;o00001_nOmMX2o`0000[o[?O]0_l00004ok7amP?o00000_nalOH3o`0000;o`_7a0_l0
000?okkXl`;o00002OnjhO<00ol0003o`=k^ol3NkP08ol3NkP03o`000?nlf>ko_=S^00_o_=S^00?o
0000okoDj_noe>X01Onoe>X2o`0000Wo^]3[00?o0000ok[@jonjd>/00_njd>/00ol0003o^lgWok_=
i`05ok_=i`;o00003?nhb^P00ol0003o^<OUokS7i@0<okS7i@;o00001OneaNH2o`0002Sooooo000Z
ooooo`?o00004oooool01?l0003o04[3o`000?n80002o`00077ooooo00?o0000ohSW]on8ikL00on8
ikL00ol0003oWoGJoioefP04oioefP;o00002_n/mnd2o`0000?o/O7f0ol00008ok7amP?o00003_nn
j?<2o`0000co^^7c00?o0000ol3Nk_o0g^h01Oo0g^h2o`0000oo_=S^00?o0000okoDj_noe>X00_no
e>X2o`0000_o^]3[00?o0000ok[@jonjd>/00onjd>/00ol0003o^lgWok_=i`02ok_=i`;o00003onh
b^P00ol0003o^<OUokS7i@08okS7i@?o00002?neaNH2o`0002Oooooo000Yooooo`;o00005_ooool0
0ol0003o04[3o`000002ohP000;o0000KOooool2o`0000CoR>Ng0_l00005oioefP;o00002_n/mnd2
o`0000;o/O7f0ol00009ok7amP;o00000onbjOP00ol0003o_^ScokkXl`0:okkXl`03o`000?njhO?o
^^7c00go^^7c00?o0000ol3Nk_o0g^h00_o0g^h2o`0001;o_=S^00Co0000okoDj_l0003o00003_nj
d>/00ol0003o^]3[ok[@j`03ok[@j`04o`000?nkcNOo0000o`0001;o^<[X00?o0000okS7iOnhanD0
1OnhanD2o`0000_o]LGV0_l0000Wooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool05_ooool3o`0000?oR0000_l0001Zooooo`03o`000?n8ikOoR>Ng00;oR>Ng0_l00005oioefP;o
00002on/mnd00ol0003o/O7fok7amP02o`0000[o/O7f0_l00006ok;Yn0;o00002?nnj?<2o`00017o
^^7c00Co0000ol3Nk_l0003o00005?nlf>h2o`00017o^]3[00?o0000ok[@jonjd>/00_njd>/2o`00
01Co^<[X00?o0000okS7iOnhanD00onhanD2o`0000ko]LGV0_l0000Vooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Sooooo0_l00004ohP000;o0000I_ooool2
o`0000CoR>Ng00?o0000oioef_nOmMX01?nOmMX00ol0003o[?O]ojcgk@09ojcgk@Go00002_nalOH2
o`0000[o/^Wh0_l00004okkXl`;o00004onjhO<3o`0001?o_=S^0_l00002okSCkP03o`000?njd>_o
^]3[00ko^]3[00?o0000ok[@jonjd>/00_l000000ongcN_o0000okS:j00DokS:j003o`000?nhanGo
000000;o00004?neaNH3o`0002Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0_l0000Jooooo`Co00000on80002
o`0006?ooooo00?o0000ohSW]on8ikL00_n8ikL2o`0000GoWoGJ0_l0000:ojcgk@Co00002_nalOH3
o`0000ko/^Wh00Co0000okkXlol0003o00004onjhO<2o`0000?o]m[b00?o0000okcHk_nlf>h03_nl
f>h2o`0000Go^=?^00?o0000ok[@jonjd>/03_njd>/2o`0000Co]lg[00?o0000okS:j?nhb^P04_nh
b^P2o`0001Co]LGV0_l0000Uooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01[ooooo00?o
0000oaAfhol000001?l000000on8003o0000o`00001Oooooo`;o00000on8ikL2o`0000CoWoGJ2?l0
0005ojcgk@?o00002onalOH2o`00017o/^Wh0ol0000Bok[Ql`;o00001_ngf_800ol0003o_=S^okcH
kP0;okcHkP;o00002?nhdnh00ol0003o^]3[ok[@j`0;ok[@j`;o000000?o]lg[o`000?ngcN/01?ng
cN/00ol0003o^<[XokS:j00?okS:j0;o000000?o]<SXo`000?neaNH05?neaNH2o`0002Cooooo0006
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Kooooo`04o`000?lDM^?o0000o`0000;o
R@001Ol0001Looooo`03o`000?n8ikOoR>Ng00;oR>Ng00?o0000oioef_l000001Ol00007oh[/k0So
00002OnalOH2o`00017o/^Wh0_l00003ok7Qm`03o`000?njhO?o^^7c00go^^7c0_l00009okOJlP03
o`000?nlf>ko_=S^00So_=S^0_l0000;okSCkP03o`000?njd>_o^]3[00So^]3[0_l00004okO=j`03
o`000?ngcN_o]lg[00?o]lg[00?o0000okS:j?nhb^P02onhb^P3o`0000Co]<SX00?o0000okG5i_ne
aNH04_neaNH2o`0002Cooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01?l0003o
57KSoaAfhol00005ohT000?o0000FOooool01?l0003oR>NgohSW]on8ikL4o`000003ofkNcOl0003o
000000WoR^c/1?l00005oi[/n0Go00000_nalOH2o`00013o/^Wh0ol00006ok7Qm`;o00002onjhO<2
o`0000co]m[b00?o0000okcHk_nlf>h01Onlf>h2o`0000ko^=?^00?o0000ok[@jonjd>/01Onjd>/2
o`0000Ko]lg[00?o0000okO=jongcN/01?ngcN/00ol0003o^<[XokS:j008okS:j0;o00002?ndb>P0
0ol0003o]LGVokG5iP0AokG5iP?o00008oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o00007ooo
ool00ol0003o57KSoaAfh`02o`0000KoR@000_l0001Eooooo`;o000000CoR>Ngo`000?l0003o0000
0_m^g/d3o`0000SoR^c/1Ol0000<oi[/n0?o00003onbjOP2o`0000_o/N7g00?o0000ok[QlonjhO<0
1_njhO<2o`0000oo]m[b00?o0000okcHk_nlf>h00_nlf>h2o`00017o^=?^00?o0000ok[@jonjd>/0
0_njd>/2o`0000Wo]lg[00?o0000okO=jongcN/00ongcN/00ol0003o^<[XokS:j006okS:j0;o0000
2ondb>P00ol0003o]LGVokG5iP0=okG5iP?o000000Co//?Wo`000?oooooo00008_ooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Gooooo00?o0000ooooooooool07oooool01?l0003o57KSoaAfholDM^<2o`0000KoR@000ol0001A
ooooo`03o`000?n8ikOo000000;o00000_m^g/d2o`0000SoR^c/1Ol0000<oi[/n0?o00000onSi_`2
o`0000_o/^Wh0_l0000>ok7Qm`;o00001?njhO<2o`0001;o]m[b00Co0000okcHk_l0003o00005?nh
dnh01?l0003o^]3[o`000?l0000<okO=j`03o`000?ngcN_o]lg[00?o]lg[00?o0000okS:j?nhb^P0
0_nhb^P3o`0000ko]<SX00?o0000okG5i_neaNH02OneaNH3o`0000Go//?W0_l0000Rooooo`00:?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?lDM^?o57KS00;o57KS00?o0000ohT00?n900001On9
0003o`0004gooooo1?l00003ofkNc@;o00001on:k>`3o`000003oh[/k?l0003o000000coV^ch0_l0
0008oj?Vo0?o00001OnbjOP3o`0001;o/N7g00Co0000ok[Qlol0003o00005?ngf_83o`0001Go^=?^
0_l0000?okO=j`03o`000?ngcN_o]lg[00?o]lg[00Co0000okS:j?l0003o00004Ondb>P00ol0003o
]LGVokG5iP07okG5iP;o00002Onb`nL2o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo000Xooooo`03o`000?oooooooooo
027ooooo00?o0000oaAfholDM^<00_lDM^<2o`0000OoR@000ol0001:ooooo`?o00000_m^g/d3o`00
00KoR^c/0ol000001?n:k>co0000o`000?l0000;oi[/n0?o00003OnSi_`2o`000003ok;Yn?l0003o
000001Go/N7g0ol0000CokOJlP;o00000onde?400ol0003o^=?^okSCkP0@okSCkP;o000000?o]<o]
o`000?ngcN/03_ngcN/00ol0003o]lg[okO=j`03okO=j`;o00005?ndb>P00ol0003o]LGVokG5iP03
okG5iP?o00003?nb`nL2o`0000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo000Xooooo`;o00008oooool3o`0000?o57KS00?o
0000ohT00?n900001_n90004o`0004Gooooo0ol000000om^g/go0000o`00000:o`0000;oR^c/0_l0
000<oi[/n0;o00004OnSi_`3o`0001Co/N7g0_l00003ok3JmP03o`000?ngf_;o]m[b00go]m[b0ol0
0006okCDl@03o`000?nhdnko^=?^00co^=?^0ol00004okC?k@03o`000?ngcN_o]lg[00go]lg[00?o
0000okO=jongcN/00_l000000oncb^_o0000okC8j00DokC8j003o`000?neaNKo000000;o00004?nb
`nL00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000?ooooo000Xooooo`03o`000?oooooooooo02?ooooo00?o0000od:Bl?l00000
2_l00003ohT000Ko0000?oooool6o`0000KoHmSV2_l0000:oi[/n0;o00004OnSi_`2o`0000?oY]ok
00?o0000ok7QmonahOL03_nahOL3o`0000Ko/=[f00?o0000okOJl_ngf_802_ngf_82o`0000[o]=Ca
00?o0000okSCk_nhdnh02Onhdnh2o`0000So]<o]00?o0000okO=jongcN/03?ngcN/3o`0000Co/l[[
00?o0000okC8j?ndb>P04_ndb>P2o`0001?o//?W0_l00007ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo000Wooooo`03o`000?oooooooooo02Go
oooo00?o0000od:Bl?m2T_000om2T_03o`0000?oNP003?l0000jooooo`Go00001omSf>H2o`000003
of?Hi_l0003o000000;o00001On0hOT5o`0000;oV^ch0ol0000@oj?Vo0?o00001_nVgo/2o`0000co
/N7g0_l0000:ok3JmP;o00002?ngf_82o`0000go]=Ca00?o0000okSCk_nhdnh01_nhdnh2o`0000_o
]<o]00?o0000okO=jongcN/02OngcN/2o`000003ok?:jol0003o/l[[00Go/l[[00?o0000okC8j?nd
b>P03ondb>P2o`000003ok76jOl0003o//?W01?o//?W0_l00006ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00?ooooo000Wooooo`03o`000?oooooooooo
02Kooooo00?o0000od:Bl?m2T_001Om2T_02o`0000WoNP002?l0000cooooo`Go00001omSf>H6o`00
00goP>7i1?l0000@oj?Vo0;o00002onVgo/00ol0003o/N7gok7Qm`07ok7Qm`;o00003_n`f_H00ol0
003o]m[bokOJlP02okOJlP?o00004?nde?400ol0003o^=?^okSCkP02okSCkP?o00003_ndcnd00ol0
003o]lg[okO=j`06okO=j`;o00001?ncb^/00ol0003o/l[[ok?:j`04ok?:j`03o`000?ndb>So]<SX
00_o]<SX0ol00004ok76j@03o`000?nb`nOo//?W01;o//?W00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4003ooooo`009oooool2
o`0002Sooooo00?o0000od:Bl?m2T_001_m2T_03o`0000[oNP002_l0000Yooooo`Ko00001omSf>H4
o`0000ooP>7i0ol00004oi7OoP?o00002onSi_`2o`0000koY]ok0_l00004ok7Qm`?o00004On`f_H0
1?l0003o]m[bo`000?l0000DokCDl@04o`000?nhdnko0000o`0001;o]<o]00?o0000okO=jongcN/0
0_ngcN/3o`0000Oo/l[[00?o0000ok?:joncb^/01?ncb^/00ol0003o]<SXokC8j008okC8j0;o0000
2?naa^T00ol0003o//?Wok;3i`0Aok;3i`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`009oooool00ol0003oooooooooo`0Xooooo`03
o`000?m2T_3o@Y;`00So@Y;`0_l0000;ogX000Co00000olo0007o`0001gooooo4ol0000?oh3Qn@?o
00002_nAgoh2o`0000KoXnKl0ol0000BojKOn`04o`000?nahOOo0000o`0001Co/=[f0ol0000EokCD
l@;o00005Ondcnd01?l0003o]lg[o`000?l0000;ok?:j`03o`000?ncb^_o/l[[00?o/l[[00?o0000
okC8j?ndb>P01_ndb>P2o`0000[o/LKY00?o0000ok;3ionb`nL03_nb`nL3o`000003ojo2j?l0003o
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003o@Y;`od:Bl008od:Bl0?o00002omj
000Ho`0000[ooooo3Ol00002oc^ngPOo00001?mUdOP3o`0000WoP>7i0ol0000?oi7OoP?o000000?o
XnKlo`000?l000005?nVgo/4o`0001;o/=[f0ol00003ojoEm003o`000?nde?7o]=Ca013o]=Ca0_l0
00000onad?3o0000okC?k@0DokC?k@;o00003Oncb^/00ol0003o/l[[ok?:j`04ok?:j`03o`000?nd
b>So]<SX00;o]<SX0ol0000=ok76j@03o`000?nb`nOo//?W00[o//?W0ol00005ojo2j003o`000?oo
oooooooo01[ooooo000Wooooo`;o0000:oooool00ol0003o@Y;`od:Bl009od:Bl0?o00000omj0006
o`0000SoGP002?l00008obD001Wo000000CoIM7ho`000?l0003o00002_mUdOP3o`0000?oP>7i0ol0
000Coi7OoPCo00004_nVgo/3o`0000CoZ=Wi00?o0000ok3Jm_n`f_H03?n`f_H3o`0000Oo[mGd00?o
0000okCDlOnde?403?nde?43o`0000Co/M3`00?o0000okC?kOndcnd04?ndcnd2o`000003ok;<kOl0
003o/l[[00go/l[[00?o0000ok?:joncb^/01?ncb^/01?l0003o]<SXo`000?l0000Aok76j@03o`00
0?nb`nOo//?W00Ko//?W0ol00009ojo2j003o`000?oooooooooo01Wooooo000Vooooo`03o`000?oo
oooooooo02cooooo00?o0000od:Bl?m2T_002Om2T_05o`0001KoGP002ol00005oc@000co00000omU
dOP3o`0000ooIM7h1Ol0000Aoi7OoPCo00001?nJfod2o`0000goY]ok0ol00008ojSIn@;o00002_n`
f_H2o`0000_o[mGd00?o0000okCDlOnde?402Onde?42o`0000So/M3`00?o0000okC?kOndcnd03?nd
cnd3o`0000Co//c]00?o0000ok?:joncb^/03?ncb^/00ol0003o/l[[ok?:j`03ok?:j`;o00004ona
a^T00ol0003o//?Wok;3i`03ok;3i`?o00003?n_`^P00ol0003oooooooooo`0Iooooo`009_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?m2T_3o@Y;`00[o@Y;`00?o0000ocVHl_liV?801?l0000@
oeh000?o00003Old000;o`0000?oC/3f1?l0000<ofGAn0Go00001OmneOl3o`0000[oTMon1?l0000:
oi[Ko@?o00001onVgo/3o`0000goZ=Wi0_l00005ok3JmP?o00003_n_eO@00ol0003o]=CaokCDl@06
okCDl@;o00002onad?000ol0003o]<o]okC?k@09okC?k@;o00002?nbc>d00ol0003o/l[[ok?:j`0<
ok?:j`03o`000?ncb^_o000000;o000000?o/LS[o`000?naa^T04onaa^T00ol0003o//?Wo`000002
o`00013o[l;X00?o0000ooooooooool06?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;_oo
ool8o`0000Go@Y;`00?o0000ocVHl_liV?800oliV?83o`0000[oGP000ol0000>oc@000[o00000om>
`?H3o`0000CoC/3f0ol00004ofGAn0Go00003OmneOl3o`0000?oTMon1?l0000Aoi[Ko@;o00000_nV
go/3o`0001;oZ=Wi00?o0000ok3Jm_l000000_l0000BojoEm003o`000?nde?7o]=Ca00;o]=Ca0ol0
000>ok7@l003o`000?ndcngo]<o]00Ko]<o]0_l0000;ok;<k@03o`000?ncb^_o/l[[00[o/l[[0ol0
0005ok78j`03o`000?naa^Wo/LKY017o/LKY0_l0000Cojo2j0;o00006Oooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo033ooooo00?o0000of6Rm?mQX_@00omQX_@Bo`0000?oGP000ol0000?oc@000Wo00000om>
`?H3o`0000?oC/3f2ol0000DogkEo`Co00005OnJfod4o`0001GoZ=Wi0ol0000EojoEm004o`000?nd
e?7o0000o`0001;o/M3`00?o0000okC?kOndcnd00_ndcnd3o`0000ko//c]00?o0000ok?:joncb^/0
1oncb^/2o`0000;o/LS[00?o0000ok78jonab>/01?nab>/00ol0003o/LKYok76j@0=ok76j@?o0000
00?o[lCYo`000?n_`^P04on_`^P2o`0001Sooooo000;ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`;o0000<_ooool00ol0003oHJ;dof6Rm00:of6Rm003o`00
0?mMZOSoGJWh00?oGJWh3ol00008oc@001Co00002_m^bOl2o`0000ooO]Go1?l00004ohgDo`;o0000
4?nJfod3o`0000CoWmKk00?o0000ojSInOnXfOT03onXfOT3o`0000?oZMCf00?o0000ojoEm?n_eO@0
4_n_eO@2o`0001Go/M3`00Co0000okC?kOl0003o00004_nbc>d00ol0003o/l[[ok?:j`03ok?:j`?o
00001Onab>/00ol0003o/LS[ok78j`04ok78j`03o`000?naa^Wo/LKY00Wo/LKY0ol00005ojo4j@03
o`000?n_`^So[l;X01;o[l;X00?o0000ooooooooool05_ooool000_ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0<oooool00ol0003o
HJ;dof6Rm00:of6Rm003o`000?mMZOSoGJWh00[oGJWh00?o0000oefbnomM/_/00omM/_/>o`0000?o
Hkgm0ol00003of>mo@;o00004?m^bOl3o`0000SoO]Go1?l0000:ohgDo`;o00002onJfod3o`0000So
WmKk00?o0000ojSInOnXfOT02onXfOT3o`0000OoZMCf00?o0000ojoEm?n_eO@03_n_eO@3o`0000;o
[]7b00?o0000ok7@l?nad?004_nad?02o`0001Go//c]00?o0000ok?:jol000000_l00008ok78j`03
o`000?nab>_o/LS[00Co/LS[00?o0000ok76jOnaa^T01onaa^T2o`0000Wo[lCY00?o0000ojo2j?n_
`^P04On_`^P2o`0001Oooooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0=?ooool00ol0003oHJ;dof6Rm00:of6R
m003o`000?mMZOSoGJWh00[oGJWh0_l0000;oefbn`;o00001OmS_Od2o`0000SoHkgm0_l0000Aofk9
o`;o00000_mneOl4o`00013oSMCo00?o0000oi[KoOnJfod01OnJfod3o`0000coWmKk0_l00009ojSI
n@;o00002onYe?H00ol0003o[mGdojoEm00:ojoEm0?o00001_n^dO800ol0003o/M3`ok7@l00>ok7@
l0?o00000_n`cNl00ol0003o//c]ok;<k@0Bok;<k@;o00003?nab>/00ol0003o/LS[ok78j`04ok78
j`03o`000?naa^Wo/LKY00?o/LKY0ol0000<ojo4j@03o`000?n_`^So[l;X00oo[l;X0ol0000Goooo
o`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0eooooo`03o`000?mQX_CoHJ;d00[oHJ;d0_l0000<oefYn003o`000?mM/__oGK;k
00[oGK;k00?o0000of>moOl000000_l0000<of>mo@;o00003Om^bOl6o`0001GoSMCo0_l00002oi[K
o@?o00004OnOe_/00ol0003oZ=WiojSIn@03ojSIn@?o00003_nYe?H00ol0003o[mGdojoEm007ojoE
m0;o00002_n^dO800ol0003o/M3`ok7@l00:ok7@l0?o00001_n`cNl00ol0003o//c]ok;<k@0>ok;<
k@?o000000?o/<W]o`000?nab>/03?nab>/00ol0003o/LS[ok78j`04ok78j`03o`000?naa^Wo0000
00;o00004?n_a>T00ol0003o[l;Xojo2j00;ojo2j0?o00000_n]`NP2o`0001Kooooo0005ooooo`03
o`000?oooooooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo0_l0000gooooo`03o`000?mQX_CoHJ;d00_oHJ;d00?o0000oefYn?mMZOP02_mMZOP00ol0
003oGK;koefbn`08oefbn`Co00004?mS_Od2o`0000CoK/Wo1ol00006oh;;o`;o00004on=e?l4o`00
01GoWmKk00?o0000ojSInOl000000_l0000BojWDmP03o`000?n_eOCo[mGd00?o[mGd0ol0000=ojkA
lP03o`000?nad?3o/M3`00Oo/M3`0_l0000:ok3=k`03o`000?nbc>go//c]00[o//c]0ol00005ok39
k@03o`000?nab>_o/LS[00_o/LS[00?o0000ok78jonab>/00onab>/2o`0001?o[lCY00?o0000ojo2
j?n_`^P02?n_`^P3o`0000Ko[L7X0_l0000Eooooo`001Oooool00ol@413ogMgMooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0=oooool00ol0
003oHJ;dof6Rm00;of6Rm003o`000?mMZOSoGJWh00[oGJWh0_l00005oefbn`?o00001?mM/_/2o`00
00coHkgm2?l0000?oh;;o`;o00003On=e?l4o`0000CoU]7l00?o0000oioFnonOe_/04_nOe_/3o`00
01GoZMCf00?o0000ojoEm?l000000_l0000AojkAlP03o`000?nad?3o/M3`00?o/M3`0ol0000=ok3=
k`03o`000?nbc>go//c]00Oo//c]0_l00009ok39k@03o`000?nab>_o/LS[00[o/LS[00?o0000ok78
jonab>/00ol000000on_a^_o0000ojo4j@0Cojo4j@03o`000?n_`^So[l;X00Co[l;X0ol0000:ojg1
j0;o00005?ooool000?ooooo00Goc<c<oa0@4?l0003o0000ohN7Q`0Mooooo`03o`000?oooooooooo
03Sooooo00?o0000of6Rm?mQX_@02omQX_@00ol0003oGJWhoefYn00;oefYn003o`000?mM/__o0000
00;o00002OmM/_/00ol0003oHkgmof>mo@02of>mo@Oo00001_mj`_h2o`00017oP/_o0_l00008ohgD
o`?o00002OnFdO`2o`0000ooWmKk0ol00003oj;An003o`000?nYe?KoZMCf01;oZMCf0ol0000DojkA
lP03o`000?nad?3o000000;o00004On`cNl00ol0003o//c]ok;<k@03ok;<k@?o00003?n`bNd00ol0
003o/LS[ok78j`0:ok78j`;o00001On_a^/00ol0003o[lCYojo4j@0Bojo4j@03o`000?n_`^So[l;X
00?o00003On]`NP2o`0001Cooooo0003ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN76oooool0
0ol0003oooooooooo`0jooooobko00003omj`_h00ol0003oP/_ooh;;o`0@oh;;o`;o00000_n=e?l4
o`0000koU]7l00?o0000oioFnonOe_/02OnOe_/3o`0000OoX]7h0_l0000?ojWDmP?o00000onYd?@0
0ol0003o[]7bojkAlP0AojkAlP?o00005?n`cNl00ol0003o//c]o`000002o`00013o/<W]00?o0000
ok78jonab>/01_nab>/3o`000003ojo6jol0003o[lK[00Go[lK[00?o0000ojo4jOn_a>T04On_a>T3
o`00017o[L7X0_l0000Cooooo`000oooool01_l0003oooooofIVI_n7QhOogMgMoa0@41_ooooo0ol0
000looooo`03o`000?mfZoCoMZ_d00_oMZ_d00?o0000ogBbn?md/_P01?md/_P3o`0000CoM;;h00?o
0000ogFjnome^_/02ome^_/2o`00013oN/;n0_l0000@oh;;o`Co00004onFdO`2o`0000KoWmKk0ol0
000<oj;An003o`000?nYe?KoZMCf00WoZMCf0ol00007ojW@m003o`000?n^dO;o[]7b00go[]7b0ol0
0003ojg=l@03o`000?n`cNoo/<g_017o/<g_0_l0000Dok39k@03o`000?nab>_o/LS[00?o/LS[0_l0
0004ojo6j`03o`000?n_a^_o[lK[00Go[lK[00?o0000ojo4jOn_a>T03On_a>T3o`000003ojg3j_l0
003o[L7X01;o[L7X00?o0000ooooooooool04Oooool000?ooooo00Ko410@omgMgOmgMgOoMgMgoooo
ool0000Kooooo`03o`000?oooooooooo03gooooo00?o0000ogJ[m?mfZo@02omfZo@00ol0003oM;;h
ogBbn003o`0000SoM;;h0_l0000=ogFjn`03o`000?mj`_koN/;n00ooN/;n0_l00009oh;;o`Go0000
1?n>bo`00ol0003oU]7loiKAo00BoiKAo003o`000?nOe__oWmKk00?o00004?nRdOP2o`0000KoZMCf
0ol0000;ojW@m0;o00002_n^dO83o`0000Oo[Lga00?o0000ok3=kon`cNl03On`cNl3o`000003ojk:
kol0003o/<W]01Co/<W]00?o0000ok78jol000000_l00007ojo6j`03o`000?n_a^_o[lK[00Go[lK[
00?o0000ojo4jOn_a>T02On_a>T3o`0000Go[L?Z00?o0000ojg1j?n]`NP04?n]`NP2o`0001;ooooo
0003ooooo`06ojVYZOm4A4CoV9RHodA4A?nHV9So410@6oooool00ol0003oooooooooo`0nooooo`03
o`000?mfZoCoMZ_d00[oMZ_d0ol0000=ogBbn003o`000?me^__oMK[k00_oMK[k0_l0000Aog[2oP04
o`000?n2boooP/_ooh;;o`Go00002_n>bo`2o`00017oU]7l1?l0000Eoj;An003o`000?nYe?KoZMCf
00?o00004?nYd?@00ol0003o[]7bojkAlP04ojkAlP?o00002on]cO400ol0003o/<g_ok3=k`0:ok3=
k`;o00001On^b^l00ol0003o/<W]ok39k@0Bok39k@;o00002on_a^/00ol0003o[lK[ojo6j`04ojo6
j`03o`000?n_a>Wo[lCY00Oo[lCY0_l00009ojg3jP03o`000?n]`NSo[L7X013o[L7X0_l0000Aoooo
o`001?ooool01OnHV9So0000o`000?l@413oc<c<01_ooooo00?o0000ooooooooool0?oooool00ol0
003oMZ_dogJ[m006ogJ[m0?o00000_mfZo@2o`0000goM;;h00?o0000ogFjnome^_/03?me^_/2o`00
00coN/;n1ol0000Aohk;o003o`000?nFdOcoU]7l00[oU]7l1?l00004oic>n@03o`000?nRdOSoX]7h
017oX]7h1?l0000DojW@m003o`000?n^dO;o[]7b00?o00003on]cO400ol0003o/<g_ok3=k`06ok3=
k`?o00002?n^b^l00ol0003o/<W]ok39k@0>ok39k@?o000000?o[/O]o`000?n_a^/02on_a^/00ol0
003o[lK[ojo6j`04ojo6j`03o`000?n_a>Wo[lCY00?o[lCY0ol0000;ojg3jP03o`000?n]`NSo[L7X
00oo[L7X0ol0000Aooooo`001Oooool00onj^[[o<S8booooo`0Looooo`;o0000@Oooool00ol0003o
MZ_dogJ[m002ogJ[m0?o00001omfZo@00ol0003oM;;hogBbn00;ogBbn0;o00003_me^_/00ol0003o
N/;nog[2oP02og[2oPOo00001_n8a?/00ol0003oS/_lohk;o00@ohk;o0;o00001onFdO`3o`0000Wo
W<ki00?o0000oj;An?nRdOP03OnRdOP3o`0000CoY<kf00?o0000ojW@m?nYd?@04OnYd?@3o`0001?o
[Lga00?o0000ok3=kon`cNl00on`cNl2o`0000co[/[_00?o0000ok39kOn`bNd02_n`bNd3o`0000Go
[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[ojo6j`05ojo6j`03o`000?n_a>Wo000000;o
00003on]`nX00ol0003o[L7Xojg1j00;ojg1j0?o00000_n[`>T2o`0000[ooooo1?l00001oa0@407o
oooo0006ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool4o`0000_oMZ_d
00?o0000ogBbn?md/_P03?md/_P00ol0003oMK[kogFjn`05ogFjn`_o00003_n8a?/2o`0001;oS/_l
00?o0000oiKAo?nFdO`01?l0000=oic>n@;o00002_nRdOP3o`0000SoY<kf00?o0000ojW@m?nYd?@0
3OnYd?@3o`0000;oZLgb00?o0000ojg=lOn]cO404_n]cO400ol0003o/<g_o`000002o`0000oo[/[_
00?o0000ok39kOn`bNd01on`bNd2o`0000Wo[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[
ojo6j`03ojo6j`?o00004on]`nX00ol0003o[L7Xojg1j007ojg1j0?o00001_n[`>T00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo000Sooooo`03o`000?oooooooooo047ooooo0ol0
000>ogJ[m003o`000?md/_SoM;;h00GoM;;h3_l00009ohFmn@03o`000?n8a?_oR<Ck00ooR<Ck00?o
0000ohk;o?n>bo`03_n>bo`4o`0001?oW<ki00?o0000oj;An?nRdOP01?nRdOP3o`0000coY<kf00?o
0000ojW@m?nYd?@02_nYd?@2o`0000KoZLgb00?o0000ojg=lOn]cO404?n]cO43o`0001?o[/[_00?o
0000ok39kOn`bNd00on`bNd3o`0000co[/O]00?o0000ojo6jon_a^/02On_a^/00ol0003o[lK[o`00
0002o`0000;o[LG[00?o0000ojg3j_n]`nX04On]`nX00ol0003o[L7Xojg1j004ojg1j0?o00002_n[
`>T00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Sooooo`03o`000?oooooo
oooo03kooooo0ol00003ooooo`03o`000?mfZoCoMZ_d00GoMZ_d3_l00009oh>gmP03o`000?n5_OWo
QKgi00coQKgi0_l0000@ohS4n`;o00002On>bo`5o`0000CoU/Wi00?o0000oic>nOnLc_T04OnLc_T0
0ol0003oX]7hoj;An003o`00013oY<kf00?o0000ojW@m?nYd?@01_nYd?@3o`0000WoZLgb00?o0000
ojg=lOn]cO403?n]cO43o`0000?o[<_`00?o0000ojk:kon^b^l04On^b^l00ol0003o/<W]o`000002
o`0000oo[/O]00?o0000ojo6jon_a^/02?n_a^/3o`0000Ko[LG[00?o0000ojg3j_n]`nX04On]`nX0
0ol0003o[L7Xojg1j003o`0000goZl3Y0_l0000:ooooo`03o`000?oooooooooo007ooooo000Soooo
o`?o0000>oooool3o`0000Oooooo1ol00009ohBalP03o`000?n3]oKoPkOf00coPkOf00?o0000ohFm
nOn5_OT03On5_OT00ol0003oR<CkohS4n`0?ohS4n`04o`000?n>bocoS/_lohk;o0Go00002_nFbOT0
0ol0003oW<kioic>n@0?oic>n@Co00005?nTc_H00ol0003oZM3dojW@m003ojW@m0;o00003OnYcO80
0ol0003o[Lgaojg=l@08ojg=l@?o00001on/bo000ol0003o[/[_ojk:k`0@ojk:k`;o00004on^and0
0ol0003o[lK[ojo6j`04ojo6j`?o00000_n]aN/00ol0003o[LG[ojg5j`05ojg5j`03o`000?n]`n[o
[L?Z00oo[L?Z1?l0000Aoj_0j@03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
02?ooooo00?o0000ooooooooool0>?ooool3o`0000_ooooo00?o0000ohBal_n4/O803On4/O800ol0
003oPkOfoh>gmP0<oh>gmP03o`000?n5_OWoQKgi00goQKgi0_l0000<ohS4n`Oo00004?nFbOT2o`00
00_oW<ki1?l00004oj3;mP03o`000?nTc_KoY<kf01;oY<kf00?o0000ojW@m?l000000_l0000@ojW=
lP03o`000?n]cO7o[Lga00Co[Lga0ol0000;ojc;l003o`000?n^b^oo[/[_00co[/[_0ol00002ojc8
kP03o`000?n^ango[/O]017o[/O]00?o0000ojo6jon_a^/00ol00006ojg5j`03o`000?n]aN_o[LG[
00Go[LG[00?o0000ojg3j_n]`nX02on]`nX3o`0000;oZl;[00?o0000oj_0jOn[`>T04On[`>T00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo03Gooooo0ol0000?ooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000
oh>gm_n3]oH03?n3]oH00ol0003oQKgiohFmn@0>ohFmn@03o`000?n8a?_oR<Ck00;oR<Ck1ol00006
oi;4n003o`000?nFbOWoU/Wi013oU/Wi00?o0000oic>nOnLc_T01OnLc_T3o`0000WoX<_f00?o0000
ojC>m_nTc_H04?nTc_H4o`0001?oZLgb00?o0000ojg=lOn]cO400ol0000?ojc;l003o`000?n^b^oo
[/[_00So[/[_0ol00006ojc8kP03o`000?n^ango[/O]013o[/O]0ol0000:ojg5j`03o`000?n]aN_o
[LG[00Co[LG[00?o0000ojg3j_n]`nX02?n]`nX3o`0000KoZl;[00?o0000oj_0jOn[`>T04?n[`>T2
o`0000Sooooo00?o0000ooooooooool00Oooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo03?ooooo0ol0000Cooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000oh>gm_n3]oH03?n3]oH0
0ol0003oQKgiohFmn@0<ohFmn@Ko00003_nBa?P2o`00017oU/Wi00?o0000oic>nOnLc_T01?l0000=
oj3;mP;o00003?nTc_H4o`0000CoY/_c00?o0000ojW=l_nYcO804?nYcO83o`0001?o[<_`00?o0000
ojk:kon^b^l01?n^b^l3o`0000[o[<S^00?o0000ojk7kOn^and03?n^and3o`000003ojc6kOl0003o
[LG[00[o[LG[00?o0000ojg5jon]aN/01On]aN/00ol0003o[L?Zojg3jP04ojg3jP?o00002_n[`^/0
0ol0003oZl3Yoj_0j@0@oj_0j@03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000000oooool0
0005oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00;ooooo0ol0000`ooooo`?o00005oooool00ol0003oQ;7bohBalP0=ohBalP03o`000?n3]oKo
PkOf00coPkOf00?o0000ohFmnOn5_OT01_n5_OT5o`0000CoSkof00?o0000oi;4n?nBa?P03onBa?P0
0ol0003oU/WioiK9n@0=oiK9n@Co00004onPboH00ol0003oY<kfojC>mP05ojC>mPCo00002OnVbo<0
0ol0003oZLgbojW=lP0<ojW=lP?o00000onYb_400ol0003o[<_`ojc;l00Aojc;l003o`000?n^b^oo
[/[_00?o00003_n/b>h00ol0003o[/O]ojk7k@08ojk7k@?o00001On/a^d00ol0003o[LG[ojg5j`09
ojg5j`03o`000?n]aN_o[LG[00Go[LG[00?o0000ojg3j_n]`nX00ol0000=oj_2j`03o`000?n[`>Wo
Zl3Y00ooZl3Y0ol0000;ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo00Kooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0]ooooo`?o00006oooool0
0ol0003oQ;7bohBalP0=ohBalP03o`000?n3]oKoPkOf00coPkOf00?o0000ohFmnOn5_OT01Ol0000:
ohnomP03o`000?nBa?SoT/Ch00ooT/Ch0_l00008oiK9n@Go00001?nLb?H00ol0003oX<_foj3;mP0A
oj3;mP03o`000?nTc_KoY<kf00Co00003_nVbo<00ol0003oZLgbojW=lP08ojW=lP?o00001onYb_40
0ol0003o[<_`ojc;l00@ojc;l0?o00004_n/b>h00ol0003o[/O]ojk7k@04ojk7k@?o00002On/a^d0
0ol0003o[LG[ojg5j`09ojg5j`03o`000?n]aN_o[LG[00Co[LG[0ol0000Aoj_2j`03o`000?n[`>Wo
Zl3Y00_oZl3Y0ol000000ooooooo0000ooooo`0;ooooo`0000Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02[ooooo0ol0000Oooooo`03o`000?n4/O;oQ;7b00goQ;7b00?o0000oh>gm_n3]oH01On3
]oH9o`00013oSkof0_l0000Aoi;4n003o`000?nFbOWoU/Wi00Go00002_nLb?H2o`00013oX<_f1?l0
000CojK;l`03o`000?nYcO;oZLgb00CoZLgb0ol0000;ojW:l@03o`000?n/bo3o[<_`00co[<_`0ol0
00000on[bNoo0000ojc8kP0Cojc8kP03o`000?n^ango[/O]00?o00003On/a^d00ol0003o[LG[ojg5
j`09ojg5j`03o`000?n]aN_o[LG[00?o000000?oZlC/o`000?n[`^/04_n[`^/00ol0003oZl3Yoj_0
j@07oj_0j@?o00001?ooool00ol0003oooooooooo`0:ooooo`0000Go410@oooooooooooooooooa0@
400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Wooooo`?o00008oooool00ol0003oQ;7bohBalP0:ohBalP[o00002On>^_@00ol0003oSkofohno
mP0?ohnomP03o`000?nBa?SoT/Ch00goT/Ch1?l0000Aoic8mP03o`000?nPboKoX<_f00[oX<_f0ol0
0004oj;9m003o`000?nVbo?oY/_c017oY/_c00?o0000ojW=l_nYcO800ol0000?ojW:l@03o`000?n/
bo3o[<_`00So[<_`0ol00005oj_9k`03o`000?n/b>ko[<S^017o[<S^0ol0000Aojc6k@03o`000?n]
aN_o[LG[00So[LG[0ol00005oj_4k003o`000?n[`^_oZl;[013oZl;[00?o0000oj_0jOn[`>T01?n[
`>T3o`0000Sooooo00?o0000ooooooooool02Oooool00005ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01_ooool2o`0002Gooooo
0ol0000Wooooo`03o`000?n4/O;oQ;7b00;oQ;7b1ol00005ohjel@03o`000?n>^_CoS[[d00coS[[d
00?o0000ohnom_n?_oH03on?_oH00ol0003oT/Choi;4n007oi;4n0Go00001?nHa?D00ol0003oW<Sf
oic8mP0?oic8mP;o00001_nPboH4o`0000SoX/Wd00?o0000ojK;lonVbo<04?nVbo<3o`0001?oZL[a
00?o0000ojc;l?n/bo001?n/bo03o`0000WoZlW_00?o0000ojc8k_n/b>h03On/b>h3o`000003oj_7
k_l0003o[<K]01;o[<K]00?o0000ojg5jon]aN/01?n]aN/3o`000003oj_4k?l0003oZlC/00KoZlC/
00?o0000oj_2jon[`^/04?n[`^/00ol0003oZl3Yoj_0j@03o`0000_ooooo00?o0000ooooooooool0
2Oooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00004ooooo`;o0000
8oooool3o`0002_ooooo1?l0000=ohjel@03o`000?n>^_CoS[[d00coS[[d0_l0000@ohnomP04o`00
0?nBa?SoT/Choi;4n0Go00002_nHa?D00ol0003oW<Sfoic8mP0@oic8mP03o`000?nPboKoX<_f00?o
00003OnRbO@00ol0003oY/_cojK;l`0<ojK;l`?o00000onWbO800ol0003oZL[aojW:l@0AojW:l@03
o`000?n/bo3o[<_`00?o00003On[bNl00ol0003o[<S^ojc8kP0:ojc8kP;o00001On[anh00ol0003o
[<K]ojc6k@0Aojc6k@03o`000?n]aN_o[LG[00?o00001On[a>`00ol0003oZlC/oj_4k005oj_4k003
o`000?n[`^_oZl;[00koZl;[1?l0000>ooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo01oooooo0ol0000`ooooo`03o`000?n>]O7oS[Ga00goS[Ga00?o0000ohjjm?n>^_@0
3On>^_@00ol0003oSkofohnomP0<ohnomPGo00004?nHa?D00ol0003oW<Sfoic8mP0>oic8mPCo0000
4OnRbO@00ol0003oY/_cojK;l`08ojK;l`?o00001onWbO800ol0003oZL[aojW:l@0@ojW:l@?o0000
4On[bNl00ol0003o[<S^ojc8kP06ojc8kP?o00002?n[anh00ol0003o[<K]ojc6k@0@ojc6k@?o0000
2On[a>`00ol0003oZlC/oj_4k004oj_4k003o`000?n[`^_oZl;[00[oZl;[1?l0000Booooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo01gooooo0_l0000dooooo`03o`000?n>
]O7oS[Ga00goS[Ga00?o0000ohjjm?n>^_@03On>^_@00ol0003oSkofohnomP06ohnomPGo00001?nF
_o@00ol0003oV<CeoiS4m@0?oiS4m@03o`000?nLb?KoW<Sf00WoW<Sf1?l00004oio6m003o`000?nR
bOCoX/Wd00ooX/Wd00?o0000ojK;lonVbo<01?nVbo<3o`0000_oYlWb00?o0000ojW:lOnYb_403?nY
b_43o`0000;oZLS`00?o0000oj_9kon[bNl04?n[bNl00ol0003o[<S^ojc8kP03ojc8kP;o00003?n[
anh00ol0003o[<K]ojc6k@0<ojc6k@?o000000?oZ/G]o`000?n[a>`02On[a>`00ol0003oZlC/oj_4
k005oj_4k003o`000?n[`^_oZl;[00GoZl;[1?l0000Fooooo`03o`000?oooooooooo00Wooooo000Q
ooooo`;o00006oooool3o`0003Oooooo00?o0000ohjelOn>]O403On>]O400ol0003oS[[dohjjm00=
ohjjm003o`000?n?_oKoSkof00Go00002_nF_o@00ol0003oV<CeoiS4m@0?oiS4m@03o`000?nLb?Ko
W<Sf00GoW<Sf0ol00009oio6m003o`000?nRbOCoX/Wd00ooX/Wd00?o0000ojK;lonVbo<00ol0000?
ojO9lP03o`000?nYb_7oZL[a00SoZL[a0ol00006ojW8l003o`000?n[bNooZlW_013oZlW_00?o0000
ojc8k_l000000_l0000?oj_7kP03o`000?n/a^go[<K]00So[<K]0ol00005oj[5k@03o`000?n[a>co
ZlC/00SoZlC/00?o0000oj_4k?n[a>`01On[a>`00ol0003oZl;[oj_2j`04o`0001[ooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool05oooool3o`0003_ooooo00?o0000ohje
lOn>]O403On>]O400ol0003oS[[dohjjm00:ohjjm0Go00004?nF_o@2o`00013oV<Ce00?o0000oic8
m_nLb?H01?l0000=oio6m003o`000?nRbOCoX/Wd00goX/Wd1?l0000CojO9lP03o`000?nYb_7oZL[a
00CoZL[a0ol0000:ojW8l003o`000?n[bNooZlW_00koZlW_0ol0000Coj_7kP03o`000?n/a^go[<K]
00Co[<K]0ol00009oj[5k@03o`000?n[a>coZlC/00SoZlC/00?o0000oj_4k?n[a>`01?n[a>`3o`00
01kooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool05?ooool3o`0003oo
oooo00?o0000ohjelOn>]O403On>]O400ol0003oS[[dohjjm002ohjjm0Oo00001OnE^o800ol0003o
U[odoiJom00?oiJom003o`000?nHa?GoV<Ce00coV<Ce1?l0000Boio6m003o`000?nRbOCoX/Wd00Wo
X/Wd0ol00004ojC7lP03o`000?nWbO;oYlWb017oYlWb00?o0000ojW:lOnYb_400ol0000>ojW8l003
o`000?n[bNooZlW_00WoZlW_1?l00003oj[7k`03o`000?n[ankoZlO^017oZlO^00?o0000ojc6kOn/
a^d00ol0000=oj[5k@03o`000?n[a>coZlC/00OoZlC/00Co0000oj_4k?n[a>coZlC/0ol0000Roooo
o`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo01;ooooo0ol00013ooooo`03
o`000?n>]O7oS[Ga00[oS[Ga1ol0000=oiFklP03o`000?nF_oCoU[od00ooU[od00?o0000oiS4mOnH
a?D01_nHa?D5o`0000CoWL?c00?o0000oio6m?nOa_@04?nOa_@00ol0003oX/Wdoj;9m004oj;9m0Co
00002?nTao800ol0003oYlWbojO9lP0@ojO9lP?o00004_nYb?000ol0003oZlW_oj_9k`05oj_9k`?o
00002?nZanl00ol0003oZlO^oj_7kP0@oj_7kP?o00004?nZaNd00ol0003oZlC/oj_4k008oj_4k0?o
00009Oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0?ooooo`?o0000
Aoooool00ol0003oS[Gaohjel@02ohjel@Oo00001OnE]nl00ol0003oUK_boiFklP0=oiFklP;o0000
4?nF_o@00ol0003oV<CeoiS4m@05o`0000[oWL?c00?o0000oio6m?nOa_@04?nOa_@00ol0003oX/Wd
oj;9m003o`0000goY<Ob00?o0000ojO9l_nWbO803?nWbO83o`0000;oYlS`00?o0000ojW8l?nYb?00
4OnYb?000ol0003oZlW_oj_9k`04o`0000coZ/O_00?o0000oj_7k_n[anh03?n[anh3o`000003oj[6
k_l0003oZ/G]017oZ/G]00?o0000oj_4k?n[a>`01?n[a>`3o`000003ooooool0003ooooo02Gooooo
00?o0000ooooooooool02?ooool0023ooooo0ol0000<ooooo`?o0000Boooool4o`0000goUKO_00?o
0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom00<oiJom0Co00004?nM`o<00ol0003oWlKdoio6
m00>oio6m0Co00004OnTao800ol0003oYlWbojO9lP08ojO9lP?o00001_nWb?000ol0003oZLS`ojW8
l00@ojW8l0?o00004OnZanl00ol0003oZlO^oj_7kP08oj_7kP?o00001OnZa^h00ol0003oZ/G]oj[5
k@0@oj[5k@03o`000?n[a>coZlC/00?o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Sooooo000Pooooo`03o`000?oooooooooo00Wooooo0ol0001?ooooo`03o`000?nE]noo
UKO_00koUKO_00?o0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom006oiJom0Go00001?nL`?40
0ol0003oWL?coig3l`0>oig3l`03o`000?nOa_CoWlKd00WoWlKd1?l00004oj;5lP03o`000?nTao;o
Y<Ob00ooY<Ob00?o0000ojO9l_nWbO801?nWbO83o`0000[oYlS`00?o0000ojW8l?nYb?003?nYb?03
o`0000;oZLO_00?o0000oj[7konZanl04?nZanl00ol0003oZlO^oj_7kP04oj_7kP?o00002OnZa^h0
0ol0003oZ/G]oj[5k@0>oj[5k@Co00002?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo000Pooooo`03o`000?oooooooooo00Kooooo0ol0001Cooooo`03o`000?nE]nooUKO_
00koUKO_00?o0000oiFkl_nE^o803_nE^o800ol0003oU[odoiJom005o`0000[oW<3a00?o0000oig3
lonM`o<03_nM`o<00ol0003oWlKdoio6m005oio6m0?o00002OnRaO800ol0003oY<ObojC7lP0?ojC7
lP03o`000?nWbO;oYlWb00?o00003_nWb?000ol0003oZLS`ojW8l008ojW8l0?o00001_nYanl00ol0
003oZ/O_oj[7k`0@oj[7k`03o`000?n[ankoZlO^00?o00003OnZa^h00ol0003oZ/G]oj[5k@09oj[5
k@Co00003Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Pooooo`03
o`000?oooooooooo00?ooooo0ol0001Gooooo`03o`000?nE]nooUKO_00koUKO_00?o0000oiFkl_nE
^o803?nE^o84o`00013oW<3a00?o0000oig3lonM`o<03_nM`o<00ol0003oWlKdoio6m004o`0000go
X/Gb00?o0000ojC7l_nTao803OnTao84o`0001;oYlS`00?o0000ojW8l?nYb?001?nYb?03o`0000[o
ZLO_00?o0000oj[7konZanl03_nZanl4o`00017oZ/K^00?o0000oj[5kOnZaNd01OnZaNd3o`0001;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`007oooool7o`0005_ooooo
00?o0000oiFgkonE]nl03_nE]nl00ol0003oUK_boiFklP06oiFklPGo00000onK_?000ol0003oW<3a
oic0l@0?oic0l@03o`000?nM`o?oWL?c00coWL?c1?l0000Boj;5lP03o`000?nTao;oY<Ob00WoY<Ob
0ol00004ojK6l003o`000?nWb?3oYlS`013oYlS`00?o0000ojW8l?nYb?000ol0000>ojW7k`03o`00
0?nZanooZ/O_00WoZ/O_1?l00002ojW7k`03o`000?nZa^koZ/K^017oZ/K^00?o0000oj[5kOnZaNd0
1?l0000Eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001oooooo1?l0
001Oooooo`03o`000?nE]nooUKO_00koUKO_00?o0000oiFkl_nE^o801Ol00009oi^ll003o`000?nL
`?7oW<3a00ooW<3a00?o0000oig3lonM`o<01_nM`o<5o`0000CoXL?a00?o0000oj;5l_nRaO804?nR
aO800ol0003oY<ObojC7lP04ojC7lPCo00002?nVa_000ol0003oYlS`ojO8l00>ojO8l0Co00004_nY
anl00ol0003oZ/O_oj[7k`05oj[7k`?o00001onYanl00ol0003oZ/K^oj[6kP0@oj[6kP?o00006_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Eooooo`Co000000?o410@
ooooooooool00oooool2o`0006;ooooo00?o0000oiFgkonE]nl03?nE]nl4o`0000ooVkc`00?o0000
oic0lOnL`?403onL`?400ol0003oWL?coig3l`05o`0000[oXL?a00?o0000oj;5l_nRaO804?nRaO80
0ol0003oY<ObojC7lP03o`0000goY/K`0_l0000;ojO8l0?o00000onXao000ol0003oZLO_ojW7k`0A
ojW7k`03o`000?nZanooZ/O_00Co00002onYanl00ol0003oZ/K^oj[6kP0<oj[6kP?o00007_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H?ooool00ol0003oUKO_oiFgk`06oiFgk`Go00001?nJ^Nh00ol0
003oVkc`oi^ll00=oi^ll003o`000?nL`?7oW<3a00goW<3a1?l0000@oj73l@03o`000?nRaO;oX/Gb
00koX/Gb1?l0000BojK6l003o`000?nWb?3oYlS`00CoYlS`1?l00007ojS7l003o`000?nYanooZLO_
013oZLO_0ol0000@ojW7k`03o`000?nZa^koZ/K^00SoZ/K^0ol0000Rooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01oooool001Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?nE]nooUKO_00Go00002_nJ^Nh00ol0003oVkc`oi^ll00=oi^ll003
o`000?nL`?7oW<3a00WoW<3a0ol00004oio0l003o`000?nQ`o7oXL?a00koXL?a00?o0000oj;5l_nR
aO802OnRaO84o`0000?oY<G`00?o0000ojK6l?nVa_004OnVa_000ol0003oYlS`ojO8l003o`0000co
Z<O`00?o0000ojW7konYanl03?nYanl3o`0000;oZLO_00?o0000ojW7konYanl03onYanl00ol0003o
Z/K^oj[6kP04oj[6kP?o00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oo
oooo000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0H?ooool2o`00013oV[W^
00?o0000oi^ll?nK_?003OnK_?000ol0003oW<3aoic0l@04oic0l@Co00002?nO`?000ol0003oXL?a
oj73l@0>oj73l@03o`000?nRaO;oX/Gb00GoX/Gb0ol00008ojC5l003o`000?nVa_3oY/K`013oY/K`
0ol0000@ojS7l003o`000?nYanooZLO_00SoZLO_0ol00006ojW7k`03o`000?nYanooZLO_00ooZLO_
00?o0000oj[6k_nZa^h00ol0000Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1oooool001Oooooo00?o0000ooooooooool02_ooool2o`0006;ooooo00?o0000oiZik_nJ^Nh03_nJ
^Nh00ol0003oVkc`oi^ll00=oi^ll003o`000?nL`?7oW<3a00?o00003OnO`?000ol0003oXL?aoj73
l@0>oj73l@03o`000?nRaO;oX/Gb00Co00003?nTaO000ol0003oY/K`ojK6l00<ojK6l0?o00000_nW
a^l00ol0003oZ<O`ojS7l00?ojS7l003o`000?nYanooZLO_00CoZLO_0ol0000:ojW7k`03o`000?nY
anooZLO_00goZLO_1?l0000]ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01ooo
ool001Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Pooooo`03o`000?nJ^Nko
V[W^00koV[W^00?o0000oi^ll?nK_?002onK_?04o`00017oWl3`00?o0000oj73lOnQ`o403?nQ`o44
o`00017oY<G`00?o0000ojK6l?nVa_002?nVa_03o`0000KoYlK_00?o0000ojS7l?nXao003onXao00
0ol0003oZLO_ojW7k`03o`0000koZLO_00?o0000ojW7konYanl02OnYanl3o`0003;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo063ooooo00?o0000oiZik_nJ^Nh03_nJ^Nh00ol0003oVkc`oi^ll005oi^l
l0Go00001?nO_Nh00ol0003oWl3`oio0l00?oio0l003o`000?nQ`o7oXL?a00KoXL?a1Ol00004oj?2
k`03o`000?nTaO3oY<G`00ooY<G`00?o0000ojK6l?nVa_001?nVa_03o`0000[oYlK_00?o0000ojS7
l?nXao003OnXao04o`0001;oZLO_00?o0000ojW7konYanl01?nYanl4o`0003Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`005Oooool00omEEEGoIVIVo`00000@ooooo`03
o`000?oooooooooo063ooooo00?o0000oiZik_nJ^Nh03_nJ^Nh00ol0003oVkc`oi^ll004o`0000[o
Wkg^00?o0000oio0l?nO`?003onO`?000ol0003oXL?aoj73l@05o`0000[oXl;_00?o0000ojC5l?nT
aO003onTaO000ol0003oY/K`ojK6l003o`0000koYlK_00?o0000ojS7l?nXao002OnXao03o`0000Co
Z<O_00?o0000ojW7konYanl04?nYanl00ol0003oZLO_ojW7k`03o`0003[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`1Pooooo`03o`00
0?nJ^NkoV[W^00coV[W^1?l0000?oinmkP03o`000?nO`?3oWl3`00goWl3`1?l0000@oj?2k`03o`00
0?nTaO3oY<G`00goY<G`1?l0000BojO6k`03o`000?nXao3oZ<O`00CoZ<O`1?l00008ojS7k`03o`00
0?nYanooZLO_00koZLO_1?l0000nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1_ooool002[ooooo0_l0001Qooooo`03o`000?nJ^NkoV[W^00KoV[W^1Ol00004oinjk003o`000?nO
_NkoWkg^00goWkg^00?o0000oio0l?nO`?002OnO`?03o`0000CoXl3^00?o0000oj?2konS`^l03_nS
`^l00ol0003oY<G`ojC5l009ojC5l0?o00001?nVa>l00ol0003oYlK_ojO6k`0@ojO6k`03o`000?nX
ao3oZ<O`00?o00003OnXanl00ol0003oZLO_ojW7k`09ojW7k`Co0000@_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Kooooo000/ooooo`03o`000?oooooooooo05oooooo00?o0000
oiZik_nJ^Nh01Ol0000:oinjk003o`000?nO_NkoWkg^00goWkg^00?o0000oio0l?nO`?001?nO`?04
o`0000SoXl3^00?o0000oj?2konS`^l03_nS`^l00ol0003oY<G`ojC5l004ojC5l0Co00002?nVa>l0
0ol0003oYlK_ojO6k`0>ojO6k`Co00004OnXanl00ol0003oZLO_ojW7k`05ojW7k`?o0000Aoooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo000]ooooo`03o`000?oooooooooo
05oooooo0_l0000@oinjk003o`000?nO_NkoWkg^00goWkg^00?o0000oio0l?nO`?000ol0000=oj?0
kP03o`000?nS`^ooXl;_00koXl;_00?o0000ojC5l?nTaO000ol0000=ojK4k`;o00002onWa^l3o`00
00?oZ<K_00?o0000ojS7konXanl04?nXanl00ol0003oZLO_ojW7k`04o`0004_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`06ooooo`00;_ooool00ol0003oooooooooo`1Pooooo`03
o`000?nO^^coWk[/00koWk[/00?o0000oinmk_nO_Nh02onO_Nh4o`00017oXl3^00?o0000oj?2konS
`^l03?nS`^l4o`0001;oY/C_00?o0000ojO6konWa^l01?nWa^l4o`0000OoZ<K_00?o0000ojS7konX
anl03onXanl3o`00053ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06ooooo`00
;oooool2o`00067ooooo00?o0000oinjk?nO^^`03_nO^^`00ol0003oWkg^oinmkP05oinmkPGo0000
1?nR_^d00ol0003oXl3^oj?0kP0?oj?0kP03o`000?nS`^ooXl;_00KoXl;_1Ol00004ojG2kP03o`00
0?nVa>ooY/C_013oY/C_00?o0000ojO6konWa^l00ol0000<ojS6k`03o`000?nXanooZ<O_00_oZ<O_
0ol0001Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0037ooooo00?o
0000ooooooooool0Goooool00ol0003oWk[/oinjk00>oinjk003o`000?nO_NkoWkg^00Co00002_nR
_^d00ol0003oXl3^oj?0kP0?oj?0kP03o`000?nS`^ooXl;_00Go00002_nU`^h00ol0003oY/C_ojK4
k`0>ojK4k`Co00004?nXa^l00ol0003oZ<O_ojS7k`07ojS7k`?o0000Eoooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Gooooo000booooo`03o`000?oooooooooo05oooooo00?o0000
oinjk?nO^^`03?nO^^`4o`0000ooX[k]0_l0000>oj?0kPCo00004?nU`^h2o`0000_oY/C_0ol00003
ojO4kP03o`000?nXa^ooZ<K_00ooZ<K_00?o0000ojS7konXanl00onXanl3o`0005_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`05ooooo`00<oooool00ol0003oooooooooo`1Ooooo
o`03o`000?nO^^coWk[/00SoWk[/0ol00003oj:kj`03o`000?nR_^goX[k]00ooX[k]00?o0000oj?0
k_nS`>h02?nS`>h3o`0000CoYL3]00?o0000ojG2k_nU`^h03onU`^h00ol0003oY/C_ojK4k`04ojK4
k`Co00001onWa>h00ol0003oZ<K_ojS6k`0?ojS6k`03o`000?nXanoo000000;o0000Goooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo000dooooo`;o0000H?ooool00ol0003o
Wk[/oinjk004oinjk0?o00001onR^n/00ol0003oX[k]oj:nk@0?oj:nk@03o`000?nS`>koXl3^00Co
Xl3^0ol00008ojG0k@03o`000?nU`^koYL;^00ooYL;^00?o0000ojK4konVa>l00ol0000<ojO4kP03
o`000?nXa^ooZ<K_00goZ<K_0ol0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01Oooool003Kooooo00?o0000ooooooooool0G_ooool00ol0003oWk[/oinjk003o`0000_oX[_[
00?o0000oj:nkOnR_^d03onR_^d00ol0003oXl3^oj?0kP03o`0000coYL3]00?o0000ojG2k_nU`^h0
3OnU`^h4o`00013oYlC^00?o0000ojS6konXa^l02OnXa^l3o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`05ooooo`00=oooool00ol0003oooooooooo`1Nooooo`;o00003onR
^n/00ol0003oX[k]oj:nk@0=oj:nk@Co00004?nU`>d00ol0003oYL;^ojG2kP09ojG2kP?o00000onW
`nd00ol0003oYlC^ojO4kP0?ojO4kP03o`000?nXa^ooZ<K_00CoZ<K_1?l0001Zooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01Oooool003Sooooo00?o0000ooooooooool0Goooool0
0ol0003oX[_[oj:kj`0=oj:kj`03o`000?nR_^goX[k]00WoX[k]0ol00003ojFnk003o`000?nU`>go
YL3]00ooYL3]00?o0000ojG2k_nU`^h01?nU`^h4o`0000OoYl?]00?o0000ojO4k_nWa>h03onWa>h0
0ol0003oZ<K_ojS6k`03o`0006kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`00>Oooool2o`00063ooooo00?o0000oj:kjonR^n/03OnR^n/00ol0003oX[k]oj:nk@04oj:n
k@Co00001onU_^`00ol0003oYL3]ojG0k@0?ojG0k@03o`000?nU`^koYL;^00?o00003?nW`nd00ol0
003oYlC^ojO4kP0=ojO4kPCo0000L_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000oj:kjonR^n/03OnR^n/00ol0003o
X[k]oj:nk@03o`0000coYKk/00?o0000ojG0kOnU`>d03OnU`>d4o`00013oYl?]00?o0000ojO4k_nW
a>h02OnWa>h3o`0007Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`00
??ooool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00_oX[_[1?l0000@ojFnk003o`00
0?nU`>goYL3]00WoYL3]0ol00003ojO1k003o`000?nW`ngoYl?]00ooYl?]00?o0000ojO4k_nWa>h0
1?nWa>h4o`0007_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`00?Ooo
ool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00GoX[_[1Ol00004ojFljP03o`000?nU
_^coYKk/00koYKk/00?o0000ojG0kOnU`>d01?nU`>d4o`0000OoYl7/00?o0000ojO3kOnW`nd03onW
`nd00ol0003oYlC^ojO4kP03o`0007oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`04ooooo`00?_ooool00ol0003oooooooooo`1Nooooo`03o`000?nR^n_oX[_[00Co00002_nU_>X0
0ol0003oYKk/ojFnk00>ojFnk003o`000?nU`>goYL3]00?o00003?nW`N`00ol0003oYl?]ojO3k@0=
ojO3k@Co0000Poooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000ooooo
o`;o0000Goooool2o`0000ooYKcZ00?o0000ojFnk?nU_^`03?nU_^`4o`00013oYl7/00?o0000ojO3
kOnW`nd02OnW`nd3o`0008Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?nU_>[oYKcZ00koYKcZ00?o0000ojFnk?nU
_^`02?nU_^`3o`0000CoYko[00?o0000ojO1k?nW`N`03_nW`N`00ol0003oYl?]ojO3k@04ojO3k@Co
0000Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo0012ooooo`03o`00
0?oooooooooo05gooooo00?o0000ojFlj_nU_>X03_nU_>X00ol0003oYKk/ojFnk004ojFnk0?o0000
2?nW_n/00ol0003oYl7/ojO1k00>ojO1k003o`000?nW`ngoYl?]00?o0000T?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00?ooooo0013ooooo`03o`000?oooooooooo05gooooo00?o
0000ojFlj_nU_>X03_nU_>X00ol0003oYKk/ojFnk003o`0000coYko[00?o0000ojO1k?nW`N`03?nW
`N`4o`0009Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00A?ooool2
o`0005kooooo00?o0000ojFlj_nU_>X03?nU_>X4o`00013oYko[00?o0000ojO1k?nW`N`02?nW`N`3
o`0009Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`00A_ooool00ol0
003oooooooooo`1Looooo`03o`000?nU_>[oYKcZ00SoYKcZ0ol00004ojNmj@03o`000?nW_n_oYko[
00koYko[00?o0000ojO1k?nW`N`01?nW`N`3o`0009cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`00Aoooool00ol0003oooooooooo`1Looooo`03o`000?nU_>[oYKcZ00Co
YKcZ0ol00008ojNmj@03o`000?nW_n_oYko[00koYko[00?o0000ojO1k?nW`N`00ol0002Pooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool004Sooooo00?o0000ooooooooool0
G?ooool00ol0003oYKcZojFljP03o`0000coYkgY00?o0000ojNojonW_n/03?nW_n/4o`000:Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`00BOooool2o`0005gooooo0_l0
000@ojNmj@03o`000?nW_n_oYko[00SoYko[0ol0002Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003oYkgYojNmj@0>
ojNmj@03o`000?nW_n_oYko[00CoYko[0ol0002/ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00_ooool004cooooo00?o0000ooooooooool0G?ooool00ol0003oYkgYojNmj@0>ojNm
j@03o`000?nW_n_oYko[00?o0000/?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo001=ooooo`03o`000?oooooooooo05cooooo00?o0000ojNmjOnW_NT03?nW_NT4o`000;Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`00C_ooool2o`0005gooooo
00?o0000ojNmjOnW_NT02?nW_NT3o`000;Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?nW_NWoYkgY00CoYkgY0ol0
002looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0057ooooo00?o0000
ooooooooool0Foooool00ol0003oYkgYojNmj@03o`000<3ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`00D_ooool00ol0003oooooooooo`1Kooooo`;o0000a?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo001Cooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo001Dooooo`;o0000F_ooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00Oooool005Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool005Oooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00Oooool005Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`36oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00Oooool005Wooooo0_l0001Eooooo`03
o`000?oooooooooo0<Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
Foooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`01ooooo`00G?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo0<Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo001Nooooo`;o0000D?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`7ooooo001Pooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0boooool01Ol0003ooooooooooooooooo000000;ooooo001Qooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool0c?ooool01Ol0003ooooooooooooooooo000000;ooooo001Rooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0cOooool01?l0003oooooooooool00002oooo
o`00Hoooool2o`0004[ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000002ooooo`00
IOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0<kooooo00Co0000oooooooooooo
00000Oooool006Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3?ooooo`03o`00
0?oooooo0000007ooooo001Wooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0d?oo
ool2o`00007ooooo001Xooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0coooool3
o`00007ooooo001Yooooo`;o0000A?ooool00ol0003oooooooooo`3;ooooo`Co00001?ooool006_o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`37ooooo`Co00002?ooool006cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o00003?ooool006gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`30ooooo`Co00003oooool006kooooo0_l0000o
ooooo`03o`000?oooooooooo0;cooooo1?l0000Cooooo`00L?ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo0;Sooooo1?l0000Gooooo`00LOooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;Cooooo1?l0000Kooooo`00L_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo0;7ooooo0ol0000Oooooo`00Loooool2o`0003[ooooo00?o0000ooooooooool0[Ooo
ool4o`0002;ooooo001eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0ZOooool4
o`0002Kooooo001fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOooool4o`00
02[ooooo001gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0XOooool4o`0002ko
oooo001hooooo`;o0000=Oooool00ol0003oooooooooo`2Mooooo`Co0000<_ooool007[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`?o0000=_ooool007_ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Fooooo`Co0000>Oooool007cooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`2Booooo`Co0000?Oooool007gooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`2>ooooo`Co0000@Oooool007kooooo0_l0000_ooooo`03o`00
0?oooooooooo08[ooooo1?l00015ooooo`00P?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo08Oooooo1?l00019ooooo`00POooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo08Cooooo0ol0001=ooooo`00P_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
083ooooo1?l0001@ooooo`00Poooool2o`0002Wooooo00?o0000ooooooooool0O?ooool4o`0005Co
oooo0025ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0005Sooooo
0026ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0005cooooo0027
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00063ooooo0028oooo
o`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000Hoooool008[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1Yooooo`Co0000Ioooool008_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1Uooooo`Co0000Joooool008cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Qooooo`Co0000Koooool008gooooo0_l0000Oooooo`03o`000?oooooo
oooo05gooooo1?l0001cooooo`00Soooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05[ooooo0ol0001gooooo`00T?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Ko
oooo1?l0001jooooo`00TOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo
1?l0001nooooo`00T_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0
0022ooooo`00Toooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0008Kooooo002Eoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool3o`0008[ooooo002Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0008gooooo002Gooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`00097ooooo002Hooooo`;o00005?oo
ool00ol0003oooooooooo`0kooooo`Co0000UOooool009[ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0gooooo`Co0000VOooool009_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`Co0000WOooool009cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0`ooooo`?o0000XOooool009gooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo
1?l0002Tooooo`00Woooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo1?l0
002Xooooo`00X?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002/
ooooo`00XOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002`oooo
o`00X_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000;Cooooo002Tooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000;Sooooo002Uooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000;_ooooo002Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;oooooo002Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`000<?ooooo002Xooooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000aoooool00:[ooooo00Co0000oooooooooooo00002Oooool3o`000<_o
oooo002[ooooo`03o`000?oooooo000000Gooooo1?l0003>ooooo`00[?ooool2o`000003ooooool0
003o000000;o0000d_ooool00:gooooo0_l0003Fooooo`00oooooon6ooooo`00oooooon6ooooo`00
oooooon6ooooo`00oooooon6ooooo`00oooooon6ooooo`00\
\>"],
  ImageRangeCache->{{{0, 388.875}, {315, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "This solution appears to match the analytic solution given by Eq. ",
  ButtonBox["(6.1.13)",
    ButtonData:>"(6.1.13)",
    ButtonStyle->"Hyperlink"],
  ". The error ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi] = \[Phi] - \[Phi]\_exact\)]],
  " is, in fact, quite small, as shown in Cell ",
  ButtonBox["6.14",
    ButtonData:>"Cell 6.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]exact[x_, y_]\  = \ Sin[Pi\ x]\ Sinh[Pi \((1 - y)\)]/Sinh[Pi]; 
    Plot3D[\[Phi][x, y] - \[Phi]exact[x, y], {x, 0, 1}, {y, 0, 1}, 
      AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[CapitalDelta]\[Phi]\>"}, 
      PlotPoints \[Rule] 50];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01723 .30827 -42 -2.7788 ]
[.01723 .30827 0 6.2212 ]
[.00908 .35932 -6 -2.82208 ]
[.00908 .35932 0 6.17792 ]
[.00067 .41207 -36 -2.86695 ]
[.00067 .41207 0 6.13305 ]
[-0.00803 .4666 -36 -2.91349 ]
[-0.00803 .4666 0 6.08651 ]
[-0.05457 .39542 -16 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02948 .30358 m
.03561 .30124 L
s
[(-0.0002)] .01723 .30827 1 -0.38249 Mshowa
.02138 .35474 m
.02752 .35245 L
s
[(0)] .00908 .35932 1 -0.37287 Mshowa
.013 .40759 m
.01917 .40536 L
s
[(0.0002)] .00067 .41207 1 -0.3629 Mshowa
.00434 .46224 m
.01053 .46006 L
s
[(0.0004)] -0.00803 .4666 1 -0.35256 Mshowa
.125 Mabswid
.03539 .26629 m
.03906 .26486 L
s
.03344 .27862 m
.03711 .2772 L
s
.03147 .29105 m
.03514 .28964 L
s
.02748 .31622 m
.03116 .31482 L
s
.02546 .32895 m
.02915 .32756 L
s
.02343 .34179 m
.02711 .34041 L
s
.01931 .36779 m
.023 .36642 L
s
.01722 .38095 m
.02092 .37959 L
s
.01512 .39422 m
.01882 .39286 L
s
.01086 .42108 m
.01457 .41975 L
s
.00871 .43469 m
.01241 .43336 L
s
.00653 .4484 m
.01024 .44709 L
s
.00213 .47619 m
.00585 .47489 L
s
gsave
-0.05457 .39542 -77 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Df) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.517 .706 .956 r
.39572 .68414 .40211 .68976 .41282 .68672 .40636 .68394 Metetra
.466 .802 .999 r
.40636 .68394 .41282 .68672 .42358 .68366 .41709 .68282 Metetra
.369 .819 .94 r
.41709 .68282 .42358 .68366 .43437 .6806 .42789 .68103 Metetra
.268 .775 .827 r
.42789 .68103 .43437 .6806 .44521 .67752 .43875 .6788 Metetra
.187 .716 .722 r
.43875 .6788 .44521 .67752 .4561 .67442 .44967 .67628 Metetra
.44967 .67628 .4561 .67442 .46702 .67132 .46064 .67364 Metetra
.46064 .67364 .46702 .67132 .478 .6682 .47166 .67096 Metetra
.001 0 0 r
.47166 .67096 .478 .6682 .48901 .66507 .48273 .66833 Metetra
.072 0 0 r
.48273 .66833 .48901 .66507 .50007 .66193 .49384 .66581 Metetra
.148 0 0 r
.49384 .66581 .50007 .66193 .51118 .65877 .505 .66341 Metetra
.222 0 0 r
.505 .66341 .51118 .65877 .52233 .6556 .51621 .66117 Metetra
.289 0 0 r
.51621 .66117 .52233 .6556 .53352 .65242 .52747 .65907 Metetra
.345 0 .014 r
.52747 .65907 .53352 .65242 .54476 .64923 .53879 .65709 Metetra
.389 0 .093 r
.53879 .65709 .54476 .64923 .55605 .64602 .55016 .65521 Metetra
.421 .014 .158 r
.55016 .65521 .55605 .64602 .56738 .6428 .56159 .65339 Metetra
.445 .058 .21 r
.56159 .65339 .56738 .6428 .57876 .63957 .57308 .65159 Metetra
.463 .093 .251 r
.57308 .65159 .57876 .63957 .59019 .63632 .58462 .64977 Metetra
.475 .12 .283 r
.58462 .64977 .59019 .63632 .60166 .63306 .59622 .64788 Metetra
.483 .14 .308 r
.59622 .64788 .60166 .63306 .61318 .62979 .60787 .64587 Metetra
.488 .155 .327 r
.60787 .64587 .61318 .62979 .62475 .6265 .61958 .64372 Metetra
.491 .165 .341 r
.61958 .64372 .62475 .6265 .63637 .6232 .63134 .64137 Metetra
.492 .172 .352 r
.63134 .64137 .63637 .6232 .64803 .61988 .64315 .6388 Metetra
.492 .176 .359 r
.64315 .6388 .64803 .61988 .65975 .61655 .655 .63599 Metetra
.49 .177 .363 r
.655 .63599 .65975 .61655 .67151 .61321 .6669 .63291 Metetra
.487 .176 .364 r
.6669 .63291 .67151 .61321 .68332 .60985 .67884 .62955 Metetra
.482 .172 .363 r
.67884 .62955 .68332 .60985 .69518 .60648 .69081 .62593 Metetra
.476 .165 .359 r
.69081 .62593 .69518 .60648 .7071 .6031 .70283 .62203 Metetra
.469 .156 .352 r
.70283 .62203 .7071 .6031 .71906 .5997 .71487 .61788 Metetra
.46 .143 .341 r
.71487 .61788 .71906 .5997 .73107 .59629 .72695 .61351 Metetra
.449 .127 .327 r
.72695 .61351 .73107 .59629 .74313 .59286 .73906 .60894 Metetra
.436 .107 .308 r
.73906 .60894 .74313 .59286 .75525 .58942 .75121 .6042 Metetra
.42 .082 .284 r
.75121 .6042 .75525 .58942 .76741 .58596 .7634 .59935 Metetra
.4 .05 .253 r
.7634 .59935 .76741 .58596 .77963 .58249 .77562 .59442 Metetra
.375 .011 .213 r
.77562 .59442 .77963 .58249 .7919 .579 .78788 .58945 Metetra
.345 0 .163 r
.78788 .58945 .7919 .579 .80422 .5755 .80019 .5845 Metetra
.307 0 .101 r
.80019 .5845 .80422 .5755 .81659 .57198 .81254 .57961 Metetra
.261 0 .025 r
.81254 .57961 .81659 .57198 .82902 .56845 .82495 .5748 Metetra
.207 0 0 r
.82495 .5748 .82902 .56845 .8415 .56491 .83742 .57012 Metetra
.145 0 0 r
.83742 .57012 .8415 .56491 .85403 .56134 .84994 .56558 Metetra
.079 0 0 r
.84994 .56558 .85403 .56134 .86662 .55777 .86254 .56118 Metetra
.014 0 0 r
.86254 .56118 .86662 .55777 .87927 .55417 .87519 .55691 Metetra
.87519 .55691 .87927 .55417 .89196 .55057 .88791 .55275 Metetra
.88791 .55275 .89196 .55057 .90472 .54694 .90069 .54863 Metetra
.90069 .54863 .90472 .54694 .91753 .5433 .91351 .54448 Metetra
.245 .748 .694 r
.91351 .54448 .91753 .5433 .93039 .53965 .92638 .54018 Metetra
.351 .825 .788 r
.92638 .54018 .93039 .53965 .94331 .53598 .93926 .53559 Metetra
.493 .904 .891 r
.93926 .53559 .94331 .53598 .95629 .53229 .95213 .53051 Metetra
.644 .941 .961 r
.95213 .53051 .95629 .53229 .96933 .52858 .96496 .52472 Metetra
.741 .893 .948 r
.96496 .52472 .96933 .52858 .98242 .52486 .9777 .51795 Metetra
.359 .636 .96 r
.38927 .67847 .39572 .68414 .40636 .68394 .39986 .68032 Metetra
.407 .744 .993 r
.39986 .68032 .40636 .68394 .41709 .68282 .41058 .68033 Metetra
.459 .812 .997 r
.41058 .68033 .41709 .68282 .42789 .68103 .42141 .67903 Metetra
.51 .851 .995 r
.42141 .67903 .42789 .68103 .43875 .6788 .43231 .67684 Metetra
.553 .868 .995 r
.43231 .67684 .43875 .6788 .44967 .67628 .44327 .67411 Metetra
.581 .87 .995 r
.44327 .67411 .44967 .67628 .46064 .67364 .45428 .67113 Metetra
.596 .862 .993 r
.45428 .67113 .46064 .67364 .47166 .67096 .46534 .66813 Metetra
.597 .851 .992 r
.46534 .66813 .47166 .67096 .48273 .66833 .47645 .66525 Metetra
.588 .839 .992 r
.47645 .66525 .48273 .66833 .49384 .66581 .4876 .66262 Metetra
.57 .83 .994 r
.4876 .66262 .49384 .66581 .505 .66341 .4988 .6603 Metetra
.542 .824 .998 r
.4988 .6603 .505 .66341 .51621 .66117 .51004 .65832 Metetra
.501 .82 1 r
.51004 .65832 .51621 .66117 .52747 .65907 .52134 .65667 Metetra
.443 .813 .994 r
.52134 .65667 .52747 .65907 .53879 .65709 .5327 .65531 Metetra
.362 .794 .967 r
.5327 .65531 .53879 .65709 .55016 .65521 .54412 .65421 Metetra
.252 .751 .901 r
.54412 .65421 .55016 .65521 .56159 .65339 .5556 .65328 Metetra
.122 .672 .786 r
.5556 .65328 .56159 .65339 .57308 .65159 .56715 .65245 Metetra
.009 0 0 r
.56715 .65245 .57308 .65159 .58462 .64977 .57876 .65164 Metetra
.118 0 0 r
.57876 .65164 .58462 .64977 .59622 .64788 .59044 .65075 Metetra
.198 0 0 r
.59044 .65075 .59622 .64788 .60787 .64587 .60217 .6497 Metetra
.249 0 0 r
.60217 .6497 .60787 .64587 .61958 .64372 .61397 .64841 Metetra
.279 0 0 r
.61397 .64841 .61958 .64372 .63134 .64137 .62582 .6468 Metetra
.293 0 0 r
.62582 .6468 .63134 .64137 .64315 .6388 .63772 .64481 Metetra
.295 0 0 r
.63772 .64481 .64315 .6388 .655 .63599 .64966 .64239 Metetra
.286 0 0 r
.64966 .64239 .655 .63599 .6669 .63291 .66165 .63951 Metetra
.268 0 0 r
.66165 .63951 .6669 .63291 .67884 .62955 .67366 .63614 Metetra
.24 0 0 r
.67366 .63614 .67884 .62955 .69081 .62593 .68571 .63229 Metetra
.2 0 0 r
.68571 .63229 .69081 .62593 .70283 .62203 .69778 .62798 Metetra
.147 0 0 r
.69778 .62798 .70283 .62203 .71487 .61788 .70988 .62322 Metetra
.075 0 0 r
.70988 .62322 .71487 .61788 .72695 .61351 .722 .61808 Metetra
.722 .61808 .72695 .61351 .73906 .60894 .73413 .6126 Metetra
.73413 .6126 .73906 .60894 .75121 .6042 .74629 .60687 Metetra
.74629 .60687 .75121 .6042 .7634 .59935 .75848 .60096 Metetra
.412 .851 .741 r
.75848 .60096 .7634 .59935 .77562 .59442 .7707 .59497 Metetra
.529 .922 .855 r
.7707 .59497 .77562 .59442 .78788 .58945 .78295 .58897 Metetra
.61 .948 .926 r
.78295 .58897 .78788 .58945 .80019 .5845 .79524 .58307 Metetra
.655 .943 .961 r
.79524 .58307 .80019 .5845 .81254 .57961 .80759 .57733 Metetra
.675 .922 .973 r
.80759 .57733 .81254 .57961 .82495 .5748 .82 .57184 Metetra
.679 .898 .975 r
.82 .57184 .82495 .5748 .83742 .57012 .83248 .56665 Metetra
.674 .878 .975 r
.83248 .56665 .83742 .57012 .84994 .56558 .84503 .56179 Metetra
.664 .863 .975 r
.84503 .56179 .84994 .56558 .86254 .56118 .85766 .55727 Metetra
.651 .855 .978 r
.85766 .55727 .86254 .56118 .87519 .55691 .87038 .55307 Metetra
.637 .853 .982 r
.87038 .55307 .87519 .55691 .88791 .55275 .88318 .54911 Metetra
.623 .858 .987 r
.88318 .54911 .88791 .55275 .90069 .54863 .89604 .54529 Metetra
.614 .868 .99 r
.89604 .54529 .90069 .54863 .91351 .54448 .90896 .54143 Metetra
.616 .882 .99 r
.90896 .54143 .91351 .54448 .92638 .54018 .92191 .53731 Metetra
.637 .898 .985 r
.92191 .53731 .92638 .54018 .93926 .53559 .93484 .53263 Metetra
.683 .911 .974 r
.93484 .53263 .93926 .53559 .95213 .53051 .94771 .527 Metetra
.746 .908 .948 r
.94771 .527 .95213 .53051 .96496 .52472 .96044 .51997 Metetra
.802 .873 .899 r
.96044 .51997 .96496 .52472 .9777 .51795 .97294 .51098 Metetra
.21 .556 .934 r
.38278 .67275 .38927 .67847 .39986 .68032 .39333 .67607 Metetra
.39 .711 .986 r
.39333 .67607 .39986 .68032 .41058 .68033 .40406 .67664 Metetra
.531 .793 .993 r
.40406 .67664 .41058 .68033 .42141 .67903 .41491 .67522 Metetra
.619 .815 .976 r
.41491 .67522 .42141 .67903 .43231 .67684 .42586 .67248 Metetra
.663 .804 .951 r
.42586 .67248 .43231 .67684 .44327 .67411 .43688 .66896 Metetra
.68 .779 .926 r
.43688 .66896 .44327 .67411 .45428 .67113 .44794 .66508 Metetra
.68 .75 .904 r
.44794 .66508 .45428 .67113 .46534 .66813 .45905 .66118 Metetra
.672 .722 .887 r
.45905 .66118 .46534 .66813 .47645 .66525 .47019 .65752 Metetra
.659 .697 .875 r
.47019 .65752 .47645 .66525 .4876 .66262 .48137 .65425 Metetra
.643 .677 .867 r
.48137 .65425 .4876 .66262 .4988 .6603 .49259 .65149 Metetra
.627 .661 .863 r
.49259 .65149 .4988 .6603 .51004 .65832 .50386 .64928 Metetra
.611 .65 .864 r
.50386 .64928 .51004 .65832 .52134 .65667 .51517 .64761 Metetra
.595 .643 .868 r
.51517 .64761 .52134 .65667 .5327 .65531 .52655 .64644 Metetra
.579 .641 .877 r
.52655 .64644 .5327 .65531 .54412 .65421 .53799 .64569 Metetra
.564 .645 .888 r
.53799 .64569 .54412 .65421 .5556 .65328 .54949 .64527 Metetra
.551 .653 .903 r
.54949 .64527 .5556 .65328 .56715 .65245 .56107 .64506 Metetra
.539 .667 .92 r
.56107 .64506 .56715 .65245 .57876 .65164 .57271 .64494 Metetra
.529 .685 .938 r
.57271 .64494 .57876 .65164 .59044 .65075 .58443 .64476 Metetra
.522 .708 .956 r
.58443 .64476 .59044 .65075 .60217 .6497 .59621 .64442 Metetra
.519 .734 .972 r
.59621 .64442 .60217 .6497 .61397 .64841 .60805 .64378 Metetra
.522 .762 .984 r
.60805 .64378 .61397 .64841 .62582 .6468 .61995 .64273 Metetra
.533 .79 .992 r
.61995 .64273 .62582 .6468 .63772 .64481 .63191 .64119 Metetra
.552 .817 .995 r
.63191 .64119 .63772 .64481 .64966 .64239 .6439 .63907 Metetra
.578 .84 .994 r
.6439 .63907 .64966 .64239 .66165 .63951 .65594 .63633 Metetra
.61 .857 .99 r
.65594 .63633 .66165 .63951 .67366 .63614 .668 .63294 Metetra
.644 .867 .983 r
.668 .63294 .67366 .63614 .68571 .63229 .68009 .6289 Metetra
.677 .869 .972 r
.68009 .6289 .68571 .63229 .69778 .62798 .69219 .62423 Metetra
.704 .862 .957 r
.69219 .62423 .69778 .62798 .70988 .62322 .70431 .61898 Metetra
.724 .848 .94 r
.70431 .61898 .70988 .62322 .722 .61808 .71644 .61322 Metetra
.737 .829 .921 r
.71644 .61322 .722 .61808 .73413 .6126 .72858 .60703 Metetra
.743 .806 .903 r
.72858 .60703 .73413 .6126 .74629 .60687 .74074 .60054 Metetra
.743 .783 .885 r
.74074 .60054 .74629 .60687 .75848 .60096 .75292 .59385 Metetra
.739 .76 .87 r
.75292 .59385 .75848 .60096 .7707 .59497 .76512 .58709 Metetra
.732 .739 .857 r
.76512 .58709 .7707 .59497 .78295 .58897 .77736 .58041 Metetra
.723 .72 .847 r
.77736 .58041 .78295 .58897 .79524 .58307 .78965 .57393 Metetra
.713 .704 .841 r
.78965 .57393 .79524 .58307 .80759 .57733 .802 .56777 Metetra
.702 .692 .837 r
.802 .56777 .80759 .57733 .82 .57184 .81442 .56203 Metetra
.69 .683 .838 r
.81442 .56203 .82 .57184 .83248 .56665 .82692 .55679 Metetra
.678 .677 .842 r
.82692 .55679 .83248 .56665 .84503 .56179 .83952 .55211 Metetra
.666 .676 .85 r
.83952 .55211 .84503 .56179 .85766 .55727 .85223 .54799 Metetra
.654 .681 .863 r
.85223 .54799 .85766 .55727 .87038 .55307 .86504 .54438 Metetra
.644 .691 .879 r
.86504 .54438 .87038 .55307 .88318 .54911 .87795 .54119 Metetra
.636 .708 .899 r
.87795 .54119 .88318 .54911 .89604 .54529 .89095 .53824 Metetra
.633 .734 .921 r
.89095 .53824 .89604 .54529 .90896 .54143 .90402 .53527 Metetra
.639 .768 .941 r
.90402 .53527 .90896 .54143 .92191 .53731 .9171 .53193 Metetra
.662 .807 .953 r
.9171 .53193 .92191 .53731 .93484 .53263 .93015 .52777 Metetra
.706 .844 .948 r
.93015 .52777 .93484 .53263 .94771 .527 .94309 .52221 Metetra
.769 .865 .92 r
.94309 .52221 .94771 .527 .96044 .51997 .95579 .51455 Metetra
.828 .854 .866 r
.95579 .51455 .96044 .51997 .97294 .51098 .96814 .50396 Metetra
.084 .48 .894 r
.37624 .667 .38278 .67275 .39333 .67607 .38676 .67139 Metetra
.4 .699 .982 r
.38676 .67139 .39333 .67607 .40406 .67664 .39751 .6721 Metetra
.587 .778 .97 r
.39751 .6721 .40406 .67664 .41491 .67522 .40841 .67017 Metetra
.673 .781 .931 r
.40841 .67017 .41491 .67522 .42586 .67248 .41941 .66648 Metetra
.705 .756 .892 r
.41941 .66648 .42586 .67248 .43688 .66896 .43049 .66175 Metetra
.71 .725 .862 r
.43049 .66175 .43688 .66896 .44794 .66508 .44161 .65658 Metetra
.702 .693 .838 r
.44161 .65658 .44794 .66508 .45905 .66118 .45276 .65142 Metetra
.688 .663 .821 r
.45276 .65142 .45905 .66118 .47019 .65752 .46394 .64659 Metetra
.671 .637 .808 r
.46394 .64659 .47019 .65752 .48137 .65425 .47515 .64234 Metetra
.653 .615 .799 r
.47515 .64234 .48137 .65425 .49259 .65149 .48639 .63879 Metetra
.635 .596 .793 r
.48639 .63879 .49259 .65149 .50386 .64928 .49767 .63602 Metetra
.618 .581 .79 r
.49767 .63602 .50386 .64928 .51517 .64761 .50899 .63401 Metetra
.603 .569 .789 r
.50899 .63401 .51517 .64761 .52655 .64644 .52037 .63272 Metetra
.589 .561 .791 r
.52037 .63272 .52655 .64644 .53799 .64569 .53181 .63204 Metetra
.577 .557 .795 r
.53181 .63204 .53799 .64569 .54949 .64527 .54331 .63186 Metetra
.568 .556 .8 r
.54331 .63186 .54949 .64527 .56107 .64506 .55489 .63202 Metetra
.563 .558 .807 r
.55489 .63202 .56107 .64506 .57271 .64494 .56655 .63235 Metetra
.561 .565 .814 r
.56655 .63235 .57271 .64494 .58443 .64476 .57827 .63269 Metetra
.563 .574 .823 r
.57827 .63269 .58443 .64476 .59621 .64442 .59007 .63286 Metetra
.57 .587 .831 r
.59007 .63286 .59621 .64442 .60805 .64378 .60194 .63272 Metetra
.581 .602 .838 r
.60194 .63272 .60805 .64378 .61995 .64273 .61387 .63211 Metetra
.596 .618 .844 r
.61387 .63211 .61995 .64273 .63191 .64119 .62585 .63091 Metetra
.614 .634 .847 r
.62585 .63091 .63191 .64119 .6439 .63907 .63787 .62904 Metetra
.633 .647 .846 r
.63787 .62904 .6439 .63907 .65594 .63633 .64993 .6264 Metetra
.652 .658 .843 r
.64993 .6264 .65594 .63633 .668 .63294 .66202 .62298 Metetra
.67 .666 .837 r
.66202 .62298 .668 .63294 .68009 .6289 .67412 .61877 Metetra
.685 .669 .829 r
.67412 .61877 .68009 .6289 .69219 .62423 .68624 .6138 Metetra
.696 .669 .819 r
.68624 .6138 .69219 .62423 .70431 .61898 .69836 .60814 Metetra
.704 .666 .809 r
.69836 .60814 .70431 .61898 .71644 .61322 .71049 .60187 Metetra
.709 .66 .799 r
.71049 .60187 .71644 .61322 .72858 .60703 .72262 .59511 Metetra
.71 .653 .79 r
.72262 .59511 .72858 .60703 .74074 .60054 .73477 .58802 Metetra
.709 .644 .783 r
.73477 .58802 .74074 .60054 .75292 .59385 .74693 .58074 Metetra
.706 .636 .776 r
.74693 .58074 .75292 .59385 .76512 .58709 .75911 .57345 Metetra
.7 .627 .772 r
.75911 .57345 .76512 .58709 .77736 .58041 .77134 .56633 Metetra
.693 .619 .769 r
.77134 .56633 .77736 .58041 .78965 .57393 .78362 .55953 Metetra
.684 .611 .768 r
.78362 .55953 .78965 .57393 .802 .56777 .79597 .55323 Metetra
.674 .605 .77 r
.79597 .55323 .802 .56777 .81442 .56203 .80841 .54754 Metetra
.663 .6 .774 r
.80841 .54754 .81442 .56203 .82692 .55679 .82095 .54258 Metetra
.652 .598 .781 r
.82095 .54258 .82692 .55679 .83952 .55211 .83362 .5384 Metetra
.639 .598 .792 r
.83362 .5384 .83952 .55211 .85223 .54799 .84641 .53502 Metetra
.626 .602 .806 r
.84641 .53502 .85223 .54799 .86504 .54438 .85933 .53238 Metetra
.615 .611 .824 r
.85933 .53238 .86504 .54438 .87795 .54119 .87239 .53032 Metetra
.605 .627 .846 r
.87239 .53032 .87795 .54119 .89095 .53824 .88555 .52863 Metetra
.602 .652 .872 r
.88555 .52863 .89095 .53824 .90402 .53527 .89879 .52695 Metetra
.61 .689 .899 r
.89879 .52695 .90402 .53527 .9171 .53193 .91206 .52481 Metetra
.639 .738 .921 r
.91206 .52481 .9171 .53193 .93015 .52777 .92527 .52159 Metetra
.694 .792 .926 r
.92527 .52159 .93015 .52777 .94309 .52221 .93831 .51651 Metetra
.77 .834 .902 r
.93831 .51651 .94309 .52221 .95579 .51455 .95105 .50865 Metetra
.842 .842 .844 r
.95105 .50865 .95579 .51455 .96814 .50396 .9633 .49687 Metetra
0 .412 .85 r
.36965 .6612 .37624 .667 .38676 .67139 .38015 .66641 Metetra
.421 .699 .979 r
.38015 .66641 .38676 .67139 .39751 .6721 .39092 .66702 Metetra
.632 .771 .947 r
.39092 .66702 .39751 .6721 .40841 .67017 .40188 .66432 Metetra
.709 .763 .894 r
.40188 .66432 .40841 .67017 .41941 .66648 .41295 .65944 Metetra
.732 .734 .853 r
.41295 .65944 .41941 .66648 .43049 .66175 .42409 .65328 Metetra
.73 .702 .823 r
.42409 .65328 .43049 .66175 .44161 .65658 .43528 .64658 Metetra
.718 .67 .802 r
.43528 .64658 .44161 .65658 .45276 .65142 .44648 .63992 Metetra
.701 .642 .787 r
.44648 .63992 .45276 .65142 .46394 .64659 .4577 .63372 Metetra
.682 .616 .775 r
.4577 .63372 .46394 .64659 .47515 .64234 .46894 .62827 Metetra
.662 .593 .767 r
.46894 .62827 .47515 .64234 .48639 .63879 .48019 .62373 Metetra
.642 .573 .762 r
.48019 .62373 .48639 .63879 .49767 .63602 .49148 .62019 Metetra
.623 .556 .758 r
.49148 .62019 .49767 .63602 .50899 .63401 .5028 .61766 Metetra
.606 .542 .757 r
.5028 .61766 .50899 .63401 .52037 .63272 .51417 .61606 Metetra
.591 .531 .757 r
.51417 .61606 .52037 .63272 .53181 .63204 .5256 .61528 Metetra
.578 .524 .758 r
.5256 .61528 .53181 .63204 .54331 .63186 .5371 .61517 Metetra
.569 .519 .76 r
.5371 .61517 .54331 .63186 .55489 .63202 .54867 .61553 Metetra
.563 .518 .764 r
.54867 .61553 .55489 .63202 .56655 .63235 .56032 .61618 Metetra
.561 .521 .768 r
.56032 .61618 .56655 .63235 .57827 .63269 .57205 .6169 Metetra
.563 .526 .773 r
.57205 .6169 .57827 .63269 .59007 .63286 .58385 .61748 Metetra
.569 .535 .777 r
.58385 .61748 .59007 .63286 .60194 .63272 .59572 .61773 Metetra
.579 .545 .781 r
.59572 .61773 .60194 .63272 .61387 .63211 .60765 .61748 Metetra
.592 .557 .784 r
.60765 .61748 .61387 .63211 .62585 .63091 .61964 .61657 Metetra
.608 .569 .785 r
.61964 .61657 .62585 .63091 .63787 .62904 .63168 .61488 Metetra
.625 .581 .784 r
.63168 .61488 .63787 .62904 .64993 .6264 .64375 .61233 Metetra
.641 .59 .782 r
.64375 .61233 .64993 .6264 .66202 .62298 .65584 .60888 Metetra
.657 .598 .778 r
.65584 .60888 .66202 .62298 .67412 .61877 .66795 .60451 Metetra
.67 .603 .772 r
.66795 .60451 .67412 .61877 .68624 .6138 .68006 .59928 Metetra
.68 .606 .766 r
.68006 .59928 .68624 .6138 .69836 .60814 .69218 .59325 Metetra
.688 .606 .76 r
.69218 .59325 .69836 .60814 .71049 .60187 .7043 .58655 Metetra
.692 .605 .754 r
.7043 .58655 .71049 .60187 .72262 .59511 .71642 .57932 Metetra
.694 .601 .748 r
.71642 .57932 .72262 .59511 .73477 .58802 .72854 .57173 Metetra
.693 .597 .744 r
.72854 .57173 .73477 .58802 .74693 .58074 .74068 .56399 Metetra
.69 .592 .74 r
.74068 .56399 .74693 .58074 .75911 .57345 .75285 .55631 Metetra
.685 .586 .739 r
.75285 .55631 .75911 .57345 .77134 .56633 .76506 .54889 Metetra
.678 .58 .738 r
.76506 .54889 .77134 .56633 .78362 .55953 .77733 .54195 Metetra
.669 .574 .74 r
.77733 .54195 .78362 .55953 .79597 .55323 .78969 .53567 Metetra
.659 .569 .743 r
.78969 .53567 .79597 .55323 .80841 .54754 .80215 .53022 Metetra
.646 .564 .748 r
.80215 .53022 .80841 .54754 .82095 .54258 .81474 .52572 Metetra
.633 .561 .756 r
.81474 .52572 .82095 .54258 .83362 .5384 .82747 .52226 Metetra
.617 .56 .767 r
.82747 .52226 .83362 .5384 .84641 .53502 .84036 .51982 Metetra
.601 .561 .781 r
.84036 .51982 .84641 .53502 .85933 .53238 .85341 .51835 Metetra
.586 .567 .8 r
.85341 .51835 .85933 .53238 .87239 .53032 .86661 .51765 Metetra
.572 .579 .822 r
.86661 .51765 .87239 .53032 .88555 .52863 .87995 .51745 Metetra
.565 .602 .849 r
.87995 .51745 .88555 .52863 .89879 .52695 .89339 .51729 Metetra
.572 .638 .878 r
.89339 .51729 .89879 .52695 .91206 .52481 .90685 .51659 Metetra
.604 .692 .905 r
.90685 .51659 .91206 .52481 .92527 .52159 .92025 .51456 Metetra
.671 .758 .916 r
.92025 .51456 .92527 .52159 .93831 .51651 .93343 .51024 Metetra
.764 .815 .893 r
.93343 .51024 .93831 .51651 .95105 .50865 .94623 .50243 Metetra
.852 .835 .829 r
.94623 .50243 .95105 .50865 .9633 .49687 .95842 .48973 Metetra
0 .349 .804 r
.36302 .65536 .36965 .6612 .38015 .66641 .37349 .66127 Metetra
.445 .704 .977 r
.37349 .66127 .38015 .66641 .39092 .66702 .38429 .66165 Metetra
.668 .771 .927 r
.38429 .66165 .39092 .66702 .40188 .66432 .39531 .65807 Metetra
.738 .757 .868 r
.39531 .65807 .40188 .66432 .41295 .65944 .40646 .65187 Metetra
.755 .727 .827 r
.40646 .65187 .41295 .65944 .42409 .65328 .41768 .64417 Metetra
.75 .696 .8 r
.41768 .64417 .42409 .65328 .43528 .64658 .42893 .63585 Metetra
.736 .666 .781 r
.42893 .63585 .43528 .64658 .44648 .63992 .44019 .6276 Metetra
.717 .638 .768 r
.44019 .6276 .44648 .63992 .4577 .63372 .45146 .61992 Metetra
.696 .612 .759 r
.45146 .61992 .4577 .63372 .46894 .62827 .46273 .61317 Metetra
.673 .589 .753 r
.46273 .61317 .46894 .62827 .48019 .62373 .474 .60756 Metetra
.651 .568 .748 r
.474 .60756 .48019 .62373 .49148 .62019 .48529 .60317 Metetra
.63 .55 .745 r
.48529 .60317 .49148 .62019 .5028 .61766 .49661 .60003 Metetra
.611 .534 .744 r
.49661 .60003 .5028 .61766 .51417 .61606 .50798 .59803 Metetra
.593 .521 .743 r
.50798 .59803 .51417 .61606 .5256 .61528 .51939 .59707 Metetra
.578 .512 .744 r
.51939 .59707 .5256 .61528 .5371 .61517 .53088 .59694 Metetra
.567 .505 .746 r
.53088 .59694 .5371 .61517 .54867 .61553 .54243 .59744 Metetra
.559 .502 .748 r
.54243 .59744 .54867 .61553 .56032 .61618 .55407 .59832 Metetra
.556 .503 .751 r
.55407 .59832 .56032 .61618 .57205 .6169 .56578 .59935 Metetra
.558 .507 .755 r
.56578 .59935 .57205 .6169 .58385 .61748 .57758 .60028 Metetra
.564 .514 .758 r
.57758 .60028 .58385 .61748 .59572 .61773 .58944 .60088 Metetra
.574 .523 .761 r
.58944 .60088 .59572 .61773 .60765 .61748 .60138 .60093 Metetra
.587 .534 .763 r
.60138 .60093 .60765 .61748 .61964 .61657 .61337 .60027 Metetra
.603 .546 .764 r
.61337 .60027 .61964 .61657 .63168 .61488 .62541 .59875 Metetra
.62 .557 .763 r
.62541 .59875 .63168 .61488 .64375 .61233 .63748 .59627 Metetra
.636 .567 .76 r
.63748 .59627 .64375 .61233 .65584 .60888 .64957 .59278 Metetra
.651 .575 .757 r
.64957 .59278 .65584 .60888 .66795 .60451 .66168 .58827 Metetra
.665 .581 .752 r
.66168 .58827 .66795 .60451 .68006 .59928 .67379 .58279 Metetra
.675 .585 .747 r
.67379 .58279 .68006 .59928 .69218 .59325 .68589 .57643 Metetra
.683 .587 .741 r
.68589 .57643 .69218 .59325 .7043 .58655 .698 .56933 Metetra
.688 .586 .737 r
.698 .56933 .7043 .58655 .71642 .57932 .7101 .56168 Metetra
.69 .584 .732 r
.7101 .56168 .71642 .57932 .72854 .57173 .7222 .55366 Metetra
.689 .581 .729 r
.7222 .55366 .72854 .57173 .74068 .56399 .73432 .54553 Metetra
.686 .577 .727 r
.73432 .54553 .74068 .56399 .75285 .55631 .74647 .53752 Metetra
.68 .571 .726 r
.74647 .53752 .75285 .55631 .76506 .54889 .75866 .52988 Metetra
.672 .566 .727 r
.75866 .52988 .76506 .54889 .77733 .54195 .77093 .52287 Metetra
.662 .56 .729 r
.77093 .52287 .77733 .54195 .78969 .53567 .78329 .5167 Metetra
.649 .554 .733 r
.78329 .5167 .78969 .53567 .80215 .53022 .79578 .51158 Metetra
.635 .548 .739 r
.79578 .51158 .80215 .53022 .81474 .52572 .80841 .50763 Metetra
.618 .543 .748 r
.80841 .50763 .81474 .52572 .82747 .52226 .82121 .50496 Metetra
.599 .539 .759 r
.82121 .50496 .82747 .52226 .84036 .51982 .83419 .50356 Metetra
.578 .537 .773 r
.83419 .50356 .84036 .51982 .85341 .51835 .84737 .50335 Metetra
.556 .539 .791 r
.84737 .50335 .85341 .51835 .86661 .51765 .86073 .50411 Metetra
.536 .548 .814 r
.86073 .50411 .86661 .51765 .87995 .51745 .87425 .50549 Metetra
.523 .566 .841 r
.87425 .50549 .87995 .51745 .89339 .51729 .88789 .50696 Metetra
.528 .602 .871 r
.88789 .50696 .89339 .51729 .90685 .51659 .90155 .50781 Metetra
.564 .659 .9 r
.90155 .50781 .90685 .51659 .92025 .51456 .91514 .5071 Metetra
.644 .735 .915 r
.91514 .5071 .92025 .51456 .93343 .51024 .92847 .50365 Metetra
.757 .805 .891 r
.92847 .50365 .93343 .51024 .94623 .50243 .94135 .49602 Metetra
.86 .832 .818 r
.94135 .49602 .94623 .50243 .95842 .48973 .95351 .48253 Metetra
0 .285 .752 r
.35633 .64948 .36302 .65536 .37349 .66127 .36678 .65606 Metetra
.464 .711 .976 r
.36678 .65606 .37349 .66127 .38429 .66165 .37762 .6562 Metetra
.698 .775 .911 r
.37762 .6562 .38429 .66165 .39531 .65807 .3887 .65172 Metetra
.762 .758 .849 r
.3887 .65172 .39531 .65807 .40646 .65187 .39992 .6442 Metetra
.776 .729 .81 r
.39992 .6442 .40646 .65187 .41768 .64417 .41122 .63494 Metetra
.77 .699 .785 r
.41122 .63494 .41768 .64417 .42893 .63585 .42255 .62499 Metetra
.754 .671 .769 r
.42255 .62499 .42893 .63585 .44019 .6276 .43388 .61515 Metetra
.734 .644 .759 r
.43388 .61515 .44019 .6276 .45146 .61992 .4452 .606 Metetra
.711 .619 .752 r
.4452 .606 .45146 .61992 .46273 .61317 .4565 .59796 Metetra
.687 .595 .747 r
.4565 .59796 .46273 .61317 .474 .60756 .4678 .59126 Metetra
.663 .573 .744 r
.4678 .59126 .474 .60756 .48529 .60317 .4791 .58603 Metetra
.639 .554 .742 r
.4791 .58603 .48529 .60317 .49661 .60003 .49042 .58226 Metetra
.616 .536 .742 r
.49042 .58226 .49661 .60003 .50798 .59803 .50177 .57987 Metetra
.596 .522 .742 r
.50177 .57987 .50798 .59803 .51939 .59707 .51318 .5787 Metetra
.578 .51 .743 r
.51318 .5787 .51939 .59707 .53088 .59694 .52465 .57855 Metetra
.564 .502 .745 r
.52465 .57855 .53088 .59694 .54243 .59744 .53619 .57916 Metetra
.554 .498 .747 r
.53619 .57916 .54243 .59744 .55407 .59832 .54781 .58027 Metetra
.55 .498 .75 r
.54781 .58027 .55407 .59832 .56578 .59935 .55951 .58159 Metetra
.55 .501 .754 r
.55951 .58159 .56578 .59935 .57758 .60028 .57129 .58284 Metetra
.556 .508 .757 r
.57129 .58284 .57758 .60028 .58944 .60088 .58316 .58377 Metetra
.567 .518 .76 r
.58316 .58377 .58944 .60088 .60138 .60093 .59509 .58413 Metetra
.582 .529 .761 r
.59509 .58413 .60138 .60093 .61337 .60027 .60708 .58371 Metetra
.599 .542 .762 r
.60708 .58371 .61337 .60027 .62541 .59875 .61911 .58235 Metetra
.617 .554 .76 r
.61911 .58235 .62541 .59875 .63748 .59627 .63119 .57993 Metetra
.636 .565 .758 r
.63119 .57993 .63748 .59627 .64957 .59278 .64328 .5764 Metetra
.652 .574 .754 r
.64328 .5764 .64957 .59278 .66168 .58827 .65538 .57174 Metetra
.667 .58 .749 r
.65538 .57174 .66168 .58827 .67379 .58279 .66749 .56602 Metetra
.678 .585 .744 r
.66749 .56602 .67379 .58279 .68589 .57643 .67958 .55935 Metetra
.686 .587 .738 r
.67958 .55935 .68589 .57643 .698 .56933 .69167 .55187 Metetra
.691 .587 .733 r
.69167 .55187 .698 .56933 .7101 .56168 .70376 .5438 Metetra
.693 .585 .729 r
.70376 .5438 .7101 .56168 .7222 .55366 .71584 .53537 Metetra
.692 .581 .726 r
.71584 .53537 .7222 .55366 .73432 .54553 .72794 .52686 Metetra
.688 .577 .725 r
.72794 .52686 .73432 .54553 .74647 .53752 .74007 .51854 Metetra
.681 .571 .724 r
.74007 .51854 .74647 .53752 .75866 .52988 .75225 .51071 Metetra
.672 .564 .725 r
.75225 .51071 .75866 .52988 .77093 .52287 .76451 .50364 Metetra
.66 .557 .728 r
.76451 .50364 .77093 .52287 .78329 .5167 .77688 .4976 Metetra
.644 .55 .733 r
.77688 .4976 .78329 .5167 .79578 .51158 .78939 .4928 Metetra
.626 .542 .74 r
.78939 .4928 .79578 .51158 .80841 .50763 .80206 .48941 Metetra
.605 .534 .749 r
.80206 .48941 .80841 .50763 .82121 .50496 .81493 .48753 Metetra
.58 .527 .76 r
.81493 .48753 .82121 .50496 .83419 .50356 .828 .48717 Metetra
.553 .522 .775 r
.828 .48717 .83419 .50356 .84737 .50335 .8413 .48822 Metetra
.523 .519 .793 r
.8413 .48822 .84737 .50335 .86073 .50411 .85481 .49043 Metetra
.495 .523 .815 r
.85481 .49043 .86073 .50411 .87425 .50549 .86851 .49339 Metetra
.475 .538 .842 r
.86851 .49339 .87425 .50549 .88789 .50696 .88234 .4965 Metetra
.476 .572 .872 r
.88234 .4965 .88789 .50696 .90155 .50781 .89621 .49891 Metetra
.517 .633 .904 r
.89621 .49891 .90155 .50781 .91514 .5071 .90998 .49953 Metetra
.615 .72 .92 r
.90998 .49953 .91514 .5071 .92847 .50365 .92347 .49696 Metetra
.752 .801 .893 r
.92347 .49696 .92847 .50365 .94135 .49602 .93643 .48953 Metetra
.868 .831 .809 r
.93643 .48953 .94135 .49602 .95351 .48253 .94855 .47527 Metetra
0 .216 .691 r
.34959 .64355 .35633 .64948 .36678 .65606 .36002 .65086 Metetra
.475 .717 .976 r
.36002 .65086 .36678 .65606 .37762 .6562 .37088 .65082 Metetra
.721 .782 .901 r
.37088 .65082 .37762 .6562 .3887 .65172 .38203 .64551 Metetra
.783 .764 .836 r
.38203 .64551 .3887 .65172 .39992 .6442 .39333 .63673 Metetra
.795 .737 .798 r
.39333 .63673 .39992 .6442 .41122 .63494 .40472 .62599 Metetra
.789 .709 .776 r
.40472 .62599 .41122 .63494 .42255 .62499 .41613 .61448 Metetra
.773 .682 .763 r
.41613 .61448 .42255 .62499 .43388 .61515 .42753 .60312 Metetra
.753 .657 .755 r
.42753 .60312 .43388 .61515 .4452 .606 .43891 .59257 Metetra
.729 .632 .75 r
.43891 .59257 .4452 .606 .4565 .59796 .45025 .58331 Metetra
.703 .608 .748 r
.45025 .58331 .4565 .59796 .4678 .59126 .46157 .5756 Metetra
.676 .586 .747 r
.46157 .5756 .4678 .59126 .4791 .58603 .47289 .56958 Metetra
.649 .565 .747 r
.47289 .56958 .4791 .58603 .49042 .58226 .48421 .56524 Metetra
.623 .546 .748 r
.48421 .56524 .49042 .58226 .50177 .57987 .49556 .5625 Metetra
.598 .53 .749 r
.49556 .5625 .50177 .57987 .51318 .5787 .50696 .56117 Metetra
.576 .516 .751 r
.50696 .56117 .51318 .5787 .52465 .57855 .51841 .56103 Metetra
.559 .507 .754 r
.51841 .56103 .52465 .57855 .53619 .57916 .52994 .56178 Metetra
.546 .501 .757 r
.52994 .56178 .53619 .57916 .54781 .58027 .54155 .56314 Metetra
.539 .5 .761 r
.54155 .56314 .54781 .58027 .55951 .58159 .55324 .56477 Metetra
.539 .504 .765 r
.55324 .56477 .55951 .58159 .57129 .58284 .56502 .56638 Metetra
.546 .511 .768 r
.56502 .56638 .57129 .58284 .58316 .58377 .57687 .56765 Metetra
.558 .522 .772 r
.57687 .56765 .58316 .58377 .59509 .58413 .5888 .56831 Metetra
.575 .536 .773 r
.5888 .56831 .59509 .58413 .60708 .58371 .6008 .56814 Metetra
.595 .55 .774 r
.6008 .56814 .60708 .58371 .61911 .58235 .61284 .56694 Metetra
.617 .564 .772 r
.61284 .56694 .61911 .58235 .63119 .57993 .62491 .56459 Metetra
.638 .576 .769 r
.62491 .56459 .63119 .57993 .64328 .5764 .63701 .56102 Metetra
.658 .586 .764 r
.63701 .56102 .64328 .5764 .65538 .57174 .64911 .55623 Metetra
.674 .594 .758 r
.64911 .55623 .65538 .57174 .66749 .56602 .66122 .55026 Metetra
.687 .598 .751 r
.66122 .55026 .66749 .56602 .67958 .55935 .67331 .54326 Metetra
.696 .6 .745 r
.67331 .54326 .67958 .55935 .69167 .55187 .68539 .53539 Metetra
.701 .6 .74 r
.68539 .53539 .69167 .55187 .70376 .5438 .69746 .5269 Metetra
.703 .598 .735 r
.69746 .5269 .70376 .5438 .71584 .53537 .70953 .51804 Metetra
.701 .593 .732 r
.70953 .51804 .71584 .53537 .72794 .52686 .72161 .50913 Metetra
.696 .588 .73 r
.72161 .50913 .72794 .52686 .74007 .51854 .73372 .50048 Metetra
.688 .581 .73 r
.73372 .50048 .74007 .51854 .75225 .51071 .74589 .49242 Metetra
.676 .573 .732 r
.74589 .49242 .75225 .51071 .76451 .50364 .75815 .48527 Metetra
.661 .564 .735 r
.75815 .48527 .76451 .50364 .77688 .4976 .77052 .4793 Metetra
.643 .555 .74 r
.77052 .4793 .77688 .4976 .78939 .4928 .78305 .47478 Metetra
.62 .545 .748 r
.78305 .47478 .78939 .4928 .80206 .48941 .79577 .4719 Metetra
.593 .534 .758 r
.79577 .4719 .80206 .48941 .81493 .48753 .80869 .47075 Metetra
.561 .523 .77 r
.80869 .47075 .81493 .48753 .828 .48717 .82186 .47136 Metetra
.524 .512 .785 r
.82186 .47136 .828 .48717 .8413 .48822 .83527 .47359 Metetra
.485 .504 .802 r
.83527 .47359 .8413 .48822 .85481 .49043 .84892 .47718 Metetra
.446 .502 .823 r
.84892 .47718 .85481 .49043 .86851 .49339 .86278 .48165 Metetra
.417 .512 .848 r
.86278 .48165 .86851 .49339 .88234 .4965 .87679 .48631 Metetra
.414 .544 .878 r
.87679 .48631 .88234 .4965 .89621 .49891 .89085 .49021 Metetra
.463 .611 .911 r
.89085 .49021 .89621 .49891 .90998 .49953 .9048 .49208 Metetra
.584 .711 .931 r
.9048 .49208 .90998 .49953 .92347 .49696 .91844 .49033 Metetra
.748 .804 .897 r
.91844 .49033 .92347 .49696 .93643 .48953 .93147 .48303 Metetra
.877 .833 .8 r
.93147 .48303 .93643 .48953 .94855 .47527 .94355 .46794 Metetra
0 .136 .616 r
.3428 .63757 .34959 .64355 .36002 .65086 .35319 .64573 Metetra
.474 .721 .978 r
.35319 .64573 .36002 .65086 .37088 .65082 .36408 .64562 Metetra
.74 .792 .894 r
.36408 .64562 .37088 .65082 .38203 .64551 .37529 .6396 Metetra
.802 .773 .827 r
.37529 .6396 .38203 .64551 .39333 .63673 .38668 .62969 Metetra
.814 .747 .79 r
.38668 .62969 .39333 .63673 .40472 .62599 .39816 .6176 Metetra
.808 .722 .77 r
.39816 .6176 .40472 .62599 .41613 .61448 .40966 .60466 Metetra
.793 .698 .76 r
.40966 .60466 .41613 .61448 .42753 .60312 .42113 .5919 Metetra
.772 .674 .755 r
.42113 .5919 .42753 .60312 .43891 .59257 .43256 .58008 Metetra
.748 .65 .753 r
.43256 .58008 .43891 .59257 .45025 .58331 .44396 .56971 Metetra
.72 .627 .753 r
.44396 .56971 .45025 .58331 .46157 .5756 .45531 .5611 Metetra
.691 .605 .755 r
.45531 .5611 .46157 .5756 .47289 .56958 .46664 .55439 Metetra
.66 .583 .757 r
.46664 .55439 .47289 .56958 .48421 .56524 .47798 .54959 Metetra
.629 .562 .76 r
.47798 .54959 .48421 .56524 .49556 .5625 .48933 .54658 Metetra
.6 .544 .764 r
.48933 .54658 .49556 .5625 .50696 .56117 .50072 .54518 Metetra
.572 .529 .768 r
.50072 .54518 .50696 .56117 .51841 .56103 .51216 .54511 Metetra
.55 .517 .772 r
.51216 .54511 .51841 .56103 .52994 .56178 .52368 .54608 Metetra
.532 .51 .777 r
.52368 .54608 .52994 .56178 .54155 .56314 .53528 .54774 Metetra
.523 .509 .782 r
.53528 .54774 .54155 .56314 .55324 .56477 .54697 .54974 Metetra
.521 .513 .787 r
.54697 .54974 .55324 .56477 .56502 .56638 .55874 .55173 Metetra
.528 .522 .793 r
.55874 .55173 .56502 .56638 .57687 .56765 .5706 .55338 Metetra
.543 .536 .797 r
.5706 .55338 .57687 .56765 .5888 .56831 .58254 .55438 Metetra
.565 .553 .8 r
.58254 .55438 .5888 .56831 .6008 .56814 .59454 .55448 Metetra
.59 .571 .8 r
.59454 .55448 .6008 .56814 .61284 .56694 .60659 .55347 Metetra
.618 .588 .797 r
.60659 .55347 .61284 .56694 .62491 .56459 .61868 .55119 Metetra
.644 .602 .792 r
.61868 .55119 .62491 .56459 .63701 .56102 .63078 .54759 Metetra
.667 .614 .785 r
.63078 .54759 .63701 .56102 .64911 .55623 .6429 .54264 Metetra
.687 .622 .777 r
.6429 .54264 .64911 .55623 .66122 .55026 .655 .53642 Metetra
.702 .626 .769 r
.655 .53642 .66122 .55026 .67331 .54326 .6671 .52907 Metetra
.712 .627 .761 r
.6671 .52907 .67331 .54326 .68539 .53539 .67918 .52079 Metetra
.718 .626 .754 r
.67918 .52079 .68539 .53539 .69746 .5269 .69124 .51184 Metetra
.719 .622 .748 r
.69124 .51184 .69746 .5269 .70953 .51804 .7033 .50251 Metetra
.717 .617 .745 r
.7033 .50251 .70953 .51804 .72161 .50913 .71537 .49316 Metetra
.71 .61 .743 r
.71537 .49316 .72161 .50913 .73372 .50048 .72747 .48412 Metetra
.7 .601 .743 r
.72747 .48412 .73372 .50048 .74589 .49242 .73964 .47577 Metetra
.686 .592 .744 r
.73964 .47577 .74589 .49242 .75815 .48527 .75189 .46845 Metetra
.667 .58 .749 r
.75189 .46845 .75815 .48527 .77052 .4793 .76427 .4625 Metetra
.644 .568 .755 r
.76427 .4625 .77052 .4793 .78305 .47478 .77682 .45817 Metetra
.615 .554 .763 r
.77682 .45817 .78305 .47478 .79577 .4719 .78957 .45569 Metetra
.58 .539 .774 r
.78957 .45569 .79577 .4719 .80869 .47075 .80255 .45517 Metetra
.539 .523 .786 r
.80255 .45517 .80869 .47075 .82186 .47136 .81579 .45663 Metetra
.491 .506 .801 r
.81579 .45663 .82186 .47136 .83527 .47359 .82931 .45993 Metetra
.437 .491 .817 r
.82931 .45993 .83527 .47359 .84892 .47718 .84309 .46476 Metetra
.385 .481 .835 r
.84309 .46476 .84892 .47718 .86278 .48165 .8571 .47061 Metetra
.345 .484 .856 r
.8571 .47061 .86278 .48165 .87679 .48631 .87128 .4767 Metetra
.339 .515 .884 r
.87128 .4767 .87679 .48631 .89085 .49021 .88551 .48195 Metetra
.401 .59 .92 r
.88551 .48195 .89085 .49021 .9048 .49208 .89963 .48494 Metetra
.552 .708 .944 r
.89963 .48494 .9048 .49208 .91844 .49033 .91339 .48387 Metetra
.748 .812 .903 r
.91339 .48387 .91844 .49033 .93147 .48303 .92648 .47659 Metetra
.887 .836 .79 r
.92648 .47659 .93147 .48303 .94355 .46794 .9385 .46056 Metetra
.471 0 0 r
.33596 .63155 .3428 .63757 .35319 .64573 .3463 .6407 Metetra
.46 .721 .981 r
.3463 .6407 .35319 .64573 .36408 .64562 .35721 .64068 Metetra
.754 .802 .892 r
.35721 .64068 .36408 .64562 .37529 .6396 .36848 .63411 Metetra
.818 .784 .821 r
.36848 .63411 .37529 .6396 .38668 .62969 .37996 .62324 Metetra
.831 .76 .785 r
.37996 .62324 .38668 .62969 .39816 .6176 .39153 .60996 Metetra
.826 .737 .767 r
.39153 .60996 .39816 .6176 .40966 .60466 .40311 .59575 Metetra
.812 .716 .759 r
.40311 .59575 .40966 .60466 .42113 .5919 .41466 .58175 Metetra
.792 .694 .757 r
.41466 .58175 .42113 .5919 .43256 .58008 .42616 .56881 Metetra
.767 .673 .758 r
.42616 .56881 .43256 .58008 .44396 .56971 .4376 .55749 Metetra
.739 .651 .762 r
.4376 .55749 .44396 .56971 .45531 .5611 .44899 .54812 Metetra
.707 .629 .767 r
.44899 .54812 .45531 .5611 .46664 .55439 .46035 .54086 Metetra
.672 .607 .774 r
.46035 .54086 .46664 .55439 .47798 .54959 .4717 .53571 Metetra
.636 .585 .781 r
.4717 .53571 .47798 .54959 .48933 .54658 .48306 .53255 Metetra
.599 .565 .788 r
.48306 .53255 .48933 .54658 .50072 .54518 .49445 .53117 Metetra
.564 .548 .794 r
.49445 .53117 .50072 .54518 .51216 .54511 .50589 .53128 Metetra
.533 .534 .801 r
.50589 .53128 .51216 .54511 .52368 .54608 .51741 .53255 Metetra
.508 .525 .809 r
.51741 .53255 .52368 .54608 .53528 .54774 .529 .53459 Metetra
.493 .523 .816 r
.529 .53459 .53528 .54774 .54697 .54974 .54069 .53702 Metetra
.489 .528 .824 r
.54069 .53702 .54697 .54974 .55874 .55173 .55247 .53946 Metetra
.497 .541 .832 r
.55247 .53946 .55874 .55173 .5706 .55338 .56434 .54154 Metetra
.517 .56 .839 r
.56434 .54154 .5706 .55338 .58254 .55438 .57629 .54293 Metetra
.546 .582 .843 r
.57629 .54293 .58254 .55438 .59454 .55448 .58831 .54333 Metetra
.58 .606 .843 r
.58831 .54333 .59454 .55448 .60659 .55347 .60038 .54252 Metetra
.617 .628 .839 r
.60038 .54252 .60659 .55347 .61868 .55119 .61248 .54033 Metetra
.652 .646 .831 r
.61248 .54033 .61868 .55119 .63078 .54759 .62461 .53669 Metetra
.682 .659 .821 r
.62461 .53669 .63078 .54759 .6429 .54264 .63674 .53159 Metetra
.706 .667 .809 r
.63674 .53159 .6429 .54264 .655 .53642 .64886 .5251 Metetra
.724 .67 .797 r
.64886 .5251 .655 .53642 .6671 .52907 .66097 .51738 Metetra
.736 .67 .785 r
.66097 .51738 .6671 .52907 .67918 .52079 .67306 .50864 Metetra
.742 .666 .776 r
.67306 .50864 .67918 .52079 .69124 .51184 .68512 .49918 Metetra
.743 .66 .769 r
.68512 .49918 .69124 .51184 .7033 .50251 .69718 .48934 Metetra
.739 .653 .764 r
.69718 .48934 .7033 .50251 .71537 .49316 .70925 .47947 Metetra
.731 .643 .761 r
.70925 .47947 .71537 .49316 .72747 .48412 .72135 .46997 Metetra
.718 .632 .761 r
.72135 .46997 .72747 .48412 .73964 .47577 .7335 .46125 Metetra
.7 .62 .764 r
.7335 .46125 .73964 .47577 .75189 .46845 .74576 .45368 Metetra
.677 .606 .769 r
.74576 .45368 .75189 .46845 .76427 .4625 .75815 .44762 Metetra
.648 .59 .776 r
.75815 .44762 .76427 .4625 .77682 .45817 .77071 .44337 Metetra
.612 .572 .786 r
.77071 .44337 .77682 .45817 .78957 .45569 .78349 .44117 Metetra
.567 .552 .797 r
.78349 .44117 .78957 .45569 .80255 .45517 .79652 .44114 Metetra
.513 .528 .81 r
.79652 .44114 .80255 .45517 .81579 .45663 .80983 .44331 Metetra
.449 .503 .822 r
.80983 .44331 .81579 .45663 .82931 .45993 .82344 .44753 Metetra
.378 .477 .835 r
.82344 .44753 .82931 .45993 .84309 .46476 .83734 .45346 Metetra
.307 .456 .846 r
.83734 .45346 .84309 .46476 .8571 .47061 .85148 .46052 Metetra
.255 .452 .861 r
.85148 .46052 .8571 .47061 .87128 .4767 .86581 .46786 Metetra
.249 .482 .885 r
.86581 .46786 .87128 .4767 .88551 .48195 .8802 .47429 Metetra
.329 .568 .926 r
.8802 .47429 .88551 .48195 .89963 .48494 .89446 .47822 Metetra
.52 .709 .957 r
.89446 .47822 .89963 .48494 .91339 .48387 .90833 .47768 Metetra
.752 .823 .907 r
.90833 .47768 .91339 .48387 .92648 .47659 .92146 .47024 Metetra
.899 .839 .778 r
.92146 .47024 .92648 .47659 .9385 .46056 .93342 .45311 Metetra
.567 .045 0 r
.32906 .62548 .33596 .63155 .3463 .6407 .33934 .63578 Metetra
.43 .715 .984 r
.33934 .63578 .3463 .6407 .35721 .64068 .35026 .63604 Metetra
.763 .813 .892 r
.35026 .63604 .35721 .64068 .36848 .63411 .36159 .6291 Metetra
.831 .796 .818 r
.36159 .6291 .36848 .63411 .37996 .62324 .37315 .61746 Metetra
.846 .774 .782 r
.37315 .61746 .37996 .62324 .39153 .60996 .38481 .60317 Metetra
.843 .754 .765 r
.38481 .60317 .39153 .60996 .40311 .59575 .39648 .58788 Metetra
.83 .735 .759 r
.39648 .58788 .40311 .59575 .41466 .58175 .40811 .57283 Metetra
.812 .717 .76 r
.40811 .57283 .41466 .58175 .42616 .56881 .41968 .55894 Metetra
.788 .698 .765 r
.41968 .55894 .42616 .56881 .4376 .55749 .43118 .54683 Metetra
.759 .679 .774 r
.43118 .54683 .4376 .55749 .44899 .54812 .44261 .53685 Metetra
.724 .659 .784 r
.44261 .53685 .44899 .54812 .46035 .54086 .454 .52919 Metetra
.685 .638 .796 r
.454 .52919 .46035 .54086 .4717 .53571 .46536 .52383 Metetra
.641 .616 .809 r
.46536 .52383 .4717 .53571 .48306 .53255 .47673 .52065 Metetra
.595 .594 .821 r
.47673 .52065 .48306 .53255 .49445 .53117 .48813 .51942 Metetra
.547 .573 .833 r
.48813 .51942 .49445 .53117 .50589 .53128 .49958 .51981 Metetra
.502 .556 .844 r
.49958 .51981 .50589 .53128 .51741 .53255 .5111 .52147 Metetra
.463 .545 .854 r
.5111 .52147 .51741 .53255 .529 .53459 .5227 .52398 Metetra
.437 .541 .865 r
.5227 .52398 .529 .53459 .54069 .53702 .5344 .52693 Metetra
.426 .548 .876 r
.5344 .52693 .54069 .53702 .55247 .53946 .54619 .52989 Metetra
.434 .566 .888 r
.54619 .52989 .55247 .53946 .56434 .54154 .55808 .53246 Metetra
.461 .593 .898 r
.55808 .53246 .56434 .54154 .57629 .54293 .57005 .53427 Metetra
.503 .627 .906 r
.57005 .53427 .57629 .54293 .58831 .54333 .58209 .53501 Metetra
.555 .661 .907 r
.58209 .53501 .58831 .54333 .60038 .54252 .59419 .53443 Metetra
.608 .691 .901 r
.59419 .53443 .60038 .54252 .61248 .54033 .60633 .53235 Metetra
.658 .713 .889 r
.60633 .53235 .61248 .54033 .62461 .53669 .61848 .52868 Metetra
.7 .728 .872 r
.61848 .52868 .62461 .53669 .63674 .53159 .63065 .52341 Metetra
.731 .734 .853 r
.63065 .52341 .63674 .53159 .64886 .5251 .6428 .51663 Metetra
.754 .734 .835 r
.6428 .51663 .64886 .5251 .66097 .51738 .65492 .5085 Metetra
.768 .73 .818 r
.65492 .5085 .66097 .51738 .67306 .50864 .66703 .49927 Metetra
.774 .723 .805 r
.66703 .49927 .67306 .50864 .68512 .49918 .67911 .48925 Metetra
.775 .714 .795 r
.67911 .48925 .68512 .49918 .69718 .48934 .69117 .47881 Metetra
.769 .702 .788 r
.69117 .47881 .69718 .48934 .70925 .47947 .70324 .46836 Metetra
.759 .69 .785 r
.70324 .46836 .70925 .47947 .72135 .46997 .71534 .45832 Metetra
.743 .676 .786 r
.71534 .45832 .72135 .46997 .7335 .46125 .7275 .44912 Metetra
.721 .661 .789 r
.7275 .44912 .7335 .46125 .74576 .45368 .73976 .44119 Metetra
.693 .643 .795 r
.73976 .44119 .74576 .45368 .75815 .44762 .75215 .43492 Metetra
.656 .623 .805 r
.75215 .43492 .75815 .44762 .77071 .44337 .76473 .43062 Metetra
.61 .6 .816 r
.76473 .43062 .77071 .44337 .78349 .44117 .77754 .42856 Metetra
.552 .572 .828 r
.77754 .42856 .78349 .44117 .79652 .44114 .79062 .42888 Metetra
.48 .538 .84 r
.79062 .42888 .79652 .44114 .80983 .44331 .80399 .4316 Metetra
.394 .5 .848 r
.80399 .4316 .80983 .44331 .82344 .44753 .81768 .43656 Metetra
.3 .46 .852 r
.81768 .43656 .82344 .44753 .83734 .45346 .83167 .44341 Metetra
.21 .425 .852 r
.83167 .44341 .83734 .45346 .85148 .46052 .84594 .4515 Metetra
.147 .411 .855 r
.84594 .4515 .85148 .46052 .86581 .46786 .86041 .4599 Metetra
.145 .442 .876 r
.86041 .4599 .86581 .46786 .8802 .47429 .87493 .46732 Metetra
.25 .545 .926 r
.87493 .46732 .8802 .47429 .89446 .47822 .88931 .47201 Metetra
.489 .713 .97 r
.88931 .47201 .89446 .47822 .90833 .47768 .90326 .47179 Metetra
.761 .838 .91 r
.90326 .47179 .90833 .47768 .92146 .47024 .91641 .464 Metetra
.91 .842 .765 r
.91641 .464 .92146 .47024 .93342 .45311 .92829 .4456 Metetra
.653 .137 0 r
.32212 .61937 .32906 .62548 .33934 .63578 .33232 .631 Metetra
.379 .698 .983 r
.33232 .631 .33934 .63578 .35026 .63604 .34324 .63171 Metetra
.768 .825 .897 r
.34324 .63171 .35026 .63604 .36159 .6291 .35462 .62461 Metetra
.843 .809 .817 r
.35462 .62461 .36159 .6291 .37315 .61746 .36625 .61238 Metetra
.859 .789 .78 r
.36625 .61238 .37315 .61746 .38481 .60317 .378 .59729 Metetra
.858 .771 .765 r
.378 .59729 .38481 .60317 .39648 .58788 .38976 .5811 Metetra
.848 .755 .761 r
.38976 .5811 .39648 .58788 .40811 .57283 .40148 .56518 Metetra
.831 .741 .765 r
.40148 .56518 .40811 .57283 .41968 .55894 .41312 .55052 Metetra
.808 .726 .774 r
.41312 .55052 .41968 .55894 .43118 .54683 .42467 .53779 Metetra
.779 .711 .788 r
.42467 .53779 .43118 .54683 .44261 .53685 .43615 .52737 Metetra
.742 .694 .806 r
.43615 .52737 .44261 .53685 .454 .52919 .44757 .51945 Metetra
.697 .676 .825 r
.44757 .51945 .454 .52919 .46536 .52383 .45896 .51403 Metetra
.643 .655 .846 r
.45896 .51403 .46536 .52383 .47673 .52065 .47034 .51096 Metetra
.581 .631 .866 r
.47034 .51096 .47673 .52065 .48813 .51942 .48175 .50999 Metetra
.511 .606 .884 r
.48175 .50999 .48813 .51942 .49958 .51981 .49321 .51078 Metetra
.439 .581 .898 r
.49321 .51078 .49958 .51981 .5111 .52147 .50474 .51294 Metetra
.373 .561 .908 r
.50474 .51294 .5111 .52147 .5227 .52398 .51636 .51602 Metetra
.321 .551 .917 r
.51636 .51602 .5227 .52398 .5344 .52693 .52807 .51956 Metetra
.293 .556 .926 r
.52807 .51956 .5344 .52693 .54619 .52989 .53988 .52311 Metetra
.296 .579 .939 r
.53988 .52311 .54619 .52989 .55808 .53246 .55179 .52624 Metetra
.331 .62 .956 r
.55179 .52624 .55808 .53246 .57005 .53427 .5638 .52854 Metetra
.396 .673 .971 r
.5638 .52854 .57005 .53427 .58209 .53501 .57588 .52966 Metetra
.48 .728 .98 r
.57588 .52966 .58209 .53501 .59419 .53443 .58801 .52934 Metetra
.568 .776 .977 r
.58801 .52934 .59419 .53443 .60633 .53235 .60019 .52738 Metetra
.648 .808 .96 r
.60019 .52738 .60633 .53235 .61848 .52868 .61239 .52368 Metetra
.711 .825 .935 r
.61239 .52368 .61848 .52868 .63065 .52341 .6246 .51824 Metetra
.757 .828 .907 r
.6246 .51824 .63065 .52341 .6428 .51663 .63678 .51114 Metetra
.787 .822 .88 r
.63678 .51114 .6428 .51663 .65492 .5085 .64895 .50257 Metetra
.805 .812 .856 r
.64895 .50257 .65492 .5085 .66703 .49927 .66108 .49279 Metetra
.813 .798 .838 r
.66108 .49279 .66703 .49927 .67911 .48925 .67318 .48215 Metetra
.813 .783 .825 r
.67318 .48215 .67911 .48925 .69117 .47881 .68527 .47105 Metetra
.807 .767 .817 r
.68527 .47105 .69117 .47881 .70324 .46836 .69735 .45993 Metetra
.794 .751 .813 r
.69735 .45993 .70324 .46836 .71534 .45832 .70946 .44925 Metetra
.775 .733 .814 r
.70946 .44925 .71534 .45832 .7275 .44912 .72162 .43948 Metetra
.749 .714 .82 r
.72162 .43948 .7275 .44912 .73976 .44119 .73388 .43108 Metetra
.714 .693 .829 r
.73388 .43108 .73976 .44119 .75215 .43492 .74629 .42446 Metetra
.668 .668 .841 r
.74629 .42446 .75215 .43492 .76473 .43062 .75889 .41999 Metetra
.609 .638 .854 r
.75889 .41999 .76473 .43062 .77754 .42856 .77172 .41793 Metetra
.532 .6 .867 r
.77172 .41793 .77754 .42856 .79062 .42888 .78483 .41844 Metetra
.437 .552 .875 r
.78483 .41844 .79062 .42888 .80399 .4316 .79826 .42155 Metetra
.323 .496 .874 r
.79826 .42155 .80399 .4316 .81768 .43656 .81202 .42709 Metetra
.202 .435 .862 r
.81202 .42709 .81768 .43656 .83167 .44341 .8261 .43467 Metetra
.092 .383 .843 r
.8261 .43467 .83167 .44341 .84594 .4515 .84048 .4436 Metetra
.022 .36 .832 r
.84048 .4436 .84594 .4515 .86041 .4599 .85505 .45287 Metetra
.031 .394 .852 r
.85505 .45287 .86041 .4599 .87493 .46732 .86969 .46107 Metetra
.167 .519 .917 r
.86969 .46107 .87493 .46732 .88931 .47201 .88417 .46631 Metetra
.464 .722 .981 r
.88417 .46631 .88931 .47201 .90326 .47179 .89819 .46621 Metetra
.775 .853 .909 r
.89819 .46621 .90326 .47179 .91641 .464 .91134 .45789 Metetra
.922 .844 .749 r
.91134 .45789 .91641 .464 .92829 .4456 .92311 .43803 Metetra
.726 .221 0 r
.31512 .61321 .32212 .61937 .33232 .631 .32523 .62633 Metetra
.302 .666 .973 r
.32523 .62633 .33232 .631 .34324 .63171 .33614 .62768 Metetra
.769 .836 .904 r
.33614 .62768 .34324 .63171 .35462 .62461 .34755 .6206 Metetra
.851 .821 .819 r
.34755 .6206 .35462 .62461 .36625 .61238 .35926 .60799 Metetra
.871 .802 .78 r
.35926 .60799 .36625 .61238 .378 .59729 .3711 .59227 Metetra
.872 .787 .765 r
.3711 .59227 .378 .59729 .38976 .5811 .38295 .57538 Metetra
.863 .775 .763 r
.38295 .57538 .38976 .5811 .40148 .56518 .39475 .55877 Metetra
.849 .765 .77 r
.39475 .55877 .40148 .56518 .41312 .55052 .40646 .54352 Metetra
.827 .755 .784 r
.40646 .54352 .41312 .55052 .42467 .53779 .41807 .53032 Metetra
.798 .746 .804 r
.41807 .53032 .42467 .53779 .43615 .52737 .4296 .51962 Metetra
.759 .735 .83 r
.4296 .51962 .43615 .52737 .44757 .51945 .44105 .51159 Metetra
.707 .721 .861 r
.44105 .51159 .44757 .51945 .45896 .51403 .45247 .50624 Metetra
.637 .702 .893 r
.45247 .50624 .45896 .51403 .47034 .51096 .46388 .50341 Metetra
.547 .675 .922 r
.46388 .50341 .47034 .51096 .48175 .50999 .4753 .50283 Metetra
.436 .638 .941 r
.4753 .50283 .48175 .50999 .49321 .51078 .48678 .50413 Metetra
.31 .591 .944 r
.48678 .50413 .49321 .51078 .50474 .51294 .49832 .50688 Metetra
.186 .542 .928 r
.49832 .50688 .50474 .51294 .51636 .51602 .50995 .51062 Metetra
.085 .503 .901 r
.50995 .51062 .51636 .51602 .52807 .51956 .52169 .51485 Metetra
.023 .487 .877 r
.52169 .51485 .52807 .51956 .53988 .52311 .53353 .51907 Metetra
.011 .503 .869 r
.53353 .51907 .53988 .52311 .55179 .52624 .54548 .52282 Metetra
.051 .553 .882 r
.54548 .52282 .55179 .52624 .5638 .52854 .55752 .52565 Metetra
.141 .633 .914 r
.55752 .52565 .5638 .52854 .57588 .52966 .56965 .5272 Metetra
.273 .731 .953 r
.56965 .5272 .57588 .52966 .58801 .52934 .58183 .52717 Metetra
.424 .823 .981 r
.58183 .52717 .58801 .52934 .60019 .52738 .59407 .52534 Metetra
.566 .891 .987 r
.59407 .52534 .60019 .52738 .61239 .52368 .60632 .52162 Metetra
.68 .925 .971 r
.60632 .52162 .61239 .52368 .6246 .51824 .61858 .51599 Metetra
.759 .932 .943 r
.61858 .51599 .6246 .51824 .63678 .51114 .63081 .50855 Metetra
.809 .923 .912 r
.63081 .50855 .63678 .51114 .64895 .50257 .64302 .4995 Metetra
.837 .906 .885 r
.64302 .4995 .64895 .50257 .66108 .49279 .65519 .48913 Metetra
.85 .886 .864 r
.65519 .48913 .66108 .49279 .67318 .48215 .66733 .47781 Metetra
.853 .865 .85 r
.66733 .47781 .67318 .48215 .68527 .47105 .67944 .46598 Metetra
.846 .844 .842 r
.67944 .46598 .68527 .47105 .69735 .45993 .69155 .4541 Metetra
.833 .823 .84 r
.69155 .4541 .69735 .45993 .70946 .44925 .70367 .4427 Metetra
.811 .803 .843 r
.70367 .4427 .70946 .44925 .72162 .43948 .71585 .43226 Metetra
.781 .78 .852 r
.71585 .43226 .72162 .43948 .73388 .43108 .72812 .42328 Metetra
.739 .755 .866 r
.72812 .42328 .73388 .43108 .74629 .42446 .74054 .4162 Metetra
.683 .725 .882 r
.74054 .4162 .74629 .42446 .75889 .41999 .75316 .41142 Metetra
.607 .687 .899 r
.75316 .41142 .75889 .41999 .77172 .41793 .76601 .40922 Metetra
.507 .635 .911 r
.76601 .40922 .77172 .41793 .78483 .41844 .77916 .40979 Metetra
.38 .568 .911 r
.77916 .40979 .78483 .41844 .79826 .42155 .79263 .41313 Metetra
.233 .486 .892 r
.79263 .41313 .79826 .42155 .81202 .42709 .80645 .41908 Metetra
.083 .4 .855 r
.80645 .41908 .81202 .42709 .8261 .43467 .82061 .4272 Metetra
0 .329 .812 r
.82061 .4272 .8261 .43467 .84048 .4436 .83507 .43679 Metetra
0 .3 .788 r
.83507 .43679 .84048 .4436 .85505 .45287 .84975 .44674 Metetra
0 .342 .81 r
.84975 .44674 .85505 .45287 .86969 .46107 .86448 .45553 Metetra
.088 .492 .899 r
.86448 .45553 .86969 .46107 .88417 .46631 .87905 .46111 Metetra
.446 .734 .988 r
.87905 .46111 .88417 .46631 .89819 .46621 .89311 .46093 Metetra
.792 .869 .905 r
.89311 .46093 .89819 .46621 .91134 .45789 .90624 .45188 Metetra
.933 .845 .732 r
.90624 .45188 .91134 .45789 .92311 .43803 .91789 .43038 Metetra
.783 .294 0 r
.30806 .607 .31512 .61321 .32523 .62633 .31807 .62176 Metetra
.198 .612 .947 r
.31807 .62176 .32523 .62633 .33614 .62768 .32895 .62392 Metetra
.764 .847 .913 r
.32895 .62392 .33614 .62768 .34755 .6206 .3404 .61704 Metetra
.858 .833 .821 r
.3404 .61704 .34755 .6206 .35926 .60799 .35218 .60422 Metetra
.88 .815 .78 r
.35218 .60422 .35926 .60799 .3711 .59227 .36409 .58806 Metetra
.883 .803 .765 r
.36409 .58806 .3711 .59227 .38295 .57538 .37603 .57064 Metetra
.877 .794 .765 r
.37603 .57064 .38295 .57538 .39475 .55877 .38791 .55351 Metetra
.864 .789 .775 r
.38791 .55351 .39475 .55877 .40646 .54352 .3997 .53782 Metetra
.844 .785 .794 r
.3997 .53782 .40646 .54352 .41807 .53032 .41137 .52432 Metetra
.815 .782 .821 r
.41137 .52432 .41807 .53032 .4296 .51962 .42295 .51347 Metetra
.773 .778 .857 r
.42295 .51347 .4296 .51962 .44105 .51159 .43445 .50547 Metetra
.71 .771 .9 r
.43445 .50547 .44105 .51159 .45247 .50624 .44589 .50032 Metetra
.614 .753 .944 r
.44589 .50032 .45247 .50624 .46388 .50341 .45732 .49784 Metetra
.473 .713 .975 r
.45732 .49784 .46388 .50341 .4753 .50283 .46877 .49776 Metetra
.283 .638 .965 r
.46877 .49776 .4753 .50283 .48678 .50413 .48026 .49967 Metetra
.069 .529 .898 r
.48026 .49967 .48678 .50413 .49832 .50688 .49182 .50312 Metetra
0 .414 .791 r
.49182 .50312 .49832 .50688 .50995 .51062 .50348 .50761 Metetra
0 .325 .682 r
.50348 .50761 .50995 .51062 .52169 .51485 .51525 .51259 Metetra
.314 0 0 r
.51525 .51259 .52169 .51485 .53353 .51907 .52712 .51755 Metetra
.324 0 0 r
.52712 .51755 .53353 .51907 .54548 .52282 .53911 .52198 Metetra
.284 0 0 r
.53911 .52198 .54548 .52282 .55752 .52565 .5512 .5254 Metetra
.195 0 0 r
.5512 .5254 .55752 .52565 .56965 .5272 .56338 .52741 Metetra
.055 0 0 r
.56338 .52741 .56965 .5272 .58183 .52717 .57563 .52769 Metetra
.131 .679 .743 r
.57563 .52769 .58183 .52717 .59407 .52534 .58792 .52602 Metetra
.34 .821 .822 r
.58792 .52602 .59407 .52534 .60632 .52162 .60024 .52228 Metetra
.534 .924 .873 r
.60024 .52228 .60632 .52162 .61858 .51599 .61256 .51645 Metetra
.681 .977 .891 r
.61256 .51645 .61858 .51599 .63081 .50855 .62486 .50865 Metetra
.779 .991 .887 r
.62486 .50865 .63081 .50855 .64302 .4995 .63712 .49908 Metetra
.836 .982 .874 r
.63712 .49908 .64302 .4995 .65519 .48913 .64935 .48807 Metetra
.866 .964 .862 r
.64935 .48807 .65519 .48913 .66733 .47781 .66153 .47602 Metetra
.878 .942 .853 r
.66153 .47602 .66733 .47781 .67944 .46598 .67368 .46339 Metetra
.878 .92 .85 r
.67368 .46339 .67944 .46598 .69155 .4541 .68581 .45069 Metetra
.866 .898 .854 r
.68581 .45069 .69155 .4541 .70367 .4427 .69796 .43847 Metetra
.845 .876 .864 r
.69796 .43847 .70367 .4427 .71585 .43226 .71016 .42726 Metetra
.813 .853 .879 r
.71016 .42726 .71585 .43226 .72812 .42328 .72245 .4176 Metetra
.765 .827 .9 r
.72245 .4176 .72812 .42328 .74054 .4162 .73488 .40996 Metetra
.698 .792 .923 r
.73488 .40996 .74054 .4162 .75316 .41142 .74752 .40476 Metetra
.603 .744 .944 r
.74752 .40476 .75316 .41142 .76601 .40922 .7604 .4023 Metetra
.473 .675 .953 r
.7604 .4023 .76601 .40922 .77916 .40979 .77357 .40277 Metetra
.308 .581 .938 r
.77357 .40277 .77916 .40979 .79263 .41313 .78709 .4062 Metetra
.124 .467 .892 r
.78709 .4062 .79263 .41313 .80645 .41908 .80096 .4124 Metetra
0 .353 .823 r
.80096 .4124 .80645 .41908 .82061 .4272 .81519 .42092 Metetra
0 .268 .757 r
.81519 .42092 .82061 .4272 .83507 .43679 .82972 .43099 Metetra
0 .238 .725 r
.82972 .43099 .83507 .43679 .84975 .44674 .84448 .44143 Metetra
0 .291 .757 r
.84448 .44143 .84975 .44674 .86448 .45553 .8593 .45062 Metetra
.019 .468 .874 r
.8593 .45062 .86448 .45553 .87905 .46111 .87392 .45637 Metetra
.439 .75 .994 r
.87392 .45637 .87905 .46111 .89311 .46093 .88802 .45592 Metetra
.812 .883 .896 r
.88802 .45592 .89311 .46093 .90624 .45188 .90111 .44596 Metetra
.943 .844 .715 r
.90111 .44596 .90624 .45188 .91789 .43038 .91263 .42268 Metetra
.825 .354 0 r
.30095 .60075 .30806 .607 .31807 .62176 .31084 .61726 Metetra
.066 .534 .897 r
.31084 .61726 .31807 .62176 .32895 .62392 .32168 .62038 Metetra
.755 .856 .925 r
.32168 .62038 .32895 .62392 .3404 .61704 .33316 .61384 Metetra
.862 .844 .825 r
.33316 .61384 .3404 .61704 .35218 .60422 .34499 .60098 Metetra
.887 .827 .782 r
.34499 .60098 .35218 .60422 .36409 .58806 .35699 .58454 Metetra
.892 .816 .766 r
.35699 .58454 .36409 .58806 .37603 .57064 .36901 .56674 Metetra
.888 .811 .767 r
.36901 .56674 .37603 .57064 .38791 .55351 .38098 .54924 Metetra
.877 .81 .779 r
.38098 .54924 .38791 .55351 .3997 .53782 .39283 .53325 Metetra
.858 .812 .803 r
.39283 .53325 .3997 .53782 .41137 .52432 .40457 .51959 Metetra
.829 .817 .838 r
.40457 .51959 .41137 .52432 .42295 .51347 .4162 .50872 Metetra
.781 .822 .884 r
.4162 .50872 .42295 .51347 .43445 .50547 .42774 .50087 Metetra
.7 .821 .94 r
.42774 .50087 .43445 .50547 .44589 .50032 .43922 .49602 Metetra
.56 .797 .988 r
.43922 .49602 .44589 .50032 .45732 .49784 .45067 .494 Metetra
.331 .714 .983 r
.45067 .494 .45732 .49784 .46877 .49776 .46214 .49451 Metetra
.035 .549 .871 r
.46214 .49451 .46877 .49776 .48026 .49967 .47365 .49712 Metetra
0 .354 .68 r
.47365 .49712 .48026 .49967 .49182 .50312 .48524 .50135 Metetra
.398 0 0 r
.48524 .50135 .49182 .50312 .50348 .50761 .49692 .50666 Metetra
.485 0 0 r
.49692 .50666 .50348 .50761 .51525 .51259 .50872 .51247 Metetra
.516 0 0 r
.50872 .51247 .51525 .51259 .52712 .51755 .52064 .51823 Metetra
.508 0 0 r
.52064 .51823 .52712 .51755 .53911 .52198 .53267 .52339 Metetra
.468 0 0 r
.53267 .52339 .53911 .52198 .5512 .5254 .54482 .52744 Metetra
.395 0 0 r
.54482 .52744 .5512 .5254 .56338 .52741 .55706 .52995 Metetra
.282 0 0 r
.55706 .52995 .56338 .52741 .57563 .52769 .56938 .53058 Metetra
.124 0 0 r
.56938 .53058 .57563 .52769 .58792 .52602 .58174 .52907 Metetra
.58174 .52907 .58792 .52602 .60024 .52228 .59413 .5253 Metetra
.59413 .5253 .60024 .52228 .61256 .51645 .60653 .51927 Metetra
.512 .893 .716 r
.60653 .51927 .61256 .51645 .62486 .50865 .6189 .51108 Metetra
.672 .967 .769 r
.6189 .51108 .62486 .50865 .63712 .49908 .63123 .50098 Metetra
.778 .996 .797 r
.63123 .50098 .63712 .49908 .64935 .48807 .64351 .48929 Metetra
.841 .999 .811 r
.64351 .48929 .64935 .48807 .66153 .47602 .65575 .47645 Metetra
.874 .989 .82 r
.65575 .47645 .66153 .47602 .67368 .46339 .66795 .46296 Metetra
.887 .974 .83 r
.66795 .46296 .67368 .46339 .68581 .45069 .68012 .44937 Metetra
.884 .957 .844 r
.68012 .44937 .68581 .45069 .69796 .43847 .6923 .43626 Metetra
.868 .94 .864 r
.6923 .43626 .69796 .43847 .71016 .42726 .70452 .42422 Metetra
.837 .92 .89 r
.70452 .42422 .71016 .42726 .72245 .4176 .71684 .41379 Metetra
.787 .895 .921 r
.71684 .41379 .72245 .4176 .73488 .40996 .72929 .40549 Metetra
.709 .86 .954 r
.72929 .40549 .73488 .40996 .74752 .40476 .74194 .39975 Metetra
.593 .803 .98 r
.74194 .39975 .74752 .40476 .7604 .4023 .75485 .39692 Metetra
.43 .713 .983 r
.75485 .39692 .7604 .4023 .77357 .40277 .76805 .39718 Metetra
.225 .585 .945 r
.76805 .39718 .77357 .40277 .78709 .4062 .7816 .40057 Metetra
.011 .436 .865 r
.7816 .40057 .78709 .4062 .80096 .4124 .79552 .40688 Metetra
0 .3 .767 r
.79552 .40688 .80096 .4124 .81519 .42092 .80981 .41565 Metetra
0 .209 .688 r
.80981 .41565 .81519 .42092 .82972 .43099 .82441 .42605 Metetra
0 .182 .657 r
.82441 .42605 .82972 .43099 .84448 .44143 .83924 .43683 Metetra
0 .246 .703 r
.83924 .43683 .84448 .44143 .8593 .45062 .85412 .44625 Metetra
0 .45 .849 r
.85412 .44625 .8593 .45062 .87392 .45637 .86879 .452 Metetra
.444 .77 .997 r
.86879 .452 .87392 .45637 .88802 .45592 .8829 .45113 Metetra
.834 .894 .883 r
.8829 .45113 .88802 .45592 .90111 .44596 .89594 .4401 Metetra
.952 .841 .697 r
.89594 .4401 .90111 .44596 .91263 .42268 .90732 .41491 Metetra
.856 .403 .035 r
.29379 .59444 .30095 .60075 .31084 .61726 .30353 .6128 Metetra
0 .43 .817 r
.30353 .6128 .31084 .61726 .32168 .62038 .31434 .61698 Metetra
.739 .862 .938 r
.31434 .61698 .32168 .62038 .33316 .61384 .32583 .61093 Metetra
.864 .853 .83 r
.32583 .61093 .33316 .61384 .34499 .60098 .33772 .59815 Metetra
.893 .836 .783 r
.33772 .59815 .34499 .60098 .35699 .58454 .34979 .58156 Metetra
.899 .827 .767 r
.34979 .58156 .35699 .58454 .36901 .56674 .36189 .56351 Metetra
.896 .825 .769 r
.36189 .56351 .36901 .56674 .38098 .54924 .37394 .54577 Metetra
.887 .828 .784 r
.37394 .54577 .38098 .54924 .39283 .53325 .38587 .52961 Metetra
.869 .836 .811 r
.38587 .52961 .39283 .53325 .40457 .51959 .39767 .51588 Metetra
.838 .848 .853 r
.39767 .51588 .40457 .51959 .4162 .50872 .40935 .5051 Metetra
.782 .862 .909 r
.40935 .5051 .4162 .50872 .42774 .50087 .42093 .49749 Metetra
.673 .863 .972 r
.42093 .49749 .42774 .50087 .43922 .49602 .43244 .49304 Metetra
.461 .81 .998 r
.43244 .49304 .43922 .49602 .45067 .494 .44392 .49157 Metetra
.122 .635 .894 r
.44392 .49157 .45067 .494 .46214 .49451 .45541 .49274 Metetra
.22 0 0 r
.45541 .49274 .46214 .49451 .47365 .49712 .46695 .49612 Metetra
.437 0 0 r
.46695 .49612 .47365 .49712 .48524 .50135 .47856 .5012 Metetra
.546 0 0 r
.47856 .5012 .48524 .50135 .49692 .50666 .49027 .50738 Metetra
.593 .035 0 r
.49027 .50738 .49692 .50666 .50872 .51247 .50211 .51408 Metetra
.602 .059 0 r
.50211 .51408 .50872 .51247 .52064 .51823 .51407 .52069 Metetra
.586 .052 0 r
.51407 .52069 .52064 .51823 .53267 .52339 .52615 .52662 Metetra
.547 .017 0 r
.52615 .52662 .53267 .52339 .54482 .52744 .53836 .53134 Metetra
.483 0 0 r
.53836 .53134 .54482 .52744 .55706 .52995 .55066 .53438 Metetra
.39 0 0 r
.55066 .53438 .55706 .52995 .56938 .53058 .56305 .53536 Metetra
.259 0 0 r
.56305 .53536 .56938 .53058 .58174 .52907 .5755 .53404 Metetra
.086 0 0 r
.5755 .53404 .58174 .52907 .59413 .5253 .58797 .53025 Metetra
.58797 .53025 .59413 .5253 .60653 .51927 .60045 .524 Metetra
.60045 .524 .60653 .51927 .6189 .51108 .6129 .51542 Metetra
.541 .877 .616 r
.6129 .51542 .6189 .51108 .63123 .50098 .62531 .50474 Metetra
.688 .95 .683 r
.62531 .50474 .63123 .50098 .64351 .48929 .63766 .49234 Metetra
.785 .984 .726 r
.63766 .49234 .64351 .48929 .65575 .47645 .64996 .47868 Metetra
.843 .995 .757 r
.64996 .47868 .65575 .47645 .66795 .46296 .66222 .46428 Metetra
.873 .994 .784 r
.66222 .46428 .66795 .46296 .68012 .44937 .67444 .44975 Metetra
.882 .988 .81 r
.67444 .44975 .68012 .44937 .6923 .43626 .68666 .4357 Metetra
.874 .979 .841 r
.68666 .4357 .6923 .43626 .70452 .42422 .69891 .42274 Metetra
.848 .966 .878 r
.69891 .42274 .70452 .42422 .71684 .41379 .71125 .41147 Metetra
.798 .948 .92 r
.71125 .41147 .71684 .41379 .72929 .40549 .72373 .40243 Metetra
.714 .914 .963 r
.72373 .40243 .72929 .40549 .74194 .39975 .73641 .39609 Metetra
.579 .851 .995 r
.73641 .39609 .74194 .39975 .75485 .39692 .74934 .39279 Metetra
.384 .74 .991 r
.74934 .39279 .75485 .39692 .76805 .39718 .76257 .39275 Metetra
.145 .579 .929 r
.76257 .39275 .76805 .39718 .7816 .40057 .77615 .39599 Metetra
0 .401 .819 r
.77615 .39599 .7816 .40057 .79552 .40688 .79011 .40231 Metetra
0 .251 .703 r
.79011 .40231 .79552 .40688 .80981 .41565 .80445 .4112 Metetra
0 .16 .621 r
.80445 .4112 .80981 .41565 .82441 .42605 .81911 .4218 Metetra
0 .139 .597 r
.81911 .4218 .82441 .42605 .83924 .43683 .83399 .43278 Metetra
0 .214 .657 r
.83399 .43278 .83924 .43683 .85412 .44625 .84893 .4423 Metetra
0 .442 .83 r
.84893 .4423 .85412 .44625 .86879 .452 .86364 .44791 Metetra
.462 .792 .999 r
.86364 .44791 .86879 .452 .8829 .45113 .87775 .44647 Metetra
.855 .9 .867 r
.87775 .44647 .8829 .45113 .89594 .4401 .89073 .43427 Metetra
.959 .838 .679 r
.89073 .43427 .89594 .4401 .90732 .41491 .90197 .40707 Metetra
.878 .441 .092 r
.28657 .58809 .29379 .59444 .30353 .6128 .29616 .60835 Metetra
0 .311 .714 r
.29616 .60835 .30353 .6128 .31434 .61698 .30691 .61367 Metetra
.718 .865 .951 r
.30691 .61367 .31434 .61698 .32583 .61093 .31841 .60819 Metetra
.863 .859 .835 r
.31841 .60819 .32583 .61093 .33772 .59815 .33035 .59559 Metetra
.895 .843 .785 r
.33035 .59559 .33772 .59815 .34979 .58156 .3425 .57896 Metetra
.903 .835 .768 r
.3425 .57896 .34979 .58156 .36189 .56351 .35468 .56076 Metetra
.902 .835 .77 r
.35468 .56076 .36189 .56351 .37394 .54577 .3668 .54287 Metetra
.893 .842 .787 r
.3668 .54287 .37394 .54577 .38587 .52961 .37881 .52663 Metetra
.876 .854 .818 r
.37881 .52663 .38587 .52961 .39767 .51588 .39067 .51293 Metetra
.842 .873 .865 r
.39067 .51293 .39767 .51588 .40935 .5051 .4024 .50232 Metetra
.774 .892 .928 r
.4024 .50232 .40935 .5051 .42093 .49749 .41402 .49502 Metetra
.626 .886 .988 r
.41402 .49502 .42093 .49749 .43244 .49304 .42556 .49103 Metetra
.325 .774 .958 r
.42556 .49103 .43244 .49304 .44392 .49157 .43707 .49016 Metetra
0 .498 .733 r
.43707 .49016 .44392 .49157 .45541 .49274 .44859 .49206 Metetra
.391 0 0 r
.44859 .49206 .45541 .49274 .46695 .49612 .46014 .49626 Metetra
.547 0 0 r
.46014 .49626 .46695 .49612 .47856 .5012 .47178 .50222 Metetra
.617 .071 0 r
.47178 .50222 .47856 .5012 .49027 .50738 .48352 .50933 Metetra
.642 .118 0 r
.48352 .50933 .49027 .50738 .50211 .51408 .49539 .51695 Metetra
.642 .132 .019 r
.49539 .51695 .50211 .51408 .51407 .52069 .5074 .52444 Metetra
.622 .121 .038 r
.5074 .52444 .51407 .52069 .52615 .52662 .51953 .53117 Metetra
.584 .086 .037 r
.51953 .53117 .52615 .52662 .53836 .53134 .5318 .53658 Metetra
.526 .029 .018 r
.5318 .53658 .53836 .53134 .55066 .53438 .54418 .54017 Metetra
.442 0 0 r
.54418 .54017 .55066 .53438 .56305 .53536 .55665 .54153 Metetra
.325 0 0 r
.55665 .54153 .56305 .53536 .5755 .53404 .56918 .54038 Metetra
.168 0 0 r
.56918 .54038 .5755 .53404 .58797 .53025 .58174 .53658 Metetra
.58174 .53658 .58797 .53025 .60045 .524 .5943 .53012 Metetra
.5943 .53012 .60045 .524 .6129 .51542 .60684 .52112 Metetra
.60684 .52112 .6129 .51542 .62531 .50474 .61934 .50986 Metetra
.617 .895 .587 r
.61934 .50986 .62531 .50474 .63766 .49234 .63177 .49672 Metetra
.735 .952 .649 r
.63177 .49672 .63766 .49234 .64996 .47868 .64414 .4822 Metetra
.81 .98 .694 r
.64414 .4822 .64996 .47868 .66222 .46428 .65646 .46687 Metetra
.853 .991 .732 r
.65646 .46687 .66222 .46428 .67444 .44975 .66873 .45136 Metetra
.872 .994 .767 r
.66873 .45136 .67444 .44975 .68666 .4357 .681 .43632 Metetra
.871 .993 .806 r
.681 .43632 .68666 .4357 .69891 .42274 .6933 .42241 Metetra
.85 .989 .85 r
.6933 .42241 .69891 .42274 .71125 .41147 .70567 .41026 Metetra
.803 .977 .901 r
.70567 .41026 .71125 .41147 .72373 .40243 .71818 .40043 Metetra
.716 .949 .953 r
.71818 .40043 .72373 .40243 .73641 .39609 .73088 .39341 Metetra
.569 .884 .991 r
.73088 .39341 .73641 .39609 .74934 .39279 .74383 .38959 Metetra
.35 .757 .982 r
.74383 .38959 .74934 .39279 .76257 .39275 .75709 .38917 Metetra
.085 .57 .901 r
.75709 .38917 .76257 .39275 .77615 .39599 .77071 .39218 Metetra
0 .372 .772 r
.77071 .39218 .77615 .39599 .79011 .40231 .78471 .39841 Metetra
0 .216 .649 r
.78471 .39841 .79011 .40231 .80445 .4112 .79908 .40733 Metetra
.418 0 0 r
.79908 .40733 .80445 .4112 .81911 .4218 .81379 .41803 Metetra
.435 0 0 r
.81379 .41803 .81911 .4218 .83399 .43278 .82873 .42911 Metetra
0 .195 .626 r
.82873 .42911 .83399 .43278 .84893 .4423 .84371 .43862 Metetra
0 .445 .822 r
.84371 .43862 .84893 .4423 .86364 .44791 .85845 .44398 Metetra
.491 .815 1 r
.85845 .44398 .86364 .44791 .87775 .44647 .87255 .44189 Metetra
.874 .903 .848 r
.87255 .44189 .87775 .44647 .89073 .43427 .88548 .42842 Metetra
.965 .833 .662 r
.88548 .42842 .89073 .43427 .90197 .40707 .89657 .39916 Metetra
.894 .471 .139 r
.27929 .58169 .28657 .58809 .29616 .60835 .28873 .60385 Metetra
.37 0 0 r
.28873 .60385 .29616 .60835 .30691 .61367 .29941 .61035 Metetra
.691 .864 .964 r
.29941 .61035 .30691 .61367 .31841 .60819 .31091 .6055 Metetra
.861 .863 .84 r
.31091 .6055 .31841 .60819 .33035 .59559 .3229 .59315 Metetra
.896 .847 .787 r
.3229 .59315 .33035 .59559 .3425 .57896 .33511 .57655 Metetra
.906 .84 .769 r
.33511 .57655 .3425 .57896 .35468 .56076 .34738 .55828 Metetra
.905 .841 .772 r
.34738 .55828 .35468 .56076 .3668 .54287 .35958 .5403 Metetra
.897 .85 .789 r
.35958 .5403 .3668 .54287 .37881 .52663 .37165 .52404 Metetra
.878 .866 .823 r
.37165 .52404 .37881 .52663 .39067 .51293 .38358 .51043 Metetra
.841 .889 .875 r
.38358 .51043 .39067 .51293 .4024 .50232 .39536 .50003 Metetra
.759 .911 .942 r
.39536 .50003 .4024 .50232 .41402 .49502 .40702 .49309 Metetra
.567 .887 .989 r
.40702 .49309 .41402 .49502 .42556 .49103 .41859 .48961 Metetra
.188 .703 .887 r
.41859 .48961 .42556 .49103 .43707 .49016 .43013 .48937 Metetra
.235 0 0 r
.43013 .48937 .43707 .49016 .44859 .49206 .44166 .49202 Metetra
.488 0 0 r
.44166 .49202 .44859 .49206 .46014 .49626 .45324 .49706 Metetra
.605 .053 0 r
.45324 .49706 .46014 .49626 .47178 .50222 .4649 .50393 Metetra
.655 .132 0 r
.4649 .50393 .47178 .50222 .48352 .50933 .47667 .51199 Metetra
.671 .168 .042 r
.47667 .51199 .48352 .50933 .49539 .51695 .48858 .52055 Metetra
.666 .176 .075 r
.48858 .52055 .49539 .51695 .5074 .52444 .50062 .52893 Metetra
.645 .161 .089 r
.50062 .52893 .5074 .52444 .51953 .53117 .51282 .53648 Metetra
.607 .126 .086 r
.51282 .53648 .51953 .53117 .5318 .53658 .52515 .54259 Metetra
.55 .069 .066 r
.52515 .54259 .5318 .53658 .54418 .54017 .5376 .54673 Metetra
.469 0 .027 r
.5376 .54673 .54418 .54017 .55665 .54153 .55014 .54847 Metetra
.355 0 0 r
.55014 .54847 .55665 .54153 .56918 .54038 .56276 .54751 Metetra
.203 0 0 r
.56276 .54751 .56918 .54038 .58174 .53658 .57541 .5437 Metetra
.01 0 0 r
.57541 .5437 .58174 .53658 .5943 .53012 .58807 .53701 Metetra
.58807 .53701 .5943 .53012 .60684 .52112 .6007 .5276 Metetra
.6007 .5276 .60684 .52112 .61934 .50986 .61329 .51575 Metetra
.594 .869 .541 r
.61329 .51575 .61934 .50986 .63177 .49672 .62581 .50187 Metetra
.719 .933 .607 r
.62581 .50187 .63177 .49672 .64414 .4822 .63826 .48648 Metetra
.799 .967 .656 r
.63826 .48648 .64414 .4822 .65646 .46687 .65064 .4702 Metetra
.847 .983 .697 r
.65064 .4702 .65646 .46687 .66873 .45136 .66298 .45369 Metetra
.87 .991 .735 r
.66298 .45369 .66873 .45136 .681 .43632 .6753 .43765 Metetra
.873 .994 .776 r
.6753 .43765 .681 .43632 .6933 .42241 .68764 .42276 Metetra
.855 .995 .823 r
.68764 .42276 .6933 .42241 .70567 .41026 .70005 .4097 Metetra
.811 .99 .878 r
.70005 .4097 .70567 .41026 .71818 .40043 .71259 .39905 Metetra
.725 .967 .936 r
.71259 .39905 .71818 .40043 .73088 .39341 .72532 .39133 Metetra
.573 .904 .979 r
.72532 .39133 .73088 .39341 .74383 .38959 .7383 .38693 Metetra
.34 .771 .97 r
.7383 .38693 .74383 .38959 .75709 .38917 .7516 .38609 Metetra
.059 .569 .881 r
.7516 .38609 .75709 .38917 .77071 .39218 .76524 .38882 Metetra
0 .358 .742 r
.76524 .38882 .77071 .39218 .78471 .39841 .77928 .39491 Metetra
0 .197 .616 r
.77928 .39491 .78471 .39841 .79908 .40733 .79369 .4038 Metetra
.445 0 0 r
.79369 .4038 .79908 .40733 .81379 .41803 .80845 .41452 Metetra
.455 0 0 r
.80845 .41452 .81379 .41803 .82873 .42911 .82343 .42562 Metetra
0 .19 .613 r
.82343 .42562 .82873 .42911 .84371 .43862 .83845 .43506 Metetra
0 .458 .826 r
.83845 .43506 .84371 .43862 .85845 .44398 .85321 .44009 Metetra
.529 .836 .999 r
.85321 .44009 .85845 .44398 .87255 .44189 .8673 .43728 Metetra
.89 .902 .829 r
.8673 .43728 .87255 .44189 .88548 .42842 .88017 .42251 Metetra
.97 .828 .647 r
.88017 .42251 .88548 .42842 .89657 .39916 .89112 .39118 Metetra
.905 .495 .176 r
.27195 .57523 .27929 .58169 .28873 .60385 .28123 .59927 Metetra
.48 0 0 r
.28123 .59927 .28873 .60385 .29941 .61035 .29184 .60694 Metetra
.661 .858 .975 r
.29184 .60694 .29941 .61035 .31091 .6055 .30334 .60274 Metetra
.857 .864 .845 r
.30334 .60274 .31091 .6055 .3229 .59315 .31537 .59067 Metetra
.895 .847 .789 r
.31537 .59067 .3229 .59315 .33511 .57655 .32766 .57413 Metetra
.906 .841 .77 r
.32766 .57413 .33511 .57655 .34738 .55828 .34 .55583 Metetra
.905 .843 .772 r
.34 .55583 .34738 .55828 .35958 .5403 .35227 .53781 Metetra
.897 .853 .791 r
.35227 .53781 .35958 .5403 .37165 .52404 .36442 .52156 Metetra
.878 .871 .826 r
.36442 .52156 .37165 .52404 .38358 .51043 .3764 .50806 Metetra
.837 .896 .881 r
.3764 .50806 .38358 .51043 .39536 .50003 .38823 .4979 Metetra
.742 .916 .951 r
.38823 .4979 .39536 .50003 .40702 .49309 .39993 .49134 Metetra
.513 .872 .985 r
.39993 .49134 .40702 .49309 .41859 .48961 .41154 .48837 Metetra
.083 .633 .826 r
.41154 .48837 .41859 .48961 .43013 .48937 .4231 .48877 Metetra
.327 0 0 r
.4231 .48877 .43013 .48937 .44166 .49202 .43465 .49217 Metetra
.544 0 0 r
.43465 .49217 .44166 .49202 .45324 .49706 .44625 .49806 Metetra
.64 .102 0 r
.44625 .49806 .45324 .49706 .4649 .50393 .45793 .50584 Metetra
.68 .17 .018 r
.45793 .50584 .4649 .50393 .47667 .51199 .46973 .51483 Metetra
.692 .199 .071 r
.46973 .51483 .47667 .51199 .48858 .52055 .48166 .52432 Metetra
.684 .202 .099 r
.48166 .52432 .48858 .52055 .50062 .52893 .49375 .53359 Metetra
.662 .185 .109 r
.49375 .53359 .50062 .52893 .51282 .53648 .50599 .54196 Metetra
.624 .147 .103 r
.50599 .54196 .51282 .53648 .52515 .54259 .51838 .54876 Metetra
.566 .088 .08 r
.51838 .54876 .52515 .54259 .5376 .54673 .5309 .55346 Metetra
.483 .002 .039 r
.5309 .55346 .5376 .54673 .55014 .54847 .54353 .55557 Metetra
.365 0 0 r
.54353 .55557 .55014 .54847 .56276 .54751 .55623 .5548 Metetra
.204 0 0 r
.55623 .5548 .56276 .54751 .57541 .5437 .56898 .55097 Metetra
.56898 .55097 .57541 .5437 .58807 .53701 .58173 .54407 Metetra
.58173 .54407 .58807 .53701 .6007 .5276 .59446 .53424 Metetra
.59446 .53424 .6007 .5276 .61329 .51575 .60714 .5218 Metetra
.623 .881 .546 r
.60714 .5218 .61329 .51575 .62581 .50187 .61975 .50718 Metetra
.743 .939 .607 r
.61975 .50718 .62581 .50187 .63826 .48648 .63228 .49093 Metetra
.818 .967 .651 r
.63228 .49093 .63826 .48648 .65064 .4702 .64474 .47371 Metetra
.862 .98 .687 r
.64474 .47371 .65064 .4702 .66298 .45369 .65715 .45621 Metetra
.883 .987 .722 r
.65715 .45621 .66298 .45369 .6753 .43765 .66953 .43916 Metetra
.886 .991 .761 r
.66953 .43916 .6753 .43765 .68764 .42276 .68192 .42331 Metetra
.869 .994 .807 r
.68192 .42331 .68764 .42276 .70005 .4097 .69438 .40933 Metetra
.828 .992 .862 r
.69438 .40933 .70005 .4097 .71259 .39905 .70695 .39785 Metetra
.746 .975 .923 r
.70695 .39785 .71259 .39905 .72532 .39133 .71972 .38943 Metetra
.597 .919 .972 r
.71972 .38943 .72532 .39133 .7383 .38693 .73273 .38445 Metetra
.36 .789 .97 r
.73273 .38445 .7383 .38693 .7516 .38609 .74605 .38316 Metetra
.068 .582 .881 r
.74605 .38316 .7516 .38609 .76524 .38882 .75973 .3856 Metetra
0 .361 .738 r
.75973 .3856 .76524 .38882 .77928 .39491 .7738 .39151 Metetra
0 .195 .609 r
.7738 .39151 .77928 .39491 .79369 .4038 .78825 .40033 Metetra
.45 0 0 r
.78825 .40033 .79369 .4038 .80845 .41452 .80305 .41104 Metetra
.457 0 0 r
.80305 .41104 .80845 .41452 .82343 .42562 .81807 .42212 Metetra
0 .197 .618 r
.81807 .42212 .82343 .42562 .83845 .43506 .83313 .43143 Metetra
0 .481 .842 r
.83313 .43143 .83845 .43506 .85321 .44009 .84791 .43612 Metetra
.569 .853 .997 r
.84791 .43612 .85321 .44009 .8673 .43728 .86199 .43257 Metetra
.904 .897 .811 r
.86199 .43257 .8673 .43728 .88017 .42251 .8748 .4165 Metetra
.973 .822 .633 r
.8748 .4165 .88017 .42251 .89112 .39118 .88562 .38313 Metetra
.913 .513 .207 r
.26456 .56873 .27195 .57523 .28123 .59927 .27367 .59456 Metetra
.564 .006 0 r
.27367 .59456 .28123 .59927 .29184 .60694 .28421 .60337 Metetra
.63 .847 .983 r
.28421 .60337 .29184 .60694 .30334 .60274 .29571 .59979 Metetra
.852 .862 .848 r
.29571 .59979 .30334 .60274 .31537 .59067 .30778 .588 Metetra
.893 .844 .789 r
.30778 .588 .31537 .59067 .32766 .57413 .32013 .57153 Metetra
.904 .838 .77 r
.32013 .57153 .32766 .57413 .34 .55583 .33255 .55319 Metetra
.903 .84 .772 r
.33255 .55319 .34 .55583 .35227 .53781 .3449 .53514 Metetra
.895 .85 .791 r
.3449 .53514 .35227 .53781 .36442 .52156 .35711 .5189 Metetra
.875 .868 .828 r
.35711 .5189 .36442 .52156 .3764 .50806 .36916 .50552 Metetra
.831 .893 .885 r
.36916 .50552 .3764 .50806 .38823 .4979 .38104 .49559 Metetra
.729 .911 .957 r
.38104 .49559 .38823 .4979 .39993 .49134 .39277 .4894 Metetra
.478 .853 .985 r
.39277 .4894 .39993 .49134 .41154 .48837 .40441 .48692 Metetra
.024 .586 .802 r
.40441 .48692 .41154 .48837 .4231 .48877 .41599 .48794 Metetra
.375 0 0 r
.41599 .48794 .4231 .48877 .43465 .49217 .42756 .49207 Metetra
.576 .006 0 r
.42756 .49207 .43465 .49217 .44625 .49806 .43917 .49877 Metetra
.664 .13 0 r
.43917 .49877 .44625 .49806 .45793 .50584 .45087 .50742 Metetra
.7 .192 .026 r
.45087 .50742 .45793 .50584 .46973 .51483 .46269 .51732 Metetra
.709 .218 .075 r
.46269 .51732 .46973 .51483 .48166 .52432 .47465 .52771 Metetra
.701 .218 .099 r
.47465 .52771 .48166 .52432 .49375 .53359 .48677 .53785 Metetra
.677 .198 .105 r
.48677 .53785 .49375 .53359 .50599 .54196 .49906 .547 Metetra
.637 .156 .095 r
.49906 .547 .50599 .54196 .51838 .54876 .51151 .55448 Metetra
.576 .092 .067 r
.51151 .55448 .51838 .54876 .5309 .55346 .5241 .5597 Metetra
.487 0 .018 r
.5241 .5597 .5309 .55346 .54353 .55557 .5368 .56219 Metetra
.357 0 0 r
.5368 .56219 .54353 .55557 .55623 .5548 .54959 .5616 Metetra
.175 0 0 r
.54959 .5616 .55623 .5548 .56898 .55097 .56243 .55775 Metetra
.56243 .55775 .56898 .55097 .58173 .54407 .57528 .55063 Metetra
.57528 .55063 .58173 .54407 .59446 .53424 .5881 .54041 Metetra
.532 .838 .522 r
.5881 .54041 .59446 .53424 .60714 .5218 .60088 .52739 Metetra
.694 .922 .594 r
.60088 .52739 .60714 .5218 .61975 .50718 .61358 .51204 Metetra
.798 .961 .64 r
.61358 .51204 .61975 .50718 .63228 .49093 .6262 .49496 Metetra
.859 .976 .672 r
.6262 .49496 .63228 .49093 .64474 .47371 .63874 .47682 Metetra
.893 .981 .699 r
.63874 .47682 .64474 .47371 .65715 .45621 .65122 .45836 Metetra
.907 .982 .727 r
.65122 .45836 .65715 .45621 .66953 .43916 .66366 .44035 Metetra
.907 .984 .76 r
.66366 .44035 .66953 .43916 .68192 .42331 .67611 .42355 Metetra
.89 .986 .803 r
.67611 .42355 .68192 .42331 .69438 .40933 .68861 .40868 Metetra
.852 .985 .856 r
.68861 .40868 .69438 .40933 .70695 .39785 .70123 .39642 Metetra
.776 .974 .917 r
.70123 .39642 .70695 .39785 .71972 .38943 .71403 .3873 Metetra
.637 .928 .972 r
.71403 .3873 .71972 .38943 .73273 .38445 .72707 .38176 Metetra
.407 .81 .982 r
.72707 .38176 .73273 .38445 .74605 .38316 .74042 .38004 Metetra
.109 .608 .903 r
.74042 .38004 .74605 .38316 .75973 .3856 .75414 .38218 Metetra
0 .382 .76 r
.75414 .38218 .75973 .3856 .7738 .39151 .76824 .38792 Metetra
0 .209 .627 r
.76824 .38792 .7738 .39151 .78825 .40033 .78273 .39666 Metetra
.436 0 0 r
.78273 .39666 .78825 .40033 .80305 .41104 .79757 .40735 Metetra
.443 0 0 r
.79757 .40735 .80305 .41104 .81807 .42212 .81264 .41841 Metetra
0 .214 .638 r
.81264 .41841 .81807 .42212 .83313 .43143 .82773 .4276 Metetra
.008 .508 .866 r
.82773 .4276 .83313 .43143 .84791 .43612 .84254 .43193 Metetra
.609 .864 .991 r
.84254 .43193 .84791 .43612 .86199 .43257 .85661 .42767 Metetra
.914 .89 .794 r
.85661 .42767 .86199 .43257 .8748 .4165 .86937 .41034 Metetra
.975 .817 .622 r
.86937 .41034 .8748 .4165 .88562 .38313 .88007 .37501 Metetra
.919 .528 .231 r
.25711 .56217 .26456 .56873 .27367 .59456 .26604 .58969 Metetra
.625 .077 0 r
.26604 .58969 .27367 .59456 .28421 .60337 .27651 .59955 Metetra
.6 .832 .988 r
.27651 .59955 .28421 .60337 .29571 .59979 .28801 .59654 Metetra
.846 .856 .85 r
.28801 .59654 .29571 .59979 .30778 .588 .30013 .58498 Metetra
.889 .838 .789 r
.30013 .58498 .30778 .588 .32013 .57153 .31254 .56855 Metetra
.9 .831 .769 r
.31254 .56855 .32013 .57153 .33255 .55319 .32504 .55016 Metetra
.9 .833 .771 r
.32504 .55016 .33255 .55319 .3449 .53514 .33747 .53205 Metetra
.891 .842 .79 r
.33747 .53205 .3449 .53514 .35711 .5189 .34976 .51581 Metetra
.87 .858 .827 r
.34976 .51581 .35711 .5189 .36916 .50552 .36186 .50251 Metetra
.825 .88 .885 r
.36186 .50251 .36916 .50552 .38104 .49559 .37379 .49278 Metetra
.72 .894 .959 r
.37379 .49278 .38104 .49559 .39277 .4894 .38556 .48691 Metetra
.467 .833 .993 r
.38556 .48691 .39277 .4894 .40441 .48692 .39722 .48488 Metetra
.012 .567 .819 r
.39722 .48488 .40441 .48692 .41599 .48794 .40882 .48647 Metetra
.389 0 0 r
.40882 .48647 .41599 .48794 .42756 .49207 .4204 .49127 Metetra
.591 .02 0 r
.4204 .49127 .42756 .49207 .43917 .49877 .43203 .49873 Metetra
.679 .143 0 r
.43203 .49873 .43917 .49877 .45087 .50742 .44373 .5082 Metetra
.715 .203 .007 r
.44373 .5082 .45087 .50742 .46269 .51732 .45557 .51893 Metetra
.724 .227 .054 r
.45557 .51893 .46269 .51732 .47465 .52771 .46755 .53017 Metetra
.716 .225 .076 r
.46755 .53017 .47465 .52771 .48677 .53785 .4797 .54112 Metetra
.691 .201 .078 r
.4797 .54112 .48677 .53785 .49906 .547 .49203 .55101 Metetra
.649 .154 .062 r
.49203 .55101 .49906 .547 .51151 .55448 .50453 .55913 Metetra
.582 .079 .024 r
.50453 .55913 .51151 .55448 .5241 .5597 .51718 .56486 Metetra
.48 0 0 r
.51718 .56486 .5241 .5597 .5368 .56219 .52996 .56769 Metetra
.326 0 0 r
.52996 .56769 .5368 .56219 .54959 .5616 .54283 .56727 Metetra
.106 0 0 r
.54283 .56727 .54959 .5616 .56243 .55775 .55575 .5634 Metetra
.55575 .5634 .56243 .55775 .57528 .55063 .5687 .55608 Metetra
.5687 .55608 .57528 .55063 .5881 .54041 .58162 .54547 Metetra
.655 .921 .625 r
.58162 .54547 .5881 .54041 .60088 .52739 .59449 .5319 Metetra
.788 .969 .668 r
.59449 .5319 .60088 .52739 .61358 .51204 .60728 .51588 Metetra
.864 .981 .69 r
.60728 .51588 .61358 .51204 .6262 .49496 .61999 .498 Metetra
.905 .98 .705 r
.61999 .498 .6262 .49496 .63874 .47682 .63261 .47899 Metetra
.925 .974 .72 r
.63261 .47899 .63874 .47682 .65122 .45836 .64517 .45962 Metetra
.931 .97 .739 r
.64517 .45962 .65122 .45836 .66366 .44035 .65768 .4407 Metetra
.926 .968 .766 r
.65768 .4407 .66366 .44035 .67611 .42355 .67018 .42301 Metetra
.909 .968 .803 r
.67018 .42301 .67611 .42355 .68861 .40868 .68274 .40732 Metetra
.873 .968 .852 r
.68274 .40732 .68861 .40868 .70123 .39642 .6954 .39431 Metetra
.805 .959 .912 r
.6954 .39431 .70123 .39642 .71403 .3873 .70824 .38456 Metetra
.68 .923 .972 r
.70824 .38456 .71403 .3873 .72707 .38176 .72132 .3785 Metetra
.467 .824 .996 r
.72132 .3785 .72707 .38176 .74042 .38004 .7347 .37639 Metetra
.175 .637 .936 r
.7347 .37639 .74042 .38004 .75414 .38218 .74845 .37826 Metetra
0 .413 .801 r
.74845 .37826 .75414 .38218 .76824 .38792 .76259 .38386 Metetra
0 .234 .664 r
.76259 .38386 .76824 .38792 .78273 .39666 .77712 .39255 Metetra
0 .136 .58 r
.77712 .39255 .78273 .39666 .79757 .40735 .792 .40324 Metetra
0 .127 .573 r
.792 .40324 .79757 .40735 .81264 .41841 .80711 .4143 Metetra
0 .237 .671 r
.80711 .4143 .81264 .41841 .82773 .4276 .82224 .42338 Metetra
.06 .536 .893 r
.82224 .42338 .82773 .4276 .84254 .43193 .83707 .42741 Metetra
.644 .867 .983 r
.83707 .42741 .84254 .43193 .85661 .42767 .85115 .42248 Metetra
.921 .881 .779 r
.85115 .42248 .85661 .42767 .86937 .41034 .86386 .40398 Metetra
.977 .811 .612 r
.86386 .40398 .86937 .41034 .88007 .37501 .87448 .36682 Metetra
.923 .539 .249 r
.2496 .55556 .25711 .56217 .26604 .58969 .25837 .5846 Metetra
.668 .13 0 r
.25837 .5846 .26604 .58969 .27651 .59955 .26877 .5954 Metetra
.576 .815 .989 r
.26877 .5954 .27651 .59955 .28801 .59654 .28026 .59287 Metetra
.84 .846 .85 r
.28026 .59287 .28801 .59654 .30013 .58498 .29242 .58149 Metetra
.884 .829 .787 r
.29242 .58149 .30013 .58498 .31254 .56855 .30491 .56503 Metetra
.895 .821 .766 r
.30491 .56503 .31254 .56855 .32504 .55016 .31749 .54654 Metetra
.894 .821 .768 r
.31749 .54654 .32504 .55016 .33747 .53205 .33 .52832 Metetra
.884 .828 .787 r
.33 .52832 .33747 .53205 .34976 .51581 .34236 .51203 Metetra
.862 .842 .823 r
.34236 .51203 .34976 .51581 .36186 .50251 .35452 .49876 Metetra
.817 .859 .879 r
.35452 .49876 .36186 .50251 .37379 .49278 .3665 .48917 Metetra
.715 .867 .954 r
.3665 .48917 .37379 .49278 .38556 .48691 .3783 .48355 Metetra
.478 .81 1 r
.3783 .48355 .38556 .48691 .39722 .48488 .38999 .4819 Metetra
.044 .57 .865 r
.38999 .4819 .39722 .48488 .40882 .48647 .4016 .48398 Metetra
.369 0 0 r
.4016 .48398 .40882 .48647 .4204 .49127 .41319 .48937 Metetra
.588 .013 0 r
.41319 .48937 .4204 .49127 .43203 .49873 .42482 .49751 Metetra
.684 .14 0 r
.42482 .49751 .43203 .49873 .44373 .5082 .43654 .5077 Metetra
.724 .203 0 r
.43654 .5077 .44373 .5082 .45557 .51893 .44838 .5192 Metetra
.735 .226 .009 r
.44838 .5192 .45557 .51893 .46755 .53017 .46038 .53121 Metetra
.727 .222 .028 r
.46038 .53121 .46755 .53017 .4797 .54112 .47255 .54289 Metetra
.702 .194 .024 r
.47255 .54289 .4797 .54112 .49203 .55101 .48492 .55346 Metetra
.656 .139 0 r
.48492 .55346 .49203 .55101 .50453 .55913 .49746 .56216 Metetra
.58 .048 0 r
.49746 .56216 .50453 .55913 .51718 .56486 .51016 .56835 Metetra
.456 0 0 r
.51016 .56835 .51718 .56486 .52996 .56769 .523 .57149 Metetra
.259 0 0 r
.523 .57149 .52996 .56769 .54283 .56727 .53595 .57122 Metetra
.53595 .57122 .54283 .56727 .55575 .5634 .54896 .56733 Metetra
.54896 .56733 .55575 .5634 .5687 .55608 .56199 .55982 Metetra
.619 .934 .704 r
.56199 .55982 .5687 .55608 .58162 .54547 .575 .54885 Metetra
.783 .986 .736 r
.575 .54885 .58162 .54547 .59449 .5319 .58796 .53478 Metetra
.871 .991 .739 r
.58796 .53478 .59449 .5319 .60728 .51588 .60085 .51812 Metetra
.916 .98 .735 r
.60085 .51812 .60728 .51588 .61999 .498 .61365 .49951 Metetra
.937 .965 .734 r
.61365 .49951 .61999 .498 .63261 .47899 .62635 .47971 Metetra
.946 .953 .738 r
.62635 .47971 .63261 .47899 .64517 .45962 .63898 .45951 Metetra
.945 .944 .75 r
.63898 .45951 .64517 .45962 .65768 .4407 .65156 .43976 Metetra
.937 .939 .77 r
.65156 .43976 .65768 .4407 .67018 .42301 .66413 .42127 Metetra
.918 .938 .802 r
.66413 .42127 .67018 .42301 .68274 .40732 .67673 .40484 Metetra
.885 .936 .845 r
.67673 .40484 .68274 .40732 .6954 .39431 .68945 .39116 Metetra
.825 .93 .901 r
.68945 .39116 .6954 .39431 .70824 .38456 .70233 .38085 Metetra
.715 .901 .962 r
.70233 .38085 .70824 .38456 .72132 .3785 .71544 .37434 Metetra
.526 .821 .999 r
.71544 .37434 .72132 .3785 .7347 .37639 .72887 .3719 Metetra
.252 .659 .964 r
.72887 .3719 .7347 .37639 .74845 .37826 .74265 .37357 Metetra
0 .447 .847 r
.74265 .37357 .74845 .37826 .76259 .38386 .75683 .37907 Metetra
0 .266 .712 r
.75683 .37907 .76259 .38386 .77712 .39255 .7714 .38776 Metetra
0 .162 .624 r
.7714 .38776 .77712 .39255 .792 .40324 .78632 .3985 Metetra
0 .151 .614 r
.78632 .3985 .792 .40324 .80711 .4143 .80147 .4096 Metetra
0 .264 .709 r
.80147 .4096 .80711 .4143 .82224 .42338 .81664 .41865 Metetra
.115 .56 .918 r
.81664 .41865 .82224 .42338 .83707 .42741 .8315 .42243 Metetra
.672 .862 .972 r
.8315 .42243 .83707 .42741 .85115 .42248 .84559 .41694 Metetra
.925 .872 .766 r
.84559 .41694 .85115 .42248 .86386 .40398 .85829 .39739 Metetra
.978 .806 .603 r
.85829 .39739 .86386 .40398 .87448 .36682 .86883 .35855 Metetra
.926 .548 .264 r
.24203 .5489 .2496 .55556 .25837 .5846 .25064 .57928 Metetra
.696 .168 0 r
.25064 .57928 .25837 .5846 .26877 .5954 .26097 .59086 Metetra
.561 .798 .988 r
.26097 .59086 .26877 .5954 .28026 .59287 .27248 .5887 Metetra
.834 .834 .847 r
.27248 .5887 .28026 .59287 .29242 .58149 .28469 .57738 Metetra
.879 .817 .783 r
.28469 .57738 .29242 .58149 .30491 .56503 .29725 .56083 Metetra
.889 .808 .763 r
.29725 .56083 .30491 .56503 .31749 .54654 .30991 .54217 Metetra
.888 .807 .764 r
.30991 .54217 .31749 .54654 .33 .52832 .3225 .52377 Metetra
.877 .812 .781 r
.3225 .52377 .33 .52832 .34236 .51203 .33493 .50734 Metetra
.854 .821 .816 r
.33493 .50734 .34236 .51203 .35452 .49876 .34716 .49403 Metetra
.808 .831 .869 r
.34716 .49403 .35452 .49876 .3665 .48917 .35918 .4845 Metetra
.711 .833 .94 r
.35918 .4845 .3665 .48917 .3783 .48355 .37103 .47906 Metetra
.501 .78 .995 r
.37103 .47906 .3783 .48355 .38999 .4819 .38273 .47769 Metetra
.111 .58 .914 r
.38273 .47769 .38999 .4819 .4016 .48398 .39436 .48016 Metetra
0 .263 .646 r
.39436 .48016 .4016 .48398 .41319 .48937 .40596 .48604 Metetra
.556 0 0 r
.40596 .48604 .41319 .48937 .42482 .49751 .41759 .49473 Metetra
.671 .121 0 r
.41759 .49473 .42482 .49751 .43654 .5077 .4293 .50555 Metetra
.721 .189 0 r
.4293 .50555 .43654 .5077 .44838 .5192 .44115 .51771 Metetra
.737 .214 0 r
.44115 .51771 .44838 .5192 .46038 .53121 .45315 .53037 Metetra
.73 .208 0 r
.45315 .53037 .46038 .53121 .47255 .54289 .46534 .5427 Metetra
.703 .173 0 r
.46534 .5427 .47255 .54289 .48492 .55346 .47773 .55385 Metetra
.65 .104 0 r
.47773 .55385 .48492 .55346 .49746 .56216 .4903 .56306 Metetra
.556 0 0 r
.4903 .56306 .49746 .56216 .51016 .56835 .50305 .56964 Metetra
.393 0 0 r
.50305 .56964 .51016 .56835 .523 .57149 .51595 .57306 Metetra
.123 0 0 r
.51595 .57306 .523 .57149 .53595 .57122 .52896 .57292 Metetra
.241 .75 .722 r
.52896 .57292 .53595 .57122 .54896 .56733 .54205 .56901 Metetra
.569 .938 .826 r
.54205 .56901 .54896 .56733 .56199 .55982 .55516 .56132 Metetra
.77 .997 .836 r
.55516 .56132 .56199 .55982 .575 .54885 .56826 .55003 Metetra
.869 .993 .811 r
.56826 .55003 .575 .54885 .58796 .53478 .58131 .5355 Metetra
.917 .971 .783 r
.58131 .5355 .58796 .53478 .60085 .51812 .59428 .51828 Metetra
.939 .949 .762 r
.59428 .51828 .60085 .51812 .61365 .49951 .60716 .49903 Metetra
.948 .93 .75 r
.60716 .49903 .61365 .49951 .62635 .47971 .61995 .47852 Metetra
.949 .916 .747 r
.61995 .47852 .62635 .47971 .63898 .45951 .63266 .4576 Metetra
.944 .906 .753 r
.63266 .4576 .63898 .45951 .65156 .43976 .6453 .43712 Metetra
.934 .9 .769 r
.6453 .43712 .65156 .43976 .66413 .42127 .65793 .41794 Metetra
.915 .897 .795 r
.65793 .41794 .66413 .42127 .67673 .40484 .6706 .40087 Metetra
.884 .895 .833 r
.6706 .40087 .67673 .40484 .68945 .39116 .68336 .38664 Metetra
.83 .887 .884 r
.68336 .38664 .68945 .39116 .70233 .38085 .69628 .37586 Metetra
.734 .863 .941 r
.69628 .37586 .70233 .38085 .71544 .37434 .70944 .36899 Metetra
.57 .798 .985 r
.70944 .36899 .71544 .37434 .72887 .3719 .7229 .36632 Metetra
.323 .663 .974 r
.7229 .36632 .72887 .3719 .74265 .37357 .73673 .36786 Metetra
.043 .473 .883 r
.73673 .36786 .74265 .37357 .75683 .37907 .75094 .37334 Metetra
0 .297 .759 r
.75094 .37334 .75683 .37907 .7714 .38776 .76555 .3821 Metetra
0 .19 .671 r
.76555 .3821 .7714 .38776 .78632 .3985 .78052 .39296 Metetra
0 .177 .657 r
.78052 .39296 .78632 .3985 .80147 .4096 .79571 .40418 Metetra
0 .288 .747 r
.79571 .40418 .80147 .4096 .81664 .41865 .81093 .41326 Metetra
.167 .575 .935 r
.81093 .41326 .81664 .41865 .8315 .42243 .82583 .41691 Metetra
.691 .852 .96 r
.82583 .41691 .8315 .42243 .84559 .41694 .83995 .41097 Metetra
.927 .861 .756 r
.83995 .41097 .84559 .41694 .85829 .39739 .85264 .39053 Metetra
.978 .801 .597 r
.85264 .39053 .85829 .39739 .86883 .35855 .86314 .35021 Metetra
.928 .554 .275 r
.23439 .54218 .24203 .5489 .25064 .57928 .24285 .57369 Metetra
.714 .192 0 r
.24285 .57369 .25064 .57928 .26097 .59086 .25314 .58588 Metetra
.555 .782 .984 r
.25314 .58588 .26097 .59086 .27248 .5887 .26465 .58394 Metetra
.829 .82 .841 r
.26465 .58394 .27248 .5887 .28469 .57738 .27692 .57258 Metetra
.873 .803 .778 r
.27692 .57258 .28469 .57738 .29725 .56083 .28956 .55583 Metetra
.883 .794 .757 r
.28956 .55583 .29725 .56083 .30991 .54217 .30231 .5369 Metetra
.88 .791 .758 r
.30231 .5369 .30991 .54217 .3225 .52377 .31499 .51824 Metetra
.868 .793 .774 r
.31499 .51824 .3225 .52377 .33493 .50734 .3275 .5016 Metetra
.844 .797 .805 r
.3275 .5016 .33493 .50734 .34716 .49403 .33979 .48815 Metetra
.798 .8 .854 r
.33979 .48815 .34716 .49403 .35918 .4845 .35186 .47858 Metetra
.708 .793 .917 r
.35186 .47858 .35918 .4845 .37103 .47906 .36374 .4732 Metetra
.526 .743 .974 r
.36374 .4732 .37103 .47906 .38273 .47769 .37547 .472 Metetra
.195 .583 .942 r
.37547 .472 .38273 .47769 .39436 .48016 .3871 .47475 Metetra
0 .312 .746 r
.3871 .47475 .39436 .48016 .40596 .48604 .39871 .48098 Metetra
.482 0 0 r
.39871 .48098 .40596 .48604 .41759 .49473 .41034 .49011 Metetra
.626 .081 0 r
.41034 .49011 .41759 .49473 .4293 .50555 .42205 .50142 Metetra
.692 .157 0 r
.42205 .50142 .4293 .50555 .44115 .51771 .43388 .5141 Metetra
.716 .184 0 r
.43388 .5141 .44115 .51771 .45315 .53037 .44589 .52731 Metetra
.711 .175 0 r
.44589 .52731 .45315 .53037 .46534 .5427 .45809 .54015 Metetra
.679 .131 0 r
.45809 .54015 .46534 .5427 .47773 .55385 .47048 .55179 Metetra
.61 .042 0 r
.47048 .55179 .47773 .55385 .4903 .56306 .48308 .56142 Metetra
.481 0 0 r
.48308 .56142 .4903 .56306 .50305 .56964 .49587 .56834 Metetra
.249 0 0 r
.49587 .56834 .50305 .56964 .51595 .57306 .50881 .57198 Metetra
.107 .654 .825 r
.50881 .57198 .51595 .57306 .52896 .57292 .52188 .57194 Metetra
.477 .883 .946 r
.52188 .57194 .52896 .57292 .54205 .56901 .53503 .568 Metetra
.719 .965 .939 r
.53503 .568 .54205 .56901 .55516 .56132 .54821 .56015 Metetra
.839 .966 .885 r
.54821 .56015 .55516 .56132 .56826 .55003 .56139 .54858 Metetra
.895 .943 .833 r
.56139 .54858 .56826 .55003 .58131 .5355 .57452 .53367 Metetra
.922 .919 .794 r
.57452 .53367 .58131 .5355 .59428 .51828 .58758 .51597 Metetra
.934 .898 .767 r
.58758 .51597 .59428 .51828 .60716 .49903 .60054 .49617 Metetra
.938 .882 .752 r
.60054 .49617 .60716 .49903 .61995 .47852 .61341 .47507 Metetra
.937 .87 .746 r
.61341 .47507 .61995 .47852 .63266 .4576 .62619 .45354 Metetra
.931 .861 .75 r
.62619 .45354 .63266 .4576 .6453 .43712 .6389 .43246 Metetra
.92 .856 .762 r
.6389 .43246 .6453 .43712 .65793 .41794 .65159 .41272 Metetra
.902 .852 .784 r
.65159 .41272 .65793 .41794 .6706 .40087 .66432 .39514 Metetra
.872 .848 .816 r
.66432 .39514 .6706 .40087 .68336 .38664 .67713 .38047 Metetra
.823 .839 .861 r
.67713 .38047 .68336 .38664 .69628 .37586 .6901 .36935 Metetra
.739 .817 .913 r
.6901 .36935 .69628 .37586 .70944 .36899 .7033 .36224 Metetra
.596 .762 .958 r
.7033 .36224 .70944 .36899 .7229 .36632 .7168 .35943 Metetra
.379 .651 .963 r
.7168 .35943 .7229 .36632 .73673 .36786 .73066 .36095 Metetra
.117 .486 .9 r
.73066 .36095 .73673 .36786 .75094 .37334 .74492 .3665 Metetra
0 .321 .795 r
.74492 .3665 .75094 .37334 .76555 .3821 .75958 .37541 Metetra
0 .215 .711 r
.75958 .37541 .76555 .3821 .78052 .39296 .77459 .38648 Metetra
0 .2 .695 r
.77459 .38648 .78052 .39296 .79571 .40418 .78983 .39791 Metetra
0 .308 .777 r
.78983 .39791 .79571 .40418 .81093 .41326 .8051 .40713 Metetra
.211 .581 .943 r
.8051 .40713 .81093 .41326 .82583 .41691 .82005 .41076 Metetra
.703 .837 .947 r
.82005 .41076 .82583 .41691 .83995 .41097 .8342 .40451 Metetra
.927 .851 .748 r
.8342 .40451 .83995 .41097 .85264 .39053 .84691 .38336 Metetra
.978 .797 .592 r
.84691 .38336 .85264 .39053 .86314 .35021 .85739 .3418 Metetra
.929 .559 .283 r
.2267 .53541 .23439 .54218 .24285 .57369 .23502 .5678 Metetra
.723 .206 0 r
.23502 .5678 .24285 .57369 .25314 .58588 .24526 .58041 Metetra
.559 .768 .976 r
.24526 .58041 .25314 .58588 .26465 .58394 .2568 .57853 Metetra
.825 .805 .832 r
.2568 .57853 .26465 .58394 .27692 .57258 .26914 .56701 Metetra
.867 .789 .771 r
.26914 .56701 .27692 .57258 .28956 .55583 .28187 .54994 Metetra
.876 .779 .751 r
.28187 .54994 .28956 .55583 .30231 .5369 .29471 .53065 Metetra
.872 .775 .751 r
.29471 .53065 .30231 .5369 .31499 .51824 .30748 .51163 Metetra
.859 .773 .765 r
.30748 .51163 .31499 .51824 .3275 .5016 .32007 .49467 Metetra
.834 .772 .793 r
.32007 .49467 .3275 .5016 .33979 .48815 .33243 .48099 Metetra
.788 .769 .836 r
.33243 .48099 .33979 .48815 .35186 .47858 .34455 .47127 Metetra
.704 .754 .891 r
.34455 .47127 .35186 .47858 .36374 .4732 .35646 .46584 Metetra
.547 .703 .943 r
.35646 .46584 .36374 .4732 .37547 .472 .36821 .46469 Metetra
.277 .575 .939 r
.36821 .46469 .37547 .472 .3871 .47475 .37986 .46757 Metetra
0 .356 .818 r
.37986 .46757 .3871 .47475 .39871 .48098 .39146 .47402 Metetra
0 .133 .626 r
.39146 .47402 .39871 .48098 .41034 .49011 .40308 .48344 Metetra
.535 .021 0 r
.40308 .48344 .41034 .49011 .42205 .50142 .41478 .49509 Metetra
.62 .103 0 r
.41478 .49509 .42205 .50142 .43388 .5141 .42661 .50816 Metetra
.652 .132 0 r
.42661 .50816 .43388 .5141 .44589 .52731 .43861 .52176 Metetra
.646 .118 0 r
.43861 .52176 .44589 .52731 .45809 .54015 .4508 .535 Metetra
.6 .06 0 r
.4508 .535 .45809 .54015 .47048 .55179 .46321 .547 Metetra
.5 0 0 r
.46321 .547 .47048 .55179 .48308 .56142 .47582 .55694 Metetra
0 .242 .651 r
.47582 .55694 .48308 .56142 .49587 .56834 .48863 .56411 Metetra
0 .497 .852 r
.48863 .56411 .49587 .56834 .50881 .57198 .5016 .56792 Metetra
.337 .733 .983 r
.5016 .56792 .50881 .57198 .52188 .57194 .51472 .56795 Metetra
.609 .857 .99 r
.51472 .56795 .52188 .57194 .53503 .568 .52792 .56398 Metetra
.763 .889 .934 r
.52792 .56398 .53503 .568 .54821 .56015 .54116 .556 Metetra
.842 .885 .872 r
.54116 .556 .54821 .56015 .56139 .54858 .55441 .5442 Metetra
.882 .87 .821 r
.55441 .5442 .56139 .54858 .57452 .53367 .56762 .52897 Metetra
.903 .854 .784 r
.56762 .52897 .57452 .53367 .58758 .51597 .58075 .51089 Metetra
.913 .841 .76 r
.58075 .51089 .58758 .51597 .60054 .49617 .59379 .49065 Metetra
.917 .83 .745 r
.59379 .49065 .60054 .49617 .61341 .47507 .60673 .46909 Metetra
.916 .822 .739 r
.60673 .46909 .61341 .47507 .62619 .45354 .61958 .44709 Metetra
.91 .815 .741 r
.61958 .44709 .62619 .45354 .6389 .43246 .63236 .42555 Metetra
.9 .811 .751 r
.63236 .42555 .6389 .43246 .65159 .41272 .64511 .40539 Metetra
.882 .806 .77 r
.64511 .40539 .65159 .41272 .66432 .39514 .65789 .38745 Metetra
.854 .801 .798 r
.65789 .38745 .66432 .39514 .67713 .38047 .67076 .37249 Metetra
.809 .791 .836 r
.67076 .37249 .67713 .38047 .6901 .36935 .68377 .36116 Metetra
.733 .769 .882 r
.68377 .36116 .6901 .36935 .7033 .36224 .69702 .35393 Metetra
.607 .721 .925 r
.69702 .35393 .7033 .36224 .7168 .35943 .71056 .3511 Metetra
.417 .627 .94 r
.71056 .3511 .7168 .35943 .73066 .36095 .72447 .3527 Metetra
.179 .485 .9 r
.72447 .3527 .73066 .36095 .74492 .3665 .73876 .35843 Metetra
0 .336 .816 r
.73876 .35843 .74492 .3665 .75958 .37541 .75346 .36759 Metetra
0 .234 .74 r
.75346 .36759 .75958 .37541 .77459 .38648 .76852 .37896 Metetra
0 .217 .723 r
.76852 .37896 .77459 .38648 .78983 .39791 .78382 .39069 Metetra
0 .319 .797 r
.78382 .39069 .78983 .39791 .8051 .40713 .79914 .40017 Metetra
.245 .576 .942 r
.79914 .40017 .8051 .40713 .82005 .41076 .81415 .40391 Metetra
.707 .818 .934 r
.81415 .40391 .82005 .41076 .8342 .40451 .82835 .39753 Metetra
.925 .841 .743 r
.82835 .39753 .8342 .40451 .84691 .38336 .8411 .37586 Metetra
.977 .793 .589 r
.8411 .37586 .84691 .38336 .85739 .3418 .85159 .33331 Metetra
.93 .562 .289 r
.21894 .52858 .2267 .53541 .23502 .5678 .22715 .5616 Metetra
.722 .208 0 r
.22715 .5616 .23502 .5678 .24526 .58041 .23736 .57443 Metetra
.571 .757 .966 r
.23736 .57443 .24526 .58041 .2568 .57853 .24894 .57245 Metetra
.821 .79 .822 r
.24894 .57245 .2568 .57853 .26914 .56701 .26134 .56061 Metetra
.862 .774 .764 r
.26134 .56061 .26914 .56701 .28187 .54994 .27417 .54313 Metetra
.87 .764 .744 r
.27417 .54313 .28187 .54994 .29471 .53065 .28711 .52336 Metetra
.865 .758 .743 r
.28711 .52336 .29471 .53065 .30748 .51163 .29998 .50388 Metetra
.851 .754 .756 r
.29998 .50388 .30748 .51163 .32007 .49467 .31265 .48652 Metetra
.824 .749 .78 r
.31265 .48652 .32007 .49467 .33243 .48099 .32508 .47248 Metetra
.779 .74 .817 r
.32508 .47248 .33243 .48099 .34455 .47127 .33726 .46251 Metetra
.701 .718 .863 r
.33726 .46251 .34455 .47127 .35646 .46584 .34921 .4569 Metetra
.564 .667 .907 r
.34921 .4569 .35646 .46584 .36821 .46469 .36098 .45566 Metetra
.344 .559 .916 r
.36098 .45566 .36821 .46469 .37986 .46757 .37264 .45854 Metetra
.056 .387 .848 r
.37264 .45854 .37986 .46757 .39146 .47402 .38424 .46506 Metetra
0 .197 .716 r
.38424 .46506 .39146 .47402 .40308 .48344 .39585 .47462 Metetra
0 .053 .585 r
.39585 .47462 .40308 .48344 .41478 .49509 .40754 .48646 Metetra
0 0 .498 r
.40754 .48646 .41478 .49509 .42661 .50816 .41935 .49974 Metetra
0 0 .464 r
.41935 .49974 .42661 .50816 .43861 .52176 .43133 .51359 Metetra
0 0 .48 r
.43133 .51359 .43861 .52176 .4508 .535 .44351 .52708 Metetra
0 .033 .548 r
.44351 .52708 .4508 .535 .46321 .547 .45591 .53932 Metetra
0 .161 .664 r
.45591 .53932 .46321 .547 .47582 .55694 .46853 .54947 Metetra
0 .344 .81 r
.46853 .54947 .47582 .55694 .48863 .56411 .48135 .5568 Metetra
.199 .542 .928 r
.48135 .5568 .48863 .56411 .5016 .56792 .49435 .56072 Metetra
.462 .691 .966 r
.49435 .56072 .5016 .56792 .51472 .56795 .50749 .56078 Metetra
.645 .767 .937 r
.50749 .56078 .51472 .56795 .52792 .56398 .52073 .55678 Metetra
.755 .795 .886 r
.52073 .55678 .52792 .56398 .54116 .556 .53403 .54869 Metetra
.817 .801 .836 r
.53403 .54869 .54116 .556 .55441 .5442 .54734 .53672 Metetra
.853 .798 .796 r
.54734 .53672 .55441 .5442 .56762 .52897 .5606 .52125 Metetra
.874 .793 .767 r
.5606 .52125 .56762 .52897 .58075 .51089 .5738 .50288 Metetra
.886 .787 .746 r
.5738 .50288 .58075 .51089 .59379 .49065 .58691 .48234 Metetra
.891 .781 .734 r
.58691 .48234 .59379 .49065 .60673 .46909 .59992 .46045 Metetra
.891 .777 .728 r
.59992 .46045 .60673 .46909 .61958 .44709 .61284 .43812 Metetra
.887 .773 .73 r
.61284 .43812 .61958 .44709 .63236 .42555 .62568 .41629 Metetra
.877 .769 .739 r
.62568 .41629 .63236 .42555 .64511 .40539 .6385 .39586 Metetra
.861 .765 .755 r
.6385 .39586 .64511 .40539 .65789 .38745 .65133 .37771 Metetra
.834 .759 .78 r
.65133 .37771 .65789 .38745 .67076 .37249 .66425 .36261 Metetra
.791 .748 .813 r
.66425 .36261 .67076 .37249 .68377 .36116 .67731 .3512 Metetra
.721 .725 .854 r
.67731 .3512 .68377 .36116 .69702 .35393 .6906 .34399 Metetra
.608 .68 .893 r
.6906 .34399 .69702 .35393 .71056 .3511 .70419 .34127 Metetra
.439 .598 .911 r
.70419 .34127 .71056 .3511 .72447 .3527 .71813 .34306 Metetra
.223 .475 .886 r
.71813 .34306 .72447 .3527 .73876 .35843 .73247 .34906 Metetra
.013 .341 .821 r
.73247 .34906 .73876 .35843 .75346 .36759 .74722 .35857 Metetra
0 .245 .756 r
.74722 .35857 .75346 .36759 .76852 .37896 .76232 .37035 Metetra
0 .227 .741 r
.76232 .37035 .76852 .37896 .78382 .39069 .77768 .3825 Metetra
0 .323 .807 r
.77768 .3825 .78382 .39069 .79914 .40017 .79306 .39234 Metetra
.267 .563 .934 r
.79306 .39234 .79914 .40017 .81415 .40391 .80813 .39633 Metetra
.704 .797 .923 r
.80813 .39633 .81415 .40391 .82835 .39753 .82239 .38998 Metetra
.921 .83 .739 r
.82239 .38998 .82835 .39753 .8411 .37586 .8352 .36803 Metetra
.976 .789 .587 r
.8352 .36803 .8411 .37586 .85159 .33331 .84574 .32474 Metetra
.931 .563 .291 r
.21112 .5217 .21894 .52858 .22715 .5616 .21923 .55509 Metetra
.714 .201 0 r
.21923 .55509 .22715 .5616 .23736 .57443 .22943 .56792 Metetra
.589 .747 .953 r
.22943 .56792 .23736 .57443 .24894 .57245 .24105 .56568 Metetra
.819 .775 .811 r
.24105 .56568 .24894 .57245 .26134 .56061 .25354 .5534 Metetra
.857 .761 .755 r
.25354 .5534 .26134 .56061 .27417 .54313 .26647 .53537 Metetra
.864 .751 .736 r
.26647 .53537 .27417 .54313 .28711 .52336 .27952 .51504 Metetra
.858 .743 .735 r
.27952 .51504 .28711 .52336 .29998 .50388 .29249 .49501 Metetra
.843 .737 .746 r
.29249 .49501 .29998 .50388 .31265 .48652 .30525 .47713 Metetra
.817 .728 .768 r
.30525 .47713 .31265 .48652 .32508 .47248 .31776 .46265 Metetra
.772 .715 .799 r
.31776 .46265 .32508 .47248 .33726 .46251 .32999 .4523 Metetra
.698 .688 .837 r
.32999 .4523 .33726 .46251 .34921 .4569 .34199 .4464 Metetra
.578 .637 .873 r
.34199 .4464 .34921 .4569 .36098 .45566 .35378 .44494 Metetra
.396 .544 .885 r
.35378 .44494 .36098 .45566 .37264 .45854 .36545 .44767 Metetra
.161 .404 .848 r
.36545 .44767 .37264 .45854 .38424 .46506 .37705 .45411 Metetra
0 .249 .762 r
.37705 .45411 .38424 .46506 .39585 .47462 .38865 .46364 Metetra
0 .123 .669 r
.38865 .46364 .39585 .47462 .40754 .48646 .40032 .47551 Metetra
0 .047 .604 r
.40032 .47551 .40754 .48646 .41935 .49974 .41211 .48886 Metetra
0 .023 .581 r
.41211 .48886 .41935 .49974 .43133 .51359 .42407 .5028 Metetra
0 .048 .603 r
.42407 .5028 .43133 .51359 .44351 .52708 .43624 .51639 Metetra
0 .122 .666 r
.43624 .51639 .44351 .52708 .45591 .53932 .44862 .52873 Metetra
0 .24 .756 r
.44862 .52873 .45591 .53932 .46853 .54947 .46123 .53898 Metetra
.102 .387 .845 r
.46123 .53898 .46853 .54947 .48135 .5568 .47405 .54638 Metetra
.324 .526 .898 r
.47405 .54638 .48135 .5568 .49435 .56072 .48706 .55033 Metetra
.512 .628 .902 r
.48706 .55033 .49435 .56072 .50749 .56078 .50022 .5504 Metetra
.646 .688 .874 r
.50022 .5504 .50749 .56078 .52073 .55678 .5135 .54636 Metetra
.734 .718 .837 r
.5135 .54636 .52073 .55678 .53403 .54869 .52683 .53819 Metetra
.789 .733 .801 r
.52683 .53819 .53403 .54869 .54734 .53672 .54018 .5261 Metetra
.824 .739 .771 r
.54018 .5261 .54734 .53672 .5606 .52125 .55351 .51048 Metetra
.845 .741 .748 r
.55351 .51048 .5606 .52125 .5738 .50288 .56676 .49194 Metetra
.859 .74 .731 r
.56676 .49194 .5738 .50288 .58691 .48234 .57993 .47121 Metetra
.865 .739 .721 r
.57993 .47121 .58691 .48234 .59992 .46045 .593 .44914 Metetra
.867 .737 .717 r
.593 .44914 .59992 .46045 .61284 .43812 .60598 .42664 Metetra
.864 .735 .719 r
.60598 .42664 .61284 .43812 .62568 .41629 .61889 .40467 Metetra
.855 .732 .727 r
.61889 .40467 .62568 .41629 .6385 .39586 .63176 .38414 Metetra
.839 .728 .742 r
.63176 .38414 .6385 .39586 .65133 .37771 .64465 .36593 Metetra
.813 .722 .764 r
.64465 .36593 .65133 .37771 .66425 .36261 .65762 .35083 Metetra
.772 .71 .793 r
.65762 .35083 .66425 .36261 .67731 .3512 .67073 .3395 Metetra
.706 .687 .829 r
.67073 .3395 .67731 .3512 .6906 .34399 .68406 .33244 Metetra
.602 .644 .864 r
.68406 .33244 .6906 .34399 .70419 .34127 .69769 .32993 Metetra
.448 .569 .883 r
.69769 .32993 .70419 .34127 .71813 .34306 .71167 .33203 Metetra
.251 .459 .868 r
.71167 .33203 .71813 .34306 .73247 .34906 .72605 .33841 Metetra
.052 .337 .816 r
.72605 .33841 .73247 .34906 .74722 .35857 .74084 .34837 Metetra
0 .247 .761 r
.74084 .34837 .74722 .35857 .76232 .37035 .756 .36064 Metetra
0 .229 .747 r
.756 .36064 .76232 .37035 .77768 .3825 .7714 .3733 Metetra
0 .319 .807 r
.7714 .3733 .77768 .3825 .79306 .39234 .78685 .38364 Metetra
.278 .545 .922 r
.78685 .38364 .79306 .39234 .80813 .39633 .80199 .38801 Metetra
.696 .775 .912 r
.80199 .38801 .80813 .39633 .82239 .38998 .81634 .38187 Metetra
.916 .821 .738 r
.81634 .38187 .82239 .38998 .8352 .36803 .82922 .35983 Metetra
.975 .786 .587 r
.82922 .35983 .8352 .36803 .84574 .32474 .83984 .31609 Metetra
.931 .564 .292 r
.20324 .51477 .21112 .5217 .21923 .55509 .21127 .54826 Metetra
.695 .182 0 r
.21127 .54826 .21923 .55509 .22943 .56792 .22147 .56089 Metetra
.611 .74 .937 r
.22147 .56089 .22943 .56792 .24105 .56568 .23315 .55822 Metetra
.818 .762 .8 r
.23315 .55822 .24105 .56568 .25354 .5534 .24574 .54538 Metetra
.853 .748 .747 r
.24574 .54538 .25354 .5534 .26647 .53537 .25878 .52672 Metetra
.859 .738 .729 r
.25878 .52672 .26647 .53537 .27952 .51504 .27195 .50573 Metetra
.853 .73 .727 r
.27195 .50573 .27952 .51504 .29249 .49501 .28502 .48506 Metetra
.837 .722 .737 r
.28502 .48506 .29249 .49501 .30525 .47713 .29788 .46659 Metetra
.81 .711 .756 r
.29788 .46659 .30525 .47713 .31776 .46265 .31046 .45157 Metetra
.767 .694 .783 r
.31046 .45157 .31776 .46265 .32999 .4523 .32276 .44074 Metetra
.698 .665 .814 r
.32276 .44074 .32999 .4523 .34199 .4464 .3348 .43443 Metetra
.591 .614 .844 r
.3348 .43443 .34199 .4464 .35378 .44494 .34662 .43263 Metetra
.435 .531 .856 r
.34662 .43263 .35378 .44494 .36545 .44767 .3583 .43507 Metetra
.241 .414 .834 r
.3583 .43507 .36545 .44767 .37705 .45411 .3699 .44129 Metetra
.047 .286 .778 r
.3699 .44129 .37705 .45411 .38865 .46364 .38149 .45064 Metetra
0 .179 .713 r
.38149 .45064 .38865 .46364 .40032 .47551 .39314 .46238 Metetra
0 .114 .666 r
.39314 .46238 .40032 .47551 .41211 .48886 .40491 .47563 Metetra
0 .094 .652 r
.40491 .47563 .41211 .48886 .42407 .5028 .41685 .4895 Metetra
0 .12 .671 r
.41685 .4895 .42407 .5028 .43624 .51639 .42898 .50305 Metetra
0 .186 .718 r
.42898 .50305 .43624 .51639 .44862 .52873 .44134 .51537 Metetra
.049 .285 .777 r
.44134 .51537 .44862 .52873 .46123 .53898 .45394 .5256 Metetra
.221 .397 .826 r
.45394 .5256 .46123 .53898 .47405 .54638 .46675 .53298 Metetra
.391 .5 .849 r
.46675 .53298 .47405 .54638 .48706 .55033 .47976 .53691 Metetra
.533 .577 .845 r
.47976 .53691 .48706 .55033 .50022 .5504 .49293 .53694 Metetra
.639 .63 .825 r
.49293 .53694 .50022 .5504 .5135 .54636 .50622 .53286 Metetra
.713 .662 .798 r
.50622 .53286 .5135 .54636 .52683 .53819 .51959 .52463 Metetra
.763 .681 .771 r
.51959 .52463 .52683 .53819 .54018 .5261 .53297 .51248 Metetra
.797 .692 .749 r
.53297 .51248 .54018 .5261 .55351 .51048 .54634 .4968 Metetra
.82 .699 .731 r
.54634 .4968 .55351 .51048 .56676 .49194 .55965 .47819 Metetra
.834 .702 .718 r
.55965 .47819 .56676 .49194 .57993 .47121 .57287 .4574 Metetra
.842 .704 .71 r
.57287 .4574 .57993 .47121 .593 .44914 .58599 .43529 Metetra
.845 .705 .707 r
.58599 .43529 .593 .44914 .60598 .42664 .59903 .41278 Metetra
.843 .704 .71 r
.59903 .41278 .60598 .42664 .61889 .40467 .61199 .39081 Metetra
.835 .702 .717 r
.61199 .39081 .61889 .40467 .63176 .38414 .62492 .37034 Metetra
.82 .698 .731 r
.62492 .37034 .63176 .38414 .64465 .36593 .63786 .35223 Metetra
.794 .691 .751 r
.63786 .35223 .64465 .36593 .65762 .35083 .65087 .33728 Metetra
.754 .678 .777 r
.65087 .33728 .65762 .35083 .67073 .3395 .66403 .32616 Metetra
.691 .654 .809 r
.66403 .32616 .67073 .3395 .68406 .33244 .67741 .31937 Metetra
.593 .612 .841 r
.67741 .31937 .68406 .33244 .69769 .32993 .69107 .3172 Metetra
.449 .542 .859 r
.69107 .3172 .69769 .32993 .71167 .33203 .70509 .3197 Metetra
.265 .44 .848 r
.70509 .3197 .71167 .33203 .72605 .33841 .71951 .32656 Metetra
.078 .328 .806 r
.71951 .32656 .72605 .33841 .74084 .34837 .73434 .33705 Metetra
0 .243 .758 r
.73434 .33705 .74084 .34837 .756 .36064 .74955 .3499 Metetra
0 .225 .746 r
.74955 .3499 .756 .36064 .7714 .3733 .76501 .36316 Metetra
0 .308 .801 r
.76501 .36316 .7714 .3733 .78685 .38364 .78053 .37407 Metetra
.279 .523 .908 r
.78053 .37407 .78685 .38364 .80199 .38801 .79575 .37896 Metetra
.684 .753 .904 r
.79575 .37896 .80199 .38801 .81634 .38187 .81018 .37318 Metetra
.909 .812 .739 r
.81018 .37318 .81634 .38187 .82922 .35983 .82316 .35129 Metetra
.973 .784 .588 r
.82316 .35129 .82922 .35983 .83984 .31609 .83388 .30737 Metetra
.931 .563 .29 r
.19529 .50777 .20324 .51477 .21127 .54826 .20326 .54112 Metetra
.666 .153 0 r
.20326 .54112 .21127 .54826 .22147 .56089 .21349 .55336 Metetra
.633 .734 .92 r
.21349 .55336 .22147 .56089 .23315 .55822 .22524 .55013 Metetra
.818 .75 .789 r
.22524 .55013 .23315 .55822 .24574 .54538 .23794 .53662 Metetra
.85 .738 .739 r
.23794 .53662 .24574 .54538 .25878 .52672 .25109 .51724 Metetra
.855 .728 .722 r
.25109 .51724 .25878 .52672 .27195 .50573 .26438 .49553 Metetra
.849 .72 .72 r
.26438 .49553 .27195 .50573 .28502 .48506 .27757 .47416 Metetra
.833 .71 .729 r
.27757 .47416 .28502 .48506 .29788 .46659 .29053 .45502 Metetra
.806 .698 .745 r
.29053 .45502 .29788 .46659 .31046 .45157 .3032 .43939 Metetra
.764 .679 .769 r
.3032 .43939 .31046 .45157 .32276 .44074 .31556 .42801 Metetra
.699 .649 .796 r
.31556 .42801 .32276 .44074 .3348 .43443 .32765 .42119 Metetra
.602 .599 .821 r
.32765 .42119 .3348 .43443 .34662 .43263 .3395 .41893 Metetra
.466 .523 .832 r
.3395 .41893 .34662 .43263 .3583 .43507 .35119 .42096 Metetra
.301 .422 .818 r
.35119 .42096 .3583 .43507 .3699 .44129 .3628 .42682 Metetra
.136 .312 .778 r
.3628 .42682 .3699 .44129 .38149 .45064 .37438 .43585 Metetra
.004 .221 .731 r
.37438 .43585 .38149 .45064 .39314 .46238 .38601 .4473 Metetra
0 .164 .697 r
.38601 .4473 .39314 .46238 .40491 .47563 .39775 .46031 Metetra
0 .148 .686 r
.39775 .46031 .40491 .47563 .41685 .4895 .40966 .47397 Metetra
0 .171 .7 r
.40966 .47397 .41685 .4895 .42898 .50305 .42177 .48734 Metetra
.029 .228 .732 r
.42177 .48734 .42898 .50305 .44134 .51537 .4341 .4995 Metetra
.152 .308 .769 r
.4341 .4995 .44134 .51537 .45394 .5256 .44667 .50959 Metetra
.292 .397 .798 r
.44667 .50959 .45394 .5256 .46675 .53298 .45946 .51687 Metetra
.427 .478 .809 r
.45946 .51687 .46675 .53298 .47976 .53691 .47246 .52071 Metetra
.542 .542 .804 r
.47246 .52071 .47976 .53691 .49293 .53694 .48563 .52068 Metetra
.631 .589 .788 r
.48563 .52068 .49293 .53694 .50622 .53286 .49893 .51655 Metetra
.696 .621 .769 r
.49893 .51655 .50622 .53286 .51959 .52463 .51231 .50829 Metetra
.743 .643 .749 r
.51231 .50829 .51959 .52463 .53297 .51248 .52573 .49613 Metetra
.776 .657 .731 r
.52573 .49613 .53297 .51248 .54634 .4968 .53912 .48047 Metetra
.799 .666 .717 r
.53912 .48047 .54634 .4968 .55965 .47819 .55247 .4619 Metetra
.814 .673 .707 r
.55247 .4619 .55965 .47819 .57287 .4574 .56574 .44118 Metetra
.823 .676 .701 r
.56574 .44118 .57287 .4574 .58599 .43529 .57891 .41916 Metetra
.826 .678 .699 r
.57891 .41916 .58599 .43529 .59903 .41278 .592 .39678 Metetra
.825 .679 .702 r
.592 .39678 .59903 .41278 .61199 .39081 .60501 .37498 Metetra
.817 .678 .709 r
.60501 .37498 .61199 .39081 .62492 .37034 .61799 .3547 Metetra
.803 .674 .722 r
.61799 .3547 .62492 .37034 .63786 .35223 .63098 .33684 Metetra
.778 .666 .74 r
.63098 .33684 .63786 .35223 .65087 .33728 .64404 .32218 Metetra
.738 .653 .765 r
.64404 .32218 .65087 .33728 .66403 .32616 .65724 .31139 Metetra
.676 .628 .794 r
.65724 .31139 .66403 .32616 .67741 .31937 .67065 .30498 Metetra
.581 .586 .823 r
.67065 .30498 .67741 .31937 .69107 .3172 .68436 .30325 Metetra
.444 .518 .84 r
.68436 .30325 .69107 .3172 .70509 .3197 .69841 .30623 Metetra
.269 .422 .831 r
.69841 .30623 .70509 .3197 .71951 .32656 .71287 .31364 Metetra
.089 .315 .793 r
.71287 .31364 .71951 .32656 .73434 .33705 .72774 .32472 Metetra
0 .234 .75 r
.72774 .32472 .73434 .33705 .74955 .3499 .74299 .33821 Metetra
0 .215 .739 r
.74299 .33821 .74955 .3499 .76501 .36316 .75851 .35213 Metetra
0 .294 .791 r
.75851 .35213 .76501 .36316 .78053 .37407 .77409 .36371 Metetra
.271 .499 .893 r
.77409 .36371 .78053 .37407 .79575 .37896 .78939 .36922 Metetra
.668 .732 .897 r
.78939 .36922 .79575 .37896 .81018 .37318 .80392 .36395 Metetra
.902 .803 .741 r
.80392 .36395 .81018 .37318 .82316 .35129 .81702 .3424 Metetra
.972 .782 .59 r
.81702 .3424 .82316 .35129 .83388 .30737 .82786 .29856 Metetra
.93 .561 .287 r
.18727 .50072 .19529 .50777 .20326 .54112 .19522 .53368 Metetra
.624 .111 0 r
.19522 .53368 .20326 .54112 .21349 .55336 .20548 .54536 Metetra
.656 .729 .903 r
.20548 .54536 .21349 .55336 .22524 .55013 .21732 .54145 Metetra
.819 .741 .778 r
.21732 .54145 .22524 .55013 .23794 .53662 .23013 .5272 Metetra
.849 .729 .732 r
.23013 .5272 .23794 .53662 .25109 .51724 .24341 .50705 Metetra
.853 .72 .715 r
.24341 .50705 .25109 .51724 .26438 .49553 .25682 .48458 Metetra
.847 .711 .714 r
.25682 .48458 .26438 .49553 .27757 .47416 .27013 .46247 Metetra
.831 .702 .721 r
.27013 .46247 .27757 .47416 .29053 .45502 .2832 .44263 Metetra
.805 .689 .737 r
.2832 .44263 .29053 .45502 .3032 .43939 .29595 .42634 Metetra
.764 .669 .758 r
.29595 .42634 .3032 .43939 .31556 .42801 .30838 .41433 Metetra
.702 .638 .782 r
.30838 .41433 .31556 .42801 .32765 .42119 .32052 .40693 Metetra
.612 .59 .804 r
.32052 .40693 .32765 .42119 .3395 .41893 .33241 .40412 Metetra
.491 .519 .814 r
.33241 .40412 .3395 .41893 .35119 .42096 .34412 .40564 Metetra
.346 .429 .804 r
.34412 .40564 .35119 .42096 .3628 .42682 .35573 .41102 Metetra
.201 .333 .774 r
.35573 .41102 .3628 .42682 .37438 .43585 .3673 .41961 Metetra
.086 .251 .738 r
.3673 .41961 .37438 .43585 .38601 .4473 .37891 .43064 Metetra
.018 .201 .71 r
.37891 .43064 .38601 .4473 .39775 .46031 .39063 .44327 Metetra
.003 .186 .701 r
.39063 .44327 .39775 .46031 .40966 .47397 .40251 .45658 Metetra
.037 .206 .71 r
.40251 .45658 .40966 .47397 .42177 .48734 .41458 .46964 Metetra
.113 .255 .732 r
.41458 .46964 .42177 .48734 .4341 .4995 .42689 .48152 Metetra
.218 .321 .756 r
.42689 .48152 .4341 .4995 .44667 .50959 .43943 .49139 Metetra
.336 .394 .774 r
.43943 .49139 .44667 .50959 .45946 .51687 .4522 .49847 Metetra
.449 .462 .781 r
.4522 .49847 .45946 .51687 .47246 .52071 .46518 .50217 Metetra
.547 .518 .776 r
.46518 .50217 .47246 .52071 .48563 .52068 .47834 .50204 Metetra
.624 .561 .763 r
.47834 .50204 .48563 .52068 .49893 .51655 .49164 .49785 Metetra
.684 .593 .748 r
.49164 .49785 .49893 .51655 .51231 .50829 .50502 .4896 Metetra
.727 .615 .732 r
.50502 .4896 .51231 .50829 .52573 .49613 .51845 .47748 Metetra
.759 .631 .718 r
.51845 .47748 .52573 .49613 .53912 .48047 .53187 .46191 Metetra
.782 .642 .707 r
.53187 .46191 .53912 .48047 .55247 .4619 .54525 .44348 Metetra
.798 .65 .699 r
.54525 .44348 .55247 .4619 .56574 .44118 .55856 .42294 Metetra
.807 .655 .694 r
.55856 .42294 .56574 .44118 .57891 .41916 .57177 .40115 Metetra
.811 .658 .693 r
.57177 .40115 .57891 .41916 .592 .39678 .5849 .37902 Metetra
.81 .66 .696 r
.5849 .37902 .592 .39678 .60501 .37498 .59796 .35752 Metetra
.803 .659 .703 r
.59796 .35752 .60501 .37498 .61799 .3547 .61099 .33758 Metetra
.788 .655 .716 r
.61099 .33758 .61799 .3547 .63098 .33684 .62402 .32009 Metetra
.763 .647 .733 r
.62402 .32009 .63098 .33684 .64404 .32218 .63713 .30583 Metetra
.724 .633 .757 r
.63713 .30583 .64404 .32218 .65724 .31139 .65037 .29547 Metetra
.662 .608 .784 r
.65037 .29547 .65724 .31139 .67065 .30498 .66382 .28954 Metetra
.568 .565 .81 r
.66382 .28954 .67065 .30498 .68436 .30325 .67756 .28832 Metetra
.434 .497 .825 r
.67756 .28832 .68436 .30325 .69841 .30623 .69165 .29186 Metetra
.263 .403 .816 r
.69165 .29186 .69841 .30623 .71287 .31364 .70614 .29985 Metetra
.089 .3 .78 r
.70614 .29985 .71287 .31364 .72774 .32472 .72105 .31157 Metetra
0 .221 .74 r
.72105 .31157 .72774 .32472 .74299 .33821 .73634 .32573 Metetra
0 .202 .73 r
.73634 .32573 .74299 .33821 .75851 .35213 .75191 .34036 Metetra
0 .277 .779 r
.75191 .34036 .75851 .35213 .77409 .36371 .76756 .35265 Metetra
.257 .475 .878 r
.76756 .35265 .77409 .36371 .78939 .36922 .78294 .35885 Metetra
.65 .711 .892 r
.78294 .35885 .78939 .36922 .80392 .36395 .79757 .35422 Metetra
.894 .795 .744 r
.79757 .35422 .80392 .36395 .81702 .3424 .81079 .33317 Metetra
.97 .78 .593 r
.81079 .33317 .81702 .3424 .82786 .29856 .82179 .28967 Metetra
.929 .557 .281 r
.17919 .49361 .18727 .50072 .19522 .53368 .18713 .52597 Metetra
.567 .057 0 r
.18713 .52597 .19522 .53368 .20548 .54536 .19744 .53694 Metetra
.676 .726 .887 r
.19744 .53694 .20548 .54536 .21732 .54145 .20938 .53228 Metetra
.821 .734 .769 r
.20938 .53228 .21732 .54145 .23013 .5272 .2223 .51724 Metetra
.848 .723 .725 r
.2223 .51724 .23013 .5272 .24341 .50705 .23572 .49631 Metetra
.852 .714 .71 r
.23572 .49631 .24341 .50705 .25682 .48458 .24926 .47308 Metetra
.846 .706 .708 r
.24926 .47308 .25682 .48458 .27013 .46247 .26269 .45022 Metetra
.831 .696 .716 r
.26269 .45022 .27013 .46247 .2832 .44263 .27586 .42967 Metetra
.805 .683 .73 r
.27586 .42967 .2832 .44263 .29595 .42634 .28871 .4127 Metetra
.766 .664 .75 r
.28871 .4127 .29595 .42634 .30838 .41433 .30121 .40003 Metetra
.707 .633 .772 r
.30121 .40003 .30838 .41433 .32052 .40693 .3134 .39199 Metetra
.624 .587 .792 r
.3134 .39199 .32052 .40693 .33241 .40412 .32533 .38857 Metetra
.512 .521 .802 r
.32533 .38857 .33241 .40412 .34412 .40564 .33707 .3895 Metetra
.38 .437 .795 r
.33707 .3895 .34412 .40564 .35573 .41102 .34868 .3943 Metetra
.249 .349 .771 r
.34868 .3943 .35573 .41102 .3673 .41961 .36025 .40234 Metetra
.144 .275 .741 r
.36025 .40234 .3673 .41961 .37891 .43064 .37185 .41284 Metetra
.082 .228 .717 r
.37185 .41284 .37891 .43064 .39063 .44327 .38354 .42497 Metetra
.069 .214 .707 r
.38354 .42497 .39063 .44327 .40251 .45658 .39539 .43782 Metetra
.1 .231 .713 r
.39539 .43782 .40251 .45658 .41458 .46964 .40744 .45045 Metetra
.169 .273 .728 r
.40744 .45045 .41458 .46964 .42689 .48152 .41971 .46196 Metetra
.262 .33 .746 r
.41971 .46196 .42689 .48152 .43943 .49139 .43221 .4715 Metetra
.364 .393 .758 r
.43221 .4715 .43943 .49139 .4522 .49847 .44495 .47832 Metetra
.463 .453 .761 r
.44495 .47832 .4522 .49847 .46518 .50217 .45791 .48182 Metetra
.549 .503 .757 r
.45791 .48182 .46518 .50217 .47834 .50204 .47106 .48157 Metetra
.619 .543 .747 r
.47106 .48157 .47834 .50204 .49164 .49785 .48435 .47733 Metetra
.674 .574 .734 r
.48435 .47733 .49164 .49785 .50502 .4896 .49773 .4691 Metetra
.716 .596 .721 r
.49773 .4691 .50502 .4896 .51845 .47748 .51117 .45707 Metetra
.747 .613 .709 r
.51117 .45707 .51845 .47748 .53187 .46191 .52461 .44166 Metetra
.77 .625 .7 r
.52461 .44166 .53187 .46191 .54525 .44348 .53801 .42346 Metetra
.786 .634 .693 r
.53801 .42346 .54525 .44348 .55856 .42294 .55134 .4032 Metetra
.795 .64 .689 r
.55134 .4032 .55856 .42294 .57177 .40115 .5646 .38174 Metetra
.8 .644 .689 r
.5646 .38174 .57177 .40115 .5849 .37902 .57777 .35999 Metetra
.799 .646 .692 r
.57777 .35999 .5849 .37902 .59796 .35752 .59087 .33891 Metetra
.792 .646 .7 r
.59087 .33891 .59796 .35752 .61099 .33758 .60394 .31942 Metetra
.777 .642 .712 r
.60394 .31942 .61099 .33758 .62402 .32009 .61702 .30239 Metetra
.752 .634 .73 r
.61702 .30239 .62402 .32009 .63713 .30583 .63016 .28863 Metetra
.712 .619 .752 r
.63016 .28863 .63713 .30583 .65037 .29547 .64344 .27879 Metetra
.649 .593 .778 r
.64344 .27879 .65037 .29547 .66382 .28954 .65693 .27339 Metetra
.554 .549 .803 r
.65693 .27339 .66382 .28954 .67756 .28832 .6707 .27274 Metetra
.419 .48 .816 r
.6707 .27274 .67756 .28832 .69165 .29186 .68483 .27686 Metetra
.25 .385 .805 r
.68483 .27686 .69165 .29186 .70614 .29985 .69935 .28547 Metetra
.078 .283 .768 r
.69935 .28547 .70614 .29985 .72105 .31157 .71429 .29783 Metetra
0 .205 .728 r
.71429 .29783 .72105 .31157 .73634 .32573 .72961 .31266 Metetra
0 .186 .718 r
.72961 .31266 .73634 .32573 .75191 .34036 .74523 .32799 Metetra
0 .258 .765 r
.74523 .32799 .75191 .34036 .76756 .35265 .76093 .341 Metetra
.237 .451 .865 r
.76093 .341 .76756 .35265 .78294 .35885 .7764 .34794 Metetra
.629 .691 .889 r
.7764 .34794 .78294 .35885 .79757 .35422 .79113 .34402 Metetra
.885 .788 .749 r
.79113 .34402 .79757 .35422 .81079 .33317 .80449 .32364 Metetra
.967 .779 .597 r
.80449 .32364 .81079 .33317 .82179 .28967 .81567 .2807 Metetra
.927 .553 .273 r
.17105 .48644 .17919 .49361 .18713 .52597 .17899 .51801 Metetra
.496 0 0 r
.17899 .51801 .18713 .52597 .19744 .53694 .18937 .52818 Metetra
.695 .723 .872 r
.18937 .52818 .19744 .53694 .20938 .53228 .20141 .52271 Metetra
.823 .729 .761 r
.20141 .52271 .20938 .53228 .2223 .51724 .21446 .50688 Metetra
.848 .719 .72 r
.21446 .50688 .2223 .51724 .23572 .49631 .228 .4852 Metetra
.853 .711 .706 r
.228 .4852 .23572 .49631 .24926 .47308 .24168 .46123 Metetra
.846 .703 .704 r
.24168 .46123 .24926 .47308 .26269 .45022 .25522 .43768 Metetra
.832 .694 .712 r
.25522 .43768 .26269 .45022 .27586 .42967 .2685 .41644 Metetra
.808 .682 .725 r
.2685 .41644 .27586 .42967 .28871 .4127 .28144 .39879 Metetra
.77 .663 .745 r
.28144 .39879 .28871 .4127 .30121 .40003 .29403 .38547 Metetra
.715 .634 .766 r
.29403 .38547 .30121 .40003 .3134 .39199 .30628 .37677 Metetra
.635 .59 .786 r
.30628 .37677 .3134 .39199 .32533 .38857 .31825 .3727 Metetra
.53 .528 .797 r
.31825 .3727 .32533 .38857 .33707 .3895 .33001 .37299 Metetra
.406 .449 .792 r
.33001 .37299 .33707 .3895 .34868 .3943 .34164 .37714 Metetra
.283 .365 .771 r
.34164 .37714 .34868 .3943 .36025 .40234 .35321 .38455 Metetra
.184 .295 .744 r
.35321 .38455 .36025 .40234 .37185 .41284 .3648 .39444 Metetra
.125 .249 .722 r
.3648 .39444 .37185 .41284 .38354 .42497 .37647 .40598 Metetra
.112 .235 .712 r
.37647 .40598 .38354 .42497 .39539 .43782 .3883 .41827 Metetra
.141 .249 .715 r
.3883 .41827 .39539 .43782 .40744 .45045 .40031 .43038 Metetra
.204 .286 .727 r
.40031 .43038 .40744 .45045 .41971 .46196 .41255 .44143 Metetra
.289 .338 .74 r
.41255 .44143 .41971 .46196 .43221 .4715 .42502 .45057 Metetra
.382 .394 .749 r
.42502 .45057 .43221 .4715 .44495 .47832 .43773 .45707 Metetra
.472 .448 .75 r
.43773 .45707 .44495 .47832 .45791 .48182 .45066 .46033 Metetra
.551 .495 .746 r
.45066 .46033 .45791 .48182 .47106 .48157 .46379 .45993 Metetra
.616 .533 .737 r
.46379 .45993 .47106 .48157 .48435 .47733 .47706 .45564 Metetra
.668 .562 .726 r
.47706 .45564 .48435 .47733 .49773 .4691 .49044 .44745 Metetra
.709 .585 .715 r
.49044 .44745 .49773 .4691 .51117 .45707 .50388 .43555 Metetra
.739 .602 .704 r
.50388 .43555 .51117 .45707 .52461 .44166 .51733 .42036 Metetra
.761 .615 .696 r
.51733 .42036 .52461 .44166 .53801 .42346 .53075 .40245 Metetra
.777 .624 .69 r
.53075 .40245 .53801 .42346 .55134 .4032 .54412 .38256 Metetra
.787 .631 .687 r
.54412 .38256 .55134 .4032 .5646 .38174 .5574 .36153 Metetra
.792 .636 .688 r
.5574 .36153 .5646 .38174 .57777 .35999 .57061 .34025 Metetra
.791 .638 .692 r
.57061 .34025 .57777 .35999 .59087 .33891 .58375 .31968 Metetra
.784 .638 .699 r
.58375 .31968 .59087 .33891 .60394 .31942 .59686 .30072 Metetra
.769 .635 .712 r
.59686 .30072 .60394 .31942 .61702 .30239 .60998 .28425 Metetra
.744 .627 .73 r
.60998 .28425 .61702 .30239 .63016 .28863 .62317 .27104 Metetra
.702 .611 .752 r
.62317 .27104 .63016 .28863 .64344 .27879 .63648 .26178 Metetra
.637 .584 .778 r
.63648 .26178 .64344 .27879 .65693 .27339 .65001 .25695 Metetra
.539 .538 .802 r
.65001 .25695 .65693 .27339 .6707 .27274 .66381 .25688 Metetra
.4 .465 .812 r
.66381 .25688 .6707 .27274 .68483 .27686 .67796 .26158 Metetra
.228 .368 .797 r
.67796 .26158 .68483 .27686 .69935 .28547 .6925 .27079 Metetra
.056 .264 .758 r
.6925 .27079 .69935 .28547 .71429 .29783 .70747 .28376 Metetra
0 .187 .716 r
.70747 .28376 .71429 .29783 .72961 .31266 .72283 .29922 Metetra
0 .167 .705 r
.72283 .29922 .72961 .31266 .74523 .32799 .73848 .31522 Metetra
0 .237 .752 r
.73848 .31522 .74523 .32799 .76093 .341 .75424 .32893 Metetra
.213 .427 .853 r
.75424 .32893 .76093 .341 .7764 .34794 .76977 .33659 Metetra
.607 .673 .887 r
.76977 .33659 .7764 .34794 .79113 .34402 .78462 .33344 Metetra
.875 .782 .755 r
.78462 .33344 .79113 .34402 .80449 .32364 .79812 .31382 Metetra
.965 .778 .601 r
.79812 .31382 .80449 .32364 .81567 .2807 .80948 .27165 Metetra
.926 .547 .263 r
.16283 .47921 .17105 .48644 .17899 .51801 .17081 .50983 Metetra
0 .081 .584 r
.17081 .50983 .17899 .51801 .18937 .52818 .18126 .51913 Metetra
.711 .722 .859 r
.18126 .51913 .18937 .52818 .20141 .52271 .19341 .51286 Metetra
.826 .726 .754 r
.19341 .51286 .20141 .52271 .21446 .50688 .20658 .4963 Metetra
.85 .717 .716 r
.20658 .4963 .21446 .50688 .228 .4852 .22025 .47393 Metetra
.854 .71 .703 r
.22025 .47393 .228 .4852 .24168 .46123 .23405 .44931 Metetra
.849 .704 .702 r
.23405 .44931 .24168 .46123 .25522 .43768 .24772 .42512 Metetra
.835 .696 .709 r
.24772 .42512 .25522 .43768 .2685 .41644 .2611 .40327 Metetra
.812 .684 .723 r
.2611 .40327 .2685 .41644 .28144 .39879 .27413 .38501 Metetra
.777 .667 .742 r
.27413 .38501 .28144 .39879 .29403 .38547 .28679 .37105 Metetra
.724 .641 .765 r
.28679 .37105 .29403 .38547 .30628 .37677 .29911 .36172 Metetra
.648 .599 .786 r
.29911 .36172 .30628 .37677 .31825 .3727 .31113 .35699 Metetra
.547 .539 .798 r
.31113 .35699 .31825 .3727 .33001 .37299 .32292 .35661 Metetra
.427 .463 .795 r
.32292 .35661 .33001 .37299 .34164 .37714 .33457 .36009 Metetra
.306 .382 .777 r
.33457 .36009 .34164 .37714 .35321 .38455 .34615 .36681 Metetra
.209 .312 .751 r
.34615 .36681 .35321 .38455 .3648 .39444 .35773 .37603 Metetra
.151 .267 .73 r
.35773 .37603 .3648 .39444 .37647 .40598 .36939 .38691 Metetra
.137 .251 .719 r
.36939 .38691 .37647 .40598 .3883 .41827 .38119 .39856 Metetra
.165 .263 .72 r
.38119 .39856 .3883 .41827 .40031 .43038 .39318 .41009 Metetra
.225 .297 .729 r
.39318 .41009 .40031 .43038 .41255 .44143 .40539 .4206 Metetra
.305 .345 .739 r
.40539 .4206 .41255 .44143 .42502 .45057 .41783 .42929 Metetra
.393 .398 .746 r
.41783 .42929 .42502 .45057 .43773 .45707 .43051 .43542 Metetra
.478 .449 .747 r
.43051 .43542 .43773 .45707 .45066 .46033 .44342 .43841 Metetra
.553 .493 .742 r
.44342 .43841 .45066 .46033 .46379 .45993 .45652 .43784 Metetra
.615 .529 .733 r
.45652 .43784 .46379 .45993 .47706 .45564 .46978 .43349 Metetra
.666 .558 .723 r
.46978 .43349 .47706 .45564 .49044 .44745 .48315 .42536 Metetra
.705 .58 .713 r
.48315 .42536 .49044 .44745 .50388 .43555 .49659 .41363 Metetra
.735 .597 .703 r
.49659 .41363 .50388 .43555 .51733 .42036 .51005 .39871 Metetra
.757 .61 .696 r
.51005 .39871 .51733 .42036 .53075 .40245 .52349 .38116 Metetra
.773 .621 .691 r
.52349 .38116 .53075 .40245 .54412 .38256 .53688 .3617 Metetra
.783 .628 .688 r
.53688 .3617 .54412 .38256 .5574 .36153 .55019 .34116 Metetra
.788 .633 .689 r
.55019 .34116 .5574 .36153 .57061 .34025 .56344 .32043 Metetra
.787 .636 .693 r
.56344 .32043 .57061 .34025 .58375 .31968 .57662 .30043 Metetra
.78 .636 .702 r
.57662 .30043 .58375 .31968 .59686 .30072 .58977 .28207 Metetra
.765 .633 .715 r
.58977 .28207 .59686 .30072 .60998 .28425 .60293 .2662 Metetra
.738 .625 .733 r
.60293 .2662 .60998 .28425 .62317 .27104 .61615 .2536 Metetra
.695 .61 .757 r
.61615 .2536 .62317 .27104 .63648 .26178 .62951 .24492 Metetra
.627 .581 .783 r
.62951 .24492 .63648 .26178 .65001 .25695 .64306 .24068 Metetra
.523 .531 .806 r
.64306 .24068 .65001 .25695 .66381 .25688 .65689 .24116 Metetra
.377 .454 .813 r
.65689 .24116 .66381 .25688 .67796 .26158 .67106 .24642 Metetra
.198 .351 .793 r
.67106 .24642 .67796 .26158 .6925 .27079 .68563 .25616 Metetra
.023 .244 .747 r
.68563 .25616 .6925 .27079 .70747 .28376 .70061 .26967 Metetra
0 .166 .702 r
.70061 .26967 .70747 .28376 .72283 .29922 .71599 .28569 Metetra
0 .147 .691 r
.71599 .28569 .72283 .29922 .73848 .31522 .73168 .30226 Metetra
0 .217 .739 r
.73168 .30226 .73848 .31522 .75424 .32893 .74748 .3166 Metetra
.186 .406 .843 r
.74748 .3166 .75424 .32893 .76977 .33659 .76308 .32494 Metetra
.585 .657 .887 r
.76308 .32494 .76977 .33659 .78462 .33344 .77803 .32254 Metetra
.866 .777 .761 r
.77803 .32254 .78462 .33344 .79812 .31382 .79168 .30376 Metetra
.963 .778 .607 r
.79168 .30376 .79812 .31382 .80948 .27165 .80324 .26251 Metetra
.923 .54 .25 r
.15455 .47192 .16283 .47921 .17081 .50983 .16257 .50147 Metetra
0 .157 .66 r
.16257 .50147 .17081 .50983 .18126 .51913 .17311 .50987 Metetra
.724 .722 .848 r
.17311 .50987 .18126 .51913 .19341 .51286 .18536 .50285 Metetra
.829 .725 .75 r
.18536 .50285 .19341 .51286 .20658 .4963 .19864 .48565 Metetra
.852 .717 .714 r
.19864 .48565 .20658 .4963 .22025 .47393 .21244 .46272 Metetra
.857 .712 .701 r
.21244 .46272 .22025 .47393 .23405 .44931 .22635 .43758 Metetra
.852 .706 .7 r
.22635 .43758 .23405 .44931 .24772 .42512 .24013 .41289 Metetra
.84 .7 .708 r
.24013 .41289 .24772 .42512 .2611 .40327 .25362 .39053 Metetra
.819 .691 .723 r
.25362 .39053 .2611 .40327 .27413 .38501 .26675 .37173 Metetra
.786 .677 .743 r
.26675 .37173 .27413 .38501 .28679 .37105 .27948 .35722 Metetra
.736 .653 .767 r
.27948 .35722 .28679 .37105 .29911 .36172 .29186 .3473 Metetra
.662 .615 .791 r
.29186 .3473 .29911 .36172 .31113 .35699 .30393 .34195 Metetra
.563 .558 .806 r
.30393 .34195 .31113 .35699 .32292 .35661 .31577 .34091 Metetra
.442 .483 .806 r
.31577 .34091 .32292 .35661 .33457 .36009 .32744 .34371 Metetra
.32 .401 .789 r
.32744 .34371 .33457 .36009 .34615 .36681 .33903 .34973 Metetra
.22 .329 .763 r
.33903 .34973 .34615 .36681 .35773 .37603 .35061 .35824 Metetra
.16 .282 .741 r
.35061 .35824 .35773 .37603 .36939 .38691 .36227 .36841 Metetra
.146 .264 .729 r
.36227 .36841 .36939 .38691 .38119 .39856 .37406 .37939 Metetra
.173 .275 .729 r
.37406 .37939 .38119 .39856 .39318 .41009 .38602 .39028 Metetra
.232 .308 .736 r
.38602 .39028 .39318 .41009 .40539 .4206 .39821 .40021 Metetra
.311 .354 .745 r
.39821 .40021 .40539 .4206 .41783 .42929 .41063 .4084 Metetra
.397 .405 .751 r
.41063 .4084 .41783 .42929 .43051 .43542 .42328 .41412 Metetra
.481 .454 .75 r
.42328 .41412 .43051 .43542 .44342 .43841 .43616 .41681 Metetra
.555 .496 .745 r
.43616 .41681 .44342 .43841 .45652 .43784 .44925 .41607 Metetra
.616 .532 .736 r
.44925 .41607 .45652 .43784 .46978 .43349 .46249 .41167 Metetra
.666 .56 .726 r
.46249 .41167 .46978 .43349 .48315 .42536 .47586 .4036 Metetra
.705 .582 .715 r
.47586 .4036 .48315 .42536 .49659 .41363 .4893 .39207 Metetra
.734 .599 .706 r
.4893 .39207 .49659 .41363 .51005 .39871 .50276 .37744 Metetra
.757 .613 .699 r
.50276 .37744 .51005 .39871 .52349 .38116 .51622 .3603 Metetra
.773 .623 .694 r
.51622 .3603 .52349 .38116 .53688 .3617 .52963 .34132 Metetra
.783 .631 .692 r
.52963 .34132 .53688 .3617 .55019 .34116 .54298 .32133 Metetra
.788 .637 .693 r
.54298 .32133 .55019 .34116 .56344 .32043 .55626 .3012 Metetra
.788 .64 .698 r
.55626 .3012 .56344 .32043 .57662 .30043 .56948 .28182 Metetra
.78 .641 .708 r
.56948 .28182 .57662 .30043 .58977 .28207 .58268 .26408 Metetra
.765 .639 .722 r
.58268 .26408 .58977 .28207 .60293 .2662 .59588 .24883 Metetra
.737 .631 .742 r
.59588 .24883 .60293 .2662 .61615 .2536 .60914 .23684 Metetra
.69 .615 .767 r
.60914 .23684 .61615 .2536 .62951 .24492 .62253 .22874 Metetra
.617 .585 .795 r
.62253 .22874 .62951 .24492 .64306 .24068 .63612 .22504 Metetra
.505 .531 .817 r
.63612 .22504 .64306 .24068 .65689 .24116 .64997 .22604 Metetra
.347 .446 .821 r
.64997 .22604 .65689 .24116 .67106 .24642 .66416 .23177 Metetra
.158 .335 .792 r
.66416 .23177 .67106 .24642 .68563 .25616 .67875 .24196 Metetra
0 .222 .737 r
.67875 .24196 .68563 .25616 .70061 .26967 .69374 .2559 Metetra
0 .143 .688 r
.69374 .2559 .70061 .26967 .71599 .28569 .70914 .27235 Metetra
0 .126 .676 r
.70914 .27235 .71599 .28569 .73168 .30226 .72484 .28936 Metetra
0 .196 .726 r
.72484 .28936 .73168 .30226 .74748 .3166 .74067 .30419 Metetra
.157 .387 .835 r
.74067 .30419 .74748 .3166 .76308 .32494 .75633 .31311 Metetra
.563 .644 .889 r
.75633 .31311 .76308 .32494 .77803 .32254 .77137 .3114 Metetra
.857 .773 .769 r
.77137 .3114 .77803 .32254 .79168 .30376 .78517 .29349 Metetra
.96 .778 .613 r
.78517 .29349 .79168 .30376 .80324 .26251 .79694 .25328 Metetra
.92 .531 .236 r
.14619 .46457 .15455 .47192 .16257 .50147 .15428 .49297 Metetra
0 .231 .726 r
.15428 .49297 .16257 .50147 .17311 .50987 .1649 .5005 Metetra
.735 .724 .841 r
.1649 .5005 .17311 .50987 .18536 .50285 .17725 .49283 Metetra
.832 .725 .747 r
.17725 .49283 .18536 .50285 .19864 .48565 .19064 .47513 Metetra
.855 .72 .713 r
.19064 .47513 .19864 .48565 .21244 .46272 .20454 .4518 Metetra
.86 .716 .701 r
.20454 .4518 .21244 .46272 .22635 .43758 .21856 .42632 Metetra
.857 .712 .701 r
.21856 .42632 .22635 .43758 .24013 .41289 .23244 .40129 Metetra
.847 .708 .709 r
.23244 .40129 .24013 .41289 .25362 .39053 .24603 .37857 Metetra
.828 .702 .725 r
.24603 .37857 .25362 .39053 .26675 .37173 .25924 .35939 Metetra
.797 .691 .748 r
.25924 .35939 .26675 .37173 .27948 .35722 .27205 .34443 Metetra
.75 .672 .775 r
.27205 .34443 .27948 .35722 .29186 .3473 .2845 .33401 Metetra
.678 .638 .802 r
.2845 .33401 .29186 .3473 .30393 .34195 .29662 .3281 Metetra
.578 .584 .823 r
.29662 .3281 .30393 .34195 .31577 .34091 .30849 .32645 Metetra
.453 .509 .826 r
.30849 .32645 .31577 .34091 .32744 .34371 .3202 .32859 Metetra
.324 .424 .81 r
.3202 .32859 .32744 .34371 .33903 .34973 .33181 .33391 Metetra
.217 .347 .782 r
.33181 .33391 .33903 .34973 .35061 .35824 .3434 .34171 Metetra
.152 .296 .758 r
.3434 .34171 .35061 .35824 .36227 .36841 .35506 .35116 Metetra
.136 .276 .744 r
.35506 .35116 .36227 .36841 .37406 .37939 .36684 .36143 Metetra
.163 .285 .743 r
.36684 .36143 .37406 .37939 .38602 .39028 .3788 .37166 Metetra
.225 .318 .75 r
.3788 .37166 .38602 .39028 .39821 .40021 .39097 .38099 Metetra
.307 .365 .759 r
.39097 .38099 .39821 .40021 .41063 .4084 .40337 .38865 Metetra
.396 .416 .763 r
.40337 .38865 .41063 .4084 .42328 .41412 .41601 .39394 Metetra
.482 .465 .762 r
.41601 .39394 .42328 .41412 .43616 .41681 .42887 .39632 Metetra
.557 .507 .755 r
.42887 .39632 .43616 .41681 .44925 .41607 .44194 .39539 Metetra
.619 .542 .745 r
.44194 .39539 .44925 .41607 .46249 .41167 .45517 .39093 Metetra
.669 .57 .734 r
.45517 .39093 .46249 .41167 .47586 .4036 .46854 .38295 Metetra
.708 .592 .723 r
.46854 .38295 .47586 .4036 .4893 .39207 .48198 .37162 Metetra
.738 .609 .714 r
.48198 .37162 .4893 .39207 .50276 .37744 .49546 .35733 Metetra
.761 .622 .706 r
.49546 .35733 .50276 .37744 .51622 .3603 .50893 .34061 Metetra
.777 .633 .701 r
.50893 .34061 .51622 .3603 .52963 .34132 .52237 .32215 Metetra
.788 .641 .7 r
.52237 .32215 .52963 .34132 .54298 .32133 .53576 .30274 Metetra
.793 .648 .701 r
.53576 .30274 .54298 .32133 .55626 .3012 .54908 .28322 Metetra
.793 .652 .707 r
.54908 .28322 .55626 .3012 .56948 .28182 .56234 .26448 Metetra
.785 .654 .718 r
.56234 .26448 .56948 .28182 .58268 .26408 .57558 .24738 Metetra
.769 .653 .734 r
.57558 .24738 .58268 .26408 .59588 .24883 .58883 .23275 Metetra
.739 .646 .756 r
.58883 .23275 .59588 .24883 .60914 .23684 .60213 .22133 Metetra
.689 .63 .784 r
.60213 .22133 .60914 .23684 .62253 .22874 .61556 .21377 Metetra
.609 .597 .814 r
.61556 .21377 .62253 .22874 .63612 .22504 .62918 .21056 Metetra
.483 .538 .837 r
.62918 .21056 .63612 .22504 .64997 .22604 .64306 .21197 Metetra
.308 .442 .834 r
.64306 .21197 .64997 .22604 .66416 .23177 .65727 .21807 Metetra
.104 .318 .792 r
.65727 .21807 .66416 .23177 .67875 .24196 .67187 .22857 Metetra
0 .198 .726 r
.67187 .22857 .67875 .24196 .69374 .2559 .68687 .24278 Metetra
0 .119 .67 r
.68687 .24278 .69374 .2559 .70914 .27235 .70226 .25947 Metetra
0 .104 .659 r
.70226 .25947 .70914 .27235 .72484 .28936 .71798 .27675 Metetra
0 .178 .713 r
.71798 .27675 .72484 .28936 .74067 .30419 .73383 .29189 Metetra
.127 .371 .829 r
.73383 .29189 .74067 .30419 .75633 .31311 .74954 .30123 Metetra
.543 .635 .892 r
.74954 .30123 .75633 .31311 .77137 .3114 .76466 .30012 Metetra
.848 .771 .776 r
.76466 .30012 .77137 .3114 .78517 .29349 .77859 .28304 Metetra
.957 .778 .619 r
.77859 .28304 .78517 .29349 .79694 .25328 .79058 .24397 Metetra
.916 .521 .22 r
.13777 .45715 .14619 .46457 .15428 .49297 .14592 .48436 Metetra
0 .297 .78 r
.14592 .48436 .15428 .49297 .1649 .5005 .15662 .49108 Metetra
.743 .726 .836 r
.15662 .49108 .1649 .5005 .17725 .49283 .16906 .4829 Metetra
.835 .728 .746 r
.16906 .4829 .17725 .49283 .19064 .47513 .18254 .46492 Metetra
.858 .724 .713 r
.18254 .46492 .19064 .47513 .20454 .4518 .19653 .44141 Metetra
.865 .722 .702 r
.19653 .44141 .20454 .4518 .21856 .42632 .21064 .41581 Metetra
.864 .721 .703 r
.21064 .41581 .21856 .42632 .23244 .40129 .22461 .39066 Metetra
.855 .72 .713 r
.22461 .39066 .23244 .40129 .24603 .37857 .23828 .36778 Metetra
.839 .718 .73 r
.23828 .36778 .24603 .37857 .25924 .35939 .25157 .34837 Metetra
.811 .712 .756 r
.25157 .34837 .25924 .35939 .27205 .34443 .26445 .33312 Metetra
.766 .699 .787 r
.26445 .33312 .27205 .34443 .2845 .33401 .27696 .32232 Metetra
.696 .671 .822 r
.27696 .32232 .2845 .33401 .29662 .3281 .28914 .31595 Metetra
.592 .621 .849 r
.28914 .31595 .29662 .3281 .30849 .32645 .30106 .31376 Metetra
.457 .545 .858 r
.30106 .31376 .30849 .32645 .3202 .32859 .3128 .31529 Metetra
.313 .453 .841 r
.3128 .31529 .3202 .32859 .33181 .33391 .32444 .31996 Metetra
.192 .367 .809 r
.32444 .31996 .33181 .33391 .3434 .34171 .33606 .32706 Metetra
.119 .308 .78 r
.33606 .32706 .3434 .34171 .35506 .35116 .34773 .33581 Metetra
.101 .285 .764 r
.34773 .33581 .35506 .35116 .36684 .36143 .35951 .34538 Metetra
.132 .294 .763 r
.35951 .34538 .36684 .36143 .3788 .37166 .37147 .35493 Metetra
.2 .329 .772 r
.37147 .35493 .3788 .37166 .39097 .38099 .38363 .36364 Metetra
.291 .379 .781 r
.38363 .36364 .39097 .38099 .40337 .38865 .39602 .37076 Metetra
.388 .433 .786 r
.39602 .37076 .40337 .38865 .41601 .39394 .40865 .37561 Metetra
.48 .484 .784 r
.40865 .37561 .41601 .39394 .42887 .39632 .42151 .37767 Metetra
.56 .527 .775 r
.42151 .37767 .42887 .39632 .44194 .39539 .43457 .37654 Metetra
.625 .561 .763 r
.43457 .37654 .44194 .39539 .45517 .39093 .4478 .37204 Metetra
.676 .589 .75 r
.4478 .37204 .45517 .39093 .46854 .38295 .46117 .36414 Metetra
.717 .61 .737 r
.46117 .36414 .46854 .38295 .48198 .37162 .47462 .35304 Metetra
.747 .627 .727 r
.47462 .35304 .48198 .37162 .49546 .35733 .48812 .33909 Metetra
.77 .641 .718 r
.48812 .33909 .49546 .35733 .50893 .34061 .50162 .32281 Metetra
.787 .652 .713 r
.50162 .32281 .50893 .34061 .52237 .32215 .51509 .30488 Metetra
.798 .661 .712 r
.51509 .30488 .52237 .32215 .53576 .30274 .52852 .28606 Metetra
.803 .668 .714 r
.52852 .28606 .53576 .30274 .54908 .28322 .54188 .26716 Metetra
.803 .674 .721 r
.54188 .26716 .54908 .28322 .56234 .26448 .5552 .24905 Metetra
.796 .677 .733 r
.5552 .24905 .56234 .26448 .57558 .24738 .56849 .23257 Metetra
.779 .678 .752 r
.56849 .23257 .57558 .24738 .58883 .23275 .58179 .21852 Metetra
.747 .673 .778 r
.58179 .21852 .58883 .23275 .60213 .22133 .59514 .20763 Metetra
.692 .657 .811 r
.59514 .20763 .60213 .22133 .61556 .21377 .60861 .20054 Metetra
.601 .622 .845 r
.60861 .20054 .61556 .21377 .62918 .21056 .62226 .1977 Metetra
.456 .554 .866 r
.62226 .1977 .62918 .21056 .64306 .21197 .63617 .19942 Metetra
.256 .441 .852 r
.63617 .19942 .64306 .21197 .65727 .21807 .6504 .20573 Metetra
.035 .3 .791 r
.6504 .20573 .65727 .21807 .67187 .22857 .665 .21636 Metetra
0 .172 .709 r
.665 .21636 .67187 .22857 .68687 .24278 .68 .23064 Metetra
0 .094 .649 r
.68 .23064 .68687 .24278 .70226 .25947 .69539 .24736 Metetra
0 .084 .641 r
.69539 .24736 .70226 .25947 .71798 .27675 .7111 .26467 Metetra
0 .162 .702 r
.7111 .26467 .71798 .27675 .73383 .29189 .72696 .27989 Metetra
.1 .361 .827 r
.72696 .27989 .73383 .29189 .74954 .30123 .7427 .28944 Metetra
.526 .63 .897 r
.7427 .28944 .74954 .30123 .76466 .30012 .75789 .28877 Metetra
.84 .769 .784 r
.75789 .28877 .76466 .30012 .77859 .28304 .77196 .27245 Metetra
.955 .779 .626 r
.77196 .27245 .77859 .28304 .79058 .24397 .78416 .23457 Metetra
.912 .51 .201 r
.12927 .44968 .13777 .45715 .14592 .48436 .13751 .47566 Metetra
0 .35 .82 r
.13751 .47566 .14592 .48436 .15662 .49108 .14828 .48169 Metetra
.748 .728 .834 r
.14828 .48169 .15662 .49108 .16906 .4829 .16078 .4732 Metetra
.837 .732 .748 r
.16078 .4732 .16906 .4829 .18254 .46492 .17433 .45516 Metetra
.862 .73 .716 r
.17433 .45516 .18254 .46492 .19653 .44141 .18838 .43175 Metetra
.87 .731 .706 r
.18838 .43175 .19653 .44141 .21064 .41581 .20256 .4063 Metetra
.871 .733 .707 r
.20256 .4063 .21064 .41581 .22461 .39066 .2166 .38129 Metetra
.865 .737 .719 r
.2166 .38129 .22461 .39066 .23828 .36778 .23033 .35849 Metetra
.852 .74 .739 r
.23033 .35849 .23828 .36778 .25157 .34837 .24369 .33908 Metetra
.828 .741 .768 r
.24369 .33908 .25157 .34837 .26445 .33312 .25664 .32371 Metetra
.786 .736 .807 r
.25664 .32371 .26445 .33312 .27696 .32232 .2692 .31269 Metetra
.715 .718 .851 r
.2692 .31269 .27696 .32232 .28914 .31595 .28144 .30599 Metetra
.604 .674 .889 r
.28144 .30599 .28914 .31595 .30106 .31376 .29341 .30336 Metetra
.45 .595 .904 r
.29341 .30336 .30106 .31376 .3128 .31529 .30519 .30437 Metetra
.278 .489 .883 r
.30519 .30437 .3128 .31529 .32444 .31996 .31687 .30844 Metetra
.134 .387 .84 r
.31687 .30844 .32444 .31996 .33606 .32706 .32852 .31488 Metetra
.049 .317 .801 r
.32852 .31488 .33606 .32706 .34773 .33581 .34021 .32295 Metetra
.029 .289 .783 r
.34021 .32295 .34773 .33581 .35951 .34538 .35201 .33183 Metetra
.066 .3 .785 r
.35201 .33183 .35951 .34538 .37147 .35493 .36398 .34071 Metetra
.147 .341 .8 r
.36398 .34071 .37147 .35493 .38363 .36364 .37615 .34881 Metetra
.254 .398 .815 r
.37615 .34881 .38363 .36364 .39602 .37076 .38855 .35539 Metetra
.368 .458 .822 r
.38855 .35539 .39602 .37076 .40865 .37561 .40118 .3598 Metetra
.473 .513 .819 r
.40118 .3598 .40865 .37561 .42151 .37767 .41403 .36153 Metetra
.562 .559 .807 r
.41403 .36153 .42151 .37767 .43457 .37654 .4271 .36022 Metetra
.633 .594 .792 r
.4271 .36022 .43457 .37654 .4478 .37204 .44034 .35566 Metetra
.688 .621 .775 r
.44034 .35566 .4478 .37204 .46117 .36414 .45372 .34786 Metetra
.73 .641 .76 r
.45372 .34786 .46117 .36414 .47462 .35304 .4672 .33698 Metetra
.762 .658 .747 r
.4672 .33698 .47462 .35304 .48812 .33909 .48072 .32338 Metetra
.786 .671 .737 r
.48072 .32338 .48812 .33909 .50162 .32281 .49426 .30756 Metetra
.803 .682 .731 r
.49426 .30756 .50162 .32281 .51509 .30488 .50777 .29016 Metetra
.814 .692 .729 r
.50777 .29016 .51509 .30488 .52852 .28606 .52125 .27192 Metetra
.82 .7 .732 r
.52125 .27192 .52852 .28606 .54188 .26716 .53467 .25363 Metetra
.821 .708 .74 r
.53467 .25363 .54188 .26716 .5552 .24905 .54804 .23612 Metetra
.813 .714 .755 r
.54804 .23612 .5552 .24905 .56849 .23257 .56139 .22021 Metetra
.795 .717 .778 r
.56139 .22021 .56849 .23257 .58179 .21852 .57475 .20669 Metetra
.761 .715 .81 r
.57475 .20669 .58179 .21852 .59514 .20763 .58815 .19626 Metetra
.699 .702 .849 r
.58815 .19626 .59514 .20763 .60861 .20054 .60167 .18952 Metetra
.591 .664 .889 r
.60167 .18952 .60861 .20054 .62226 .1977 .61537 .18694 Metetra
.418 .581 .907 r
.61537 .18694 .62226 .1977 .63617 .19942 .6293 .18879 Metetra
.184 .443 .872 r
.6293 .18879 .63617 .19942 .6504 .20573 .64355 .19513 Metetra
0 .28 .783 r
.64355 .19513 .6504 .20573 .665 .21636 .65816 .20568 Metetra
0 .144 .684 r
.65816 .20568 .665 .21636 .68 .23064 .67315 .21979 Metetra
0 .069 .623 r
.67315 .21979 .68 .23064 .69539 .24736 .68853 .23627 Metetra
0 .065 .621 r
.68853 .23627 .69539 .24736 .7111 .26467 .70422 .25333 Metetra
0 .151 .692 r
.70422 .25333 .7111 .26467 .72696 .27989 .72008 .26835 Metetra
.076 .357 .828 r
.72008 .26835 .72696 .27989 .7427 .28944 .73583 .27787 Metetra
.514 .63 .903 r
.73583 .27787 .7427 .28944 .75789 .28877 .75107 .27743 Metetra
.834 .77 .791 r
.75107 .27743 .75789 .28877 .77196 .27245 .76526 .26176 Metetra
.952 .781 .633 r
.76526 .26176 .77196 .27245 .78416 .23457 .77768 .22508 Metetra
.906 .498 .181 r
.1207 .44214 .12927 .44968 .13751 .47566 .12902 .46691 Metetra
.002 .39 .847 r
.12902 .46691 .13751 .47566 .14828 .48169 .13986 .47237 Metetra
.75 .732 .836 r
.13986 .47237 .14828 .48169 .16078 .4732 .1524 .4638 Metetra
.839 .737 .752 r
.1524 .4638 .16078 .4732 .17433 .45516 .16598 .446 Metetra
.865 .738 .721 r
.16598 .446 .17433 .45516 .18838 .43175 .18007 .423 Metetra
.876 .742 .711 r
.18007 .423 .18838 .43175 .20256 .4063 .19429 .39801 Metetra
.879 .749 .714 r
.19429 .39801 .20256 .4063 .2166 .38129 .20837 .37344 Metetra
.877 .757 .727 r
.20837 .37344 .2166 .38129 .23033 .35849 .22215 .351 Metetra
.867 .768 .75 r
.22215 .351 .23033 .35849 .24369 .33908 .23555 .33183 Metetra
.847 .779 .785 r
.23555 .33183 .24369 .33908 .25664 .32371 .24856 .31657 Metetra
.807 .786 .833 r
.24856 .31657 .25664 .32371 .2692 .31269 .26118 .3055 Metetra
.734 .781 .891 r
.26118 .3055 .2692 .31269 .28144 .30599 .27347 .29862 Metetra
.607 .746 .943 r
.27347 .29862 .28144 .30599 .29341 .30336 .28549 .29569 Metetra
.415 .658 .96 r
.28549 .29569 .29341 .30336 .30519 .30437 .29732 .29627 Metetra
.196 .525 .92 r
.29732 .29627 .30519 .30437 .31687 .30844 .30904 .29982 Metetra
.018 .395 .851 r
.30904 .29982 .31687 .30844 .32852 .31488 .32073 .30568 Metetra
0 .309 .796 r
.32073 .30568 .32852 .31488 .34021 .32295 .33246 .3131 Metetra
0 .276 .777 r
.33246 .3131 .34021 .32295 .35201 .33183 .3443 .32133 Metetra
0 .293 .791 r
.3443 .32133 .35201 .33183 .36398 .34071 .35629 .32956 Metetra
.046 .346 .823 r
.35629 .32956 .36398 .34071 .37615 .34881 .36848 .33705 Metetra
.182 .42 .855 r
.36848 .33705 .37615 .34881 .38855 .35539 .38089 .3431 Metetra
.325 .495 .872 r
.38089 .3431 .38855 .35539 .40118 .3598 .39354 .34707 Metetra
.456 .559 .871 r
.39354 .34707 .40118 .3598 .41403 .36153 .40642 .34848 Metetra
.563 .608 .856 r
.40642 .34848 .41403 .36153 .4271 .36022 .4195 .34698 Metetra
.644 .644 .835 r
.4195 .34698 .4271 .36022 .44034 .35566 .43276 .34238 Metetra
.705 .67 .812 r
.43276 .34238 .44034 .35566 .45372 .34786 .44617 .33467 Metetra
.75 .689 .792 r
.44617 .33467 .45372 .34786 .4672 .33698 .45968 .32402 Metetra
.784 .703 .775 r
.45968 .32402 .4672 .33698 .48072 .32338 .47324 .31077 Metetra
.808 .716 .763 r
.47324 .31077 .48072 .32338 .49426 .30756 .48682 .2954 Metetra
.826 .727 .755 r
.48682 .2954 .49426 .30756 .50777 .29016 .50039 .27853 Metetra
.838 .737 .753 r
.50039 .27853 .50777 .29016 .52125 .27192 .51393 .26085 Metetra
.845 .747 .756 r
.51393 .26085 .52125 .27192 .53467 .25363 .52741 .24314 Metetra
.845 .758 .766 r
.52741 .24314 .53467 .25363 .54804 .23612 .54086 .2262 Metetra
.838 .768 .784 r
.54086 .2262 .54804 .23612 .56139 .22021 .55427 .21082 Metetra
.819 .776 .813 r
.55427 .21082 .56139 .22021 .57475 .20669 .5677 .19774 Metetra
.78 .78 .852 r
.5677 .19774 .57475 .20669 .58815 .19626 .58117 .18765 Metetra
.707 .77 .901 r
.58117 .18765 .58815 .19626 .60167 .18952 .59475 .18115 Metetra
.574 .726 .946 r
.59475 .18115 .60167 .18952 .61537 .18694 .60849 .17867 Metetra
.357 .619 .951 r
.60849 .17867 .61537 .18694 .6293 .18879 .62246 .18048 Metetra
.082 .443 .879 r
.62246 .18048 .6293 .18879 .64355 .19513 .63672 .18663 Metetra
0 .254 .754 r
.63672 .18663 .64355 .19513 .65816 .20568 .65134 .19685 Metetra
0 .116 .645 r
.65134 .19685 .65816 .20568 .67315 .21979 .66632 .21049 Metetra
0 .047 .588 r
.66632 .21049 .67315 .21979 .68853 .23627 .68168 .22644 Metetra
0 .052 .599 r
.68168 .22644 .68853 .23627 .70422 .25333 .69735 .24291 Metetra
0 .148 .685 r
.69735 .24291 .70422 .25333 .72008 .26835 .71318 .25742 Metetra
.061 .363 .833 r
.71318 .25742 .72008 .26835 .73583 .27787 .72893 .26659 Metetra
.509 .637 .911 r
.72893 .26659 .73583 .27787 .75107 .27743 .74421 .26614 Metetra
.829 .771 .798 r
.74421 .26614 .75107 .27743 .76526 .26176 .75851 .25098 Metetra
.949 .782 .641 r
.75851 .25098 .76526 .26176 .77768 .22508 .77113 .21549 Metetra
.9 .484 .158 r
.11206 .43453 .1207 .44214 .12902 .46691 .12047 .45811 Metetra
.041 .417 .863 r
.12047 .45811 .12902 .46691 .13986 .47237 .13135 .46316 Metetra
.748 .735 .84 r
.13135 .46316 .13986 .47237 .1524 .4638 .14391 .45478 Metetra
.839 .744 .759 r
.14391 .45478 .1524 .4638 .16598 .446 .15749 .43753 Metetra
.868 .749 .729 r
.15749 .43753 .16598 .446 .18007 .423 .17158 .41528 Metetra
.882 .756 .72 r
.17158 .41528 .18007 .423 .19429 .39801 .18579 .3911 Metetra
.888 .768 .724 r
.18579 .3911 .19429 .39801 .20837 .37344 .19988 .36731 Metetra
.889 .784 .739 r
.19988 .36731 .20837 .37344 .22215 .351 .21369 .34554 Metetra
.883 .804 .766 r
.21369 .34554 .22215 .351 .23555 .33183 .22712 .32688 Metetra
.866 .827 .808 r
.22712 .32688 .23555 .33183 .24856 .31657 .24017 .31196 Metetra
.826 .851 .866 r
.24017 .31196 .24856 .31657 .26118 .3055 .25283 .30107 Metetra
.742 .863 .937 r
.25283 .30107 .26118 .3055 .27347 .29862 .26518 .29419 Metetra
.575 .83 .993 r
.26518 .29419 .27347 .29862 .28549 .29569 .27725 .29109 Metetra
.311 .708 .978 r
.27725 .29109 .28549 .29569 .29732 .29627 .28914 .29137 Metetra
.027 .52 .876 r
.28914 .29137 .29732 .29627 .30904 .29982 .30091 .2945 Metetra
0 .353 .76 r
.30091 .2945 .30904 .29982 .32073 .30568 .31265 .29983 Metetra
0 .254 .69 r
.31265 .29983 .32073 .30568 .33246 .3131 .32443 .30667 Metetra
0 .223 .679 r
.32443 .30667 .33246 .3131 .3443 .32133 .33631 .31427 Metetra
0 .249 .717 r
.33631 .31427 .3443 .32133 .35629 .32956 .34834 .32188 Metetra
0 .324 .79 r
.34834 .32188 .35629 .32956 .36848 .33705 .36057 .32878 Metetra
.042 .429 .869 r
.36057 .32878 .36848 .33705 .38089 .3431 .37302 .3343 Metetra
.235 .537 .923 r
.37302 .3343 .38089 .3431 .39354 .34707 .3857 .33784 Metetra
.413 .624 .939 r
.3857 .33784 .39354 .34707 .40642 .34848 .39861 .33893 Metetra
.553 .683 .925 r
.39861 .33893 .40642 .34848 .4195 .34698 .41172 .33725 Metetra
.655 .72 .896 r
.41172 .33725 .4195 .34698 .43276 .34238 .42502 .3326 Metetra
.726 .743 .865 r
.42502 .3326 .43276 .34238 .44617 .33467 .43847 .32499 Metetra
.776 .758 .837 r
.43847 .32499 .44617 .33467 .45968 .32402 .45202 .31458 Metetra
.812 .77 .814 r
.45202 .31458 .45968 .32402 .47324 .31077 .46564 .30168 Metetra
.838 .78 .797 r
.46564 .30168 .47324 .31077 .48682 .2954 .47928 .28675 Metetra
.856 .79 .786 r
.47928 .28675 .48682 .2954 .50039 .27853 .49292 .27039 Metetra
.868 .801 .782 r
.49292 .27039 .50039 .27853 .51393 .26085 .50653 .25326 Metetra
.875 .814 .786 r
.50653 .25326 .51393 .26085 .52741 .24314 .52009 .23611 Metetra
.875 .828 .797 r
.52009 .23611 .52741 .24314 .54086 .2262 .53362 .21968 Metetra
.867 .843 .819 r
.53362 .21968 .54086 .2262 .55427 .21082 .54712 .20475 Metetra
.845 .859 .853 r
.54712 .20475 .55427 .21082 .5677 .19774 .56062 .19203 Metetra
.798 .87 .901 r
.56062 .19203 .5677 .19774 .58117 .18765 .57417 .18218 Metetra
.704 .862 .957 r
.57417 .18218 .58117 .18765 .59475 .18115 .58782 .17576 Metetra
.527 .803 .996 r
.58782 .17576 .59475 .18115 .60849 .17867 .60161 .1732 Metetra
.251 .65 .963 r
.60161 .1732 .60849 .17867 .62246 .18048 .61563 .17476 Metetra
0 .427 .838 r
.61563 .17476 .62246 .18048 .63672 .18663 .62992 .18047 Metetra
0 .222 .689 r
.62992 .18047 .63672 .18663 .65134 .19685 .64454 .19007 Metetra
0 .09 .586 r
.64454 .19007 .65134 .19685 .66632 .21049 .65951 .20295 Metetra
0 .032 .547 r
.65951 .20295 .66632 .21049 .68168 .22644 .67484 .21801 Metetra
0 .048 .576 r
.67484 .21801 .68168 .22644 .69735 .24291 .69047 .23355 Metetra
0 .155 .682 r
.69047 .23355 .69735 .24291 .71318 .25742 .70627 .24718 Metetra
.058 .381 .845 r
.70627 .24718 .71318 .25742 .72893 .26659 .72199 .25568 Metetra
.513 .65 .919 r
.72199 .25568 .72893 .26659 .74421 .26614 .7373 .25495 Metetra
.826 .774 .803 r
.7373 .25495 .74421 .26614 .75851 .25098 .75169 .24012 Metetra
.946 .784 .648 r
.75169 .24012 .75851 .25098 .77113 .21549 .76452 .20582 Metetra
.892 .468 .133 r
.10334 .42686 .11206 .43453 .12047 .45811 .11185 .44925 Metetra
.063 .432 .872 r
.11185 .44925 .12047 .45811 .13135 .46316 .12275 .45406 Metetra
.74 .737 .849 r
.12275 .45406 .13135 .46316 .14391 .45478 .13529 .44613 Metetra
.837 .752 .77 r
.13529 .44613 .14391 .45478 .15749 .43753 .14883 .42977 Metetra
.87 .761 .739 r
.14883 .42977 .15749 .43753 .17158 .41528 .16288 .40865 Metetra
.887 .774 .731 r
.16288 .40865 .17158 .41528 .18579 .3911 .17706 .38565 Metetra
.896 .792 .737 r
.17706 .38565 .18579 .3911 .19988 .36731 .19112 .36299 Metetra
.901 .816 .755 r
.19112 .36299 .19988 .36731 .21369 .34554 .20492 .34222 Metetra
.898 .847 .786 r
.20492 .34222 .21369 .34554 .22712 .32688 .21836 .32438 Metetra
.88 .886 .833 r
.21836 .32438 .22712 .32688 .24017 .31196 .23142 .31008 Metetra
.83 .926 .897 r
.23142 .31008 .24017 .31196 .25283 .30107 .24413 .29958 Metetra
.706 .942 .96 r
.24413 .29958 .25283 .30107 .26518 .29419 .25652 .29289 Metetra
.448 .861 .957 r
.25652 .29289 .26518 .29419 .27725 .29109 .26865 .28978 Metetra
.094 .643 .823 r
.26865 .28978 .27725 .29109 .28914 .29137 .28059 .28988 Metetra
.199 0 0 r
.28059 .28988 .28914 .29137 .30091 .2945 .29243 .29267 Metetra
.37 0 0 r
.29243 .29267 .30091 .2945 .31265 .29983 .30423 .29755 Metetra
.45 0 0 r
.30423 .29755 .31265 .29983 .32443 .30667 .31607 .30385 Metetra
.469 0 0 r
.31607 .30385 .32443 .30667 .33631 .31427 .32801 .31087 Metetra
.433 0 0 r
.32801 .31087 .33631 .31427 .34834 .32188 .3401 .31788 Metetra
.338 0 0 r
.3401 .31788 .34834 .32188 .36057 .32878 .35238 .3242 Metetra
0 .376 .752 r
.35238 .3242 .36057 .32878 .37302 .3343 .36488 .3292 Metetra
.057 .539 .891 r
.36488 .3292 .37302 .3343 .3857 .33784 .37761 .33231 Metetra
.303 .683 .976 r
.37761 .33231 .3857 .33784 .39861 .33893 .39057 .33309 Metetra
.506 .775 .992 r
.39057 .33309 .39861 .33893 .41172 .33725 .40374 .33122 Metetra
.648 .821 .966 r
.40374 .33122 .41172 .33725 .42502 .3326 .41709 .32653 Metetra
.74 .842 .927 r
.41709 .32653 .42502 .3326 .43847 .32499 .43059 .31903 Metetra
.8 .852 .889 r
.43059 .31903 .43847 .32499 .45202 .31458 .4442 .30885 Metetra
.84 .858 .858 r
.4442 .30885 .45202 .31458 .46564 .30168 .45789 .2963 Metetra
.867 .865 .834 r
.45789 .2963 .46564 .30168 .47928 .28675 .47161 .28183 Metetra
.885 .873 .819 r
.47161 .28183 .47928 .28675 .49292 .27039 .48533 .26597 Metetra
.897 .883 .812 r
.48533 .26597 .49292 .27039 .50653 .25326 .49902 .24937 Metetra
.902 .897 .813 r
.49902 .24937 .50653 .25326 .52009 .23611 .51268 .23273 Metetra
.899 .913 .823 r
.51268 .23273 .52009 .23611 .53362 .21968 .5263 .21678 Metetra
.885 .933 .845 r
.5263 .21678 .53362 .21968 .54712 .20475 .5399 .20223 Metetra
.852 .953 .879 r
.5399 .20223 .54712 .20475 .56062 .19203 .5535 .18977 Metetra
.783 .963 .923 r
.5535 .18977 .56062 .19203 .57417 .18218 .56714 .18004 Metetra
.646 .94 .963 r
.56714 .18004 .57417 .18218 .58782 .17576 .58087 .17355 Metetra
.407 .835 .958 r
.58087 .17355 .58782 .17576 .60161 .1732 .59473 .17073 Metetra
.091 .625 .863 r
.59473 .17073 .60161 .1732 .61563 .17476 .6088 .1718 Metetra
0 .379 .712 r
.6088 .1718 .61563 .17476 .62992 .18047 .62312 .17681 Metetra
.383 0 0 r
.62312 .17681 .62992 .18047 .64454 .19007 .63775 .1855 Metetra
.477 0 0 r
.63775 .1855 .64454 .19007 .65951 .20295 .65271 .19727 Metetra
.496 0 0 r
.65271 .19727 .65951 .20295 .67484 .21801 .66801 .21107 Metetra
0 .057 .558 r
.66801 .21107 .67484 .21801 .69047 .23355 .68359 .2253 Metetra
0 .179 .688 r
.68359 .2253 .69047 .23355 .70627 .24718 .69934 .23767 Metetra
.074 .415 .864 r
.69934 .23767 .70627 .24718 .72199 .25568 .71503 .24514 Metetra
.528 .669 .927 r
.71503 .24514 .72199 .25568 .7373 .25495 .73035 .24385 Metetra
.825 .778 .807 r
.73035 .24385 .7373 .25495 .75169 .24012 .74482 .22919 Metetra
.943 .785 .656 r
.74482 .22919 .75169 .24012 .76452 .20582 .75785 .19605 Metetra
.883 .449 .105 r
.09455 .41912 .10334 .42686 .11185 .44925 .10316 .4403 Metetra
.071 .436 .875 r
.10316 .4403 .11185 .44925 .12275 .45406 .11407 .44503 Metetra
.727 .738 .86 r
.11407 .44503 .12275 .45406 .13529 .44613 .12655 .43781 Metetra
.831 .759 .783 r
.12655 .43781 .13529 .44613 .14883 .42977 .14001 .42268 Metetra
.869 .774 .754 r
.14001 .42268 .14883 .42977 .16288 .40865 .15396 .40305 Metetra
.89 .793 .747 r
.15396 .40305 .16288 .40865 .17706 .38565 .16806 .38163 Metetra
.903 .819 .754 r
.16806 .38163 .17706 .38565 .19112 .36299 .18206 .36047 Metetra
.91 .853 .774 r
.18206 .36047 .19112 .36299 .20492 .34222 .19582 .34104 Metetra
.906 .898 .808 r
.19582 .34104 .20492 .34222 .21836 .32438 .20924 .32433 Metetra
.877 .948 .854 r
.20924 .32433 .21836 .32438 .23142 .31008 .22231 .31091 Metetra
.786 .985 .898 r
.22231 .31091 .23142 .31008 .24413 .29958 .23504 .30104 Metetra
.561 .936 .879 r
.23504 .30104 .24413 .29958 .25652 .29289 .24746 .29473 Metetra
.196 .722 .723 r
.24746 .29473 .25652 .29289 .26865 .28978 .25964 .29177 Metetra
.141 0 0 r
.25964 .29177 .26865 .28978 .28059 .28988 .27165 .2918 Metetra
.352 0 0 r
.27165 .2918 .28059 .28988 .29243 .29267 .28356 .29435 Metetra
.468 0 0 r
.28356 .29435 .29243 .29267 .30423 .29755 .29544 .29884 Metetra
.525 0 0 r
.29544 .29884 .30423 .29755 .31607 .30385 .30735 .30464 Metetra
.543 0 0 r
.30735 .30464 .31607 .30385 .32801 .31087 .31937 .31109 Metetra
.526 0 0 r
.31937 .31109 .32801 .31087 .3401 .31788 .33154 .31751 Metetra
.468 0 0 r
.33154 .31751 .3401 .31788 .35238 .3242 .34389 .32326 Metetra
.353 0 0 r
.34389 .32326 .35238 .3242 .36488 .3292 .35646 .32773 Metetra
.164 0 0 r
.35646 .32773 .36488 .3292 .37761 .33231 .36926 .3304 Metetra
.095 .638 .844 r
.36926 .3304 .37761 .33231 .39057 .33309 .38228 .33086 Metetra
.365 .807 .955 r
.38228 .33086 .39057 .33309 .40374 .33122 .39551 .32881 Metetra
.575 .901 .982 r
.39551 .32881 .40374 .33122 .41709 .32653 .40893 .32409 Metetra
.711 .939 .96 r
.40893 .32409 .41709 .32653 .43059 .31903 .42251 .31669 Metetra
.794 .95 .922 r
.42251 .31669 .43059 .31903 .4442 .30885 .4362 .30676 Metetra
.844 .952 .886 r
.4362 .30676 .4442 .30885 .45789 .2963 .44996 .29458 Metetra
.875 .953 .856 r
.44996 .29458 .45789 .2963 .47161 .28183 .46377 .28056 Metetra
.893 .957 .834 r
.46377 .28056 .47161 .28183 .48533 .26597 .47758 .26521 Metetra
.9 .964 .82 r
.47758 .26521 .48533 .26597 .49902 .24937 .49138 .24914 Metetra
.898 .974 .814 r
.49138 .24914 .49902 .24937 .51268 .23273 .50515 .23301 Metetra
.883 .986 .815 r
.50515 .23301 .51268 .23273 .5263 .21678 .51889 .21749 Metetra
.85 .997 .822 r
.51889 .21749 .5263 .21678 .5399 .20223 .5326 .20326 Metetra
.785 .999 .833 r
.5326 .20326 .5399 .20223 .5535 .18977 .54631 .19098 Metetra
.669 .975 .838 r
.54631 .19098 .5535 .18977 .56714 .18004 .56005 .18124 Metetra
.477 .895 .818 r
.56005 .18124 .56714 .18004 .58087 .17355 .57387 .17454 Metetra
.213 .735 .749 r
.57387 .17454 .58087 .17355 .59473 .17073 .58782 .17126 Metetra
.068 0 0 r
.58782 .17126 .59473 .17073 .6088 .1718 .60194 .17162 Metetra
.292 0 0 r
.60194 .17162 .6088 .1718 .62312 .17681 .61631 .17565 Metetra
.437 0 0 r
.61631 .17565 .62312 .17681 .63775 .1855 .63095 .18311 Metetra
.509 0 0 r
.63095 .18311 .63775 .1855 .65271 .19727 .64591 .19342 Metetra
.516 0 0 r
.64591 .19342 .65271 .19727 .66801 .21107 .66117 .20558 Metetra
.445 0 0 r
.66117 .20558 .66801 .21107 .68359 .2253 .6767 .2181 Metetra
0 .224 .709 r
.6767 .2181 .68359 .2253 .69934 .23767 .69238 .22883 Metetra
.115 .466 .891 r
.69238 .22883 .69934 .23767 .71503 .24514 .70803 .23493 Metetra
.554 .693 .932 r
.70803 .23493 .71503 .24514 .73035 .24385 .72334 .2328 Metetra
.826 .781 .809 r
.72334 .2328 .73035 .24385 .74482 .22919 .73788 .21814 Metetra
.939 .786 .664 r
.73788 .21814 .74482 .22919 .75785 .19605 .75112 .18618 Metetra
.87 .427 .07 r
.08568 .41132 .09455 .41912 .10316 .4403 .09441 .43122 Metetra
.07 .434 .874 r
.09441 .43122 .10316 .4403 .11407 .44503 .10531 .43596 Metetra
.706 .735 .873 r
.10531 .43596 .11407 .44503 .12655 .43781 .11771 .42969 Metetra
.821 .766 .801 r
.11771 .42969 .12655 .43781 .14001 .42268 .13104 .41611 Metetra
.865 .787 .773 r
.13104 .41611 .14001 .42268 .15396 .40305 .14485 .39833 Metetra
.89 .814 .767 r
.14485 .39833 .15396 .40305 .16806 .38163 .15882 .37885 Metetra
.906 .849 .776 r
.15882 .37885 .16806 .38163 .18206 .36047 .17271 .35955 Metetra
.912 .895 .798 r
.17271 .35955 .18206 .36047 .19582 .34104 .18638 .3418 Metetra
.899 .949 .829 r
.18638 .3418 .19582 .34104 .20924 .32433 .19976 .32652 Metetra
.833 .994 .853 r
.19976 .32652 .20924 .32433 .22231 .31091 .21281 .31425 Metetra
.649 .967 .821 r
.21281 .31425 .22231 .31091 .23504 .30104 .22554 .30524 Metetra
.312 .779 .659 r
.22554 .30524 .23504 .30104 .24746 .29473 .238 .29948 Metetra
.039 0 0 r
.238 .29948 .24746 .29473 .25964 .29177 .25024 .29681 Metetra
.279 0 0 r
.25024 .29681 .25964 .29177 .27165 .2918 .26231 .29687 Metetra
.419 0 0 r
.26231 .29687 .27165 .2918 .28356 .29435 .2743 .29924 Metetra
.498 0 0 r
.2743 .29924 .28356 .29435 .29544 .29884 .28626 .30338 Metetra
.54 .014 0 r
.28626 .30338 .29544 .29884 .30735 .30464 .29827 .30869 Metetra
.554 .024 0 r
.29827 .30869 .30735 .30464 .31937 .31109 .31038 .31457 Metetra
.544 .003 0 r
.31038 .31457 .31937 .31109 .33154 .31751 .32264 .32038 Metetra
.505 0 0 r
.32264 .32038 .33154 .31751 .34389 .32326 .33508 .32552 Metetra
.428 0 0 r
.33508 .32552 .34389 .32326 .35646 .32773 .34774 .32945 Metetra
.297 0 0 r
.34774 .32945 .35646 .32773 .36926 .3304 .36062 .33166 Metetra
.097 0 0 r
.36062 .33166 .36926 .3304 .38228 .33086 .37373 .33179 Metetra
.156 .697 .745 r
.37373 .33179 .38228 .33086 .39551 .32881 .38704 .32954 Metetra
.404 .858 .853 r
.38704 .32954 .39551 .32881 .40893 .32409 .40054 .32479 Metetra
.592 .948 .889 r
.40054 .32479 .40893 .32409 .42251 .31669 .4142 .31752 Metetra
.712 .985 .881 r
.4142 .31752 .42251 .31669 .4362 .30676 .42798 .30785 Metetra
.784 .997 .856 r
.42798 .30785 .4362 .30676 .44996 .29458 .44184 .29606 Metetra
.823 .999 .828 r
.44184 .29606 .44996 .29458 .46377 .28056 .45575 .28253 Metetra
.841 .999 .801 r
.45575 .28253 .46377 .28056 .47758 .26521 .46967 .26772 Metetra
.842 .998 .778 r
.46967 .26772 .47758 .26521 .49138 .24914 .48358 .2522 Metetra
.825 .995 .756 r
.48358 .2522 .49138 .24914 .50515 .23301 .49747 .23657 Metetra
.787 .987 .736 r
.49747 .23657 .50515 .23301 .51889 .21749 .51134 .22148 Metetra
.721 .967 .712 r
.51134 .22148 .51889 .21749 .5326 .20326 .52518 .20755 Metetra
.617 .926 .681 r
.52518 .20755 .5326 .20326 .54631 .19098 .53901 .19539 Metetra
.466 .851 .636 r
.53901 .19539 .54631 .19098 .56005 .18124 .55287 .18555 Metetra
.55287 .18555 .56005 .18124 .57387 .17454 .5668 .17849 Metetra
.5668 .17849 .57387 .17454 .58782 .17126 .58084 .17458 Metetra
.158 0 0 r
.58084 .17458 .58782 .17126 .60194 .17162 .59505 .17401 Metetra
.325 0 0 r
.59505 .17401 .60194 .17162 .61631 .17565 .60946 .17679 Metetra
.44 0 0 r
.60946 .17679 .61631 .17565 .63095 .18311 .62413 .1827 Metetra
.5 0 0 r
.62413 .1827 .63095 .18311 .64591 .19342 .63907 .19121 Metetra
.5 0 0 r
.63907 .19121 .64591 .19342 .66117 .20558 .6543 .20137 Metetra
.416 0 0 r
.6543 .20137 .66117 .20558 .6767 .2181 .66977 .21179 Metetra
0 .299 .75 r
.66977 .21179 .6767 .2181 .69238 .22883 .68539 .22051 Metetra
.187 .533 .924 r
.68539 .22051 .69238 .22883 .70803 .23493 .70098 .2249 Metetra
.588 .717 .932 r
.70098 .2249 .70803 .23493 .72334 .2328 .71627 .22168 Metetra
.827 .782 .809 r
.71627 .22168 .72334 .2328 .73788 .21814 .73088 .20692 Metetra
.934 .786 .673 r
.73088 .20692 .73788 .21814 .75112 .18618 .74431 .17622 Metetra
.853 .397 .026 r
.07673 .40345 .08568 .41132 .09441 .43122 .08561 .42191 Metetra
.071 .43 .872 r
.08561 .42191 .09441 .43122 .10531 .43596 .0965 .4267 Metetra
.677 .725 .886 r
.0965 .4267 .10531 .43596 .11771 .42969 .10878 .42154 Metetra
.803 .767 .821 r
.10878 .42154 .11771 .42969 .13104 .41611 .12194 .40976 Metetra
.853 .798 .796 r
.12194 .40976 .13104 .41611 .14485 .39833 .13557 .39415 Metetra
.883 .834 .793 r
.13557 .39415 .14485 .39833 .15882 .37885 .14936 .37694 Metetra
.901 .879 .805 r
.14936 .37694 .15882 .37885 .17271 .35955 .1631 .35984 Metetra
.902 .935 .825 r
.1631 .35984 .17271 .35955 .18638 .3418 .17665 .34409 Metetra
.862 .987 .842 r
.17665 .34409 .18638 .3418 .19976 .32652 .18995 .33051 Metetra
.726 .988 .812 r
.18995 .33051 .19976 .32652 .21281 .31425 .20295 .31962 Metetra
.438 .846 .667 r
.20295 .31962 .21281 .31425 .22554 .30524 .21568 .31165 Metetra
.21568 .31165 .22554 .30524 .238 .29948 .22817 .30659 Metetra
.179 0 0 r
.22817 .30659 .238 .29948 .25024 .29681 .24045 .30429 Metetra
.344 0 0 r
.24045 .30429 .25024 .29681 .26231 .29687 .2526 .30445 Metetra
.443 0 0 r
.2526 .30445 .26231 .29687 .2743 .29924 .26467 .30666 Metetra
.501 .008 .016 r
.26467 .30666 .2743 .29924 .28626 .30338 .27674 .31043 Metetra
.533 .038 .028 r
.27674 .31043 .28626 .30338 .29827 .30869 .28885 .31523 Metetra
.543 .043 .017 r
.28885 .31523 .29827 .30869 .31038 .31457 .30107 .32048 Metetra
.534 .023 0 r
.30107 .32048 .31038 .31457 .32264 .32038 .31344 .32563 Metetra
.502 0 0 r
.31344 .32563 .32264 .32038 .33508 .32552 .32599 .33011 Metetra
.441 0 0 r
.32599 .33011 .33508 .32552 .34774 .32945 .33875 .33343 Metetra
.338 0 0 r
.33875 .33343 .34774 .32945 .36062 .33166 .35173 .33514 Metetra
.183 0 0 r
.35173 .33514 .36062 .33166 .37373 .33179 .36493 .3349 Metetra
.36493 .3349 .37373 .33179 .38704 .32954 .37834 .33245 Metetra
.247 .747 .681 r
.37834 .33245 .38704 .32954 .40054 .32479 .39193 .32766 Metetra
.443 .87 .756 r
.39193 .32766 .40054 .32479 .4142 .31752 .40568 .32053 Metetra
.584 .937 .781 r
.40568 .32053 .4142 .31752 .42798 .30785 .41955 .31117 Metetra
.672 .968 .775 r
.41955 .31117 .42798 .30785 .44184 .29606 .43352 .29983 Metetra
.72 .977 .754 r
.43352 .29983 .44184 .29606 .45575 .28253 .44753 .28683 Metetra
.738 .975 .726 r
.44753 .28683 .45575 .28253 .46967 .26772 .46157 .27263 Metetra
.73 .964 .693 r
.46157 .27263 .46967 .26772 .48358 .2522 .47561 .25772 Metetra
.699 .945 .657 r
.47561 .25772 .48358 .2522 .49747 .23657 .48963 .24266 Metetra
.642 .914 .616 r
.48963 .24266 .49747 .23657 .51134 .22148 .50363 .22803 Metetra
.556 .866 .568 r
.50363 .22803 .51134 .22148 .52518 .20755 .51761 .2144 Metetra
.51761 .2144 .52518 .20755 .53901 .19539 .53158 .20234 Metetra
.53158 .20234 .53901 .19539 .55287 .18555 .54558 .19235 Metetra
.54558 .19235 .55287 .18555 .5668 .17849 .55963 .18484 Metetra
.031 0 0 r
.55963 .18484 .5668 .17849 .58084 .17458 .57378 .18015 Metetra
.183 0 0 r
.57378 .18015 .58084 .17458 .59505 .17401 .58807 .17845 Metetra
.309 0 0 r
.58807 .17845 .59505 .17401 .60946 .17679 .60254 .17976 Metetra
.402 0 0 r
.60254 .17976 .60946 .17679 .62413 .1827 .61724 .18385 Metetra
.452 0 0 r
.61724 .18385 .62413 .1827 .63907 .19121 .63218 .19022 Metetra
.443 0 0 r
.63218 .19022 .63907 .19121 .6543 .20137 .64738 .19804 Metetra
.339 0 0 r
.64738 .19804 .6543 .20137 .66977 .21179 .66279 .20602 Metetra
0 .407 .818 r
.66279 .20602 .66977 .21179 .68539 .22051 .67834 .2124 Metetra
.291 .609 .954 r
.67834 .2124 .68539 .22051 .70098 .2249 .69386 .21482 Metetra
.628 .736 .925 r
.69386 .21482 .70098 .2249 .71627 .22168 .70913 .21034 Metetra
.827 .779 .807 r
.70913 .21034 .71627 .22168 .73088 .20692 .7238 .19543 Metetra
.928 .785 .683 r
.7238 .19543 .73088 .20692 .74431 .17622 .73744 .16616 Metetra
.824 .353 0 r
.06771 .39551 .07673 .40345 .08561 .42191 .07677 .41224 Metetra
.088 .432 .873 r
.07677 .41224 .08561 .42191 .0965 .4267 .08766 .41699 Metetra
.641 .706 .894 r
.08766 .41699 .0965 .4267 .10878 .42154 .09982 .41302 Metetra
.774 .761 .841 r
.09982 .41302 .10878 .42154 .12194 .40976 .11277 .40321 Metetra
.832 .801 .822 r
.11277 .40321 .12194 .40976 .13557 .39415 .12617 .38999 Metetra
.866 .847 .823 r
.12617 .38999 .13557 .39415 .14936 .37694 .13974 .37531 Metetra
.883 .903 .838 r
.13974 .37531 .14936 .37694 .1631 .35984 .15328 .36067 Metetra
.872 .964 .856 r
.15328 .36067 .1631 .35984 .17665 .34409 .16668 .34716 Metetra
.792 .998 .846 r
.16668 .34716 .17665 .34409 .18995 .33051 .17987 .3355 Metetra
.579 .928 .743 r
.17987 .3355 .18995 .33051 .20295 .31962 .19281 .32617 Metetra
.19281 .32617 .20295 .31962 .21568 .31165 .20552 .31935 Metetra
.046 0 0 r
.20552 .31935 .21568 .31165 .22817 .30659 .21802 .31507 Metetra
.245 0 0 r
.21802 .31507 .22817 .30659 .24045 .30429 .23036 .31318 Metetra
.369 0 0 r
.23036 .31318 .24045 .30429 .2526 .30445 .24258 .31342 Metetra
.444 0 .015 r
.24258 .31342 .2526 .30445 .26467 .30666 .25476 .31542 Metetra
.49 .01 .042 r
.25476 .31542 .26467 .30666 .27674 .31043 .26694 .31874 Metetra
.514 .031 .046 r
.26694 .31874 .27674 .31043 .28885 .31523 .27917 .32292 Metetra
.521 .03 .031 r
.27917 .32292 .28885 .31523 .30107 .32048 .29152 .32744 Metetra
.51 .006 0 r
.29152 .32744 .30107 .32048 .31344 .32563 .30401 .3318 Metetra
.477 0 0 r
.30401 .3318 .31344 .32563 .32599 .33011 .31669 .33551 Metetra
.416 0 0 r
.31669 .33551 .32599 .33011 .33875 .33343 .32957 .33812 Metetra
.318 0 0 r
.32957 .33812 .33875 .33343 .35173 .33514 .34266 .33925 Metetra
.175 0 0 r
.34266 .33925 .35173 .33514 .36493 .3349 .35596 .33857 Metetra
.35596 .33857 .36493 .3349 .37834 .33245 .36947 .33588 Metetra
.36947 .33588 .37834 .33245 .39193 .32766 .38315 .33107 Metetra
.391 .834 .714 r
.38315 .33107 .39193 .32766 .40568 .32053 .397 .32411 Metetra
.524 .905 .743 r
.397 .32411 .40568 .32053 .41955 .31117 .41097 .31512 Metetra
.608 .938 .74 r
.41097 .31512 .41955 .31117 .43352 .29983 .42503 .30429 Metetra
.652 .949 .719 r
.42503 .30429 .43352 .29983 .44753 .28683 .43915 .29195 Metetra
.665 .944 .686 r
.43915 .29195 .44753 .28683 .46157 .27263 .4533 .27847 Metetra
.65 .927 .646 r
.4533 .27847 .46157 .27263 .47561 .25772 .46747 .26429 Metetra
.61 .897 .599 r
.46747 .26429 .47561 .25772 .48963 .24266 .48162 .24991 Metetra
.544 .852 .546 r
.48162 .24991 .48963 .24266 .50363 .22803 .49576 .23585 Metetra
.49576 .23585 .50363 .22803 .51761 .2144 .50988 .22261 Metetra
.50988 .22261 .51761 .2144 .53158 .20234 .524 .2107 Metetra
.524 .2107 .53158 .20234 .54558 .19235 .53814 .20057 Metetra
.53814 .20057 .54558 .19235 .55963 .18484 .55233 .19258 Metetra
.04 0 0 r
.55233 .19258 .55963 .18484 .57378 .18015 .56659 .18704 Metetra
.157 0 0 r
.56659 .18704 .57378 .18015 .58807 .17845 .58098 .18408 Metetra
.255 0 0 r
.58098 .18408 .58807 .17845 .60254 .17976 .59552 .18373 Metetra
.327 0 0 r
.59552 .18373 .60254 .17976 .61724 .18385 .61026 .18578 Metetra
.361 0 0 r
.61026 .18578 .61724 .18385 .63218 .19022 .62521 .18978 Metetra
.33 0 0 r
.62521 .18978 .63218 .19022 .64738 .19804 .64037 .19498 Metetra
0 .384 .715 r
.64037 .19498 .64738 .19804 .66279 .20602 .65573 .20025 Metetra
.084 .543 .905 r
.65573 .20025 .66279 .20602 .67834 .2124 .6712 .20405 Metetra
.412 .676 .97 r
.6712 .20405 .67834 .2124 .69386 .21482 .68666 .20432 Metetra
.665 .744 .909 r
.68666 .20432 .69386 .21482 .70913 .21034 .7019 .19851 Metetra
.823 .771 .804 r
.7019 .19851 .70913 .21034 .7238 .19543 .71665 .18355 Metetra
.918 .782 .696 r
.71665 .18355 .7238 .19543 .73744 .16616 .7305 .156 Metetra
.772 .279 0 r
.05861 .3875 .06771 .39551 .07677 .41224 .06794 .40204 Metetra
.136 .449 .881 r
.06794 .40204 .07677 .41224 .08766 .41699 .07886 .4065 Metetra
.603 .677 .893 r
.07886 .4065 .08766 .41699 .09982 .41302 .09088 .40362 Metetra
.735 .739 .855 r
.09088 .40362 .09982 .41302 .11277 .40321 .10362 .39581 Metetra
.796 .788 .845 r
.10362 .39581 .11277 .40321 .12617 .38999 .11676 .38508 Metetra
.832 .843 .855 r
.11676 .38508 .12617 .38999 .13974 .37531 .13007 .37308 Metetra
.848 .908 .876 r
.13007 .37308 .13974 .37531 .15328 .36067 .14338 .36104 Metetra
.825 .971 .892 r
.14338 .36104 .15328 .36067 .16668 .34716 .15659 .3499 Metetra
.713 .987 .861 r
.15659 .3499 .16668 .34716 .17987 .3355 .16964 .34028 Metetra
.465 .872 .716 r
.16964 .34028 .17987 .3355 .19281 .32617 .18251 .33256 Metetra
.18251 .33256 .19281 .32617 .20552 .31935 .19518 .32693 Metetra
.094 0 0 r
.19518 .32693 .20552 .31935 .21802 .31507 .2077 .3234 Metetra
.256 0 0 r
.2077 .3234 .21802 .31507 .23036 .31318 .2201 .32184 Metetra
.358 0 0 r
.2201 .32184 .23036 .31318 .24258 .31342 .23241 .32203 Metetra
.422 0 0 r
.23241 .32203 .24258 .31342 .25476 .31542 .2447 .32367 Metetra
.46 0 0 r
.2447 .32367 .25476 .31542 .26694 .31874 .25701 .32637 Metetra
.478 0 0 r
.25701 .32637 .26694 .31874 .27917 .32292 .26939 .32972 Metetra
.478 0 0 r
.26939 .32972 .27917 .32292 .29152 .32744 .28188 .3333 Metetra
.458 0 0 r
.28188 .3333 .29152 .32744 .30401 .3318 .29451 .33667 Metetra
.412 0 0 r
.29451 .33667 .30401 .3318 .31669 .33551 .30732 .33942 Metetra
.332 0 0 r
.30732 .33942 .31669 .33551 .32957 .33812 .32033 .34116 Metetra
.207 0 0 r
.32033 .34116 .32957 .33812 .34266 .33925 .33353 .34157 Metetra
.036 0 0 r
.33353 .34157 .34266 .33925 .35596 .33857 .34694 .34038 Metetra
.163 .698 .706 r
.34694 .34038 .35596 .33857 .36947 .33588 .36054 .3374 Metetra
.352 .827 .801 r
.36054 .3374 .36947 .33588 .38315 .33107 .37432 .33255 Metetra
.502 .909 .843 r
.37432 .33255 .38315 .33107 .397 .32411 .38824 .32581 Metetra
.604 .953 .848 r
.38824 .32581 .397 .32411 .41097 .31512 .40229 .31727 Metetra
.666 .973 .83 r
.40229 .31727 .41097 .31512 .42503 .30429 .41644 .3071 Metetra
.697 .979 .8 r
.41644 .3071 .42503 .30429 .43915 .29195 .43066 .29556 Metetra
.7 .973 .76 r
.43066 .29556 .43915 .29195 .4533 .27847 .44491 .28299 Metetra
.678 .956 .713 r
.44491 .28299 .4533 .27847 .46747 .26429 .45919 .26974 Metetra
.632 .925 .659 r
.45919 .26974 .46747 .26429 .48162 .24991 .47346 .25625 Metetra
.562 .878 .597 r
.47346 .25625 .48162 .24991 .49576 .23585 .48773 .24296 Metetra
.47 .815 .529 r
.48773 .24296 .49576 .23585 .50988 .22261 .502 .2303 Metetra
.502 .2303 .50988 .22261 .524 .2107 .51626 .2187 Metetra
.51626 .2187 .524 .2107 .53814 .20057 .53054 .20855 Metetra
.53054 .20855 .53814 .20057 .55233 .19258 .54486 .20016 Metetra
.54486 .20016 .55233 .19258 .56659 .18704 .55925 .19378 Metetra
.072 0 0 r
.55925 .19378 .56659 .18704 .58098 .18408 .57374 .18956 Metetra
.148 0 0 r
.57374 .18956 .58098 .18408 .59552 .18373 .58836 .18747 Metetra
.195 0 0 r
.58836 .18747 .59552 .18373 .61026 .18578 .60314 .18736 Metetra
.197 0 0 r
.60314 .18736 .61026 .18578 .62521 .18978 .6181 .18884 Metetra
.124 0 0 r
.6181 .18884 .62521 .18978 .64037 .19498 .63324 .19126 Metetra
.055 .577 .871 r
.63324 .19126 .64037 .19498 .65573 .20025 .64855 .19368 Metetra
.302 .668 .974 r
.64855 .19368 .65573 .20025 .6712 .20405 .66395 .19479 Metetra
.526 .713 .958 r
.66395 .19479 .6712 .20405 .68666 .20432 .67934 .19289 Metetra
.692 .736 .885 r
.67934 .19289 .68666 .20432 .7019 .19851 .69457 .18584 Metetra
.813 .756 .799 r
.69457 .18584 .7019 .19851 .71665 .18355 .70939 .17109 Metetra
.903 .776 .711 r
.70939 .17109 .71665 .18355 .7305 .156 .7235 .14574 Metetra
.656 .14 0 r
.04942 .37942 .05861 .3875 .06794 .40204 .05914 .39108 Metetra
.229 .485 .892 r
.05914 .39108 .06794 .40204 .07886 .4065 .07015 .39478 Metetra
.574 .641 .879 r
.07015 .39478 .07886 .4065 .09088 .40362 .08207 .3927 Metetra
.688 .699 .855 r
.08207 .3927 .09088 .40362 .10362 .39581 .0946 .3867 Metetra
.746 .749 .855 r
.0946 .3867 .10362 .39581 .11676 .38508 .10747 .37838 Metetra
.781 .808 .874 r
.10747 .37838 .11676 .38508 .13007 .37308 .1205 .369 Metetra
.797 .876 .905 r
.1205 .369 .13007 .37308 .14338 .36104 .13357 .35955 Metetra
.775 .943 .934 r
.13357 .35955 .14338 .36104 .15659 .3499 .14657 .35075 Metetra
.676 .97 .919 r
.14657 .35075 .15659 .3499 .16964 .34028 .15948 .34311 Metetra
.463 .886 .805 r
.15948 .34311 .16964 .34028 .18251 .33256 .17225 .33692 Metetra
.17225 .33692 .18251 .33256 .19518 .32693 .1849 .33234 Metetra
.031 0 0 r
.1849 .33234 .19518 .32693 .2077 .3234 .19744 .32937 Metetra
.183 0 0 r
.19744 .32937 .2077 .3234 .2201 .32184 .20991 .32792 Metetra
.28 0 0 r
.20991 .32792 .2201 .32184 .23241 .32203 .22233 .3278 Metetra
.338 0 0 r
.22233 .3278 .23241 .32203 .2447 .32367 .23475 .32877 Metetra
.367 0 0 r
.23475 .32877 .2447 .32367 .25701 .32637 .24721 .33052 Metetra
.37 0 0 r
.24721 .33052 .25701 .32637 .26939 .32972 .25974 .33272 Metetra
.345 0 0 r
.25974 .33272 .26939 .32972 .28188 .3333 .27239 .33504 Metetra
.282 0 0 r
.27239 .33504 .28188 .3333 .29451 .33667 .28518 .33711 Metetra
.171 0 0 r
.28518 .33711 .29451 .33667 .30732 .33942 .29814 .33861 Metetra
0 .568 .738 r
.29814 .33861 .30732 .33942 .32033 .34116 .31127 .33924 Metetra
.182 .701 .88 r
.31127 .33924 .32033 .34116 .33353 .34157 .32458 .33874 Metetra
.362 .797 .965 r
.32458 .33874 .33353 .34157 .34694 .34038 .33809 .33689 Metetra
.505 .853 .994 r
.33809 .33689 .34694 .34038 .36054 .3374 .35176 .33356 Metetra
.607 .883 .991 r
.35176 .33356 .36054 .3374 .37432 .33255 .36561 .32866 Metetra
.68 .903 .975 r
.36561 .32866 .37432 .33255 .38824 .32581 .37959 .3222 Metetra
.732 .921 .956 r
.37959 .3222 .38824 .32581 .40229 .31727 .3937 .31423 Metetra
.769 .939 .938 r
.3937 .31423 .40229 .31727 .41644 .3071 .4079 .3049 Metetra
.793 .959 .92 r
.4079 .3049 .41644 .3071 .43066 .29556 .42217 .29441 Metetra
.803 .978 .9 r
.42217 .29441 .43066 .29556 .44491 .28299 .43649 .28301 Metetra
.798 .993 .876 r
.43649 .28301 .44491 .28299 .45919 .26974 .45085 .27101 Metetra
.771 .997 .843 r
.45085 .27101 .45919 .26974 .47346 .25625 .46522 .25873 Metetra
.718 .984 .798 r
.46522 .25873 .47346 .25625 .48773 .24296 .4796 .24654 Metetra
.639 .95 .74 r
.4796 .24654 .48773 .24296 .502 .2303 .49398 .23477 Metetra
.537 .893 .674 r
.49398 .23477 .502 .2303 .51626 .2187 .50837 .22379 Metetra
.424 .822 .607 r
.50837 .22379 .51626 .2187 .53054 .20855 .52278 .21388 Metetra
.52278 .21388 .53054 .20855 .54486 .20016 .53723 .20532 Metetra
.53723 .20532 .54486 .20016 .55925 .19378 .55174 .19829 Metetra
.55174 .19829 .55925 .19378 .57374 .18956 .56633 .19292 Metetra
.56633 .19292 .57374 .18956 .58836 .18747 .58103 .18919 Metetra
.58103 .18919 .58836 .18747 .60314 .18736 .59586 .18697 Metetra
.107 .661 .778 r
.59586 .18697 .60314 .18736 .6181 .18884 .61083 .18595 Metetra
.214 .71 .917 r
.61083 .18595 .6181 .18884 .63324 .19126 .62595 .18562 Metetra
.358 .731 .988 r
.62595 .18562 .63324 .19126 .64855 .19368 .6412 .18522 Metetra
.494 .721 .973 r
.6412 .18522 .64855 .19368 .66395 .19479 .65654 .18374 Metetra
.607 .709 .916 r
.65654 .18374 .66395 .19479 .67934 .19289 .67189 .17984 Metetra
.703 .71 .854 r
.67189 .17984 .67934 .19289 .69457 .18584 .68711 .17185 Metetra
.793 .73 .794 r
.68711 .17185 .69457 .18584 .70939 .17109 .70204 .1578 Metetra
.878 .763 .731 r
.70204 .1578 .70939 .17109 .7235 .14574 .71642 .13538 Metetra
0 .144 .624 r
.04016 .37126 .04942 .37942 .05914 .39108 .05042 .37904 Metetra
.364 .535 .891 r
.05042 .37904 .05914 .39108 .07015 .39478 .06164 .38124 Metetra
.566 .604 .85 r
.06164 .38124 .07015 .39478 .08207 .3927 .07353 .37938 Metetra
.644 .642 .834 r
.07353 .37938 .08207 .3927 .0946 .3867 .08587 .37477 Metetra
.687 .682 .84 r
.08587 .37477 .0946 .3867 .10747 .37838 .0985 .3685 Metetra
.715 .73 .862 r
.0985 .3685 .10747 .37838 .1205 .369 .11127 .36146 Metetra
.73 .787 .898 r
.11127 .36146 .1205 .369 .13357 .35955 .12409 .35432 Metetra
.725 .849 .94 r
.12409 .35432 .13357 .35955 .14657 .35075 .1369 .34761 Metetra
.683 .901 .974 r
.1369 .34761 .14657 .35075 .15948 .34311 .14966 .34165 Metetra
.586 .915 .973 r
.14966 .34165 .15948 .34311 .17225 .33692 .16235 .33668 Metetra
.438 .87 .92 r
.16235 .33668 .17225 .33692 .1849 .33234 .17499 .33279 Metetra
.28 .783 .837 r
.17499 .33279 .1849 .33234 .19744 .32937 .18757 .32999 Metetra
.154 .696 .768 r
.18757 .32999 .19744 .32937 .20991 .32792 .20013 .32821 Metetra
.078 .639 .741 r
.20013 .32821 .20991 .32792 .22233 .3278 .21268 .32732 Metetra
.053 .619 .761 r
.21268 .32732 .22233 .3278 .23475 .32877 .22526 .32713 Metetra
.078 .63 .821 r
.22526 .32713 .23475 .32877 .24721 .33052 .2379 .32744 Metetra
.148 .659 .898 r
.2379 .32744 .24721 .33052 .25974 .33272 .25061 .328 Metetra
.246 .684 .959 r
.25061 .328 .25974 .33272 .27239 .33504 .26344 .32857 Metetra
.346 .692 .982 r
.26344 .32857 .27239 .33504 .28518 .33711 .27639 .32891 Metetra
.431 .683 .97 r
.27639 .32891 .28518 .33711 .29814 .33861 .28949 .32878 Metetra
.495 .669 .941 r
.28949 .32878 .29814 .33861 .31127 .33924 .30274 .32797 Metetra
.544 .657 .91 r
.30274 .32797 .31127 .33924 .32458 .33874 .31615 .3263 Metetra
.582 .65 .883 r
.31615 .3263 .32458 .33874 .33809 .33689 .32972 .32362 Metetra
.614 .649 .862 r
.32972 .32362 .33809 .33689 .35176 .33356 .34344 .31983 Metetra
.641 .654 .847 r
.34344 .31983 .35176 .33356 .36561 .32866 .35731 .31489 Metetra
.667 .665 .839 r
.35731 .31489 .36561 .32866 .37959 .3222 .3713 .30877 Metetra
.691 .681 .836 r
.3713 .30877 .37959 .3222 .3937 .31423 .38541 .30154 Metetra
.715 .703 .838 r
.38541 .30154 .3937 .31423 .4079 .3049 .39961 .29329 Metetra
.738 .731 .845 r
.39961 .29329 .4079 .3049 .42217 .29441 .41388 .28415 Metetra
.76 .765 .857 r
.41388 .28415 .42217 .29441 .43649 .28301 .42822 .2743 Metetra
.78 .804 .872 r
.42822 .2743 .43649 .28301 .45085 .27101 .44259 .26396 Metetra
.795 .847 .89 r
.44259 .26396 .45085 .27101 .46522 .25873 .457 .25337 Metetra
.802 .892 .909 r
.457 .25337 .46522 .25873 .4796 .24654 .47144 .24275 Metetra
.794 .933 .923 r
.47144 .24275 .4796 .24654 .49398 .23477 .4859 .23238 Metetra
.767 .963 .93 r
.4859 .23238 .49398 .23477 .50837 .22379 .50038 .22248 Metetra
.717 .974 .925 r
.50038 .22248 .50837 .22379 .52278 .21388 .51489 .21329 Metetra
.65 .964 .913 r
.51489 .21329 .52278 .21388 .53723 .20532 .52944 .20499 Metetra
.578 .941 .903 r
.52944 .20499 .53723 .20532 .55174 .19829 .54405 .19771 Metetra
.518 .914 .908 r
.54405 .19771 .55174 .19829 .56633 .19292 .55872 .19155 Metetra
.483 .891 .933 r
.55872 .19155 .56633 .19292 .58103 .18919 .57349 .18649 Metetra
.477 .869 .97 r
.57349 .18649 .58103 .18919 .59586 .18697 .58836 .18244 Metetra
.497 .836 .998 r
.58836 .18244 .59586 .18697 .61083 .18595 .60335 .17918 Metetra
.529 .788 .992 r
.60335 .17918 .61083 .18595 .62595 .18562 .61845 .17636 Metetra
.564 .734 .955 r
.61845 .17636 .62595 .18562 .6412 .18522 .63366 .17344 Metetra
.601 .69 .905 r
.63366 .17344 .6412 .18522 .65654 .18374 .64895 .16972 Metetra
.643 .667 .858 r
.64895 .16972 .65654 .18374 .67189 .17984 .66426 .16427 Metetra
.694 .666 .819 r
.66426 .16427 .67189 .17984 .68711 .17185 .67951 .15595 Metetra
.758 .69 .787 r
.67951 .15595 .68711 .17185 .70204 .1578 .69456 .14336 Metetra
.837 .739 .757 r
.69456 .14336 .70204 .1578 .71642 .13538 .70927 .12491 Metetra
.212 .557 .934 r
.03081 .36304 .04016 .37126 .05042 .37904 .04185 .36557 Metetra
.511 .58 .861 r
.04185 .36557 .05042 .37904 .06164 .38124 .05344 .36516 Metetra
.583 .573 .808 r
.05344 .36516 .06164 .38124 .07353 .37938 .06542 .36261 Metetra
.616 .582 .792 r
.06542 .36261 .07353 .37938 .08587 .37477 .07768 .3586 Metetra
.637 .6 .795 r
.07768 .3586 .08587 .37477 .0985 .3685 .09012 .35371 Metetra
.652 .625 .81 r
.09012 .35371 .0985 .3685 .11127 .36146 .10267 .34838 Metetra
.662 .656 .834 r
.10267 .34838 .11127 .36146 .12409 .35432 .11529 .34297 Metetra
.665 .689 .863 r
.11529 .34297 .12409 .35432 .1369 .34761 .12793 .33776 Metetra
.66 .721 .894 r
.12793 .33776 .1369 .34761 .14966 .34165 .14059 .33291 Metetra
.646 .744 .921 r
.14059 .33291 .14966 .34165 .16235 .33668 .15324 .32854 Metetra
.625 .755 .94 r
.15324 .32854 .16235 .33668 .17499 .33279 .1659 .32471 Metetra
.602 .75 .948 r
.1659 .32471 .17499 .33279 .18757 .32999 .17857 .32141 Metetra
.582 .731 .945 r
.17857 .32141 .18757 .32999 .20013 .32821 .19126 .31861 Metetra
.569 .7 .93 r
.19126 .31861 .20013 .32821 .21268 .32732 .20398 .31624 Metetra
.561 .662 .905 r
.20398 .31624 .21268 .32732 .22526 .32713 .21675 .31419 Metetra
.557 .622 .873 r
.21675 .31419 .22526 .32713 .2379 .32744 .22959 .31235 Metetra
.556 .585 .838 r
.22959 .31235 .2379 .32744 .25061 .328 .24251 .3106 Metetra
.557 .553 .805 r
.24251 .3106 .25061 .328 .26344 .32857 .25552 .30881 Metetra
.56 .527 .776 r
.25552 .30881 .26344 .32857 .27639 .32891 .26864 .30684 Metetra
.563 .508 .751 r
.26864 .30684 .27639 .32891 .28949 .32878 .28187 .30458 Metetra
.567 .494 .732 r
.28187 .30458 .28949 .32878 .30274 .32797 .29522 .30191 Metetra
.573 .485 .717 r
.29522 .30191 .30274 .32797 .31615 .3263 .3087 .29875 Metetra
.579 .48 .707 r
.3087 .29875 .31615 .3263 .32972 .32362 .32229 .29501 Metetra
.586 .479 .699 r
.32229 .29501 .32972 .32362 .34344 .31983 .336 .29065 Metetra
.593 .481 .696 r
.336 .29065 .34344 .31983 .35731 .31489 .34982 .28563 Metetra
.601 .487 .695 r
.34982 .28563 .35731 .31489 .3713 .30877 .36375 .27996 Metetra
.611 .495 .697 r
.36375 .27996 .3713 .30877 .38541 .30154 .37778 .27366 Metetra
.621 .506 .702 r
.37778 .27366 .38541 .30154 .39961 .29329 .39189 .26677 Metetra
.632 .521 .71 r
.39189 .26677 .39961 .29329 .41388 .28415 .40607 .25938 Metetra
.643 .539 .721 r
.40607 .25938 .41388 .28415 .42822 .2743 .42033 .25156 Metetra
.656 .561 .736 r
.42033 .25156 .42822 .2743 .44259 .26396 .43464 .24344 Metetra
.669 .586 .754 r
.43464 .24344 .44259 .26396 .457 .25337 .449 .23512 Metetra
.682 .616 .776 r
.449 .23512 .457 .25337 .47144 .24275 .46342 .22675 Metetra
.693 .65 .802 r
.46342 .22675 .47144 .24275 .4859 .23238 .47787 .21845 Metetra
.703 .685 .83 r
.47787 .21845 .4859 .23238 .50038 .22248 .49238 .21035 Metetra
.707 .719 .859 r
.49238 .21035 .50038 .22248 .51489 .21329 .50693 .20257 Metetra
.705 .749 .886 r
.50693 .20257 .51489 .21329 .52944 .20499 .52153 .19522 Metetra
.697 .769 .907 r
.52153 .19522 .52944 .20499 .54405 .19771 .5362 .18836 Metetra
.682 .775 .921 r
.5362 .18836 .54405 .19771 .55872 .19155 .55093 .18204 Metetra
.666 .767 .926 r
.55093 .18204 .55872 .19155 .57349 .18649 .56574 .17626 Metetra
.65 .745 .919 r
.56574 .17626 .57349 .18649 .58836 .18244 .58064 .17097 Metetra
.637 .712 .901 r
.58064 .17097 .58836 .18244 .60335 .17918 .59563 .16606 Metetra
.628 .675 .875 r
.59563 .16606 .60335 .17918 .61845 .17636 .61071 .16134 Metetra
.625 .64 .845 r
.61071 .16134 .61845 .17636 .63366 .17344 .62589 .15654 Metetra
.629 .615 .817 r
.62589 .15654 .63366 .17344 .64895 .16972 .64113 .15128 Metetra
.641 .602 .795 r
.64113 .15128 .64895 .16972 .66426 .16427 .65642 .14509 Metetra
.663 .606 .781 r
.65642 .14509 .66426 .16427 .67951 .15595 .67172 .13737 Metetra
.701 .633 .777 r
.67172 .13737 .67951 .15595 .69456 .14336 .68696 .12741 Metetra
.764 .694 .785 r
.68696 .12741 .69456 .14336 .70927 .12491 .70205 .11434 Metetra
.657 .75 .919 r
.02138 .35474 .03081 .36304 .04185 .36557 .03352 .35021 Metetra
.633 .607 .806 r
.03352 .35021 .04185 .36557 .05344 .36516 .04571 .34566 Metetra
.618 .553 .759 r
.04571 .34566 .05344 .36516 .06542 .36261 .05797 .34109 Metetra
.611 .532 .74 r
.05797 .34109 .06542 .36261 .07768 .3586 .07029 .3365 Metetra
.609 .526 .736 r
.07029 .3365 .07768 .3586 .09012 .35371 .08267 .33188 Metetra
.61 .53 .739 r
.08267 .33188 .09012 .35371 .10267 .34838 .09511 .32724 Metetra
.613 .537 .745 r
.09511 .32724 .10267 .34838 .11529 .34297 .10761 .32258 Metetra
.616 .546 .753 r
.10761 .32258 .11529 .34297 .12793 .33776 .12017 .3179 Metetra
.618 .552 .759 r
.12017 .3179 .12793 .33776 .14059 .33291 .1328 .31319 Metetra
.618 .554 .76 r
.1328 .31319 .14059 .33291 .15324 .32854 .14549 .30846 Metetra
.617 .551 .757 r
.14549 .30846 .15324 .32854 .1659 .32471 .15824 .30371 Metetra
.614 .541 .749 r
.15824 .30371 .1659 .32471 .17857 .32141 .17105 .29893 Metetra
.61 .527 .736 r
.17105 .29893 .17857 .32141 .19126 .31861 .18393 .29413 Metetra
.604 .51 .721 r
.18393 .29413 .19126 .31861 .20398 .31624 .19688 .2893 Metetra
.597 .491 .704 r
.19688 .2893 .20398 .31624 .21675 .31419 .20988 .28445 Metetra
.59 .473 .687 r
.20988 .28445 .21675 .31419 .22959 .31235 .22296 .27957 Metetra
.584 .456 .671 r
.22296 .27957 .22959 .31235 .24251 .3106 .2361 .27467 Metetra
.578 .441 .658 r
.2361 .27467 .24251 .3106 .25552 .30881 .24931 .26975 Metetra
.573 .428 .646 r
.24931 .26975 .25552 .30881 .26864 .30684 .26258 .2648 Metetra
.569 .417 .636 r
.26258 .2648 .26864 .30684 .28187 .30458 .27592 .25983 Metetra
.565 .409 .628 r
.27592 .25983 .28187 .30458 .29522 .30191 .28933 .25483 Metetra
.563 .402 .621 r
.28933 .25483 .29522 .30191 .3087 .29875 .30281 .2498 Metetra
.561 .397 .617 r
.30281 .2498 .3087 .29875 .32229 .29501 .31636 .24475 Metetra
.559 .394 .614 r
.31636 .24475 .32229 .29501 .336 .29065 .32997 .23967 Metetra
.559 .392 .612 r
.32997 .23967 .336 .29065 .34982 .28563 .34366 .23457 Metetra
.559 .392 .612 r
.34366 .23457 .34982 .28563 .36375 .27996 .35742 .22944 Metetra
.559 .394 .614 r
.35742 .22944 .36375 .27996 .37778 .27366 .37125 .22428 Metetra
.561 .397 .617 r
.37125 .22428 .37778 .27366 .39189 .26677 .38515 .2191 Metetra
.563 .402 .621 r
.38515 .2191 .39189 .26677 .40607 .25938 .39913 .21389 Metetra
.565 .409 .628 r
.39913 .21389 .40607 .25938 .42033 .25156 .41317 .20865 Metetra
.569 .417 .636 r
.41317 .20865 .42033 .25156 .43464 .24344 .42729 .20338 Metetra
.573 .428 .646 r
.42729 .20338 .43464 .24344 .449 .23512 .44149 .19809 Metetra
.578 .441 .658 r
.44149 .19809 .449 .23512 .46342 .22675 .45576 .19277 Metetra
.584 .456 .671 r
.45576 .19277 .46342 .22675 .47787 .21845 .4701 .18742 Metetra
.59 .473 .687 r
.4701 .18742 .47787 .21845 .49238 .21035 .48453 .18204 Metetra
.597 .491 .704 r
.48453 .18204 .49238 .21035 .50693 .20257 .49902 .17664 Metetra
.604 .51 .721 r
.49902 .17664 .50693 .20257 .52153 .19522 .5136 .1712 Metetra
.61 .527 .736 r
.5136 .1712 .52153 .19522 .5362 .18836 .52825 .16574 Metetra
.614 .541 .749 r
.52825 .16574 .5362 .18836 .55093 .18204 .54298 .16025 Metetra
.617 .551 .757 r
.54298 .16025 .55093 .18204 .56574 .17626 .55779 .15472 Metetra
.618 .554 .76 r
.55779 .15472 .56574 .17626 .58064 .17097 .57268 .14917 Metetra
.618 .552 .759 r
.57268 .14917 .58064 .17097 .59563 .16606 .58765 .14359 Metetra
.616 .546 .753 r
.58765 .14359 .59563 .16606 .61071 .16134 .60271 .13798 Metetra
.613 .537 .745 r
.60271 .13798 .61071 .16134 .62589 .15654 .61784 .13233 Metetra
.61 .53 .739 r
.61784 .13233 .62589 .15654 .64113 .15128 .63305 .12666 Metetra
.609 .526 .736 r
.63305 .12666 .64113 .15128 .65642 .14509 .64835 .12096 Metetra
.611 .532 .74 r
.64835 .12096 .65642 .14509 .67172 .13737 .66374 .11522 Metetra
.618 .553 .759 r
.66374 .11522 .67172 .13737 .68696 .12741 .6792 .10945 Metetra
.633 .607 .806 r
.6792 .10945 .68696 .12741 .70205 .11434 .69475 .10365 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{327, 265.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006H0001Bb000`400?l00000o`00003ooooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooonI
ooooo`00oooooonIooooo`00oooooonIooooo`00oooooonIooooo`00oooooolPooooo`Co000000?o
410@ooooooooool0L_ooool00?oooooo8_ooool00ol0003oooooooooo`1dooooo`00oooooolRoooo
o`03o`000?oooooooooo07Cooooo003oooooob;ooooo00?o0000ooooooooool0M?ooool00?oooooo
8_ooool00ol0003oooooooooo`1dooooo`00oooooolRooooo`03o`000?oooooooooo07Cooooo003o
ooooob;ooooo00?o0000ooooooooool0M?ooool00?oooooo8?ooool00omEEEGoIVIVo`00000:oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo;Oooool01OmgMgOoV9RHoooooonHV9So
MgMg06Oooooo003oooooobgooooo00Go410@oooooooooooooooooa0@401Wooooo`00ooooool]oooo
o`05o`000?ooooooooooooooool00000Ioooool00?oooooo;Oooool01Ol0003ooooooooooooooooo
000006Oooooo003oooooobgooooo00Go410@oooooooooooooooooa0@401Wooooo`00oooooolWoooo
o`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06Oooooo003oooooobCooooo0ol000000ooo
oooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Ioooool00?oooooo8_ooool2o`00
00Cooooo0_l0001_ooooo`00oooooolOooooo`?o00001_ooool00ol0003oooooo`00001^ooooo`00
oooooolMooooo`;o00002Oooool00ol0003oooooo`00001^ooooo`00oooooolJooooo`?o00002ooo
ool01?l0003oooooooooool0001]ooooo`00oooooolGooooo`Co00003Oooool01Ol0003ooooooooo
oooooooo000006cooooo003ooooooaGooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00001/ooooo`00g?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08?ooool3o`0001?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Yooooo`00g?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407_ooool2o`0001Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Xooooo`00g?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`?o00006Oooool00ol0003oooooooooo`03
o`0006[ooooo003Looooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b01Wooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Iooo
ool00=cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
5_ooool3o`0000?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Oooooo003Looooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@01Cooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0I_ooool00=cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000004Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uoooo
o`00g?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0?
ooooo`;o00009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo003moooo
o`Co00009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo002@ooooo`;o
00000_ooool2o`0006Cooooo0ol00003ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Sooooo`00T?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
gF;ooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool0097o
oooo00CogMgMo`000?l@413oc<c<H?ooool3o`00033ooooo00?o0000ooooooooool01_ooool3o`00
06Cooooo002Aooooo`04onk^k_lQ8B7o410@onk^kUkooooo0_l0000cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0HOooool0097ooooo00Co8B4QogMgMomgMgOo<S8bFoooool4o`00
03Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`00T?ooool2o`0000;o
oooo0_l0001Hooooo`;o00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0H?ooool00>_ooooo0ol0000jooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Goooool00>Wooooo0_l0000mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Goooool00>Kooooo0ol0000oooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0G_ooool00>Cooooo0_l000000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0GOooool00:[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02;ooooo0ol00003ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Mooooo`00Z_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B408?oo
ool2o`0004Sooooo00?o0000ooooooooool02oooool3o`0005kooooo002Zooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000001gooooo0ol0001:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Foooool00:[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406_ooool3o`0004gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol0000oooooo`00Z_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c00Hooooo`;o00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0?oooool00:[ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Oooooo0ol0001Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h0@?ooool00:[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Go
oooo0_l0001Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?oooool00:[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@413ooooo0ol0001Gooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool0?_ooool00<gooooo0_l0001Jooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0?Ooo
ool00<[ooooo0ol00002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@03oooooo0038ooooo`;o0000Goooool00ol0003oooooooooo`0Aooooo`?o00001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00oooooo`00
aOooool3o`00063ooooo0_l0000Booooo`04o`000?ooooooooooo`0005Sooooo0033ooooo`;o0000
H?ooool3o`000003oj:Kc_l0003ooooo01Gooooo00?o0000ooooooooool0EOooool00<3ooooo1?l0
001Nooooo`?o00001?nRVlh2o`0001Kooooo00?o0000ooooooooool0E?ooool00;gooooo0ol00004
ooooo`03o`000?oooooooooo05Sooooo0ol000000onNSL;o0000oj:KcP04oj:KcP03o`000?nRVlko
000001Gooooo00?o0000ooooooooool0E?ooool00;_ooooo0_l0001Pooooo`;o00001OnNSL800ol0
003oXY_>oj:KcP02oj:KcP?o00005_ooool00ol0003oooooooooo`1Cooooo`00^?ooool3o`0005oo
oooo0ol000000onLR;go0000oij=`P04oij=`P03o`000?nRVlkoXY_>00;oXY_>00Co0000ol>ab?o3
/LSo00005_ooool00ol0003oooooooooo`1Booooo`00]_ooool2o`0005oooooo0ol00004oib8_@03
o`000?nNSL;oWXg200CoWXg200?o0000oj:Kc_nRVlh00_l00003ol>ab003o`000?oooooooooo01?o
oooo00?o0000ooooooooool0D_ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo02;ooooo0ol000000ooooooo0000ooooo`1Kooooo`?o
000000?oVhJlo`000?nLR;d01OnLR;d00ol0003oWXg2oij=`P03oij=`P03o`000?nRVlko000000;o
`k7800Go0000ol>ab?o3/LSo`k78o`00000Eooooo`03o`000?oooooooooo057ooooo001jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool08Oooool2o`00
05oooooo0_l00005oi^6_003o`000?nLR;goW8Rm00?oW8Rm00?o0000oij=`_nNSL800onNSL82o`00
00?o`k7800Go0000ol>ab?o3/LSo`k78o`00000Dooooo`03o`000?oooooo000005;ooooo001joooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0001oooooo0ol0001Nooooo`?o000000?oW8Nm
o`000?nKQ[`01?nKQ[`00ol0003oW8Rmoib8_@03oib8_@03o`000?nNSL;oWXg200;oWXg200?o0000
ok>Ra_l000000oo3/LP01_l0003o`k78ol>ab?l0003oe[g1o`0001Gooooo00?o0000ooooooooool0
D?ooool007[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001ko
oooo0_l0001Nooooo`?o00001?nLQkd00ol0003oVhJloi^6_003oi^6_003o`000?nLR;goW8Rm00?o
W8Rm00?o0000oij=`_nNSL800_l00003ok>RaP06o`000?o3/LSo`k78o`000?o3/LSo00000_oF_L40
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo001jooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool0000Kooooo`?o0000GOooool3o`000003oib9__l0
003oW8Nm00GoW8Nm00?o0000oi^6_?nKQ[`00onKQ[`00ol0003oW8Rmoib8_@03oib8_@;o00001Onc
X/H00ol0003o`k78ol>ab002o`0000Coe[g100?o0000ooooooooool04oooool00ol0003ooooooooo
o`1?ooooo`00N_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000006Ooo
ool2o`0000;ooooo00?o0000ooooooooool0FOooool2o`0000GoW8Vn00?o0000oib7_OnLQkd00onL
Qkd00ol0003oVhJloi^6_003oi^6_003o`000?nLR;goW8Rm00;oW8Rm0_l00007ok>RaP04o`000?o3
/LSo0000o`0000Coe[g100?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`00N_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000005_ooool3o`0005gooooo
0ol000000onMRl3o0000oib9_P04oib9_P03o`000?nLQkgoW8Nm00?oW8Nm00?o0000oi^6_?nKQ[`0
0onKQ[`00ol0003oW8Rmo`000002o`000003ojVKaol0003o/j;600Ko/j;600?o0000ol>ab?l00000
1?oF_L400ol0003oh<>ko`00000Fooooo`03o`000?oooooooooo04gooooo001jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Booooo`?o0000GOooool3o`0000GoWH_0
00?o0000oib9__nLRKh00_nLRKh00ol0003oW8Nmoib7_@03oib7_@03o`000?nKQ[coVhJl00?oVhJl
0_l00005ojVKa`03o`000?ncX/Ko/j;600Co/j;60ol00003omJm`@05o`000?oP`k_oh<>kon33^ol0
00005Oooool00ol0003oooooooooo`1=ooooo`00Woooool2o`0005gooooo0ol000000onNSL;o0000
oif;`005oif;`003o`000?nLRKkoW8Vn00?oW8Vn00?o0000oib7_OnLQkd00_nLQkd01?l0003oVhJl
oi^6_?nKQ[`2o`000003ojBJbol0003oZI_700CoZI_700?o0000ok>Ra_ncX/H00oncX/H01?l0003o
`[39o`000?l00003omJm`@03o`000?oP`k_oh<>k00;oh<>k00?o0000ooooooooool04oooool00ol0
003oooooooooo`1<ooooo`00W?ooool3o`000003ooooool0003ooooo05[ooooo0_l00005oij=`P03
o`000?nMRl3oWH_000?oWH_000?o0000oib9__nLRKh00onLRKh00ol0003oW8Nmoib7_@03oib7_@?o
00001?nTV//00ol0003oZI_7ojVKa`03ojVKa`03o`000?ncX/Ko/j;600;o00000oo2/<T01?l0003o
e[g1omJm`Ol00005on33^`;o00004oooool3o`0004gooooo002Jooooo`;o0000GOooool3o`000003
oij=`_l0003oWXg200CoWXg200?o0000oif;`?nMRl001?nMRl000ol0003oW8Vnoib9_P02oib9_P03
o`000?nLQkgoW8Nm00;oW8Nm0_l00006ojBJb`03o`000?nYVlOoZI_700?oZI_700?o0000ok>Ra_l0
00001Oo2/<T01?l0003oe[g1omJm`Ol00004on33^`04o`000?oWa[KoilJfo`0001Cooooo00?o0000
ooooooooool0Boooool009Oooooo0ol0001Mooooo`;o00001OnNSL800ol0003oWXg2oij=`P02oij=
`P03o`000?nMRl3oWH_000CoWH_000?o0000oib9__nLRKh00onLRKh4o`000003oj6MdOl0003oY9[;
00KoY9[;00?o0000ojVKaonYVlL00_nYVlL2o`0000Ko`[3900?o0000omJm`Ol000001OoP`k/01Ol0
003oilJfonO6]_oWa[Ko000001Cooooo00?o0000ooooooooool0B_ooool009Gooooo0_l0001Moooo
o`?o000000?oWHg1o`000?nNSL801?nNSL800ol0003oWXg2oij=`P03oij=`P03o`000?nMRl3oWH_0
00?oWH_000Co0000oib9__nLRKkoW8Vn0ol00005oj6Md@03o`000?nTV/_oY9[;00CoY9[;00?o0000
ojVKaonYVlL00_l000000onaZ]7o0000ol:`b@05ol:`b@;o00001OoP`k/00ol0003oilJfonO6]P02
onO6]P03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool009;ooooo0ol0001Loooo
o`?o00001?nMSL400ol0003oWXg2oij=`P03oij=`P03o`000?nNSL;oWXg200?oWXg200?o0000oif;
`?nMRl000onMRl04o`0000;oWj?H00?o0000oj6MdOnQWM400onQWM400ol0003oY9[;ojBJb`04ojBJ
b`03o`000?nYVlOo000000Co/J[A00?o0000ol:`bOo2/<T00oo2/<T2o`0000Coh<>k00?o0000onO6
]_oWa[H00_oWa[H00ol0003ojlRbo`00000Dooooo`03o`000?oooooooooo04Wooooo002@ooooo`;o
00000_ooool00ol0003oooooooooo`1Gooooo`?o000000?oWHZoo`000?nMSL401OnMSL400ol0003o
WXg2oij=`P03oij=`P03o`000?nNSL;oWXg200;oWXg200?o0000oif;`?nMRl000ol000000onP[=oo
0000oinSf004oinSf003o`000?nQWM7oXIgA00?oXIgA00?o0000ojBJbonTV//00onTV//2o`0000Go
/J[A00?o0000ol:`bOo2/<T00_o2/<T2o`000003ol^jbol0003oh<>k00;oh<>k00?o0000onO6]_oW
a[H00_oWa[H00ol0003ojlRbo`00000Eooooo`03o`000?oooooooooo04Sooooo002=ooooo`?o0000
1Oooool00ol0003oooooooooo`1Dooooo`;o00001OnMR[l00ol0003oWHg1oif=`@03oif=`@03o`00
0?nNSL;oWXg200?oWXg200?o0000oij=`_nNSL800_nNSL83o`0000GoX:cO00?o0000oinSf?nOXmP0
0_nOXmP00ol0003oXIgAoj6Md@03oj6Md@03o`000?nTV/_oY9[;00?o000000?oY:[Ko`000?naZ]40
1OnaZ]401_l0003o`[39ol:`bOl0003obk[;o`0000;obk[;00?o0000on33^ol000001?oWa[H01Ol0
003ojlRbon_8/_o[b;;o000001Gooooo00?o0000ooooooooool0Aoooool008_ooooo0_l0001Loooo
o`?o000000?oW8Jlo`000?nMR[l01?nMR[l00ol0003oWHg1oif=`@03oif=`@03o`000?nNSL;oWXg2
00?oWXg200?o0000oij=`_l000000_l000000onS]^Ko0000oj2/g`05oj2/g`03o`000?nOXmSoWj?H
00?oWj?H00?o0000oj6MdOnQWM400_nQWM43o`0000GoY:[K00?o0000ok6ZdOnaZ]400onaZ]400ol0
003o`[39o`000002ol^jb`06o`000?o;^/_obk[;o`000?oP`k_o00001?oWa[H01Ol0003ojlRbon_8
/_o[b;;o000001Gooooo00?o0000ooooooooool0Aoooool008Sooooo0ol0001Looooo`;o00001OnL
Q[`00ol0003oWHZooif:_`02oif:_`03o`000?nMSL7oWHg100?oWHg100?o0000oij=`_nNSL800onN
SL82o`0000GoXkKV00?o0000oj2/gonP[=l00onP[=l00ol0003oWj?HoinSf003oinSf003o`000?nQ
WM7o000000;o000000?oVK3Wo`000?nTZ]/01OnTZ]/00ol0003o/J[Aok6Zd@03ok6Zd@;o00000oo;
^//01Ol0003obk[;ol^jboo;^/_o000000CoilJf00Oo0000on_8/_o[b;;ojlRbo`000?o]b:ko0000
01Cooooo0_l00018ooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool3o`000003ooooool0003ooooo05Wooooo0ol000000onJP[So0000oib6_004oib6
_003o`000?nMR[ooWHZo00?oWHZo00?o0000oif=`OnMSL400onMSL400ol0003oWXg2o`000002o`00
0003ojJnjol0003oXkKV00GoXkKV00?o0000oj2/gonP[=l00onP[=l00ol0003oWj?HoinSf004o`00
00GoVK3W00?o0000ojBZfonTZ]/00onTZ]/01?l0003o/J[Aok6ZdOnaZ]42o`000003ok>ef_l0003o
bk[;00?obk[;00Co0000ol^jbol0003o00001?oWa[H01ol0003ojlRbon_8/_o[b;;o0000ong8[_l0
00005_ooool00ol0003oooooooooo`15ooooo`00COooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool2o`0005cooooo0ol00005oiZ2
^003o`000?nLQ[coW8Jl00;oW8Jl00?o0000oif:_onMR[l00onMR[l00ol0003oWHg1oif=`@02oif=
`@?o00001OnV_^/00ol0003oXkKVoj>fiP03oj>fiP04o`000?nP[=ooX:cOoj2/g`Go00000on@^o@0
0ol0003oVK3WoiV`i`04oiV`i`03o`000?nTZ]_oY:[K00?oY:[K0ol00004ok>efP04o`000?o;^/_o
bk[;ol^jb`;o00000_o@`L`01?l0003oilJfonO6]_l00003on_8/P05o`000?o]b:kokLR^ong8[_l0
00005Oooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Wooooo`00COooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h07oooool3o`0005_ooooo0ol000000onHOKCo0000oiZ2^005oiZ2
^003o`000?nLQ[coW8Jl00?oW8Jl00?o0000oif:_onMR[l00_nMR[l00ol0003oWHg1o`000002o`00
00;oZ/C]00?o0000ojJnjonV_^/01?nV_^/01?l0003oXkKVoj>fi_nS]^H5o`0000?oQlWm00?o0000
oi2km?n@^o@00on@^o@00ol0003oVK3WoiV`i`03oiV`i`04o`000?nTZ]_oY:[KojBZf`?o00001onc
]MX01?l0003obk[;ol^jbol00004om31c003o`000?oWa[Ko000000?ojlRb00Co0000ong8[_o]b:ko
kLR^0_l0000Eooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`0Xooooo`00COooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h07?ooool2o`0005cooooo0_l00005oiQm]003o`000?nJP[SoVX:h
00?oVX:h00?o0000oib6_?nLQ[`00onLQ[`00ol0003oWHZooif:_`02oif:_`;o00001_nZa>d01?l0
003oY[k[ojJnjonV_^/6o`0000CoOmKo00?o0000ohO9oOn7bOd00_n7bOd00ol0003oT;_doi2km002
oi2km004o`000?nI/>OoVK3WoiV`i`Ko00000_nK]NX00ol0003o/kGJok>efP05ok>efP04o`000?o;
^/_o0000o`0000God<7<00Go0000on_8/_o[b;;ojlRbo`000003ong8[P04o`000?o_bJcoklV/o`00
01Gooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Y
ooooo`00COooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool06?ooool3
o`0005_ooooo0ol000000onGNJoo0000oiQm]004oiQm]003o`000?nJP[SoVX:h00CoVX:h00?o0000
oib6_?nLQ[`00_nLQ[`00ol0003oWHZoo`000002o`0000;o[/K[00?o0000oj[4kOnZa>d00onZa>d4
o`0000?oN]kh5Ol00003ogjhn@03o`000?nK]N[oVkGZ00?oVkGZ00?o0000ok>ef_nc]MX01?nc]MX2
o`000003om31c?l0003od<7<00?od<7<0_l00003on_8/P05o`000?o]b:kokLR^ong8[_l000000oo_
bJ`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002[ooooo001=ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Eooooo`;o00000oooool00ol0003oooooooooo`1Fooooo`;o
00001?nGNJl00ol0003oV7fdoiQm]003oiQm]003o`000?nJP[SoVX:h00CoVX:h00?o0000oib6_?nL
Q[`00_nLQ[`2o`0000Ko[/K[00?o0000oj[4kOl000000_l00003og_TkQ;o000000?o=[GZo`000?mK
^o`00_mK^o`00ol0003oO[Siogjhn@03ogjhn@03o`000?nK]N[oVkGZ00?oVkGZ00Co0000ok>ef_nc
]M[o/kGJ0_l000001?na_>;o0000om31c?l00003om31c006o`000?oBaLgod/G=o`000?o[b;;o0000
1?o]b:h01Ol0003oklV/ono9[?o_bJco000001Gooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00003_ooool3o`000003oa0@4?oooooo
oooo01Kooooo001=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01Cooooo0ol0001Kooooo`?o000000?oUGB[o`000?nGNJl01?nGNJl00ol0003oV7fdoiQm
]003oiQm]003o`000?nJP[SoVX:h00?oVX:h00?o0000oib6_?l000000_l00002ok;4j003o`000?n^
a^_o[/K[00?o[/K[1?l000001_mki>ko0000o`000?l0003oalOJo`0000?o]<GV0_l000000onb/mWo
0000oiNYh`04oiNYh`04o`000?m[U>SoJiCXof^Dj0Oo00001Omn^?T00ol0003oVkGZoi^ejP02oi^e
jP04o`000?nc]M[o0000o`0000Co/KcR0_l00002om31c007o`000?oBaLgod/G=om;5cOl0003ojlRb
o`000003ong8[P07o`000?o_bJcoklV/ono9[?l0003ol<VYo`00000Dooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000013ooooo00?o410@
okZj^_ooool05oooool004gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`04_ooool2o`0005_ooooo0ol00004oiEdZ`03o`000?nGNJooUgV_00?oUgV_00?o
0000oiQm]?nHOK@00onHOK@00ol0003oVX:hoiZ2^003oiZ2^0;o00001_nba>P00ol0003o[/K[o`00
0002o`000003ohCYj?l0003o000000?o00001?o7amX00ol0003o]<GVo`000004ok:cf@03o`000?nG
ZN?oUjWS00?oUjWS00Go0000of^Dj?m[U>SoJiCXo`000002obmag`oo00001_na_>82o`000003om31
c?l0003od/G=00Cod/G=00?o0000ong8[_o]b:h00_o]b:h01ol0003oklV/ono9[?o_bJco0000oo39
ZOl000005?ooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
0000013ooooo00?oV9RHoc8b<_ooool05oooool0077ooooo0ol0001Iooooo`Co00000_nCL:P00ol0
003oUGB[oiEdZ`03oiEdZ`03o`000?nGNJooUgV_00;oUgV_00?o0000oiQm]?nHOK@00onHOK@01?l0
003oVX:hoiZ2^?nJP[P2o`000003okBoh_l0003o//CX00Go//CX1_l00003omSKfP03o`000?o7am[o
alOJ00CoalOJ00?o0000ok:cfOnb/mT01?nb/mT01?l0003oUjWSoiNYhonGZN<7o`0000;o;g7O00?o
0000o`17b?l000000_l00003odf[n@03o`000?n6]_GoQ[Ke00;oQ[Ke00?o0000ok6lh_na_>801?na
_>83o`0000Kod/G=00?o0000ong8[_o]b:h00_o]b:h01Ol0003oklV/ono9[?o_bJco000000;ol<VY
00?o0000ooooooooool04?ooool01?l0003oooooooooool00004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`03omgMgOl0003o^[Zj01Oooooo001_ooooo`;o
00000_ooool00ol0003oooooooooo`1Dooooo`?o000000?oTVfUo`000?nCL:P00onCL:P00ol0003o
UGB[oiEdZ`03oiEdZ`03o`000?nGNJooUgV_00?oUgV_00?o0000oiQm]?nHOK@00onHOK@3o`0000Co
];oR00Co0000ok;4j?nba>So//CX1?l00002om[ch@04o`000?oHfm[of=_JomSKfP;o00001Oo7amX2
o`0000Ko/[?I1?l00002oiVOf004o`000?mdSMgoM8gMogB=g@?o000000?o;g7Oo`000?l0AlP01?l0
0002odf[n@03o`000?n6]_GoQ[Ke00;oQ[Ke00?o0000ok6lh_na_>800ona_>82o`0000Kod/G=00?o
0000om?7c_l000000_o]b:h01Ol0003oklV/ono9[?o_bJco000000?ol<VY0_l0000Dooooo`03o`00
0?oooooooooo02Kooooo00?oEEEEogMgMom4A4@05oooool006cooooo0ol0001Iooooo`;o00001?nB
KJD00ol0003oTg2Xoi=`Z003oi=`Z003o`000?nEM:_oUGB[00;oUGB[00?o0000oiMi[onGNJl00onG
NJl00ol0003oV7fdoiQm]002oiQm]0;o00001_nd_n801Ol0003o//CXo`000?l0003oTo3W00?o0000
00?of_?Qo`000?oHfmX00_oHfmX01?l0003odLK@om76d?l00003olO7fP04o`000?o2]loo`[O?o`00
00?o/[?I0_l000000onaZ<oo0000oiVOf004oiVOf006o`000?mdSMgoM8gMogB=gOl0003o@G3J0ol0
00000ol0AlSo0000o`000004o`0000GoQ[Ke00?o0000ok6lh_l000000_l000000onZ_^So0000om;5
c@04om;5c@07o`000?oCalkodlO>om?7c_l0003okLR^o`000003ono9[004o`000?o`bJWol<VYo`00
00;olLRW00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`05omgMgOl@413ooooo
ob4Q8OoMgMd05_ooool006[ooooo0_l0001Iooooo`?o000000?oTFZRo`000?nBKJD01?nBKJD00ol0
003oTg2Xoi=`Z002oi=`Z003o`000?nEM:_oUGB[00?oUGB[00?o0000oiMi[onGNJl00_nGNJl00ol0
003oV7fdoiQm]002o`000003okBhfol0003o];oR00Go];oR1Ol00003on;^f005o`000?oHfm[of=_J
omSKf_l000001?oAa]000ol0003oalOJo`000004ol:gc`03o`000?nb/mWo000000Co/JS?00?o0000
oiVOf?nIWmP00_nIWmP00ol0003oM8gMogB=g@02ogB=g@04o`000?m1L=[o@G3Jod5`fP;o000000Go
04O8o`000?l0003o0000oaF;i`07o`0000CoZ[kX0_l00003om;5c@03o`000?oCalkodlO>00;odlO>
00?o0000ong8[_l000000_o_bJ`01Ol0003ol<VYoo39ZOo`bJWo000000?olLRW00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Sooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool006Oo
oooo0ol0001Iooooo`;o00001?nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X00;o
Tg2X00?o0000oiEdZonEM:/00onEM:/00ol0003oUgV_oiMi[`03oiMi[`;o00001?nd^=/01?l0003o
];oRokBoh_nd_n82o`000004ojKfjOl0003o0000o`0000?oh^kH00Go0000omgGdOl0003of=_Jo`00
0005om76d0;o00001Oo2]ll2o`0000Go/JS?00?o0000oiVOf?nIWmP00_nIWmP00ol0003oM8gMogB=
g@02ogB=g@06o`000?m1L=[o@G3Jod5`f_l0003o24c:1ol00004ofV]n003o`000?nZ_^SoZ[kX00;o
Z[kX00Go0000ojZnj?l0003od/G=o`000005om?7cP;o00000oo_bJ`01Ol0003ol<VYoo39ZOo`bJWo
000000?olLRW00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03onk^k_l0003o
k^k^00;ooooo00?o0000omgMgOooool05?ooool006Cooooo0ol000000ooooooo0000ooooo`1Foooo
o`?o000000?oT6RPo`000?nAJZ800onAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X
00;oTg2X00?o0000oiEdZonEM:/00onEM:/00ol0003oUgV_oiMi[`02oiMi[`;o00001_nd^=/00ol0
003o];oRo`000002ojKfj@03o`000?oIom;o000000?oh^kH00Go0000omgGdOoMem7ogMOAo`000005
om76d003o`000?o;]lOo000000Co`[O?00?o0000okn/aol000001OnaZ<l01?l0003oVIoHoiVOf?nI
WmP9o`0000;o@G3J00?o0000o`Q<b_l000001_l00004ofV]n004o`000?nZ_^SoZ[kXojZnj0Co0000
1OoCalh00ol0003odlS?o`000002ono9[005o`000?o`bJWol<VYoo39ZOl000000ooab:L00ol0003o
l/RUo`00000Dooooo`03o`000?oooooooooo027ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`0Cooooo`00H_ooool2o`0000Gooooo00?o0000ooooooooool0D_ooool2o`0000Co
T6RP00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:SoTg2X00?o
Tg2X00?o0000oiEdZonEM:/00_nEM:/00ol0003oUgV_oiMi[`02o`000003ok>_e?l0003o];SK00Go
];SK1Ol000000ooIom;o0000on;^f002on;^f003o`000?oMem7ogMOA00;ogMOA0_l00003om76d005
o`000?o;]lOobkO7ol^gaol000000_o2]ll01Ol0003o_jc7okn/aono[<Oo000000Co/JS?1?l00002
oi^Hd003o`000?mkRMKoNhWF00;oNhWF00?o0000odiaeOl000000_l00002o`Q<bP05o`000?l09:oo
0000o`000?l0C;l02_l00002oj2lk003o`000?oCalkodlO>00;odlO>00Oo0000om?8cooCb<oodlS?
o`000?o_bJco000000?ol<VY00Oo0000oo78Yooab:OolLRWo`000?obb:Go000001Gooooo00?o0000
ooooooooool0??ooool005oooooo0ol0001Iooooo`?o000000?oT6JNo`000?n@J:000on@J:000ol0
003oTFZRoi5ZXP03oi5ZXP03o`000?nBKJGoTVfU00;oTVfU00?o0000oi=`Z?nCL:P00onCL:P00ol0
003oUGB[oiEdZ`03oiEdZ`;o00001?nc[m@01?l0003o];SKokBhfond^=/2o`0000;o]oW/1_l00000
0ooRk]So0000omgGd@03omgGd@06o`000?oFa<Soe/C8o`000?oAa]3o00001?o;]lL00ol0003o`[O?
o`000004okn/a`03o`000?naZ<oo/JS?00;o000000?o/:78o`000?nKV=001?nKV=000ol0003oNhWF
og^9eP02og^9eP04o`000?m>LMGoCW7Eo`0000?o24c:00Co0000o`0T[ol0003o00000_l0C;l01Ol0
003oBY_dodZKm?m:VoCo000000;oX;c/00Go0000oj2lk?nP_>coX;c/o`000002om?7cP03o`000?oC
b<oodlS?00;odlS?00?o0000ono9[?l000000oo`bJT01Ol0003olLRWoo78Yooab:Oo000000;ol/RU
00?o0000ooooooooool04Oooool2o`0003kooooo001Mooooo`;o0000F_ooool2o`0000CoT6JN00?o
0000oi1XX?n@J:000_n@J:000ol0003oTFZRoi5ZXP03oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o
0000oi=`Z?nCL:P00_nCL:P00ol0003oUGB[oiEdZ`02oiEdZ`;o00001_nc[m@00ol0003o];SKo`00
0003okOik0?o000000Goh_c@o`000?oVjM;oi^WBo`000004omgGd@03o`000?oFa<Soe/C800;oe/C8
00?o0000ol^gaoo;]lL01?o;]lL00ol0003o_jc7okn/a`03okn/a`03o`000?naZ<oo000000Co/:78
00?o0000oi^Hd?nKV=000onKV=000ol0003oNhWFog^9eP02og^9eP03o`000?m>LMGoCW7E00;o0000
00Co24c:o`000?l0003o02B_0ol000002?l0C;oo0000o`000?l0003oBY_do`000?nP_>co00000onP
_>`00ol0003odlO>o`000006om?8c`05o`000?o`bJWol<VYoo39ZOl000000ooab:L01Ol0003ol/RU
oo;8YOobb:Go000001Gooooo00?o0000ooooooooool0>oooool003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0Sooooo`?o0000FOooool3o`000003ohmUWOl0003oT6JN00?oT6JN00?o0000oi1XX?n@
J:000on@J:000ol0003oTFZRoi5ZXP02oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o0000oi=`Z?nC
L:P00_nCL:P00ol0003oUGB[oiEdZ`02o`000003ok6VcOl0003o/joD00Go/joD1?l000001_ngnNco
0000olWl_?l0003oh_c@o`0000?oi^WB00Go0000omgGdOoMem7ogMOAo`000005omK4b003o`000?o;
]lOobkO700?obkO70_l00006okn/a`03o`000?n`XLSo/:7800Co/:7800?o0000oi^Hd?nKV=000_nK
V=000ol0003oNhWFog^9eP02og^9eP05o`000?m>LMGoCW7Eo`000?lJDLX02_l000001ol_R>co0000
o`000?l0003oX;c/o`000?nP_>`00ol00006om?8c`;o00000oo`bJT01Ol0003olLRWoo78Yooab:Oo
000000;ol/RU00?o0000oo;8Y?l000005Oooool00ol0003oooooooooo`0jooooo`00<_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg027ooooo0_l00003ooooo`03o`000?oooooooooo05Cooooo0_l00004
ohmUW@03o`000?n@IYkoT6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:000ol0003oTFZRoi5ZXP02
oi5ZXP03o`000?nBKJGoTVfU00?oTVfU00?o0000oi=`Z?nCL:P00onCL:P2o`0000Co/JK=00?o0000
ok>_e?nc[m@00_nc[m@01?l0003oa?K^olCfk_o4m^h2o`000004olWl_?l0003oh_c@o`0000?oi^WB
00Go0000omoCc?l0003ogMOAo`000005omK4b003o`000?o@]/7o000000?obkO700Co0000olN]`?o7
[L3o00001?no[<L2o`0000Ko/:7800Co0000oi^Hd?nKV=3oViS@2Ol000001_m>LMGo0000oaYAb_lJ
DL[o0000o`0/]@Oo00000ol_R>`3o`0000;oU[O^00?o0000om?8cooCb<l00ooCb<l01?l0003odlO?
om?7col00002oo39Z@04o`000?oab:OolLRWo`0000?ol/RU00Co0000oo;8Y?obb:Co00005?ooool0
0ol0003oooooooooo`0jooooo`00<_ooool01Ol@413ooooooooooooooooo410@01kooooo0ol0001I
ooooo`?o000000?oSfBMo`000?n?IId00on?IId00ol0003oT6JNoi1VWP03oi1VWP03o`000?n@J:3o
T6RP00;oT6RP00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oTVfUoi9]Y@03oi9]Y@03o`000?nCL:So
Tg2X00;oTg2X0_l00006ok6Vc@04o`000?nc[mCo/joDo`0000?oa?K^0_l000001?o9o;co0000on;l
d?l00003onKYdP05o`000?oOdlcogm?<omoCc?l000001OoFa<P01?l0003od;K1om2f`Ol00002ol^g
a`03o`000?o7[L3oajg000;oajg000Co0000okn/aono[<Oo00000_nmYL400ol0003o/:78ok2Qb003
ok2Qb0Co00000_nMUL/00ol0003oPHOAoh67d@02oh67d@03o`000?mHL];o000000;o00000_lJDLX7
o`000004o`0i]Ol0003o0000obn8k0;o00001?nF]nh01Ol0003odlS?om?8cooCb<oo000000CodlO?
0_l00003oo78Y`05o`000?obb:Gol/RUoo;8YOl000000_obb:@00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo03Wooooo000booooo`05o`000?ooooooooooooooool000007?ooool2o`0005[o
oooo0_l00004ohmTW@03o`000?n?IIgoSfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh00ol0003o
T6RPoi1XX002oi1XX003o`000?nAJZ;oTFZR00;oTFZR00?o0000oi9]YOnBKJD00onBKJD00ol0003o
Tg2Xoi=`Z002o`000003ojjMa_l0003o/JK=00Go/JK=00?o0000ok>_e?l000000oo4m^h2o`000004
olWl_?l0003oh_c@o`0000?oi^WB00?o0000omoCc?oOdl`00_oOdl`2o`0000?oe/C800Oo0000om2f
`Oo@]/7od;K1o`000?o;]lOo000000Goajg000?o0000okn/aol000001?nmYL400ol0003o/:78ok2Q
b002o`000003ok2Ma?l0003oWIG;00CoWIG;00?o0000oh67dOn1Qm400_n1Qm401?l0003oF7;BoeQb
d_l00002oaYAbP03o`000?l0<[Wo000000Ko000000Co7GOTo`000?l0003o00001OnF]nh00ol0003o
dlS?o`000005om?7c`;o00000ooab:L01?l0003ol/RUoo;8YOl00003oo;8Y0;o00005Oooool00ol0
003oooooooooo`0hooooo`00<_ooool01Ol0003ooooooooooooooooo000001Wooooo0ol0001Ioooo
o`?o000000?oSfBLo`000?n?I9d00on?I9d00ol0003oSfFMohmUW@03ohmUW@03o`000?n@IYkoT6JN
00;oT6JN00?o0000oi1XX?n@J:000_n@J:000ol0003oTFZRoi5ZXP02oi5ZXP03o`000?nBKJGoTVfU
00CoTVfU0_l00004ojjMaP03o`000?naY/go/JK=00?o/JK=1?l000000oo4m^ko0000o`000006o`00
0003onKYd_l0003ogm?<00?ogm?<00Ko0000omS2a?oH`/Co0000omK4b?l00005om2f`@03o`000?o7
[L3oajg000Goajg000?o0000okfU`OnmYL400onmYL400ol0003o/:78o`000004ok2Ma003o`000?nM
UL_oWIG;00;oWIG;00?o0000oh67dOn1Qm400_n1Qm401?l0003oF7;BoeQbd_mHL]82o`000003oaYA
b_l0003o03:i00Oo00000_lMMn@01?l0003oU[O^oiJgk_nF]nh4o`0000GodlO?00?o0000om?7c_l0
00000_oab:L01Ol0003ol/RUoo;8YOobb:Go000000;ol/RT00Co0000oo?7X_ocaj;o00005?ooool0
0ol0003oooooooooo`0hooooo`00<_ooool01Ol@413ooooooooooooooooo410@01Oooooo0_l00003
ooooo`03o`000?oooooooooo05?ooooo0ol00004ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000
ohmUWOn?IId00on?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3oT6RP00;oT6RP00?o0000
oi5ZX_nAJZ800onAJZ800ol0003oTVfUoi9]Y@02oi9]Y@;o00001_n^WLH00ol0003o/JK=ok6Vc@02
o`0000?obnk/1?l000001?oCo/7o0000onGid?l00002onKUd003o`000?oOdlcogm?<00;ogm?<00?o
0000omS2a?oH`/@00_oH`/@00ol0003od;K1om2f`@04om2f`@03o`000?o7[L3oajg000Coajg00_l0
0006okfU`@03o`000?n`WLCo/9g400?o/9g400?o0000oifEbonMUL/00_nMUL/00ol0003oPHOAoh67
d@02oh67d@06o`000?mHL];oF7;BoeQbd_l0003o:5G:0ol000000ol0<[Wo0000o`000002o`000004
o`0W[_l0003o7GOToaegi0Co00000on=/Nh00ol0003odlO?om?7c`02om?7c`07o`000?oCalkodlO>
om?7c_l0003olLRWo`000003oo;8Y@04o`000?obb:Col/RTo`0000?ollNR00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0gooooo`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo
0ol0001Gooooo`Co00000_n?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00?oSfBM
00?o0000ohmUWOn?IId00_n?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3oT6RP00;oT6RP
00?o0000oi5ZX_nAJZ800onAJZ800ol0003oTVfUoi9]Y@02o`000003oj^F`Ol0003o[Yg600Go[Yg6
00?o0000ok6VcOl000001?o;k^`2o`000006ok;aZ?l0003odok1o`000?oUnM3o00000ooViM02o`00
00?ogm?<00?o0000omS2a?oH`/@00_oH`/@00ol0003od;K1om2f`@03om2f`@03o`000?o;[K_o0000
00Coajg000Co0000olBW^oo4Yk_o00001?nmYL42o`0000Go/9g400?o0000oifEbonMUL/00onMUL/0
0ol0003oPHOAoh67d@02oh67d@05o`000?mHL];oF7;BoeQbd_l000000_lXELX00ol0003o03:io`0b
^@04o`000006o`0W[_l0003o0000o`000?lMMnCo00001On=/Nh01?l0003odlO?om?7col00004om?7
cP03o`000?oab:Oo000000;ol/RU00Go0000oo;8Y?obb:Col/RTo`000003oo?7XP03o`000?oooooo
oooo017ooooo0ol0000hooooo`00<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol0001G
ooooo`?o000000?oSfBMo`000?n?I9`00on?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9go
SfBM00?oSfBM00?o0000ohmUWOn?IId00_n?IId00ol0003oT6JNoi1VWP02oi1VWP03o`000?n@J:3o
T6RP00;oT6RP00?o0000oi5ZX_nAJZ800onAJZ83o`0000CoZiK100?o0000ojjMa_n^WLH00on^WLH2
o`0000?obnk/0ol000001_nblJSo0000om?n`Ol0003oiOW@o`0000?oi^G@00Ko0000omo@bOoOd<Wo
0000omoCc?l00004omS2a003o`000?oB]Kgo000000?od;K100Go0000ol^]^oo;[K_objfko`000002
olN]`005o`000?o4Yk_oa:NkolBW^ol000000onmYL401?l0003o_:6mokbQ_Ol00005ok2Ma003o`00
0?nMUL_oWIG;00Wo00000_mHL]801Ol0003o:5G:obQEb_lXEL[o000000;o03:i1?l000000ol09jko
0000o`000003o`0000CoSK7^00?o0000om?7col000001_oCalh01Ol0003ol/RUoo;8YOobb:Go0000
00;ol/RT00Oo0000oo?7X_ocaj;ollNRo`000?odaj3o000001Cooooo00?o0000ooooooooool0=_oo
ool004Kooooo0_l0001Hooooo`;o00001?n?I9d00ol0003oSfBLohmTW002ohmTW003o`000?n?I9co
SfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@02ohmUW@03o`000?n@IYko
T6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:001?l0003oTFZRoi5ZX_nAJZ82o`0000KoZiK100?o
0000ojjMa_n^WLH00_n^WLH01Ol0003ocNCXolgTj?l0003obnk/00Go000000Codok1o`000?oUnM3o
00000ooViM000ol0003ogm39omo@b@02omo@b@03o`000?oH`/Cof<;400;of<;400Go0000om:e_OoB
]Kgod[Fmo`000002om2f`@07o`000?o;[K_objfkol^]^ol0003oajg0o`000004olBW^`04o`000?nm
YL7o_JG1o`0000?o_:6m00?o0000ok2Ma?n`WL@00_n`WL@4o`0000;oX9C800?o0000ohF7c_n5Qlh0
0_n5Qlh00ol0003oH7C@o`000002o`0000?o:5G:0_l000000ol0<[Wo0000o`0HYP05o`0000?o4V[M
1_l00006om?7cP03o`000?oCa/go000000;ol/RU00Co0000oo;8Y?obb:Co00000oocaj801?l0003o
m<NPooC7X?l0000Dooooo`03o`000?oooooooooo03Gooooo0013ooooo`?o00000_ooool00ol0003o
ooooooooo`1Booooo`?o000000?oSfFMo`000?n?I9d00on?I9d00ol0003oSfBLohmTW002ohmTW003
o`000?n?I9coSfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@02ohmUW@03
o`000?n@IYkoT6JN00;oT6JN00?o0000oi1XX?n@J:000on@J:001_l0003oTFZRo`000?l0003oYhnl
o`0000KoZiK100?o0000ojjMa_n^WLH00_l00003olgTj0Ko000000Codok1o`000?oUnM3o00000ooV
iM000ol0003ogm39omo@b@03omo@b@05o`000?oH`/Cof<;4omS2a?l000001?oB]Kd00ol0003od;K1
o`000005ol^]^`03o`000?o4Yk_oa:Nk00Coa:Nk0_l00004okbQ_@03o`000?n`WLCo/9g400;o0000
00?o/Ic1o`000?nPU<P01?nPU<P00ol0003oQHO>ohF7cP02ohF7cP04o`000?mPM=3oH7C@of1dd0;o
00000_lXELX2o`000003o`0b^Ol0003o000000Ko000000?o4V[Mo`000?n7Znd00on7Znd00ol0003o
dlO>om?7cP03om?7cP04o`000?oCa/godlK=om?6c@;o00000oobb:@01Ol0003ollNRoo?7X_ocaj;o
000000;om<NP00?o0000ooooooooool04_ooool00ol0003oooooooooo`0eooooo`00@Oooool2o`00
05Sooooo0_l00004ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00on?I9`00ol0
003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000ohmUWOn?IId00_n?IId00ol0
003oT6JNoi1VWP03oi1VWP03o`000?n@J:3oT6RP00;oT6RP0_l00004ojN?_003o`000?n[U/7oZiK1
00CoZiK10_l00004olgTj003o`000?ngnlco000000Wo000000?oi^G@o`000?oOd<T01?oOd<T01Ol0
003of;o1o`000?oH`/Co000000Kod[Fm00?o0000ol^]^oo;[K/01?o;[K/00ol0003oa:NkolBW^`04
olBW^`03o`000?nlXKgo_:6m00Co_:6m0_l00004ok6L`@03o`000?nPU<SoX9C800;oX9C800?o0000
ohF7c_n5Qlh00_n5Qlh01_l0003oH7C@of1dd?mPM=3o0000oc9Ib`co000000Co3V7Ho`000?l0003o
00001?n7Znd01Ol0003odlO>om?7c_oCalko000000GodlK=00Co0000oo;8Y?obb:Co00000oocaj80
1?l0003om<NPooC7X?odaj02o`0001Cooooo00?o0000ooooooooool0=?ooool003kooooo0ol0001G
ooooo`?o000000?oT6JNo`000?n?IId00on?IId00ol0003oSfBMohmTW@02ohmTW@03o`000?n?I9co
SfBL00?oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@02ohmTW@03o`000?n?IIgo
SfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh01?l0003oT6RPoi1XX?n@J:02o`0000GoYhnl00?o
0000oj^F`On[U/400on[U/43o`0000?ocNCX00?o0000okOkc?l000001?l000001?oGolOo0000onKf
dOl00002onGRc`03o`000?oOd<Wogm3900?ogm3900Go0000omRo`OoH_l7of;o1o`000007om:e_@03
o`000?o;[K_objfk00?objfk00?o0000olRW]ol000001?o4Yk/2o`0000Ko_:6m00?o0000ok6L`Ona
W<400onaW<400ol0003oX9C8oj2Db003oj2Db003o`000?n5QlkoQHO>00;oQHO>00Co0000of1dd?mP
M=3oH7C@1?l00002o`0h_003o`000?l07Z_o000000Go00000_l>HMP00ol0003oQj_]ohN[k@03ohN[
k@03o`000?oCalko000000GodlK=0_l00002oo;8Y005o`000?ocaj;ollNRoo?7X_l000000_odaj00
1?l0003om<NNooC7W_l0000Dooooo`03o`000?oooooooooo03?ooooo000mooooo`;o0000Eoooool2
o`0000CoT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@03ohmTW@03o`000?n?I9co
SfBL00;oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@02ohmTW@03o`000?n?IIgo
SfFM00;oSfFM00?o0000oi1VW_n@IYh00on@IYh4o`000003ojB9^?l0003oYhnl00GoYhnl00Go0000
oj^F`On[U/7oZiK1o`000003ol_Hh`03o`000?o=i>So000000Go00000_oGolL00ol0003oi_KAo`00
0003onGRc`;o00000ooOd<T00ol0003of;o1omRo`@02omRo`@03o`000?oB]Kgod[Fm00Cod[Fm00?o
0000olf/^?l000000oo;[K/01?l0003ob:NgolRW]ol00003olBW^`04o`000?o3XkSo`j>ho`0000Go
_:6m00?o0000ok6L`OnaW<401?naW<400ol0003oX9C8oj2Db002oj2Db003o`000?n5QlkoQHO>00;o
QHO>00?o0000of1dd?l000000ol00002oc9Ib`;o000000Go03Rlo`000?l07Z_o0000o`0EY004o`00
00;o3V7H1ol00005om?6c@06o`000?oDaLcoe<G<o`000?obb:Co00000_ocaj801Ol0003om<NPooC7
X?odaj3o000000;om<NN00?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00?Ooo
ool3o`0005?ooooo0ol000000on@J:3o0000oi1VWP03oi1VWP03o`000?n?IIgoSfFM00?oSfFM00?o
0000ohmTWOn?I9d00_n?I9d00ol0003oSfBLohmTW002ohmTW003o`000?n?I9coSfBL00;oSfBL00?o
0000ohmTWOn?I9d00_n?I9d00ol0003oSfFMohmUW@03ohmUW@04o`000?n@IYkoT6JNoi1VWP;o0000
1OnTRKP00ol0003oYhnlojN?_003ojN?_004o`000?n[U/7oZiK1o`0000GobmSS1_l00002omOoa`03
o`000?oVm]7o000000?oiN;?00Ko0000omk=b?oNcLSo0000omo@bOl00004omRo`@03o`000?oA/k_o
000000Cod[Fm00Co0000olf/^?o=[;So00000_o;[K/01Ol0003ob:NgolRW]oo8YkOo000000;oa:Nk
00Go0000ol>S^?o3XkSo`j>ho`000004okbQ_@03o`000?nlWk_o000000Go/Ic100Co0000oj2Db?nP
U<SoX9C83?l00002oc9Ib`03o`000?l5?[oo000000;o000000?o01j[o`000?l05J@01?l000000ol>
HMSo0000oh>Vj`04oh>Vj`03o`000?oCa/godlK=00;odlK=00Co0000omC5c?oDaLcoe<G<0_l00003
oo?7XP05o`000?odaj3om<NPooC7X?l000000_odaih2o`0001Cooooo00?o0000ooooooooool0<_oo
ool003gooooo00Co0000oooooooooooo0000Coooool3o`0000CoT6RP00?o0000oi1VW_n@IYh00_n@
IYh00ol0003oSfFMohmUW@03ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00_n?
I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00;oSfBM00?o0000ohmUWOn?IId00on?
IId01_l0003oT6JNo`000?l0003oXHFeo`0000GoY8Vh00?o0000ojN?_?nWSk`00onWSk`00ol0003o
ZiK1o`000005ol_Hh`03o`000?o5omOo000000?o00000_oGolL01?l0003oi_KAonKfdOl00002onGR
c`03o`000?oNcLSog/g800;og/g800?o0000omRo`OoH_l400_oH_l401Ol0003odK>kom6c^ooA/k_o
000000;od[Fm00Oo0000olf/^?o=[;SocJbho`000?o;[K_o000000Gob:Ng0_l00005ol>S^004o`00
0?nlXKgo_:6mo`0000;o_9nk00?o0000ok6L`OnaW<400onaW<44o`0000;oXiG70ol00002ohV9c@04
o`000?mVMlooIWO?ofIgc`?o000000?o<UW;o`000?l5?[l01?l00002o`0EY0Ko00001On3Y^/01?l0
003odlK=om?6cOl00005omC5c005o`000?ocaj;ollNRoo?7X_l000000_odaj001?l0003om<NNooC7
W_l00002ooG7W003o`000?oooooooooo013ooooo00?o0000ooooool000002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05Oooool003go
oooo00Go0000ooooooooooooooooo`00001;ooooo`?o00000_nAJZ800ol0003oT6RPoi1XX002oi1X
X003o`000?n@IYkoT6JN00?oT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00;oSfBL00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBMohmTW@03ohmT
W@03o`000?n?IIgoSfFM00;oSfFM0_l00004oj65]@03o`000?nTRKSoY8Vh00;oY8Vh00?o0000ojN?
_?nWSk`00onWSk`2o`0000GobmSS00?o0000olGoeol000000ol00002omOoa`04o`000?oVm]7oi_KA
o`0000;oiN;?00?o0000omk=b?oNcLP00ooNcLP01Ol0003of;o1omRo`OoH_l7o000000CodK>k00?o
0000om:e_Ol000001Oo=[;P00ol0003ob:NgolRW]`04olRW]`03o`000?o3XkSo`j>h00Co`j>h00?o
0000okbQ_Ol000001?nlWk/02?l0003o/Ic1ok6L`OnaW<7o0000ok>L`?l0003oXiG70ol000000onS
ULOo0000ohV9c@03ohV9c@06o`000?mVMlooIWO?ofIgcol0003o>Uk<0_l00002o`Dn_`Co00000_l0
5J@3o`000003o`mLeOl0003o000000CoPjK[00?o0000om?6cOl000001_oDaL`01?l0003ollNRoo?7
X_l00003ooC7X004o`000?odaikom<NNo`0000?omLNL00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@0Eooooo`00??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04Gooooo0ol000000onBKJGo0000oi5ZXP02oi5ZXP03o`000?n@J:3oT6RP00;oT6RP00?o0000oi1V
W_n@IYh00on@IYh00ol0003oSfFMohmUW@02ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmT
W?n?I9`00_n?I9`00ol0003oSfBLohmTW002ohmTW003o`000?n?I9goSfBM00?oSfBM00Co0000ohmU
WOn?IIgoSfFM0_l00005oj65]@03o`000?nTRKSoY8Vh00?oY8Vh00Go0000ojN?_?nWSkcoYhnlo`00
0002olO=g`06o`000?o;f>?obmSSol_Hhol0003oaOoG2ol000000ooUh/oo0000omk=b004omk=b003
o`000?oF_<3o000000;of;o100?o0000om6c^ooA/k/00ooA/k/00ol0003ocJbholf/^004olf/^003
o`000?o8YkOob:Ng00Cob:Ng00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o_9nkokbO^`03okbO^`04
o`000?naW<7o/Ic1o`0000;o/ic00_l00004oj>Ea`03o`000?n9RLgoRHW=00;oRHW=00?o0000ofIg
comVMll00_mVMll01?l0003o>Uk<o`000?l00002o`Dn_`08o`000?l09;3o0000o`000?l05JCo0000
o`0V/Ol00003o`mLe@Ko00001_oDaL`01Ol0003oeLG:o`000?ocaj;o000000?om<NP00Co0000ooC7
W_odaiko00000ooeai`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000005Oooool003cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`;o00001?nBKJD01Ol0003oTFZRoi5Z
X_nAJZ;o000000GoT6RP00?o0000oi1VW_n@IYh00_n@IYh00ol0003oSfFMohmUW@02ohmUW@03o`00
0?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00_n?I9`00ol0003oSfBLohmTW003ohmTW003o`00
0?n?I9goSfBM00;oSfBM00Ko0000ohmUWOl0003o0000oij1/ol00005oj65]@03o`000?nTRKSoY8Vh
00?oY8Vh00Co0000ojN?_?nWSkco00001?o7cMl00ol0003obmSSo`000004o`000004okci^Ol0003o
eoo=o`0000;oi?CE00Co0000on;OdOoRgm7o00001OoNcLP01_l0003oe[c0omJl`?l0003of;o1o`00
00KodK>k00?o0000olf/^?o=[;P00oo=[;P00ol0003objJdo`000004olRW]`03o`000?o7Y;Go0000
00Ko`j>h00?o0000okbO^onlWk/00onlWk/00ol0003o/Ic1o`000003o`000003ok>L`?l0003oXiG7
00?oXiG700?o0000ohV9cOn9RLd00_n9RLd00ol0003oIWO?ofIgc`02ofIgc`04o`000?ljG/co>Uk<
o`0000?o1Cjo00Oo0000o`0T/?l0003o0000o`0EY?l0003o02Ja00;o000000?o3ecEo`000?n2XnT0
0on2XnT00ol0003oe<G<omC5c003omC5c006o`000?oEaL[oeLG:o`000?ocaj;o00000oodaj001?l0
003om<NNooC7W_l00002ooG7W003o`000?ofai_o000001Cooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Eooooo`00??oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo0ol000000onCL:So0000oi9]
Y@03oi9]Y@03o`000?nAJZ;oTFZR00;oTFZR00?o0000oi1XX?n@J:000_n@J:000ol0003oT6JNoi1V
WP02oi1VWP03o`000?n?IIgoSfFM00;oSfFM00?o0000ohmTWOn?I9d00_n?I9d00ol0003oSfBLohmT
W002ohmTW003o`000?n?I9coSfBL00?oSfBL00?o0000ohmTWOn?I9d00_n?I9d2o`0000?oWX6c00?o
0000oj65]OnQQKD01?nQQKD00ol0003oY8VhojB9^002ojB9^003o`000?nWSkco000000GoalgO1_l0
00001?nlnKWo0000omOocOl00002onCde@04o`000?oRgm7oh]oAon;Od@;o00000ooNcLP00ol0003o
e[c0omJl`002omJl`003o`000?oA/k_odK>k00CodK>k00?o0000olf[]_l000000oo=[;P01?l0003o
bjJdol^V]?l00003olRW]`04o`000?o7Y;GoajBeo`0000Go`j>h00?o0000ol>R]ol000001?nlWk/3
o`0000Co/ic000?o0000oj>EaonSULL00_nSULL8o`0000;oIWO?00Co0000ocYNc?ljG/co>Uk<0_l0
00001?l5?[oo0000o`0T/?l09;09o`0000CoPZ?Y00Go0000omC5c?oDaLcoe<G<o`000004omG5bP05
o`000?odaj3om<NPooC7X?l000000_odaih01Ol0003omLNLooG7W?oeaico000000;om/NK00?o0000
ooooooooool04Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<01Gooooo000looooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0>oooool2o`0000CoTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003oTFZRoi5Z
XP02oi5ZXP03o`000?n@J:3oT6RP00;oT6RP00?o0000oi1VW_n@IYh00_n@IYh00ol0003oSfFMohmU
W@02ohmUW@03o`000?n?I9goSfBM00;oSfBM00?o0000ohmTW?n?I9`00on?I9`00ol0003oSfBLohmT
W002ohmTW004o`000?n?I9goSfBMohmTW@;o00001OnNPK<00ol0003oXHFeoj65]@03oj65]@03o`00
0?nTRKSoY8Vh00;oY8Vh0_l00005olO=g`03o`000?o<o^3oc?kP00?o000000Co_?Vio`000?oGolgo
00000_oTm=D01Ol0003oh]oAon;OdOoRgm7o000000;ofl[900?o0000omk=b?l000001OoF_<000ol0
003odK>kom6c^`03om6c^`04o`000?o=ZkKocJ^fo`0000;ocJbh00?o0000ol^V]?o;Y[@00_o;Y[@0
1?l0003ob:NgolRW]ol00003olNT]@05o`000?o3XkSo`j>hol>S^?l000000_o3X[L00ol0003o_9nk
o`000002o`000003okjP^_l0003o/ic000Go/ic01?l000000onVUlOo0000ohf<c@03ohf<c@03o`00
0?m[N]3o000000?o00000_ljG/`02_l0003o3T?2o`000?l5?[oo0000o`0T/?l0003o01ZXo`000?l0
:K<3o`000003oa=Kdol0003oPZ?Y00CoPZ?Y00?o0000omC5c?l000001OoEaLX01Ol0003om<NPooC7
X?odaj3o000000;om<NN00Go0000ooG7W?oeaicomLNLo`000002ooK7V`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool05oooool003_ooooo0ol00008ooooo`03o`000?oooooooooo03Oooooo0ol000000onEM:_o
0000oi=`Z003oi=`Z003o`000?nBKJGoTVfU00?oTVfU00Go0000oi5ZX_nAJZ;oTFZRo`000004oi1X
X003o`000?n@IYkoT6JN00;oT6JN00?o0000ohmUWOn?IId00_n?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00?oSfBL00?o0000ohmTW?n?I9`00_n?I9`4o`000003oian/_l0003oWX6c
00CoWX6c00?o0000oj65]OnQQKD00onQQKD00ol0003oY8VhojB9^002o`0000;o`/?K00Go0000olO=
goo7cMooalgOo`000002olcnh0?o000000Co_?Vio`000?oGolgo00000_oTm=D01Ol0003oh]oAon;O
dOoRgm7o000000Cofl[900?o0000omJl`?oF_<000ooF_<000ol0003od;6jo`000003om6c^`05o`00
0?o=ZkKocJ^folf[]_l000000_o=[;P00ol0003objJdol^V]002ol^V]003o`000?o8YkOo000000Co
ajBe00Co0000ol>S^?o3XkSo00000_o3X[L3o`000003okbO^ol0003o_Z2j00;o_Z2j00?o0000ok>L
`?ncW<000oncW<000ol0003oYYO7ojJGa`03ojJGa`03o`000?n=S<goSHc=00;oSHc=00Co0000of]j
d?m[N]3oJg[@0_l00002ocYNc003o`000?l>@l;o000000;o000000?o02B`o`000?l06ZP01?l00002
oa=Kd`Oo00001OoEaLX00ol0003oelC8o`000002ooC7X004o`000?odaikom<NNo`0000;omLNL00Co
0000ooK7Voofai_om/NK0_l0000Dooooo`03o`000?oooooooooo00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Oooooo000looooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0<oooool3o`0000CoUGB[00?o0000oi=`Z?nCL:P00onCL:P00ol0003oTVfU
oi9]Y@02oi9]Y@05o`000?nAJZ;oTFZRoi5ZX_l000001?n@J:000ol0003oT6JNoi1VWP02oi1VWP03
o`000?n?IIgoSfFM00;oSfFM00?o0000ohmTWOn?I9d00on?I9d00ol0003oSfBLohmTW002ohmTW004
o`000?n?I9coSfBLohmTW0;o00001?nLO[800ol0003oWX6coij1/`03oij1/`03o`000?nQQKGoXHFe
00CoXHFe0_l00005ol;3f`03o`000?o7cMoo000000;oc?kP0ol000000onlnKWo0000o`000004o`00
00?oh]oA00?o0000om_:bOoKb/T00ooKb/T00ol0003oe[c0omJl`002omJl`005o`000?o@/K[od;6j
om2a^_l000000_oA/k/00ol0003ocJ^folf[]P02olf[]P;o00001_o;Y[@00ol0003oajBeolNT]@03
olNT]@03o`000?o3XkSo000000?o00000_o3X[L2o`0000Co_Z2j00?o0000ok>L`?ncW<000_ncW<02
o`0000GoYYO700?o0000ohf<cOn=S<d00_n=S<d01_l0003oJg[@of]jd?m[N]3o0000ocmRcP?o0000
0_l>@l800ol0003o02Zco`000003o`000006o`0]]_l0003o0000o`000?lCFm?o00001On3XNL00ol0
003oeLG:omG5bP02omG5bP04o`000?oGa<SoelC8omO4b0;o00000_odaih01Ol0003omLNLooG7W?oe
aico000000;om/NK00Co0000ooO7VOogaiWo00004Oooool3o`0000Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Gooooo000kooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0;oooool3o`0000;oUgV_00?o0000oiEdZonEM:/00_nEM:/00ol0003o
Tg2Xoi=`Z003oi=`Z003o`000?nBKJGoTVfU00;oTVfU00Go0000oi5ZX_nAJZ;oTFZRo`000004oi1X
X003o`000?n@IYkoT6JN00;oT6JN00?o0000ohmUWOn?IId00on?IId00ol0003oSfBMohmTW@02ohmT
W@03o`000?n?I9coSfBL00;oSfBL1?l000000onIO;7o0000oian/P04oian/P03o`000?nNPK?oWX6c
00?oWX6c00?o0000oj65]OnQQKD00_nQQKD2o`0000Ko`/?K2ol00003omocf`;o000000?oh]oAo`00
0?oKb/T01?oKb/T00ol0003odk[1o`000003omJl`007o`000?o@/K[od;6jom2a^_l0003odK>ko`00
0005olf[]P03o`000?o;Y[CobjJd00GobjJd00?o0000olNT]Oo7Y;D00oo7Y;D3o`0000Go`j:g00?o
0000okjP^_nnX;X01?nnX;X01?l0003o/ic0ok>L`?l00002okJN`003o`000?nVUlOoYYO700?oYYO7
00?o0000ohf<cOn=S<d00_n=S<d01Ol0003oJg[@of]jd?m[N]3o000000;o?f;>00So0000o`i3`_l>
@l;o3T?2o`000?l0:[?o0000o`0P[@;o000000?o02ffo`000?lIG=<00ol00005oh>Qi`04o`000?oE
aL[oeLG:o`0000GoelC800Co0000ooC7W_odaiko00000ooeai`01?l0003om/NKooK7Vol00002ooO7
V@03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;?ooool003_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0[ooooo`?o000000?oV7fdo`000?nGNJl00_nGNJl00ol0003o
UGB[oiEdZ`03oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003o
TFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001?n@IYh00ol0003oSfFMohmUW@03ohmU
W@03o`000?n?I9goSfBM00;oSfBM00Co0000ohmTW?n?I9coSfBL0_l00004oiUl/@03o`000?nLO[;o
W7jb00?oW7jb00?o0000oij1/onNPK<00onNPK<01ol0003oXHFeoj65]OnQQKGo0000okbkf?l00000
1Oo2`m/01Ol0003ocO[Volgji_l0003o/oW200Co000000?od_oCo`000?oOlm/00_oOlm/01?l0003o
gMgEomgMeOl00005om_:b@07o`000?oC^/7odk[1om>j`Ol0003oe[c0o`000005om2a^P03o`000?o=
ZkKocJ^f00CocJ^f00?o0000ol^V]?o;Y[@01?o;Y[@2o`0000;oajBe0ol000000oo7Y;Go0000ol>R
]`05ol>R]`03o`000?nnX;[o_Z2j00Co_Z2j00?o0000ok>L`?l000000onfW/000ol0003oYYO7ojJG
a`03ojJGa`03o`000?n=S<goSHc=00;oSHc=00?o0000of]jd?m[N]000_m[N]000ol0003o?f;>ocmR
cP02o`000007o`i3`_l0003o0000o`0Z/ol0003o022]o`000002o`0]]P;o000000?o6EcCo`000?l0
00001?n3XNL00ol0003oeLG:o`000006omO4b004o`000?odaikom<NNo`0000;omLNL00Go0000ooK7
Voofai_om/NKo`000002ooO7V@;o00005?ooool00ol0003oooooooooo`0[ooooo`00>oooool2o`00
00gooooo00?o0000ooooooooool0:?ooool2o`0000CoV7fd00?o0000oiMi[onGNJl00_nGNJl00ol0
003oUGB[oiEdZ`02oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0
003oTFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001On@IYh00ol0003oSfFMohmUW@02
ohmUW@03o`000?n?I9goSfBM00;oSfBM1?l000000onGNk;o0000oiUl/@04oiUl/@03o`000?nLO[;o
W7jb00;oW7jb00?o0000oij1/onNPK<00onNPK<01?l0003oXHFeoj65]Ol00003okbkf005o`000?o2
`m_o`/?Kol;3fol000000_o=n^H02?l0003o/oW2o`000?l0003o^?[1o`000?oBom?o00000ooOlm/0
1?l0003ogMgEomgMeOoMgMD2o`0000?ofl[900?o0000om>j`OoC^/400ooC^/400ol0003od;6jom2a
^P04om2a^P03o`000?o=ZkKocJ^f00?ocJ^f00?o0000ol^U/ol000001?o;Y[@00ol0003obJ>bolVS
/P02o`0000?oajBe00?o0000olNR/ol000001?o3X[L00ol0003oa::fo`000006okjP^P03o`000?nf
W/3o]Yk000?o]Yk000?o0000ojJGaonVUlL00_nVUlL;o`0000;o?f;>00Co0000oa=8a?l0003o3T?2
1?l000001?l08:go0000o`000?l0;KH2o`0000;o6EcC1_l00006omO4b005o`000?oIaLKo0000ooC7
W_l000000_oeai`01ol0003om/NKooK7Voofai_o0000ooO7VOl000000_ogaiP00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02_ooooo000kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool09?ooool3o`000003oiZ2^?l0003oV7fd00?oV7fd00?o0000oiMi[onGNJl00_nGNJl0
0ol0003oUGB[oiEdZ`02oiEdZ`03o`000?nCL:SoTg2X00;oTg2X00?o0000oi9]YOnBKJD00_nBKJD0
0ol0003oTFZRoi5ZXP02oi5ZXP05o`000?n@J:3oT6RPoi1XX?l000001On@IYh00ol0003oSfFMohmU
W@02ohmUW@03o`000?n?I9goSfBM00?o00001?nGNk800ol0003oVGbaoiUl/@03oiUl/@03o`000?nL
O[;oW7jb00?oW7jb00?o0000oij1/onNPK<00onNPK<2o`0000Go_;_H00?o0000ol;3fol000000_o=
n^H4o`000004okSj`Ol0003od_oCo`0000?ogo?K00Go0000omgMeOoMgMGogMgEo`000002omK7c003
o`000?oKb/Wo000000Kodk[100?o0000om2a^_o@/KX00oo@/KX00ol0003oc:Vfo`000004olf[]P03
o`000?o;YK?o000000?objJd1Ol00003olNT]@04o`000?o7X[?oaj:co`0000?o`j:g00Co0000olBR
]_o4X[Ko00001OnnX;X2o`0000Go]Yk000?o0000ojJGaol000000_l000000onYVlSo0000oi6@c`03
oi6@c`04o`000?m_Om?oKgoCofmod`?o000000?o?f;>o`000?lCB<@01ol000000ol0<[Wo0000o`0]
]P02o`000003oaULdol0003oQZ7U00?oQZ7U00?o0000omO4b?oGa<P00ooGa<P00ol0003ofLG6omW5
aP02o`0000?omLNL00Co0000ooK7Voofai_o00000_ogaiT01?l0003omlNHooO7V?l0000Dooooo`03
o`000?oooooooooo02[ooooo000kooooo`03o`000?oooooooooo00kooooo0_l0000Rooooo`;o0000
1?nJP[P00ol0003oV7fdoiQm]003oiQm]005o`000?nGNJooUgV_oiMi[ol000001?nEM:/00ol0003o
Tg2Xoi=`Z002oi=`Z003o`000?nBKJGoTVfU00;oTVfU00?o0000oi5ZX_nAJZ800_nAJZ800ol0003o
T6RPoi1XX002oi1XX003o`000?n@IYkoT6JN00;oT6JN00Co0000ohmUWOn?IIgoSfFM1?l00002oiIj
/P03o`000?nGNk;oUg^b00?oUg^b00?o0000oiUl/OnIO;400_nIO;400ol0003oW7jboian/P03oian
/P03o`000?nNPK?oWX6c00;oWX6c0_l00006okbkf0So000000?o^?[1o`000?l000000ol000000ooO
lm_o0000omgMe@02omgMe@03o`000?oFalcoe/O<00;oe/O<00?o0000om>j`OoC^/401?oC^/400ol0
003ocJjko`000003om2a^P04o`000?o<ZKKoc:Vfo`0000?ocJ^f00Co0000ol^U/oo;YK?objFc1?l0
0003olVS/P04o`000?o7Y;GoajBeo`0000Coaj:c00Co0000ol>R]oo3X[Oo00000oo4X[H01Ol0003o
_Z2jokjP^_nnX;[o000000;o`::j00?o0000okJN`?nfW/000_nfW/02o`0000GoZI_800?o0000oi6@
conAT<l00_nAT<l01_l0003oKgoCofmodom_Om?o0000od=Wd0?o00000_lCB<@00ol0003o02ngo`00
0003o`000004o`0b^Ol0003o0000ob1Ne0?o00001?n6XND01Ol0003oelC8omO4b?oGa<So000000Co
fLG600Co0000ooG7W?oeaico00000oofai/01?l0003omlNIooO7VOl00002ooO7V0;o00005?ooool0
0ol0003oooooooooo`0Yooooo`00>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01gooooo0_l000000onLQ[co0000oiZ2^004oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi
[onGNJl00_nGNJl01Ol0003oUGB[oiEdZonEM:_o000000CoTg2X00?o0000oi9]YOnBKJD00onBKJD0
1Ol0003oTFZRoi5ZX_nAJZ;o000000CoT6RP00?o0000oi1VW_n@IYh00_n@IYh4o`000003oiAj]?l0
003oUWZb00?oUWZb00?o0000oiMk/_nGNk800onGNk800ol0003oVGbaoiUl/@03oiUl/@03o`000?nL
O[;oW7jb00;oW7jb00?o0000oij1/onNPK<00_l000000ong/mKo0000okbkf004okbkf006o`000?o;
mN_oboG[ol_ejol0003o/_[<1Ol00003omSchP;o00000ooMgMD00ol0003oe/O<omK7c003omK7c003
o`000?oC^/7odk[100?odk[100Co0000olf^^oo=[[_o00000_o@/KX00ol0003oc:VfolbY]P02olbY
]P03o`000?o=ZkKo000000;objFc0ol000000oo;Y[Co0000olVS/P04olVS/P;o00001Oo7X[<00ol0
003o`j:go`000004olBR]P04o`000?nnX;[o_Z2jo`0000?o`::j00Oo0000okJN`?nfW/3o]Yk0o`00
0?niX/7o000000GoZI_800?o0000oi6@conAT<l00_nAT<l00ol0003oKgoCofmod`02ofmod`04o`00
0?m3Im3o@fO@o`0000?o4dS400Co0000o`0_]ol0003o02F`0_l000001_l0<[Wo0000o`000?l0003o
85kDo`0000GoQZ7U00?o0000omO4b?l000001OoIaLH01?l0003omLNLooG7W?l00003ooK7V`06o`00
0?ogaiWomlNIo`000?ogaiSo00000_ohaiL00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Wooooo000jooooo`?o00004_ooool00ol0003oooooooooo`0Iooooo`?o00001?nLQ[`00ol0003o
VX:hoiZ2^002oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi[onGNJl00_nGNJl01Ol0003o
UGB[oiEdZonEM:_o000000GoTg2X00?o0000oi9]YOnBKJD00_nBKJD00ol0003oTFZRoi5ZXP02oi5Z
XP05o`000?n@J:3oT6RPoi1XX?l000000_n@IYh3o`0000CoU7Zd00?o0000oiIj/_nFN[800onFN[80
0ol0003oUg^boiMk/P02oiMk/P03o`000?nIO;7oVGba00?oVGba00?o0000oian/_nLO[800onLO[82
o`0000Co]k?F00Go0000okbkf?nl^mSo_;_Ho`000003ol_ej`03o`000?nbn/co000000;o000000?o
b?oKo`000?oHln800_oHln801_l0003oem_KomOKfol0003ogMgEo`0000Goe/O<00?o0000oljg`ol0
00000ooC^/401Ol0003ocJjkolf^^oo=[[_o000000;od;6j00?o0000olbY]_o<ZKH00_o<ZKH00ol0
003ocJ^fo`000002o`0000?objFc00?o0000olVS/_o9Xk801?o9Xk800ol0003oaj:colNR/`05olNR
/`03o`000?o4X[Koa::f00?oa::f00?o0000okjP^_l000001?o0X[X01?l0003o]Yk0okJN`?l00003
okVR`@03o`000?nYVlSoZI_800;oZI_800?o0000oi6@conAT<l00_nAT<l00ol0003oKgoCofmod`02
ofmod`04o`000?m3Im3o@fO@od=Wd0;o000000Oo4dS4o`000?l0;kOo02ngo`000?l09K3o000000;o
03:i00Co0000ob1Ne?l0003o85kD1ol00005omW5aP05o`000?oKaLCo0000ooG7W?l000000_ofai/0
1?l0003omlNIooO7VOl00002ooO7V004o`000?ohaiOon<NGo`0001;ooooo0ol0000Zooooo`00>_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo1?l00002oif:_`03o`000?nL
Q[coW8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00_nJP[P00ol0003oV7fdoiQm]002oiQm]003o`000?nG
NJooUgV_00;oUgV_00Go0000oiEdZonEM:_oUGB[o`000005oi=`Z003o`000?nBKJGoTVfU00;oTVfU
00?o0000oi5ZX_nAJZ800_nAJZ800ol0003oT6RPo`000004o`0000;oTWbg00?o0000oiAj]?nDN[@0
0onDN[@00ol0003oUWZboiIj/P02oiIj/P03o`000?nGNk;oUg^b00?oUg^b00?o0000oiUl/OnIO;40
0_nIO;400ol0003oW7jboian/P02oian/P;o00001_ng/mH00ol0003o_;_Ho`000003ol_ej`07o`00
0?nbn/co0000ojcga_l0003ob?oKo`000003omSchP03o`000?oGfm_oem_K00;oem_K00?o0000omK7
c?oFal`00ooFal`01Ol0003oc[O3oljg`oo>]l?o000000;odk[100?o0000olf^^oo=[[/00_o=[[/2
o`0000Coc:Vf0ol00006ol^U/`03o`000?o9Xk;obJ>b00CobJ>b00?o0000olNR/oo7X[<01Oo7X[<0
0ol0003oa::folBR]P04olBR]P03o`000?o0X[[o`::j00Co`::j0_l00004okVR`@03o`000?nYVlSo
ZI_800?oZI_800?o0000oi6@conAT<l01ol00003od=Wd006o`000?lFC<Oo0000oa=8a?l0003o02ng
0_l000001?l09K3o0000o`000?l0<[T4o`0000GoRj;T00?o0000omW5a_oIaLH00_oIaLH01Ol0003o
flG4om_5a?oKaLCo000000?om/NK00Co0000ooO7VOogaiWo00000_ogaiP00ol0003on<NGooS7U`02
o`0001?ooooo00?o0000ooooooooool0:?ooool003[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Aooooo`;o000000?oWHg1o`000?nMR[l00onMR[l00ol0003oW8Jloib6_002oib6
_003o`000?nJP[SoVX:h00?oVX:h00Go0000oiQm]?nHOKCoV7fdo`000004oiMi[`03o`000?nEM:_o
UGB[00;oUGB[00?o0000oi=`Z?nCL:P00_nCL:P00ol0003oTVfUoi9]Y@09o`0000;oTGjk00?o0000
oi9l]onBO;L00onBO;L00ol0003oU7ZdoiAj]002oiAj]003o`000?nFN[;oUWZb00;oUWZb00?o0000
oiMk/_nGNk800onGNk800ol0003oVGbaoiUl/@03oiUl/@Co000000?o/:kFo`000?ng/mH01Ong/mH4
o`000005ol_ejol0003o0000o`000?n/mlH01Ol000000ooHln;o0000omOKf`03omOKf`03o`000?o?
aM3o000000?oe/O<00?o0000oljg`oo>]l<00_o>]l<00ol0003odk[1o`000005olf^^`03o`000?o<
ZKKoc:Vf00?o00000_o<ZKH00ol0003objFcol^U/`03ol^U/`03o`000?o9Xk7o000000CobJ>b00?o
0000olVR/Ol000001Oo7X[<2o`0000Koa::f00?o0000ol2R^_o0X[X01?o0X[X00ol0003o^J;1okVR
`@03okVR`@03o`000?nYVlSoZI_800;oZI_81?l00002oiBFdP04o`000?maQ=OoLHCGog64e`?o0000
0_m3Im000ol0003o5Tc7o`000002o`000005o`0_]ol0003o0000o`000?l0=kd00_l000001?lXHmGo
0000o`000?l00005oh^Ri004o`000?oIaLKofLG6o`0000CoflG400Go0000ooK7Voofai_om/NKo`00
0002ooO7V@04o`000?ogaiSomlNHo`0000;on<NG00?o0000ooS8Uol000004oooool00ol0003ooooo
ooooo`0Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`Go00001_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo0_l00004oif=`@03o`000?nMR[ooWHZo00;oWHZo00?o0000oib6_?nLQ[`00_nLQ[`0
0ol0003oVX:hoiZ2^002oiZ2^003o`000?nHOKCoV7fd00;oV7fd00?o0000oiMi[onGNJl00_nGNJl0
1Ol0003oUGB[oiEdZonEM:_o000000;oTg2X1Ol00002ohn6aP03o`000?n@P/3oT8;000;oT8;000?o
0000oi5n^onAO[/00_nAO[/00ol0003oTWbgoi9l]`02oi9l]`03o`000?nDN[CoU7Zd00;oU7Zd00?o
0000oiIj/_nFN[800onFN[800ol0003oUg^boiMk/P02oiMk/P03o`000?nIO;7oVGba00;oVGba0_l0
0005ok2^eP04o`000?ng/mKo]k?FokNceP;o00000oo4l?07o`0000?obo?/0ol00003omOKf`07o`00
0?o?aM3oclG@olo5d?l0003oe/O<o`000006oljg``03o`000?o=[[_ocJjk00CocJjk0ol00004olbY
]P;o00001?o;YK<01?l0003obJ>aolVS/Ol00004olVS/P03o`000?o9X[7o000000Coaj:c00Co0000
olRS/_o8Xk;o00001?o4X[H00ol0003oaZBfo`000004ol2R^P;o00001_niX/44o`000003ojfPbol0
003oU9KB00CoU9KB00Ko0000og64eomaQ=OoLHCGo`000?m4K=@3o`0000;o5Tc700Go0000o`0d^_l0
003o0000o`0Z]002o`000004o`0g_Ol0003o0000obQSe@?o00001?n;X^@00ol0003ofLG6o`000004
om_5a003o`000?oMa/;o000000;om/NK00?o0000ooO7VOl000000_ogaiP01?l0003on<NGooS7Uol0
0003ooS8U`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:
ooooo`?o000000?oWXg2o`000?nMSL400onMSL400ol0003oWHZooif:_`02oif:_`03o`000?nLQ[co
W8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00_nJP[P00ol0003oV7fdoiQm]002oiQm]003o`000?nGNJoo
UgV_00Wo00000_n>SLh00ol0003oShK6ohn6aP03ohn6aP05o`000?n@P/3oT8;0oi22`?l000001?nA
O[/00ol0003oTWbgoi9l]`02oi9l]`03o`000?nDN[CoU7Zd00?oU7Zd00?o0000oiIj/_nFN[800_nF
N[800ol0003oUg^boiMk/P03oiMk/PCo000000?oZZ[Fo`000?n`[]H01On`[]H00ol0003o]k?Fo`00
0003olC`l0Ko000000?o]_cQo`000?o;ln`00_o;ln`01ol0003oc=[SolcJhoo<f^?o0000omOKfol0
00001Oo?aM000ol0003oc[O3oljg``04oljg``;o00001?o=[[/2o`000003olVV]_l0003oc:Vf00?o
c:Vf00Co0000olVT/oo9Y;?o00000oo;YK<01Ol0003obJ>aolVS/Oo9Xk7o000000;obJ>b00Go0000
olVR/Oo9X[7obJ:ao`000002olNR/`05o`000?o8Xk;ob:>bolRS/_l000000oo4X[H01?l0003oaZBf
olJT]_l00003ol2R^P04o`000?o3YK_o`jFko`0000Go^J;100?o0000ojfPbon]X</00on]X</00ol0
003oU9KBoiBFdP02oiBFdP03o`000?maQ=OoLHCG00;oLHCG00Co0000odA/e?m4K=Co00000olFC<L3
o`0000;o02Zd00?o0000o`0g_Ol0=kd00_l000000olXHmGo0000o`000003oh^Ri0?o00001OoKaL@0
0ol0003ogLK2omg6`P02o`0000;omlNI00Co0000ooO7V?ogaiSo00000_ohaiL01Ol0003on<RGooS8
Uoohb9Oo000001?ooooo00?o0000ooooooooool09_ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01oooool2
o`0001Sooooo00?o0000ooooooooool01_ooool3o`0000CoWXg200?o0000oif=`OnMSL400_nMSL40
0ol0003oWHZooif:_`02oif:_`03o`000?nLQ[coW8Jl00;oW8Jl00?o0000oiZ2^?nJP[P00onJP[P0
0ol0003oV7fdo`000004o`0000;oSYoO00Go0000ohjEe_n>UMKoSYGFo`000005ohj=cP03o`000?n?
Q/KoShK600;oShK600?o0000oi22`?n@P/000_n@P/001Ol0003oTGjkoi5n^onAO[_o000000GoTWbg
00?o0000oiAj]?nDN[@00_nDN[@00ol0003oUWZboiIj/P02oiIj/P03o`000?nGNk;oUg^b00;oUg^b
0_l00005ojZZeP03o`000?n`[]Ko/:kF00?o/:kF1?l000000oo4l?3o0000o`000003o`0000;o]_cQ
00Go0000ol_ck?o;lncobo?/o`000004olcJh`;o00001Oo?aM02o`0000Goc[O300?o0000olV[_?o9
Zk`01Ol00002olVV]P05o`000?o<ZKKoc:VfolbY]_l000000oo9Y;<01?l0003objFcol^U/ol00004
olVS/@03o`000?o9Xk;o000000CobJ:a00Co0000olNR/oo7X[?o00000oo8Xk801?l0003oa::folBR
]_l00003olJT]P04o`000?o0X[[o`::jo`0000?o`jFk00?o0000okVR`OniX/400_niX/42o`0000Go
[J3;00?o0000oiBFd_nDU]800_nDU]800ol0003oLHCGog64e`02og64e`04o`000?m4K=CoA6cDodA/
e0;o000000?o5Tc7o`000?l0>;d00ol000001Ol0:[Co0000o`000?l0=kgo000000;o:6?E1?l00002
oi2Th`03o`000?oKaLCoflG400;oflG400?o0000omg6`_oMa/800_oMa/801?l0003omlNIooO7VOl0
0002ooO7V004o`000?ohaiOon<NGo`0000?on<RG0_l0000Cooooo`03o`000?oooooooooo02Gooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool0
0onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool3
o`0000;oWXg200?o0000oij=`_nNSL800onNSL800ol0003oWHg1oif=`@02oif=`@05o`000?nMR[oo
WHZooif:_ol000001OnLQ[`00ol0003oVX:hoiZ2^004o`0000;oSjWW00?o0000ohjOgon>Wml00on>
Wml01Ol0003oSYGFohjEe_n>UMKo000000CoSXg>00?o0000ohn6a_n?Q/H00_n?Q/H00ol0003oT8;0
oi22`002oi22`003o`000?nAO[_oTGjk00;oTGjk00?o0000oi9l]onBO;L00_nBO;L00ol0003oU7Zd
oiAj]002oiAj]003o`000?nFN[;oUWZb00?oUWZb1?l000000onTYmSo0000ojZZeP05ojZZeP03o`00
0?n`[]Ko/:kF00;o00000onkjo@;o`000003ol_ck?l0003oc=[S00?oc=[S00?o0000olK2e_l00000
1?o?aM001?l0003ob;?6olRca_l00003oljg``03o`000?o9Zkco000000;o00000_o=[[/00ol0003o
bJJfolVV]P02olVV]P04o`000?o<ZKKoc:Vfo`0000?obJBc00Co0000ol^U/oo;YK?o00001?o9Xk40
0ol0003obJ>bo`000004olVR/@03o`000?o7X[?o000000Gob:>b0_l00005olJT]P;o00001Oo3YK/0
1?l0003o^J;1okVR`Ol00002okbW``03o`000?n]X<_o[J3;00;o[J3;00Co0000oiBFd_nDU];oU9KB
1ol00003odA/e008o`000?lFD<_o0000oaI<aol0003o03Rmo`000?l0;kL2o`000003o`0l`?l0003o
03Nm00Co00001On@Y><01?l0003oflG4om_5a?l00005omg6`P04o`000?ogaiWomlNIo`0000;omlNH
00Co0000ooS7UoohaiOo00000_ohb9L01?l0003onLRFooW8U_l0000Cooooo`03o`000?oooooooooo
02Cooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01[ooooo1?l000000onMRl3o0000
oij=`P03oij=`P03o`000?nNSL;oWXg200;oWXg200?o0000oif=`OnMSL400_nMSL400ol0003oWHZo
oif:_`02oif:_`03o`000?nLQ[coW8Jl00Go00000_nA/nh00ol0003oSjWWohnYi`02ohnYi`03o`00
0?n>WmooSYoO00;oSYoO00Go0000ohjEe_n>UMKoSYGFo`000005ohj=cP03o`000?n?Q/KoShK600;o
ShK600Go0000oi22`?n@P/3oT8;0o`000004oi5n^`03o`000?nBO;OoTWbg00;oTWbg00?o0000oiAj
]?nDN[@00onDN[@00ol0003oUWZboiIj/P03o`0000GoY:OH00?o0000ojZZe_nZZ]H00onZZ]H00ol0
003o/:kFo`000003ok_[m0;o000000GoV_?Io`000?l0003o0000oiObh`02o`0000?o]_3e0ol00003
olcJh`05o`000?o6`]Koa/;FolK2e_l000000_o?aM000ol0003ob;?6olRcaP02olRcaP03o`000?o>
]l?o000000;o00000_o9Zk`00ol0003ocJjko`000005olVV]P03o`000?o<ZKKo000000GobJBc0_l0
0006olVS/@03o`000?o9X[7obJ:a00CobJ:a00?o0000olRS/_o8Xk801?o8Xk800ol0003oaZBfolJT
]P04olJT]P03o`000?o3YK_o`jFk00Co`jFk00?o0000okVR`Ol000001?nlYl<01?l0003o[J3;ojfP
bon]X</4o`0000;oUicG00Co0000og::fombR]_oLX[K0ol00002odA/e003o`000?lFD<_o000000;o
000000?o03Rmo`000?l0;kL00_l000001?l0?<3o0000o`000?l_ImL3o`0000GoT:CS00?o0000om_5
a?l000001?oMa/801?l0003oglS1o`000?l00002ooO7V005o`000?ohaiOon<NGooS7Uol000000_oh
b9L01?l0003onLRFooW8U_l0000Booooo`;o00009_ooool000Oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06Oooool2o`0000CoWH_000?o0000oij=`_nNSL800_nNSL800ol0003oWXg2oij=`P02
oij=`P03o`000?nMSL7oWHg100;oWHg100?o0000oif:_onMR[l01Ol00003oiBkl@03o`000?nA/nko
TK?^00;oTK?^00?o0000ohnYion?ZNL00_n?ZNL00ol0003oSYoOohjOg`02ohjOg`05o`000?n>UMKo
SYGFohjEe_l000001?n>SLh00ol0003oShK6ohn6aP02ohn6aP05o`000?n@P/3oT8;0oi22`?l00000
1?nAO[/00ol0003oTWbgoi9l]`03oi9l]`03o`000?nDN[CoU7Zd00Go00000_nMY]`00ol0003oY:OH
ojBWf004ojBWf003o`000?nZZ]KoZZ[F00;oZZ[F1?l000001?nkjoCo0000oi[cfOnJlmT2o`0000;o
Uo;S00Co0000okK`mOnfl?Go]_3e0_l00003okgGk@03o`000?o<f^?o000000Coa/;F00?o0000olo5
d?l000001?o8/lH3o`0000KobJ^l00?o0000olVV]_o9Y[H01Oo9Y[H00ol0003obJBcolVT/`04olVT
/`03o`000?o9Xk7obJ>a00GobJ>a00?o0000olVR/Oo9X[401?o9X[400ol0003ob:>bolRS/P04olRS
/P03o`000?o6Y;KoaZBf00CoaZBf00?o0000ol>U^oo3YK/01Oo3YK/00ol0003o_:O3okbW``03okbW
``06o`000?n]X<_o0000o`000?n`Yloo00001OnGW=L01_l0003oLX[Kog::fombR]_o0000od=`f@;o
000000GoA6cDo`000?lFD<_o5U3;o`000002o`0h_@05o`000?l0;kOo0000o`000?l0?<000_l00002
obmWe`04o`000?n@Y>?oT:CSoi2Th`Co00001?oMa/801Ol0003oglS1omo8`OoOb<7o000000;omlNH
00Co0000ooS7UoohaiOo00000oohb9L00ol0003onLRFooW8UP02o`0001?ooooo00?o0000oooooooo
ool08oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0Gooooo`;o0000
00?oW8Vno`000?nMRl001?nMRl000ol0003oWXg2oij=`P02oij=`P03o`000?nNSL;oWXg200;oWXg2
00?o0000oif=`OnMSL401?l00004oiZolP03o`000?nD^o7oU;_a00;oU;_a00?o0000oi6ck_nA/nh0
0_nA/nh01Ol0003oSjWWohnYion?ZNOo000000CoSYoO00Go0000ohjEe_n>UMKoSYGFo`000004ohj=
cP03o`000?n?Q/KoShK600;oShK600?o0000oi22`?n@P/000_n@P/000ol0003oTGjkoi5n^`02oi5n
^`03o`000?nBO;OoTWbg00Go00000_nDY^800ol0003oWJKLoifVg003oifVg003o`000?nTYmSoY:OH
00?oY:OH00?o0000ojZZe_l000000_l00003ojkWn@_o000000?o]_3eo`000?nmend01?nmend2o`00
00Goa/;F0_l00002olRcaP?o000000?ob;?6o`000?l000001_o9Zk`00ol0003obJJfolVV]P05olVV
]P03o`000?o9Y;?obJBc00CobJBc00?o0000olVS/Oo9Xk401?o9Xk42o`0000GobJ:a0_l00005olRS
/P03o`000?o:YK?o000000CoaZBf00?o0000olVW]ol000001Oo3YK/2o`0000Go_:O30_l00004ok2W
c`03o`000?nGW=OoUicG00?oUicG00Go0000og::fombR]_oLX[Ko`000002od=`f@;o00000olFD</0
1_l0003o03Rmo`0h_Ol0003o02ngo`0000;o03c000Co0000obmWeol_ImOo;fOG0ol00003oiFXh`05
o`000?oMa/;ogLK2omg6`_l000001?oOb<401?l0003omlNHooO7V?l00002ooS7U`07o`000?ohb9Oo
n<RGooS8Uol0003onLRFo`000002ooW9UP03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool2o`0001Gooooo0ol00004oib9_P03o`000?nM
Rl3oWH_000;oWH_000?o0000oij=`_nNSL800_nNSL801?l0003oWXg2oij=`_nNSL84o`0000?oWl7`
00?o0000oiZol_nJ_o800onJ_o800ol0003oU;_aoiBkl@0Zo`0000;oRjSX00?o0000oiBVh_nDY^80
0onDY^800ol0003oWJKLoifVg003oifVg003o`000?nTYmSoY:OH00;oY:OH0ol00003ojkWn@So0000
0onCi_/4o`0000?o_MO]0_l000000oni_]go0000olK2eP02olK2eP;o000000Co_k3:o`000?l0003o
00000oo8/lH01?l0003o`jRool>X_ol00004olV[_003o`000?o5Y;Oo000000GobJJf0_l00005olVT
/`03o`000?o8XK7o000000CobJ>a00Co0000olVR/?o9X[3o00000oo9X[401?l0003obZ>aolZS/Ol0
0003olRS/P04o`000?o:YK?obZFco`0000?oaZBf00Co0000olVW]oo9YkOo00001?o3YK/01?l0003o
ajZmolNZ_Ol00003okbW``03o`000?o1[LKo000000Go/:O?00?o0000oiNLeonGW=L00_nGW=L00ol0
003oLX[Kog::f`02og::f`04o`000?m3L=Wo@g3Iod=`f@;o000000Co5U3;o`000?l0003o03Rm0_l0
00001?l0;kOo0000o`0l`?l0?<02o`000003obmWeol0003oUJSS00GoUJSS00Co0000omg6`_oMa/;o
00000ooOb<401Ol0003oh/Voo`000?ogaiSo000000;on<NG00Co0000ooS8Uoohb9Oo00000_oib9H0
1?l0003onLVFooW9U_l0000Cooooo`03o`000?oooooooooo02;ooooo000iooooo`03o`000?oooooo
oooo013ooooo1?l00002oib7_@03o`000?nLRKkoW8Vn00;oW8Vn00?o0000oif;`?nMRl000_nMRl00
0ol0003oWXg2oij=`P02oij=`P04o`000?nNSL;o0000o`0000?oYKk[00?o0000oio1l?nO`O000_nO
`O001?l0003oV[oboiZol_nJ_o89o`0000?oinG>00Go0000onGHbOoUf<WoiMS9o`000002on;=a003
o`000?oHalSof<O800Ko00000_ln[oD00ol0003oF;7koeRan`02oeRan`04o`000?m^[_SoKZkho`00
00CoOZ_`00?o0000oh^Xj?n;Z>P00on;Z>P00ol0003oU:KRoiBVhP03oiBVhP03o`000?nMY]coWJKL
00;oWJKL00?o0000ojBWf?l000000_l00003oi_Ro@03o`000?n^ioWo000000Co00000_mMc_@5o`00
00CoYM;g00?o0000okgGkOl000001?ni_]d00ol0003oa/;Fo`000003o`000003okn`b_l0003ob;?6
00;ob;?600Go0000ol>X_oo3Z;oo`jRoo`000003olV[_004o`000?o5Y;OoaJBgo`0000CobJJf00Co
0000olJR/oo6X[?o00000oo9Y;<01?l0003ob:6aolRQ/Ol00004olVS/@04o`000?o9X[3obJ:`o`00
00;obJ:a00Go0000olZS/Oo:Xk7obZ>ao`000002olRS/P03o`000?o:YK?obZFc00;obZFc00Co0000
olJT]_o6Y;Ko00000oo9YkL01?l0003o`jFkol>U^ol00003olNZ_@04o`000?nlYl?o_:O3o`0000?o
`Jg600?o0000ok2Wcon`Yll00_n`Yll01?l0003oUicGoiNLeonGW=L9o`000003od=`fOl0003o4e?>
00Co000000?o03Rmo`000?l000000_l000000ol0?<3o0000ocI]fP03o`0000GoUJSS00?o0000omg6
`_l000000ooOb<400ol0003oh/Voon;9_`02o`0000?on<NG00Co0000ooS8Uoohb9Oo00000_oib9H0
0ol0003onLVFooW9UP02o`0001?ooooo00?o0000ooooooooool08Oooool003Sooooo00?o0000oooo
ooooool03oooool2o`000003oi^6_?l0003oW8Nm00?oW8Nm00?o0000oib9__nLRKh00onLRKh01Ol0
003oWH_0oif;`?nMRl3o000000CoWXg20_l00006ojFnj`03o`000?nO`O3oWl7`00So000000Gog?cG
o`000?oVl]Coi_;Do`000003onOUcP05o`000?oUf<WoiMS9onGHbOl000000ooRcL@2o`0000?of<O8
00?o0000om>ma?oC_L@01Ol00004oeRan`04o`000?m^[_SoKZkho`0000CoOZ_`00?o0000oh^Xj?n;
Z>P00on;Z>P00ol0003oU:KRoiBVhP02oiBVhP04o`000?nMY]coWJKLoifVg0Go00000onKh_d:o`00
00CoPLKm00Co0000ojGBmonUd_OoYM;g0ol00005okVng@?o00001Ono/<X00ol0003ob;?6o`000005
ol>X_`04o`000?o9ZkcobJ^lo`0000?oaJBg00Co0000olVV]_o9Y[Ko00000oo6X[<01?l0003obJBc
olVT/ol00004olRQ/@04o`000?o9Xk7obJ>ao`0000?obJ:`00Co0000olVR/Oo9X[7o00000oo:Xk40
1?l0003ob:>bolRS/_l00004olZU/`03o`000?o6Y;Ko000000CobJNg00?o0000ol>U^ol000001?o7
Z[d00ol0003o_:O3o`000004ol6]aP03o`000?n`Yloo/:O?00;o/:O?1?l00002oiZTg@03o`000?mb
TN;oLY7R00;oLY7R00?o0000od1eg_l000000_l00002oa=CcP05o`000?l0>koo0000o`000?l0<kX0
0ol000001?l0?<3o0000ocI]f_lfKMX2o`0000?oUJSS0ol00004omo8`@05o`000?oRbKooh/Voon;9
_ol000000oohaiL01?l0003on<RGooS8Uol00002ooW8UP03o`000?oibIKo000000;onLVF00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00>?ooool00ol0003oooooooooo`0=oooo
o`;o00001?nKQ[`00ol0003oW8Nmoib7_@02oib7_@03o`000?nLRKkoW8Vn00;oW8Vn00?o0000oif;
`?nMRl000_nMRl04o`0000;oZ;ST00?o0000ojFnjonU_^/00onU_^/8o`000004ol[of?l0003og?cG
o`0000?oi_;D00Co0000onOUc_oWiLko00000ooUf<T01Ol0003oh/g4on;=a?oRcLCo000000;ogLBo
00?o0000omS7b?l000001OoC_L@00ol0003oa;;9o`000009o`0000CoOZ_`00?o0000oh^Xj?n;Z>P0
0_n;Z>P01?l0003oU:KRoiBVh_nDY^85o`0000?oPM[n2ol00003odf^n@04o`000?n1a_goPLKmoh76
o@Go00000onW^>D00ol0003o^KkMokVng@04o`0000Ko_k3:0_l00006ol>X_`03o`000?o9Zkco0000
00CoaJBg00Co0000olVV]_o9Y[Ko00000oo6X[<01?l0003obJBcolVT/ol00004olRQ/@04o`000?o9
Xk7obJ>ao`0000CobJ:`0_l00005olZS/@;o00001_o:YK<00ol0003obJNgolVW]`04olVW]`03o`00
0?o7Z[goajZm00CoajZm00?o0000ol6]a_o1[LH00oo1[LH00ol0003o/:O?o`000002o`000003okB_
e?l0003oVZCM00CoVZCM00?o0000og:Ah_mbTN800_mbTN801?l0003o@7GNod1eg_l00003oa=CcP03
o`000?l0>koo000000;o03>j00Co0000o`12`ol0003o00000olfKMX4o`0000;oVjcS00Go0000omo8
`OoOb<7oglS1o`000004on;9_`;o000000Gon<NGo`000?ohb9Oon<RGo`000002ooW8UP04o`000?oi
bIKonLVFo`0000;onLVF00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00>?oo
ool2o`0000_ooooo0ol000000onLR;go0000oi^6_003oi^6_003o`000?nLQkgoW8Nm00;oW8Nm00?o
0000oib9__nLRKh00_nLRKh00ol0003oWH_0oif;`004o`0000GoZ;ST00?o0000ojFnjol000000_l0
00000onFj_Wo0000o`000003o`0000;ob_oH00?o0000omcleol000000ooVl]@01?l0003oinG>onOU
c_l00003onGHb@05o`000?oRcLCoh/g4on;=a?l000001?oMa;l00ol0003odkg4om>ma003om>ma003
o`000?o?]/7o000000?oa;;900Co0000okn/a_no[<Ko00000_n]Xld>o`0000?oG<cg2?l00002o`]H
dP04o`000?l^Jm[o0000o`0000;o?8W/1ol00002ohf^k003o`000?nW^>GoYkSU00?oYkSU1?l00003
okB[c`03o`000?no/<[o_k3:00;o_k3:00?o0000okZT`_l000001oo3Z;l00ol0003oaJBgolFT]`03
olFT]`03o`000?o9Y[Ko000000GoaZ:c0_l00005olRQ/@03o`000?o9Xk7o000000GobJ:`00?o0000
olZS/Oo:Xk401?o:Xk400ol0003obZFcolZU/`05olZU/`03o`000?o9YkOobJNg00CobJNg00?o0000
olNZ_Oo7Z[d01?o7Z[d00ol0003o`Jg6ol6]aP03ol6]aP;o00001Ond[m@00ol0003oVZCMoiZTg@02
oiZTg@03o`000?mbTN;oLY7R00;oLY7R00Co0000od1eg_m0MMko@7GN0_l000001?lCDlko0000o`00
0?l0>kl2o`000004o`0c^_l0003o0000o`0000Co=VgJ00?o0000oi^/honK[><00onK[><01?l0003o
glS1omo8`Ol00003on;9_`03o`000?oTbkkoi<^n00;o00000_ohb9L01?l0003onLRFooW8U_l00002
ooW9UP03o`000?oibIKonLVF00;o00004_ooool2o`00027ooooo000hooooo`03o`000?oooooooooo
00Oooooo0ol00004oib8_@03o`000?nKQ[coVhJl00;oVhJl00?o0000oib7_OnLQkd00_nLQkd00ol0
003oW8Vnoib9_P02oib9_P?o00001?nZ/=`00ol0003oZ;STojRhi002ojRhi0So000000Co]_cLo`00
0?o:omSob_oH3?l000000ooUf<Wo0000on;=a002on;=a003o`000?oMa;oogLBo00?ogLBo0_l00003
om>ma007o`000?o?]/7ockK1olnf`Ol0003oa;;9o`000004okn/aP04o`000?n]Xlgo[J?=ojfSc@oo
000000Ko=eS8o`000?l0003o0000oaU8`ol00002oa1<b0;o000000Co2eSBo`000?l^Jm[o;V_J0_l0
00000ollRNco0000ofVOl002ofVOl003o`000?n=[^coSJk/00;oSJk/00?o0000ojNhiOl000000_l0
00000onW^>Go0000o`000005okB[c`04o`000?no/<[o_k3:o`0000?o^ZC200?o0000ol>X_oo3Z;l0
0oo3Z;l2o`0000KoaJBg00?o0000olJR/oo6X[<01?o6X[<00ol0003ob:6aolRQ/@05olRQ/@03o`00
0?o9X[3obJ:`00CobJ:`00?o0000olZS/Oo:Xk401?o:Xk400ol0003obZFcolZU/`04olZU/`;o0000
1Oo9YkL00ol0003ocJbho`000004olNZ_@03o`000?o;/<3o000000?o`Jg600?o0000olFebol00000
1Ond[m@01?l0003oVZCMoiZTgOnJY=d9o`000003od1eg_l0003o3EK@00Go000000Co03Nmo`000?l0
003o04K71?l00002ocI]fP03o`000?nK[>?oVjcS00;oVjcS00?o0000omo8`Ol000001?oRbKl01Ol0
003oi<^nonC;__oTbkko000000;on<RG00Co0000ooW8U_oib9Ko00000_oibIH00ol0003onLVFo`00
0002oo[;UP03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool003Sooooo
00?o0000ooooooooool01?ooool3o`0000;oWXg200?o0000oib8_OnLR;d00onLR;d00ol0003oVhJl
oi^6_002oi^6_003o`000?nLQkgoW8Nm00;oW8Nm1?l000000onYYmGo0000ojZ`g005ojZ`g004o`00
0?nX^>Co0000o`0000;o[^Ki0_l00002ojghj`03o`000?nfo=co000000Co000000?oi^oCo`000?oY
iL`00_oYiL`01?l0003oj=[6onSJa_l00002onK@`@;o00000ooRcL@00ol0003ogLBoomg4_`02omg4
_`06o`000?oJ_Kgof[fmo`000?oC_LCo00001Oo?]/400ol0003o_jc6okn/aP03okn/aP06o`000?n]
Xlgo0000o`000?nYWL[o00001?n@S/h00ol0003oLG_>og5kcP03o`000006oe9/col0003o=eS8ocMH
b?l0003o9T_20_l000001OlIB<?o0000o`000?l0003o9EO<00;o00000_l^JmX00ol0003oDgkOo`00
0002o`0000?oJIo`00?o0000ohf^k?n=[^`00ol000001_nW^>Go0000o`000?l0003oY:CEo`0000Go
]:_?00?o0000okn`b_l000001?njY<800ol0003o`jRool>X_`02ol>X_`03o`000?noX;[o000000Ko
aJBg00?o0000olJR/oo6X[<01?o6X[<00ol0003ob:6aolRQ/@05olRQ/@03o`000?o9X[3obJ:`00?o
bJ:`00?o0000olZR/?l000001?o:Xk400ol0003oc:Fao`000004olZU/`04o`000?o=Z;?ocJRco`00
00?obJNg00Co0000olf/^?o=[;So00000oo7Z[d01?l0003obk30ol^``?l00002ol6]aP05o`000?o5
]L_oaKG;olFebol000001?nd[m@4o`0000;oVjkT00?o0000og2IjOm`VNT00_m`VNT00ol0003o>GWR
o`000002o`0000;o3EK@00Go0000o`0n`_l0003o0000o`0g_@02o`000004o`16aol0003o?7?Mocac
g@Co00000_nK[><3o`0000Coh/Vo00?o0000onC;__oTbkh00_oTbkh01_l0003on<RGooS8Uol0003o
nLRFo`0000;onLVF00Co0000ooW9U_oibIKo00000_ojbiH00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00?ooooo000hooooo`04o`000?ooooooooooooooo`?o000000?oXY_>o`00
0?nNSL800onNSL800ol0003oW8Rmoib8_@02oib8_@03o`000?nKQ[coVhJl00;oVhJl00Co0000oib7
_OnLQkgoW8Nm0_l00005ojVWe@03o`000?nZ/=coZ[3L00?oZ[3L1?l000000on^i_Wo0000ojghj`02
ojghj`Co000000GogoKKo`000?oVkm?oi^oCo`000003onWUc004o`000?oXf/Koj=[6o`0000?oi]31
00Go0000on?8_Ol0003oh/g4o`000004omg4_`03o`000?oJ_Kgof[fm00;of[fm00?o0000olnf`Oo?
]/400oo?]/42o`0000Ko_jc600?o0000ojVMb_nYWLX00_nYWLX00ol0003oT8k>oi2>cP02oi2>cP05
o`000?maNlkoLG_>o`000?mAI/T00_l00003ocMHb006o`000?lVBl;o0000oaU8`ol0003o8D_30_l0
00000olUElco0000obi[fP02obi[fP04o`000?mCO]ooDgkOoe=ng`[o00001OnTY=D00ol0003o]:_?
okB[c`02okB[c`;o00001_njY<801?l0003o`jRool>X_ol00003oknP^P03o`000?o5Y;OoaJBg00;o
aJBg00?o0000ol:O]?l000001?o6X[<00ol0003oaInao`000005olRQ/@;o00001?o9X[001?l0003o
bZ:`olZR/?l00004olZS/@03o`000?o<YK7o000000CobZFc00Co0000olfX/oo=Z;?o00000_o9YkL0
1Ol0003ocJbholf/^?o=[;So000000;oajZm00Oo0000ol^``?o;/<3obk30o`000?o1[LKo000000Co
aKG;00?o0000okB_e?l000000_l00002okRifP03o`000?nK[^CoVjkT00;oVjkT00?o0000og2IjOm`
VNT00_m`VNT01?l0003o>GWRocUih_l00003o`eFd0?o00000_l0=kd2o`000003o`16aol0003o?7?M
00?o?7?M0ol00003oj6`h`04o`000?oRbKooh/Voo`0000Coi<^n00Co0000onK=_Ol0003o00000_oi
b9H01?l0003onLVFooW9U_l00002ooW9UP03o`000?ojbiKon/^F00;o00004oooool00ol0003ooooo
ooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00?ooooo000gooooo`03o`000?oooooooooo00;o00001OnRVlh01Ol0003oWXg2oij=`_nNSL;o0000
00CoW8Rm00?o0000oi^6_?nKQ[`00_nKQ[`01_l0003oW8Nmo`000?l0003oYYo?o`0000KoZJOE00?o
0000ojZ`g?l000000_l00003okWIl0So00000_oOm]/01?l0003oi^oConK_dol00003onWUc004o`00
0?oXf/Koj=[6o`0000?oi]3100Go0000on?8_OoSb;gohlRmo`000004omg4_`03o`000?oJ_Kgof[fm
00?of[fm00?o0000olnf`Oo?]/400_o?]/401?l0003oc;2oolb`_ol00004okn/aP;o00001OnYWLX0
1Ol0003oT8k>oi2>c_n@S/ko000000?oLG_>00?o0000oe5VbOmAI/T00_l000002?lgF<So0000obI;
`_lVBl;o0000oaU8`ol0003o8D_30_l000000olUElco0000o`000002obi[fP03o`000?mCO]ooDgkO
00?o000000?oM8oNo`000?n@Vm/00on@Vm/00ol0003oY:CEojBTe@03ojBTe@03o`000?ndZloo]:_?
00;o000000?o/9k6o`000?njY<801OnjY<800ol0003o`jRoo`000004oknP^P05o`000?o5Y;OoaJBg
olFT]ol000000_o2Wk@00ol0003oaZ:colJR/`02olJR/`03o`000?o5Wk7o000000Cob:6a00Co0000
olRP/?o8X;3o00000oo9X[001?l0003obZ:`olZR/?l00003olZS/@05o`000?o<YK7oc:FaolbU/Ol0
00000_o:YK<01Ol0003ocJRcolfX/oo=Z;?o000000;obJNg00?o0000olf/^?o=[;P00_o=[;P2o`00
00Gobk3000?o0000olFeboo5]L/01?o5]L/00ol0003o^;WJokRifP04okRifP03o`000?nK[^CoVjkT
00Oo00000oliNN82o`000003o`eFd?l0003o03o200?o000000Go03Nmo`000?l0A/Oo04K7o`000003
ocacg@;o00001OnQ/><00ol0003oh/Voo`000003onC;_P05o`000?oVcKgoi/fmonK=_Ol000000_oi
b9H01?l0003onLVFooW9U_l00002ooW9UP03o`000?ojbiKo000000;on/bG00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00?ooooo000gooooo`?o000000?oZ;o[o`000?nRVlh01?nRVlh00ol0003o
WXg2oij=`P02oij=`P05o`000?nLR;goW8Rmoib8_Ol000001?nKQ[`2o`0000CoYYo?00?o0000ojVW
eOnYYmD00onYYmD3o`0000?o^MW`0_l00003olKak`04o`000?oCn>CodoSTo`0000;ogoKK00Co0000
onK_dooVkm?o00000ooYiL`01Ol0003oj=[6onSJa_oXf/Ko000000;oi]3100?o0000on?8_OoSb;d0
0_oSb;d2o`0000?ogLBo00?o0000omZm_OoJ_Kd00_oJ_Kd00ol0003oe[Njo`000002olnf`@03o`00
0?o</;ooc;2o00;oc;2o00Co0000okn/a_no[<Ko00000_nlYl@00ol0003oZIg:ojVMbP02ojVMbP05
o`000?n@S/koT8k>oi2>c_l000000omaNlh01Ol0003oDFK9oe5VbOl0003o>5C300;o00000_lVBl83
o`0000;o8D_300Co0000obEGc?l0003o@FG@1Ol000000omCO]oo0000ogB?gP02ogB?gP03o`000?n@
Vm_oT9_K00;oT9_K00?o0000ojBTeOnTY=D00_nTY=D00ol0003o]:_?o`000004ok2NaP03o`000?nj
Y<;o^ZC200?o^ZC20_l00005oknP^P04o`000?o5Y;OoaJBgo`0000Co`Ynd00Co0000olJR/oo6X[?o
00000oo5Wk401?l0003ob:6aolRQ/Ol00003olRP/004o`000?o9X[3obJ:`o`0000CobZ:`00Co0000
olZS/Oo:Xk7o00000oo<YK401?l0003obZFcolZU/ol00004olfX/`;o00001Oo=[;P00ol0003obk30
ol^``004ol^``003o`000?o5]L_oaKG;00?oaKG;0_l00006okRifP?o00000onK^>`00ol0003oJZ3`
ofZPl003o`000003ocUih_l0003o0eOB00?o000000Go03o2o`000?l0>Kko0000o`0g_@02o`000003
o`16aol0003o000000;o?7?M0_l00004oj6`h`;o00001?oTbkh01Ol0003oi/fmonK=_OoVcKgo0000
00;onLRF00?o0000ooW9U_l000000_oibIH01?l0003on/^Foo[;U_l00002oo[<U`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c003ooooo`00=oooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nR
VlkoXY_>00?oXY_>00Go0000oij=`_nNSL;oWXg2o`000004oib8_@Co000000?oXiW;o`000?nVWll0
1?nVWll00ol0003oZJOEojVWe@02o`0000?o^/WU00?o0000okWIl?l000001?o6lNl01?l0003odoST
om?hi?l00002omoff`04o`000?oVkm?oi^oCo`0000CojNG<00Co0000onSJa_oXf/Ko00000ooVd<40
1Ol0003ohlRmon?8_OoSb;go000000;oh<6j00?o0000omg4_ol000001?oJ_Kd01_l0003oe[NjomJg
^_l0003ockK1o`0000Goc;2o00?o0000okn/a_l000001?nlYl@01?l0003oZIg:ojVMb_nYWLX7o`00
0003og5kc_l0003oDFK900;oDFK900Oo0000ocQD`ol0003o0000obI;`_l0003o8TJn00;o00000_lQ
Bl<5o`000003od5Ud?l0003o000000;o00001?mdSmh00ol0003oT9_Koi2Kf`02oi2Kf`04o`000?nT
Y=GoY:CEojBTe@;o00001On`W/H00ol0003o^ZC2okZT`P02okZT`P03o`000?ngW;co000000Ko_j2j
0_l00005ol:O]003o`000?o6X[?o000000CoaIna00Co0000olRQ/Oo8XK7o00000oo8X;001?l0003o
bJ:`olVR/?l00004olZR/003o`000?o:Xk7o000000Coc:Fa00?o0000olZU/ol000001Oo=Z;<00ol0
003ocJbholf/^004olf/^003o`000?o;/<3obk3000?obk3000?o0000om2h`ol000000oo5]L/01?l0
003ob[o@olZod?l00003okRifP;o000000?o^lCQo`000?nK^>`01?nK^>`01?l0003oJZ3`ofZPl?mZ
X?04o`0000;o0eOB0_l000000ol0?l;o0000o`0i_P02o`000004o`1;b_l0003o0000od5ih0Co0000
00KoXK3So`000?l0003o0000ojJfi?l00003onC;_P06o`000?oVcKgoi/fmonK=_Ol0003oj<nm0_l0
0002ooW9UP04o`000?oibIKonLVFo`0000;on/^F00?o0000oo[<Uoojc9L00_l0000Cooooo`03o`00
0?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41000oooool002cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00000onX_n/00ol0
003oXY_>oj:KcP03oj:KcP05o`000?nNSL;oWXg2oij=`_l000000_nLR;d3o`0000GoXiW;00?o0000
ojJOconVWll00_nVWll00ol0003oZJOEo`000006ok[9i@?o00000_o6lNl00ol0003odoSTom?hi009
o`0000;ojNG<00Go0000onSJa_oXf/Koj=[6o`000002onK@`@05o`000?oSb;gohlRmon?8_Ol00000
1?oP`KX00ol0003of[fmomZm_@02omZm_@03o`000?oF]k[oe[Nj00;oe[Nj00?o0000olb`_oo</;l0
1Oo</;l00ol0003o_:O4okbWa003okbWa006o`000?nYWL[o0000o`000?nUVLWo00000on<RL`00ol0
003oKGK;o`000002o`0000;oDFK900Co0000ocQD`olhE<?o00000_lVBl800ol0003o8TJno`000002
ob5;``Co00000_m1IM000ol0003oGWGBoeiedP06o`0000CoT9_K00Ko0000ojBTeOl0003o0000oj:H
b_l00006ok2NaP04o`000?njY<;o^ZC2o`0000;o]ibl00?o0000oknP^_noX;X01?noX;X00ol0003o
`Yndol:O]004ol:O]003o`000?o6X[?o000000CoaIna00?o0000olRQ/Ol000001Oo8X;02o`0000Go
bZ:`00?o0000olZS/Ol000001Oo<YK400ol0003ocJRcolfX/`04olfX/`03o`000?o=[;SocJbh00?o
cJbh00?o0000om6b^ol000000oo;/<001ol0003od;S3om2h`oo@^<?o0000olFebol000001?o:_m00
0ol0003o^;WJo`000004ok_4h@04o`000?nK^>coVkS/oi^hk0Oo00000_l]O>H2o`0000;o0eOB0ol0
00001?l0>Kko0000o`000?l0BlX2o`0000?o@GWP0_l00005ojJfi004o`000?oTbkkoi<^no`0000;o
i/fm00Go0000onS?_OoXckgoj<nmo`000002ooW9UP04o`000?oibIKonLVFo`0000;on/^F00?o0000
oo[<Uol000000_ojcIP00ol0003oooooooooo`0>ooooo`?o00001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000003ooooo`00;?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooool000000onX_n/00ol0003oXY_>oj:KcP02oj:KcP03o`00
0?nNSL;oWXg200Co00000_nMU<X00ol0003oXiW;oj>Ib`03oj>Ib`03o`000?nVWlooYYo?00;oYYo?
0ol00005ok[9i@04o`000?o<h>Ooc>3WolcPi`Ko00000_oRimH01?l0003oi^7>onKQc_l00002onOI
aPCo000000?oj=[6o`000?oVd<400_oVd<401Ol0003ohlRmon?8_OoSb;go000000Coh<6j0_l00003
omZm_@03o`000?oF]k[oe[Nj00;oe[Nj00?o0000olb`_oo</;l01?o</;l2o`0000Go_:O40_l00004
ojFIb@05o`000?n<RLcoS8W<ohb9c?l000000_m]M//2o`0000;oDFK900Oo0000ocQD`ol0003o0000
obI;`_l0003o8TJn00?o000000Co8D_3o`000?lcE<Go00000om1IM001?l0003oGWGBoeied_l00003
ogV3d@Oo00001?nRV<X00ol0003o/9k6ok2NaP03ok2NaP03o`000?njY<;o000000Co]ibl00?o0000
oknP^_noX;X00_noX;X2o`0000Oo`Ynd00?o0000olFO/Oo5Wk401?o5Wk400ol0003ob:2`olRP/004
olRP/003o`000?o:X[3obZ:`00GobZ:`00?o0000olbU/Oo<YK401?o<YK400ol0003ocJRcolfX/`03
olfX/`03o`000?oA[KGo000000?ocJbh00Go0000om6b^ooA/[_odK:ko`000002ol^``003o`000?o@
^<?od;S300;od;S300?o0000olZod?o:_m000oo:_m02o`0000Go^lCQ1?l00002oiS3m@04o`000?mQ
Y_KoHJKfof6VmP?o000000?o;GcVo`000?l000000_l000000ol0?/7o0000o`000002o`0000;o04_:
00Oo0000od5ih?m1NN3o@GWPo`000?nV]^Co000000CoY[KT00?o0000onC;__l000000ooVcKd01Ol0
003oj<nmonS?_OoXckgo000000;onLVF00?o0000ooW9U_l000000_ojbiH01?l0003on/bGoo[<Uol0
0002oo[=V003o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`00;?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?l00003oj:KcPCo00000_nET/h00ol0003o
WIC:oifDbP02oifDbP03o`000?nSVL_oXiW;00?oXiW;00Co0000ojJOconVWloo00000ong^]`01Ol0
003o^/WUok[9iOnjbNGo000000?oc>3W00?o0000omWXh?oIj>000_oIj>001?l0003oh^OFon;We_l0
0002onKQcP03o`000?oWfLKoimW600;oimW600?o0000onOA`OoWdL400ol000000ooVd<7o0000on?8
_@02on?8_@03o`000?oP`K[oh<6j00;oh<6j00Ko0000omfl^?oM_;So0000omZm_Ol00004omJg^P03
o`000?oC/kWo000000Coc;2o00Co0000olV]__o9[Kko00000_nlYl@2o`000003okVT`ol0003oYIW9
00?oYIW900Go0000ohb9c?n<RLcoS8W<o`000002ofefb`03o`000?m>HLKo000000;o00000_lhE<<4
o`000005ob96__l0003o0000ob5;`ol000000_lcE<D2o`000003od5Ud?l0003oGWGB00;oGWGB00Go
0000ogV3dOmiPm7oNH?Ao`000004ohn?cP03o`000?nRV<[oXYS:00;oXYS:00?o0000ok2Na_n`W/H0
0on`W/H2o`0000Go]ibl00Go0000oknP^_noX;[o_j2jo`000002okbK]P03o`000?o2WkCo`Ynd00Co
`Ynd00?o0000olFO/Oo5Wk401?o5Wk400ol0003ob:2`olRP/004olRP/003o`000?o:X[3obZ:`00Go
bZ:`00?o0000olbU/Oo<YK400oo<YK400ol0003ocjRbo`000003olfX/`05o`000?oA[KGodJfeom6]
]Ol000000_o=[;P01ol0003odK:kom6b^ooA/[_o0000ol^``?l000001Oo@^<<00ol0003ob[o@olZo
d002olZod003o`000?o?b]Ko000000?o^lCQ0_l000000onmdNWo0000oiS3m@04oiS3m@03o`000?mQ
Y_KoHJKf00;oHJKf1?l000001_l0E]3o0000o`000?l0?/7o0000o`0j_`?o000000So04_:o`000?l0
003o0000od5ih?l0003oY[KTo`0000?oY[KT0_l00003onK=_@06o`000?oXckgoj<nmonS?_Ol0003o
j]:l0_l00002ooW9UP04o`000?ojbiKon/^Fo`0000;on/bG00?o0000oo[=V?ojcIP00_l0000Coooo
o`03o`000?oooooooooo01Wooooo000/ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
00?ooooo1Ol00002oh:Dg003o`000?nET/koUI;>00;oUI;>00Go0000oifDb_nMU<[oWIC:o`000005
oj>Ib`03o`000?nVWloo000000Go]k[L00?o0000ok[9iOl000000oo<h>L00ol0003ofNSPomWXh002
omWXh004o`000?oRimKoh^OFo`0000;oi^7>00?o0000onOIa_oWfLH00_oWfLH01Ol0003oim71onOA
`OoWdL7o000000;oiLZl0_l00003on?8_@05o`000?oP`K[oh<6jon31^_l000001?oM_;P00ol0003o
e[NjomJg^P03omJg^P04o`000?oC/kWodk>io`0000;oc;2o00Oo0000olV]__o9[KkobJfno`000?nl
YlCo000000Co^JC300?o0000ojFIbOnUVLT00_nUVLT01Ol0003oS8W<ohb9c?n<RLco000000;oKGK;
00Co0000odiQa_m>HLKoCV760ol000000olXB;go0000o`000002ob96_P?o00000_lcE<D01?l0003o
BV77o`000?l00003oeiedP03o`000?miPm7oNH?A00;oNH?A00?o0000ohn?c_n?Slh00_n?Slh00ol0
003oXYS:oj:HbP02oj:HbP03o`000?n`W/Ko/9k600;o000000?o[IJoo`000?ngW;`01?ngW;`01?l0
003o_j2joknP^_l00003okbK]P03o`000?o2WkCo`Ynd00?o`Ynd0_l00005olFO/@03o`000?o5W[3o
000000Cob:2`00?o0000olVQ[ol000001Oo:X[000ol0003oc:B`o`000003olbU/@04o`000?o?Z;;o
cjRbo`0000;ocJRc00?o0000om6]]OoA[KD00_oA[KD00ol0003ocJbho`000005om6b^`03o`000?o@
^<?od;S300?od;S300?o0000omG2aol000000_o:_m001ol0003ocl[Folo:e_o?b]Ko0000ok_4hOl0
00001?nmdNT01?l0003oV<?eoiS3mOnH`oD9o`000004oaeli_l0003o0000o`1Fd0?o000000?o03Zo
o`000?l0C/d00_l00002odEoi0Oo000000?oZk_Uo`000?oVcKd00_oVcKd01?l0003oj<nmonS?_Ol0
0003on[B_004o`000?oibIKonLVFo`0000;on/^F00?o0000oo[<Uol000000_ojcIP01?l0003on/jJ
oo[>V_l0000Booooo`03o`000?oooooooooo01Wooooo000/ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`04ooooo`;o00001On2U=`01Ol0003oUI;>oiFBc_nET/ko0000
00CoWIC:00?o0000oj>IbonSVL/00_nSVL/2o`0000Ko]k[L1?l000000oo<h>Oo0000omWXh003omWX
h004o`000?oRimKoh^OFo`0000;oi^7>00?o0000onOIa_oWfLH00_oWfLH01Ol0003oim71onOA`OoW
dL7o000000?oiLZl00Go0000on?4^Ol0003ohlRmo`000004on31^P03o`000?oM_;SogKbh00;ogKbh
00?o0000omJg^_oF]kX00_oF]kX01ol0003odk>iom>c^OoC/kWo0000olb`_ol000001Oo9[Kh00ol0
003o^JC3okVT``03okVT``03o`000?nUVLWoYIW900;oYIW900Go0000ohb9c?n<RLcoS8W<o`000002
ofefb`Go000000Co=Do0o`000?l0003o:4Rm0_l000000olRA[ko0000obU8_P02o`0000;o<eC500?o
0000odYQaom:HLL00_l00002oeiedP05o`000?miPm7oNH?AogV3dOl000001?n?Slh00ol0003oXYS:
oj:HbP02oj:HbP03o`000?n`W/Ko000000Co[IJo00?o0000okNL_?ngW;`00ongW;`2o`0000Go_9^f
00Go0000ol:O]?o2WkCo`Yndo`000002ol6L/P05o`000?o5Wk7oaInaolFO/Ol000000_o5W[000ol0
003ob:2`olRP/002olRP/003o`000?o9XJoo000000CobZ:`00Co0000olbT/?o<Y;3o00000_o<YK40
1Ol0003ocjRbolnX/_o?Z;;o000000;ocJRc00?o0000om6]]OoA[KD00ooA[KD00ol0003odK:kom6b
^`04om6b^`03o`000?o@^<?od;S300;od;S300Ko0000omG2aooE`/Oo0000olZod?l00004olo:eP;o
00001OnmdNT4o`0000?oTLcl00?o0000oe:YnOmBZOT00_mBZOT6o`000006o`0k_Ol0003o0000o`0j
_ol0003o04k=0_l00004odEoi0;o00001?n[^nD00ol0003oi/fmo`000003onS?_@05o`000?oZd[co
j]:lon[B_?l000000_oibIH00ol0003on/^Fo`000002oo[<U`04o`000?ojcISon/fHo`0000;on/jJ
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`00;?ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool01Oooool2o`0000CoPYCL00?o0000oiFBc_nET/h0
0_nET/h01_l0003oWIC:oifDb_nMU<[o0000oj>Ib`?o00000_n_[]L01?l0003o]k[LokNjg?ng^]`2
o`0000CoalkO0ol00002omWXh005o`000?oRimKoh^OFon;We_l000000_oVhLh01Ol0003oimW6onOI
a_oWfLKo000000?oim7100Go0000onG:_?oUb[coiLZlo`000003on?4^@03o`000?oP`K[oh<6j00;o
h<6j00?o0000omfl^?oM_;P00_oM_;P00ol0003of[Rfo`000002omJg^P03o`000?oC/kWodk>i00?o
dk>i00?o0000olV]__o9[Kh01?o9[Kh00ol0003o^JC3okVT``03okVT``03o`000?nUVLWoYIW900;o
YIW92Ol00003odiQaP06o`000?leCl3o0000obQ8_Ol0003o9D>j0ol000001OlYB;ko0000o`000?lc
E<Go000000;oBV7700?o0000of=^bOl000000_l00004ogV3d@05o`000?n?SlkoSho>ohn?c_l00000
0onRV<X3o`0000Go[IJo00?o0000okNL_?ngW;`00ongW;`00ol0003o_9^fokbK]P04okbK]P04o`00
0?o2WkCo`Yndo`0000?o`Ibb00Co0000olFO/Oo5Wk7o00000oo5W[001Ol0003ob:2`olRP/?o8X;3o
000000?obJ6_00Co0000olZR/?o:X[3o00000oo<Y;001?l0003oc:FaolbU/Ol00004olnX/P;o0000
1_oA[KD00ol0003odK:kom6b^`03om6b^`03o`000?oF^[go000000;od;S300?o0000omG2aooE`/L0
0_oE`/L00ol0003ocl[Folo:eP02olo:eP05o`000?oBe]cod]KLo`000?nmdNT00ol00002ok_Ll004
o`000?nAc?coTLcloi7<o0Wo000000Go2gWRo`000?l0003o0000o`0k_@02o`000004o`0j_ol0003o
0000o`0000CoAGoT00?o0000oj^kiOl000000on[^nD2o`0000?oj<nm00Ko0000on[B_?oZd[coj]:l
o`000?o[e;d2o`0000;on/^F00Co0000oo[<Uoojc9Oo00000_ojcIP00ol0003on/jJoo[>VP02o`00
01?ooooo00?o0000ooooooooool05oooool002cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000oh:Dg?n2U=`00_n2U=`01Ol0003oUI;>oiFBc_nET/ko
000000;oWIC:0ol00006ojn^e`03o`000?ng^]co000000GoalkO00Co0000omCGf_oDem[oe=OJ1?l0
00001OoRimKo0000onKQc_oVhLko000000CoimW600Go0000onOA`OoWdL7oim71o`000003onG:_004
o`000?oSa;WohlBion?4^@;o00000ooP`KX00ol0003ogKbhomfl^002omfl^006o`000?oJ^;Kof[Rf
o`000?oF]k[o00001OoC/kT00ol0003obJfnolV]_P03olV]_P03o`000?o6Z[go000000Go^JC31?l0
00000onRUlWo0000o`000003o`000003ofMbb_l0003o000000?oCV7600Ko0000ocE?`?leCl3o0000
obQ8_Ol00002obE3^P04o`000?lYB;ko0000ocUA_`?o00000_m:HLL01?l0003oHfk9of=^bOmSK/T5
o`0000;oSho>1Ol00002oin?``03o`000?n]U[oo[IJo00Co[IJo00Co0000okNL_?ngW;co]ibl0_l0
0006okbK]P03o`000?o2WkCo000000Co`Ibb00Co0000olFO/Oo5Wk7o00001?o5W[001?l0003ob:2`
olRP/?l00003olVQ[`04o`000?o:X[3obZ:`o`0000Coc:B`0_l00005olnX/P03o`000?oA[KGodJfe
00CodJfe00?o0000omFc]ol000000ooA/[/01_l0003oe[ZmomJj_Ol0003od;S3o`0000CoeL;70_l0
0003olo:eP03o`000?oBe]cod]KL00;od]KL00?o0000ok_Ll?nkg?000onkg?04o`0000;oQ];o4?l0
00000ol0DLko0000o`000003o`000003odEoi?l0003oZk_U00?o000000?o[l3Wo`000?oXckd00_oX
ckd01Ol0003oj]:lon[B_?oZd[co000000;ojmBm00Co0000oo[;U_ojbiKo00000_ojc9L00ol0003o
n/fHo`000002oo[>VP04o`000?ojcicon/nLo`0001;ooooo0_l0000Hooooo`00;?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool5o`0000;oUI;>1?l00002ojBT
e@03o`000?n_[]Oo[jkG00Co[jkG0_l00005olO>g`03o`000?oDem[oe=OJ00;oe=OJ00Co0000omgH
d_oMf=;ogMSB1_l00002onOIaP05o`000?oWdL7oim71onOA`Ol000000ooUb[`01Ol0003ohlBion?4
^OoSa;Wo000000;ohKnf00?o0000on31^_l000001?oM_;P00ol0003of[RfomZh]P02omZh]P03o`00
0?oC/kWodk>i00?odk>i00?o0000om6`^Ol000000oo9[Kh01?l0003oaZZmolJZ_Ol00004okVT``;o
00000onRUlT3o`0000?oQhO<00?o0000ofMbb_mWL/X00_l000001?m>HLKo0000ocE?`?leCl03o`00
00?o9D>j00?o0000obU8__l000000_liDKl01?l0003oBV77odYQaol00003of=^b@04o`000?mjNlSo
NW_8ogYkb0?o00000_n?Q/H00ol0003oWho3oin?``03oin?``03o`000?n]U[oo[IJo00?o[IJo00Co
0000okNL_?ngW;co00000_neUkT00ol0003o_9^fokbK]P04okbK]P03o`000?o1W;;o`Ibb00Co`Ibb
0_l00005olFN/003o`000?o8X;3o000000CobJ6_00?o0000olZR/?l000001Oo<Y;000ol0003ocjRb
olnX/P04olnX/P03o`000?oA[KGodJfe00?odJfe00Co0000omFc]ooE/kOo00000_oA/[/00ol0003o
e[ZmomJj_@02omJj_@03o`000?oE`/OoeL;700;oeL;700Ko0000om[=c?oJcLco0000olo:e_l00004
om;Fg004o`000?oDhn;o0000ok_Ll0?o00000_ngi_H4o`0000?oMm;n00?o0000obbSkol/Xnl00ol0
00000ol0L]So0000o`000005o`000003o`1Ac_l0003o000000;oAhGX1?l00004ojo0i`03o`000?oX
ckgo000000?oj]:l00Go0000on_D_Oo[e;gojmBmo`000002oo[;UP03o`000?ojc9Oo000000;on/fH
00Co0000oo[>V_ojcY[o00000_ojci`00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001So
oooo000fooooo`;o00002Oooool01?l0003oGHSToef8i?mMR>@3o`0000;oT9[I00?o0000ojBTeOnT
Y=D00_nTY=D01?l0003o[jkGojn^eon_[]L2o`0000;o_[oJ00Go0000olO>goo7c]ooalkOo`000004
omCGfP03o`000?oMf=;ogMSB00;ogMSB00Co0000on;EbooReL_o00000_oSd<@3o`0000?oim7100Co
0000onG:_?oUb[co00001?oSa;T01Ol0003ohKnfon6o]_oQ_kKo000000CogKbh00?o0000omZh]_oJ
^;H00ooJ^;H00ol0003odk>iom>c^@02om>c^@07o`000?oA/;WodK2iom6`^Ol0003obJfno`000004
olJZ_@05o`000?niY<?o^JC3o`000?ngX/@01?l00002oj:Gb@05o`000?n7QlcoQhO<ohN7c?l00000
0_mWL/X00ol0003oB5g5o`000002o`000003ocE?`?l0003o9TBj00;o00000_lU@kX3o`0000?o>E6o
0_l000000om:HLOo0000of=^b@02of=^b@05o`000?mjNlSoNW_8ogYkb?l000001?n?Q/H00ol0003o
Who3oin?``02oin?``03o`000?n]U[oo[IJo00?o[IJo00?o0000okNL_?l000000oneUkT00ol0003o
_9^fokbK]P03okbK]P;o00001_o1W;800ol0003oaIj`olFN/004olFN/003o`000?o8X;3o000000Go
bJ6_00?o0000olbT/?o<Y;001?o<Y;000ol0003ocjRbolnX/P03olnX/P03o`000?oC[K?o000000Co
dJfe00Ko0000omFc]ooE/kOo0000om6b^ol00005omJj_@05o`000?oE`/OoeL;7omG2aol000001?oJ
cL`2o`0000?od]KL00Co0000omCSh_oDhn;oe>?R0ol000000ongi_Ko0000o`000002ojk/n17o0000
00?o03Nio`000?l0DLh00_l0DLh01ol0003oAhGXodN5j?m7QNSo0000ojo0iol000000on_`>L2o`00
00Coj]:l00Go0000on_D_Oo[e;go0000oncG_P02o`0000;on/bG00Co0000oo[=V?ojcISo00000_oj
cYX00ol0003on/nLoo[?W002o`0001?ooooo00?o0000ooooooooool05Oooool003Gooooo00?o0000
ooooooooool02_ooool01Ol0003oGHSToef8i?mMR>Co000000CoT9[I00?o0000ojBTeOnTY=D00_nT
Y=D00ol0003o[jkGo`000005okjofP03o`000?o7c]oo000000Coe=OJ00?o0000omgHd_oMf=800_oM
f=801?l0003oh]G;on;Ebol00004on?@a005o`000?oSbkoo0000onOA`Ol000000ooUb[`01Ol0003o
hlBion?4^OoSa;Wo000000CohKnf00?o0000omfl^?oM_;P00_oM_;P00ol0003of[RfomZh]P02omZh
]P03o`000?oH]KGo000000;odk>i00?o0000om6`^OoA/;T00ooA/;T00ol0003oaZZmolJZ_@03olJZ
_@03o`000?niY<?o000000Co00001?nRUlT01Ol0003oQhO<ohN7c?n7Qlco000000?oIg;:00Co0000
odQMaOm8GLGo00000_leCl000ol0003o9TBjo`000002obE3^P04o`000?l/A[[o0000o`0000;o>E6o
00Co0000odiM`_l0003o00000omSK/T01Ol0003oNW_8ogYkb?mjNlSo000000CoShK600?o0000oin?
`onOSl<00onOSl<00ol0003o[IJoojfF_`02ojfF_`;o00001OneUkT01ol0003o_9^fokbK]_nlVkKo
0000ok^I]?l000001_o1W;800ol0003oaIj`olFN/005olFN/003o`000?o9XJoobJ6_00CobJ6_00?o
0000olbT/?o<Y;000oo<Y;000ol0003ocjRao`000004olnX/P03o`000?oC[K?o000000?odJfe00?o
0000omFc]ooE/kL00_oE/kL00ol0003oe[ZmomJj_@03omJj_@05o`000?oL`l7o0000omG2aol00000
1OoJcL`01Ol0003ogmW@o`000?oBe]co000000?oe>?R00?o0000om?^i_oCk^H00ol000000on^k?So
0000o`000002oj?]n13o000000?o03Nio`000?l000000_l0DLh2o`0000;oAhGX00?o0000ojo0iol0
00000_l00002ok;6j@04o`000?oZd[coj]:lo`0000?ojmBm00Co0000oncG__o/ekko00000_ojc9L0
1_l0003on/fHoo[=V?l0003on/jJo`0000;on/nL00Co0000ooWAWooidIoo00004_ooool00ol0003o
ooooooooo`0Eooooo`00=Oooool00ol0003oooooooooo`0;ooooo`05o`000?mMR>CoGHSToef8i?l0
00001?n@V]T01?l0003oY:CEojBTeOnTY=D3o`0000Go_[oJ1?l00002omCGfP03o`000?oMf=;ogMSB
00;ogMSB00Co0000on;EbooReL_o00001?oSd<@01?l0003ohl^oon?;_ooSbkl2o`0000;oiLZl00Go
0000on?4^OoSa;WohlBio`000004on6o]P03o`000?oN^kCo000000;ogKbh00?o0000omZh]_oJ^;H0
0_oJ^;H01_l0003of;FeomRe]Ol0003odk>io`0000KodK2i00?o0000olJZ_Oo6Z[d00oo6Z[d3o`00
00Co]j;400?o0000oj:GbOnRUlT00_nRUlT01Ol0003oQhO<ohN7c?n7Qlco000000;oIg;:00?o0000
odQMaOm8GLD00_l000001OleCl3o0000obI4^_lVA;[o000000;o9D>j00?o0000oba6^_l000000_li
DKl01?l0003oCUg2odiM`_l00004of=^b@05o`000?mjNlSoNW_8ogYkb?l000001?n?Q/H00ol0003o
Who3oin?``02oin?``03o`000?n]U[oo[IJo00;o000000?oZi6ko`000?neUkT01?neUkT01?l0003o
_9^fokbK]_l00003ok^I]003o`000?o1W;;o`Ibb00;o`Ibb00?o0000ol6L/_l000001_o5W[000ol0
003obJ6_olVQ[`03olVQ[`03o`000?o;Xk3o000000Coc:B`00?o0000olnX/Ol000000oo?Z;801Ol0
003odjfcom>]/ooC[K?o000000;odJfe00?o0000omFc]ooE/kL00_oE/kL00ol0003oe[ZmomJj_@02
omJj_@05o`000?oL`l7og<?1omc3`Ol000001OoJcL`01Ol0003ogmW@omoId?oOfM3o000000?oe>?R
00Co0000om?^i_oCk^Ko00000_o>mNT3o`000003oj?]n?l0003o000000;oV>_h5?l000001_m7Rnco
0000o`000?l0003o[l3Wo`0000Go//KY00?o0000on[B_?l000000_o[e;d01?l0003ok=NnoncG__o/
ekh3o`0000;on/fH00Co0000oo[>V_ojcY[o00000_ojci`01?l0003onM6OooWAWol0000Cooooo`03
o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3?ooool01Ol0003oGHSToef8i?mMR>Co000000?oT9[I00Co0000ojBTeOl0003o00000on`/]X01Ol0
003o_[oJokjof_nn_m[o000000CoblWH0ol00003omgHdP04o`000?oReL_oh]G;o`0000Cohm3400?o
0000on?;_ooSbkl00_oSbkl01Ol0003ohlJko`000?oUb[co000000?ohlBi00?o0000on6o]_oQ_kH0
0_oQ_kH01_l0003og[^domjk]?l0003ogKbho`0000Cof[Rf00Go0000omRe]OoH]KGof;Feo`000006
om6`^@04o`000?o?[kWo0000olJZ_@?o000000?oaJVno`000?ngX/@01?ngX/@00ol0003oXYO9oj:G
b@08o`0000;oIg;:00?o0000odQMaOm8GLD00ol00002obI4^P;o000000Go9D>jo`000?l/A[[o;4Jj
o`000002ocUA_`03o`000?m>GL;oCUg200;o00000_mSK/T01Ol0003oNW_8ogYkb?mjNlSo000000Co
ShK600?o0000oin?`onOSl<00_nOSl<00ol0003o[IJoo`000003oj^A^`03o`000?neUkWo]INi00?o
]INi00?o0000okbK]_l000001?nkVK@01Ol0003o`Ibbol6L/_o1W;;o000000;o`Ibb00?o0000olFN
/?o5W[000oo5W[02o`0000CobJ6_00Co0000ol^S/?o;Xk3o00000oo<Y;001Ol0003ocjRaolnX/Oo?
Z;7o000000;ocjRb00Oo0000om>]/ooC[K?odjfco`000?oA[KGo000000CoeK>g00?o0000omZk^_l0
00000ooF^[d01?l0003og<?1omc3`OoL`l42o`0000?of/g<00Wo0000omoId?oOfM3ogmW@o`000?oR
iMGo0000omCSh_l000000_oCk^H01?l0003oc_GYolkejOl00002olKijP?o000000?oV>_ho`000?l0
00000_nBioX@o`000003o`1Bc_l0003o000000?oAh_/00?o0000ok;6jOl000001?nba^T2o`0000?o
jmBm00Co0000oncG__o/ekko00000_o]fKl01?l0003on/fHoo[=V?l00002oo[>VP08o`000?ojcico
n/nLo`000?oidIoo0000ooWBX_l0000Cooooo`03o`000?oooooooooo01?ooooo000Eooooo`03oa0@
4?oMgMgooooo01gooooo0_l0000>ooooo`Co00000_n@V]T3o`0000Ko/;;J00?o0000okjof_l00000
1Oo;bMP01_l0003oe<gBomC=d_l0003ogMSBo`0000?oh]G;00?o0000on?@a?oSd<@00_oSd<@01Ol0
003ohl^oon?;_ooSbkoo000000?ohlJk0_l00002on?4^@03o`000?oQ_kKohKnf00;ohKnf00?o0000
omjk]?oN^k@00_oN^k@00ol0003of[RfomZh]P02omZh]P03o`000?oH]KGof;Fe00;of;Fe00?o0000
om6`^OoA/;T00ooA/;T00ol0003ocjnio`000002o`000003olJZ_Ol0003oaJVn00;oaJVn00?o0000
okNRa?ngX/@00_ngX/@3o`0000;oWiK:00Ko0000oh>5cOn3QLgoPhG=o`000?mQKl/3o`0000;oB5g5
00Oo0000obm;__l0003o0000obI4^_l0003o8d2h00;o00000_l/A[X2o`000006ocUA_ol0003oCUg2
odiM`_l0003oIF[30ol00003ogYkb003o`000?n?Q/KoShK600;oShK600Co0000oin?`onOSl?oWho3
0ol00005oj^A^`03o`000?neUkWo]INi00;o]INi0_l00005ok^I]004o`000?o1W;;o`Ibbo`0000?o
`Ibb00?o0000olFN/?o5W[000_o5W[001?l0003oaYn`olJO/?l00003olVQ[`05o`000?o;Xk3obj>`
ol^S/?l000000_o<Y;001ol0003ocjRaolnX/Oo?Z;7o0000olnX/_l000001OoC[K<00ol0003oeK>g
omFc]`02omFc]`07o`000?oJ^k[of[^jomZk^_l0003oe[Zmo`000003omc3`@06o`000?oQc/GohLk5
o`000?oJcLco00000ooOfM001?l0003oh^GEon;UeOoRiMD2o`000006om?^i_l0003oc_GYolkejOl0
003oa_WZ0_l00002okkik0?o000000CoT^Ojo`000?l0003oTN;m4Ol000001Ol0D/ko0000o`000?m7
Rnco000000;o//KY00Ko0000ok;6jOl0003o0000okC<k?l00002on_D_@05o`000?o/ekkok=NnoncG
__l000000_o]fKl01_l0003on/fHoo[=V?l0003on/jJo`0000;on/nL00Co0000ooWAWooidIoo0000
0_oidZ800ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo000:ooooo`03oc8b<_l0
003o000000?o000000Go<S8booooooooooooc<c<oa0@4002o`000003ohN7Qooooooooooo01_ooooo
00?o0000ooooooooool03Oooool00ol0003o>WcTocYli003o`0000;oTZCQ00?o0000ok2bf_n`/]X0
1?n`/]X2o`0000GoblWH00?o0000omC=d_oDcM800_oDcM83o`000003on;Ebol0003ohm3400?ohm34
00Go0000on?;_ooSbkoohl^oo`000004on?6^`05o`000?oQ`KSo0000on?4^Ol000000ooQ_kH00ol0
003og[^domjk]003omjk]0;o00000ooJ^;H01ol0003of;FeomRe]OoH]KGo0000omNc]Ol000000ooA
/;T3o`000004oln_^Ol0003oaZZmo`0000CoaJVn00?o0000okNRa?ngX/@00_l000000ondX/Go0000
oinFbP03oinFbP05o`000?n3QLgoPhG=oh>5cOl000000omQKl/2o`000004odQMaOl0003o;d^no`00
00;o9TBj00Oo0000ob=0^?l0003o0000oba6^_l0003o>djl00;o00000om>GL801?l0003oIF[3ofEZ
`omUJ/<3o`000004ogYkb?l0003oShK6ohn6aPGo00000_nNR[h00ol0003oZi6koj^A^`03oj^A^`07
o`000?neUkWo]INiokFG^Ol0003o]9Bgo`000006ok^I]0;o00001Oo1W;801?l0003oaIj`olFN/?l0
0003olJO/004o`000?o9XJoobJ6_o`0000Cobj>`00?o0000olbT/?l000001?o?Z;400ol0003ocjRb
o`000005om>]/`03o`000?oE/kOoeK>g00;oeK>g00?o0000omZk^_oJ^kX00_oJ^kX00ol0003og<?1
omc3`@02omc3`@05o`000?oQc/GohLk5on7>aOl000000ooOfM001Ol0003oh^GEon;UeOoRiMGo0000
00;oh^oH0_l000001?o>mNWo0000olKij_l00002okkik0;o00000_nimnl5o`0000?oU=Wn00?o0000
of:moOmR_Od00_mR_Od00ol0003o9IC]obFDk@08o`000005odB@kol0003o0000o`000?nba^T00_l0
0004okC<k003o`000?o[e;go000000;ok=Nn00Go0000ongI_oo]fKoo0000ongL`@02o`0000;on/jJ
00Co0000oo[?W?ojcico00000_oidIl01?l0003onM:RooWBX_l0000Booooo`;o00005?ooool000[o
oooo00?oV9RHodA4A?ooool00_ooool02_m4A4CoV9RHoooooooooooo8B4QohN7Qolb<S;oZJVYodA4
A?n7QhLLooooo`03o`000?oooooooooo00kooooo00Co0000ocYli?ljO>Co00001?nBY>401?l0003o
/;;Jok2bf_n`/]X2o`0000;o_;gJ00Go0000ol_9f?o;bMSoblWHo`000004omC=dP04o`000?oJc<_o
f/c;om[<b`;o00001?oSd<@01Ol0003ohl^oon?;_ooSbkoo000000?ohlJk00Go0000on71^?oQ`KSo
hL6ho`000004on6o]P03o`000?oN^kCog[^d00;og[^d00Ko0000omfh/ooM^;?o0000omZh]_l00004
omRe]@03o`000?oG/kGoek>e00Co00001?o?[kT00ol0003oaJVnolFY_P03olFY_P03o`000?ngX/Co
000000Co]:;500?o0000oinFb_nOU/X00_nOU/X01?l0003oPhG=oh>5cOl00003of5_b`05o`000?lo
FLGo0000o`000?l_Bkh00_l000001OlVA;[o0000ob=0^?lS@;So000000;o;4Jj00Co0000oc]>_?l0
003o00000_m>GL801Ol0003oIF[3ofEZ`omUJ/?o000000;oNgO31?l00002ohj1`@03o`000?nNR[ko
WXZn00;oWXZn00?o0000oj^A^on[TK/00on[TK/01?l0003o]INiokFG^Ol00003okBD]`03o`000?nk
VKCo^iVd00?o^iVd00?o0000ol6L/_o1W;801?o1W;801?l0003oaIj`olFN/?l00003olJO/004o`00
0?o9XJoobJ6_o`0000Cobj>`00?o0000olbT/?l000001Oo?Z;400ol0003odjfcom>]/`03om>]/`03
o`000?oG];Go000000;oeK>g00?o0000omZk^_oJ^kX00ooJ^kX01Ol0003og<?1omc3`OoL`l7o0000
00CohLk50_l000000ooOfM3o0000on;Ue@02on;Ue@05o`000?oRkmSoh^oHo`000?oOmmX01Ol00000
0onnnNco0000okWgk`05o`0000;o]^Wf00?o0000oiCIo_nDfOh04_l00003odB@k`?o00001?ndc>`2
o`0000;ok=Nn00Go0000ongI_oo]fKookMVoo`000002ongL`@04o`000?ojcY[on/jJo`0000;on/nL
00?o0000ooWAWol000000_oidZ800ol0003on=>Uo`00000Cooooo`03o`000?oooooooooo017ooooo
000;ooooo`05oa0@4?oMgMgoooooomgMgOl@41000oooool01_l0003oooooofIVI_n7QhOogMgMoa0@
41_ooooo00?o0000ooooooooool04?ooool01?l0003o>WcTocYli?l00004oi:Th@03o`000?n`/][o
000000Go_;gJ00?o0000ol_9f?l000001?oDcM800ol0003of/c;om[<b`02om[<b`06o`000?oMbLGo
0000o`000?oSd<Co00000ooSbkl01Ol0003ohlJkon?6^ooSa[_o000000CohL6h0_l00002on6o]P03
o`000?oN^kCog[^d00?og[^d00Go0000omfh/ooM^;?ogKRco`000004omRe]@03o`000?oG/kGo0000
00;o000000?odK2io`000?o?[kT01?o?[kT00ol0003oaJVnolFY_P04olFY_P03o`000?ndX/Go]:;5
00?o]:;500?o0000oinFb_nOU/X00_nOU/X01Ol0003oPhG=oh>5cOn3QLgo000000?oHFo;00?o0000
ocmIaOl000000_l_Bkh3o`0000;o8d2h0_l000001?l/A[[o0000oc]>_?lkC[`2o`0000;oCUg200Co
0000ofEZ`omUJ/?o00000omkMl<00ol0003oSX71ohj1`@03ohj1`@03o`000?nNR[koWXZn00;oWXZn
00?o0000oj^A^on[TK/00on[TK/2o`0000Co]9Bg00?o0000ok^I]?nkVK@00onkVK@00ol0003o`Ibb
ol6L/P04ol6L/P03o`000?o5W[3o000000GoaYn`0_l00006ol^S/003o`000?o?Z;7ocjRa00CocjRa
00?o0000om>]/ooC[K<00_oC[K<01?l0003oekBeomNd]Ol00002omFc]`03o`000?oJ^k[of[^j00;o
f[^j00Go0000on34_Ol0003og<?1o`000004on7>a@04o`000?oVf/Soi][8o`0000?oh^GE00Ko0000
on;_f?oRkmSo0000omogf_l00002om[lf`03o`000?oCoMco000000Co000000?o]o;co`000?nfjOH0
0onfjOH3o`0000?oUlgj00?o0000ofjfnom^]_/00_m^]_/00ol0003o>IGaocVEl@0;o`000003odB@
kol0003o000000?o00000_nddNl00ol0003ok=Nno`000002ongI_`04o`000?o]g<7okMc1ongL`@?o
00000_ojci`01?l0003onM6OooWAWol00002ooWBXP04o`000?ohdjGon=>Uo`0001;ooooo00?o0000
ooooooooool04Oooool000_ooooo00GoQhN7ogMgMoooooooIVIVohN7Q`03ooooo`06oa0@4?oMgMgo
MgMgogMgMooooooo00006oooool00ol0003oooooooooo`0Aooooo`Co00000_nBY>43o`0000Ko_;gJ
0ol00003omC=dP03o`000?oJc<_of/c;00;of/c;00?o0000omg9aOoMbLD00_oMbLD2o`0000?ohl^o
00Go0000on?6^ooSa[_ohlJko`000003on71^006o`000?oP_KKoh;ffo`000?oQ_kKo00001?oN^k@0
0ol0003ogKRcomfh/`02omfh/`04o`000?oH]KGof;FeomRe]@?o00000ooG/kD00ol0003ocjnioln_
^@03oln_^@03o`000?o>[[Wo000000CoaJVn0_l00005okBRa@04o`000?nOU/[oWiK:oinFbPKo0000
0omQKl/00ol0003o?eW5ocmIa@03o`000003oalo^?l0003o000000;o8d2h0ol00002oc]>_003o`00
0?m?F[ko000000;o00000omUJ/<01Ol0003oNgO3og]g`omkMl?o000000CoSX7100?o0000oij:__nN
R[h00_nNR[h00ol0003oZi6koj^A^`02oj^A^`;o00001OndU;L00ol0003o^iVdok^I]002ok^I]003
o`000?nlV;?o000000Ko`Ibb00?o0000olJO/?o6Wk001?o6Wk000ol0003obj>`ol^S/005ol^S/003
o`000?o?Z;7ocjRa00?ocjRa00?o0000om>]/_l000000_oC[K<01ol0003oekBeomNd]OoG];Go0000
omFc]ol000001?oJ^kX01_l0003oh<Bmon34_Ol0003og<?1o`0000?ohLk500Co0000onKJb?oVf/So
i][80_l000001ooRiMGo0000on;_f?oRkmSo0000omogf_l000000_oJo=/00ol0003odogLo`000002
olomh003o`000?o=n^Ko000000;o000000Co]^Wfo`000?l0003o00000_neg?@00ol0003oUlgjoiO=
nP0Bo`0000;o?Y?a1?l00004okCAk`;o00000oo]fKl01?l0003okMc1ongL`Ol00002oncOa004o`00
0?ojcicon/nLo`0000;onM6O00Co0000ooWBX_oidZ;o00000_ohdjD2o`0001;ooooo00?o0000oooo
ooooool04?ooool000_ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP03ooooo`06ojVYZOm4A4CoV9RH
odA4A?nHV9So410@6oooool3o`0001;ooooo00?o0000ob9bhOl000000_l00002oiZ]i003o`000?nl
_M[o_;gJ00?o_;gJ00Oo0000olK2eoo6`]Ooa/;Go`000?oDcM;o000000Cof/c;00?o0000omg9aOoM
bLD00ooMbLD01Ol0003og/K1o`000?oSbkoo000000?ohlJk00?o0000on71^?oQ`KP00_oQ`KP01Ol0
003oh;ffon2m]_oP_KKo000000Cog[^d00?o0000omfh/ooM^;<00_oM^;<00ol0003ofkJco`000002
o`000003omRe]Ol0003oek>e00?oek>e00?o0000oln_^Oo?[kT00oo?[kT01?l0003ocZjiolj^^Ol0
0002olFY_P04o`000?o4ZKooa:Voo`0000Co]:;51?l00002oibGc@03o`000?mmQ=3oOHC@00?o0000
00KoHFo;o`000?loFLGo?eW5o`000?lTA[d2o`000006oalo^?l0003o0000ob=0^?l0003o:T>h0_l0
0002oc]>_004o`000?m?F[koCeZno`0000?oIF[300Go0000og]g`omkMl?oNgO3o`000004ohj1`@03
o`000?nNR[koWXZn00;oWXZn00?o0000oj^A^on[TK/00_l000000onZSkWo0000okBD]`05okBD]`04
o`000?nkVKCo^iVdo`0000;o_9Rc00?o0000ol6L/_o1W;801?o1W;800ol0003oaYn`olJO/004olJO
/003o`000?o;Xk3obj>`00Cobj>`0_l00004olnX/@04o`000?oC[K;odjfbo`0000;odjfc00?o0000
omNd]OoG];D00_oG];D00ol0003of[^jomZk^P03omZk^P05o`000?oPa;goh<Bmon34_Ol000000ooQ
c/D01Ol0003oi][8onKJb?oVf/So000000;oj^G;0_l000001?oRkmSo0000omogf_l00002om[lf`03
o`000?oCoMco000000;ocogP00?o0000olgji_l000000_o<l^/3o`0000?o]Mcd1?l00003oiZnl@03
o`000?mi[??oNJcc00;oNJcc00?o0000odjDl?m>U?000ol000000ol2Kmgo0000o`000004o`000003
ocjClOl0003o000000;o]=7_0_l000001Once_;o0000ongI_oo]fKoo000000?okMc100Co0000oncO
a?o/glCo00000_ojci`00ol0003onM6Oo`000002ooWBXP04o`000?ohdjGon=>Uo`0000;ommFY00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`003?ooool00omgMgOo8B4QoeEEE@05
ooooo`05oiRHV?l0003o0000oa0@4?o<c<`06oooool00ol0003oooooooooo`0Cooooo`03o`000?lR
L^7o000000CoVZgT00Go0000okbmf_nl_M[o_;gJo`000005olK2e`03o`000?oJc<_of/c;00;of/c;
00?o0000omg9aOoMbLD00ooMbLD01?l0003og/K1omk6`OoNa/42o`0000?ohlJk00Go0000on71^?oQ
`KSohL6ho`000004on2m]P03o`000?oN^kCog[^d00;og[^d00Co0000omfh/ooM^;?ogKRc0ol00000
1?oK][?o0000omRe]Ol00004omNc]@03o`000?oE/[Go000000?ocjni00Oo0000olj^^Oo>[[WocZji
o`000?o5ZKko000000Coa:Vo00Ko0000okBRaOndX/Go0000ok>Sb?l00005oibGc@05o`000?mmQ=3o
OHC@o`000?mHKLd00ol00002ocmIa@0:o`000?lTA[go0000oalo^?l0003o73bfo`000?lS@;So0000
obY3^0;o000000?o>djlo`000?m?F[h00_m?F[h2o`000003ofEZ`ol0003oNgO300?oNgO300?o0000
ohj1`On>PL400_n>PL400ol0003oWXZnoij:_P02oij:_P;o00001?nZSkT00ol0003o]9BgokBD]`03
okBD]`04o`000?nkVKCo^iVdo`0000;o_9Rc00?o0000ol6L/_o1W;800oo1W;82o`0000GoaYn`00?o
0000olVR/Ol000001?o;Xk001?l0003ocZNaoljW/Ol00003olnX/@06o`000?oC[K;odjfbo`000?oC
[K?o00001OoG];D00ol0003of[^jomZk^P02omZk^P03o`000?oPa;goh<Bm00;oh<Bm0_l000000ooQ
c/Go0000onKJb002onKJb006o`000?oZiL_oj^G;on[Ubol0003ojo3=2Ol000001?o?oN3o0000olgj
i_l00002olcbj`03o`000?o9iN_obNG[00Co00000onbb^`00ol0003oV[kaoiZnl@09o`000003odjD
l?l0003o7gOT00Go00000_lfU?45o`0000Co/mKb00?o0000ongI_ol000000_o]g<401Ol0003ok=o4
oncOa?l0003ojn7700;o00000_oidIl01?l0003onM:RooWBX_l00002ooSCY@04o`000?ogeJWommFY
o`0001;ooooo00?o0000ooooooooool03oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool01?lQ8B7o71`Lo`000?oMgMd2ooooo`06onk^k_lb<S;o0000oc8b<_n^[Zko<S8b0_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001_oo
ool00ol0003oooooooooo`0Dooooo`?o00001?nJ[N@00ol0003o_;gJo`000005olK2e`03o`000?o=
a=;o000000?of/c;00?o0000omg9aOoMbLD00_oMbLD00ol0003og/K1omk6`@02omk6`@05o`000?oN
`[go0000on?6^ol000000ooQ`KP00ol0003oh;ffon2m]P02on2m]P03o`000?oN^kCo000000;og[^d
00?o0000omfh/ol000000ol00003om^f/`03o`000?oH]KGo000000?oek>e00Oo0000omFb]OoE/[Go
eK:eo`000?o?[kWo000000GocZji00?o0000olBY_oo4ZKl00oo4ZKl00ol0003o]:;5o`000003ok>S
b003o`000?nLUlgoW9O=00;oW9O=00Go0000ogf4d?mmQ=3oOHC@o`000002oeQ]c@;o000000So?eW5
o`000?lTA[go94Jmo`000?lO?kSo0000oa`l]P;o000000Ko:T>ho`000?liC;[o0000oc]>_?l00002
odmJ_P03o`000?mUIl3o000000;o00000omkMl<00ol0003oSX71ohj1`@02ohj1`@04o`000?nNR[ko
WXZnoij:_P;o00001OnZSkT00ol0003o]9BgokBD]`03okBD]`03o`000?nkVKCo000000Co_9Rc00Go
0000ol6L/_o1W;;o`Ibbo`000002ol:M/P05o`000?o6Wk3oaYn`olJO/?l000000_o9X[400ol0003o
bj>`ol^S/002ol^S/004o`000?o>Yk7ocZNao`0000;ocjRa00?o0000om>]/_oC[K800_oC[K800ol0
003oekBeomNd]@03omNd]@03o`000?oM_;So000000?of[^j00Go0000on34_OoPa;goh<Bmo`000002
onK?`005o`000?oVf/Soi][8onKJb?l000000ooZiL/02ol0003ojo3=on_`cOl0003oj?O=o`000?oS
o<go0000omknc_l0003of_kB00Go000000Ooc?;[o`000?o9iN_obNG[o`000?o3dnKo000000Go//[/
0ol00002oi^_iP03o`000?n1X^WoPJ;Y00;oPJ;Y00?o0000of6AjOl000000_l00003oamgi0?o0000
1?lfU?42o`0000Co/mKb0_l00002ongL`@05o`000?o/glCok=o4oncOa?l000000_o[hLL01?l0003o
nM6OooWAWol00002ooWBXP08o`000?ohdjGon=>Uo`000?ogeJWo0000ooGF[Ol0000Booooo`03o`00
0?oooooooooo00kooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B402_nYZJWo
ooooooooooooooooMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo01Cooooo00Co0000oaI^gol0003o00000_nJ[N@3o`0000Goa/;G00Oo
0000olg4d_o=a=;ocLCBo`000?oJc<_o000000CogLW500?o0000omk6`OoNa/400_oNa/401Ol0003o
g/:momk2_OoN`[go000000CohL6h00?o0000on2m]_oP_KH00_oP_KH00ol0003og[^domjk]004o`00
00;ogKRc00?o0000om^f/ooK][<00ooK][<00ol0003oek>eomNc]@02omNc]@07o`000?oE/[GoeK:e
omFb]Ol0003ocjnio`000005olj^^@03o`000?o4ZKooa:Vo00Coa:Vo00?o0000ok>Sb?ncXlP00onc
XlP01Ol0003oW9O=oibGcOnLUlgo000000?oOHC@00Go0000oeQ]cOmHKLgo0000oc=EaP02o`0000;o
94Jm00?o0000oalo^?l000000_lL?;H01Ol0003o:T>hobY3^?l0003o>Dbj00;o00000_m?F[h01?l0
003oIFO0ofEW`?mUIl05o`0000CoSX7100Ko0000oij:__l0003o0000oif8_?l00005ojZ?^@03o`00
0?ndU;Oo]9Bg00?o]9Bg0_l00005okbH/`04o`000?o1W;;o`Ibbo`0000?o`Yfb00Co0000olJO/?o6
Wk3o00001?o9X[401?l0003obj>`ol^S/?l00003oljW/@04o`000?o?Z;7ocjRao`0000Codjfb00?o
0000omNd]OoG];D00ooG];D01_l0003ogKbhomfl^?l0003of[^jo`0000?oh<Bm00Co0000onK?`?oV
cl3oi/o00_l000000ooVf/So0000on[Ub`02on[Ub`0>o`000?o[l<gojo3=o`000?oXmlgo0000on?l
cOl0003og_k>o`000?oJo];o0000omWmfOl00002omWgh0?o000000?obNG[o`000?o3dnH00_o3dnH0
0ol0003o//[/o`000002o`000003ojjihOl0003oVjoV00?oVjoV00?o0000oh6RjOn1X^T00_n1X^T0
1?l0003oHI7Yof6AjOmQTNT2o`000003oamgi?l0003o05[B00Go000000?o=YCao`000?l000000ol0
0002ok3Jm@03o`000?o]g<7o000000;ok=o400Co0000on_Qaoo[hLOojn770ol00002ooWBXP04o`00
0?ohdjGon=>Uo`0000;ommFY00Co0000ooGF[OoeeZgo00004?ooool2o`0000[ooooo1?l00001oa0@
407ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Fooooo`03o`000?lF
K]oo5VkO00;o00000onT]>@01Ol0003oa/;GolK2eoo6`]Oo000000GocLCB0_l00004omg9a@05o`00
0?oNa/7og/K1omk6`Ol000001?oN`[d2o`0000;ohL6h00?o0000on2m]_oP_KH00_oP_KH00ol0003o
g[^do`000003o`0000CogKRc00?o0000om^f/ooK][<00ooK][<01Ol0003oek>eomNc]OoG/kGo0000
00GoeK:e00?o0000olj^^Oo>[[T00oo>[[T00ol0003ocZjjo`000004olBY_`;o00001OncXlP00ol0
003oW9O=oibGc@02oibGc@04o`000?mmQ=3oOHC@o`0000?oF6g=00Go0000oc=Ea_l0003o0000obA6
_@02o`000007oalo^?l0003o73bfoa`l]_l0003o:T>ho`000002ocU<^P05o`000?m?F[koCeZnodmJ
__l000000_mUIl001?l0003oNgBoog]d_omkM;l7o`0000CoWHRl00?o0000ojZ?^OnZSkT00onZSkT0
1ol0003o]9BgokBD]ondU;Oo0000okBD]_l000001OnlV;<00ol0003o`Ibbo`000004ol:M/P04o`00
0?o6Wk3oaYn`o`0000CobJ:a00Co0000ol^S/?o;Xk3o00001?o>Yk42o`0000Codjfb00?o0000omRd
]?l000000ooG];D00ol0003ogKbhomfl^002omfl^005o`000?oPa;goh<Bmon34_Ol000000ooVcl00
0ol0003ojm_3on_K``02o`0000?oj^G;00go0000on_`cOl0003oj?O=o`000?oSo<go0000omknc_l0
003of_kBo`000?oIoMWo000000;ofOOP00?o0000omK[hooFjn<00_l00004ol?CiP;o00001On^^N40
0ol0003oVjoVoi^_iP09o`000003of6AjOl0003o>gcT00?o00000_l0F]800ol0003o:Y?_obZCk`03
o`0000Go/=[e0_l00002oncOa005o`000?o[hLOojn77on_Qaol000000_oYhl/01?l0003onM:RooWB
X_l00002ooSCY@04o`000?ogeJWommFYo`0000;omMJ]00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`0001Oooooo00Co0000oaI^golFK]oo00001?nT]>@00ol0003oa/;Go`000006olg4dP06o`000?oB
a<go0000o`000?oMbLGo00001?oNa/401Ol0003og/:momk2_OoN`[go000000;og[nj00?o0000on71
^?l000000ooP_KH3o`0000?og[^d0_l00002omfh/`03o`000?oK][?ofkJc00?ofkJc00?o0000omZd
/ol000000_oG/kD00ol0003oeK:eomFb]@03omFb]@03o`000?o>[[WocZji00;ocZji00Go0000olj^
^_o>[[[ocZjjo`000002olBY_`04o`000?o3Zl;o`j_2o`0000Co/j?82ol000001OmHKLgo0000oc=E
a_lcELKo000000;o94Jm0ol00002oa`l]P03o`000?lZ@kSo000000?o>Dbj0_l000000om?F[ko0000
ofEW`002ofEW`005o`000?mkM;ooNgBoog]d_ol000001?n>O[h00ol0003oWHRloif8_002oif8_003
o`000?nZSkWoZXni00?oZXni00Co0000okBD]ondU;Oo00000_ndU;H00ol0003o_9RcokbH/`04okbH
/`03o`000?o2WK;o`Yfb00Co`Yfb0_l00005olVR/@03o`000?o;Xk3o000000GocZNa00?o0000om>]
/_oC[K800ooC[K801_l0003of;BdomRd]?l0003oekBeo`0000GogKbh00Go0000on34_OoPa;goh<Bm
o`000003onK?`00Do`000?o[fl?ojm_3o`000?o_i/Co0000on[Ubol0003ojo3=o`000?oXmlgo0000
on?lcOl0003og_k>o`000?oJo];o0000omWmfOl00002omWgh004o`000?oFjn?oe^_So`0000;od=[Q
00Ko0000ol?Ci_l0003o0000okg1gOl00005ojjih@?o00000_nKXmX00ol0003oR9WMohRIg@02ohRI
g@03o`000?m_SMoo000000;o00000olkO>@2o`000003o`1Jd_l0003o000000;o000000?o:Y?_o`00
0?n`f_D00ol00002ojcLn003o`000?o/glCo000000;ojn7700Co0000onWSbooYhl_ojN?;0_l00000
1?oidZ;o0000ooSCYOl00002ooOEZ@06o`000?oeeZgomMJ]o`000?ocek;o00004_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`0Hooooo`Co00000_nT]>@4o`0000GocLCB00?o0000om;4cOoBa<d00_oBa<d0
0ol0003og/K1omk6`@02omk6`@05o`000?oN`[gog/:momk2_Ol000001?oN_kX00ol0003oh;ffon2m
]P03o`0000Cog[^d00Ko0000omfh/ooM^;?o0000omfh/ol00004om^f/`06o`000?oJ];?of[Bco`00
0?oG/kGo00001OoE/[D00ol0003oe;6fo`000002olj^^@03o`000?o>[[[ocZjj00;ocZjj00?o0000
olBY_ol000001?o3Zl801_l0003o/j?8ok>Sb?l0003o/ZK;o`0000?oVYWB00Ko0000ogN5e?mgQMCo
MhGDo`000?m=K=43o`000007oc=Ea_l0003o0000obA6_Ol0003o53Zgo`000002oa`l]P;o000000Ko
:T>ho`000?liC;[o>Dbjo`000?m>F;d2o`0000?oIFO000?o0000og]d_omkM;l00_mkM;l01Ol0003o
SWjnohin__n>O[ko000000CoWHRl00?o0000ojZ?^OnZSkT00onZSkT00ol0003o]9Bgo`000004okBD
]P03o`000?nlV;?o_9Rc00?o_9Rc00?o0000ol:M/_o2WK801?o2WK800ol0003obJ:aolVR/@05olVR
/@03o`000?o>Yk7ocZNa00CocZNa00?o0000om>]/_oC[K800_oC[K801ol0003of;BdomRd]?oH];Co
0000omNd]Ol000001?oM_;P01Ol0003ohlFjo`000?oPa;go000000?oi/o000Co0000on_K`oo[fl?o
00000oo_i/@>o`000005omWgh?l0003oe^_SomK[hol000000oo@f^42o`0000Co_L7M00?o0000ojji
hOl000000_l000000on[ZmOo0000oi^SfP03oi^SfP03o`000?n8VMgoR9WM00;oR9WM00Co0000ofn=
gom_SMooKhgO0_l000000olkO>Co0000oaEVfP08o`0000Go[=ch0_l00003on_Qa`04o`000?oYhl_o
jN?;o`0000;oinG?00Co0000ooSCYOohdjGo00000_ogeJT01?l0003omMJ]ooGF[Ol00002oo?G/P03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
00?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003o4VkOo`000002
o`0000Co[KWR00Go0000olg4d_o=a=;ocLCBo`000004om;4c@03o`000?oD`/So000000?og/K100Go
0000omk2_OoN`[gog/:mo`000004omjo^P?o000000?oh;ffo`000?oN^k@01?oN^k@01Ol0003ogKRc
omfh/ooM^;?o000000GofkJc00Go0000omZd/ooJ];?of[Bco`000005omFb]@04o`000?oD/KKoe;6f
o`0000;ocZji00?o0000olj^^_o>[[X00oo>[[X00ol0003o`j_2ol>[`P03ol>[`P03o`000?ncXlSo
000000?o/ZK;00Go0000oiZId_nJVM;oVYWBo`000003ogN5e004o`000?m=K=7oCFcAo`0000;o<eG6
0ol00002oa@j]`03o`000?lL?;Ko73bf00?o00000_liC;X00ol0003oCURmodiH_@02o`0000;oIFO0
00?o0000og]d_omkM;l00_mkM;l00ol0003oSWjnohin_P02ohin_P03o`000?nMR;coWHRl00;oWHRl
00?o0000ojZ?^OnZSkT00_nZSkT2o`0000Go]9Bf00?o0000okbH/onlV;<00_nlV;<00ol0003o_IZd
o`000005ol:M/P03o`000?o9X[7obJ:a00GobJ:a00?o0000oljW/Oo>Yk400oo>Yk400ol0003odZfc
o`000003om>]/P03o`000?oH];Cof;Bd00;of;Bd00?o0000omfl^?oM_;P00_oM_;P01Ol0003ohlFj
on?5^_oSaK[o000000Coi/o000Co0000on_K`oo[fl?o00000oo_i/@03_l0003oko35o`000?o]mlCo
0000onSk`_l0003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[G0_l000001?oFjn?o0000om3JhOo@
f^42o`000003olO7f_l0003o_L7M00?o_L7M0_l00005oj^[e`05o`000?nKXm[oVj?Joi^Sf_l00000
1?n8VMd01_l0003oKhgOofn=gom_SMoo0000oe9ng`?o00000_lEI]X01?l0003o04C1o`000?l?RN@3
o`000004ojcLn?l0003o0000o`0000;oY=gk00?o0000on_Qaol000000_oYhl/01?l0003oinG?onOU
cooWiLl2o`000004ooSCYOl0003ommFYo`0000;omMJ]00Go0000oo?G/_ocek;olmNbo`00000Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool00006oooooomgMgOoV9RHoooo
oonHV9SoMgMg2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool06_ooool00ol0003o4VkOo`000006ojfihP03o`000?o=a=;o0000
00Cod/C=00Oo0000omC2b?oD`/Soe<;8o`000?oNa/7o000000?og/:m00?o0000omjo^_oN_kX00ol0
0002omfl^003o`000?oP_KKo000000Cog[^d00?o0000omfh/ooM^;<00_oM^;<00ol0003ofkJcom^f
/`02om^f/`03o`000?oJ];?of[Bc00;of[Bc00?o0000omFb]OoE/[D00_oE/[D01ol0003oe;6fomBa
]_oD/KKo0000olj^^Ol000001_o>[[X00ol0003o`j_2ol>[`P03ol>[`P;o00001OnbY//01Ol0003o
VYWBoiZId_nJVM;o000000?oMhGD00?o0000ode/dOm=K=400ol000001?lF@;co0000o`000?lD>[L2
o`000004oa`l]_l0003o93ngo`0000?o>Dbj00?o0000odiH_Om>F;d00_l00002ofEW`005o`000?mk
M;ooNgBoog]d_ol000001?n>O[h00ol0003oWHRloif8_002oif8_003o`000?nZSkWoZXni00;o0000
00?oZXjio`000?ndU;H01?ndU;H01Ol0003o_9RcokbH/onlV;?o000000;o_IZd00?o0000ol:M/_o2
WK800_o2WK800ol0003oaInco`000005olVR/@;o00001?o>Yk401?l0003odZfcom:]/ol00003om>]
/P03o`000?oH];Cof;Bd00;of;Bd00?o0000omfl^?oM_;P00_oM_;P01?l0003ohlFjon?5^_oSaKX2
o`0000;oi/o000Co0000on_K`oo[fl?o00000oo_i/@03ol0003oko35o`000?o]mlCo0000onSk`_l0
003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[Go`000002omk`g@;o000000?od=[Qo`000?o7amX0
0oo7amX01_l0003o_L7Mo`000?l0003o][7Do`0000GoZj_G00?o0000oi^Sf_nKXmX03?l00003oe9n
g`;o000000?o5FKJo`000?l000001_l00003ojCMn`?o00000ooYhl/01?l0003oinG?onOUcol00002
on?Ve004o`000?ogeJWommFYo`0000;omMJ]00Ko0000oo?G/_ocek;o0000oo7H]ol0000@ooooo`?o
00002?ooool00ol0003oooooooooo`01ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`0Kooooo`?o00001On]^N83o`0000?od/C=00?o0000omC2b?oD`/P00ooD`/P2o`0000?o
g/:m0ol000000ooN_k[o0000omfl^003omfl^003o`000?oN^kCog[^d00;og[^d00?o0000omfh/ooM
^;<00_oM^;<00ol0003og;Nco`000003om^f/`07o`000?oJ];?of[BcomZd/ol0003ofKBco`000003
omFb]@03o`000?oD/KKoe;6f00;oe;6f00?o0000olj^^_o>[[X01?o>[[X00ol0003oc[2lo`000003
ol>[`P03o`000?o3[LCo000000Go/ZK;00Go0000oiZId_nJVM;oVYWBo`000003ogN5e005o`000?m=
K=7oCFcAo`000?lRClL00_l000001?lF@;co0000o`000?lD>[L3o`0000;o93ng00Co0000ocU<^_li
C;[o00000_m>F;d00ol0003oI6Fno`000002o`0000CoNgBo00Go0000ohin__n>O[koSWjno`000004
oif8_003o`000?nZSkWo000000?oZXji00?o0000okBD]_ndU;H00ondU;H01?l0003o_9RcokbH/ol0
0003okfJ]003o`000?o2WK;o`Yfb00;o`Yfb00?o0000olFO/ol000001?o9X[401?l0003oc:JbolbV
/_l00003oljW/@07o`000?oB[K?odZfcom:]/ol0003odjfbo`000004omRd]003o`000?oM_;Oo0000
00;ogKbh00Go0000on?5^_oSaK[ohlFjo`000002onS@_@05o`000?oVcl3o0000on_K`ol000000oo_
i/@03ol0003oko35o`000?o]mlCo0000onSk`_l0003oh_g2o`000?oOo/Ko0000omknc_l0003ogo[G
o`000002omk`g@04o`000?oHh=gof>3Mo`0000GoalOJ0_l00004okJae004o`000?n[ZmOoZj_Goj^[
e`Co00000_nLVM000ol0003oSI;CohfBd`02ohfBd`04o`000?mjRMOoNXWGogZ9e`?o000000?oDWkO
o`000?lcKm`03?l00003oi_Mo@03o`000?oYhl_o000000;oinG?00Co0000on?Ve?oSi]CohnKD0_l0
00001OogeJWo0000ooGF[OoeeZgo000000;olmNb00Co0000oo7H]ooaf;Oo00003?ooool4o`000003
ooooool0003ooooo00Oooooo00?o0000ooooooooool00Oooool003;ooooo0ol0000Mooooo`?o0000
00Co[KWRo`000?l0003o00000ond_=l00ol0003od/C=o`000005omC2b003o`000?oF`<Goe/3500?o
00001?oN_kX00ol0003ogKbhomfl^002omfl^003o`000?oN^kCog[^d00;og[^d00?o0000omfh/ooM
^;<00_oM^;<01_l0003og;Ncombg/ol0003ofkJco`0000Cof[Bc00Ko0000omVd/ooI];?o0000omFb
]Ol00005omBa]P03o`000?o>[[[ocZjj00?ocZjj00Co0000olj`_?o>/;co00000_o3Zl801Ol0003o
`jg4ol>]a?o3[LCo000000Co/ZK;2ol000001om=K=7o0000ob9?aol0003o5T2lo`000?l4<kD00_l0
00001?lA=[Co0000o`000?lT?kL2o`000003ocU<^_l0003oCURm00;oCURm00Co0000ofAU__mTIKko
00001?mkM;l00ol0003oSWjnohin_P02ohin_P03o`000?nMR;coWHRl00?o00001OnZS[T00ol0003o
]9BfokBD]P03okBD]P;o00001OnmV[@01?l0003o`Yfbol:M/_l00003olFO/`04o`000?o9X[7obJ:a
o`0000?oc:Jb00Co0000oljW/Oo>Yk7o00001?oB[K<00ol0003odjfbo`000004omRd]003o`000?oM
_;Oo000000;ogKbh00Go0000on?5^_oSaK[ohlFjo`000003onS@_@;o000000Oojm_3o`000?o_i/Co
knK4o`000?o_l<Go000000;okOO400[o0000onSk`_l0003o0000omona_l0003og_k>o`000?oOn]Oo
00000_oNl=d00ol0003of>3MomSPg@02o`0000?oalOJ0_l000000ono]]7o0000okJae003okJae0Co
00000_nWWlh00ol0003oW9W@oibId002oibId003o`000?n=T]?oSI;C00;oSI;C00Ko0000ogZ9eomj
RMOoNXWGo`000?mTOmT3o`0000?o<foL2?l00003oi_Mo@Co000000?oinG?o`000?oSi]@00_oSi]@0
1?l0003ognOIomoWfOl00002ooGF[@04o`000?ocek;olmNbo`0000?olMRg00?o0000ooooooooool0
1oooool3o`0000Gooooo00?o0000ooooooooool01?ooool00omEEEGoIVIVo`000003ooooo`00<_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?lAKmoo000000Ko];cO0_l00005omC2b0Co000000?o
e/35o`000?oN_kX00ooN_kX00ol0003ogKbhomfl^002omfl^003o`000?oL^[Oo000000;og[^d00?o
0000omfh/ooM^;<00_oM^;<00ol0003og;Ncombg/`02ombg/`03o`000?oJ];?of[Bc00;of[Bc00?o
0000omVd/ooI];<00_oI];<00ol0003oe;6fomBa]P03omBa]P03o`000?oD/[Oo000000?ocZjj00Oo
0000olj`_?o>/;coc[2lo`000?o3Zl;o000000Co`jg400?o0000ok:Vbol000000_l000000onbZ]3o
0000oiNMf002oiNMf006o`000?m_Qm_oKhOKofn7fol0003o?FWE0_l00002ob9?a`04o`000?lF@;co
0000o`@c]@;o000000Co4CJdo`000?lT?kOo93ng0ol00003odiH_@04o`000?mTIKkoI6FnofAU_PGo
00000_n>O[h5o`0000;oWHNk00?o0000ojZ>^OnZS[T00onZS[T00ol0003o]9BfokBD]P02okBD]P;o
00001_nmV[@00ol0003o`Yfbo`000004olFO/`04o`000?o9X[7obJ:ao`0000?oc:Jb00Co0000oljW
/Oo>Yk7o00001OoB[K<00ol0003of;BdomRd]002omRd]006o`000?oM_;OogKbgo`000?oM_;So0000
0ooSaKX00ol0003oj=2monS@_@02onS@_@08o`000?o^g;oo0000o`000?o_i/Co0000ono`aOl00002
ongga003o`000?oXnl;o000000So000000Gog_3Mo`000?oHh=gof>3Mo`000002olo=e`03o`000?o7
am[o000000Co_kKA00Ko0000okJae?nf/MCo0000ok6Tbol00005ojNOcP03o`000?nLVM3oW9W@00;o
W9W@00Go0000ohfBdon=T]?oSI;Co`000004ogZ9e`04o`000?mTOmWoI7oIofAof@;o000000?o<foL
o`000?lGH]L01?l000000ol0MM?o0000o`000002o`0000;oTM[o0ol00003on?Ve008o`000?oOimWo
gnOIo`000?oJi]go0000ooGF[Ol00002oo?G/P06o`000?oaf;OolMRgo`000?o^f;_o00001?ooool4
o`0000Sooooo00?o0000ooooooooool02_ooool003;ooooo00?o0000ooooooooool07oooool3o`00
00?o];cO0_l00002okZlg003o`000?oD`/Soe<;800?o00001?oF`<D2o`0000?og[nj00?o0000omfl
^?oM_;P00_oM_;P01_l0003og;Zgombj]ol0003og[^do`0000?ogKRc00?o0000ombg/ooL]k<00ooL
]k<01Ol0003of[BcomZd/ooJ];?o000000GofKBc00?o0000omBa]_oD/KH00ooD/KH01_l0003oe;:g
omBb]ol0003ocZjjo`0000Goc[2l00?o0000ol>]a?o3[L@01?o3[L@00ol0003o/Z[@ok:Zd003ok:Z
d005o`000?nGWMSoUigHoiNMf?l000000om_Qm/00ol0003o?FWEo`000002ob9?a`?o00000_l4<kD0
1ol0003o4CJdo`000?l0003o93ngo`000?ldBKX00_l00002odiH_@05o`000?mTIKkoI6FnofAU__l0
00000omjL[l3o`0000;oSGjm00?o0000oif7^onMQk/00onMQk/00ol0003oZXjiojZ>^@02ojZ>^@07
o`000?ndU;Ko]9BfokBD]_l0003o]IFgo`000006okfJ]003o`000?o2WK;o000000CoaInc00?o0000
olVR/Ol000001Oo<Y[82o`0000KodZfc00Go0000omRd]?oH];Cof;Bdo`000004omfl]`03o`000?oS
aK[ohlFj00;ohlFj00Go0000onS@_OoXd;goj=2mo`000002onkL_`03o`000?oail3o000000Oo0000
00Soh_bho`000?l0003ogok4o`000?oQo<oo0000on;df0?o000000?of>3Mo`000?o?cML00oo?cML0
0ol0003o_kKAoknfd@03oknfd@03o`000?nf/MCo000000?o/JC;00?o0000ojNOc_nWWlh00_nWWlh0
0ol0003oW9W@oibId002oibId005o`000?n=T]?oSI;CohfBdol000001?mjRML01_l0003oI7oIofAo
fOmTOmWo0000odaefP?o000000?o5f;Go`000?l0C<T00ol00002o`1ed`?o00000on7e_l00ol0003o
hnKDo`000002omoWf@03o`000?oJi]gof^KM00;o00000_ocek801Ol0003olMRgoo7H]ooaf;Oo0000
00;ok]Rk1?l0000<ooooo`03o`000?oooooooooo00[ooooo000booooo`03o`000?oooooooooo023o
oooo0ol000000ond_=oo0000okZlg003okZlg0Co00001OoF`<D01_l0003oe[k2omJn`_l0003og[nj
o`0000CogKbh00?o0000ombj]ooL^[L00_oL^[L00ol0003ogKRcomfh/`02omfh/`03o`000?oL]k?o
g;Nc00;og;Nc00?o0000om^f/ol000000_oJ];<00ol0003ofKBcomVd/`02omVd/`03o`000?oH/kCo
000000?oe;6f00?o0000omBb]ooD/[L00_oD/[L00ol0003oc[2lolj`_004olj`_003o`000?o3[LCo
`jg400?o`jg40_l00005ok:Zd005o`000?nGWMSoUigHoiNMf?l000001?m_Qm/01Ol0003o?FWEo`00
0?l0003o8To700?o00000_l4<kD01ol0003o4CJdo`000?l0003o93ngo`000?ldBKX00_l00002odiH
_@04o`000?mTIKkoI6Fno`0000CoNW:o00?o0000ohen_On=O[d00_n=O[d00ol0003oWHNkoif7^`02
oif7^`03o`000?nZS[WoZXji00;oZXji00Co0000okBD]_ndU;Ko00000oneUKL00ol0003o_IZdokfJ
]004okfJ]003o`000?o5Wk?oaInc00CoaInc00?o0000olbV/_o<Y[801?o<Y[800ol0003odZfcom:]
/`04om:]/`03o`000?oG];Go000000;of;Bd00?o0000omfl]ooM_;L00_oM_;L2o`0000;ohlFj00Go
0000onS@_OoXd;goj=2mo`000002onkL_`06o`000?oail3olNO0o`000?oalKoo00000_o^n;d00ol0
003oj?^jo`000002o`000006omona?l0003ohOc?o`000?oRm=So00000ooMiMX00ol0003oclgGolo=
e`02olo=e`;o00001Ono]]42o`0000Co/JC;00?o0000ojNOc_nWWlh00_nWWlhAo`0000;oI7oI00Co
0000odaef_m<MM[oC7GJ0ol000000ol0C<Wo0000o`000003o`0000?oQmKo1?l00002omoWf@04o`00
0?oJi]gof^KMo`0000;oeNCR00?o0000oo?G/_l000000_oaf;L01?l0003ok]RkonkH^oo^f;/2o`00
00oooooo00?o0000ooooooooool02Oooool003;ooooo00?o0000ooooooooool08Oooool00ol0003o
4VoOo`000003okZlg0;o000000?o^[cLo`000?l000001OoF`<D00ol0003oe[k2omJn`P02omJn`P03
o`000?oM_;SogKbh00;ogKbh00?o0000ombj]ooL^[L00ooL^[L2o`0000;ogKRc00?o0000ombg/ooL
]k<00ooL]k<01Ol0003ofkJco`000?oJ];?o000000GofKBc00Ko0000omRc]?oH/kCo0000omBa]_l0
0005omBb]`03o`000?o>/;coc[2l00?oc[2l00?o0000oljb__l000000oo3[L@01?l0003oa;78olBa
b?l00004ok:Zd003o`000?nGWMSoUigH00Oo000000?o?FWEo`000?l<BLL00_l000002?l1>;_o0000
o`@c]Ol4<kGo0000oa4f]?l0003o6C^f0_l000000oldBK[o0000odUF_@03o`0000?oI6Fn00Go0000
ogYb_omjL[ooNW:oo`000004ohen_@03o`000?nMQk_oWHNk00;oWHNk00?o0000ojZ>^OnZS[T00onZ
S[T2o`0000Co]IFg00?o0000okfJ]?nmV[@00onmV[@2o`0000KoaInc00?o0000olbV/_o<Y[801?o<
Y[800ol0003odZfcom:]/`03om:]/`06o`000?oG];GoekBeo`000?oH];Co00001?oM_;L01_l0003o
i<JjonC6^_l0003ohlFjo`0000;oj=2m00Co0000onkL_oo^g;oo00000_oail000ol0003olO6oo`00
0002onkh_@03o`000?oXnk[o000000;o000000Kogok4o`000?oQo<oo0000on;df?l00003omgUfP;o
00000oo?cML01?l0003oa[_@olJkd?l00002oknfd@;o000000?o^:W9o`000?naY</00onaY</00ol0
003oYio>o`000002o`000003ojFGa_l0003oW9;900?oW9;900Go0000oi6=c?nASLcoTHg<o`000004
oh>7c`03o`000?mbP=;o000000;o00000om<MMX00ol0003o=FcJo`000009o`0000?oOM3o00?o0000
omoWfOl000000_oJi]d01?l0003oeNCRomGTh_oEi>82o`0000;olMRg00Go0000onkH^oo^f;_ok]Rk
o`000002oncH_`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool003;ooooo0_l0
000Sooooo`03o`000?lBKmoo000000;o000000Go^[cLo`000?l0003o_KcIo`000004omK0a@03o`00
0?oF_/;oe[k200?oe[k200?o0000omfl^?oM_;P00_oM_;P00ol0003og;Zgombj]`02ombj]`06o`00
0?oK^KKofkVfo`000?oM^;?o00001?oL]k<01_l0003ofkJcom^f/ol0003of[Bco`0000CofKBc00Oo
0000omRc]?oH/kCof;>do`000?oD/KKo000000Coe;:g00?o0000omBc^?l000000oo>/;`01ol0003o
c[:noljb__o>/[ko0000ol>]a?l000001?o4/LP01?l0003o/Z[@ok:Zd?nbZ]03o`0000;oTj?O00Co
0000ofF;h_mURn;oIH_R1?l000001_l<BLOo0000o`4h^ol1>;_o0000o`@c]@;o000000Co4CJdo`00
0?lI>kKo00000_ldBKX01?l0003oBEJmodUF_Ol00003ofAU_P03o`000?mjL[ooNW:o00;oNW:o00Go
0000ohen_On=O[goSGjmo`000005oif7^`04o`000?nZS[WoZXjiojZ>^@;o00001_neUKL01ol0003o
_IZdokfJ]?nmV[Co0000oknL]Ol000001Oo5Wk<00ol0003ob:Bdo`000004olbV/P03o`000?o@[;Co
000000?odZfc00Oo0000omNd]OoG];GoekBeo`000?oH];Co000000CogKbg00Go0000onC6^_oTa[[o
i<Jjo`000003onS@_@04o`000?o^g;ook]boo`0000;olNO000Ko0000oo7a_ol0003ok_Rmo`000?oX
nkX3o`000006omona?l0003ohOc?o`000?oRm=So00000ooMiMX01_l0003oeM;GomGBeol0003oclgG
o`0000?oa[_@00?o0000oknfdOl000001?nhZLT01?l0003o/JC;ok6TbonaY</2o`0000GoYIO600?o
0000oibBbOnLT/T00_nLT/T01Ol0003oTHg<oi6=c?nASLco000000CoPhO?00Co0000og:0d_mbP=;o
LX3B0_l00002odaefP03o`000?leK=[o=FcJ00ko000000?of^KMo`000?oEi>800_oEi>801_l0003o
cn;UoloRiOl0003olMRgo`0000;ok]Rk00Go0000oncH_oo/f;ook=Roo`00000>ooooo`03o`000?oo
oooooooo00Wooooo000aooooo`03o`000?oooooooooo02;ooooo1Ol000000onj_=co0000okflf@03
okflf@05o`000?oF`<Goe/35omK0aOl000001?oF_/800ol0003oe[c0o`000002omfl^003o`000?oL
^[Oog;Zg00;og;Zg00?o0000om^i]_oK^KH00_oK^KH00ol0003og;Ncombg/`02ombg/`03o`000?oK
][?ofkJc00;ofkJc00?o0000omVd/ooI];<00_oI];<00ol0003of;>domRc]003omRc]003o`000?oD
/[Ooe;:g00;oe;:g00Go0000omBc^?oD/kSoe;>ho`000002olj`_003o`000?o>/[koc[:n00;oc[:n
00?o0000olBab?o4/LP00oo4/LP01?l0003o/Z[@o`000?l00002ok:`eP05o`000?nCXmooTj?Ooi>S
gol000000omURn802?l0003o:FOIo`000?l0003o34W7o`000?l1>;_o00000_l4<kD3o`0000;o6C^f
00?o0000ocA9^_l000000om9E[d2o`000003ofAU__l0003oNW:o00?oNW:o00?o0000ohen_On=O[d0
0_n=O[d00ol0003oWHNkoif7^`02oif7^`06o`000?nZS[WoZXjio`000?n[SkWo00001_neUKL01?l0
003o_IZdokfJ]?l00003oknL]@05o`000?o5Wk?oaIncolFO/ol000000_o8Y;@00ol0003oc:JbolbV
/P02olbV/P04o`000?o@[;Cod:bdo`0000;odZfc00?o0000omNd]OoG];D00_oG];D00ol0003ogKbg
omfl]`02omfl]`03o`000?oTa[[oi<Jj00;oi<Jj0_l000001OoXd;go0000onkL_oo^g;oo000000;o
lNO000Ko0000oo7a_ol0003ok_Rmo`000?oXnkX;o`000003omgUf_l0003oeM;G00;oeM;G0_l00004
olJkd0;o00001OnhZLT01_l0003o/JC;o`000?l0003o[I_4o`0000GoYIO600?o0000oibBbOnLT/T0
0_nLT/T01Ol0003oTHg<oi6=c?nASLco000000CoPhO?00Ko0000og:0d_mbP=;oLX3Bo`000?mPN]D3
o`0000?o=FcJ2?l00003ogK:o`?o00000ooEi>801?l0003ocn;UoloRiOo?h^D2o`0000;ok]Rk00Oo
0000oncH_oo/f;ook=Roo`000?oXel?o000000gooooo00?o0000ooooooooool02Oooool0037ooooo
00?o0000ooooooooool07oooool3o`0000?ooooo00?o0000oa1^gol000001_nm_=T00ol0003oe/35
o`000004omJn`P07o`000?oF_<3oe[c0omJl`?l0003ogKbho`000004ombj]`03o`000?oK^KKofkVf
00;ofkVf00?o0000ombg/ooL]k<00_oL]k<00ol0003ofkJcom^f/`02om^f/`03o`000?oI];?ofKBc
00;ofKBc00?o0000omRc]?oH/k@00ooH/k@01Ol0003oe;:gomBb]ooD/[Oo000000Coe;>h00?o0000
olj`_?l000001Oo>/[h00ol0003oa;78olBab003olBab0;o00001Onb/=H01Ol0003oTj?Ooi>SgonC
Xmoo000000?oIH_R00?o0000obUWfOlYImT00ol000001_l1>;_o0000o`@c]Ol0003o02nco`0000;o
6C^f0_l000001_ldBK[o0000odUF_Om9E[go0000of5T_`?o00000omjL[l00ol0003oSGjmohen_@02
ohen_@03o`000?nMQk_oWHNk00;oWHNk00?o0000ojZ>^Ol000000on[SkT00ol0003o]IFgokFE]`03
okFE]`03o`000?nmV[Co000000Co_ibe00Co0000olFO/oo5Wk?o00001?o8Y;@01?l0003oc:JbolbV
/_l00003om2/]003o`000?oB[K?o000000GoekBe00?o0000omfl]ooM_;L00_oM_;L01Ol0003oi<Jj
onC6^_oTa[[o000000;oj]:m00Wo0000onkL_oo^g;ook]boo`000?oail3o0000oo7a_ol000000_o^
n;d3o`000003omSk/_l0003of_fk00;o00000_oSnM@01?l0003oh>_Ion3[fOl00003omGBe`03o`00
0?o;`=3o000000?oa[_@00?o0000okj]bOl000001OnhZLT2o`0000Co[I_400?o0000ojFGa_nUUlH0
0_nUUlH00ol0003oW9;9oibBb@02oibBb@05o`000?nASLcoTHg<oi6=c?l000001?n3Qll00ol0003o
LX3Bog:0dP02og:0dP04o`000?mPN]GoH7[Eof1je@;o000000?o=FcJo`000?lUJMX02Ol00003og75
o`03o`000?oEi>;o000000?ocn;U00?o0000ol[Niol000000_o^f;/01?l0003ok=RooncH_ol00002
onSG``03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool0037ooooo00?o0000oooo
ooooool07?ooool3o`0000Oooooo00?o0000oa1^gol000001Onm_=T2o`0000Coe[k200?o0000omJl
`?oF_<000ooF_<000ol0003og;Zgombj]`02ombj]`03o`000?oK^KKofkVf00;ofkVf00?o0000omZh
]_l000000_oL]k<00ol0003ofkJcom^f/`02om^f/`03o`000?oJ]K?o000000;ofKBc00?o0000omRc
]?oH/k@00ooH/k@00ol0003of;Beo`000002omBb]`03o`000?oD/kSoe;>h00?oe;>h00?o0000oljb
__o>/[h00oo>/[h00ol0003ockK1o`000002olBab0;o000000?oaKO<o`000?nb/=H01?nb/=H9o`00
00;o:FOI1ol00002o`0_/`04o`000?lI>kKo0000ob]5^P;o00000_m9E[d01?l0003oHFBoof5T_omQ
I;l2o`0000;oNW:o00?o0000ohen_On=O[d00_n=O[d01?l0003oWHNkoif7^onMQk/3o`0000CoZhni
00?o0000okFE]oneUKL01?neUKL00ol0003o_ibeoknL]@03oknL]@04o`000?o5Wk?oaInco`0000Co
b:Bd00?o0000olbV/_l000001Oo@[;@00ol0003oekBeomNd]@03omNd]@03o`000?oM_KSo000000;o
gKbg00Go0000onC6^_oTa[[oi<Jjo`000003on[B_@;o000000Sok]boo`000?oail3olNO0o`000?oa
lKoo0000onkh_@;o000000Cog?Z_o`000?l0003of_fk0_l00002on?ie008o`000?oPjmWoh>_Io`00
0?oHf=Oo0000omGBeol00003ol_0d003o`000?o6^m3o000000?o_Zg900Oo0000okRYbOnhZLWo^:W9
o`000?ncW/?o000000Go[I_400?o0000ojFGa_nUUlH00_nUUlH00ol0003oW9;9oibBb@0@o`0000?o
H7[E00?o0000odidf?l000000_l000000olUJM[o0000o`000004o`000003o`Aggol0003o000000Co
00000oo?h^D01?l0003ob]kWol[Nioo:g^L2o`0000;ok=Ro00Go0000onSG`ooXel?oj=O3o`00000=
ooooo`03o`000?oooooooooo00Wooooo000aooooo`?o00006Oooool3o`0000_ooooo0ol00003okfl
f@04o`000?no_=Oo_kcGo`0000?oe[k200?o0000omJl`?oF_<000ooF_<02o`0000?og;Zg00?o0000
om^i]_oK^KH00_oK^KH01_l0003of[RfomZh]_l0003og;Nco`0000?ofkJc00Oo0000omZe/ooJ]K?o
f[Fco`000?oI];?o000000Cof;>d00Ko0000omRd]OoH];Go0000omBb]ol00006omBc^003o`000?o>
/[koc[:n00;oc[:n00Ko0000olnf`Oo?]/7o0000olBab?l00004olFgc003o`000?nb/=Ko000000;o
000000?o/kOLo`000?n@Z^P00on@Z^P00ol0003oF8oZo`000002o`000003obUWfOl0003o000000;o
000000Go02Vbo`000?l0003o02nco`000002oaTk]P03o`000?l[AK[o000000?oBEJm00Go0000of5T
_omQI;oo0000ogQb_`04o`0000;oSGjm1Ol00002oif8_003o`000?n[SkWoZhni00;oZhni00?o0000
okFE]oneUKL00oneUKL2o`0000Ko_ibe0_l00005olRT]003o`000?o<Y[;o000000God:bd00?o0000
omNd]OoG];D00_oG];D01ol0003ogKfhomfm^?oM_KSo0000omfl]ol000000ooTa[X01?l0003oj]:m
on[B_Ol00002onoN_PSo000000Goi?^bo`000?l0003o0000om[m^`02o`0000;ohoWD00Co0000on3[
fOoPjmWo00000_oHf=L2o`0000Cobl3@0_l00005okj]b@03o`000?nhZLWo000000?o/ik300?o0000
ojfKa?n]Vl@00_n]Vl@00ol0003oYIO6ojFGaP05o`0000;oWHg300Go0000oiB9a_nDRLKoU8W6o`00
0004ohV5b@04o`000?mmPLgoOH7=ogf1c@?o00000_mPN]D01?l0003oCWCHodidf?l00002obEYfPCo
000000Co5WgVo`000?l0003o00001?m`_oh00ol0003ocn;Uo`000003ol[Ni`;o00000oo/f;l01_l0
003oj=O3onSG`ol0003oi]K7o`0000cooooo00?o0000ooooooooool02Oooool0037ooooo00?o0000
ooooooooool05_ooool3o`0000oooooo0ol000000onm_=Wo0000oknle`03oknle`03o`000?oF_/;o
000000Goe[c000Ko0000omJk_ooF^koo0000ombj]ol00004om^i]P03o`000?oJ^;Kof[Rf00;of[Rf
00?o0000om^f/ooK][<00_oK][<00ol0003of[FcomZe/`02omZe/`03o`000?oH/kCof;>d00?of;>d
00Go0000omRd]OoH];Gof;Beo`000006omBc^003o`000?oE]K[o000000;oc[:n00?o0000olnf`Oo?
]/400_o?]/400ol0003oaKO<olFgc004olFgc003o`000?nc]mco/kOL00?o/kOL00?o0000oi2Zj?n@
Z^P00_n@Z^P00ol0003oF8oZoeR?jP03o`000006o`0o`ol0003o02ffo`000?l0:K;o00000_l0;k<0
0ol0003o6C^fo`000002ob]5^P04o`000?m9E[goBEJmo`0000?oHFBo00Co0000ogQb_omhL[ooN7:o
0ol00002ohen_P03o`000?nMR;coWHRl00;oWHRl00?o0000oj^?^On[SkT00on[SkT01ol0003o]IFg
okFE]oneUKOo0000okNH^?l000001_noW;D00ol0003ob:BdolRT]005olRT]003o`000?o@[;Cod:bd
00?od:bd00?o0000omFc]ol000000_oG];D00ol0003ogKfhomfm^003omfm^005o`000?oTa[[oi<Jj
onC6^_l000000ooZd[d01?l0003okmjnonoN__l00002oo;Z_`04o`000?oblkco0000onci^0?o0000
00?of?^bo`000?l000000_l000001OoSnMCo0000on3[fOoPjmWo000000;of=SG00?o0000olk4dOl0
00000oo;`=000ol0003o`[38o`000005okj]b@;o00001?ncW/<00ol0003o[I_4ojfKa002ojfKa0?o
00000_nTTL400ol0003oWHg3oif=``03oif=``05o`000?nDRLKoU8W6oiB9a_l000001?n9QLT01_l0
003oOH7=ogf1cOmmPLgo0000ofmmd@?o00000om>M=P2o`000003obEYf_l0003o9G7P00Co000000?o
5WgVo`000?l000001?l00003ol[Ni`06o`000?o6f^Soa][Xo`000?o/f;oo00000_oXel<01Ol0003o
i]K7onKFaooVe/Oo000000cooooo00?o0000ooooooooool02?ooool0037ooooo00?o0000oooooooo
ool04oooool3o`0001?ooooo00?o0000o`YZg?l000001Ono_=L2o`0000Goe[c000?o0000omJk_ooF
^kl00_oF^kl00ol0003ofkVfom^i]P02om^i]P03o`000?oJ^;Kof[Rf00?of[Rf00Go0000om^f/ooK
][?ofkJco`000005omZe/`03o`000?oH/kCof;>d00;of;>d00?o0000omRd]OoH];D00_oH];D00ol0
003oe;>homBc^003omBc^006o`000?oE]K[oeKFjo`000?o>/[ko00001Oo?]/400ol0003oaKO<olFg
c003olFgc003o`000?o7_M7o000000Co/kOL00Co0000oi2Zj?n@Z^SoT:[X1_l000000ol>HmWo0000
o`0o``05o`000004o`0_/ol0003o0000o`0000;o:dFj0_l000000om9E[go0000of5T_`02of5T_`05
o`000?mhL[ooN7:oogQb_ol000001?n=O[h00ol0003oWHRloif8_003oif8_003o`000?n[SkWoZhni
00;oZhni00Co0000okFE]oneUKOo00000ongV;P00ol0003o_ibeoknL]@03oknL]@03o`000?o8Y;Co
b:Bd00Gob:Bd00?o0000om2/]?o@[;@00_o@[;@01?l0003oeK>gomFc]ol00002omNd]@03o`000?oM
_KSogKfh00?ogKfh00Go0000onC6^_oTa[[oi<Jjo`000002on[B_@04o`000?o_g[kokmjno`0000;o
l^Zo00Co0000oo;c_?l0003ok?Vh0_l000001ooLnZoo0000o`000?l0003oeok1o`000?oOoM400_l0
00001OoPjmWo0000omSHeooHf=Oo000000?oc/CA00?o0000ol_0d?l000000oo2/<P00ol0003o_Zg9
okj]b@02o`000003okNQ`_l0003o/ik300?o/ik300?o0000ojfKa?l000000_l000000onZU;oo0000
ojBA`@03ojBA`@03o`000?nMSL?oWHg300;oWHg300?o0000oiB9a_nDRLH00_nDRLH01Ol0003oRHG9
ohV5bOn9QLWo000000CoOH7=00Co0000ofmmdOm_OM7oKggA0_l000000om>M=So0000od5cg003o`00
00;o9G7P00?o0000obZ4j_l000000_l00004og:ko003o`000?o:g^Oo000000?oa][X0_l00003onSG
``04o`000?oVe/Ooi]K7onKFa`;o00002oooool00ol0003oooooooooo`08ooooo`0000?o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo0_l0000Gooooo`?o00000ono_=L01?l0003o_k_F
oknke_l00003omJl`003o`000?oF^kooe[^o00?oe[^o00?o0000om^i]_oK^KH00_oK^KH00ol0003o
f[RfomZh]P02omZh]P03o`000?oJ]kKo000000;ofkJc00?o0000omZe/ooJ]K<00_oJ]K<00ol0003o
f[Jdo`000003omRc]007o`000?oH];Gof;BeomRd]Ol0003of;Jfo`000003omBc^003o`000?oE]K[o
eKFj00;oeKFj00?o0000olnf`Oo?]/400oo?]/400ol0003odK[4o`000003olFgc005o`000?o7_M7o
akgAolNmdOl000000_nc]m`5o`0000;oS;?a00?o0000odJCl?m6To002ol000000ol9=;Go0000o`00
0002ob]5^P?o00000omQI;l00ol0003oN7:oogQb_`02ogQb_`03o`000?n=O[koSGjn00;oSGjn00?o
0000oif8_?nMR;`00_nMR;`00ol0003oZhnioj^?^@02oj^?^@03o`000?neUKOo000000Co]iRh00?o
0000oknL]OnoW;D00_noW;D00ol0003o`Z6go`000005olRT]003o`000?o<Z[Oo000000?od:bd00Ko
0000omFc]ooE/kOo0000omNd]Ol00005omfm^005o`000?oTak_o0000onC6^_l000000ooZd[d02ol0
003okmjnonoN__l0003ol^Zoo`000?oblkco0000onci^?l0003oi?^b00?o000000GocoZao`000?l0
003ogogAo`000002on3afP;o000000?of=SGo`000?o>a=400oo>a=42o`0000Co`[3800?o0000okj]
bOl000001?ngXL801?l0003o/ik3ok>N`oncW/<2o`0000GoZYBo00Go0000ojBA`OnTTL7oY971o`00
0004oif=``03o`000?nDRLKoU8W600;oU8W600Go0000ohV5bOn9QLWoRHG9o`000004ogf1c@06o`00
0?m_OM7oKggAofmmdOl0003oHW_E0ol00002od5cg0?o000000Go9G7Po`000?l0003o0000obZ4jP06
o`0000?oa][X00Ko0000ol;Fj?o2e^So0000onSG`ol00003onKFa`04o`000?oSe/[ohmK:o`0000[o
oooo00?o0000ooooooooool02?ooool00003oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool3
o`0001[ooooo0ol000000ono_=Oo0000oknkeP03oknkeP03o`000?oF_<3o000000Goe[^o00?o0000
omFj__l000000_oK^KH00ol0003of[RfomZh]P03omZh]P05o`000?oJ]kKo0000om^f/ol000001?oJ
]K<01ol0003of[JdomZf]?oJ][Co0000omRc]?l000001?oH];D01_l0003of;JfomRf]_l0003oe;>h
o`0000GoeKFj00?o0000olnf`Oo?]/400_o?]/401ol0003odK[4om6ja?oA^/Co0000olFgc?l00000
1Oo7_M42o`0000Co]<7T00Go0000ohbclOn</o7oS;?ao`000002odJCl003o`000?l0Fm7o000000So
000000Ko2CBeo`000?l0003o:dFjo`000?m3E;h2o`0000?oHFBo00Go0000ogQb_omhL[ooN7:oo`00
0004ohen_P03o`000?nMR;coWHRl00;oWHRl00?o0000oj^?^On[SkT00_n[SkT2o`0000Go]iRh00Go
0000oknL]OnoW;Go_ibeo`000002ol:Q]`03o`000?o8Y;Cob:Bd00;ob:Bd00Co0000olbZ]oo<Z[Oo
00000_o@[;@00ol0003oeK>gomFc]`02omFc]`03o`000?oM_KSogKfh00?ogKfh00Co0000onC7^ooT
ak_oi<Nk0_l00002on[B_@08o`000?o_g[kokmjno`000?obj[oo0000oo;c_?l00002onci^0?o0000
00Koc?NWo`000?l0003o0000omomdOl00002on3afP04o`000?oJgMWof]gIo`0000Coc/CA00?o0000
olBcbOl000001?o2/<P2o`0000Go]j7200Ko0000ok>N`oncW/?o0000ojnG__l00005ojZD_`05o`00
0?nTTL7oY971ojBA`Ol000001OnMSL<00ol0003oU8W6oiB9aP0;o`0000CoKggA00Co0000of9keOmR
NmGoHW_E0_l000000om1Lmco0000ocmkhP02o`0000;o?h_]0ol00004ogJhn`03o`000?o6f^So0000
00?o`]KX0_l00003onKFa`05o`000?oSe/[ohmK:on?Fb_l000002_ooool00ol0003oooooooooo`08
ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`Go0000
1Oooool00ol0003oooooooooo`0<ooooo`?o00007_ooool00ol0003o06?Ho`000005oknkeP;o0000
1OoF^kl01ol0003oeKZnomFj__oE^[ko0000om^i]_l000001?oJ^;H01Ol0003of[NfomZg]_oJ]kKo
000000Gof[Fc00?o0000omZf]?oJ][@00_oJ][@00ol0003of;BeomRd]@02omRd]@03o`000?oH][Ko
f;Jf00;of;Jf00?o0000omFe^_oE]KX00ooE]KX00ol0003oe[Rlo`000003olnf`@03o`000?oA^/Co
dK[400;odK[400?o0000olNmdOo7_M400oo7_M400ol0003obLCFo`000004okC1i0Wo00000_l0Fm40
3_l0003o01n[o`000?l07J[o0000o`0U[ol0003o2CBeo`000?lL@K_o0000ob]5^_l0003o@eBn0_l0
0002of5T_`03o`000?mhL[ooN7:o00;oN7:o00Go0000ohen__n=O[koSGjno`000004oif8_003o`00
0?n[SkWoZhni00;o000000?o[9:ko`000?ngV;P01?ngV;P01?l0003o_ibeoknL]Ol00004ol:Q]`04
o`000?o8Y;Cob:Bdo`0000?oc:Zg00Co0000om2/]?o@[;Co00001?oE/kL00ol0003ogKfhomfm^002
omfm^003o`000?oTak_oi<Nk00;oi<Nk00Oo0000on[D__l0003oj]:mo`000?o_g[ko000000;ol^Zo
00Co0000oo;c_?l0003ok?Vh0_l000000ooAmjKo0000o`000002o`000005omomdOl0003oh?7Jon3a
f_l000000_oJgMT2o`0000?oc/CA00Go0000olBcbOo4/lWoa;?9o`000002ol:`b003o`000?nkY<;o
000000Go]j7200?o0000ok>N`ol000000on_Ukh00ol0003oZYBoojZD_`02ojZD_`03o`000?nTTL7o
Y97100;oY97100?o0000oif=`onMSL<01Ol00002oiN8`P05o`000?n?QLGoShG5ohn5aOl000000on6
PlP3o`0000;oKggA00Ko0000of9keOmRNmGoHW_Eo`000?mHNm/3o`0000;o?g_R00?o0000ocn;kOlo
Rnd00_loRnd6o`0000;o`]KX0_l00002ol3Bj003o`000?oVe/Oo000000?ohmK:00?o0000on3Ec?l0
00002Oooool00ol0003oooooooooo`08ooooo`000_ooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo0_l0000:ooooo`?o00008_oo
ool3o`0000?o_k_F00?o0000oknjeOl000001?oF^kl00ol0003oeKZnomFj_P03omFj_P03o`000?oJ
^;Kof[Rf00;of[Rf00?o0000omZg]_oJ]kH00_oJ]kH00ol0003of[FcomZe/`02omZe/`03o`000?oJ
][Cof[Jd00?of[Jd00?o0000omRd]OoH];D00_oH];D00ol0003of;JfomRf]P02omRf]P03o`000?oE
]K[oeKFj00;oeKFj00Oo0000omJh_?oF^;coe[Rlo`000?o?]/7o000000GodK[40_l00003olNmd@06
o`000?o9a=KobLCFolW4e_l0003o]<7T0_l00003okG;jP04o`000?n6__WoQ[kiohJnn@So000000Oo
01fZo`000?l0003o0000o`Td]Ol0003o746k00;o000000?o@eBno`000?mMI<800ol00004ogQb_`05
o`000?n=O[koSGjnohen__l000001OnMR;`2o`0000Co[9:k00?o0000okNH^?ngV;P00ongV;P2o`00
00Go`Z6g00Co0000olRT]?o8Y;Co00001?o<Z[L2o`0000CoeK>g00?o0000om^m^ol000000ooM_KP0
1Ol0003oi<NkonC7^ooTak_o000000?oj]Bn0_l000001Oo_g[ko0000oo;Z_ol0003ol_>l00?o0000
00?ofoV/o`000?l000001_l000001OoPlM[o0000om[MfOoJgMWo000000;od<SC00?o0000olk4dOl0
00001?o4/lT00ol0003o`[38o`000003ok^T`P03o`000?ngXL;o]j7200;o]j720_l00004ojnG_P03
o`000?nZU;ooZYBo00?oZYBo00?o0000ojBA`Ol000001?l00002oij;_`03o`000?nGR<;oUhS200?o
UhS200Go0000ohn5aOn?QLGoShG5o`000003ohJ3b003o`000?mlPLgo000000;o00001?mRNmD00ol0
003oF7_KoeQkf`03o`000003ocmkh_l0003o000000?o00001?mm]_P00ol0003o`]KXo`000004ol3B
j0;o00000ooSe/X01Ol0003oh=G<on3Ec?oPeLco000000Sooooo00?o0000ooooooooool02?ooool0
00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?oMgMgoEEEE
ooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0000Vooooo`?o000000?o_k_Fo`000?no
^]D00_no^]D01Ol0003oe[^oomJk_ooF^koo000000GoeKZn00?o0000omZh]_oJ^;H00_oJ^;H01ol0
003of[NfomZg]_oJ]kKo0000omVg]ol000000ooJ]K<00ol0003of[JdomZf]002omZf]003o`000?oJ
][Go000000;of;Be00?o0000omRf]_oH][H00_oH][H00ol0003ofKRho`000003omFe^P03o`000?oF
^;coe[Rl00;oe[Rl00?o0000om6ja?oA^/@00ooA^/@01_l0003od[o7om:oaol0003oakgAo`0000Co
bLCF0_l00005okG;jPco000000?o01fZo`000?l09Jl00ol00002oaa1^`04o`000?m3E;ko@eBno`00
00?oGFC21Ol00004ohen_P03o`000?nMR;coWHRl00?o00001On/T[/00ol0003o]iRhokNH^003okNH
^003o`000?o2XKOo`Z6g00Co`Z6g00?o0000olRT]?l000001Oo<Z[L00ol0003oeK>gomFc]`03omFc
]`06o`000?oK_K_ofkfko`000?oM_KSo00000ooTak/00ol0003oj]Bnon[D_P02on[D_P03o`000?o`
hL3o000000Go000000?oioZdo`000?l000001Ol00003omgfg0;o000000?of]gIo`000?o@b=<00oo@
b=<00ol0003oa;?9olBcb@04olBcb@03o`000?nkY<;o^jC200;o^jC200?o0000okNQ`_ngXL800_l0
00000oncVKko0000ojnG_P03ojnG_P03o`000?nZU;ooZYBo00;oZYBo0ol00002ojB>_@03o`000?nN
RkooWX^o00?oWX^o00?o0000oiN8`_nGR<800_nGR<801Ol0003oShG5ohn5aOn?QLGo000000CoQX?8
00Co0000ogb1cOmlPLgoO87=1Ol00003oeQkf`03o`000?mFPn;o000000;o00000_mDTNd7o`0000?o
`=;X0_l000000onocnOo0000on?FbP02on?FbP06o`000?oPeLcoh=G<o`000?oNe<oo00001oooool0
0ol0003oooooooooo`08ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4004ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool00oooool3o`0002[ooooo
00?o0000o`1IdOl000001Ono^]D00ol0003oe[^oo`000005omFj_P03o`000?oD^Koo000000;of[Rf
00?o0000omZg]_oJ]kH00_oJ]kH01_l0003ofKNgomVg]ol0003of[Fco`0000Cof[Jd00Oo0000omZf
]OoJ][Gof[Jeo`000?oH];Go000000?of;Jf00Oo0000omVh^?oI^;SofKRho`000?oE]K[o000000Go
e[Rl0_l00003om6ja003o`000?oB_lOod[o700;od[o700?o0000olW4e_o9a=H00_o9a=H01Ol0003o
c<cJolc<f_l0003o]L_Z00?o00000_nfeO000ol0003oP<Onoh37oP08o`000004o`0MZ_l0003o0000
o`0[/`;o00000_lL@K/00ol0003o@eBno`000003oeeT`P04o`000?mfLl;oMW?2ogIc`PSo00000_nN
Rkl00ol0003o[9:kojbB^`04ojbB^`04o`000?ngV;So]iRhokNH^0;o00001oo2XKL00ol0003oc:Zg
olbZ]`04olbZ]`03o`000?oE/kOoeK>g00;oeK>g00?o0000om^m^ooK_K/00_oK_K/01Ol0003oi<Nk
onC7^ooTak_o000000Coj]Bn00Wo0000oo3Q`?o`hL3o0000oo;^_ol0003okoNko`000?oWn[@01ol0
0003omgfg004o`000?oIh]gofN;Mo`0000Cod<SC0_l00005olBcb@;o00001?nkY<800ol0003o]j72
o`000004ok>I_P03o`000?n_Ukko[iNn00;o[iNn1?l000000onYT;co0000ojB>_@03ojB>_@03o`00
0?nNRkooWX^o00;oWX^o00?o0000oiN8`_nGR<800_nGR<800ol0003oShG5ohn5a@02ohn5a@05o`00
0?n6PlSoQX?8ohJ3b?l000000omlPLd01?l0003oLX3Bog:0d_mbP=83o`0000;oF7_K00Co0000oeJ3
h_mFPn;oEX?R1Ol00004ohFem003o`000?o0d^So000000Co_loW00?o0000on?Fb_l000000_oPeL`0
1Ol0003og]C?omkDcooNe<oo000000Oooooo00?o0000ooooooooool01oooool00003oooooonHV9So
MgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l000001Oooool01?l0003o
ooooooooooooool3o`0002kooooo0_l00005oknje@;o00001OoE^[h01ol0003oe;VoomBi_ooD^Koo
0000omZh]_l000000ooJ]kH00ol0003ofKNgomVg]`02omVg]`03o`000?oJ][Cof[Jd00?of[Jd00?o
0000omZf]OoJ][D00_oJ][D00ol0003of;JfomRf]P02omRf]P03o`000?oI^;SofKRh00;ofKRh00?o
0000omJh_?oF^;`00ooF^;`01_l0003oekbnomNl__l0003odK[4o`0000Cod[o70_l00003olW4eP03
o`000?o<c=[oc<cJ00;oc<cJ0_l00004okKEl0Co00000_mjcol9o`000004o`0[/ol0003o746koaa1
^`;o000000?o@eBno`000?mMI<800_mMI<801Ol0003oMW?2ogIc`_mfLl;o000000?oS83100?o0000
oij;_onNRkl00onNRkl00ol0003o[9:kojbB^`03ojbB^`04o`000?ngV;So]iRho`0000;o^Yfk00?o
0000ol:Q]oo2XKL00oo2XKL2o`0000Goc:Zg00?o0000om6b^ol000000ooE/kL00ol0003ofkfkom^m
^`02om^m^`05o`000?oTak_oi<NkonC7^ol000000ooZe;h02Ol0003ol>70oo3Q`?l0003ol^joo`00
0?o_mk_o0000onOj]003o`000004okS^Vol0003o0000o`0000?ogOKL00?o0000omWRgOoIh]d00_l0
0003om38d`04o`000?o6]/_oa[K;o`0000?oa;?900Co0000okfW`onmYl?o00000onkY<82o`0000Go
/iVn00Co0000ojnG__n_Ukko[iNn0_l00004ojV@_003o`000?nTS[goY8jm00;oY8jm00?o0000oij;
_onNRkl00_nNRkl00ol0003oUhS2oiN8`P03oiN8`P05o`000?n?QLGoShG5ohn5aOl000000on6PlP0
0ol0003oO87=ogb1c@02ogb1c@06o`000?mbP=;oLX3Bog:0d_l0003oJX?I1?l00002oeJ3hP04o`00
0?mVUn_oIYO[ofJGj`Oo00001OnocnL2o`0000;oh=G<00Co0000omkDcooNe<oog]C?0_l00007oooo
o`03o`000?oooooooooo00Oooooo00000ol0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03ogMgMol0003ooooo00Cooooo1?l0000booooo`;o00000ono^]D01?l0003o_[WFokji
e_l00003omFj_P03o`000?oD^Kooe;Vo00?oe;Vo00?o0000omZg]_oJ]kH00_oJ]kH00ol0003ofKNg
omVg]`02omVg]`03o`000?oJ][Cof[Jd00;of[Jd00?o0000omZf]OoJ][D00ooJ][D01Ol0003of;Jf
omRf]_oH][Ko000000GofKRh00?o0000omJh_?oF^;`00_oF^;`00ol0003oekbnomNl_P02omNl_P03
o`000?oB_lOod[o700;od[o700Ko0000omG5booEaL_o0000olW4e_l00004olc<fP05o`000?o>e=ko
c]CNo`000?nfeO000_l00003okOMm0?o00000omgeOh4o`000008o`0HY_l0003o02^co`0[/ol0003o
746ko`000?lgD/42o`0000?oGFC200Go0000ogIc`_mfLl;oMW?2o`000004ohb0`@03o`000?nNRkoo
WX^o00;oWX^o00?o0000ojbB^on/T[/00on/T[/00ol0003o]iRho`000003okZM^`03o`000?o2XKOo
`Z6g00;o`Z6g00Co0000olJX^oo6Z;_o00000oo<Z[L01ol0003odK:kom6b^ooA/[_o0000omFc]ol0
00001?oK_K/01Ol0003oh/Vno`000?oTak_o000000?oj]Bn00Co0000oo3Q`?o`hL3o00000_obk[l0
1ol0003okoNko`000?l0003ofoV/o`000?nhkY/01Ol000001OoMm]co0000omWRgOoIh]go000000;o
d<cF00?o0000om38dol000001?o6]//00ol0003oa;?9o`000003okfW``06o`000?nkY<;o^jC2o`00
0?neW;ko00001OncVKh01_l0003o[iNnojnG__l0003o[I:ko`0000GoZI2l00?o0000ojB>_OnTS[d0
0_nTS[d00ol0003oWX^ooij;_`02oij;_`03o`000?nGR<;oUhS200[o000000?oQX?8o`000?mlPLd0
0_mlPLd00ol0003oLX3Bog:0dP02og:0dP04o`000?mZPmWoJX?IofZ3f@Go00000omVUn/00ol0003o
SKGaohfel@03ohfel@03o`000?nocnOo000000;o000000Co_lgUo`000?oPeLco00000ooNe<l01?l0
003og=CAomcDdOl00006ooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000=Oooool2o`00
0003oknjeOl0003o_[WF00?o_[WF00?o0000omFj__l000001_oD^Kl2o`0000;of[Nf00?o0000omVg
]ooI]kL00_oI]kL00ol0003ofKRho`000003omZf]003o`000?oJ][Gof[Je00;of[Je00?o0000omZh
]ol000000_oH][H00ol0003ofKRhomVh^002omVh^003o`000?oJ^[[o000000;oe[Rl00?o0000omNl
__oG_;h00ooG_;h01Ol0003od[o7om:oaooB_lOo000000CoeLG;0_l00003olc<fP04o`000?o>e=ko
c]CNolkDgPCo000000?o]mgdo`000?l000000_nhi?D4o`0000;oN][l0ol000001?l06:Ko0000o`0[
/ol00002oaa1^`03o`000?lgD/7o000000CoGFC200Go0000ogIc`_mfLl;oMW?2o`000003ohb0`@03
o`000?nNRkooWX^o00?oWX^o00?o0000ojbB^on/T[/00_n/T[/2o`0000Go^Yfk00Co0000ol:Q]oo2
XKOo00000oo6Z;/01?l0003oc:ZgolbZ]ol00004om6b^`03o`000?oE/kOo000000?ofkfk00Co0000
on;9__oRbKkoh/Vn0_l00003on[D_P03o`000?o`hL3o000000;ol^jo00Co0000onog^ol0003oioZd
1_l00002omKkg`?o000000?ofN;Mo`000?o@c=H00_o@c=H2o`0000Goa[K;0_l00004okfW``03o`00
0?nkY<;o000000?o]Ibn00?o0000ok>I__ncVKh00oncVKh2o`0000?o[I:k00?o0000ojV@_?nYT;`0
0_nYT;`00ol0003oY8jmojB>_@02ojB>_@03o`000?nNRkooWX^o00Go00000_nJR;l00ol0003oU8K2
oiB6`P02oiB6`P03o`000?n=QLKoSHG600_o00000omZPmT2o`0000;oJH_P1_l00003ohfel@?o0000
1?nocND2o`0000?og]C?00Go0000omcDdOoLe=7og=CAo`000006ooooo`03o`000?oooooooooo00Oo
oooo000aooooo`03o`000?oooooooooo03?ooooo0_l00005okjieP;o00001_oD^Kl01_l0003oe;Vo
omBi_ol0003of[Nfo`0000?ofKNg00Oo0000omVh^?oI^;SofKRho`000?oJ][Co000000Cof[Je00Ko
0000omZh]ooJ^;Oo0000omRf]_l00004omVh^006o`000?oJ^[[of[Zjo`000?oF^;co00001OoG_;h0
1Ol0003ofL71o`000?oB_lOo000000CoeLG;00Ko0000omS<c_oHc<ko0000olc<f_l00003olkDgP04
o`000?oAfn7odM_Qom7Kh@?o000000?o^>Ceo`000?l000000onjjO@8o`0000;o02^c00?o0000oaa1
^ol000000_lgD/42o`0000;oGFC200Go0000ogIc`_mfLl;oMW?2o`000004ohb0`@03o`000?nNRkoo
WX^o00;oWX^o00?o0000ojbB^on/T[/00_l000000on_Ukoo0000okZM^`04okZM^`03o`000?o2XKOo
000000CoaZRk00Co0000olbZ]oo<Z[Oo00001OoA/[/00ol0003ofkfkom^m^`02om^m^`09o`000?oR
bKkoh/Vnon;9__l0003ojMO2o`000?oZe;ko000000;ol>7000?o0000oo;^_oobk[l00_l000000ooW
n[Co0000o`000004o`0000;oe__O00?o0000omKWh_oFin800_l00003om3<eP03o`000?o6^Lko0000
00?oa[K;0_l000000onnZ<Co0000okfW``04okfW``03o`000?neW;ko]Ibn00;o]Ibn00?o0000ok>I
__ncVKh00_ncVKh2o`0000Co[I:k00?o0000ojV@_?nYT;`00_nYT;`00ol0003oY8jmojB>_@02ojB>
_@?o00000_nPR[d00ol0003oVXRooiZ8_`02oiZ8_`03o`000?nDQ/;oU8K200?oU8K200Co0000ohf5
a_n=QLKo00001?n5Q</01?l0003oOXG@ogj5d?mnQM03o`0000;oJX?I0_l00002ofV;h004o`000?mf
W>WoMYcYogJLj@Co00000_nE]^h01Ol0003o_lgUoko=iOnocNGo000000;o`<gT00?o0000omkDcol0
00001?oLe=400ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000booooo`03o`00
0?oooooooooo03?ooooo0_l00003okjieP03o`000?nl^MOo000000Goe;Vo00?o0000omBi_ooD^Kl0
0_oD^Kl00ol0003ofKNgomVg]`02omVg]`03o`000?oI^;SofKRh00;ofKRh00?o0000omZf]OoJ][D0
0ooJ][D01Ol0003of[RgomZh]ooJ^;Oo000000GofKRh00Go0000omZj^_oJ^[[of[Zjo`000005omNl
_P04o`000?oI`L7ofL71omW1`@;o00000ooEaL/00ol0003of<c>omS<cP02omS<cP?o000000?oc]CN
o`000?oAfn400_oAfn401?l0003odn7Rom?Qh_oChN83o`000005ok[Ym?l0003o0000okgZlol00000
0oo2jO44o`000004o`0[/ol0003o0000o`0000;o=e;100?o0000oeITa_l000000_l00003ogIc`P03
o`000?n<P<7oS83100;oS83100?o0000oij;_onNRkl00_nNRkl00ol0003o[9:ko`000003ojnG_`03
o`000?njWK_o^Yfk00Co^Yfk00?o0000olJX^oo6Z;/01?o6Z;/2o`0000KodK:k00Go0000om^m^ooK
_K_ofkfko`000003on;9_P04o`000?oYel;ojMO2onWG`P;o000000Kol>70o`000?obk[ool^joo`00
0?o_mk/2o`000003olcfXol0003o000000;o00000_oFnml01?l0003oe^ORomKWh_l00002olk?f`03
o`000?o@c=Ko000000?oa[W>00?o0000olJfbol000001?nnZ<@01?l0003o_JO3okfW`onmYl<2o`00
00Go]Ibn00Ko0000ok>I__ncVKko0000ok2D^_l00005ojfB^`03o`000?nYT;coZI2l00;oZI2l1?l0
00000onTS;_o0000oj2:_@03oj2:_@03o`000?nJR;ooVXRo00;oVXRo00?o0000oiB6`_nDQ/800_nD
Q/801Ol0003oSHG6ohf5a_n=QLKo000000CoQHC;00Ko0000ogj5d?mnQM3oOXG@o`000?miRML3o`00
0005ofV;h?l0003oJH_PofV;h?l000000omfW>T00ol0003oUKK^oiFfkP03oiFfkP03o`000?nocNGo
000000?o`<gT0_l00004omcDd@03o`000?oJeMCo000000Gooooo00?o0000ooooooooool01oooool0
03?ooooo00?o0000ooooooooool0<oooool2o`000003okjie_l0003o_;WG00;o_;WG00Go0000omBi
_ooD^Kooe;Voo`000005omBi_`05o`000?oI]kOofKNgomVg]ol000001OoI^;P00ol0003of[JeomZf
]@02omZf]@03o`000?oJ^;Oof[Rg00;of[Rg00?o0000omVh^?oI^;P00_oI^;P00ol0003of[ZjomZj
^P02omZj^P;o00000ooG_;h00ol0003ofL71omW1`@02omW1`@05o`000?oKaL?o0000omG5bol00000
1?oHc<h01Ol0003of];@om[Bd?oJd]3o000000?odM_Q00Go0000om?Qh_oChN;odn7Ro`000002omCT
hP?o000000?o_N[co`000?o2jO400_o2jO400ol0003oa^C]o`000004o`000003o`Lj^ol0003o0000
00;o=e;100Co0000oeITa_mFI<KoEVC60_l000000omfLl;o0000ohb0`@03ohb0`@04o`000?nNRkoo
WX^ooij;_`?o00001On_Ukl00ol0003o^YfkokZM^`02okZM^`;o00001_o6Z;/00ol0003odK:kom6b
^`04om6b^`03o`000?oH_Koo000000;ofkfk00Go0000on;9__oRbKkoh/Vno`000003onWG`P03o`00
0?o_iLCo000000;o000000Col^joo`000?l0003ogO^`1_l000001OoFnmoo0000omKWh_oFin;o0000
00?oc/oK0_l00005olJicP03o`000?nnZ<Co_ZS400?o_ZS400Co0000okfW`onmYl?o00000_ngWKh0
0ol0003o]IbnokFL_P02okFL_P03o`000?ncVKko000000;o/9Bj00?o0000ojfB^on]T[/00on]T[/0
1?l0003oZI2lojV@_?nYT;`2o`0000CoY8bk00?o0000oj2:_OnPR[d00_nPR[d00ol0003oVXRooiZ8
_`02oiZ8_`03o`000?nDQ/;oU8K200;oU8K200Go0000ohf5a_n=QLKoSHG6o`000004ohF4b`03o`00
0?mnQM3oOXG@00;oOXG@00Co0000ogV9eomiRMOoNHWG2_l00003oiFfkP?o00000oo0cN@00ol0003o
`LkTo`000003omcDd@05o`000?oJeMCof]GDom[Ee?l000001?ooool00ol0003oooooooooo`07oooo
o`00=?ooool2o`0003Cooooo0_l00005okbie`03o`000?oD^Koo000000Goe;Vo00?o0000om>i`Ol0
00000_oI]kL00ol0003ofKRhomVh^002omVh^003o`000?oI^KWo000000?of[Je00Oo0000omZh]ooJ
^;Oof[Rgo`000?oJ^[So000000?ofKRh00Go0000omZj^_oJ^[[of[Zjo`000002om^n_003o`000?oG
_;ko000000CofL7100Co0000om_5`ooKaL?oflG30_l00003omS<cP09o`000?oJd]3of];@om[Bd?l0
003og=OBo`000?oAfn7o000000?odn7R00Co0000omCTh_oDi>;o00000ooFiN43o`000004ol;YlOl0
003oa^C]olKTk@Ko000000Go1cZko`000?l0003o=e;1o`000003oeITaP03o`000?mbM/Oo000000;o
00000_n<P<45o`0000;oWho300?o0000ojnG_on_Ukl00on_Ukl01Ol0003o^YfkokZM^onjWK_o0000
00;o_ZBo00?o0000olJX^oo6Z;/00oo6Z;/00ol0003odK:kom6b^`03om6b^`06o`000?oH_Koof;fo
o`000?oK_K_o00000ooRbKh01Ol0003ojMO2onWG`_oYel;o000000;oknG400Go0000oo3b`oo`l/?o
0000on[j_006o`000006olOmhol0003o0000o`000?oFin;o00000oo>cm/00ol0003oa;[Ao`000004
olJicP;o00001OnnZ<@00ol0003o_JO3o`000003okNM_P03o`000?neW;ko]Ibn00;o]Ibn0_l00004
ok2D^P03o`000?n]T[_o[I:k00;o[I:k00Ko0000ojV@_?l0003o0000ojR>^_l00005ojB<^`05o`00
0?nPR[goX8Zmoj2:_Ol000001?nJR;l00ol0003oU8K2oiB6`P03oiB6`P04o`000?n=QLKoSHG6o`00
00CoQHC;00?o0000ogj5d?mnQM000_mnQM001ol0003oNHWGogV9eomiRMOo0000ogVBgol000000_mi
T]l01?l0003oQ:;WohBRion4X^L4o`0000?oWKS[00?o0000ol3=i?l000000oo1c^@00ol0003og=CA
o`000003om[Ee003o`000?oGemSo000000?ooooo00?o0000ooooooooool01oooool003Kooooo00?o
0000ooooooooool0<_ooool2o`0000Co_;WG0_l00005omBi_`06o`000?oC^L7odkW1o`000?oI]kOo
00001?oI^;P01ol0003ofKViomVi^OoI^KWo0000omZf]Ol000000ooJ^;L01ol0003of[ZhomZj^?oJ
^[So0000omVh^?l000001?oJ^[X01Ol0003ofkjlom^n_?oK_[co000000CofL7100?o0000om_5`ooK
aL<00_oKaL<01Ol0003og/_6o`000?oHc<ko000000?of];@00Co0000omcGd_oLem;og=OB0ol00000
1OoChN;o0000omCTh_oDi>;o000000?oe^GQ00?o0000omOSgooGhml00ol000001_o6i>go0000olSL
j?o8g>So0000o`05U0Co000000Co9Tk4o`000?l0003o00000_mFI<H01?l0003oLWK7og9faombM/L3
o`0000;oS8C600?o0000oin?`onOSl<00_nOSl<00ol0003o[iNoojnG_`03ojnG_`04o`000?njWK_o
^Yfko`0000?o_ZBo00?o0000olJX^oo6Z;/00_o6Z;/00ol0003oc;6oo`000003om6b^`03o`000?oH
_Koof;fo00;of;fo00?o0000on;9__oRbKh00_oRbKh01?l0003ojMO2onWG`_l00002onoUa004o`00
0?o`l/?ol?;3oo3b``Go000000Co[?O4o`000?o7oN?o00000_o?k>T2o`0000?oc/oK00Go0000olBj
dOo4^]7oa;[Ao`000002olJicP04o`000?nmZ/Ko_J[6o`0000Co_ZS40_l00004okNM_P03o`000?ne
W;ko]Ibn00;o000000?o/YJjo`000?n`U;X00on`U;X00ol0003o[I:kojfB^`02ojfB^`;o00000onX
S[X00ol0003oY8bkojB<^`03ojB<^`03o`000?nPR[goX8Zm00;oX8Zm00?o0000oiZ8_onJR;l00_nJ
R;l00ol0003oU8K2oiB6`P0@o`0000CoNHWG00?o0000ogVBgol000000_miT]l00ol0003oQ:;WohBR
i`02ohBRi`04o`000?nM^>_oWKS[oifhj`?o00001?o1c^@2o`0000?of]GD00?o0000omOGf?oGemP0
0_l00003ooooo`03o`000?oooooooooo00Kooooo000gooooo`03o`000?oooooooooo03;ooooo0_l0
00000onl^MOo0000o`000002okVhf@05o`000?oD^Kooe;VoomBi_ol000001?oC^L400ol0003ofKRh
omVh^003omVh^003o`000?oI^KWofKVi00;ofKVi00?o0000omZh]ooJ^;L00_oJ^;L00ol0003of[Zh
omZj^002omZj^003o`000?oJ^[[of[Zj00;of[Zj00?o0000om^n_?oK_[`00_oK_[`2o`0000?ofL71
00Go0000om_5`ooKaL?oflG3o`000003omk;aP05o`000?oJd]3of];@om[Bd?l000000ooLem801?l0
003og]_ComkKdooNfm<2o`000003omCTh_l0003oe^GQ00;oe^GQ00Co0000omOSgooGhmoo00000_oG
gmd4o`000003olSLj?l0003o000000;o000000?o02ngo`000?l000000_lVC/@01Ol0003oEVC6oeIT
a_mFI<Ko000000;oLWK700?o0000ohb4a_n<Q<H00on<Q<H00ol0003oWho3oin?``02oin?``03o`00
0?n_Ukoo[iNo00?o[iNo0_l00005okjT_`04o`000?o6Z;_oaZRko`0000?oc;6o00Co0000om6b^ooA
/[_o00001?oH_Kl2o`0000;oh/Vn00Co0000onWG`_oYel;o00000oo_iL@00ol0003ol?;3oo3b``02
o`000007omgk/?l0003o0000ojcga?l0003oaogSo`000002olo/j@06o`000?o9d^7obM;Qo`000?o>
cm_o00001?o4^]400ol0003oa[W>o`000003okfZaP03o`000?nnZ<Co_ZS400;o000000?o^9noo`00
0?ngWKh01?ngWKh2o`0000Co/YJj00Go0000ok2D^_n`U;[o/9Bjo`000002ojfB^`;o000000?o[92i
o`000?nXS[X00onXS[X00ol0003oY8bkojB<^`02ojB<^`04o`000?nPR[goX8Zmoj2:_@Wo00000_nI
RL801Ol0003oThW5oi>9aOnCRLGo000000CoSXW:00Co0000ohV<d?n9S=3oRHc@2ol00003ohBRi`Go
00000_nT_>X00ol0003o`LkTo`000002o`0000;o`m3T00?o0000om[Ee?l000000_oGemP00ol0003o
dm[Mo`000003ooooo`03o`000?oooooooooo00Kooooo000hooooo`03o`000?oooooooooo03;ooooo
0_l00005okVhf@03o`000?oD^Koo000000GodkW100?o0000omVh^?oI^;P00_oI^;P00ol0003ofKVi
omVi^@03omVi^@05o`000?oJ^;Oof[RgomZh]ol000001OoJ^[P2o`0000;of[Zj00?o0000om^n_?oK
_[`00_oK_[`01_l0003ogL:nomg2__l0003ofL71o`0000?oflG300?o0000omk;a_oNblH00_oNblH2
o`000003om[Bd?l0003og=OB00;og=OB00?o0000omkKdooNfm<00_oNfm<00ol0003ogmkCo`000002
o`000005omKUhOl0003oen?OomOSgol000000_oGgmd00ol0003oe]WJomKIfP02omKIfP03o`000?o7
d^;oam;R00?o000000?o02ngo`000?l000000_lVC/@2o`000003oeITa_l0003oLWK700;oLWK700?o
0000ohb4a_n<Q<H00_n<Q<H00ol0003oWho3oin?``02oin?``03o`000?n_Ukoo[iNo00;o[iNo0_l0
0006okjT_`03o`000?o6Z;_o000000Coc;6o00?o0000om6b^ol000001?oH_Kl01_l0003ogl_4omo;
a?l0003oh/Vno`0000;ojMO200Co0000onoUa?o_iLCo00000_o`l/<2o`000003omgk/?l0003o0000
00Go000000?ocncYo`000?o9d^400_o9d^42o`0000Goa;[A0_l00004okfZaP03o`000?nnZ<Co0000
00Co^9no00Co0000okNM__ngWKko]ifn0_l00005ok:F^P03o`000?n`U;[o/9Bj00;o/9Bj0_l00003
ojb@^@03o`000?nXS[[oZ8jj00;oZ8jj00?o0000ojB<^onTS;/00onTS;/3o`000003oj:<_Ol0003o
WX^o00?oWX^o00?o0000oiV9`_nIRL800onIRL801Ol0003oThW5oi>9aOnCRLGo000000CoSXW:00Go
0000ohV<d?n9S=3oRHc@o`000004ohF@e`04o`000?n7V]ko0000ohNJgPCo00000_n@Z>H00ol0003o
Y;cZojBljP02ojBljP;o00001Oo3d>@2o`0000;oemOH00Go0000om?JgOoCf]godm[Mo`000002oooo
o`03o`000?oooooooooo00Kooooo000iooooo`;o0000<_ooool2o`0000Go^KSI0_l00005om>i`@03
o`000?oB^/;o000000?ofKRh00?o0000omVi^OoI^KT00_oI^KT00ol0003ofKZko`000002omZh]`03
o`000?oJ^[Sof[Zh00;of[Zh00Ko0000om^l^_oK_;[o0000omZj^_l00003om^n_003o`000?oM`[ko
gL:n00;ogL:n00Go0000om_5`ooKaL?oflG3o`000004omk;aP03o`000?oPclOoh<o700?o000000?o
g=OBo`000?oNfm<00ooNfm<00ol0003ogmkCo`000003on3Nd`Go000000?oemoMo`000?oFfMX00ooF
fMX01?l0003oe=7Fo`000?o7d^84o`000006o`0_]ol0003o9Tk4obI>a?l0003oBVG<0_l00003og9f
a`03o`000?n<Q<KoS8C600?oS8C600Go0000oin?`onOSl?oWho3o`000002ojnG_`;o000000?o/Yk4
o`000?nnY;l01_nnY;l00ol0003oc;6oolba_`04olba_`03o`000?oH_Koof;fo00;of;fo00?o0000
omo;a?oObl@00_oObl@2o`000005onWG`_l0003oknG4onoUa?l000000_o`l/<8o`0000;o`^ka0_l0
0003olWBh@04o`000?o1^mGo`K_Eo`0000?oa;[A00?o0000okb[b?l000001?nmZ/H2o`0000Go^9no
00Ko0000okNM__ngWKko0000ok>G^ol00005ok:F^P04o`000?n`U;[o/9Bjok2D^P;o00001On/T;T0
1Ol0003oZ8jjojR>^_nXS[[o000000CoY8bk0_l00004oj:<_@03o`000?nNRkooWX^o00;oWX^o00?o
0000oiV9`_nIRL800_nIRL800ol0003oThW5oi>9a@02oi>9a@05o`000?n>RL[oSXW:ohj9b_l00000
1?n9S=000ol0003oQI3GohF@e`02ohF@e`05o`000?n7V]ko0000ohNJg_l000001On@Z>H01_l0003o
Y;cZo`000?l0003oZl;Zo`0000?o`m3T0_l000001?o5eNKo0000omOGf?l00004om?Jg@;o000000?o
ooooo`000?ooool01oooool003_ooooo00?o0000ooooooooool0<?ooool2o`0000;o^KSI0_l00000
0onf^=_o0000om>i`@03om>i`@07o`000?oB^/;od[[2om:j`_l0003ofKRho`000004omVi^@06o`00
0?oI^[_ofKZko`000?oJ^;Oo00001?oJ^[P00ol0003ofkbjom^l^P02om^l^P05o`000?oK_[cofkjl
om^n_?l000001OoM`[h2o`000003om_5`ol0003og/_600?og/_600Go0000on3?aooPclOoh<o7o`00
0002on;Cb@;o00000ooNfm<00ol0003ogmkCo`000003on3Nd`04o`000?oPgM;oh=gBo`0000;oh=[A
0_l00003omKIfP03o`000?oDdMKoe=7F00?o000000?oaLOKo`000?l000000_l0;kL01Ol0003o9Tk4
obI>a?l0003oBVG<00;o00000ombM/L00ol0003oS8C6ohb4aP02ohb4aP03o`000?nOSl?oWho300;o
Who30_l00004ok:Na003o`000?nnY;oo_ZBo00?o_ZBo0_l00005olba_`03o`000?oB_LGo000000?o
f;fo00?o0000omo;a?oObl@00_oObl@00ol0003oim[8o`000002o`000003onoUa?l0003ol?;300?o
000000?obOR[o`000?l000000_l000000oo2k_7o0000o`000002ol7Cj003o`000?o9d^7o000000Co
`K_E00?o0000olBjdOl000000onlZlP01_l0003o_J[6okfZa_l0003o]j31o`0000Go^9no00?o0000
okNM__l000000oncUk/00ol0003o/YJjok:F^P03ok:F^P?o000000?o[Y:io`000?n/T;T01?n/T;T0
0ol0003oZ8jjojR>^P02ojR>^PCo000000?oYXfko`000?nRS;d00onRS;d00ol0003oWX^ooij;_`02
oij;_`03o`000?nIRL;oVHW200;oVHW200?o0000oi>9aOnCRLD00_nCRLD01Ol0003oSXW:ohj9b_n>
RL[o000000CoRHc@00?o0000ohF@eon5T=L00_n5T=L01_l0003oQi[NohNJg_l0003oQi[No`0000?o
T:SV0ol00004oj_2jP03o`000?o3d>Co000000?oaMGV0_l00003om?Jg@;o000000CocMoVo`000?oo
oooo00002?ooool003cooooo00?o0000ooooooooool0<?ooool00ol0003o^KSIo`000004okJhf`05
o`000?oC^L7odkW1om>i`Ol000001?oB^/800ol0003ofKViomVi^@03omVi^@05o`000?oI^[_ofKZk
omVj^ol000001?oJ^[P00ol0003ofkbjom^l^P03om^l^P05o`000?oK_[cofkjlom^n_?l000001?oM
`[h00ol0003oglK0omo6`002o`0000?og/_600Go0000on3?aooPclOoh<o7o`000003on;Cb@07o`00
0?oTel[o0000omkKdol0003ogmkCo`000003on3Nd`04o`000?oPgM;oh=gBo`0000?oh=[A00Go0000
omkFcol0003oe]WJo`000002omCAeP06o`000?o@b=;od<SBom38d_l0003oaLOK0_l000001Ol0;kOo
0000o`000?lVC/Co000000;oBVG<1Ol00004ohb4aP03o`000?nOSl?oWho300?o00001OnbW/@00ol0
003o_ZBookjT_`02okjT_`04o`000?o3[/Go`jk5o`0000?oc;6o00Oo0000om:maOoB_LGod[g5o`00
0?oH_Koo000000Cogl_400Co0000onOJb?oWf/So00000_o/jl/3o`000004omkm_Ol0003obOR[o`00
00?o[^ch0_l00004ol7Cj0;o00001Oo1^mD2o`0000Co_:_800?o0000okfZa_l000000ongX<400ol0
003o^9nookRO_`02okRO_`;o00001?ncUk/00ol0003o/YJjok:F^P02ok:F^P;o00001?n^T[T00ol0
003o[92iojb@^@02ojb@^@04o`000?nXS[[oZ8jjojR>^P;o00001?nVSK/00ol0003oXXbmoj:<_@03
oj:<_@05o`000?nNRkooWX^ooij;_ol000001OnIRL800ol0003oThW5oi>9a@0Ho`0000;oV[7W00?o
0000oj_2j_n[`^X00_n[`^X2o`0000?oaMGV00Ko0000olCMjoo4gN_o0000om?JgOl00003olgOiP?o
00002?ooool003gooooo00?o0000ooooooooool0<?ooool00ol0003o][SKokJhf`04okJhf`03o`00
0?oC^L7o000000God[[200?o0000omVi^OoI^KT00_oI^KT00ol0003ofKZkomVj^`02omVj^`;o0000
0ooJ^[P00ol0003ofkbjom^l^P02om^l^P05o`000?oM`;co0000om^n_?l000001?oM`[h02Ol0003o
glK0omo6`?oOa/3o0000on7:`_l0003og/_6o`000003on3?a`05o`000?oRdlWoh]?9on;CbOl00000
0ooTelX5o`000005on3Ndol0003oh=gBon3Md_l000000ooPf]401?l0003og]K?omkFcooNe/l2o`00
0003omCAe_l0003od<SB00?od<SB0_l000001?o2_=Co0000o`000?l0;kL3o`0000;oBVG<00Co0000
ofejcom]N/ooKG[?2?l00002oj6Fb@03o`000?nbW/Co/Yk400Co/Yk400Co0000okjT_onnY;oo0000
0oo3[/D01?l0003oc;6oolba_ol00005om:ma@03o`000?oOblCogl_400;ogl_400Co0000onOJb?oW
f/So00000oo/jl/01ol0003oj_S8o`000?l0003obOR[o`000?n^k?P00ol00002okKCk`06o`000?o1
dnSo0000o`000?nk^m[o00000oo1^mD2o`000003okV[c?l0003o_:_800?o_:_80_l00005okNP`@06
o`000?nhWkoo^9noo`000?ncVKco00001OncUk/01_l0003o/YJjok:F^_l0003o/9>io`0000Co[Y:i
00?o0000ojb@^On/T;T00on/T;T3o`000003ojV?^_l0003oYXfk00CoYXfk00?o0000oj:<_OnRS;d0
0_nRS;d00ol0003oWX^ooij;_`02oij;_`03o`000?nIRL;oVHW200Go00000_nISlL01Ol0003oUY7<
oiJAc?nFTLco000000CoTYCB00?o0000oi2JfOn@V]T00_n@V]T01_l0003oTZ?Poi:Sh?l0003oTZ?P
o`0000GoV[7W1?l00002ok7:k@03o`000?o5eNKo000000?oa=g[0_l00003olgOiP04o`000?nmi?;o
0000o`0000Sooooo000nooooo`;o0000<Oooool00ol0003o][SKokJhf`03okJhf`;o00001OoB^/80
0ol0003od[_4o`000003omVi^@05o`000?oI^[_ofKZkomVj^ol000000_oI_;d00ol0003of[Zho`00
0004om^l^P05o`000?oM`;cogL2lomg0_?l000001?oM`[h01Ol0003oglK0omo6`?oOa/3o000000?o
hL[20_l00003on3?a`04o`000?oRdlWoh]?9o`0000?oi=O:00Co0000onGIb_oUfL[o00000_oUf/X2
o`000003on3Md_l0003oh=[A00;oh=[A00Go0000omkFcooNe/oog]K?o`000002om_?c@03o`000?o@
b=;od<SB00;od<SB00?o0000olbncOl000000_o2_=@3o`000003o`a8a_l0003o000000;oBVG<00Go
0000ofejcom]N/ooKG[?o`000004ohZ:c@03o`000?nQU/WoXIK900;oXIK900?o0000ok:Na?nbW/@0
0onbW/@00ol0003o_ZBoo`000004ol>^a@03o`000?o</Koo000000Kod[g500Go0000omo;a?oOblCo
gl_4o`000003onOJb005o`000?o/jl_ok>_;o`000?oZn<P00_l000001?o9n:_o0000o`000?l00005
okKCk`;o00001?nk^mX00ol0003o`K_Eo`000004okV[c006o`000?nlZlSo_:_8o`000?nfX<;o0000
1OngX<400ol0003o^9noo`000003ok>I_003o`000?ncUk_o/iNk00;o/iNk00?o0000ok:F^_l00000
0_n`TkT00ol0003o[Y:iojjB^@03ojjB^@04o`000?n/T;Wo[92iojb@^@;o00001?nYSkX00ol0003o
YXfkojJ=^`02ojJ=^`03o`000?nRS;goXXbm00;oXXbm00?o0000oij;_onNRkl01Ol00002oif?a003
o`000?nISlOoVHo700?oVHo700Go0000oiJAc?nFTLcoUY7<o`000004oi:DdP03o`000?n@V]WoT9[I
00;oT9[I00Ko0000oi:Sh?nBXn3o0000oi:Sh?l00002oiZai`?o00001Onab^d2o`000004olCMjol0
003o0000o`0000;o_^Sb00?o0000olgOi_l000000onmi?82o`0000Oooooo0010ooooo`03o`000?oo
oooooooo02oooooo00?o0000okJhfol000000_l00002ok6ig`05o`000?oB^/;od[[2om:j`_l00000
0ooB^l@00ol0003ofKVio`000004omVj^`05o`000?oI_;gofKbmomVl_Ol000001?oK_;X00ol0003o
gL2lomg0_002omg0_0;o00000ooM`[h01Ol0003oglK0omo6`?oOa/3o000000?ohL[200Go0000on?>
`ol0003oh<o7o`000002on;Cb@05o`000?oTel[oi=O:onCGb_l000000_oUfLX01_l0003oiM[:onGJ
b_oUf/[o0000onGIb@?o000000?oh=[Ao`000?oNe/l00_oNe/l01Ol0003oflo=om_?cOoKclgo0000
00?od<SB00Ko0000olbncOo<_/goc;k=o`000?o2_=@3o`0000;o34S60_l000000om:ILco0000ofej
c`03ofejc`03o`000?n:R/goRX[=00;oRX[=00Go0000oj6FbOnQU/WoXIK9o`000005ok:Na0;o0000
1Oo3[/D2o`0000Kod[g500Go0000om[<bol0003ogl_4o`000003onOJb007o`000?o/jl_ok>_;o`00
0?oZn<So0000omkm_@03o`0000;oYLke00?o0000okKCkol000000_l000000onc^]oo0000ok^kfP03
ok^kfP;o00001OniZl`00ol0003o_:_8o`000003okJP`P03o`000?ngX<7o]j3100;o]j310_l00004
ok>I_003o`000?ncUk_o/iNk00;o/iNk0_l00004ok2C^@03o`000?n^T[Wo[Y:i00;o[Y:i00Ko0000
ojb@^Ol0003o0000ojb@^_l00004ojV?^P03o`000?nVSK_oYXfk00;oYXfk00?o0000oj:<_OnRS;d0
0_nRS;d3o`0000;oXXo100?o0000oif?a?nMSl@00onMSl@00ol0003oVHo7oiV?a`02oiV?a`05o`00
0?nFTLcoUY7<oiJAc?l000001?nBU=801?l0003oT9[Ioi2JfOn@V]T9o`0000?oXkc[00?o0000ok7:
kOl000000_l000000ondf?;o0000o`000005okkXlP;o00000onmi?83o`0000Oooooo0011ooooo`03
o`000?oooooooooo02oooooo00?o0000ok6igona^Ml01?na^Ml00ol0003od[[2o`000005om:ka003
o`000?oI^[_ofKZk00;ofKZk00?o0000omVl_OoI_;d00_oI_;d2o`0000?ofkbj00Go0000omg0_?oM
`;cogL2lo`000002omk3_P03o`000?oM`[ko000000?oglK000Go0000on7:`_oQb/;ohL[2o`000003
on?>``;o000000?oh]?9o`000?oTelX00_oTelX01?l0003oiMW:onGIb_l00003onGJbP04o`000?oU
fLWoiMW9o`0000;oi=O900Go0000omkFcooNe/oog]K?o`000003om_?c@05o`000?oHb<_o0000om38
d_l000001?o<_/d2o`0000;o_K7>1?l000001?lhIM?o0000o`000?l00003ofejc`03o`000?n:R/go
RX[=00;oRX[=00?o0000oj6FbOnQU/T00_nQU/T00ol0003o/Yk4ok:Na002o`000003okJYc?l0003o
`jk500?o`jk500?o0000olVkcOl000001OoB_LD01?l0003of/c;om[<booJc</2o`0000;oim[800Oo
0000onc[boo/jl_o0000on[hb?l0003og_fm00?o00000_nUc_D3o`0000Go/k[O00Ko0000ok^kf_l0
003o0000okBZcol00005okV[c0;o00001?nfX<800ol0003o]j31okNP`@02o`000003ok>I_Ol0003o
/iVl00?o/iVl00?o0000ok>G^oncUk/00_l000000onaU;Wo0000ok2C^@03ok2C^@03o`000?n^T[Wo
[Y:i00;o[Y:i0_l00003ojb@^P03o`000?nYSk[oZHnj00?oZHnj00?o0000ojJ=^onVSK/00_nVSK/4
o`000003ojF@_ol0003oXXo100?oXXo100?o0000oif?a?nMSl@00_nMSl@00ol0003oVHo7oiV?a`02
oiV?a`05o`000?nFTLcoUY7<oiJAc?l000000onBU=85o`0000;oVZKO00Ko0000oib`i_nL/>Ko0000
oib`i_l00003oj>lj`Co000000?o]=Sbo`000?l000000_n^jOT00ol0003o_^Sbo`000007o`0000;o
oooo00?o0000ooooooooool01Oooool004;ooooo00?o0000ooooooooool0;oooool00ol0003o/KWO
ok6ig`03ok6ig`;o00001OoB^l@00ol0003odKg7o`000002omVj^`03o`000?oI_;gofKbm00;ofKbm
00Ko0000omZo_ooJ_koo0000om^l^_l00004omg0_004o`000?oN`kkog/>nomk3_P;o00000_oOa/00
0ol0003ohL[2on7:`P02on7:`P06o`000?oSc/?ohlk3on?>`ol0003oi=;40ol000000ooTel[o0000
onGIbP02onGIbP04o`000?oUf/[oiM[:o`0000;oiMW900Co0000onCGbOoTelWoi=O90_l000000ooN
e/oo0000om_?c@02om_?c@04o`000?oHb<_of<S;omS8b`;o00000oo<_/d00ol0003oakK9o`000003
okfacP04o`000?l0?L7o0000o`0000;o>6GC00?o0000ofejcom]N/l00_m]N/l01Ol0003oRX[=ohZ:
cOn:R/go000000CoXIK900?o0000ok:Na?l000001?nfZL`01?l0003o`jk5ol>^aOl00003olVkc@05
o`000?oB_LGod[g5om:maOl000001?oJc</01Ol0003ohMkBo`000?oWf/So000000;ok>_;2Ol00003
ojRfh`03o`000?nc^]oo/k[O00;o/k[O0_l00004okBZc`03o`000?niZlco^J_<00;o000000?o/j34
o`000?nfX<800onfX<800ol0003o]j31o`000004ok>I_@03o`000?ncVKco/iVl00;o/iVl0_l00003
ok6D^@03o`000?n`TkWo/9>i00;o/9>i00?o0000ojjB^On^T[T00_l000000on^T[Wo0000ojb@^P03
ojb@^P03o`000?nYSk[oZHnj00;oZHnj00Co0000ojJ=^onVSK_oYXfk0_l00005ojF@_`05o`000?nR
Sl7oXXo1oj:?`Ol000001?nMSl@01?l0003oVHo7oiV?aonISlL9o`0000;oVZ3H00?o0000oiZVgonJ
Y]l00onJY]l00ol0003oW;3Voib`iP05o`0000?oZLkc0_l00004ojkYn@Go00001oooool00ol0003o
ooooooooo`05ooooo`00@oooool2o`00033ooooo00?o0000ok6igol000000_l000000on]^N?o0000
om:ka003om:ka007o`000?oA_LOodKg7om6maol0003ofKZko`000004omVl_@05o`000?oJ_koof[no
omZo_ol000001?oM`;`00ol0003og/>nomk3_P02omk3_P05o`000?oPal3o0000omo6`?l000000ooQ
b/801Ol0003ohlk3on?>`ooSc/?o000000;oi=;400?o0000onKEaOoVeLD00ol000001OoUfL[o0000
onGJb_oUf/[o000000;oiMW900Go0000onCGbOoTelWoi=O9o`000002on?Cb0?o000000?oflo=o`00
0?oHb</00_oHb</01_l0003odl78om?1b?l0003oc;k=o`0000?oakK900Ko0000okfac_l0003o^JS8
o`000?l0?L42o`0000;o>6GC1Ol00004ohZ:c@03o`000?nQU/WoXIK900?o00001OnfZL`00ol0003o
`jk5o`000005olVkc@03o`000?oB_LGo000000Cof/c;00Co0000on7Nd_oQg];ohMkB0_l000000oo/
jl_o0000o`000004o`0000;oVk3V00?o0000ojRfhonX]^<00onX]^<01_l0003o/k[Oo`000?l0003o
[ZSBo`0000Co]:[?00?o0000okV[c?l000001?ncX<@01?l0003o]Z32okJP`_nfX<82o`0000Go/iVm
00Co0000ok>I_?ncVKco/iVl0_l00005ok6D^@03o`000?n`TkWo/9>i00;o/9>i0_l00003ojjB^@03
o`000?n/T;[o[92j00;o[92j00?o0000ojV?^_nYSkX00_nYSkX01_l0003oYXfko`000?l0003oZ96n
o`0000GoYI2o00?o0000oj:?`OnRSl400_nRSl401?l0003oWHo4oif?a?nMSl@4o`0000;oX9[>00Go
0000oifLd_nMW=;oWIcBo`000005oiZPf004o`000?nJY]ooVZKOoiZVg`Co000000GoXlC`o`000?nS
a?3o0000ojW>l`03o`000003oj?Uo?l0003o[^Wi00Go00002_ooool00ol0003oooooooooo`05oooo
o`00AOooool00ol0003oooooooooo`0^ooooo`03o`000?n]^N?o[KWS00?o[KWS00Co0000om:ka?oB
^lCo00001OoA_LL00ol0003ofKbmomVl_@02omVl_@03o`000?oJ_koof[no00;of[no0_l00002omg0
_003o`000?oN`kkog/>n00;og/>n00Co0000on37`?oPal3oh<O00_l00002on7:`P05o`000?oSc/?o
hlk3on?>`ol000000_oTd/@01Ol0003oi]G5onKEaOoVeLGo000000;oimO50_l000000ooUf/[o0000
onGIb@02onGIb@04o`000?oTelWoi=O9o`0000?ohm?800Co0000on3?aooPclOo00000ooHb</00ol0
003odl78om?1b002om?1b003o`000?o7]/WoakK900?oakK900Oo0000okVXb?niZ<So^JS8o`000?l0
?L7o000000;o>6GC00Co0000ofAofOmTOmWoI7oI2?l00002oj>Qd`03o`000?nfZLco]ZW<00?o]ZW<
0_l00006olVkc@;o00001?oJc</01Ol0003ohMkBon7Nd_oQg];o000000;oiO7E00Ko0000omkncol0
003o0000ohjYj?l00004oi^`iP04o`000?nX]^?oZ;KSojRfh`?o00001?n^Z=801?l0003o]:[?okBZ
condZ/l2o`0000Go/j3400Ko0000okJP`_nfX<;o0000ok:I__l00005ok>I_@06o`000?ncVKco/iVl
o`000?naUK[o00001OnaU;T01?l0003o/9>iok2C^On`TkT2o`0000Go[Y:i00Go0000ojb@^_n/T;[o
[92jo`000004ojV?^P;o00001?nXTKh00ol0003oYI2oojF@_`02ojF@_`03o`000?nRSl7oXXo100;o
XXo100Ko0000oif?a?l0003o0000oj>Ib_l00005oj2JcP05o`000?nMW=;oWIcBoifLd_l000001?nJ
X=P4o`0000;oX[_[00Go0000oj?4l?nSa?3o0000oj?4l003o`0000;oXnGl1Ol0000=ooooo`03o`00
0?oooooooooo00Gooooo0016ooooo`03o`000?oooooooooo02kooooo00?o0000ojfihon]^N<00_n]
^N<00ol0003od[_4o`000005om6ma`03o`000?oA_lWo000000;ofKbm00?o0000omZo_ooJ_kl00_oJ
_kl01_l0003ofl;1om_2`Ol0003ogL2lo`0000Cog/>n00Wo0000on37`?oPal3oh<O0o`000?oRbl7o
0000on7:`_l000000_oSc/<01Ol0003oi=;4onCBa?oTd/Co000000;oi]G500Ko0000onOGaOoWelGo
imO5o`000?oWelD3o`000003onGIbOl0003oi=O900;oi=O900Co0000on?Cb?oSdlSo00000ooPclL2
o`000003omS8bol0003odl7800Codl7800?o0000olNfbOo7]/T00_o7]/T2o`0000Co^JS81?l00000
0olhIM?o0000ofAof@02ofAof@05o`000?n8TmSoR9?HohRCf?l000001OnSXM<01ol0003o]ZW<okJY
c?nfZLco0000ok^ge_l000001Oo9^ld00ol0003odLgFo`000003om[<b`05o`000?oQg];ohMkBon7N
d_l000000_oUlMD01?l0003og_k?o`000?l00003ohjYj003o`000?nK/>KoVk3V00Go00000_nVYM@0
0ol0003o[ZSBojjXdP02ojjXdP06o`000?ndZ/oo0000o`000?n_WlKo00001OncX<@00ol0003o]Z32
o`000003ok:I_P03o`000?ncVKgo/iVm00?o/iVm0_l00003ok6E^P03o`000?naU;Wo/IBi00;o/IBi
00Ko0000ok2C^On`TkWo0000ojnC^_l00005ojjB^@03o`000?n/T;[o[92j00;o[92j1?l000000on[
T[go0000ojRA_P03ojRA_P03o`000?nUT;ooYI2o00?oYI2o00?o0000oj:?`OnRSl400ol00004oj>I
bP03o`000?nPV/koX9[>00;oX9[>00Ko0000oifLd_nMW=;oWIcBo`000?nJX=P3o`000003oj:ei_l0
003oX[_[00CoX[_[00Co0000oj?4l?l0003o00000_nMhOd5o`00013ooooo00?o0000ooooooooool0
1Oooool004Oooooo00?o0000ooooooooool0;_ooool00ol0003o[KWSojfih`03o`0000GodKg700Oo
0000om6obOoA_lWodKo9o`000?oI_;go000000?of[no00?o0000om_2`OoK`/400_oK`/400ol0003o
g/>nomk3_P02omk3_P05o`000?oPal3oh<O0on37`?l000000ooRbl42o`000003on?>`ol0003oi=;4
00;oi=;400Go0000onKEaOoVeLGoi]G5o`000002onOGa@04o`000?oWelGoimO5o`0000;oimO50ol0
00001OoTelWo0000on?Cb?oSdlSo000000?oh<o700Co0000omg9a_oMbLKo00001OoC`LP00ol0003o
c[W6o`000002olNfb@04o`000?o2[LKo`Zg6o`0000?o^JS80ol000001?lJHmSo0000o`000?l00003
ofAof@05o`000?n8TmSoR9?HohRCf?l000001OnSXM<00ol0003o]ZW<o`000003ok^geP05o`000?o9
^lgobK_=olVkcOl000000ooAcMH00ol0003of/c;o`000003on7NdP05o`000?oUlMGoiO7Eo`000?oN
o/l02Ol00002oifPeP03o`000?nVYMCoYZGD00?oYZGD00Co0000ojjXd_n^Z=;o[ZSB0_l00004ojnO
aP03o`000?ncX<Co/j3400;o/j340_l00004ok:I_P03o`000?ncVKgo/iVm00;o/iVm0_l00004ok6E
^P03o`000?naU;Wo/IBi00?o/IBi0_l00003ojnC^P03o`000?n^T[Wo[Y:i00;o[Y:i00Co0000ojb@
^_n/T;[o[92j0_l00005oj^B_@05o`000?nXTKkoZ96nojRA__l000001?nUT;l4o`0000;oYYW700?o
0000oj>Ib_nSVLX00_nSVLX00ol0003oX9[>oj2JcP02oj2JcP03o`000?nMW=;oWIcB00?o00001OnR
]NH01?l0003oX[_[oj:kjonR^n/3o`000004oigQoOl0003o0000o`0001Kooooo00?o0000oooooooo
ool01?ooool004Sooooo00?o0000ooooooooool0;_ooool2o`0000?oYk[W00Go0000om6maooA_LOo
dKg7o`000005om6ob@05o`000?oJ_koof[noomZo_ol000001OoK`/42o`0000;og/>n00Go0000on37
`?oPal3oh<O0o`000004on;;`@04o`000?oSc/?o0000o`0000;oi=;400Go0000onKEaOoVeLGoi]G5
o`000002onOGa@04o`000?oWelGoimO5o`0000?oimO500?o0000onKEaOoVeLD00_l000000ooSdlSo
0000on3?a`02on3?a`04o`000?oMbLKogLW6omg9aP;o00000ooC`LP01_l0003oc[W6oljia_l0003o
akK9o`0000Co`Zg600?o0000okVXb?l000000_ndXL@2o`0000?o6V?H0_l000000omTOmWo0000ohRC
f003ohRCf003o`000?nSXM?oXj7C00;oXj7C0_l00005ok^geP03o`000?o9^lgo000000GodLgF0ol0
00001_oQg];o0000onGaeOoUlMGo0000omknc`;o00000_n;U=L01Ol0003oU9_GoiBKeonDVmOo0000
00CoWJ3F00?o0000ojJUe?nVYM@00_nVYM@01_l0003o[ZSBo`000?l0003oZYg8o`0000Go[io600Ko
0000ok>Pa?ncX<Co0000ojnI`?l00005ok:I_P06o`000?ncVKgo/iVmo`000?n`U[_o00001OnaUKX0
1?l0003o/IBiok6D^OnaU;T2o`0000Co[i>j00?o0000ojjB^On^T[T00on^T[T3o`000003ojfD_?l0
003oZi:m00CoZi:m00?o0000ojRA__nXTKh00_nXTKh4o`000003ojVIa_l0003oYYW700CoYYW700Go
0000oj>Ib_nSVL[oXiW:o`000003oj2JcPCo00000onT/>401?l0003oX[GVoj:ei_nR]NH5o`000004
oigNoOl0003o0000o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04oooo
o`00BOooool2o`0002oooooo00?o0000ojNjionW^^L00_nW^^L00ol0003odKg7o`000005om6ob@;o
00000ooJ_kl00ol0003ofl;1om_2`@02om_2`@06o`000?oLa/?og<K3o`000?oN`kko00000_oPal00
0ol0003oh/_1on;;`@02on;;`@08o`000?oSc/?ohlk3o`000?oUd/Co0000onCBa?l00002onKEa@04
o`000?oWelGoimO5o`0000?oimO500Co0000onOGaOoWelGo00000ooVeLD01?l0003oiM?4o`000?l0
0003on3?a`04o`000?oMbLKogLW6o`0000;ofL?500?o0000om?1b?l000001?o>^LH00ol0003o`Zg6
ol:]aP03ol:]aP;o00001?ndXL@2o`0000;o6V?H00Co0000oe:6iOl0003o00001?n8TmP00ol0003o
Xj7Co`000002o`000003ojF`gol0003o^kOF00Co^kOF0_l00005om7=eP03o`000?oGh]ooen;O00?o
000000?oiO7Eo`000?l000000_l00004oh^De`05o`000?nDVmOoU9_GoiBKeol000000onMX=H01?l0
003oYZGDojJUe?nVYM@3o`0000CoZYg800?o0000ojnOa_n_WlH00_n_WlH00ol0003o/j34o`000003
ojnI`003o`000?nbVKko/YVn00;o/YVn00?o0000ok>I_Ol000000_n`U[/00ol0003o/IFjok6E^P03
ok6E^P06o`000?naU;Wo/IBio`000?n`U;[o00001On_TkX01?l0003o[Y:iojjB^On^T[T2o`0000Co
[IBl00?o0000oj^B_On[T[d00_n[T[d01?l0003oZ96nojRA__nXTKh2o`0000GoZIW600?o0000ojJI
aonVVLL00_nVVLL00ol0003oXiW:oj>IbP05o`0000;oYjkL00?o0000ojB`hOnT/>400_nT/>44o`00
00?oWm_l0ol00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool004_o
oooo00?o0000ooooooooool0;Oooool00ol0003oYk[WojNji`03o`0000GodKo900Ko0000om73c?oA
`lco0000omZo_ol00004om_2`@03o`000?oLa/?og<K300;og<K300Go0000on37`?oPal3oh<O0o`00
0003on;;`@04o`000?oSc/?ohlk3o`0000?oiM;40ol000001OoVeLGo0000onOGaOoWelGo000000;o
imO500Go0000onOGaOoWelGoimO5o`000002onKEa@08o`000?oUdlCoiM?4o`000?oSclCo0000on3?
aol00002omg9aP03o`000?oI`lGofL?500;ofL?500?o0000oljia_o>^LH00_o>^LH2o`0000?o`Zg6
0_l000000onmY/?o0000okBQa003okBQa006o`000?n/VlKo0000o`000?lJHmSo00000_mBQ^D6o`00
00GoYK3O00?o0000ok^ge_nk]mH00_l00002ol7;hP05o`000?oAcMKodLgFom7=e_l000000_oGh]l0
1?l0003oe_ORomKgh_oFmn85o`0000CoRiCG00Go0000oiBKeonDVmOoU9_Go`000002oifPePGo0000
0_nTV/X00ol0003oZYg8ojZMb002ojZMb003o`000?n_WlKo[io600;o[io60_l00004ojnI`003o`00
0?nbVKko/YVn00;o/YVn0_l00004ok2F^`03o`000?naUK[o/IFj00;o/IFj00?o0000ok6D^Ol00000
0_n`U;X00ol0003o[i>jojnC^P03ojnC^P06o`000?n^T[Wo[Y:io`000?n_U[go00001?n]U;`00ol0
003oZi:moj^B_@03oj^B_@?o000000?o[9[5o`000?nYVLH01?nYVLH00ol0003oYYW7ojJIa`02ojJI
a`?o00000_nZ[MT00ol0003oYjkLojN^g003ojN^g004o`000?nT/>7o0000o`0000;oXm[k00?o0000
oioKo?l000000_l00009ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool0
04cooooo00?o0000ooooooooool0;Oooool2o`0000?oX[_[00Go0000om6obOoA_lWodKo9o`000004
om73c003o`000?oK`/7ofl;100;ofl;100?o0000omc6`ooLa/<00ooLa/<2o`000003on37`?l0003o
h/_100;oh/_100Go0000on?>`ooSc/?ohlk3o`000003onGBa003o`000?oVe<Coi]C400;o000000Go
imO5o`000?oWelGoimO5o`000003onOGa@04o`000?oVeLGoi]G5o`0000;oiM?400Go0000on??a?oS
clCohlo4o`000003omg9aP04o`000?oI`lGofL?5omW3a@;o00000oo>^LH01_l0003obK;3olVb`ol0
003o`Zg6o`0000Co_JK300Co0000okBQa?ndXLCo]:741_l00002oe:6i@03o`000?n3X>KoPj3V00;o
Pj3V00?o0000ojF`gonU/=l00onU/=l00ol0003o^kOFo`000005ol7;hP03o`000?oAcMKo000000;o
en;O00Co0000omKgh_oFmn;oe_OR4Ol00002oijFc003o`000?nTV/[oY9[:00?oY9[:00Ko0000ojZM
b?nZWLSoZYg8o`000?n_WlH3o`000003ojbH`_l0003o[iW000?o[iW000?o0000ok:I__nbVKh00_l0
00000on_U[co0000ok2F^`03ok2F^`03o`000?naUK[o/IFj00;o/IFj0_l00004ok2D^P03o`000?n_
Tk[o[i>j00;o[i>j00?o0000ojjB^Ol000000_n_U[d00ol0003o[IBlojfD_003ojfD_004o`000?n[
T[goZi:moj^B_@;o00001?n/V/D00ol0003oZIW6ojVIaP02ojVIaP03o`000?nVVLOo000000;o0000
00?o[JgGo`000?nZ[MT00onZ[MT01?l0003oYjkLojN^g?nW[]`3o`0000?oXm[k0ol0000=ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool004gooooo00?o0000ooooooooool0
;Oooool00ol0003oX[_[oj:kj`02oj:kj`03o`000?oA_lWo000000CodL?<00?o0000om76col00000
0ooK`/400ol0003og<K3omc6``02omc6``03o`000?oMbLGogLW500;o00000ooRbl401?l0003ohlk3
on?>`ol00003onGBa006o`000?oVe<Coi]C4onKDa?l0003oimK50ol000001OoWelGo0000onOGaOoW
elGo000000;oi]G500Go0000onGCa?oUdlCoiM?4o`000003on??a0;o000000?ogLW6o`000?oI`lD0
0_oI`lD01_l0003oe;g3omBm`ol0003oc[W6o`0000CobK;300?o0000okfV`onmY/<00onmY/<01_l0
003o]:74okBQa?l0003o/9[1o`0000;oZ9G11?l000000omBQ^Go0000oh>PiP03oh>PiP03o`000?nU
/=ooYK3O00;oYK3O0_l00006ol7;hP?o000000?oen;Oo`000?oFmn800_oFmn84o`0000?oRhW<00?o
0000oi2=c?n@SL`00_n@SL`01Ol0003oUi;<oiNBc?nGT/co000000CoWYK<00?o0000ojBJb_nTV/X0
0_nTV/X01?l0003oZYg8ojZMb?nZWLP2o`0000Go[9S200?o0000ojnI`?n_VL000_n_VL02o`0000?o
[iJl00?o0000ok2F^on`U[/00_n`U[/00ol0003o/IFjok6E^P02o`000003ok2E^ol0003o/9Bj00?o
/9Bj00?o0000ojnC^_n_TkX00_n_TkX2o`0000Co[iJm00?o0000ojfD_?n]U;`00_n]U;`01_l0003o
Zi:mo`000?l0003o[ic4o`0000Go[9[500Co0000ojVIa_nYVLKoZIW60_l00005ojf]e`04o`000?nZ
[MWoZZgIojZ]f@Co00000_nVf_X4o`00013ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`00C_ooool2o`0002kooooo00?o0000oj:kjonR^n/01?l00003om73c007o`000?oA
a/oodLK?om76col0003ofl;1o`000004omc6``09o`000?oMbLGogLW5omg9aOl0003oglg7o`000?oR
bl7o000000;ohlk300Go0000onGBa?oUd/CoiM;4o`000003onKDa004o`000?oWe/GoimK5o`0000;o
imO50ol000001OoWelGo0000onKEaOoVeLGo000000;oiM?400Go0000on??a?oSclCohlo4o`000002
on3;``05o`000?oI`lGofL?5omW3aOl000001?oD_L<00ol0003obK;3olVb``02olVb``;o00001Onm
Y/<00ol0003o]:74o`000003ok2J`@04o`000?nXUL7oZ9G1ojRE`@Go00001?n3X>H01?l0003oYK3O
o`000?l00002ojG4k`04o`000?o1bn;o`L_Rol7;hP;o00000_o3hnl4o`000003omKgh_l0003o0000
00?oQhG;00Go0000oh^9c?n;RLcoRhW<o`000004oi2=c005o`000?nGT/coUi;<oiNBc?l000001?nN
U/`01_l0003oY9[:ojBJb_nTV/[o0000ojZMb0;o000000?oZ9K3o`000?n/V<801?n/V<801?l0003o
[iW0ojnI`?n_VL02o`0000Go[iJl00?o0000ok2F^on`U[/00_n`U[/2o`0000?o/9Fk00?o0000ok2D
^_n`U;X00_n`U;X00ol0003o[i>jojnC^P02o`000003ok2G_Ol0003o[iJm00?o[iJm00?o0000ojfD
_?n]U;`00_n]U;`2o`0000Co[ic400?o0000ojbJaOn/V/D00_n/V/D01_l0003oZIW6o`000?l0003o
/:kFo`0000Go[JgG00Co0000ojZ]fOl0003o00000_nYg?T01?l0003oY][jo`000?l0000Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0053ooooo00?o0000ooooooooool0
;?ooool2o`0000CoW;g_00?o0000om73c?l000001OoAa/l2o`0000?og<K300Go0000omg9aOoMbLGo
gLW5o`000003omo=a`?o000000?ohlk3o`000?oUd/@00_oUd/@01?l0003oi]C4onKDa?l00002onOF
a@05o`000?oWelGoimO5onOGaOl000000_oWel@2o`000005onKEaOl0003oiM?4onGCa?l000000ooS
cl@01?l0003oh<_3on3;`ooPbl<2o`000003omW3aOl0003oe;g300Coe;g300Go0000olVb`oo9//?o
bK;3o`000002olB/`P03o`000?nmY/?o_JK300;o_JK30_l00004ok2J`@04o`000?nXUL7oZ9G1ojRE
`@?o00000_lbR^d6o`0000GoYLC_00?o0000ol7;h_l000000_o3hnl2o`0000?o^?O`1?l00003ohN5
b`03o`000?n;RLcoRhW<00;oRhW<00Go0000oi2=c?n@SLcoT8g<o`000003oiNBc003o`000?nNU/co
WYK<00;oWYK<00?o0000ojBJb_nTV/X00ol00004ojRF``03o`000?n/V<;o[9S200;o[9S200Ko0000
ojnI`?l0003o0000ojfE__l00005ojnF_004o`000?n`U[_o/9Jkok2F^`;o00001On`UK/00ol0003o
/9Bjok2D^P02ok2D^P;o00001?n`Ukd01Ol0003o[iJmojnF_On_U[go000000;o[IBl0_l000000ona
W/Co0000ojnLa003ojnLa003o`000?n/V/Go[9[500;o[9[50_l00004ok2^eP03o`000?n][MOo[JgG
00;o[JgG0_l00003ojWLn@?o00006?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo001Aooooo`03o`000?oooooooooo02gooooo00?o0000oibmkonL_Nl00ol00005om76c`06
o`000?oBb];od/[Bo`000?oLa/?o00000ooMbLD00ol0003oglg7omo=a`02omo=a`03o`000?oQdLSo
hM7800?o000000GoiM;4o`000?oVe<Coi]C4o`000002onOFa@05o`000?oWelGoimO5onOGaOl00000
0ooWel@00ol0003oimG4o`000002o`000005onGCa?l0003ohlo4on??a?l000000ooPbl<01?l0003o
g<K3omc6`ol00005omBm``05o`000?o?]l;o0000olVb`ol000001?o4[<801_l0003o_JK3okfV`ol0
003o^:30o`0000Co/9[100Co0000ojRE`OnXUL7oZ9G11ol00004ogJ`m`04o`000?nUa>ooYLC_ojG4
k`Co000000?o`n?_o`000?nhmo000_nhmo05o`000005ohF3bOl0003oQhG;ohN5bol000001?n;RL`0
1Ol0003oT8g<oi2=c?n@SLco000000?oUi;<00Co0000oijFc?nNU/coWYK<1?l00002oj>Ca003o`00
0?nXU/?oZ9K300;oZ9K300?o0000ojbH`_n/V<800_n/V<82o`0000Co[IFn00?o0000ojnF_?n_U[`0
0_n_U[`01_l0003o/9Jkok2F^ol0003o/9Jlo`0000Go/9Fk00Co0000ok2D^_n`U;[o/9Bj0_l00005
ok2G_@03o`000?n_U[go[iJm00;o[iJm0_l00004ok6Na006o`000?n_W<Co[ic4ojnLa?l0003o[9[5
0ol000000onc/MKo0000ok2^eP03ok2^eP03o`000?n][MOo000000;o000000?o[>3io`000?l00000
0_l0000Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool005;ooooo00?o
0000ooooooooool0;Oooool2o`0000?oU[oc00Go0000om76cooAa/oodLK?o`000004om;:dP;o0000
0ooMbLD01Ol0003oglg7omo=aooOcLOo000000?ohM7800?o0000on;DbOoRe<T00_l000000ooVe<Co
0000onOFa@02onOFa@04o`000?oWelGoimO5o`0000?oimO400Co0000onOEa?oWeLCo00000_oVdl@2
o`000003on??a?l0003oh<_300;oh<_300Co0000omc6`ooLa/?og<K30_l00003omBm``05o`000?o?
]l;ockO2olng`_l000001Oo4[<800ol0003o_JK3o`000003okRP`003o`000?n`V/7o/9[100;o/9[1
0ol000000onVT;oo0000oin;_`02oin;_`[o00000onKfod4o`000003okSgl?l0003o000000;o0000
0_n9PL<Eo`0000;oWI3500?o0000oj>Ca?nSTl@00_nSTl@00ol0003oZ9K3ojRF``02ojRF``06o`00
0?n/V<;o[9S2o`000?nZU;oo00001?n]UKh00ol0003o[iJlojnF_003ojnF_0;o00000on`U[`00ol0
003o/9Fkok2E^`02ok2E^`06o`000?n`U;[o/9Bjo`000?naV;ko00001On`Ukd01?l0003o[iJmojnF
_On_U[d2o`0000Go/Ik400Co0000ojnLa?n_W<Co[ic40_l00005ok>aeP04o`000?n`[]Ko/:kFok2^
eP?o000000?o[>3io`000?l000008?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00?ooooo001Cooooo`;o0000;oooool01ol0003oU[ocoiJolonF_o?o0000om76col000001?oBb]80
1_l0003odlkDom?>e?l0003ogLW5o`0000?oglg700Go0000on7Ab?oQdLSohM78o`000003on;Db@03
o`000?oSe/Wo000000;o000000?oimK5o`000?oWelD00_oWelD01?l0003oimO4onOGa?l00002onOE
a006o`000?oVdlCoi]?4onKCa?l0003oi=340_l00003on3;``04o`000?oLa/?og<K3o`0000;ofL72
00?o0000omBm`ol000001?o?]l800ol0003oa:c2olB/`P03olB/`P;o00001?nhX<001?l0003o/9[1
ok2J`On`V/42o`0000CoYY2o00Co0000oin;_onORkooWh^o1?l00004oeJkn`04o`000?nKfogo0000
o`0000;oN^;b1?l00003ohUo`P04o`000?n9PL?oRH73o`0000?oRh;400?o0000ohj5aOn>QLD00_n>
QLD01Ol0003oThW5oi>9aOnCRLGo000000?oV8c600?o0000oif@aOnMT<D00onMT<D01Ol0003oXi?4
oj>Ca?nSTlCo000000CoZ9K300?o0000ojbH`_l000000onZU;l00ol0003o[IFnojfE_P02ojfE_P04
o`000?n_U[co[iJlojnF_0;o00001?n`U[`00ol0003o/9Fkok2E^`03ok2E^`;o00000onaV;h00ol0
003o/9Nmok2G_@03ok2G_@?o000000?o/j35o`000?naW/@01?naW/@01_l0003o[ic4o`000?l0003o
][CGo`0000Go/k7F00Co0000ok2^e_l0003o00000_n]iOT2o`0002?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`00EOooool00ol0003oooooooooo`0]ooooo`Ko00000ooB
b]801?l0003odlkDom?>e?oCc]@3o`0000?oglg700Co0000on7Ab?oQdLSo00000ooRe<T01?l0003o
hmK9on?FbOl00002onCHb@?o000000GoimO5o`000?oWelCoimO4o`000002onOEa005o`000?oVdlCo
i]?4onKCa?l000000_oTd<@01Ol0003oh/g3o`000?oPbl?o000000;og<K300?o0000omW1`_oI`L80
0_oI`L800ol0003ockO2olng`P02olng`P03o`000?o:/L7o000000?oa:c200?o0000oknV`?l00000
1?nhX<001_l0003o/9[1o`000?l0003o[IJoo`0000CoYY2o00Go0000oin;_onORkooWh^oo`000003
oiV7_`[o00000on;P<401Ol0003oRGo2ohUo`_n9Ol;o000000?oRH7300Go0000oh^2a?n;P/CoRh;4
o`000004ohj5a@05o`000?nCRLGoThW5oi>9aOl000000onHS<H00ol0003oWI35oif@a@02oif@a@05
o`000?nSTlCoXi?4oj>Ca?l000000onXU/<3o`0000CoZYBo00?o0000ojfE__n]UKh00_n]UKh01_l0
003o[iJlo`000?l0003o[YJmo`0000Co/9Jl00?o0000ok2E^on`UK/00_n`UK/2o`0000Co/IRn00?o
0000ok2G_On`Ukd00_n`Ukd2o`0000Co/j3500?o0000ok6Na?naW/@00_naW/@2o`0000Co][CG00?o
0000ok>ae_nc/MH00_nc/MH2o`000004ojgUnOl0003o0000o`0002Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`0/ooooo`03o`000?nB
`OOoT/7g00?oT/7g00?o0000om;:d_l000000ooCc]@01ol0003oe=7GomCAeooDdMOo0000omo=aol0
00000_oQdLP01Ol0003oh]C9on;DbOoRe<Wo000000;ohmK900Go0000onCHbOoTf<Woi=S9o`000002
onGHb@;o000000?oimO4o`000?oWeL@00_oWeL@01?l0003oi]?4onKCa?l00002onC@a005o`000?oR
cL?oh/g3on;=`ol000000ooLa/<00ol0003ofL72omW1`P02omW1`P05o`000?o?]l;ockO2olng`_l0
00000oo:/L400ol0003oa:c2o`000003oknV`004o`000?nhX<3o^:30okRP`0;o00001?n]U[l01Ol0
003oYY2oojJ@_onVT;oo000000CoWh^o00Go0000oiV7_onIQkooVHNoo`000003oi>4`003o`000?n?
PL7oSh7100;oSh7100Co0000oh^0`On;P<7o00000on9Ol801Ol0003oRH73ohV1`on9PL?o000000?o
Rh;400?o0000ohj5aOn>QLD00_n>QLD01Ol0003oThW5oi>9aOnCRLGo000000CoV8c600Go0000oif@
aOnMT<GoWI35o`000002oj>Ca0Go00000_nVT/400ol0003oZYBoojZD_`02ojZD_`03o`000?n]UKko
[IFn00;o[IFn0_l00004ojjF_@03o`000?n`U[co/9Jl00;o/9Jl1?l000000onaVKoo0000ok6H_P03
ok6H_P03o`000?n`Ukgo/9Nm00;o000000?o]:;6o`000?ncX<D00oncX<D00ol0003o/Ik4ok6Na002
o`000003okVhf?l0003o][CG00?o][CG00?o0000ok>ae_l000001Ol0000Yooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool005Oooooo00?o0000ooooooooool0;?ooool01?l0
003oT/7goi;1monB`OL3o`0000?odlkD00?o0000omCAeooDdML00_oDdML3o`000003on7Ab?l0003o
h]C900;oh]C900Co0000on?FbOoSe/Wo00000ooTf<T01_l0003oiMS9onGHbOoUf<Wo0000onGHb@?o
000000GoimG4o`000?oVdlCoi]?4o`000002onC@a003o`000?oRcL?oh/g300;oh/g30_l000000ooL
a/?o0000omW1`P03omW1`P05o`000?oD_<;o0000olng`_l000001Oo:/L400ol0003o_jK0oknV`002
oknV`006o`000?nhX<3o^:30o`000?ncVkoo00001?n]U[l00ol0003oYY2oojJ@_`02ojJ@_`03o`00
0?nORkoo0000017o000000?oRh31o`000?n9Ol800_n9Ol801?l0003oRH73ohV1`ol00004oh^2a005
o`000?n>QLGoSXG5ohj5aOl000000onCRLD00ol0003oV8c6oiR<aP02oiR<aP03o`000?nMT<GoWI35
00Co00000_nRT<800ol0003oYY;1ojJB`@03ojJB`@03o`000?nZU;ooZYBo00;oZYBo1?l000000on/
UKoo0000ojjF_@03ojjF_@04o`000?n`U[co/9Jlok2F_0;o00001OnaVKl00ol0003o/IRnok6H_P02
ok6H_P;o00001?ndX/H01ol0003o/j35ok>PaOncX<Go0000ok6Na?l000001?ni^=P01?l0003o][CG
okJdeonf]=L5o`0002gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`00
F?ooool2o`0002gooooo0ol00003oho4n@03o`000?oCc]Co000000Coe=7G00Co0000omGEf?oEeMSo
eMGH0ol000000ooRe<Wo0000on?Fb@02on?Fb@04o`000?oTf<Woi=S9o`0000?oiMS900Co0000onGH
bOoUf<Wo00000_oUelP2o`000003onKCa?l0003oi=3400;oi=3400Go0000on;=`ooRcL?oh/g3o`00
0002omo9``;o00000ooI`L801Ol0003oe;c2omBl`_oD_<;o000000Kob[7100?o0000oknV`?noY/00
0_noY/000ol0003o^:30o`000003ok>K_`05o`000?n]U[oo[IJoojfF_ol000000onVT;l3o`0000;o
WHVm00?o0000oiR5_OnHQKd00_nHQKd01Ol0003oTh:noi>2__nCP[ko000000?oT82n00?o0000oheo
_on=Okl03_l00004ohj5a@05o`000?nCRLGoThW5oi>9aOl000000_nHS<H4o`0000;oWHg200?o0000
oj:@`_nRT<800_nRT<800ol0003oYY;1ojJB`@02ojJB`@04o`000?nZU;ooZYBoojZD_`;o00001On/
UKl01Ol0003o[YJmojjF_On^U[go000000;o/9Jl00?o0000ok6J`Ol000001OnaVKl01?l0003o/IRn
ok6H__naV;h2o`0000Go]:;600Co0000ok>PaOncX<Go/j350_l00005okVhf003o`000?nf]=Oo0000
00?o0000<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo001Jooooo`03
o`000?oooooooooo02cooooo00?o0000oho4nOn?a?T01?l00003omCAe`05o`000?oEeMSoeMGHomGE
f?l000000ooGf=T3o`000003on?FbOl0003oi=S900;oi=S900Co0000onGHbOoUf<Wo00000_oUf<T0
1_l0003oiMO8onGGb?oUelSo0000onCFb0?o000000?oi=34o`000?oRcL<00_oRcL<02Ol0003oglW3
omo9`ooObL?o0000om_5`ol0003ofL72o`000004omBl`P03o`000?o:/L7ob[7100?ob[7100?o0000
olF/`Ol000000onoY/02o`0000Co/i^o00?o0000ojfF_on]U[l00_n]U[l3o`000003oj>=_Ol0003o
WHVm00?oWHVm00Go0000oiR5_OnHQKgoV8Fmo`000003oi>2_P05o`000?n@P;koT82noi20__l00000
0on=Okl01Ol0003oS7noohao_on<Okoo000000?oS83100Co0000ohj2`On>P/7oSX;13?l00002oiV:
``03o`000?nMSL;oWHg200;oWHg200Go0000oj:@`_nRT<;oXY32o`000004ojJB`@06o`000?nZU;oo
0000o`000?nZU<3o00001On/UKl00ol0003o[YJmojjF_@02ojjF_@;o00000onaV/400ol0003o/IVo
ok6I_`02ok6I_`06o`000?naV;ko0000o`000?neY<So00001OndX/H01_l0003o/j35o`000?l0003o
^kgKo`0000Go^KSH1?l0000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool005_ooooo00?o0000ooooooooool0;?ooool3o`0000?oS/Sk00?o0000omCAeol000000ooEeMP0
1Ol0003oemSIomOHfOoGf=Wo000000?of=_I0ol000001OoTf<Wo0000onGHbOoUf<Wo000000;oiMS9
00Go0000onGGb?oUelSoiMO8o`000002onCFb003o`000?oSdlSohm?800;o00000ooRcL<01?l0003o
glW3omo9`ol00003om_5``03o`000?oD_<;oe;c200;oe;c200?o0000olng`_l000000oo:/L401?l0
003oaJc1olF/`Ol00002oknV`003o`000?njXKoo000000Co/i^o00Co0000ojfF_on]U[oo[IJo0_l0
0004oj>=_@05o`000?nMRKgoWHVmoif9_Ol000001?nHQKd01Ol0003oTh:noi>2__nCP[ko000000?o
T82n00Go0000oheo_on=OkooSGnoo`000003ohao_`05o`000?n<P<7oS831ohb0`Ol000000on>P/40
1Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o0000oiV:`onIR/<00onIR/<01Ol0003oWHg2oif=
`_nMSL;o000000?oXY3200?o0000ojJB`OnVT/400_nVT/42o`0000CoZYC000?o0000ojbE_on/UKl0
0_n/UKl01?l0003o[YJmojjF_On^U[d2o`0000Co/I[100?o0000ok6I_onaVKl00_naVKl2o`0000Co
]JC800?o0000okBRa_ndX/H00_ndX/H2o`0000Co^kgK00?o0000okVhf?l000001?l0000fooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool005cooooo00?o0000ooooooooool0
;_ooool7o`000003omGEf?l0003oemSI00;oemSI00?o0000omSKfOoHfmT00_oHfmT00ol0003of]cI
om[Lf@02o`000003onGHbOl0003oiMS900;oiMS900Co0000onGGb?oUelSo00000_oTe/P02Ol0003o
hm?8on?Cb?oSdlSo0000on7@aol0003oh/g3o`000002omo9``03o`000?oKaL?oflG300;oflG300Go
0000omBl`_oD_<;oe;c2o`000003olng`P03o`000?o:/L7o000000?oaJc100?o0000oknV`?l00000
0onjXKl00ol0003o/i^ook>K_`02ok>K_`?o000000?oZI:no`000?nSSKd00onSSKd00ol0003oWHVm
oif9_@02oif9_@05o`000?nHQKgoV8FmoiR5_Ol000000onCP[h01Ol0003oT82noi20__n@P;ko0000
00?oSGno00Go0000ohao_on<OkooS7noo`000003ohb0`@03o`000?n>P/7oSX;100;oSX;100Go0000
oi64`_nAQ<;oTHC2o`000003oiB7`P03o`000?nIR/?oVH[300;oVH[300Go0000oif=`_nMSL;oWHg2
o`000004oj:@`PCo000000?oYY?1o`000?nZU<000onZU<000ol0003o[9FoojbE_`03ojbE_`?o0000
00?o/9_2o`000?naV/401?naV/401_l0003o/IVook6I_ol0003o]JO:o`0000Go]JC800Ko0000okBR
a_l0003o0000okg2g_l00004ok^mf`Co0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo001Mooooo`;o0000<?ooool00ol0003oSlcloho<o005o`000003omOHfOl0003o
f=_I00?of=_I00Co0000om[LfOoJg=Wo00000_oKgMP3o`000003onGHbOl0003oiMO800;oiMO800?o
0000onCFb?l000000ooSdlP01Ol0003ohM37on7@aooQd<Oo000000?oglW300Wo0000om_5`ooKaL?o
flG3o`000?oG`L?o0000omBl`_l000001?o?]l82o`0000GoaJc100?o0000okZQ_onjXKl00_njXKl0
1?l0003o/i^ook>K_oncVkl2o`0000CoZI:n00?o0000oj>=_OnSSKd00_nSSKd01Ol0003oWHVmoif9
_OnMRKgo000000?oV8Fm00Go0000oi>2__nCP[koTh:no`000003oi20_P05o`000?n=OkooSGnooheo
_ol000000on<Okl00ol0003oS831ohb0`@02ohb0`@05o`000?n>P/7oSX;1ohj2`Ol000000onAQ<80
1Ol0003oU8O2oiB7`_nDQl;o000000CoVH[300?o0000oif=`_nMSL800_nMSL800ol0003oXY32o`00
0002o`0000GoYY?100Go0000ojZD`?nZU<3oZYC0o`000004ojbE_`;o00001?n`Vl800ol0003o/I[1
ok6J`@02ok6J`@03o`000?naVKoo000000?o]JO:00?o0000okFTb?neY<P00_neY<P2o`0000Co_L;N
00?o0000ok^mfol000000ol0000mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool005oooooo00?o0000ooooooooool0;_ooool3o`0000;oTm3m1?l00003omSKf@04o`000?oJ
g=Wof]cIo`0000?ofmgH00?o0000omcLeooLg=L00ol000001OoUelSo0000onCFb?oTe/So000000;o
hm?800?o0000on7@aooQd<L00_oQd<L2o`000003omo9`ol0003oflG300;oflG300Go0000omO1`ooG
`L?oel73o`000004olng`P03o`000?o;//;o000000CoaJc10_l00004okZQ_`06o`000?ncVkoo0000
o`000?n_V;oo00001?nYT[h00ol0003oXhfmoj>=_@02oj>=_@05o`000?nMRKgoWHVmoif9_Ol00000
1?nHQKd01Ol0003oTh:noi>2__nCP[ko000000?oT82n00Go0000oheo_on=OkooSGnoo`000003ohao
_`05o`000?n<P<7oS831ohb0`Ol000000on>P/401Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o
0000oiV:`onIR/<00onIR/<00ol0003oWHg2o`000003o`0000;oXY7200?o0000ojJC`OnVTl400onV
Tl400ol0003oZYC0ojZD`002ojZD`0Co000000?o[Y_4o`000?n`Vl800on`Vl800ol0003o/I[1ok6J
`@02ok6J`@;o00001?neYlX00ol0003o]JC8okFTb002o`000003okk8h_l0003o_L;N00?o_L;N1?l0
000oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0063ooooo00?o0000
ooooooooool0<?ooool2o`0000CoVMCl00?o0000omSKfOl000000_oJg=T01Ol0003ofmgHom_Mf?oK
gMSo000000?og=cG00?o0000omcKeOoLfmD00_l000000ooTe/So0000on?Cb002on?Cb005o`000?oQ
d<OohM37on7@aol000000_oNcLL01Ol0003oflG3om_5`ooKaL?o000000Coel7300Go0000olng`_o?
]l;ockO2o`000003ol^b`P04o`000?o5[<7oaJc1o`0000;o`:S100Co0000okZQ_onjXKoo^Z6o0_l0
0004ojnH_`03o`000?nYT[koZI:n00;oZI:n00Go0000oj>=_OnSSKgoXhfmo`000002oif9_A_o0000
1?n>P/401Ol0003oTHC2oi64`_nAQ<;o000000?oU8O200?o0000oiV:`onIR/<01?l00002oij>``03
o`000?nRTL;oXY7200;oXY7200?o0000ojJC`OnVTl400_nVTl401?l0003oZYC0ojZD`?nZU<02o`00
00Go[Y_400Ko0000ok2K`_n`Vl;o/9_2o`000?naV/43o`000003okFXc?l0003o]JO:00?o]JO:00?o
0000okFTb?l000001?nnb>800ol0003o_L;No`000002o`0004?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`00HOooool00ol0003oooooooooo`0`ooooo`04o`000?nIe?co
VMCloiWDo0Co000000?of]cIo`000?oKgMP00_oKgMP01Ol0003og=cGomcLeooLg=Oo000000;og=_E
00?o0000omgJe?oMf]@00ol000000ooSdlSo0000on7@a`02on7@a`04o`000?oNcLOog/g7omk=a`;o
000000?oflG3o`000?oG`L<00ooG`L<01Ol0003odkc4o`000?o?]l;o000000Cobk;200?o0000olF/
`Ol000000oo0Z<401_l0003o^Z6ookZQ_ol0003o]Yk0o`0000Co[iRo00?o0000ojVB__nYT[h00_nY
T[h00ol0003oXhfmoj>=_@04o`0000;oW8Rn00Go0000oiN5__nGQKkoUhFno`000003oi>3_P05o`00
0?nAPKkoTH6noi61__l000000on?P;l01Ol0003oSX30ohj0`?n>P<3o000000?oSX714?l00002oiZ;
``03o`000?nNS/?oWXk300;oWXk300Go0000oj:A`_nRTL;oXY72o`000005ojJC`@?o000000?oZi[5
o`000?n^Vl@01?n^Vl@01?l0003o/9_2ok2K`_n`Vl82o`0000Go]JS<00Co0000okFWb_neYl[o]JO:
0_l00005okk8hP;o0000Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
001Rooooo`;o0000<Oooool3o`0000;oXMSk1Ol000000ooKgMSo0000omcLe`02omcLe`04o`000?oL
fmGog=_Eo`0000?ogM[D00Co0000omcHdooLf=?o00000ooQd<L01Ol0003og/g7omk=aooNcLOo0000
00;oflW70_l00003omO1``05o`000?oC_<Codkc4om>la?l000001_o;//800ol0003o`:S1ol2X`@02
ol2X`@03o`000?njXKoo000000?o]Yk000Go0000ojnH_on_V;oo[iRoo`000003ojVB_PCo00000_nQ
S;h00ol0003oW8Rnoib8_P02oib8_P05o`000?nGQKkoUhFnoiN5__l000000onCPkh01Ol0003oTH6n
oi61__nAPKko000000?oSh2o00Go0000ohj0`?n>P<3oSX30o`000003ohj1`@05o`000?n@Pl;oT8?2
oi23`_l000000onBQL801Ol0003oUXS3oiJ8`onFR<?o000000GoVX_300Go0000oij>`onNS/?oWXk3
o`000004oj:A`P04o`000?nVTl7oYY?1ojJC`@;o00001?n[V/D00ol0003o[Y_4ojjKa002ojjKa006
o`000?n`Vl;o/9_2o`000?ndZ/oo00001OneZ<`01?l0003o]JO:o`000?l00002okk>i`03o`000?nn
b>;o000000;o0000B_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo001T
ooooo`03o`000?oooooooooo037ooooo0ol00002ojWKn@Go000000Gog=cGo`000?oLfmGog=_Eo`00
0003omgJe004o`000?oLf=?og=SComcHd`;o000000?ohM37o`000?oNcLL00_oNcLL02Ol0003oflW7
om_9aooKbLOo0000omS6b?l0003oel73o`000004om>la003o`000?o;//;obk;200?obk;20_l00004
ol2X`@;o00001?nfW/001?l0003o[iRoojnH_on_V;l4o`0000;oYY6o00?o0000oj6<__nQS;h00_nQ
S;h01Ol0003oW8Rnoib8__nLR;ko000000?oUhFn00Go0000oi>3__nCPkkoTh>no`000003oi61_P05
o`000?n?P;ooSh2oohn0_ol000000on>P<000ol0003oSX71ohj1`@02ohj1`@05o`000?n@Pl;oT8?2
oi23`_l000000onBQL801Ol0003oUXS3oiJ8`onFR<?o000000CoVX_300Go0000oij>`onNS/?oWXk3
o`000004oj:A`P06o`000?nVTl7o0000o`000?nXVLOo00001?n[V/D00ol0003o[Y_4ojjKa003ojjK
a0;o00000ondZ/l00ol0003o]JS<okFXc002okFXc0;o00001?nnc^L2o`0004gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`01ooooo`00IOooool00ol0003oooooooooo`0booooo`?o
00001?n`gOH3o`000003omcKeOl0003ogM[D00;ogM[D00Go0000omcHdooLf=?og=SCo`000002om_E
dP?o000000?og/g7o`000?oKbLL00_oKbLL01Ol0003of<K8omS6b?oHa/So000000Codkc400?o0000
oljhaOl000000oo;//801?l0003oaJk3olF^`ol00002ol2X`@03o`000?nkY<;o000000Co]Yk000Ko
0000ojnH_ol0003o0000ojbF`?l00005ojJA_`05o`000?nQS;koXHbnoj6<__l000000onLR;h01Ol0
003oUhFnoiN5__nGQKko000000?oTh>n00Go0000oi61__nAPKkoTH6no`000003ohn0_`03o`000?n>
P<3oSX3000;oSX3000Go0000ohj1`On>PL7oSX71o`000003oi23`P05o`000?nBQL;oTXG2oi:5`_l0
00000onFR<<00ol0003oVX_3oiZ;``02oiZ;``03o`000?nNS/?oWXk300;oWXk300?o0000oj:A`_nR
TL800ol00004ojRIa`03o`000?n[V/GoZi[500;oZi[500Co0000ojjKa?n^VlCo[Y_40_l00004okBZ
c`03o`000?neZ<co000000;o00000_nle>/01?l0003o_/kWo`000?l0001@ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0<oooool2o`00
0003ok3Mm_l0003o000000;o]mgc1?l000000ooMf]Co0000omcHd`02omcHd`04o`000?oKeM;ofmGB
o`0000?ofM;A00Go0000om_9aooKbLOoflW7o`000004omS6b005o`000?oC_<Codkc4om>la?l00000
0oo>^<D00ol0003obk;2o`000003olF^``03o`000?o0Z<7o000000?o^jC200Co0000okJN`?nfW/3o
]Yk00_l00004ojbF`003o`000?nVTKooYY6o00;oYY6o00Go0000oj6<__nQS;koXHbno`000004oib8
_P05o`000?nGQKkoUhFnoiN5__l000000onCPkh01Ol0003oTH6noi61__nAPKko000000?oSh2o00Go
0000ohj0`?n>P<3oSX30o`000003ohj1`@05o`000?n@Pl;oT8?2oi23`_l000000onBQL800ol0003o
UXS3oiJ8``02oiJ8``03o`000?nJRl?oVX_300;oVX_300?o0000oij>`ol000001?l00002ojBGb003
o`000?nXVLOoZ9W700;oZ9W700?o0000oj^JaOn[V/D00_n[V/D01_l0003o[Y_4o`000?l0003o/Z_A
o`0000Co]:[?0_l00005okcDj`;o0000Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo007ooooo001Wooooo`;o0000=Oooool2o`000003okOMlol0003o000000?o_Mc`1?l000001OoL
f=?o0000om_Ed_oKeM;o000000?ofM;A00Go0000omO?dOl0003oflW7o`000004omS6b005o`000?oD
`/So0000om>la?l000001Oo>^<D00ol0003oaJk3olF^``03olF^``03o`000?nkY<;o^jC200;o^jC2
00Ko0000okJN`?nfW/3o0000ok:L`_l00004ojbF`003o`000?nVTKooYY6o00;oYY6o00?o0000oj6<
__nQS;h00_nQS;h00ol0003oW8Rno`00000Fo`0000CoSX7100Go0000oi23`_n@Pl;oT8?2o`000003
oi:5`P05o`000?nFR<?oUXS3oiJ8`ol000000_nJRl<4o`0000;oWiC800?o0000ojBGb?nTUlP00onT
UlP01Ol0003oZ9W7ojRIaonXVLOo000000?oZi[50ol00004ok:[d@04o`000?ndZ/oo0000o`0000;o
^MW`00?o0000okcDjol000000_l0001Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00Oooool006Wooooo00?o0000ooooooooool0<oooool4o`000003okgLl?l0003o000000?o`M_/
0ol000000ooKeM;o0000omWBd@02omWBd@04o`000?oGcm7oeloAomO?d@;o00000ooHa/P01Ol0003o
e<;8omC2b?oD`/So000000Goc[S50_l00004olF^``;o00001?nkY<800ol0003o]Yk0o`000003ok:L
`P03o`000?n/U/3o[9K000;o[9K000?o0000ojJA_onVTKl00_nVTKl00ol0003oXHbno`000003o`00
00;oVh[100Go0000oiN7`OnGQl7oUhO1o`000003oi>6`P05o`000?nAQ<;oTHC2oi64`_l000000on@
Q<<01?l0003oShG4ohn5a?n?QL@Do`0000;oVi7800?o0000oinDb?nOU<P00_nOU<P00ol0003oY9O8
ojBGb002ojBGb004o`000?nXVLOoZ9W7ojRIa`Co00000_n_Zm@00ol0003o/Z_Aok:[d@02ok:[d@;o
00001?nifO02o`0005Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`01ooooo`00
J_ooool00ol0003oooooooooo`0eooooo`?o000000Co`M_/o`000?l0003o00000_o3f>T4o`000003
omWBdOl0003oeloA00;oeloA00Ko0000omC;dOoDbm7o0000omS6b?l00003omC2b003o`000?o@_l[o
000000?oc[S500Co0000olVea_o9]LKo00000_o5[/<01?l0003o`J_4ol6[a?l00003ok^T`P;o0000
1?nbW<800ol0003o[9K0ojbF`002ojbF`003o`000?nVTKooYY6o00Co00000_nOS/800ol0003oVh[1
oi^:`@02oi^:`@05o`000?nGQl7oUhO1oiN7`Ol000000onCQ/801Ol0003oTHC2oi64`_nAQ<;o0000
00?oT8C300Go0000ohn5a?n?QLCoShG4o`000003oi26a@05o`000?nAR<KoTHS6oi68a_l000000onD
RlL00ol0003oUhk8oiN>b002oiN>b003o`000?nKTLSoVi7800;oVi7800?o0000oinDb?nOU<P00_nO
U<P01_l0003oY9O8ojBGb?nTUlSo0000ojRIa`;o000000?oZj[Fo`000?n_Zm@01?n_Zm@01?l0003o
/Z_Ao`000?l00002okCLm004o`000?nifO3o0000o`0005cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`00Joooool00ol0003oooooooooo`0eooooo`04o`000?lbW?;o0000
o`0000?o`mSY00Co0000olCFioo4e^Ooa=KW0_l00003omO?d@03o`000?oDbm7oe<_A00;oe<_A00Go
0000omC2b?oD`/Soe<;8o`000003om2obP03o`000?o>^<Go000000?obKG600?o0000olF^`ol00000
0oo1Zl@01_l0003o^jC2ok^T`_l0003o]j?4o`0000Go/Yc200Co0000ojbF`?n/U/3o[9K00ol00002
ojBB``03o`000?nOS/;oWhk200;oWhk200Go0000oi^:`OnKR/7oVh[1o`000003oiN7`@05o`000?nC
Q/;oThK2oi>6`_l000000onAQ<801Ol0003oT8C3oi24`on@Q<?o000000CoShG400Go0000oi26aOn@
Q/GoT8K5o`000003oi68aP05o`000?nDRlOoU8_7oiB;aol000001?nGS/P01Ol0003oVi78oi^Ab?nK
TLSo000000CoWiC800?o0000ojBGb?nTUlP00ol00004oj^ZeP03o`000?n_ZmCo[j_D00;o[j_D0_l0
0004okCLm0;o0000Goooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo007ooooo001/
ooooo`;o0000=_ooool4o`000003ol?HjOl0003oa=KW00;oa=KW00Ko0000olCCiOo4dnGo0000omO?
dOl00004omC;d@05o`000?oAb=;o0000omC2b?l000001Oo@_lX00ol0003obKG6olVeaP02olVeaP;o
00001?o1Zl@00ol0003o^jC2o`000003okNSa003o`000?nbW<;o/Yc200;o/Yc200Ko0000ojbF`?l0
003o0000ojVGa?l00004ojBB``05o`000?nOS/;oWhk2oin>`_l000000onKR/401Ol0003oUhO1oiN7
`OnGQl7o000000?oThK200?o0000oi64`_nAQ<800_nAQ<801Ol0003oT8C3oi24`on@Q<?o000000?o
ShG400Go0000oi26aOn@Q/GoT8K5o`000003oi68aP03o`000?nDRlOoU8_700;oU8_700Go0000oiN>
b?nGS/SoUhk8o`000003oi^Ab004o`000?nOU<SoWiC8oinDb0Co00000_nVZ=L00ol0003oZj[Foj^Z
eP02oj^ZeP03o`000?n_ZmCo000000;o00000_n]g_P01?l0003o]=cdo`000?l0001Qooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo03Gooooo1Ol0
00000oo4e^Oo0000olCCi@02olCCi@?o00000ooDbm401Ol0003odLSBom78d_oAb=;o000000God;o:
0_l00003olVeaP03o`000?o5//So000000Co`J_40_l00005okNSa004o`000?nbW<;o/Yc2ok:L`P;o
00001?nYUl@01Ol0003oY9;3ojBB`onTT/?o000000?oWhk200?o0000oi^:`OnKR/400_nKR/401Ol0
003oUhO1oiN7`OnGQl7o000000?oThK200Go0000oi64`_nAQ<;oTHC2o`000003oi24``05o`000?n?
QLCoShG4ohn5a?l000000on@Q/D01Ol0003oTHS6oi68a_nAR<Ko000000CoU8_700Go0000oiN>b?nG
S/SoUhk8o`000002oi^Ab0Go00000_nRYMP00ol0003oYZSGojJXe`02ojJXe`03o`000?n[Z]KoZj[F
00Co00000on]g_P3o`0006Cooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool006oo
oooo00?o0000ooooooooool0=Oooool5o`0000?oa=?U00Oo0000ol?@i?o3d>Co`m3To`000?oDbm7o
000000?odLSB00?o0000olg5dol000000oo@_lX01_l0003obkc<ol^lc?l0003obKG6o`0000?oaK;8
00Ko0000ol6[a?o1ZlCo0000okbZaol00005okNSa006o`000?nbW<;o0000o`000?n^WLKo00001?nY
Ul@01Ol0003oY9;3ojBB`onTT/?o000000CoWhk200?o0000oi^:`Ol00000:Ol00002oifRf003o`00
0?nRYMSoXZGH00?oXZGH00Co0000ojJXeonVZ=OoYZSG0ol00003ojCMn`Co0000J?ooool00ol0003o
ooooooooo`02ooooo`7o00000Oooool1ooooo`00L?ooool00ol0003oooooooooo`0fooooo`Co0000
00?oa=?Uo`000?o3d>@00oo3d>@2o`0000?odLSB00Oo0000olg5doo=aM?ocLGCo`000?o@_l[o0000
00Cobkc<00?o0000olFbb?o5//P00_o5//P00ol0003o`J_4o`000003okbZa`03o`000?ngXlCo]j?4
00;o]j?40_l00004ojjMaP05o`000?nYUlCoZIO4ojVGa?l000001?nTT/<00ol0003oWhk2o`000003
o`0000;oVY7900Go0000oiJ?b_nFSl[oUXo:o`000003oi>>b`03o`000?nAS/coTHk<00;oTHk<00Go
0000oi2>c_n@S/koT8k>o`000003ohn@d005o`000?n@T];oT9;Boi2Bd_l000000onAU]@00ol0003o
U9[FoiBJeP02oiBJeP05o`000?nHW]SoV9kHoiRNf?l000001?nMX]P00ol0003oXZGHoj:Uf002oj:U
f004o`000?nVZ=Oo0000o`0000;oW=_m00Co0000ojCMnol0003o0000KOooool01Ol0003ooooooooo
oooooooo000000;ooooo001aooooo`;o0000=oooool6o`000003ol?@i?l0003o000000;o`LgT00?o
0000om78d_l000001?o=aM<2o`0000Cobkc<0_l00004olFbb0;o00001OnlZ/L01_l0003o]j?4o`00
0?l0003o/jC9o`0000Co[Yg600?o0000ojVGa?nYUl@00_nYUl@00ol0003oY9;3o`000003o`0000;o
WYC:00?o0000oiZAbOnJTLT00_nJTLT01Ol0003oUXo:oiJ?b_nFSl[o000000?oThk;00?o0000oi6>
c?nAS/`00_nAS/`01Ol0003oT8k>oi2>c_n@S/ko000000?oSi3@00Go0000oi2Bd_n@T];oT9;Bo`00
0003oi6Fe003o`000?nDV]KoU9[F00;oU9[F00Go0000oiRNf?nHW]SoV9kHo`000003oifRf004o`00
0?nRYMSoXZGHoj:Uf0Co00000_nLfod3o`0006oooooo00Go0000ooooooooooooooooo`000002oooo
o`00Loooool00ol0003oooooooooo`0fooooo`Go00001?o1cN@2o`0000?ocLGC0_l000000oo8`mKo
0000ol^lc002ol^lc005o`000?o6^/ooa[[?o`000?o5//P00_l00002oknbc003o`000?nlZ/Oo_:[7
00;o_:[70_l00004ok>Tb@05o`000?n^WLKo[Yg6ojjMa_l000000_nYUl@4o`0000;oXYS;00?o0000
oijDb_nNU<X00_nNU<X01Ol0003oVY79oiZAbOnJTLWo000000?oUXo:00?o0000oi>>bonCS//00_nC
S//01Ol0003oTHk<oi6>c?nAS/co000000?oT8k>00Go0000ohn@d?n?T=3oSi3@o`000003oi2BdP03
o`000?nAU]CoTIKD00;oTIKD00Go0000oiBJe_nDV]KoU9[Fo`000002oiRNf0Wo00000_nCeoh4o`00
07?ooooo00Co0000oooooooooooo00000_ooool007Cooooo00?o0000ooooooooool0=_ooool01_l0
003oMKSkogFhnome^?_o0000ol7=i0;o00000_nmb^@00ol0003ocLGCo`000004olS3eP03o`000?o;
_<co000000?oa[[?0_l00005oknbc006o`000?nlZ/Oo0000o`000?ngZlgo00001?ncY<T00ol0003o
[Yg6ojjMaP04o`0000;oYig<00?o0000oj:HbonRV</00_nRV</01Ol0003oWYC:oijDb_nNU<[o0000
00?oVY7900Go0000oiJ?b_nFSl[oUXo:o`000004oi>>b`05o`000?nAS/coTHk<oi6>c?l000000on@
S/h01Ol0003oSi3@ohn@d?n?T=3o000000?oT9;B00Co0000oi6Fe?nAU]CoTIKD2?l00003ohS:o@04
o`000?n=dOkoSM7nohgAoPCo0000N?ooool00ol0003oooooo`000002ooooo`00MOooool00ol0003o
ooooooooo`0fooooo`Go00001?nmb^@3o`0000Cob<?F0_l00003olJjc`03o`000?o1^]?o000000Go
_k;<0_l00004okN[c@04o`000?ncY<Wo/jC9ok>Tb@?o00000_n[Xlh00ol0003oYig<ojNMc002ojNM
c005o`000?nRV<_oXYS;oj:Hbol000000onNU<X00ol0003oVY79oiZAb@0No`0000?oQ;_h00?o0000
ohG3non5`o/02Ol0001looooo`04o`000?ooooooooooo`00007ooooo001fooooo`;o0000=oooool2
o`0000;oNKSj00Co0000okg:i?l0003o00000onhb>H01?l0003ob<?Fo`000?l00002ol?2f@03o`00
0?o6^/oo000000?o`K[C00Oo0000oknbc?no//co_k;<o`000?nj/m;o000000Co]j_=00Ko0000ok>T
bOl0003o0000ok2Yd_l00004oj^ScP05o`000?nWWLcoYig<ojNMc?l000000_nRV</8o`0000?oV:CN
00Go0000oiBTh?nDY>3oU:CPo`000003oi2Uh`03o`000?n=YnOoSJOW00;oSJOW00Go0000ohVZjon9
Z^_oRJ[[o`000003ohN_l003o`000?n5]OCoQKGd00Wo0000Q_ooool00ol0003oooooo`000001oooo
o`00N?ooool00ol0003oooooooooo`0eooooo`Ko00001?nhb>H2o`0000Co`l;I0_l00005ol6jd`03
o`000?no//co000000?o^[?B00Co0000okN[cOngZlgo]j_=0_l00004ok2YdP05o`000?n[XlkoZj?>
oj^Sc_l000000_nWWL`4o`0000;oX:WL00Go0000oibVgOnLY]goW:KMo`000005oiRTgP05o`000?nD
Y>3oU:CPoiBTh?l000000on@YN<00ol0003oSJOWohfWi`0<o`00093ooooo0_l00001ooooo`00NOoo
ool00ol0003oooooooooo`0eooooo`;o00000omi]oT01?l0003o^<SVo`000?l00002ok;6j@04o`00
0?o3`]Wo0000o`0000;o_<7N00?o0000ol6jdoo1^]<00_o1^]<2o`0000Co^[?B00Ko0000okN[cOl0
003o0000ok>ae_l00004ok2YdP03o`000?n[XlkoZj?>00Co00000_nT[Md00ol0003oX:WLoj2Yg002
oj2Yg005o`000?nLY]goW:KMoibVgOl000000onHY=h>o`0009Wooooo0ol00001ooooo`00N_ooool0
0ol0003oooooooooo`0eooooo`Ko00001?nba^T2o`0000Go_<7N00Ko0000ol6jdol0003o0000ok^k
f_l00004okZcdP;o00001?nc/MH01?l0003o/:WBok2Yd_n`ZM83o`0000;oZ;;O00?o0000ojB]gOnT
[Md00_nT[Md01Ol0003oX:WLoj2Yg?nPZMco000000;oW:KM1Ol00002og7@oPCo0000WOooool4o`00
00Cooooo001kooooo`03o`000?oooooooooo03Gooooo0_l00003ogJfn@04o`000?nba^Wo0000o`00
00;oZlG]00?o0000okc1g_nl`Mh00_nl`Mh2o`0000Co^k_J00Ko0000okZcd_l0003o0000okFig?l0
0004ok>aeP06o`000?n`ZM;o0000o`000?n/^>?o00001?nX/]l00ol0003oY:gMojB]g@09o`0000;o
P=7o1?l0002Mooooo`Co00002?ooool007cooooo0_l0000fooooo`Oo00001?n[aNd01_l0003o_<7N
o`000?l0003o]L?To`0000Co^k_J0_l00004okFig003o`000?nc/MKo/k7F00?o00001?n/^><00ol0
003oZ;;OojRbg`05o`0000;oTMCn2?l0002Mooooo`Co00003?ooool007kooooo00?o0000oooooooo
ool0=?ooool00ol0003o06WIo`000004o`0000;oZlG]0ol00004okG3i004o`000?nk^m[o0000o`00
00;o]<7T00?o0000okFig?ne^M`01?l00003ojjoi`03o`000?n/^>?o[;SS00Go00000_nFe_d4o`00
0:;ooooo0ol0000@ooooo`00Ooooool00ol0003oooooooooo`0dooooo`Co000000CoJk;jo`000?l0
003o00000onQaO800ol0003o]L?TokG3i003o`0000Co]<7T0ol00003ojk7k@03o`000?n^_nOo[[oW
00Go00000_nHfOd4o`000:;ooooo1?l0000Cooooo`00P?ooool00ol0003oooooooooo`0eooooo`Ko
00000_nQaO84o`0000?o[<O^00Co0000okC1i?l0003o00000_nYcO<00ol0003o[/O]ojk7k@05o`00
00;oV=cn1?l0002Rooooo`Co00005oooool0087ooooo0_l0000fooooo`Oo00000onFaoP00ol0003o
[<O^ojc7kP05o`0000;oZLgc1?l00002oiCNoPCo0000X_ooool4o`0001_ooooo0023ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ocF>kol000002_l00002oik@n@Co00000_n=g_h4o`000:;ooooo
1?l0000Oooooo`00Q?ooool00ol0003oooooooooo`0dooooo`ko00000_n2fOh4o`000:;ooooo1?l0
000Sooooo`00QOooool00ol0003oooooooooo`0dooooo`05o`000?mKX_GoFj;eoe^RmOl000000_mX
__h9o`000:7ooooo1?l0000Wooooo`00Q_ooool2o`0003Gooooo1ol00002ogO=o`?o0000XOooool3
o`0002_ooooo0028ooooo`03o`000?oooooooooo03Cooooo00?o0000ohBdm?n4]?@01?l0002Poooo
o`Co0000;_ooool008Wooooo00?o0000ooooooooool0=?ooool2o`000:3ooooo1?l0000booooo`00
R_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo09_ooooo1?l0000fooooo`00Rooo
ool2o`0003?ooooo00?o0000ooooooooool0Uoooool4o`0003[ooooo002=ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Toooool4o`0003kooooo002>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0Soooool4o`0004;ooooo002?ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0S?ooool3o`0004Kooooo002@ooooo`;o0000;Oooool00ol0003ooooo
ooooo`29ooooo`Co0000BOooool009;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`25ooooo`Co0000COooool009?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`21
ooooo`Co0000DOooool009Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1moooo
o`Co0000EOooool009Gooooo0_l0000Xooooo`03o`000?oooooooooo07Wooooo1?l0001Iooooo`00
Uoooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Gooooo1?l0001Mooooo`00V?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07;ooooo0ol0001Qooooo`00VOooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06kooooo1?l0001Tooooo`00V_ooool2o`00
02?ooooo00?o0000ooooooooool0J_ooool4o`0006Sooooo002Looooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0I_ooool4o`0006cooooo002Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0H_ooool4o`00073ooooo002Nooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0G_ooool4o`0007Cooooo002Oooooo`;o00007_ooool00ol0003oooooooooo`1J
ooooo`Co0000N?ooool00:7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Goooo
o`?o0000O?ooool00:;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Cooooo`Co
0000Ooooool00:?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000
Poooool00:Cooooo0_l0000Iooooo`03o`000?oooooooooo04_ooooo1?l00027ooooo`00Y_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo1?l0002;ooooo`00Yoooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo1?l0002?ooooo`00Z?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l0002Cooooo`00ZOooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03cooooo0ol0002Gooooo`00Z_ooool2o`0001?ooooo00?o
0000ooooooooool0>?ooool4o`0009[ooooo002/ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0=?ooool4o`0009kooooo002]ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<?ooool4o`000:;ooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0;?ooool4o`000:Kooooo002_ooooo`;o00003Oooool00ol0003oooooooooo`0Yooooo`Co0000
Z_ooool00;7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000[_oo
ool00;;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`?o0000/_ooool0
0;?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000]Oooool00;Co
oooo0_l00008ooooo`03o`000?oooooooooo01[ooooo1?l0002iooooo`00]_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002mooooo`00]oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo1?l00031ooooo`00^?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00kooooo1?l00035ooooo`00^Oooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool4o`000<Wooooo002kooooo`04o`000?ooooooooooo`0000Wooooo0ol0003=oooo
o`00_?ooool00ol0003oooooo`000005ooooo`Co0000d?ooool00;gooooo0_l000000ooooooo0000
o`000002o`000=Cooooo002nooooo`;o0000f?ooool00?ooooooVOooool00?ooooooVOooool00?oo
ooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?oo
ooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00?ooooooVOooool00001
\
\>"],
  ImageRangeCache->{{{0, 407.75}, {330.438, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The error could be reduced even further  by increasing ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_y\)]],
  ". However, the more terms one keeps, the more time it takes to create and \
solve the equations."
}], "Text"],

Cell[TextData[{
  "\t The computation time can be reduced significantly if a general analytic \
form for one or more of the inner products can be found.  For example, the \
inner product ",
  Cell[BoxData[
      \(TraditionalForm\`L[i, j, k, l]\)]],
  " in the above example can  be determined analytically for general ",
  Cell[BoxData[
      \(TraditionalForm\`i, j, k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lmat[i_, j_, k_, l_] = \ \ Integrate[
        v[i, j, x, y]\ \ L[v[k, l, x, y]], {x, 0, 1}, {y, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.15"],

Cell[BoxData[
    \(\((2\ \((\(2\ k\)\/\(1 + i + k\) + \(3\ j\ k\)\/\(1 + i + k\) + \(j\^2\ \
k\)\/\(1 + i + k\) + \(2\ k\^2\)\/\(1 + i + k\) + \(3\ j\ k\^2\)\/\(1 + i + k\
\) + \(j\^2\ k\^2\)\/\(1 + i + k\) - 
              4\/\(2 + i + k\) - \(6\ j\)\/\(2 + i + k\) - \(2\ j\^2\)\/\(2 + \
i + k\) - \(8\ k\)\/\(2 + i + k\) - \(12\ j\ k\)\/\(2 + i + k\) - \(4\ j\^2\ \
k\)\/\(2 + i + k\) - \(4\ k\^2\)\/\(2 + i + k\) - \(6\ j\ k\^2\)\/\(2 + i + k\
\) - \(2\ j\^2\ k\^2\)\/\(2 + i + k\) - 
              16\/\(3 + i + k\) - \(23\ j\)\/\(3 + i + k\) - \(8\ j\^2\)\/\(3 \
+ i + k\) - 
              j\^3\/\(3 + i + k\) + \(6\ k\)\/\(3 + i + k\) + \(9\ j\ \
k\)\/\(3 + i + k\) + \(3\ j\^2\ k\)\/\(3 + i + k\) + \(2\ k\^2\)\/\(3 + i + k\
\) + \(3\ j\ k\^2\)\/\(3 + i + k\) + \(j\^2\ k\^2\)\/\(3 + i + k\) + 
              40\/\(4 + i + k\) + \(58\ j\)\/\(4 + i + k\) + \(20\ \
j\^2\)\/\(4 + i + k\) + \(2\ j\^3\)\/\(4 + i + k\) - 
              20\/\(5 + i + k\) - \(29\ j\)\/\(5 + i + k\) - \(10\ \
j\^2\)\/\(5 + i + k\) - 
              j\^3\/\(5 + i + k\) + \(3\ k\ l\)\/\(1 + i + k\) + \(2\ j\ k\ l\
\)\/\(1 + i + k\) + \(3\ k\^2\ l\)\/\(1 + i + k\) + \(2\ j\ k\^2\ l\)\/\(1 + \
i + k\) - \(6\ l\)\/\(2 + i + k\) - \(4\ j\ l\)\/\(2 + i + k\) - \(12\ k\ l\)\
\/\(2 + i + k\) - \(8\ j\ k\ l\)\/\(2 + i + k\) - \(6\ k\^2\ l\)\/\(2 + i + k\
\) - \(4\ j\ k\^2\ l\)\/\(2 + i + k\) - \(23\ l\)\/\(3 + i + k\) - \(36\ j\ l\
\)\/\(3 + i + k\) - \(12\ j\^2\ l\)\/\(3 + i + k\) - \(j\^3\ l\)\/\(3 + i + k\
\) + \(9\ k\ l\)\/\(3 + i + k\) + \(6\ j\ k\ l\)\/\(3 + i + k\) + \(3\ k\^2\ \
l\)\/\(3 + i + k\) + \(2\ j\ k\^2\ l\)\/\(3 + i + k\) + \(58\ l\)\/\(4 + i + \
k\) + \(80\ j\ l\)\/\(4 + i + k\) + \(24\ j\^2\ l\)\/\(4 + i + k\) + \(2\ \
j\^3\ l\)\/\(4 + i + k\) - \(29\ l\)\/\(5 + i + k\) - \(40\ j\ l\)\/\(5 + i + \
k\) - \(12\ j\^2\ l\)\/\(5 + i + k\) - \(j\^3\ l\)\/\(5 + i + k\) + \(k\ l\^2\
\)\/\(1 + i + k\) + \(k\^2\ l\^2\)\/\(1 + i + k\) - \(2\ l\^2\)\/\(2 + i + \
k\) - \(4\ k\ l\^2\)\/\(2 + i + k\) - \(2\ k\^2\ l\^2\)\/\(2 + i + k\) - \(8\ \
l\^2\)\/\(3 + i + k\) - \(12\ j\ l\^2\)\/\(3 + i + k\) - \(2\ j\^2\ \
l\^2\)\/\(3 + i + k\) + \(3\ k\ l\^2\)\/\(3 + i + k\) + \(k\^2\ l\^2\)\/\(3 + \
i + k\) + \(20\ l\^2\)\/\(4 + i + k\) + \(24\ j\ l\^2\)\/\(4 + i + k\) + \(4\ \
j\^2\ l\^2\)\/\(4 + i + k\) - \(10\ l\^2\)\/\(5 + i + k\) - \(12\ j\ l\^2\)\/\
\(5 + i + k\) - \(2\ j\^2\ l\^2\)\/\(5 + i + k\) - 
              l\^3\/\(3 + i + k\) - \(j\ l\^3\)\/\(3 + i + k\) + \(2\ \
l\^3\)\/\(4 + i + k\) + \(2\ j\ l\^3\)\/\(4 + i + k\) - 
              l\^3\/\(5 + i + k\) - \(j\ l\^3\)\/\(5 + i + k\))\))\)/\((\((1 \
+ j + l)\)\ \((2 + j + l)\)\ \((3 + j + l)\)\ \((4 + j + l)\)\ \((5 + j + 
              l)\))\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "(the result is suppressed to save space). Even though this expression for \
",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(i\ j\ k\ l\)\)]],
  " is quite complicated, it takes less time to evaluate than the previous \
expression that contained a delayed evaluation of the inner product. \
Previously, when the equations ",
  Cell[BoxData[
      FormBox[
        RowBox[{"eq", "[", 
          RowBox[{
            StyleBox["i",
              FontSlant->"Plain"], ",", 
            StyleBox["j",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "were constructed, the integrals in the inner product had to be performed \
separately for every value of ",
  StyleBox["i, j, k",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["l",
    FontSlant->"Italic"],
  ".  Now, the equations take much less time to create. (Try it.)"
}], "Text"],

Cell[TextData[{
  "\t  However, it is not always possible to work out the inner products \
analytically for general values of the indices. For instance, the integrals \
needed in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\_\(k\ l\)\)]],
  " are too complex to be done for general ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Section",
  CellTags->"c:7"],

Cell[TextData[{
  "In the next example, we will solve Poisson's equation in a domain that \
does not allow for an analytic solution. The domain is defined by the \
equations ",
  Cell[BoxData[
      \(TraditionalForm\`y \[LessEqual] \ x/6\  + \ 1, \ 
      y \[GreaterEqual] \ x\^2\)]],
  ". This domain is plotted in Cell ",
  ButtonBox["6.17",
    ButtonData:>"Cell 6.17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(<< Calculus`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.16"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\ 
        Boole[y \[LessEqual] \ x/6\  + \ 1 && \ 
            y \[GreaterEqual] \ x\^2], {x, \(-1\), 1.3}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 100];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.17"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437291 0.41806 0.0192308 0.739645 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.22826 -0.0125 -12 -9 ]
[.22826 -0.0125 12 0 ]
[.43729 -0.0125 -3 -9 ]
[.43729 -0.0125 3 0 ]
[.64632 -0.0125 -9 -9 ]
[.64632 -0.0125 9 0 ]
[.85535 -0.0125 -3 -9 ]
[.85535 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16716 -18 -4.5 ]
[-0.0125 .16716 0 4.5 ]
[-0.0125 .31509 -18 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .46302 -18 -4.5 ]
[-0.0125 .46302 0 4.5 ]
[-0.0125 .61095 -18 -4.5 ]
[-0.0125 .61095 0 4.5 ]
[-0.0125 .75888 -6 -4.5 ]
[-0.0125 .75888 0 4.5 ]
[-0.0125 .9068 -18 -4.5 ]
[-0.0125 .9068 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.22826 0 m
.22826 .00625 L
s
[(-0.5)] .22826 -0.0125 0 1 Mshowa
.43729 0 m
.43729 .00625 L
s
[(0)] .43729 -0.0125 0 1 Mshowa
.64632 0 m
.64632 .00625 L
s
[(0.5)] .64632 -0.0125 0 1 Mshowa
.85535 0 m
.85535 .00625 L
s
[(1)] .85535 -0.0125 0 1 Mshowa
.125 Mabswid
.06104 0 m
.06104 .00375 L
s
.10284 0 m
.10284 .00375 L
s
.14465 0 m
.14465 .00375 L
s
.18645 0 m
.18645 .00375 L
s
.27007 0 m
.27007 .00375 L
s
.31187 0 m
.31187 .00375 L
s
.35368 0 m
.35368 .00375 L
s
.39548 0 m
.39548 .00375 L
s
.4791 0 m
.4791 .00375 L
s
.5209 0 m
.5209 .00375 L
s
.56271 0 m
.56271 .00375 L
s
.60452 0 m
.60452 .00375 L
s
.68813 0 m
.68813 .00375 L
s
.72993 0 m
.72993 .00375 L
s
.77174 0 m
.77174 .00375 L
s
.81355 0 m
.81355 .00375 L
s
.89716 0 m
.89716 .00375 L
s
.93896 0 m
.93896 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16716 m
.00625 .16716 L
s
[(0.2)] -0.0125 .16716 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(0.4)] -0.0125 .31509 1 0 Mshowa
0 .46302 m
.00625 .46302 L
s
[(0.6)] -0.0125 .46302 1 0 Mshowa
0 .61095 m
.00625 .61095 L
s
[(0.8)] -0.0125 .61095 1 0 Mshowa
0 .75888 m
.00625 .75888 L
s
[(1)] -0.0125 .75888 1 0 Mshowa
0 .9068 m
.00625 .9068 L
s
[(1.2)] -0.0125 .9068 1 0 Mshowa
.125 Mabswid
0 .05621 m
.00375 .05621 L
s
0 .0932 m
.00375 .0932 L
s
0 .13018 m
.00375 .13018 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .5 m
.00375 .5 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .64793 m
.00375 .64793 L
s
0 .68491 m
.00375 .68491 L
s
0 .72189 m
.00375 .72189 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .86982 m
.00375 .86982 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.22826 .99375 m
.22826 1 L
s
.43729 .99375 m
.43729 1 L
s
.64632 .99375 m
.64632 1 L
s
.85535 .99375 m
.85535 1 L
s
.125 Mabswid
.06104 .99625 m
.06104 1 L
s
.10284 .99625 m
.10284 1 L
s
.14465 .99625 m
.14465 1 L
s
.18645 .99625 m
.18645 1 L
s
.27007 .99625 m
.27007 1 L
s
.31187 .99625 m
.31187 1 L
s
.35368 .99625 m
.35368 1 L
s
.39548 .99625 m
.39548 1 L
s
.4791 .99625 m
.4791 1 L
s
.5209 .99625 m
.5209 1 L
s
.56271 .99625 m
.56271 1 L
s
.60452 .99625 m
.60452 1 L
s
.68813 .99625 m
.68813 1 L
s
.72993 .99625 m
.72993 1 L
s
.77174 .99625 m
.77174 1 L
s
.81355 .99625 m
.81355 1 L
s
.89716 .99625 m
.89716 1 L
s
.93896 .99625 m
.93896 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16716 m
1 .16716 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .46302 m
1 .46302 L
s
.99375 .61095 m
1 .61095 L
s
.99375 .75888 m
1 .75888 L
s
.99375 .9068 m
1 .9068 L
s
.125 Mabswid
.99625 .05621 m
1 .05621 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13018 m
1 .13018 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .5 m
1 .5 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .68491 m
1 .68491 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .86982 m
1 .86982 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.39802 .01961 m
.40773 .01961 L
.41744 .01961 L
.42716 .01961 L
.43687 .01961 L
.44658 .01961 L
.45629 .01961 L
.46601 .01961 L
.47572 .01961 L
.48465 .02894 L
.48543 .02973 L
.49514 .02973 L
.50486 .02973 L
.51378 .03866 L
.51457 .03944 L
.5235 .04837 L
.52428 .04915 L
.53321 .05808 L
.53399 .05887 L
.54371 .05887 L
.55263 .06779 L
.55342 .06858 L
.56235 .07751 L
.56313 .07829 L
.57206 .08722 L
.57206 .09693 L
.57284 .09772 L
.58177 .10664 L
.58256 .10743 L
.59148 .11636 L
.59227 .11714 L
.6012 .12607 L
.60198 .12685 L
.61091 .13578 L
.61091 .14549 L
.61169 .14628 L
.62062 .15521 L
.62141 .15599 L
.63033 .16492 L
.63033 .17463 L
.63112 .17542 L
.64005 .18434 L
.64005 .19406 L
.64083 .19484 L
.64976 .20377 L
.65054 .20455 L
.65947 .21348 L
.65947 .22319 L
.66026 .22398 L
.66918 .23291 L
.66918 .24262 L
.66997 .2434 L
.6789 .25233 L
.6789 .26204 L
.67968 .26283 L
.68861 .27176 L
.68861 .28147 L
.68939 .28225 L
.69832 .29118 L
.69832 .30089 L
.69911 .30168 L
.70803 .31061 L
.70803 .32032 L
.70803 .33003 L
.70882 .33082 L
.71775 .33974 L
.71775 .34946 L
.71853 .35024 L
.72746 .35917 L
.72746 .36888 L
.72824 .36967 L
.73717 .37859 L
.73717 .38831 L
.73717 .39802 L
.73796 .3988 L
.74688 .40773 L
.74688 .41744 L
.74767 .41823 L
.7566 .42716 L
.7566 .43687 L
.7566 .44658 L
.75738 .44737 L
.76631 .45629 L
.76631 .46601 L
.76631 .47572 L
.76709 .4765 L
.77602 .48543 L
.77602 .49514 L
.77602 .50486 L
.77681 .50564 L
.78573 .51457 L
.78573 .52428 L
.78573 .53399 L
.78652 .53478 L
.79545 .54371 L
.79545 .55342 L
.79545 .56313 L
.79623 .56392 L
.80516 .57284 L
.80516 .58256 L
.80516 .59227 L
.80594 .59305 L
.81487 .60198 L
.81487 .61169 L
.81487 .62141 L
.81566 .62219 L
.82458 .63112 L
.82458 .64083 L
.82458 .65054 L
.82537 .65133 L
.8343 .66026 L
.8343 .66997 L
.8343 .67968 L
.83508 .68047 L
.84401 .68939 L
.84401 .69911 L
.84401 .70882 L
.84401 .71853 L
.84479 .71932 L
.85372 .72824 L
.85372 .73796 L
.85372 .74767 L
.85451 .74845 L
.86343 .75738 L
.86343 .76709 L
.86343 .77681 L
.86343 .78652 L
.86422 .7873 L
.87315 .79623 L
.87315 .80594 L
.87315 .81566 L
.87315 .82537 L
.87393 .82615 L
.88286 .83508 L
.88286 .84479 L
.88286 .85451 L
.88364 .85529 L
.89257 .86422 L
.89257 .87393 L
.89257 .88364 L
.88364 .89257 L
.87393 .89257 L
.86422 .89257 L
.85529 .88364 L
.85451 .88286 L
.84479 .88286 L
.83508 .88286 L
.82615 .87393 L
.82537 .87315 L
.81566 .87315 L
.80594 .87315 L
.79623 .87315 L
.7873 .86422 L
.78652 .86343 L
.77681 .86343 L
.76709 .86343 L
.75817 .85451 L
.75738 .85372 L
.74767 .85372 L
.73796 .85372 L
.72903 .84479 L
.72824 .84401 L
.71853 .84401 L
.70882 .84401 L
.69911 .84401 L
.69018 .83508 L
.68939 .8343 L
.67968 .8343 L
.66997 .8343 L
.66104 .82537 L
.66026 .82458 L
.65054 .82458 L
.64083 .82458 L
.63112 .82458 L
.62219 .81566 L
.62141 .81487 L
.61169 .81487 L
.60198 .81487 L
.59305 .80594 L
.59227 .80516 L
.58256 .80516 L
.57284 .80516 L
.56392 .79623 L
.56313 .79545 L
.55342 .79545 L
.54371 .79545 L
.53399 .79545 L
.52507 .78652 L
.52428 .78573 L
.51457 .78573 L
.50486 .78573 L
.49593 .77681 L
.49514 .77602 L
.48543 .77602 L
.47572 .77602 L
.46601 .77602 L
.45708 .76709 L
.45629 .76631 L
.44658 .76631 L
.43687 .76631 L
.42794 .75738 L
.42716 .7566 L
.41744 .7566 L
.40773 .7566 L
.3988 .74767 L
.39802 .74688 L
.38831 .74688 L
.37859 .74688 L
.36888 .74688 L
.35995 .73796 L
.35917 .73717 L
.34946 .73717 L
.33974 .73717 L
.33082 .72824 L
.33003 .72746 L
.32032 .72746 L
.31061 .72746 L
.30089 .72746 L
.29197 .71853 L
.29118 .71775 L
.28147 .71775 L
.27176 .71775 L
.26283 .70882 L
.26204 .70803 L
.25233 .70803 L
.24262 .70803 L
.23369 .69911 L
.23291 .69832 L
.22319 .69832 L
.21348 .69832 L
.20377 .69832 L
.19484 .68939 L
.19406 .68861 L
.18434 .68861 L
.17463 .68861 L
.1657 .67968 L
.16492 .6789 L
.15521 .6789 L
.14549 .6789 L
.13578 .6789 L
.12685 .66997 L
.12607 .66918 L
.11636 .66918 L
.10664 .66918 L
.09772 .66026 L
.09693 .65947 L
.08722 .65947 L
.07751 .65947 L
.06858 .65054 L
.06779 .64976 L
.05808 .64976 L
.04915 .64083 L
.04915 .63112 L
.05808 .62219 L
.05887 .62141 L
.05887 .61169 L
.05887 .60198 L
.06779 .59305 L
.06858 .59227 L
.06858 .58256 L
.06858 .57284 L
.07751 .56392 L
.07829 .56313 L
.07829 .55342 L
.07829 .54371 L
.08722 .53478 L
.088 .53399 L
.088 .52428 L
.088 .51457 L
.09693 .50564 L
.09772 .50486 L
.09772 .49514 L
.09772 .48543 L
.10664 .4765 L
.10743 .47572 L
.10743 .46601 L
.10743 .45629 L
.11636 .44737 L
.11714 .44658 L
.11714 .43687 L
.12607 .42794 L
.12685 .42716 L
.12685 .41744 L
.12685 .40773 L
.13578 .3988 L
.13657 .39802 L
.13657 .38831 L
.14549 .37938 L
.14628 .37859 L
.14628 .36888 L
.14628 .35917 L
.15521 .35024 L
.15599 .34946 L
.15599 .33974 L
.16492 .33082 L
.1657 .33003 L
.1657 .32032 L
.17463 .31139 L
.17542 .31061 L
.17542 .30089 L
.17542 .29118 L
.18434 .28225 L
.18513 .28147 L
.18513 .27176 L
.19406 .26283 L
.19484 .26204 L
.19484 .25233 L
.20377 .2434 L
.20455 .24262 L
.20455 .23291 L
.21348 .22398 L
.21427 .22319 L
.21427 .21348 L
.22319 .20455 L
.22398 .20377 L
.23291 .19484 L
.23369 .19406 L
.23369 .18434 L
.24262 .17542 L
.2434 .17463 L
.2434 .16492 L
.25233 .15599 L
.25312 .15521 L
.26204 .14628 L
.26283 .14549 L
.26283 .13578 L
.27176 .12685 L
.27254 .12607 L
.28147 .11714 L
.28225 .11636 L
.29118 .10743 L
.29197 .10664 L
.30089 .09772 L
.30168 .09693 L
.30168 .08722 L
.31061 .07829 L
.31139 .07751 L
.32032 .06858 L
.33003 .06858 L
.33082 .06779 L
.33974 .05887 L
.34053 .05808 L
.34946 .04915 L
.35024 .04837 L
.35917 .03944 L
.36888 .03944 L
.36967 .03866 L
.37859 .02973 L
.38831 .02973 L
.38909 .02894 L
F
0 g
.39802 .01961 m
.40773 .01961 L
.41744 .01961 L
.42716 .01961 L
.43687 .01961 L
.44658 .01961 L
.45629 .01961 L
.46601 .01961 L
.47572 .01961 L
.48465 .02894 L
.48543 .02973 L
.49514 .02973 L
.50486 .02973 L
.51378 .03866 L
.51457 .03944 L
.5235 .04837 L
.52428 .04915 L
.53321 .05808 L
.53399 .05887 L
.54371 .05887 L
.55263 .06779 L
.55342 .06858 L
.56235 .07751 L
.56313 .07829 L
.57206 .08722 L
.57206 .09693 L
.57284 .09772 L
.58177 .10664 L
.58256 .10743 L
.59148 .11636 L
.59227 .11714 L
.6012 .12607 L
.60198 .12685 L
.61091 .13578 L
.61091 .14549 L
.61169 .14628 L
.62062 .15521 L
.62141 .15599 L
.63033 .16492 L
.63033 .17463 L
.63112 .17542 L
.64005 .18434 L
.64005 .19406 L
.64083 .19484 L
.64976 .20377 L
.65054 .20455 L
.65947 .21348 L
.65947 .22319 L
.66026 .22398 L
.66918 .23291 L
Mistroke
.66918 .24262 L
.66997 .2434 L
.6789 .25233 L
.6789 .26204 L
.67968 .26283 L
.68861 .27176 L
.68861 .28147 L
.68939 .28225 L
.69832 .29118 L
.69832 .30089 L
.69911 .30168 L
.70803 .31061 L
.70803 .32032 L
.70803 .33003 L
.70882 .33082 L
.71775 .33974 L
.71775 .34946 L
.71853 .35024 L
.72746 .35917 L
.72746 .36888 L
.72824 .36967 L
.73717 .37859 L
.73717 .38831 L
.73717 .39802 L
.73796 .3988 L
.74688 .40773 L
.74688 .41744 L
.74767 .41823 L
.7566 .42716 L
.7566 .43687 L
.7566 .44658 L
.75738 .44737 L
.76631 .45629 L
.76631 .46601 L
.76631 .47572 L
.76709 .4765 L
.77602 .48543 L
.77602 .49514 L
.77602 .50486 L
.77681 .50564 L
.78573 .51457 L
.78573 .52428 L
.78573 .53399 L
.78652 .53478 L
.79545 .54371 L
.79545 .55342 L
.79545 .56313 L
.79623 .56392 L
.80516 .57284 L
.80516 .58256 L
Mistroke
.80516 .59227 L
.80594 .59305 L
.81487 .60198 L
.81487 .61169 L
.81487 .62141 L
.81566 .62219 L
.82458 .63112 L
.82458 .64083 L
.82458 .65054 L
.82537 .65133 L
.8343 .66026 L
.8343 .66997 L
.8343 .67968 L
.83508 .68047 L
.84401 .68939 L
.84401 .69911 L
.84401 .70882 L
.84401 .71853 L
.84479 .71932 L
.85372 .72824 L
.85372 .73796 L
.85372 .74767 L
.85451 .74845 L
.86343 .75738 L
.86343 .76709 L
.86343 .77681 L
.86343 .78652 L
.86422 .7873 L
.87315 .79623 L
.87315 .80594 L
.87315 .81566 L
.87315 .82537 L
.87393 .82615 L
.88286 .83508 L
.88286 .84479 L
.88286 .85451 L
.88364 .85529 L
.89257 .86422 L
.89257 .87393 L
.89257 .88364 L
.88364 .89257 L
.87393 .89257 L
.86422 .89257 L
.85529 .88364 L
.85451 .88286 L
.84479 .88286 L
.83508 .88286 L
.82615 .87393 L
.82537 .87315 L
.81566 .87315 L
Mistroke
.80594 .87315 L
.79623 .87315 L
.7873 .86422 L
.78652 .86343 L
.77681 .86343 L
.76709 .86343 L
.75817 .85451 L
.75738 .85372 L
.74767 .85372 L
.73796 .85372 L
.72903 .84479 L
.72824 .84401 L
.71853 .84401 L
.70882 .84401 L
.69911 .84401 L
.69018 .83508 L
.68939 .8343 L
.67968 .8343 L
.66997 .8343 L
.66104 .82537 L
.66026 .82458 L
.65054 .82458 L
.64083 .82458 L
.63112 .82458 L
.62219 .81566 L
.62141 .81487 L
.61169 .81487 L
.60198 .81487 L
.59305 .80594 L
.59227 .80516 L
.58256 .80516 L
.57284 .80516 L
.56392 .79623 L
.56313 .79545 L
.55342 .79545 L
.54371 .79545 L
.53399 .79545 L
.52507 .78652 L
.52428 .78573 L
.51457 .78573 L
.50486 .78573 L
.49593 .77681 L
.49514 .77602 L
.48543 .77602 L
.47572 .77602 L
.46601 .77602 L
.45708 .76709 L
.45629 .76631 L
.44658 .76631 L
.43687 .76631 L
Mistroke
.42794 .75738 L
.42716 .7566 L
.41744 .7566 L
.40773 .7566 L
.3988 .74767 L
.39802 .74688 L
.38831 .74688 L
.37859 .74688 L
.36888 .74688 L
.35995 .73796 L
.35917 .73717 L
.34946 .73717 L
.33974 .73717 L
.33082 .72824 L
.33003 .72746 L
.32032 .72746 L
.31061 .72746 L
.30089 .72746 L
.29197 .71853 L
.29118 .71775 L
.28147 .71775 L
.27176 .71775 L
.26283 .70882 L
.26204 .70803 L
.25233 .70803 L
.24262 .70803 L
.23369 .69911 L
.23291 .69832 L
.22319 .69832 L
.21348 .69832 L
.20377 .69832 L
.19484 .68939 L
.19406 .68861 L
.18434 .68861 L
.17463 .68861 L
.1657 .67968 L
.16492 .6789 L
.15521 .6789 L
.14549 .6789 L
.13578 .6789 L
.12685 .66997 L
.12607 .66918 L
.11636 .66918 L
.10664 .66918 L
.09772 .66026 L
.09693 .65947 L
.08722 .65947 L
.07751 .65947 L
.06858 .65054 L
.06779 .64976 L
Mistroke
.05808 .64976 L
.04915 .64083 L
.04915 .63112 L
.05808 .62219 L
.05887 .62141 L
.05887 .61169 L
.05887 .60198 L
.06779 .59305 L
.06858 .59227 L
.06858 .58256 L
.06858 .57284 L
.07751 .56392 L
.07829 .56313 L
.07829 .55342 L
.07829 .54371 L
.08722 .53478 L
.088 .53399 L
.088 .52428 L
.088 .51457 L
.09693 .50564 L
.09772 .50486 L
.09772 .49514 L
.09772 .48543 L
.10664 .4765 L
.10743 .47572 L
.10743 .46601 L
.10743 .45629 L
.11636 .44737 L
.11714 .44658 L
.11714 .43687 L
.12607 .42794 L
.12685 .42716 L
.12685 .41744 L
.12685 .40773 L
.13578 .3988 L
.13657 .39802 L
.13657 .38831 L
.14549 .37938 L
.14628 .37859 L
.14628 .36888 L
.14628 .35917 L
.15521 .35024 L
.15599 .34946 L
.15599 .33974 L
.16492 .33082 L
.1657 .33003 L
.1657 .32032 L
.17463 .31139 L
.17542 .31061 L
.17542 .30089 L
Mistroke
.17542 .29118 L
.18434 .28225 L
.18513 .28147 L
.18513 .27176 L
.19406 .26283 L
.19484 .26204 L
.19484 .25233 L
.20377 .2434 L
.20455 .24262 L
.20455 .23291 L
.21348 .22398 L
.21427 .22319 L
.21427 .21348 L
.22319 .20455 L
.22398 .20377 L
.23291 .19484 L
.23369 .19406 L
.23369 .18434 L
.24262 .17542 L
.2434 .17463 L
.2434 .16492 L
.25233 .15599 L
.25312 .15521 L
.26204 .14628 L
.26283 .14549 L
.26283 .13578 L
.27176 .12685 L
.27254 .12607 L
.28147 .11714 L
.28225 .11636 L
.29118 .10743 L
.29197 .10664 L
.30089 .09772 L
.30168 .09693 L
.30168 .08722 L
.31061 .07829 L
.31139 .07751 L
.32032 .06858 L
.33003 .06858 L
.33082 .06779 L
.33974 .05887 L
.34053 .05808 L
.34946 .04915 L
.35024 .04837 L
.35917 .03944 L
.36888 .03944 L
.36967 .03866 L
.37859 .02973 L
.38831 .02973 L
.38909 .02894 L
Mistroke
.39802 .01961 L
Mfstroke
.2 g
.39802 .02016 m
.40773 .02016 L
.41744 .02016 L
.42716 .02016 L
.43687 .02016 L
.44658 .02016 L
.45629 .02016 L
.46601 .02016 L
.47572 .02016 L
.48367 .02894 L
.48543 .03071 L
.49514 .03071 L
.50486 .03071 L
.5128 .03866 L
.51457 .04042 L
.52252 .04837 L
.52428 .05013 L
.53223 .05808 L
.53399 .05985 L
.54371 .05985 L
.55165 .06779 L
.55342 .06956 L
.56137 .07751 L
.56313 .07927 L
.57108 .08722 L
.57108 .09693 L
.57284 .0987 L
.58079 .10664 L
.58256 .10841 L
.5905 .11636 L
.59227 .11812 L
.60022 .12607 L
.60198 .12783 L
.60993 .13578 L
.60993 .14549 L
.61169 .14726 L
.61964 .15521 L
.62141 .15697 L
.62935 .16492 L
.62935 .17463 L
.63112 .1764 L
.63907 .18434 L
.63907 .19406 L
.64083 .19582 L
.64878 .20377 L
.65054 .20553 L
.65849 .21348 L
.65849 .22319 L
.66026 .22496 L
.6682 .23291 L
.6682 .24262 L
.66997 .24438 L
.67792 .25233 L
.67792 .26204 L
.67968 .26381 L
.68763 .27176 L
.68763 .28147 L
.68939 .28323 L
.69734 .29118 L
.69734 .30089 L
.69911 .30266 L
.70705 .31061 L
.70705 .32032 L
.70705 .33003 L
.70882 .3318 L
.71677 .33974 L
.71677 .34946 L
.71853 .35122 L
.72648 .35917 L
.72648 .36888 L
.72824 .37065 L
.73619 .37859 L
.73619 .38831 L
.73619 .39802 L
.73796 .39978 L
.7459 .40773 L
.7459 .41744 L
.74767 .41921 L
.75562 .42716 L
.75562 .43687 L
.75562 .44658 L
.75738 .44835 L
.76533 .45629 L
.76533 .46601 L
.76533 .47572 L
.76709 .47748 L
.77504 .48543 L
.77504 .49514 L
.77504 .50486 L
.77681 .50662 L
.78475 .51457 L
.78475 .52428 L
.78475 .53399 L
.78652 .53576 L
.79447 .54371 L
.79447 .55342 L
.79447 .56313 L
.79623 .5649 L
.80418 .57284 L
.80418 .58256 L
.80418 .59227 L
.80594 .59403 L
.81389 .60198 L
.81389 .61169 L
.81389 .62141 L
.81566 .62317 L
.8236 .63112 L
.8236 .64083 L
.8236 .65054 L
.82537 .65231 L
.83332 .66026 L
.83332 .66997 L
.83332 .67968 L
.83508 .68145 L
.84303 .68939 L
.84303 .69911 L
.84303 .70882 L
.84303 .71853 L
.84479 .7203 L
.85274 .72824 L
.85274 .73796 L
.85274 .74767 L
.85451 .74943 L
.86245 .75738 L
.86245 .76709 L
.86245 .77681 L
.86245 .78652 L
.86422 .78828 L
.87217 .79623 L
.87217 .80594 L
.87217 .81566 L
.87217 .82537 L
.87393 .82713 L
.88188 .83508 L
.88188 .84479 L
.88188 .85451 L
.88364 .85627 L
.89159 .86422 L
.89159 .87393 L
.89159 .88364 L
.88364 .89159 L
.87393 .89159 L
.86422 .89159 L
.85627 .88364 L
.85451 .88188 L
.84479 .88188 L
.83508 .88188 L
.82713 .87393 L
.82537 .87217 L
.81566 .87217 L
.80594 .87217 L
.79623 .87217 L
.78828 .86422 L
.78652 .86245 L
.77681 .86245 L
.76709 .86245 L
.75915 .85451 L
.75738 .85274 L
.74767 .85274 L
.73796 .85274 L
.73001 .84479 L
.72824 .84303 L
.71853 .84303 L
.70882 .84303 L
.69911 .84303 L
.69116 .83508 L
.68939 .83332 L
.67968 .83332 L
.66997 .83332 L
.66202 .82537 L
.66026 .8236 L
.65054 .8236 L
.64083 .8236 L
.63112 .8236 L
.62317 .81566 L
.62141 .81389 L
.61169 .81389 L
.60198 .81389 L
.59403 .80594 L
.59227 .80418 L
.58256 .80418 L
.57284 .80418 L
.5649 .79623 L
.56313 .79447 L
.55342 .79447 L
.54371 .79447 L
.53399 .79447 L
.52605 .78652 L
.52428 .78475 L
.51457 .78475 L
.50486 .78475 L
.49691 .77681 L
.49514 .77504 L
.48543 .77504 L
.47572 .77504 L
.46601 .77504 L
.45806 .76709 L
.45629 .76533 L
.44658 .76533 L
.43687 .76533 L
.42892 .75738 L
.42716 .75562 L
.41744 .75562 L
.40773 .75562 L
.39978 .74767 L
.39802 .7459 L
.38831 .7459 L
.37859 .7459 L
.36888 .7459 L
.36093 .73796 L
.35917 .73619 L
.34946 .73619 L
.33974 .73619 L
.3318 .72824 L
.33003 .72648 L
.32032 .72648 L
.31061 .72648 L
.30089 .72648 L
.29295 .71853 L
.29118 .71677 L
.28147 .71677 L
.27176 .71677 L
.26381 .70882 L
.26204 .70705 L
.25233 .70705 L
.24262 .70705 L
.23467 .69911 L
.23291 .69734 L
.22319 .69734 L
.21348 .69734 L
.20377 .69734 L
.19582 .68939 L
.19406 .68763 L
.18434 .68763 L
.17463 .68763 L
.16668 .67968 L
.16492 .67792 L
.15521 .67792 L
.14549 .67792 L
.13578 .67792 L
.12783 .66997 L
.12607 .6682 L
.11636 .6682 L
.10664 .6682 L
.0987 .66026 L
.09693 .65849 L
.08722 .65849 L
.07751 .65849 L
.06956 .65054 L
.06779 .64878 L
.05808 .64878 L
.05013 .64083 L
.05013 .63112 L
.05808 .62317 L
.05985 .62141 L
.05985 .61169 L
.05985 .60198 L
.06779 .59403 L
.06956 .59227 L
.06956 .58256 L
.06956 .57284 L
.07751 .5649 L
.07927 .56313 L
.07927 .55342 L
.07927 .54371 L
.08722 .53576 L
.08898 .53399 L
.08898 .52428 L
.08898 .51457 L
.09693 .50662 L
.0987 .50486 L
.0987 .49514 L
.0987 .48543 L
.10664 .47748 L
.10841 .47572 L
.10841 .46601 L
.10841 .45629 L
.11636 .44835 L
.11812 .44658 L
.11812 .43687 L
.12607 .42892 L
.12783 .42716 L
.12783 .41744 L
.12783 .40773 L
.13578 .39978 L
.13755 .39802 L
.13755 .38831 L
.14549 .38036 L
.14726 .37859 L
.14726 .36888 L
.14726 .35917 L
.15521 .35122 L
.15697 .34946 L
.15697 .33974 L
.16492 .3318 L
.16668 .33003 L
.16668 .32032 L
.17463 .31237 L
.1764 .31061 L
.1764 .30089 L
.1764 .29118 L
.18434 .28323 L
.18611 .28147 L
.18611 .27176 L
.19406 .26381 L
.19582 .26204 L
.19582 .25233 L
.20377 .24438 L
.20553 .24262 L
.20553 .23291 L
.21348 .22496 L
.21525 .22319 L
.21525 .21348 L
.22319 .20553 L
.22496 .20377 L
.23291 .19582 L
.23467 .19406 L
.23467 .18434 L
.24262 .1764 L
.24438 .17463 L
.24438 .16492 L
.25233 .15697 L
.2541 .15521 L
.26204 .14726 L
.26381 .14549 L
.26381 .13578 L
.27176 .12783 L
.27352 .12607 L
.28147 .11812 L
.28323 .11636 L
.29118 .10841 L
.29295 .10664 L
.30089 .0987 L
.30266 .09693 L
.30266 .08722 L
.31061 .07927 L
.31237 .07751 L
.32032 .06956 L
.33003 .06956 L
.3318 .06779 L
.33974 .05985 L
.34151 .05808 L
.34946 .05013 L
.35122 .04837 L
.35917 .04042 L
.36888 .04042 L
.37065 .03866 L
.37859 .03071 L
.38831 .03071 L
.39007 .02894 L
F
0 g
.39802 .02016 m
.40773 .02016 L
.41744 .02016 L
.42716 .02016 L
.43687 .02016 L
.44658 .02016 L
.45629 .02016 L
.46601 .02016 L
.47572 .02016 L
.48367 .02894 L
.48543 .03071 L
.49514 .03071 L
.50486 .03071 L
.5128 .03866 L
.51457 .04042 L
.52252 .04837 L
.52428 .05013 L
.53223 .05808 L
.53399 .05985 L
.54371 .05985 L
.55165 .06779 L
.55342 .06956 L
.56137 .07751 L
.56313 .07927 L
.57108 .08722 L
.57108 .09693 L
.57284 .0987 L
.58079 .10664 L
.58256 .10841 L
.5905 .11636 L
.59227 .11812 L
.60022 .12607 L
.60198 .12783 L
.60993 .13578 L
.60993 .14549 L
.61169 .14726 L
.61964 .15521 L
.62141 .15697 L
.62935 .16492 L
.62935 .17463 L
.63112 .1764 L
.63907 .18434 L
.63907 .19406 L
.64083 .19582 L
.64878 .20377 L
.65054 .20553 L
.65849 .21348 L
.65849 .22319 L
.66026 .22496 L
.6682 .23291 L
Mistroke
.6682 .24262 L
.66997 .24438 L
.67792 .25233 L
.67792 .26204 L
.67968 .26381 L
.68763 .27176 L
.68763 .28147 L
.68939 .28323 L
.69734 .29118 L
.69734 .30089 L
.69911 .30266 L
.70705 .31061 L
.70705 .32032 L
.70705 .33003 L
.70882 .3318 L
.71677 .33974 L
.71677 .34946 L
.71853 .35122 L
.72648 .35917 L
.72648 .36888 L
.72824 .37065 L
.73619 .37859 L
.73619 .38831 L
.73619 .39802 L
.73796 .39978 L
.7459 .40773 L
.7459 .41744 L
.74767 .41921 L
.75562 .42716 L
.75562 .43687 L
.75562 .44658 L
.75738 .44835 L
.76533 .45629 L
.76533 .46601 L
.76533 .47572 L
.76709 .47748 L
.77504 .48543 L
.77504 .49514 L
.77504 .50486 L
.77681 .50662 L
.78475 .51457 L
.78475 .52428 L
.78475 .53399 L
.78652 .53576 L
.79447 .54371 L
.79447 .55342 L
.79447 .56313 L
.79623 .5649 L
.80418 .57284 L
.80418 .58256 L
Mistroke
.80418 .59227 L
.80594 .59403 L
.81389 .60198 L
.81389 .61169 L
.81389 .62141 L
.81566 .62317 L
.8236 .63112 L
.8236 .64083 L
.8236 .65054 L
.82537 .65231 L
.83332 .66026 L
.83332 .66997 L
.83332 .67968 L
.83508 .68145 L
.84303 .68939 L
.84303 .69911 L
.84303 .70882 L
.84303 .71853 L
.84479 .7203 L
.85274 .72824 L
.85274 .73796 L
.85274 .74767 L
.85451 .74943 L
.86245 .75738 L
.86245 .76709 L
.86245 .77681 L
.86245 .78652 L
.86422 .78828 L
.87217 .79623 L
.87217 .80594 L
.87217 .81566 L
.87217 .82537 L
.87393 .82713 L
.88188 .83508 L
.88188 .84479 L
.88188 .85451 L
.88364 .85627 L
.89159 .86422 L
.89159 .87393 L
.89159 .88364 L
.88364 .89159 L
.87393 .89159 L
.86422 .89159 L
.85627 .88364 L
.85451 .88188 L
.84479 .88188 L
.83508 .88188 L
.82713 .87393 L
.82537 .87217 L
.81566 .87217 L
Mistroke
.80594 .87217 L
.79623 .87217 L
.78828 .86422 L
.78652 .86245 L
.77681 .86245 L
.76709 .86245 L
.75915 .85451 L
.75738 .85274 L
.74767 .85274 L
.73796 .85274 L
.73001 .84479 L
.72824 .84303 L
.71853 .84303 L
.70882 .84303 L
.69911 .84303 L
.69116 .83508 L
.68939 .83332 L
.67968 .83332 L
.66997 .83332 L
.66202 .82537 L
.66026 .8236 L
.65054 .8236 L
.64083 .8236 L
.63112 .8236 L
.62317 .81566 L
.62141 .81389 L
.61169 .81389 L
.60198 .81389 L
.59403 .80594 L
.59227 .80418 L
.58256 .80418 L
.57284 .80418 L
.5649 .79623 L
.56313 .79447 L
.55342 .79447 L
.54371 .79447 L
.53399 .79447 L
.52605 .78652 L
.52428 .78475 L
.51457 .78475 L
.50486 .78475 L
.49691 .77681 L
.49514 .77504 L
.48543 .77504 L
.47572 .77504 L
.46601 .77504 L
.45806 .76709 L
.45629 .76533 L
.44658 .76533 L
.43687 .76533 L
Mistroke
.42892 .75738 L
.42716 .75562 L
.41744 .75562 L
.40773 .75562 L
.39978 .74767 L
.39802 .7459 L
.38831 .7459 L
.37859 .7459 L
.36888 .7459 L
.36093 .73796 L
.35917 .73619 L
.34946 .73619 L
.33974 .73619 L
.3318 .72824 L
.33003 .72648 L
.32032 .72648 L
.31061 .72648 L
.30089 .72648 L
.29295 .71853 L
.29118 .71677 L
.28147 .71677 L
.27176 .71677 L
.26381 .70882 L
.26204 .70705 L
.25233 .70705 L
.24262 .70705 L
.23467 .69911 L
.23291 .69734 L
.22319 .69734 L
.21348 .69734 L
.20377 .69734 L
.19582 .68939 L
.19406 .68763 L
.18434 .68763 L
.17463 .68763 L
.16668 .67968 L
.16492 .67792 L
.15521 .67792 L
.14549 .67792 L
.13578 .67792 L
.12783 .66997 L
.12607 .6682 L
.11636 .6682 L
.10664 .6682 L
.0987 .66026 L
.09693 .65849 L
.08722 .65849 L
.07751 .65849 L
.06956 .65054 L
.06779 .64878 L
Mistroke
.05808 .64878 L
.05013 .64083 L
.05013 .63112 L
.05808 .62317 L
.05985 .62141 L
.05985 .61169 L
.05985 .60198 L
.06779 .59403 L
.06956 .59227 L
.06956 .58256 L
.06956 .57284 L
.07751 .5649 L
.07927 .56313 L
.07927 .55342 L
.07927 .54371 L
.08722 .53576 L
.08898 .53399 L
.08898 .52428 L
.08898 .51457 L
.09693 .50662 L
.0987 .50486 L
.0987 .49514 L
.0987 .48543 L
.10664 .47748 L
.10841 .47572 L
.10841 .46601 L
.10841 .45629 L
.11636 .44835 L
.11812 .44658 L
.11812 .43687 L
.12607 .42892 L
.12783 .42716 L
.12783 .41744 L
.12783 .40773 L
.13578 .39978 L
.13755 .39802 L
.13755 .38831 L
.14549 .38036 L
.14726 .37859 L
.14726 .36888 L
.14726 .35917 L
.15521 .35122 L
.15697 .34946 L
.15697 .33974 L
.16492 .3318 L
.16668 .33003 L
.16668 .32032 L
.17463 .31237 L
.1764 .31061 L
.1764 .30089 L
Mistroke
.1764 .29118 L
.18434 .28323 L
.18611 .28147 L
.18611 .27176 L
.19406 .26381 L
.19582 .26204 L
.19582 .25233 L
.20377 .24438 L
.20553 .24262 L
.20553 .23291 L
.21348 .22496 L
.21525 .22319 L
.21525 .21348 L
.22319 .20553 L
.22496 .20377 L
.23291 .19582 L
.23467 .19406 L
.23467 .18434 L
.24262 .1764 L
.24438 .17463 L
.24438 .16492 L
.25233 .15697 L
.2541 .15521 L
.26204 .14726 L
.26381 .14549 L
.26381 .13578 L
.27176 .12783 L
.27352 .12607 L
.28147 .11812 L
.28323 .11636 L
.29118 .10841 L
.29295 .10664 L
.30089 .0987 L
.30266 .09693 L
.30266 .08722 L
.31061 .07927 L
.31237 .07751 L
.32032 .06956 L
.33003 .06956 L
.3318 .06779 L
.33974 .05985 L
.34151 .05808 L
.34946 .05013 L
.35122 .04837 L
.35917 .04042 L
.36888 .04042 L
.37065 .03866 L
.37859 .03071 L
.38831 .03071 L
.39007 .02894 L
Mistroke
.39802 .02016 L
Mfstroke
.3 g
.39802 .02074 m
.40773 .02074 L
.41744 .02074 L
.42716 .02074 L
.43687 .02074 L
.44658 .02074 L
.45629 .02074 L
.46601 .02074 L
.47572 .02074 L
.48275 .02894 L
.48543 .03163 L
.49514 .03163 L
.50486 .03163 L
.51189 .03866 L
.51457 .04134 L
.5216 .04837 L
.52428 .05105 L
.53131 .05808 L
.53399 .06076 L
.54371 .06076 L
.55074 .06779 L
.55342 .07048 L
.56045 .07751 L
.56313 .08019 L
.57016 .08722 L
.57016 .09693 L
.57284 .09961 L
.57987 .10664 L
.58256 .10933 L
.58959 .11636 L
.59227 .11904 L
.5993 .12607 L
.60198 .12875 L
.60901 .13578 L
.60901 .14549 L
.61169 .14818 L
.61872 .15521 L
.62141 .15789 L
.62844 .16492 L
.62844 .17463 L
.63112 .17731 L
.63815 .18434 L
.63815 .19406 L
.64083 .19674 L
.64786 .20377 L
.65054 .20645 L
.65757 .21348 L
.65757 .22319 L
.66026 .22588 L
.66729 .23291 L
.66729 .24262 L
.66997 .2453 L
.677 .25233 L
.677 .26204 L
.67968 .26473 L
.68671 .27176 L
.68671 .28147 L
.68939 .28415 L
.69642 .29118 L
.69642 .30089 L
.69911 .30358 L
.70614 .31061 L
.70614 .32032 L
.70614 .33003 L
.70882 .33271 L
.71585 .33974 L
.71585 .34946 L
.71853 .35214 L
.72556 .35917 L
.72556 .36888 L
.72824 .37156 L
.73527 .37859 L
.73527 .38831 L
.73527 .39802 L
.73796 .4007 L
.74499 .40773 L
.74499 .41744 L
.74767 .42013 L
.7547 .42716 L
.7547 .43687 L
.7547 .44658 L
.75738 .44926 L
.76441 .45629 L
.76441 .46601 L
.76441 .47572 L
.76709 .4784 L
.77412 .48543 L
.77412 .49514 L
.77412 .50486 L
.77681 .50754 L
.78384 .51457 L
.78384 .52428 L
.78384 .53399 L
.78652 .53668 L
.79355 .54371 L
.79355 .55342 L
.79355 .56313 L
.79623 .56581 L
.80326 .57284 L
.80326 .58256 L
.80326 .59227 L
.80594 .59495 L
.81297 .60198 L
.81297 .61169 L
.81297 .62141 L
.81566 .62409 L
.82269 .63112 L
.82269 .64083 L
.82269 .65054 L
.82537 .65323 L
.8324 .66026 L
.8324 .66997 L
.8324 .67968 L
.83508 .68236 L
.84211 .68939 L
.84211 .69911 L
.84211 .70882 L
.84211 .71853 L
.84479 .72121 L
.85182 .72824 L
.85182 .73796 L
.85182 .74767 L
.85451 .75035 L
.86154 .75738 L
.86154 .76709 L
.86154 .77681 L
.86154 .78652 L
.86422 .7892 L
.87125 .79623 L
.87125 .80594 L
.87125 .81566 L
.87125 .82537 L
.87393 .82805 L
.88096 .83508 L
.88096 .84479 L
.88096 .85451 L
.88364 .85719 L
.89067 .86422 L
.89067 .87393 L
.89067 .88364 L
.88364 .89067 L
.87393 .89067 L
.86422 .89067 L
.85719 .88364 L
.85451 .88096 L
.84479 .88096 L
.83508 .88096 L
.82805 .87393 L
.82537 .87125 L
.81566 .87125 L
.80594 .87125 L
.79623 .87125 L
.7892 .86422 L
.78652 .86154 L
.77681 .86154 L
.76709 .86154 L
.76006 .85451 L
.75738 .85182 L
.74767 .85182 L
.73796 .85182 L
.73093 .84479 L
.72824 .84211 L
.71853 .84211 L
.70882 .84211 L
.69911 .84211 L
.69208 .83508 L
.68939 .8324 L
.67968 .8324 L
.66997 .8324 L
.66294 .82537 L
.66026 .82269 L
.65054 .82269 L
.64083 .82269 L
.63112 .82269 L
.62409 .81566 L
.62141 .81297 L
.61169 .81297 L
.60198 .81297 L
.59495 .80594 L
.59227 .80326 L
.58256 .80326 L
.57284 .80326 L
.56581 .79623 L
.56313 .79355 L
.55342 .79355 L
.54371 .79355 L
.53399 .79355 L
.52696 .78652 L
.52428 .78384 L
.51457 .78384 L
.50486 .78384 L
.49783 .77681 L
.49514 .77412 L
.48543 .77412 L
.47572 .77412 L
.46601 .77412 L
.45898 .76709 L
.45629 .76441 L
.44658 .76441 L
.43687 .76441 L
.42984 .75738 L
.42716 .7547 L
.41744 .7547 L
.40773 .7547 L
.4007 .74767 L
.39802 .74499 L
.38831 .74499 L
.37859 .74499 L
.36888 .74499 L
.36185 .73796 L
.35917 .73527 L
.34946 .73527 L
.33974 .73527 L
.33271 .72824 L
.33003 .72556 L
.32032 .72556 L
.31061 .72556 L
.30089 .72556 L
.29386 .71853 L
.29118 .71585 L
.28147 .71585 L
.27176 .71585 L
.26473 .70882 L
.26204 .70614 L
.25233 .70614 L
.24262 .70614 L
.23559 .69911 L
.23291 .69642 L
.22319 .69642 L
.21348 .69642 L
.20377 .69642 L
.19674 .68939 L
.19406 .68671 L
.18434 .68671 L
.17463 .68671 L
.1676 .67968 L
.16492 .677 L
.15521 .677 L
.14549 .677 L
.13578 .677 L
.12875 .66997 L
.12607 .66729 L
.11636 .66729 L
.10664 .66729 L
.09961 .66026 L
.09693 .65757 L
.08722 .65757 L
.07751 .65757 L
.07048 .65054 L
.06779 .64786 L
.05808 .64786 L
.05105 .64083 L
.05105 .63112 L
.05808 .62409 L
.06076 .62141 L
.06076 .61169 L
.06076 .60198 L
.06779 .59495 L
.07048 .59227 L
.07048 .58256 L
.07048 .57284 L
.07751 .56581 L
.08019 .56313 L
.08019 .55342 L
.08019 .54371 L
.08722 .53668 L
.0899 .53399 L
.0899 .52428 L
.0899 .51457 L
.09693 .50754 L
.09961 .50486 L
.09961 .49514 L
.09961 .48543 L
.10664 .4784 L
.10933 .47572 L
.10933 .46601 L
.10933 .45629 L
.11636 .44926 L
.11904 .44658 L
.11904 .43687 L
.12607 .42984 L
.12875 .42716 L
.12875 .41744 L
.12875 .40773 L
.13578 .4007 L
.13846 .39802 L
.13846 .38831 L
.14549 .38128 L
.14818 .37859 L
.14818 .36888 L
.14818 .35917 L
.15521 .35214 L
.15789 .34946 L
.15789 .33974 L
.16492 .33271 L
.1676 .33003 L
.1676 .32032 L
.17463 .31329 L
.17731 .31061 L
.17731 .30089 L
.17731 .29118 L
.18434 .28415 L
.18703 .28147 L
.18703 .27176 L
.19406 .26473 L
.19674 .26204 L
.19674 .25233 L
.20377 .2453 L
.20645 .24262 L
.20645 .23291 L
.21348 .22588 L
.21616 .22319 L
.21616 .21348 L
.22319 .20645 L
.22588 .20377 L
.23291 .19674 L
.23559 .19406 L
.23559 .18434 L
.24262 .17731 L
.2453 .17463 L
.2453 .16492 L
.25233 .15789 L
.25501 .15521 L
.26204 .14818 L
.26473 .14549 L
.26473 .13578 L
.27176 .12875 L
.27444 .12607 L
.28147 .11904 L
.28415 .11636 L
.29118 .10933 L
.29386 .10664 L
.30089 .09961 L
.30358 .09693 L
.30358 .08722 L
.31061 .08019 L
.31329 .07751 L
.32032 .07048 L
.33003 .07048 L
.33271 .06779 L
.33974 .06076 L
.34243 .05808 L
.34946 .05105 L
.35214 .04837 L
.35917 .04134 L
.36888 .04134 L
.37156 .03866 L
.37859 .03163 L
.38831 .03163 L
.39099 .02894 L
F
0 g
.39802 .02074 m
.40773 .02074 L
.41744 .02074 L
.42716 .02074 L
.43687 .02074 L
.44658 .02074 L
.45629 .02074 L
.46601 .02074 L
.47572 .02074 L
.48275 .02894 L
.48543 .03163 L
.49514 .03163 L
.50486 .03163 L
.51189 .03866 L
.51457 .04134 L
.5216 .04837 L
.52428 .05105 L
.53131 .05808 L
.53399 .06076 L
.54371 .06076 L
.55074 .06779 L
.55342 .07048 L
.56045 .07751 L
.56313 .08019 L
.57016 .08722 L
.57016 .09693 L
.57284 .09961 L
.57987 .10664 L
.58256 .10933 L
.58959 .11636 L
.59227 .11904 L
.5993 .12607 L
.60198 .12875 L
.60901 .13578 L
.60901 .14549 L
.61169 .14818 L
.61872 .15521 L
.62141 .15789 L
.62844 .16492 L
.62844 .17463 L
.63112 .17731 L
.63815 .18434 L
.63815 .19406 L
.64083 .19674 L
.64786 .20377 L
.65054 .20645 L
.65757 .21348 L
.65757 .22319 L
.66026 .22588 L
.66729 .23291 L
Mistroke
.66729 .24262 L
.66997 .2453 L
.677 .25233 L
.677 .26204 L
.67968 .26473 L
.68671 .27176 L
.68671 .28147 L
.68939 .28415 L
.69642 .29118 L
.69642 .30089 L
.69911 .30358 L
.70614 .31061 L
.70614 .32032 L
.70614 .33003 L
.70882 .33271 L
.71585 .33974 L
.71585 .34946 L
.71853 .35214 L
.72556 .35917 L
.72556 .36888 L
.72824 .37156 L
.73527 .37859 L
.73527 .38831 L
.73527 .39802 L
.73796 .4007 L
.74499 .40773 L
.74499 .41744 L
.74767 .42013 L
.7547 .42716 L
.7547 .43687 L
.7547 .44658 L
.75738 .44926 L
.76441 .45629 L
.76441 .46601 L
.76441 .47572 L
.76709 .4784 L
.77412 .48543 L
.77412 .49514 L
.77412 .50486 L
.77681 .50754 L
.78384 .51457 L
.78384 .52428 L
.78384 .53399 L
.78652 .53668 L
.79355 .54371 L
.79355 .55342 L
.79355 .56313 L
.79623 .56581 L
.80326 .57284 L
.80326 .58256 L
Mistroke
.80326 .59227 L
.80594 .59495 L
.81297 .60198 L
.81297 .61169 L
.81297 .62141 L
.81566 .62409 L
.82269 .63112 L
.82269 .64083 L
.82269 .65054 L
.82537 .65323 L
.8324 .66026 L
.8324 .66997 L
.8324 .67968 L
.83508 .68236 L
.84211 .68939 L
.84211 .69911 L
.84211 .70882 L
.84211 .71853 L
.84479 .72121 L
.85182 .72824 L
.85182 .73796 L
.85182 .74767 L
.85451 .75035 L
.86154 .75738 L
.86154 .76709 L
.86154 .77681 L
.86154 .78652 L
.86422 .7892 L
.87125 .79623 L
.87125 .80594 L
.87125 .81566 L
.87125 .82537 L
.87393 .82805 L
.88096 .83508 L
.88096 .84479 L
.88096 .85451 L
.88364 .85719 L
.89067 .86422 L
.89067 .87393 L
.89067 .88364 L
.88364 .89067 L
.87393 .89067 L
.86422 .89067 L
.85719 .88364 L
.85451 .88096 L
.84479 .88096 L
.83508 .88096 L
.82805 .87393 L
.82537 .87125 L
.81566 .87125 L
Mistroke
.80594 .87125 L
.79623 .87125 L
.7892 .86422 L
.78652 .86154 L
.77681 .86154 L
.76709 .86154 L
.76006 .85451 L
.75738 .85182 L
.74767 .85182 L
.73796 .85182 L
.73093 .84479 L
.72824 .84211 L
.71853 .84211 L
.70882 .84211 L
.69911 .84211 L
.69208 .83508 L
.68939 .8324 L
.67968 .8324 L
.66997 .8324 L
.66294 .82537 L
.66026 .82269 L
.65054 .82269 L
.64083 .82269 L
.63112 .82269 L
.62409 .81566 L
.62141 .81297 L
.61169 .81297 L
.60198 .81297 L
.59495 .80594 L
.59227 .80326 L
.58256 .80326 L
.57284 .80326 L
.56581 .79623 L
.56313 .79355 L
.55342 .79355 L
.54371 .79355 L
.53399 .79355 L
.52696 .78652 L
.52428 .78384 L
.51457 .78384 L
.50486 .78384 L
.49783 .77681 L
.49514 .77412 L
.48543 .77412 L
.47572 .77412 L
.46601 .77412 L
.45898 .76709 L
.45629 .76441 L
.44658 .76441 L
.43687 .76441 L
Mistroke
.42984 .75738 L
.42716 .7547 L
.41744 .7547 L
.40773 .7547 L
.4007 .74767 L
.39802 .74499 L
.38831 .74499 L
.37859 .74499 L
.36888 .74499 L
.36185 .73796 L
.35917 .73527 L
.34946 .73527 L
.33974 .73527 L
.33271 .72824 L
.33003 .72556 L
.32032 .72556 L
.31061 .72556 L
.30089 .72556 L
.29386 .71853 L
.29118 .71585 L
.28147 .71585 L
.27176 .71585 L
.26473 .70882 L
.26204 .70614 L
.25233 .70614 L
.24262 .70614 L
.23559 .69911 L
.23291 .69642 L
.22319 .69642 L
.21348 .69642 L
.20377 .69642 L
.19674 .68939 L
.19406 .68671 L
.18434 .68671 L
.17463 .68671 L
.1676 .67968 L
.16492 .677 L
.15521 .677 L
.14549 .677 L
.13578 .677 L
.12875 .66997 L
.12607 .66729 L
.11636 .66729 L
.10664 .66729 L
.09961 .66026 L
.09693 .65757 L
.08722 .65757 L
.07751 .65757 L
.07048 .65054 L
.06779 .64786 L
Mistroke
.05808 .64786 L
.05105 .64083 L
.05105 .63112 L
.05808 .62409 L
.06076 .62141 L
.06076 .61169 L
.06076 .60198 L
.06779 .59495 L
.07048 .59227 L
.07048 .58256 L
.07048 .57284 L
.07751 .56581 L
.08019 .56313 L
.08019 .55342 L
.08019 .54371 L
.08722 .53668 L
.0899 .53399 L
.0899 .52428 L
.0899 .51457 L
.09693 .50754 L
.09961 .50486 L
.09961 .49514 L
.09961 .48543 L
.10664 .4784 L
.10933 .47572 L
.10933 .46601 L
.10933 .45629 L
.11636 .44926 L
.11904 .44658 L
.11904 .43687 L
.12607 .42984 L
.12875 .42716 L
.12875 .41744 L
.12875 .40773 L
.13578 .4007 L
.13846 .39802 L
.13846 .38831 L
.14549 .38128 L
.14818 .37859 L
.14818 .36888 L
.14818 .35917 L
.15521 .35214 L
.15789 .34946 L
.15789 .33974 L
.16492 .33271 L
.1676 .33003 L
.1676 .32032 L
.17463 .31329 L
.17731 .31061 L
.17731 .30089 L
Mistroke
.17731 .29118 L
.18434 .28415 L
.18703 .28147 L
.18703 .27176 L
.19406 .26473 L
.19674 .26204 L
.19674 .25233 L
.20377 .2453 L
.20645 .24262 L
.20645 .23291 L
.21348 .22588 L
.21616 .22319 L
.21616 .21348 L
.22319 .20645 L
.22588 .20377 L
.23291 .19674 L
.23559 .19406 L
.23559 .18434 L
.24262 .17731 L
.2453 .17463 L
.2453 .16492 L
.25233 .15789 L
.25501 .15521 L
.26204 .14818 L
.26473 .14549 L
.26473 .13578 L
.27176 .12875 L
.27444 .12607 L
.28147 .11904 L
.28415 .11636 L
.29118 .10933 L
.29386 .10664 L
.30089 .09961 L
.30358 .09693 L
.30358 .08722 L
.31061 .08019 L
.31329 .07751 L
.32032 .07048 L
.33003 .07048 L
.33271 .06779 L
.33974 .06076 L
.34243 .05808 L
.34946 .05105 L
.35214 .04837 L
.35917 .04134 L
.36888 .04134 L
.37156 .03866 L
.37859 .03163 L
.38831 .03163 L
.39099 .02894 L
Mistroke
.39802 .02074 L
Mfstroke
.4 g
.39802 .02137 m
.40773 .02137 L
.41744 .02137 L
.42716 .02137 L
.43687 .02137 L
.44658 .02137 L
.45629 .02137 L
.46601 .02137 L
.47572 .02137 L
.48187 .02894 L
.48543 .03251 L
.49514 .03251 L
.50486 .03251 L
.511 .03866 L
.51457 .04222 L
.52072 .04837 L
.52428 .05193 L
.53043 .05808 L
.53399 .06165 L
.54371 .06165 L
.54985 .06779 L
.55342 .07136 L
.55957 .07751 L
.56313 .08107 L
.56928 .08722 L
.56928 .09693 L
.57284 .1005 L
.57899 .10664 L
.58256 .11021 L
.5887 .11636 L
.59227 .11992 L
.59842 .12607 L
.60198 .12963 L
.60813 .13578 L
.60813 .14549 L
.61169 .14906 L
.61784 .15521 L
.62141 .15877 L
.62755 .16492 L
.62755 .17463 L
.63112 .1782 L
.63727 .18434 L
.63727 .19406 L
.64083 .19762 L
.64698 .20377 L
.65054 .20733 L
.65669 .21348 L
.65669 .22319 L
.66026 .22676 L
.6664 .23291 L
.6664 .24262 L
.66997 .24618 L
.67612 .25233 L
.67612 .26204 L
.67968 .26561 L
.68583 .27176 L
.68583 .28147 L
.68939 .28503 L
.69554 .29118 L
.69554 .30089 L
.69911 .30446 L
.70525 .31061 L
.70525 .32032 L
.70525 .33003 L
.70882 .3336 L
.71497 .33974 L
.71497 .34946 L
.71853 .35302 L
.72468 .35917 L
.72468 .36888 L
.72824 .37245 L
.73439 .37859 L
.73439 .38831 L
.73439 .39802 L
.73796 .40158 L
.7441 .40773 L
.7441 .41744 L
.74767 .42101 L
.75382 .42716 L
.75382 .43687 L
.75382 .44658 L
.75738 .45015 L
.76353 .45629 L
.76353 .46601 L
.76353 .47572 L
.76709 .47928 L
.77324 .48543 L
.77324 .49514 L
.77324 .50486 L
.77681 .50842 L
.78295 .51457 L
.78295 .52428 L
.78295 .53399 L
.78652 .53756 L
.79267 .54371 L
.79267 .55342 L
.79267 .56313 L
.79623 .5667 L
.80238 .57284 L
.80238 .58256 L
.80238 .59227 L
.80594 .59583 L
.81209 .60198 L
.81209 .61169 L
.81209 .62141 L
.81566 .62497 L
.8218 .63112 L
.8218 .64083 L
.8218 .65054 L
.82537 .65411 L
.83152 .66026 L
.83152 .66997 L
.83152 .67968 L
.83508 .68325 L
.84123 .68939 L
.84123 .69911 L
.84123 .70882 L
.84123 .71853 L
.84479 .7221 L
.85094 .72824 L
.85094 .73796 L
.85094 .74767 L
.85451 .75123 L
.86065 .75738 L
.86065 .76709 L
.86065 .77681 L
.86065 .78652 L
.86422 .79008 L
.87037 .79623 L
.87037 .80594 L
.87037 .81566 L
.87037 .82537 L
.87393 .82893 L
.88008 .83508 L
.88008 .84479 L
.88008 .85451 L
.88364 .85807 L
.88979 .86422 L
.88979 .87393 L
.88979 .88364 L
.88364 .88979 L
.87393 .88979 L
.86422 .88979 L
.85807 .88364 L
.85451 .88008 L
.84479 .88008 L
.83508 .88008 L
.82893 .87393 L
.82537 .87037 L
.81566 .87037 L
.80594 .87037 L
.79623 .87037 L
.79008 .86422 L
.78652 .86065 L
.77681 .86065 L
.76709 .86065 L
.76095 .85451 L
.75738 .85094 L
.74767 .85094 L
.73796 .85094 L
.73181 .84479 L
.72824 .84123 L
.71853 .84123 L
.70882 .84123 L
.69911 .84123 L
.69296 .83508 L
.68939 .83152 L
.67968 .83152 L
.66997 .83152 L
.66382 .82537 L
.66026 .8218 L
.65054 .8218 L
.64083 .8218 L
.63112 .8218 L
.62497 .81566 L
.62141 .81209 L
.61169 .81209 L
.60198 .81209 L
.59583 .80594 L
.59227 .80238 L
.58256 .80238 L
.57284 .80238 L
.5667 .79623 L
.56313 .79267 L
.55342 .79267 L
.54371 .79267 L
.53399 .79267 L
.52785 .78652 L
.52428 .78295 L
.51457 .78295 L
.50486 .78295 L
.49871 .77681 L
.49514 .77324 L
.48543 .77324 L
.47572 .77324 L
.46601 .77324 L
.45986 .76709 L
.45629 .76353 L
.44658 .76353 L
.43687 .76353 L
.43072 .75738 L
.42716 .75382 L
.41744 .75382 L
.40773 .75382 L
.40158 .74767 L
.39802 .7441 L
.38831 .7441 L
.37859 .7441 L
.36888 .7441 L
.36273 .73796 L
.35917 .73439 L
.34946 .73439 L
.33974 .73439 L
.3336 .72824 L
.33003 .72468 L
.32032 .72468 L
.31061 .72468 L
.30089 .72468 L
.29475 .71853 L
.29118 .71497 L
.28147 .71497 L
.27176 .71497 L
.26561 .70882 L
.26204 .70525 L
.25233 .70525 L
.24262 .70525 L
.23647 .69911 L
.23291 .69554 L
.22319 .69554 L
.21348 .69554 L
.20377 .69554 L
.19762 .68939 L
.19406 .68583 L
.18434 .68583 L
.17463 .68583 L
.16848 .67968 L
.16492 .67612 L
.15521 .67612 L
.14549 .67612 L
.13578 .67612 L
.12963 .66997 L
.12607 .6664 L
.11636 .6664 L
.10664 .6664 L
.1005 .66026 L
.09693 .65669 L
.08722 .65669 L
.07751 .65669 L
.07136 .65054 L
.06779 .64698 L
.05808 .64698 L
.05193 .64083 L
.05193 .63112 L
.05808 .62497 L
.06165 .62141 L
.06165 .61169 L
.06165 .60198 L
.06779 .59583 L
.07136 .59227 L
.07136 .58256 L
.07136 .57284 L
.07751 .5667 L
.08107 .56313 L
.08107 .55342 L
.08107 .54371 L
.08722 .53756 L
.09078 .53399 L
.09078 .52428 L
.09078 .51457 L
.09693 .50842 L
.1005 .50486 L
.1005 .49514 L
.1005 .48543 L
.10664 .47928 L
.11021 .47572 L
.11021 .46601 L
.11021 .45629 L
.11636 .45015 L
.11992 .44658 L
.11992 .43687 L
.12607 .43072 L
.12963 .42716 L
.12963 .41744 L
.12963 .40773 L
.13578 .40158 L
.13935 .39802 L
.13935 .38831 L
.14549 .38216 L
.14906 .37859 L
.14906 .36888 L
.14906 .35917 L
.15521 .35302 L
.15877 .34946 L
.15877 .33974 L
.16492 .3336 L
.16848 .33003 L
.16848 .32032 L
.17463 .31417 L
.1782 .31061 L
.1782 .30089 L
.1782 .29118 L
.18434 .28503 L
.18791 .28147 L
.18791 .27176 L
.19406 .26561 L
.19762 .26204 L
.19762 .25233 L
.20377 .24618 L
.20733 .24262 L
.20733 .23291 L
.21348 .22676 L
.21705 .22319 L
.21705 .21348 L
.22319 .20733 L
.22676 .20377 L
.23291 .19762 L
.23647 .19406 L
.23647 .18434 L
.24262 .1782 L
.24618 .17463 L
.24618 .16492 L
.25233 .15877 L
.2559 .15521 L
.26204 .14906 L
.26561 .14549 L
.26561 .13578 L
.27176 .12963 L
.27532 .12607 L
.28147 .11992 L
.28503 .11636 L
.29118 .11021 L
.29475 .10664 L
.30089 .1005 L
.30446 .09693 L
.30446 .08722 L
.31061 .08107 L
.31417 .07751 L
.32032 .07136 L
.33003 .07136 L
.3336 .06779 L
.33974 .06165 L
.34331 .05808 L
.34946 .05193 L
.35302 .04837 L
.35917 .04222 L
.36888 .04222 L
.37245 .03866 L
.37859 .03251 L
.38831 .03251 L
.39187 .02894 L
F
0 g
.39802 .02137 m
.40773 .02137 L
.41744 .02137 L
.42716 .02137 L
.43687 .02137 L
.44658 .02137 L
.45629 .02137 L
.46601 .02137 L
.47572 .02137 L
.48187 .02894 L
.48543 .03251 L
.49514 .03251 L
.50486 .03251 L
.511 .03866 L
.51457 .04222 L
.52072 .04837 L
.52428 .05193 L
.53043 .05808 L
.53399 .06165 L
.54371 .06165 L
.54985 .06779 L
.55342 .07136 L
.55957 .07751 L
.56313 .08107 L
.56928 .08722 L
.56928 .09693 L
.57284 .1005 L
.57899 .10664 L
.58256 .11021 L
.5887 .11636 L
.59227 .11992 L
.59842 .12607 L
.60198 .12963 L
.60813 .13578 L
.60813 .14549 L
.61169 .14906 L
.61784 .15521 L
.62141 .15877 L
.62755 .16492 L
.62755 .17463 L
.63112 .1782 L
.63727 .18434 L
.63727 .19406 L
.64083 .19762 L
.64698 .20377 L
.65054 .20733 L
.65669 .21348 L
.65669 .22319 L
.66026 .22676 L
.6664 .23291 L
Mistroke
.6664 .24262 L
.66997 .24618 L
.67612 .25233 L
.67612 .26204 L
.67968 .26561 L
.68583 .27176 L
.68583 .28147 L
.68939 .28503 L
.69554 .29118 L
.69554 .30089 L
.69911 .30446 L
.70525 .31061 L
.70525 .32032 L
.70525 .33003 L
.70882 .3336 L
.71497 .33974 L
.71497 .34946 L
.71853 .35302 L
.72468 .35917 L
.72468 .36888 L
.72824 .37245 L
.73439 .37859 L
.73439 .38831 L
.73439 .39802 L
.73796 .40158 L
.7441 .40773 L
.7441 .41744 L
.74767 .42101 L
.75382 .42716 L
.75382 .43687 L
.75382 .44658 L
.75738 .45015 L
.76353 .45629 L
.76353 .46601 L
.76353 .47572 L
.76709 .47928 L
.77324 .48543 L
.77324 .49514 L
.77324 .50486 L
.77681 .50842 L
.78295 .51457 L
.78295 .52428 L
.78295 .53399 L
.78652 .53756 L
.79267 .54371 L
.79267 .55342 L
.79267 .56313 L
.79623 .5667 L
.80238 .57284 L
.80238 .58256 L
Mistroke
.80238 .59227 L
.80594 .59583 L
.81209 .60198 L
.81209 .61169 L
.81209 .62141 L
.81566 .62497 L
.8218 .63112 L
.8218 .64083 L
.8218 .65054 L
.82537 .65411 L
.83152 .66026 L
.83152 .66997 L
.83152 .67968 L
.83508 .68325 L
.84123 .68939 L
.84123 .69911 L
.84123 .70882 L
.84123 .71853 L
.84479 .7221 L
.85094 .72824 L
.85094 .73796 L
.85094 .74767 L
.85451 .75123 L
.86065 .75738 L
.86065 .76709 L
.86065 .77681 L
.86065 .78652 L
.86422 .79008 L
.87037 .79623 L
.87037 .80594 L
.87037 .81566 L
.87037 .82537 L
.87393 .82893 L
.88008 .83508 L
.88008 .84479 L
.88008 .85451 L
.88364 .85807 L
.88979 .86422 L
.88979 .87393 L
.88979 .88364 L
.88364 .88979 L
.87393 .88979 L
.86422 .88979 L
.85807 .88364 L
.85451 .88008 L
.84479 .88008 L
.83508 .88008 L
.82893 .87393 L
.82537 .87037 L
.81566 .87037 L
Mistroke
.80594 .87037 L
.79623 .87037 L
.79008 .86422 L
.78652 .86065 L
.77681 .86065 L
.76709 .86065 L
.76095 .85451 L
.75738 .85094 L
.74767 .85094 L
.73796 .85094 L
.73181 .84479 L
.72824 .84123 L
.71853 .84123 L
.70882 .84123 L
.69911 .84123 L
.69296 .83508 L
.68939 .83152 L
.67968 .83152 L
.66997 .83152 L
.66382 .82537 L
.66026 .8218 L
.65054 .8218 L
.64083 .8218 L
.63112 .8218 L
.62497 .81566 L
.62141 .81209 L
.61169 .81209 L
.60198 .81209 L
.59583 .80594 L
.59227 .80238 L
.58256 .80238 L
.57284 .80238 L
.5667 .79623 L
.56313 .79267 L
.55342 .79267 L
.54371 .79267 L
.53399 .79267 L
.52785 .78652 L
.52428 .78295 L
.51457 .78295 L
.50486 .78295 L
.49871 .77681 L
.49514 .77324 L
.48543 .77324 L
.47572 .77324 L
.46601 .77324 L
.45986 .76709 L
.45629 .76353 L
.44658 .76353 L
.43687 .76353 L
Mistroke
.43072 .75738 L
.42716 .75382 L
.41744 .75382 L
.40773 .75382 L
.40158 .74767 L
.39802 .7441 L
.38831 .7441 L
.37859 .7441 L
.36888 .7441 L
.36273 .73796 L
.35917 .73439 L
.34946 .73439 L
.33974 .73439 L
.3336 .72824 L
.33003 .72468 L
.32032 .72468 L
.31061 .72468 L
.30089 .72468 L
.29475 .71853 L
.29118 .71497 L
.28147 .71497 L
.27176 .71497 L
.26561 .70882 L
.26204 .70525 L
.25233 .70525 L
.24262 .70525 L
.23647 .69911 L
.23291 .69554 L
.22319 .69554 L
.21348 .69554 L
.20377 .69554 L
.19762 .68939 L
.19406 .68583 L
.18434 .68583 L
.17463 .68583 L
.16848 .67968 L
.16492 .67612 L
.15521 .67612 L
.14549 .67612 L
.13578 .67612 L
.12963 .66997 L
.12607 .6664 L
.11636 .6664 L
.10664 .6664 L
.1005 .66026 L
.09693 .65669 L
.08722 .65669 L
.07751 .65669 L
.07136 .65054 L
.06779 .64698 L
Mistroke
.05808 .64698 L
.05193 .64083 L
.05193 .63112 L
.05808 .62497 L
.06165 .62141 L
.06165 .61169 L
.06165 .60198 L
.06779 .59583 L
.07136 .59227 L
.07136 .58256 L
.07136 .57284 L
.07751 .5667 L
.08107 .56313 L
.08107 .55342 L
.08107 .54371 L
.08722 .53756 L
.09078 .53399 L
.09078 .52428 L
.09078 .51457 L
.09693 .50842 L
.1005 .50486 L
.1005 .49514 L
.1005 .48543 L
.10664 .47928 L
.11021 .47572 L
.11021 .46601 L
.11021 .45629 L
.11636 .45015 L
.11992 .44658 L
.11992 .43687 L
.12607 .43072 L
.12963 .42716 L
.12963 .41744 L
.12963 .40773 L
.13578 .40158 L
.13935 .39802 L
.13935 .38831 L
.14549 .38216 L
.14906 .37859 L
.14906 .36888 L
.14906 .35917 L
.15521 .35302 L
.15877 .34946 L
.15877 .33974 L
.16492 .3336 L
.16848 .33003 L
.16848 .32032 L
.17463 .31417 L
.1782 .31061 L
.1782 .30089 L
Mistroke
.1782 .29118 L
.18434 .28503 L
.18791 .28147 L
.18791 .27176 L
.19406 .26561 L
.19762 .26204 L
.19762 .25233 L
.20377 .24618 L
.20733 .24262 L
.20733 .23291 L
.21348 .22676 L
.21705 .22319 L
.21705 .21348 L
.22319 .20733 L
.22676 .20377 L
.23291 .19762 L
.23647 .19406 L
.23647 .18434 L
.24262 .1782 L
.24618 .17463 L
.24618 .16492 L
.25233 .15877 L
.2559 .15521 L
.26204 .14906 L
.26561 .14549 L
.26561 .13578 L
.27176 .12963 L
.27532 .12607 L
.28147 .11992 L
.28503 .11636 L
.29118 .11021 L
.29475 .10664 L
.30089 .1005 L
.30446 .09693 L
.30446 .08722 L
.31061 .08107 L
.31417 .07751 L
.32032 .07136 L
.33003 .07136 L
.3336 .06779 L
.33974 .06165 L
.34331 .05808 L
.34946 .05193 L
.35302 .04837 L
.35917 .04222 L
.36888 .04222 L
.37245 .03866 L
.37859 .03251 L
.38831 .03251 L
.39187 .02894 L
Mistroke
.39802 .02137 L
Mfstroke
.5 g
.39802 .02205 m
.40773 .02205 L
.41744 .02205 L
.42716 .02205 L
.43687 .02205 L
.44658 .02205 L
.45629 .02205 L
.46601 .02205 L
.47572 .02205 L
.481 .02894 L
.48543 .03337 L
.49514 .03337 L
.50486 .03337 L
.51014 .03866 L
.51457 .04308 L
.51985 .04837 L
.52428 .0528 L
.52957 .05808 L
.53399 .06251 L
.54371 .06251 L
.54899 .06779 L
.55342 .07222 L
.5587 .07751 L
.56313 .08193 L
.56842 .08722 L
.56842 .09693 L
.57284 .10136 L
.57813 .10664 L
.58256 .11107 L
.58784 .11636 L
.59227 .12078 L
.59755 .12607 L
.60198 .1305 L
.60727 .13578 L
.60727 .14549 L
.61169 .14992 L
.61698 .15521 L
.62141 .15963 L
.62669 .16492 L
.62669 .17463 L
.63112 .17906 L
.6364 .18434 L
.6364 .19406 L
.64083 .19848 L
.64612 .20377 L
.65054 .2082 L
.65583 .21348 L
.65583 .22319 L
.66026 .22762 L
.66554 .23291 L
.66554 .24262 L
.66997 .24705 L
.67525 .25233 L
.67525 .26204 L
.67968 .26647 L
.68497 .27176 L
.68497 .28147 L
.68939 .2859 L
.69468 .29118 L
.69468 .30089 L
.69911 .30532 L
.70439 .31061 L
.70439 .32032 L
.70439 .33003 L
.70882 .33446 L
.7141 .33974 L
.7141 .34946 L
.71853 .35388 L
.72382 .35917 L
.72382 .36888 L
.72824 .37331 L
.73353 .37859 L
.73353 .38831 L
.73353 .39802 L
.73796 .40245 L
.74324 .40773 L
.74324 .41744 L
.74767 .42187 L
.75295 .42716 L
.75295 .43687 L
.75295 .44658 L
.75738 .45101 L
.76267 .45629 L
.76267 .46601 L
.76267 .47572 L
.76709 .48015 L
.77238 .48543 L
.77238 .49514 L
.77238 .50486 L
.77681 .50928 L
.78209 .51457 L
.78209 .52428 L
.78209 .53399 L
.78652 .53842 L
.7918 .54371 L
.7918 .55342 L
.7918 .56313 L
.79623 .56756 L
.80152 .57284 L
.80152 .58256 L
.80152 .59227 L
.80594 .5967 L
.81123 .60198 L
.81123 .61169 L
.81123 .62141 L
.81566 .62583 L
.82094 .63112 L
.82094 .64083 L
.82094 .65054 L
.82537 .65497 L
.83065 .66026 L
.83065 .66997 L
.83065 .67968 L
.83508 .68411 L
.84037 .68939 L
.84037 .69911 L
.84037 .70882 L
.84037 .71853 L
.84479 .72296 L
.85008 .72824 L
.85008 .73796 L
.85008 .74767 L
.85451 .7521 L
.85979 .75738 L
.85979 .76709 L
.85979 .77681 L
.85979 .78652 L
.86422 .79095 L
.8695 .79623 L
.8695 .80594 L
.8695 .81566 L
.8695 .82537 L
.87393 .8298 L
.87922 .83508 L
.87922 .84479 L
.87922 .85451 L
.88364 .85893 L
.88893 .86422 L
.88893 .87393 L
.88893 .88364 L
.88364 .88893 L
.87393 .88893 L
.86422 .88893 L
.85893 .88364 L
.85451 .87922 L
.84479 .87922 L
.83508 .87922 L
.8298 .87393 L
.82537 .8695 L
.81566 .8695 L
.80594 .8695 L
.79623 .8695 L
.79095 .86422 L
.78652 .85979 L
.77681 .85979 L
.76709 .85979 L
.76181 .85451 L
.75738 .85008 L
.74767 .85008 L
.73796 .85008 L
.73267 .84479 L
.72824 .84037 L
.71853 .84037 L
.70882 .84037 L
.69911 .84037 L
.69382 .83508 L
.68939 .83065 L
.67968 .83065 L
.66997 .83065 L
.66468 .82537 L
.66026 .82094 L
.65054 .82094 L
.64083 .82094 L
.63112 .82094 L
.62583 .81566 L
.62141 .81123 L
.61169 .81123 L
.60198 .81123 L
.5967 .80594 L
.59227 .80152 L
.58256 .80152 L
.57284 .80152 L
.56756 .79623 L
.56313 .7918 L
.55342 .7918 L
.54371 .7918 L
.53399 .7918 L
.52871 .78652 L
.52428 .78209 L
.51457 .78209 L
.50486 .78209 L
.49957 .77681 L
.49514 .77238 L
.48543 .77238 L
.47572 .77238 L
.46601 .77238 L
.46072 .76709 L
.45629 .76267 L
.44658 .76267 L
.43687 .76267 L
.43158 .75738 L
.42716 .75295 L
.41744 .75295 L
.40773 .75295 L
.40245 .74767 L
.39802 .74324 L
.38831 .74324 L
.37859 .74324 L
.36888 .74324 L
.3636 .73796 L
.35917 .73353 L
.34946 .73353 L
.33974 .73353 L
.33446 .72824 L
.33003 .72382 L
.32032 .72382 L
.31061 .72382 L
.30089 .72382 L
.29561 .71853 L
.29118 .7141 L
.28147 .7141 L
.27176 .7141 L
.26647 .70882 L
.26204 .70439 L
.25233 .70439 L
.24262 .70439 L
.23733 .69911 L
.23291 .69468 L
.22319 .69468 L
.21348 .69468 L
.20377 .69468 L
.19848 .68939 L
.19406 .68497 L
.18434 .68497 L
.17463 .68497 L
.16935 .67968 L
.16492 .67525 L
.15521 .67525 L
.14549 .67525 L
.13578 .67525 L
.1305 .66997 L
.12607 .66554 L
.11636 .66554 L
.10664 .66554 L
.10136 .66026 L
.09693 .65583 L
.08722 .65583 L
.07751 .65583 L
.07222 .65054 L
.06779 .64612 L
.05808 .64612 L
.0528 .64083 L
.0528 .63112 L
.05808 .62583 L
.06251 .62141 L
.06251 .61169 L
.06251 .60198 L
.06779 .5967 L
.07222 .59227 L
.07222 .58256 L
.07222 .57284 L
.07751 .56756 L
.08193 .56313 L
.08193 .55342 L
.08193 .54371 L
.08722 .53842 L
.09165 .53399 L
.09165 .52428 L
.09165 .51457 L
.09693 .50928 L
.10136 .50486 L
.10136 .49514 L
.10136 .48543 L
.10664 .48015 L
.11107 .47572 L
.11107 .46601 L
.11107 .45629 L
.11636 .45101 L
.12078 .44658 L
.12078 .43687 L
.12607 .43158 L
.1305 .42716 L
.1305 .41744 L
.1305 .40773 L
.13578 .40245 L
.14021 .39802 L
.14021 .38831 L
.14549 .38302 L
.14992 .37859 L
.14992 .36888 L
.14992 .35917 L
.15521 .35388 L
.15963 .34946 L
.15963 .33974 L
.16492 .33446 L
.16935 .33003 L
.16935 .32032 L
.17463 .31503 L
.17906 .31061 L
.17906 .30089 L
.17906 .29118 L
.18434 .2859 L
.18877 .28147 L
.18877 .27176 L
.19406 .26647 L
.19848 .26204 L
.19848 .25233 L
.20377 .24705 L
.2082 .24262 L
.2082 .23291 L
.21348 .22762 L
.21791 .22319 L
.21791 .21348 L
.22319 .2082 L
.22762 .20377 L
.23291 .19848 L
.23733 .19406 L
.23733 .18434 L
.24262 .17906 L
.24705 .17463 L
.24705 .16492 L
.25233 .15963 L
.25676 .15521 L
.26204 .14992 L
.26647 .14549 L
.26647 .13578 L
.27176 .1305 L
.27618 .12607 L
.28147 .12078 L
.2859 .11636 L
.29118 .11107 L
.29561 .10664 L
.30089 .10136 L
.30532 .09693 L
.30532 .08722 L
.31061 .08193 L
.31503 .07751 L
.32032 .07222 L
.33003 .07222 L
.33446 .06779 L
.33974 .06251 L
.34417 .05808 L
.34946 .0528 L
.35388 .04837 L
.35917 .04308 L
.36888 .04308 L
.37331 .03866 L
.37859 .03337 L
.38831 .03337 L
.39273 .02894 L
F
0 g
.39802 .02205 m
.40773 .02205 L
.41744 .02205 L
.42716 .02205 L
.43687 .02205 L
.44658 .02205 L
.45629 .02205 L
.46601 .02205 L
.47572 .02205 L
.481 .02894 L
.48543 .03337 L
.49514 .03337 L
.50486 .03337 L
.51014 .03866 L
.51457 .04308 L
.51985 .04837 L
.52428 .0528 L
.52957 .05808 L
.53399 .06251 L
.54371 .06251 L
.54899 .06779 L
.55342 .07222 L
.5587 .07751 L
.56313 .08193 L
.56842 .08722 L
.56842 .09693 L
.57284 .10136 L
.57813 .10664 L
.58256 .11107 L
.58784 .11636 L
.59227 .12078 L
.59755 .12607 L
.60198 .1305 L
.60727 .13578 L
.60727 .14549 L
.61169 .14992 L
.61698 .15521 L
.62141 .15963 L
.62669 .16492 L
.62669 .17463 L
.63112 .17906 L
.6364 .18434 L
.6364 .19406 L
.64083 .19848 L
.64612 .20377 L
.65054 .2082 L
.65583 .21348 L
.65583 .22319 L
.66026 .22762 L
.66554 .23291 L
Mistroke
.66554 .24262 L
.66997 .24705 L
.67525 .25233 L
.67525 .26204 L
.67968 .26647 L
.68497 .27176 L
.68497 .28147 L
.68939 .2859 L
.69468 .29118 L
.69468 .30089 L
.69911 .30532 L
.70439 .31061 L
.70439 .32032 L
.70439 .33003 L
.70882 .33446 L
.7141 .33974 L
.7141 .34946 L
.71853 .35388 L
.72382 .35917 L
.72382 .36888 L
.72824 .37331 L
.73353 .37859 L
.73353 .38831 L
.73353 .39802 L
.73796 .40245 L
.74324 .40773 L
.74324 .41744 L
.74767 .42187 L
.75295 .42716 L
.75295 .43687 L
.75295 .44658 L
.75738 .45101 L
.76267 .45629 L
.76267 .46601 L
.76267 .47572 L
.76709 .48015 L
.77238 .48543 L
.77238 .49514 L
.77238 .50486 L
.77681 .50928 L
.78209 .51457 L
.78209 .52428 L
.78209 .53399 L
.78652 .53842 L
.7918 .54371 L
.7918 .55342 L
.7918 .56313 L
.79623 .56756 L
.80152 .57284 L
.80152 .58256 L
Mistroke
.80152 .59227 L
.80594 .5967 L
.81123 .60198 L
.81123 .61169 L
.81123 .62141 L
.81566 .62583 L
.82094 .63112 L
.82094 .64083 L
.82094 .65054 L
.82537 .65497 L
.83065 .66026 L
.83065 .66997 L
.83065 .67968 L
.83508 .68411 L
.84037 .68939 L
.84037 .69911 L
.84037 .70882 L
.84037 .71853 L
.84479 .72296 L
.85008 .72824 L
.85008 .73796 L
.85008 .74767 L
.85451 .7521 L
.85979 .75738 L
.85979 .76709 L
.85979 .77681 L
.85979 .78652 L
.86422 .79095 L
.8695 .79623 L
.8695 .80594 L
.8695 .81566 L
.8695 .82537 L
.87393 .8298 L
.87922 .83508 L
.87922 .84479 L
.87922 .85451 L
.88364 .85893 L
.88893 .86422 L
.88893 .87393 L
.88893 .88364 L
.88364 .88893 L
.87393 .88893 L
.86422 .88893 L
.85893 .88364 L
.85451 .87922 L
.84479 .87922 L
.83508 .87922 L
.8298 .87393 L
.82537 .8695 L
.81566 .8695 L
Mistroke
.80594 .8695 L
.79623 .8695 L
.79095 .86422 L
.78652 .85979 L
.77681 .85979 L
.76709 .85979 L
.76181 .85451 L
.75738 .85008 L
.74767 .85008 L
.73796 .85008 L
.73267 .84479 L
.72824 .84037 L
.71853 .84037 L
.70882 .84037 L
.69911 .84037 L
.69382 .83508 L
.68939 .83065 L
.67968 .83065 L
.66997 .83065 L
.66468 .82537 L
.66026 .82094 L
.65054 .82094 L
.64083 .82094 L
.63112 .82094 L
.62583 .81566 L
.62141 .81123 L
.61169 .81123 L
.60198 .81123 L
.5967 .80594 L
.59227 .80152 L
.58256 .80152 L
.57284 .80152 L
.56756 .79623 L
.56313 .7918 L
.55342 .7918 L
.54371 .7918 L
.53399 .7918 L
.52871 .78652 L
.52428 .78209 L
.51457 .78209 L
.50486 .78209 L
.49957 .77681 L
.49514 .77238 L
.48543 .77238 L
.47572 .77238 L
.46601 .77238 L
.46072 .76709 L
.45629 .76267 L
.44658 .76267 L
.43687 .76267 L
Mistroke
.43158 .75738 L
.42716 .75295 L
.41744 .75295 L
.40773 .75295 L
.40245 .74767 L
.39802 .74324 L
.38831 .74324 L
.37859 .74324 L
.36888 .74324 L
.3636 .73796 L
.35917 .73353 L
.34946 .73353 L
.33974 .73353 L
.33446 .72824 L
.33003 .72382 L
.32032 .72382 L
.31061 .72382 L
.30089 .72382 L
.29561 .71853 L
.29118 .7141 L
.28147 .7141 L
.27176 .7141 L
.26647 .70882 L
.26204 .70439 L
.25233 .70439 L
.24262 .70439 L
.23733 .69911 L
.23291 .69468 L
.22319 .69468 L
.21348 .69468 L
.20377 .69468 L
.19848 .68939 L
.19406 .68497 L
.18434 .68497 L
.17463 .68497 L
.16935 .67968 L
.16492 .67525 L
.15521 .67525 L
.14549 .67525 L
.13578 .67525 L
.1305 .66997 L
.12607 .66554 L
.11636 .66554 L
.10664 .66554 L
.10136 .66026 L
.09693 .65583 L
.08722 .65583 L
.07751 .65583 L
.07222 .65054 L
.06779 .64612 L
Mistroke
.05808 .64612 L
.0528 .64083 L
.0528 .63112 L
.05808 .62583 L
.06251 .62141 L
.06251 .61169 L
.06251 .60198 L
.06779 .5967 L
.07222 .59227 L
.07222 .58256 L
.07222 .57284 L
.07751 .56756 L
.08193 .56313 L
.08193 .55342 L
.08193 .54371 L
.08722 .53842 L
.09165 .53399 L
.09165 .52428 L
.09165 .51457 L
.09693 .50928 L
.10136 .50486 L
.10136 .49514 L
.10136 .48543 L
.10664 .48015 L
.11107 .47572 L
.11107 .46601 L
.11107 .45629 L
.11636 .45101 L
.12078 .44658 L
.12078 .43687 L
.12607 .43158 L
.1305 .42716 L
.1305 .41744 L
.1305 .40773 L
.13578 .40245 L
.14021 .39802 L
.14021 .38831 L
.14549 .38302 L
.14992 .37859 L
.14992 .36888 L
.14992 .35917 L
.15521 .35388 L
.15963 .34946 L
.15963 .33974 L
.16492 .33446 L
.16935 .33003 L
.16935 .32032 L
.17463 .31503 L
.17906 .31061 L
.17906 .30089 L
Mistroke
.17906 .29118 L
.18434 .2859 L
.18877 .28147 L
.18877 .27176 L
.19406 .26647 L
.19848 .26204 L
.19848 .25233 L
.20377 .24705 L
.2082 .24262 L
.2082 .23291 L
.21348 .22762 L
.21791 .22319 L
.21791 .21348 L
.22319 .2082 L
.22762 .20377 L
.23291 .19848 L
.23733 .19406 L
.23733 .18434 L
.24262 .17906 L
.24705 .17463 L
.24705 .16492 L
.25233 .15963 L
.25676 .15521 L
.26204 .14992 L
.26647 .14549 L
.26647 .13578 L
.27176 .1305 L
.27618 .12607 L
.28147 .12078 L
.2859 .11636 L
.29118 .11107 L
.29561 .10664 L
.30089 .10136 L
.30532 .09693 L
.30532 .08722 L
.31061 .08193 L
.31503 .07751 L
.32032 .07222 L
.33003 .07222 L
.33446 .06779 L
.33974 .06251 L
.34417 .05808 L
.34946 .0528 L
.35388 .04837 L
.35917 .04308 L
.36888 .04308 L
.37331 .03866 L
.37859 .03337 L
.38831 .03337 L
.39273 .02894 L
Mistroke
.39802 .02205 L
Mfstroke
.6 g
.39802 .02281 m
.40773 .02281 L
.41744 .02281 L
.42716 .02281 L
.43687 .02281 L
.44658 .02281 L
.45629 .02281 L
.46601 .02281 L
.47572 .02281 L
.48015 .02894 L
.48543 .03423 L
.49514 .03423 L
.50486 .03423 L
.50928 .03866 L
.51457 .04394 L
.519 .04837 L
.52428 .05365 L
.52871 .05808 L
.53399 .06337 L
.54371 .06337 L
.54813 .06779 L
.55342 .07308 L
.55785 .07751 L
.56313 .08279 L
.56756 .08722 L
.56756 .09693 L
.57284 .10222 L
.57727 .10664 L
.58256 .11193 L
.58698 .11636 L
.59227 .12164 L
.5967 .12607 L
.60198 .13135 L
.60641 .13578 L
.60641 .14549 L
.61169 .15078 L
.61612 .15521 L
.62141 .16049 L
.62583 .16492 L
.62583 .17463 L
.63112 .17992 L
.63555 .18434 L
.63555 .19406 L
.64083 .19934 L
.64526 .20377 L
.65054 .20905 L
.65497 .21348 L
.65497 .22319 L
.66026 .22848 L
.66468 .23291 L
.66468 .24262 L
.66997 .2479 L
.6744 .25233 L
.6744 .26204 L
.67968 .26733 L
.68411 .27176 L
.68411 .28147 L
.68939 .28675 L
.69382 .29118 L
.69382 .30089 L
.69911 .30618 L
.70353 .31061 L
.70353 .32032 L
.70353 .33003 L
.70882 .33532 L
.71325 .33974 L
.71325 .34946 L
.71853 .35474 L
.72296 .35917 L
.72296 .36888 L
.72824 .37417 L
.73267 .37859 L
.73267 .38831 L
.73267 .39802 L
.73796 .4033 L
.74238 .40773 L
.74238 .41744 L
.74767 .42273 L
.7521 .42716 L
.7521 .43687 L
.7521 .44658 L
.75738 .45187 L
.76181 .45629 L
.76181 .46601 L
.76181 .47572 L
.76709 .481 L
.77152 .48543 L
.77152 .49514 L
.77152 .50486 L
.77681 .51014 L
.78123 .51457 L
.78123 .52428 L
.78123 .53399 L
.78652 .53928 L
.79095 .54371 L
.79095 .55342 L
.79095 .56313 L
.79623 .56842 L
.80066 .57284 L
.80066 .58256 L
.80066 .59227 L
.80594 .59755 L
.81037 .60198 L
.81037 .61169 L
.81037 .62141 L
.81566 .62669 L
.82008 .63112 L
.82008 .64083 L
.82008 .65054 L
.82537 .65583 L
.8298 .66026 L
.8298 .66997 L
.8298 .67968 L
.83508 .68497 L
.83951 .68939 L
.83951 .69911 L
.83951 .70882 L
.83951 .71853 L
.84479 .72382 L
.84922 .72824 L
.84922 .73796 L
.84922 .74767 L
.85451 .75295 L
.85893 .75738 L
.85893 .76709 L
.85893 .77681 L
.85893 .78652 L
.86422 .7918 L
.86865 .79623 L
.86865 .80594 L
.86865 .81566 L
.86865 .82537 L
.87393 .83065 L
.87836 .83508 L
.87836 .84479 L
.87836 .85451 L
.88364 .85979 L
.88807 .86422 L
.88807 .87393 L
.88807 .88364 L
.88364 .88807 L
.87393 .88807 L
.86422 .88807 L
.85979 .88364 L
.85451 .87836 L
.84479 .87836 L
.83508 .87836 L
.83065 .87393 L
.82537 .86865 L
.81566 .86865 L
.80594 .86865 L
.79623 .86865 L
.7918 .86422 L
.78652 .85893 L
.77681 .85893 L
.76709 .85893 L
.76267 .85451 L
.75738 .84922 L
.74767 .84922 L
.73796 .84922 L
.73353 .84479 L
.72824 .83951 L
.71853 .83951 L
.70882 .83951 L
.69911 .83951 L
.69468 .83508 L
.68939 .8298 L
.67968 .8298 L
.66997 .8298 L
.66554 .82537 L
.66026 .82008 L
.65054 .82008 L
.64083 .82008 L
.63112 .82008 L
.62669 .81566 L
.62141 .81037 L
.61169 .81037 L
.60198 .81037 L
.59755 .80594 L
.59227 .80066 L
.58256 .80066 L
.57284 .80066 L
.56842 .79623 L
.56313 .79095 L
.55342 .79095 L
.54371 .79095 L
.53399 .79095 L
.52957 .78652 L
.52428 .78123 L
.51457 .78123 L
.50486 .78123 L
.50043 .77681 L
.49514 .77152 L
.48543 .77152 L
.47572 .77152 L
.46601 .77152 L
.46158 .76709 L
.45629 .76181 L
.44658 .76181 L
.43687 .76181 L
.43244 .75738 L
.42716 .7521 L
.41744 .7521 L
.40773 .7521 L
.4033 .74767 L
.39802 .74238 L
.38831 .74238 L
.37859 .74238 L
.36888 .74238 L
.36445 .73796 L
.35917 .73267 L
.34946 .73267 L
.33974 .73267 L
.33532 .72824 L
.33003 .72296 L
.32032 .72296 L
.31061 .72296 L
.30089 .72296 L
.29647 .71853 L
.29118 .71325 L
.28147 .71325 L
.27176 .71325 L
.26733 .70882 L
.26204 .70353 L
.25233 .70353 L
.24262 .70353 L
.23819 .69911 L
.23291 .69382 L
.22319 .69382 L
.21348 .69382 L
.20377 .69382 L
.19934 .68939 L
.19406 .68411 L
.18434 .68411 L
.17463 .68411 L
.1702 .67968 L
.16492 .6744 L
.15521 .6744 L
.14549 .6744 L
.13578 .6744 L
.13135 .66997 L
.12607 .66468 L
.11636 .66468 L
.10664 .66468 L
.10222 .66026 L
.09693 .65497 L
.08722 .65497 L
.07751 .65497 L
.07308 .65054 L
.06779 .64526 L
.05808 .64526 L
.05365 .64083 L
.05365 .63112 L
.05808 .62669 L
.06337 .62141 L
.06337 .61169 L
.06337 .60198 L
.06779 .59755 L
.07308 .59227 L
.07308 .58256 L
.07308 .57284 L
.07751 .56842 L
.08279 .56313 L
.08279 .55342 L
.08279 .54371 L
.08722 .53928 L
.0925 .53399 L
.0925 .52428 L
.0925 .51457 L
.09693 .51014 L
.10222 .50486 L
.10222 .49514 L
.10222 .48543 L
.10664 .481 L
.11193 .47572 L
.11193 .46601 L
.11193 .45629 L
.11636 .45187 L
.12164 .44658 L
.12164 .43687 L
.12607 .43244 L
.13135 .42716 L
.13135 .41744 L
.13135 .40773 L
.13578 .4033 L
.14107 .39802 L
.14107 .38831 L
.14549 .38388 L
.15078 .37859 L
.15078 .36888 L
.15078 .35917 L
.15521 .35474 L
.16049 .34946 L
.16049 .33974 L
.16492 .33532 L
.1702 .33003 L
.1702 .32032 L
.17463 .31589 L
.17992 .31061 L
.17992 .30089 L
.17992 .29118 L
.18434 .28675 L
.18963 .28147 L
.18963 .27176 L
.19406 .26733 L
.19934 .26204 L
.19934 .25233 L
.20377 .2479 L
.20905 .24262 L
.20905 .23291 L
.21348 .22848 L
.21877 .22319 L
.21877 .21348 L
.22319 .20905 L
.22848 .20377 L
.23291 .19934 L
.23819 .19406 L
.23819 .18434 L
.24262 .17992 L
.2479 .17463 L
.2479 .16492 L
.25233 .16049 L
.25762 .15521 L
.26204 .15078 L
.26733 .14549 L
.26733 .13578 L
.27176 .13135 L
.27704 .12607 L
.28147 .12164 L
.28675 .11636 L
.29118 .11193 L
.29647 .10664 L
.30089 .10222 L
.30618 .09693 L
.30618 .08722 L
.31061 .08279 L
.31589 .07751 L
.32032 .07308 L
.33003 .07308 L
.33532 .06779 L
.33974 .06337 L
.34503 .05808 L
.34946 .05365 L
.35474 .04837 L
.35917 .04394 L
.36888 .04394 L
.37417 .03866 L
.37859 .03423 L
.38831 .03423 L
.39359 .02894 L
F
0 g
.39802 .02281 m
.40773 .02281 L
.41744 .02281 L
.42716 .02281 L
.43687 .02281 L
.44658 .02281 L
.45629 .02281 L
.46601 .02281 L
.47572 .02281 L
.48015 .02894 L
.48543 .03423 L
.49514 .03423 L
.50486 .03423 L
.50928 .03866 L
.51457 .04394 L
.519 .04837 L
.52428 .05365 L
.52871 .05808 L
.53399 .06337 L
.54371 .06337 L
.54813 .06779 L
.55342 .07308 L
.55785 .07751 L
.56313 .08279 L
.56756 .08722 L
.56756 .09693 L
.57284 .10222 L
.57727 .10664 L
.58256 .11193 L
.58698 .11636 L
.59227 .12164 L
.5967 .12607 L
.60198 .13135 L
.60641 .13578 L
.60641 .14549 L
.61169 .15078 L
.61612 .15521 L
.62141 .16049 L
.62583 .16492 L
.62583 .17463 L
.63112 .17992 L
.63555 .18434 L
.63555 .19406 L
.64083 .19934 L
.64526 .20377 L
.65054 .20905 L
.65497 .21348 L
.65497 .22319 L
.66026 .22848 L
.66468 .23291 L
Mistroke
.66468 .24262 L
.66997 .2479 L
.6744 .25233 L
.6744 .26204 L
.67968 .26733 L
.68411 .27176 L
.68411 .28147 L
.68939 .28675 L
.69382 .29118 L
.69382 .30089 L
.69911 .30618 L
.70353 .31061 L
.70353 .32032 L
.70353 .33003 L
.70882 .33532 L
.71325 .33974 L
.71325 .34946 L
.71853 .35474 L
.72296 .35917 L
.72296 .36888 L
.72824 .37417 L
.73267 .37859 L
.73267 .38831 L
.73267 .39802 L
.73796 .4033 L
.74238 .40773 L
.74238 .41744 L
.74767 .42273 L
.7521 .42716 L
.7521 .43687 L
.7521 .44658 L
.75738 .45187 L
.76181 .45629 L
.76181 .46601 L
.76181 .47572 L
.76709 .481 L
.77152 .48543 L
.77152 .49514 L
.77152 .50486 L
.77681 .51014 L
.78123 .51457 L
.78123 .52428 L
.78123 .53399 L
.78652 .53928 L
.79095 .54371 L
.79095 .55342 L
.79095 .56313 L
.79623 .56842 L
.80066 .57284 L
.80066 .58256 L
Mistroke
.80066 .59227 L
.80594 .59755 L
.81037 .60198 L
.81037 .61169 L
.81037 .62141 L
.81566 .62669 L
.82008 .63112 L
.82008 .64083 L
.82008 .65054 L
.82537 .65583 L
.8298 .66026 L
.8298 .66997 L
.8298 .67968 L
.83508 .68497 L
.83951 .68939 L
.83951 .69911 L
.83951 .70882 L
.83951 .71853 L
.84479 .72382 L
.84922 .72824 L
.84922 .73796 L
.84922 .74767 L
.85451 .75295 L
.85893 .75738 L
.85893 .76709 L
.85893 .77681 L
.85893 .78652 L
.86422 .7918 L
.86865 .79623 L
.86865 .80594 L
.86865 .81566 L
.86865 .82537 L
.87393 .83065 L
.87836 .83508 L
.87836 .84479 L
.87836 .85451 L
.88364 .85979 L
.88807 .86422 L
.88807 .87393 L
.88807 .88364 L
.88364 .88807 L
.87393 .88807 L
.86422 .88807 L
.85979 .88364 L
.85451 .87836 L
.84479 .87836 L
.83508 .87836 L
.83065 .87393 L
.82537 .86865 L
.81566 .86865 L
Mistroke
.80594 .86865 L
.79623 .86865 L
.7918 .86422 L
.78652 .85893 L
.77681 .85893 L
.76709 .85893 L
.76267 .85451 L
.75738 .84922 L
.74767 .84922 L
.73796 .84922 L
.73353 .84479 L
.72824 .83951 L
.71853 .83951 L
.70882 .83951 L
.69911 .83951 L
.69468 .83508 L
.68939 .8298 L
.67968 .8298 L
.66997 .8298 L
.66554 .82537 L
.66026 .82008 L
.65054 .82008 L
.64083 .82008 L
.63112 .82008 L
.62669 .81566 L
.62141 .81037 L
.61169 .81037 L
.60198 .81037 L
.59755 .80594 L
.59227 .80066 L
.58256 .80066 L
.57284 .80066 L
.56842 .79623 L
.56313 .79095 L
.55342 .79095 L
.54371 .79095 L
.53399 .79095 L
.52957 .78652 L
.52428 .78123 L
.51457 .78123 L
.50486 .78123 L
.50043 .77681 L
.49514 .77152 L
.48543 .77152 L
.47572 .77152 L
.46601 .77152 L
.46158 .76709 L
.45629 .76181 L
.44658 .76181 L
.43687 .76181 L
Mistroke
.43244 .75738 L
.42716 .7521 L
.41744 .7521 L
.40773 .7521 L
.4033 .74767 L
.39802 .74238 L
.38831 .74238 L
.37859 .74238 L
.36888 .74238 L
.36445 .73796 L
.35917 .73267 L
.34946 .73267 L
.33974 .73267 L
.33532 .72824 L
.33003 .72296 L
.32032 .72296 L
.31061 .72296 L
.30089 .72296 L
.29647 .71853 L
.29118 .71325 L
.28147 .71325 L
.27176 .71325 L
.26733 .70882 L
.26204 .70353 L
.25233 .70353 L
.24262 .70353 L
.23819 .69911 L
.23291 .69382 L
.22319 .69382 L
.21348 .69382 L
.20377 .69382 L
.19934 .68939 L
.19406 .68411 L
.18434 .68411 L
.17463 .68411 L
.1702 .67968 L
.16492 .6744 L
.15521 .6744 L
.14549 .6744 L
.13578 .6744 L
.13135 .66997 L
.12607 .66468 L
.11636 .66468 L
.10664 .66468 L
.10222 .66026 L
.09693 .65497 L
.08722 .65497 L
.07751 .65497 L
.07308 .65054 L
.06779 .64526 L
Mistroke
.05808 .64526 L
.05365 .64083 L
.05365 .63112 L
.05808 .62669 L
.06337 .62141 L
.06337 .61169 L
.06337 .60198 L
.06779 .59755 L
.07308 .59227 L
.07308 .58256 L
.07308 .57284 L
.07751 .56842 L
.08279 .56313 L
.08279 .55342 L
.08279 .54371 L
.08722 .53928 L
.0925 .53399 L
.0925 .52428 L
.0925 .51457 L
.09693 .51014 L
.10222 .50486 L
.10222 .49514 L
.10222 .48543 L
.10664 .481 L
.11193 .47572 L
.11193 .46601 L
.11193 .45629 L
.11636 .45187 L
.12164 .44658 L
.12164 .43687 L
.12607 .43244 L
.13135 .42716 L
.13135 .41744 L
.13135 .40773 L
.13578 .4033 L
.14107 .39802 L
.14107 .38831 L
.14549 .38388 L
.15078 .37859 L
.15078 .36888 L
.15078 .35917 L
.15521 .35474 L
.16049 .34946 L
.16049 .33974 L
.16492 .33532 L
.1702 .33003 L
.1702 .32032 L
.17463 .31589 L
.17992 .31061 L
.17992 .30089 L
Mistroke
.17992 .29118 L
.18434 .28675 L
.18963 .28147 L
.18963 .27176 L
.19406 .26733 L
.19934 .26204 L
.19934 .25233 L
.20377 .2479 L
.20905 .24262 L
.20905 .23291 L
.21348 .22848 L
.21877 .22319 L
.21877 .21348 L
.22319 .20905 L
.22848 .20377 L
.23291 .19934 L
.23819 .19406 L
.23819 .18434 L
.24262 .17992 L
.2479 .17463 L
.2479 .16492 L
.25233 .16049 L
.25762 .15521 L
.26204 .15078 L
.26733 .14549 L
.26733 .13578 L
.27176 .13135 L
.27704 .12607 L
.28147 .12164 L
.28675 .11636 L
.29118 .11193 L
.29647 .10664 L
.30089 .10222 L
.30618 .09693 L
.30618 .08722 L
.31061 .08279 L
.31589 .07751 L
.32032 .07308 L
.33003 .07308 L
.33532 .06779 L
.33974 .06337 L
.34503 .05808 L
.34946 .05365 L
.35474 .04837 L
.35917 .04394 L
.36888 .04394 L
.37417 .03866 L
.37859 .03423 L
.38831 .03423 L
.39359 .02894 L
Mistroke
.39802 .02281 L
Mfstroke
.7 g
.39802 .02365 m
.40773 .02365 L
.41744 .02365 L
.42716 .02365 L
.43687 .02365 L
.44658 .02365 L
.45629 .02365 L
.46601 .02365 L
.47572 .02365 L
.47928 .02894 L
.48543 .03509 L
.49514 .03509 L
.50486 .03509 L
.50842 .03866 L
.51457 .0448 L
.51813 .04837 L
.52428 .05452 L
.52785 .05808 L
.53399 .06423 L
.54371 .06423 L
.54727 .06779 L
.55342 .07394 L
.55698 .07751 L
.56313 .08365 L
.5667 .08722 L
.5667 .09693 L
.57284 .10308 L
.57641 .10664 L
.58256 .11279 L
.58612 .11636 L
.59227 .1225 L
.59583 .12607 L
.60198 .13222 L
.60555 .13578 L
.60555 .14549 L
.61169 .15164 L
.61526 .15521 L
.62141 .16135 L
.62497 .16492 L
.62497 .17463 L
.63112 .18078 L
.63468 .18434 L
.63468 .19406 L
.64083 .2002 L
.6444 .20377 L
.65054 .20992 L
.65411 .21348 L
.65411 .22319 L
.66026 .22934 L
.66382 .23291 L
.66382 .24262 L
.66997 .24877 L
.67353 .25233 L
.67353 .26204 L
.67968 .26819 L
.68325 .27176 L
.68325 .28147 L
.68939 .28762 L
.69296 .29118 L
.69296 .30089 L
.69911 .30704 L
.70267 .31061 L
.70267 .32032 L
.70267 .33003 L
.70882 .33618 L
.71238 .33974 L
.71238 .34946 L
.71853 .3556 L
.7221 .35917 L
.7221 .36888 L
.72824 .37503 L
.73181 .37859 L
.73181 .38831 L
.73181 .39802 L
.73796 .40417 L
.74152 .40773 L
.74152 .41744 L
.74767 .42359 L
.75123 .42716 L
.75123 .43687 L
.75123 .44658 L
.75738 .45273 L
.76095 .45629 L
.76095 .46601 L
.76095 .47572 L
.76709 .48187 L
.77066 .48543 L
.77066 .49514 L
.77066 .50486 L
.77681 .511 L
.78037 .51457 L
.78037 .52428 L
.78037 .53399 L
.78652 .54014 L
.79008 .54371 L
.79008 .55342 L
.79008 .56313 L
.79623 .56928 L
.7998 .57284 L
.7998 .58256 L
.7998 .59227 L
.80594 .59842 L
.80951 .60198 L
.80951 .61169 L
.80951 .62141 L
.81566 .62755 L
.81922 .63112 L
.81922 .64083 L
.81922 .65054 L
.82537 .65669 L
.82893 .66026 L
.82893 .66997 L
.82893 .67968 L
.83508 .68583 L
.83865 .68939 L
.83865 .69911 L
.83865 .70882 L
.83865 .71853 L
.84479 .72468 L
.84836 .72824 L
.84836 .73796 L
.84836 .74767 L
.85451 .75382 L
.85807 .75738 L
.85807 .76709 L
.85807 .77681 L
.85807 .78652 L
.86422 .79267 L
.86778 .79623 L
.86778 .80594 L
.86778 .81566 L
.86778 .82537 L
.87393 .83152 L
.8775 .83508 L
.8775 .84479 L
.8775 .85451 L
.88364 .86065 L
.88721 .86422 L
.88721 .87393 L
.88721 .88364 L
.88364 .88721 L
.87393 .88721 L
.86422 .88721 L
.86065 .88364 L
.85451 .8775 L
.84479 .8775 L
.83508 .8775 L
.83152 .87393 L
.82537 .86778 L
.81566 .86778 L
.80594 .86778 L
.79623 .86778 L
.79267 .86422 L
.78652 .85807 L
.77681 .85807 L
.76709 .85807 L
.76353 .85451 L
.75738 .84836 L
.74767 .84836 L
.73796 .84836 L
.73439 .84479 L
.72824 .83865 L
.71853 .83865 L
.70882 .83865 L
.69911 .83865 L
.69554 .83508 L
.68939 .82893 L
.67968 .82893 L
.66997 .82893 L
.6664 .82537 L
.66026 .81922 L
.65054 .81922 L
.64083 .81922 L
.63112 .81922 L
.62755 .81566 L
.62141 .80951 L
.61169 .80951 L
.60198 .80951 L
.59842 .80594 L
.59227 .7998 L
.58256 .7998 L
.57284 .7998 L
.56928 .79623 L
.56313 .79008 L
.55342 .79008 L
.54371 .79008 L
.53399 .79008 L
.53043 .78652 L
.52428 .78037 L
.51457 .78037 L
.50486 .78037 L
.50129 .77681 L
.49514 .77066 L
.48543 .77066 L
.47572 .77066 L
.46601 .77066 L
.46244 .76709 L
.45629 .76095 L
.44658 .76095 L
.43687 .76095 L
.4333 .75738 L
.42716 .75123 L
.41744 .75123 L
.40773 .75123 L
.40417 .74767 L
.39802 .74152 L
.38831 .74152 L
.37859 .74152 L
.36888 .74152 L
.36532 .73796 L
.35917 .73181 L
.34946 .73181 L
.33974 .73181 L
.33618 .72824 L
.33003 .7221 L
.32032 .7221 L
.31061 .7221 L
.30089 .7221 L
.29733 .71853 L
.29118 .71238 L
.28147 .71238 L
.27176 .71238 L
.26819 .70882 L
.26204 .70267 L
.25233 .70267 L
.24262 .70267 L
.23905 .69911 L
.23291 .69296 L
.22319 .69296 L
.21348 .69296 L
.20377 .69296 L
.2002 .68939 L
.19406 .68325 L
.18434 .68325 L
.17463 .68325 L
.17107 .67968 L
.16492 .67353 L
.15521 .67353 L
.14549 .67353 L
.13578 .67353 L
.13222 .66997 L
.12607 .66382 L
.11636 .66382 L
.10664 .66382 L
.10308 .66026 L
.09693 .65411 L
.08722 .65411 L
.07751 .65411 L
.07394 .65054 L
.06779 .6444 L
.05808 .6444 L
.05452 .64083 L
.05452 .63112 L
.05808 .62755 L
.06423 .62141 L
.06423 .61169 L
.06423 .60198 L
.06779 .59842 L
.07394 .59227 L
.07394 .58256 L
.07394 .57284 L
.07751 .56928 L
.08365 .56313 L
.08365 .55342 L
.08365 .54371 L
.08722 .54014 L
.09337 .53399 L
.09337 .52428 L
.09337 .51457 L
.09693 .511 L
.10308 .50486 L
.10308 .49514 L
.10308 .48543 L
.10664 .48187 L
.11279 .47572 L
.11279 .46601 L
.11279 .45629 L
.11636 .45273 L
.1225 .44658 L
.1225 .43687 L
.12607 .4333 L
.13222 .42716 L
.13222 .41744 L
.13222 .40773 L
.13578 .40417 L
.14193 .39802 L
.14193 .38831 L
.14549 .38474 L
.15164 .37859 L
.15164 .36888 L
.15164 .35917 L
.15521 .3556 L
.16135 .34946 L
.16135 .33974 L
.16492 .33618 L
.17107 .33003 L
.17107 .32032 L
.17463 .31675 L
.18078 .31061 L
.18078 .30089 L
.18078 .29118 L
.18434 .28762 L
.19049 .28147 L
.19049 .27176 L
.19406 .26819 L
.2002 .26204 L
.2002 .25233 L
.20377 .24877 L
.20992 .24262 L
.20992 .23291 L
.21348 .22934 L
.21963 .22319 L
.21963 .21348 L
.22319 .20992 L
.22934 .20377 L
.23291 .2002 L
.23905 .19406 L
.23905 .18434 L
.24262 .18078 L
.24877 .17463 L
.24877 .16492 L
.25233 .16135 L
.25848 .15521 L
.26204 .15164 L
.26819 .14549 L
.26819 .13578 L
.27176 .13222 L
.2779 .12607 L
.28147 .1225 L
.28762 .11636 L
.29118 .11279 L
.29733 .10664 L
.30089 .10308 L
.30704 .09693 L
.30704 .08722 L
.31061 .08365 L
.31675 .07751 L
.32032 .07394 L
.33003 .07394 L
.33618 .06779 L
.33974 .06423 L
.34589 .05808 L
.34946 .05452 L
.3556 .04837 L
.35917 .0448 L
.36888 .0448 L
.37503 .03866 L
.37859 .03509 L
.38831 .03509 L
.39445 .02894 L
F
0 g
.39802 .02365 m
.40773 .02365 L
.41744 .02365 L
.42716 .02365 L
.43687 .02365 L
.44658 .02365 L
.45629 .02365 L
.46601 .02365 L
.47572 .02365 L
.47928 .02894 L
.48543 .03509 L
.49514 .03509 L
.50486 .03509 L
.50842 .03866 L
.51457 .0448 L
.51813 .04837 L
.52428 .05452 L
.52785 .05808 L
.53399 .06423 L
.54371 .06423 L
.54727 .06779 L
.55342 .07394 L
.55698 .07751 L
.56313 .08365 L
.5667 .08722 L
.5667 .09693 L
.57284 .10308 L
.57641 .10664 L
.58256 .11279 L
.58612 .11636 L
.59227 .1225 L
.59583 .12607 L
.60198 .13222 L
.60555 .13578 L
.60555 .14549 L
.61169 .15164 L
.61526 .15521 L
.62141 .16135 L
.62497 .16492 L
.62497 .17463 L
.63112 .18078 L
.63468 .18434 L
.63468 .19406 L
.64083 .2002 L
.6444 .20377 L
.65054 .20992 L
.65411 .21348 L
.65411 .22319 L
.66026 .22934 L
.66382 .23291 L
Mistroke
.66382 .24262 L
.66997 .24877 L
.67353 .25233 L
.67353 .26204 L
.67968 .26819 L
.68325 .27176 L
.68325 .28147 L
.68939 .28762 L
.69296 .29118 L
.69296 .30089 L
.69911 .30704 L
.70267 .31061 L
.70267 .32032 L
.70267 .33003 L
.70882 .33618 L
.71238 .33974 L
.71238 .34946 L
.71853 .3556 L
.7221 .35917 L
.7221 .36888 L
.72824 .37503 L
.73181 .37859 L
.73181 .38831 L
.73181 .39802 L
.73796 .40417 L
.74152 .40773 L
.74152 .41744 L
.74767 .42359 L
.75123 .42716 L
.75123 .43687 L
.75123 .44658 L
.75738 .45273 L
.76095 .45629 L
.76095 .46601 L
.76095 .47572 L
.76709 .48187 L
.77066 .48543 L
.77066 .49514 L
.77066 .50486 L
.77681 .511 L
.78037 .51457 L
.78037 .52428 L
.78037 .53399 L
.78652 .54014 L
.79008 .54371 L
.79008 .55342 L
.79008 .56313 L
.79623 .56928 L
.7998 .57284 L
.7998 .58256 L
Mistroke
.7998 .59227 L
.80594 .59842 L
.80951 .60198 L
.80951 .61169 L
.80951 .62141 L
.81566 .62755 L
.81922 .63112 L
.81922 .64083 L
.81922 .65054 L
.82537 .65669 L
.82893 .66026 L
.82893 .66997 L
.82893 .67968 L
.83508 .68583 L
.83865 .68939 L
.83865 .69911 L
.83865 .70882 L
.83865 .71853 L
.84479 .72468 L
.84836 .72824 L
.84836 .73796 L
.84836 .74767 L
.85451 .75382 L
.85807 .75738 L
.85807 .76709 L
.85807 .77681 L
.85807 .78652 L
.86422 .79267 L
.86778 .79623 L
.86778 .80594 L
.86778 .81566 L
.86778 .82537 L
.87393 .83152 L
.8775 .83508 L
.8775 .84479 L
.8775 .85451 L
.88364 .86065 L
.88721 .86422 L
.88721 .87393 L
.88721 .88364 L
.88364 .88721 L
.87393 .88721 L
.86422 .88721 L
.86065 .88364 L
.85451 .8775 L
.84479 .8775 L
.83508 .8775 L
.83152 .87393 L
.82537 .86778 L
.81566 .86778 L
Mistroke
.80594 .86778 L
.79623 .86778 L
.79267 .86422 L
.78652 .85807 L
.77681 .85807 L
.76709 .85807 L
.76353 .85451 L
.75738 .84836 L
.74767 .84836 L
.73796 .84836 L
.73439 .84479 L
.72824 .83865 L
.71853 .83865 L
.70882 .83865 L
.69911 .83865 L
.69554 .83508 L
.68939 .82893 L
.67968 .82893 L
.66997 .82893 L
.6664 .82537 L
.66026 .81922 L
.65054 .81922 L
.64083 .81922 L
.63112 .81922 L
.62755 .81566 L
.62141 .80951 L
.61169 .80951 L
.60198 .80951 L
.59842 .80594 L
.59227 .7998 L
.58256 .7998 L
.57284 .7998 L
.56928 .79623 L
.56313 .79008 L
.55342 .79008 L
.54371 .79008 L
.53399 .79008 L
.53043 .78652 L
.52428 .78037 L
.51457 .78037 L
.50486 .78037 L
.50129 .77681 L
.49514 .77066 L
.48543 .77066 L
.47572 .77066 L
.46601 .77066 L
.46244 .76709 L
.45629 .76095 L
.44658 .76095 L
.43687 .76095 L
Mistroke
.4333 .75738 L
.42716 .75123 L
.41744 .75123 L
.40773 .75123 L
.40417 .74767 L
.39802 .74152 L
.38831 .74152 L
.37859 .74152 L
.36888 .74152 L
.36532 .73796 L
.35917 .73181 L
.34946 .73181 L
.33974 .73181 L
.33618 .72824 L
.33003 .7221 L
.32032 .7221 L
.31061 .7221 L
.30089 .7221 L
.29733 .71853 L
.29118 .71238 L
.28147 .71238 L
.27176 .71238 L
.26819 .70882 L
.26204 .70267 L
.25233 .70267 L
.24262 .70267 L
.23905 .69911 L
.23291 .69296 L
.22319 .69296 L
.21348 .69296 L
.20377 .69296 L
.2002 .68939 L
.19406 .68325 L
.18434 .68325 L
.17463 .68325 L
.17107 .67968 L
.16492 .67353 L
.15521 .67353 L
.14549 .67353 L
.13578 .67353 L
.13222 .66997 L
.12607 .66382 L
.11636 .66382 L
.10664 .66382 L
.10308 .66026 L
.09693 .65411 L
.08722 .65411 L
.07751 .65411 L
.07394 .65054 L
.06779 .6444 L
Mistroke
.05808 .6444 L
.05452 .64083 L
.05452 .63112 L
.05808 .62755 L
.06423 .62141 L
.06423 .61169 L
.06423 .60198 L
.06779 .59842 L
.07394 .59227 L
.07394 .58256 L
.07394 .57284 L
.07751 .56928 L
.08365 .56313 L
.08365 .55342 L
.08365 .54371 L
.08722 .54014 L
.09337 .53399 L
.09337 .52428 L
.09337 .51457 L
.09693 .511 L
.10308 .50486 L
.10308 .49514 L
.10308 .48543 L
.10664 .48187 L
.11279 .47572 L
.11279 .46601 L
.11279 .45629 L
.11636 .45273 L
.1225 .44658 L
.1225 .43687 L
.12607 .4333 L
.13222 .42716 L
.13222 .41744 L
.13222 .40773 L
.13578 .40417 L
.14193 .39802 L
.14193 .38831 L
.14549 .38474 L
.15164 .37859 L
.15164 .36888 L
.15164 .35917 L
.15521 .3556 L
.16135 .34946 L
.16135 .33974 L
.16492 .33618 L
.17107 .33003 L
.17107 .32032 L
.17463 .31675 L
.18078 .31061 L
.18078 .30089 L
Mistroke
.18078 .29118 L
.18434 .28762 L
.19049 .28147 L
.19049 .27176 L
.19406 .26819 L
.2002 .26204 L
.2002 .25233 L
.20377 .24877 L
.20992 .24262 L
.20992 .23291 L
.21348 .22934 L
.21963 .22319 L
.21963 .21348 L
.22319 .20992 L
.22934 .20377 L
.23291 .2002 L
.23905 .19406 L
.23905 .18434 L
.24262 .18078 L
.24877 .17463 L
.24877 .16492 L
.25233 .16135 L
.25848 .15521 L
.26204 .15164 L
.26819 .14549 L
.26819 .13578 L
.27176 .13222 L
.2779 .12607 L
.28147 .1225 L
.28762 .11636 L
.29118 .11279 L
.29733 .10664 L
.30089 .10308 L
.30704 .09693 L
.30704 .08722 L
.31061 .08365 L
.31675 .07751 L
.32032 .07394 L
.33003 .07394 L
.33618 .06779 L
.33974 .06423 L
.34589 .05808 L
.34946 .05452 L
.3556 .04837 L
.35917 .0448 L
.36888 .0448 L
.37503 .03866 L
.37859 .03509 L
.38831 .03509 L
.39445 .02894 L
Mistroke
.39802 .02365 L
Mfstroke
.8 g
.39802 .02463 m
.40773 .02463 L
.41744 .02463 L
.42716 .02463 L
.43687 .02463 L
.44658 .02463 L
.45629 .02463 L
.46601 .02463 L
.47572 .02463 L
.4784 .02894 L
.48543 .03597 L
.49514 .03597 L
.50486 .03597 L
.50754 .03866 L
.51457 .04568 L
.51725 .04837 L
.52428 .0554 L
.52696 .05808 L
.53399 .06511 L
.54371 .06511 L
.54639 .06779 L
.55342 .07482 L
.5561 .07751 L
.56313 .08454 L
.56581 .08722 L
.56581 .09693 L
.57284 .10396 L
.57553 .10664 L
.58256 .11367 L
.58524 .11636 L
.59227 .12339 L
.59495 .12607 L
.60198 .1331 L
.60466 .13578 L
.60466 .14549 L
.61169 .15252 L
.61438 .15521 L
.62141 .16224 L
.62409 .16492 L
.62409 .17463 L
.63112 .18166 L
.6338 .18434 L
.6338 .19406 L
.64083 .20109 L
.64351 .20377 L
.65054 .2108 L
.65323 .21348 L
.65323 .22319 L
.66026 .23022 L
.66294 .23291 L
.66294 .24262 L
.66997 .24965 L
.67265 .25233 L
.67265 .26204 L
.67968 .26907 L
.68236 .27176 L
.68236 .28147 L
.68939 .2885 L
.69208 .29118 L
.69208 .30089 L
.69911 .30792 L
.70179 .31061 L
.70179 .32032 L
.70179 .33003 L
.70882 .33706 L
.7115 .33974 L
.7115 .34946 L
.71853 .35649 L
.72121 .35917 L
.72121 .36888 L
.72824 .37591 L
.73093 .37859 L
.73093 .38831 L
.73093 .39802 L
.73796 .40505 L
.74064 .40773 L
.74064 .41744 L
.74767 .42447 L
.75035 .42716 L
.75035 .43687 L
.75035 .44658 L
.75738 .45361 L
.76006 .45629 L
.76006 .46601 L
.76006 .47572 L
.76709 .48275 L
.76978 .48543 L
.76978 .49514 L
.76978 .50486 L
.77681 .51189 L
.77949 .51457 L
.77949 .52428 L
.77949 .53399 L
.78652 .54102 L
.7892 .54371 L
.7892 .55342 L
.7892 .56313 L
.79623 .57016 L
.79891 .57284 L
.79891 .58256 L
.79891 .59227 L
.80594 .5993 L
.80863 .60198 L
.80863 .61169 L
.80863 .62141 L
.81566 .62844 L
.81834 .63112 L
.81834 .64083 L
.81834 .65054 L
.82537 .65757 L
.82805 .66026 L
.82805 .66997 L
.82805 .67968 L
.83508 .68671 L
.83776 .68939 L
.83776 .69911 L
.83776 .70882 L
.83776 .71853 L
.84479 .72556 L
.84748 .72824 L
.84748 .73796 L
.84748 .74767 L
.85451 .7547 L
.85719 .75738 L
.85719 .76709 L
.85719 .77681 L
.85719 .78652 L
.86422 .79355 L
.8669 .79623 L
.8669 .80594 L
.8669 .81566 L
.8669 .82537 L
.87393 .8324 L
.87661 .83508 L
.87661 .84479 L
.87661 .85451 L
.88364 .86154 L
.88633 .86422 L
.88633 .87393 L
.88633 .88364 L
.88364 .88633 L
.87393 .88633 L
.86422 .88633 L
.86154 .88364 L
.85451 .87661 L
.84479 .87661 L
.83508 .87661 L
.8324 .87393 L
.82537 .8669 L
.81566 .8669 L
.80594 .8669 L
.79623 .8669 L
.79355 .86422 L
.78652 .85719 L
.77681 .85719 L
.76709 .85719 L
.76441 .85451 L
.75738 .84748 L
.74767 .84748 L
.73796 .84748 L
.73527 .84479 L
.72824 .83776 L
.71853 .83776 L
.70882 .83776 L
.69911 .83776 L
.69642 .83508 L
.68939 .82805 L
.67968 .82805 L
.66997 .82805 L
.66729 .82537 L
.66026 .81834 L
.65054 .81834 L
.64083 .81834 L
.63112 .81834 L
.62844 .81566 L
.62141 .80863 L
.61169 .80863 L
.60198 .80863 L
.5993 .80594 L
.59227 .79891 L
.58256 .79891 L
.57284 .79891 L
.57016 .79623 L
.56313 .7892 L
.55342 .7892 L
.54371 .7892 L
.53399 .7892 L
.53131 .78652 L
.52428 .77949 L
.51457 .77949 L
.50486 .77949 L
.50217 .77681 L
.49514 .76978 L
.48543 .76978 L
.47572 .76978 L
.46601 .76978 L
.46332 .76709 L
.45629 .76006 L
.44658 .76006 L
.43687 .76006 L
.43419 .75738 L
.42716 .75035 L
.41744 .75035 L
.40773 .75035 L
.40505 .74767 L
.39802 .74064 L
.38831 .74064 L
.37859 .74064 L
.36888 .74064 L
.3662 .73796 L
.35917 .73093 L
.34946 .73093 L
.33974 .73093 L
.33706 .72824 L
.33003 .72121 L
.32032 .72121 L
.31061 .72121 L
.30089 .72121 L
.29821 .71853 L
.29118 .7115 L
.28147 .7115 L
.27176 .7115 L
.26907 .70882 L
.26204 .70179 L
.25233 .70179 L
.24262 .70179 L
.23994 .69911 L
.23291 .69208 L
.22319 .69208 L
.21348 .69208 L
.20377 .69208 L
.20109 .68939 L
.19406 .68236 L
.18434 .68236 L
.17463 .68236 L
.17195 .67968 L
.16492 .67265 L
.15521 .67265 L
.14549 .67265 L
.13578 .67265 L
.1331 .66997 L
.12607 .66294 L
.11636 .66294 L
.10664 .66294 L
.10396 .66026 L
.09693 .65323 L
.08722 .65323 L
.07751 .65323 L
.07482 .65054 L
.06779 .64351 L
.05808 .64351 L
.0554 .64083 L
.0554 .63112 L
.05808 .62844 L
.06511 .62141 L
.06511 .61169 L
.06511 .60198 L
.06779 .5993 L
.07482 .59227 L
.07482 .58256 L
.07482 .57284 L
.07751 .57016 L
.08454 .56313 L
.08454 .55342 L
.08454 .54371 L
.08722 .54102 L
.09425 .53399 L
.09425 .52428 L
.09425 .51457 L
.09693 .51189 L
.10396 .50486 L
.10396 .49514 L
.10396 .48543 L
.10664 .48275 L
.11367 .47572 L
.11367 .46601 L
.11367 .45629 L
.11636 .45361 L
.12339 .44658 L
.12339 .43687 L
.12607 .43419 L
.1331 .42716 L
.1331 .41744 L
.1331 .40773 L
.13578 .40505 L
.14281 .39802 L
.14281 .38831 L
.14549 .38562 L
.15252 .37859 L
.15252 .36888 L
.15252 .35917 L
.15521 .35649 L
.16224 .34946 L
.16224 .33974 L
.16492 .33706 L
.17195 .33003 L
.17195 .32032 L
.17463 .31764 L
.18166 .31061 L
.18166 .30089 L
.18166 .29118 L
.18434 .2885 L
.19137 .28147 L
.19137 .27176 L
.19406 .26907 L
.20109 .26204 L
.20109 .25233 L
.20377 .24965 L
.2108 .24262 L
.2108 .23291 L
.21348 .23022 L
.22051 .22319 L
.22051 .21348 L
.22319 .2108 L
.23022 .20377 L
.23291 .20109 L
.23994 .19406 L
.23994 .18434 L
.24262 .18166 L
.24965 .17463 L
.24965 .16492 L
.25233 .16224 L
.25936 .15521 L
.26204 .15252 L
.26907 .14549 L
.26907 .13578 L
.27176 .1331 L
.27879 .12607 L
.28147 .12339 L
.2885 .11636 L
.29118 .11367 L
.29821 .10664 L
.30089 .10396 L
.30792 .09693 L
.30792 .08722 L
.31061 .08454 L
.31764 .07751 L
.32032 .07482 L
.33003 .07482 L
.33706 .06779 L
.33974 .06511 L
.34677 .05808 L
.34946 .0554 L
.35649 .04837 L
.35917 .04568 L
.36888 .04568 L
.37591 .03866 L
.37859 .03597 L
.38831 .03597 L
.39534 .02894 L
F
0 g
.39802 .02463 m
.40773 .02463 L
.41744 .02463 L
.42716 .02463 L
.43687 .02463 L
.44658 .02463 L
.45629 .02463 L
.46601 .02463 L
.47572 .02463 L
.4784 .02894 L
.48543 .03597 L
.49514 .03597 L
.50486 .03597 L
.50754 .03866 L
.51457 .04568 L
.51725 .04837 L
.52428 .0554 L
.52696 .05808 L
.53399 .06511 L
.54371 .06511 L
.54639 .06779 L
.55342 .07482 L
.5561 .07751 L
.56313 .08454 L
.56581 .08722 L
.56581 .09693 L
.57284 .10396 L
.57553 .10664 L
.58256 .11367 L
.58524 .11636 L
.59227 .12339 L
.59495 .12607 L
.60198 .1331 L
.60466 .13578 L
.60466 .14549 L
.61169 .15252 L
.61438 .15521 L
.62141 .16224 L
.62409 .16492 L
.62409 .17463 L
.63112 .18166 L
.6338 .18434 L
.6338 .19406 L
.64083 .20109 L
.64351 .20377 L
.65054 .2108 L
.65323 .21348 L
.65323 .22319 L
.66026 .23022 L
.66294 .23291 L
Mistroke
.66294 .24262 L
.66997 .24965 L
.67265 .25233 L
.67265 .26204 L
.67968 .26907 L
.68236 .27176 L
.68236 .28147 L
.68939 .2885 L
.69208 .29118 L
.69208 .30089 L
.69911 .30792 L
.70179 .31061 L
.70179 .32032 L
.70179 .33003 L
.70882 .33706 L
.7115 .33974 L
.7115 .34946 L
.71853 .35649 L
.72121 .35917 L
.72121 .36888 L
.72824 .37591 L
.73093 .37859 L
.73093 .38831 L
.73093 .39802 L
.73796 .40505 L
.74064 .40773 L
.74064 .41744 L
.74767 .42447 L
.75035 .42716 L
.75035 .43687 L
.75035 .44658 L
.75738 .45361 L
.76006 .45629 L
.76006 .46601 L
.76006 .47572 L
.76709 .48275 L
.76978 .48543 L
.76978 .49514 L
.76978 .50486 L
.77681 .51189 L
.77949 .51457 L
.77949 .52428 L
.77949 .53399 L
.78652 .54102 L
.7892 .54371 L
.7892 .55342 L
.7892 .56313 L
.79623 .57016 L
.79891 .57284 L
.79891 .58256 L
Mistroke
.79891 .59227 L
.80594 .5993 L
.80863 .60198 L
.80863 .61169 L
.80863 .62141 L
.81566 .62844 L
.81834 .63112 L
.81834 .64083 L
.81834 .65054 L
.82537 .65757 L
.82805 .66026 L
.82805 .66997 L
.82805 .67968 L
.83508 .68671 L
.83776 .68939 L
.83776 .69911 L
.83776 .70882 L
.83776 .71853 L
.84479 .72556 L
.84748 .72824 L
.84748 .73796 L
.84748 .74767 L
.85451 .7547 L
.85719 .75738 L
.85719 .76709 L
.85719 .77681 L
.85719 .78652 L
.86422 .79355 L
.8669 .79623 L
.8669 .80594 L
.8669 .81566 L
.8669 .82537 L
.87393 .8324 L
.87661 .83508 L
.87661 .84479 L
.87661 .85451 L
.88364 .86154 L
.88633 .86422 L
.88633 .87393 L
.88633 .88364 L
.88364 .88633 L
.87393 .88633 L
.86422 .88633 L
.86154 .88364 L
.85451 .87661 L
.84479 .87661 L
.83508 .87661 L
.8324 .87393 L
.82537 .8669 L
.81566 .8669 L
Mistroke
.80594 .8669 L
.79623 .8669 L
.79355 .86422 L
.78652 .85719 L
.77681 .85719 L
.76709 .85719 L
.76441 .85451 L
.75738 .84748 L
.74767 .84748 L
.73796 .84748 L
.73527 .84479 L
.72824 .83776 L
.71853 .83776 L
.70882 .83776 L
.69911 .83776 L
.69642 .83508 L
.68939 .82805 L
.67968 .82805 L
.66997 .82805 L
.66729 .82537 L
.66026 .81834 L
.65054 .81834 L
.64083 .81834 L
.63112 .81834 L
.62844 .81566 L
.62141 .80863 L
.61169 .80863 L
.60198 .80863 L
.5993 .80594 L
.59227 .79891 L
.58256 .79891 L
.57284 .79891 L
.57016 .79623 L
.56313 .7892 L
.55342 .7892 L
.54371 .7892 L
.53399 .7892 L
.53131 .78652 L
.52428 .77949 L
.51457 .77949 L
.50486 .77949 L
.50217 .77681 L
.49514 .76978 L
.48543 .76978 L
.47572 .76978 L
.46601 .76978 L
.46332 .76709 L
.45629 .76006 L
.44658 .76006 L
.43687 .76006 L
Mistroke
.43419 .75738 L
.42716 .75035 L
.41744 .75035 L
.40773 .75035 L
.40505 .74767 L
.39802 .74064 L
.38831 .74064 L
.37859 .74064 L
.36888 .74064 L
.3662 .73796 L
.35917 .73093 L
.34946 .73093 L
.33974 .73093 L
.33706 .72824 L
.33003 .72121 L
.32032 .72121 L
.31061 .72121 L
.30089 .72121 L
.29821 .71853 L
.29118 .7115 L
.28147 .7115 L
.27176 .7115 L
.26907 .70882 L
.26204 .70179 L
.25233 .70179 L
.24262 .70179 L
.23994 .69911 L
.23291 .69208 L
.22319 .69208 L
.21348 .69208 L
.20377 .69208 L
.20109 .68939 L
.19406 .68236 L
.18434 .68236 L
.17463 .68236 L
.17195 .67968 L
.16492 .67265 L
.15521 .67265 L
.14549 .67265 L
.13578 .67265 L
.1331 .66997 L
.12607 .66294 L
.11636 .66294 L
.10664 .66294 L
.10396 .66026 L
.09693 .65323 L
.08722 .65323 L
.07751 .65323 L
.07482 .65054 L
.06779 .64351 L
Mistroke
.05808 .64351 L
.0554 .64083 L
.0554 .63112 L
.05808 .62844 L
.06511 .62141 L
.06511 .61169 L
.06511 .60198 L
.06779 .5993 L
.07482 .59227 L
.07482 .58256 L
.07482 .57284 L
.07751 .57016 L
.08454 .56313 L
.08454 .55342 L
.08454 .54371 L
.08722 .54102 L
.09425 .53399 L
.09425 .52428 L
.09425 .51457 L
.09693 .51189 L
.10396 .50486 L
.10396 .49514 L
.10396 .48543 L
.10664 .48275 L
.11367 .47572 L
.11367 .46601 L
.11367 .45629 L
.11636 .45361 L
.12339 .44658 L
.12339 .43687 L
.12607 .43419 L
.1331 .42716 L
.1331 .41744 L
.1331 .40773 L
.13578 .40505 L
.14281 .39802 L
.14281 .38831 L
.14549 .38562 L
.15252 .37859 L
.15252 .36888 L
.15252 .35917 L
.15521 .35649 L
.16224 .34946 L
.16224 .33974 L
.16492 .33706 L
.17195 .33003 L
.17195 .32032 L
.17463 .31764 L
.18166 .31061 L
.18166 .30089 L
Mistroke
.18166 .29118 L
.18434 .2885 L
.19137 .28147 L
.19137 .27176 L
.19406 .26907 L
.20109 .26204 L
.20109 .25233 L
.20377 .24965 L
.2108 .24262 L
.2108 .23291 L
.21348 .23022 L
.22051 .22319 L
.22051 .21348 L
.22319 .2108 L
.23022 .20377 L
.23291 .20109 L
.23994 .19406 L
.23994 .18434 L
.24262 .18166 L
.24965 .17463 L
.24965 .16492 L
.25233 .16224 L
.25936 .15521 L
.26204 .15252 L
.26907 .14549 L
.26907 .13578 L
.27176 .1331 L
.27879 .12607 L
.28147 .12339 L
.2885 .11636 L
.29118 .11367 L
.29821 .10664 L
.30089 .10396 L
.30792 .09693 L
.30792 .08722 L
.31061 .08454 L
.31764 .07751 L
.32032 .07482 L
.33003 .07482 L
.33706 .06779 L
.33974 .06511 L
.34677 .05808 L
.34946 .0554 L
.35649 .04837 L
.35917 .04568 L
.36888 .04568 L
.37591 .03866 L
.37859 .03597 L
.38831 .03597 L
.39534 .02894 L
Mistroke
.39802 .02463 L
Mfstroke
.9 g
.39802 .0258 m
.40773 .0258 L
.41744 .0258 L
.42716 .0258 L
.43687 .0258 L
.44658 .0258 L
.45629 .0258 L
.46601 .0258 L
.47572 .0258 L
.47748 .02894 L
.48543 .03689 L
.49514 .03689 L
.50486 .03689 L
.50662 .03866 L
.51457 .0466 L
.51633 .04837 L
.52428 .05632 L
.52605 .05808 L
.53399 .06603 L
.54371 .06603 L
.54547 .06779 L
.55342 .07574 L
.55518 .07751 L
.56313 .08545 L
.5649 .08722 L
.5649 .09693 L
.57284 .10488 L
.57461 .10664 L
.58256 .11459 L
.58432 .11636 L
.59227 .1243 L
.59403 .12607 L
.60198 .13402 L
.60375 .13578 L
.60375 .14549 L
.61169 .15344 L
.61346 .15521 L
.62141 .16315 L
.62317 .16492 L
.62317 .17463 L
.63112 .18258 L
.63288 .18434 L
.63288 .19406 L
.64083 .202 L
.6426 .20377 L
.65054 .21172 L
.65231 .21348 L
.65231 .22319 L
.66026 .23114 L
.66202 .23291 L
.66202 .24262 L
.66997 .25057 L
.67173 .25233 L
.67173 .26204 L
.67968 .26999 L
.68145 .27176 L
.68145 .28147 L
.68939 .28942 L
.69116 .29118 L
.69116 .30089 L
.69911 .30884 L
.70087 .31061 L
.70087 .32032 L
.70087 .33003 L
.70882 .33798 L
.71058 .33974 L
.71058 .34946 L
.71853 .3574 L
.7203 .35917 L
.7203 .36888 L
.72824 .37683 L
.73001 .37859 L
.73001 .38831 L
.73001 .39802 L
.73796 .40597 L
.73972 .40773 L
.73972 .41744 L
.74767 .42539 L
.74943 .42716 L
.74943 .43687 L
.74943 .44658 L
.75738 .45453 L
.75915 .45629 L
.75915 .46601 L
.75915 .47572 L
.76709 .48367 L
.76886 .48543 L
.76886 .49514 L
.76886 .50486 L
.77681 .5128 L
.77857 .51457 L
.77857 .52428 L
.77857 .53399 L
.78652 .54194 L
.78828 .54371 L
.78828 .55342 L
.78828 .56313 L
.79623 .57108 L
.798 .57284 L
.798 .58256 L
.798 .59227 L
.80594 .60022 L
.80771 .60198 L
.80771 .61169 L
.80771 .62141 L
.81566 .62935 L
.81742 .63112 L
.81742 .64083 L
.81742 .65054 L
.82537 .65849 L
.82713 .66026 L
.82713 .66997 L
.82713 .67968 L
.83508 .68763 L
.83685 .68939 L
.83685 .69911 L
.83685 .70882 L
.83685 .71853 L
.84479 .72648 L
.84656 .72824 L
.84656 .73796 L
.84656 .74767 L
.85451 .75562 L
.85627 .75738 L
.85627 .76709 L
.85627 .77681 L
.85627 .78652 L
.86422 .79447 L
.86598 .79623 L
.86598 .80594 L
.86598 .81566 L
.86598 .82537 L
.87393 .83332 L
.8757 .83508 L
.8757 .84479 L
.8757 .85451 L
.88364 .86245 L
.88541 .86422 L
.88541 .87393 L
.88541 .88364 L
.88364 .88541 L
.87393 .88541 L
.86422 .88541 L
.86245 .88364 L
.85451 .8757 L
.84479 .8757 L
.83508 .8757 L
.83332 .87393 L
.82537 .86598 L
.81566 .86598 L
.80594 .86598 L
.79623 .86598 L
.79447 .86422 L
.78652 .85627 L
.77681 .85627 L
.76709 .85627 L
.76533 .85451 L
.75738 .84656 L
.74767 .84656 L
.73796 .84656 L
.73619 .84479 L
.72824 .83685 L
.71853 .83685 L
.70882 .83685 L
.69911 .83685 L
.69734 .83508 L
.68939 .82713 L
.67968 .82713 L
.66997 .82713 L
.6682 .82537 L
.66026 .81742 L
.65054 .81742 L
.64083 .81742 L
.63112 .81742 L
.62935 .81566 L
.62141 .80771 L
.61169 .80771 L
.60198 .80771 L
.60022 .80594 L
.59227 .798 L
.58256 .798 L
.57284 .798 L
.57108 .79623 L
.56313 .78828 L
.55342 .78828 L
.54371 .78828 L
.53399 .78828 L
.53223 .78652 L
.52428 .77857 L
.51457 .77857 L
.50486 .77857 L
.50309 .77681 L
.49514 .76886 L
.48543 .76886 L
.47572 .76886 L
.46601 .76886 L
.46424 .76709 L
.45629 .75915 L
.44658 .75915 L
.43687 .75915 L
.4351 .75738 L
.42716 .74943 L
.41744 .74943 L
.40773 .74943 L
.40597 .74767 L
.39802 .73972 L
.38831 .73972 L
.37859 .73972 L
.36888 .73972 L
.36712 .73796 L
.35917 .73001 L
.34946 .73001 L
.33974 .73001 L
.33798 .72824 L
.33003 .7203 L
.32032 .7203 L
.31061 .7203 L
.30089 .7203 L
.29913 .71853 L
.29118 .71058 L
.28147 .71058 L
.27176 .71058 L
.26999 .70882 L
.26204 .70087 L
.25233 .70087 L
.24262 .70087 L
.24085 .69911 L
.23291 .69116 L
.22319 .69116 L
.21348 .69116 L
.20377 .69116 L
.202 .68939 L
.19406 .68145 L
.18434 .68145 L
.17463 .68145 L
.17287 .67968 L
.16492 .67173 L
.15521 .67173 L
.14549 .67173 L
.13578 .67173 L
.13402 .66997 L
.12607 .66202 L
.11636 .66202 L
.10664 .66202 L
.10488 .66026 L
.09693 .65231 L
.08722 .65231 L
.07751 .65231 L
.07574 .65054 L
.06779 .6426 L
.05808 .6426 L
.05632 .64083 L
.05632 .63112 L
.05808 .62935 L
.06603 .62141 L
.06603 .61169 L
.06603 .60198 L
.06779 .60022 L
.07574 .59227 L
.07574 .58256 L
.07574 .57284 L
.07751 .57108 L
.08545 .56313 L
.08545 .55342 L
.08545 .54371 L
.08722 .54194 L
.09517 .53399 L
.09517 .52428 L
.09517 .51457 L
.09693 .5128 L
.10488 .50486 L
.10488 .49514 L
.10488 .48543 L
.10664 .48367 L
.11459 .47572 L
.11459 .46601 L
.11459 .45629 L
.11636 .45453 L
.1243 .44658 L
.1243 .43687 L
.12607 .4351 L
.13402 .42716 L
.13402 .41744 L
.13402 .40773 L
.13578 .40597 L
.14373 .39802 L
.14373 .38831 L
.14549 .38654 L
.15344 .37859 L
.15344 .36888 L
.15344 .35917 L
.15521 .3574 L
.16315 .34946 L
.16315 .33974 L
.16492 .33798 L
.17287 .33003 L
.17287 .32032 L
.17463 .31855 L
.18258 .31061 L
.18258 .30089 L
.18258 .29118 L
.18434 .28942 L
.19229 .28147 L
.19229 .27176 L
.19406 .26999 L
.202 .26204 L
.202 .25233 L
.20377 .25057 L
.21172 .24262 L
.21172 .23291 L
.21348 .23114 L
.22143 .22319 L
.22143 .21348 L
.22319 .21172 L
.23114 .20377 L
.23291 .202 L
.24085 .19406 L
.24085 .18434 L
.24262 .18258 L
.25057 .17463 L
.25057 .16492 L
.25233 .16315 L
.26028 .15521 L
.26204 .15344 L
.26999 .14549 L
.26999 .13578 L
.27176 .13402 L
.2797 .12607 L
.28147 .1243 L
.28942 .11636 L
.29118 .11459 L
.29913 .10664 L
.30089 .10488 L
.30884 .09693 L
.30884 .08722 L
.31061 .08545 L
.31855 .07751 L
.32032 .07574 L
.33003 .07574 L
.33798 .06779 L
.33974 .06603 L
.34769 .05808 L
.34946 .05632 L
.3574 .04837 L
.35917 .0466 L
.36888 .0466 L
.37683 .03866 L
.37859 .03689 L
.38831 .03689 L
.39625 .02894 L
F
0 g
.39802 .0258 m
.40773 .0258 L
.41744 .0258 L
.42716 .0258 L
.43687 .0258 L
.44658 .0258 L
.45629 .0258 L
.46601 .0258 L
.47572 .0258 L
.47748 .02894 L
.48543 .03689 L
.49514 .03689 L
.50486 .03689 L
.50662 .03866 L
.51457 .0466 L
.51633 .04837 L
.52428 .05632 L
.52605 .05808 L
.53399 .06603 L
.54371 .06603 L
.54547 .06779 L
.55342 .07574 L
.55518 .07751 L
.56313 .08545 L
.5649 .08722 L
.5649 .09693 L
.57284 .10488 L
.57461 .10664 L
.58256 .11459 L
.58432 .11636 L
.59227 .1243 L
.59403 .12607 L
.60198 .13402 L
.60375 .13578 L
.60375 .14549 L
.61169 .15344 L
.61346 .15521 L
.62141 .16315 L
.62317 .16492 L
.62317 .17463 L
.63112 .18258 L
.63288 .18434 L
.63288 .19406 L
.64083 .202 L
.6426 .20377 L
.65054 .21172 L
.65231 .21348 L
.65231 .22319 L
.66026 .23114 L
.66202 .23291 L
Mistroke
.66202 .24262 L
.66997 .25057 L
.67173 .25233 L
.67173 .26204 L
.67968 .26999 L
.68145 .27176 L
.68145 .28147 L
.68939 .28942 L
.69116 .29118 L
.69116 .30089 L
.69911 .30884 L
.70087 .31061 L
.70087 .32032 L
.70087 .33003 L
.70882 .33798 L
.71058 .33974 L
.71058 .34946 L
.71853 .3574 L
.7203 .35917 L
.7203 .36888 L
.72824 .37683 L
.73001 .37859 L
.73001 .38831 L
.73001 .39802 L
.73796 .40597 L
.73972 .40773 L
.73972 .41744 L
.74767 .42539 L
.74943 .42716 L
.74943 .43687 L
.74943 .44658 L
.75738 .45453 L
.75915 .45629 L
.75915 .46601 L
.75915 .47572 L
.76709 .48367 L
.76886 .48543 L
.76886 .49514 L
.76886 .50486 L
.77681 .5128 L
.77857 .51457 L
.77857 .52428 L
.77857 .53399 L
.78652 .54194 L
.78828 .54371 L
.78828 .55342 L
.78828 .56313 L
.79623 .57108 L
.798 .57284 L
.798 .58256 L
Mistroke
.798 .59227 L
.80594 .60022 L
.80771 .60198 L
.80771 .61169 L
.80771 .62141 L
.81566 .62935 L
.81742 .63112 L
.81742 .64083 L
.81742 .65054 L
.82537 .65849 L
.82713 .66026 L
.82713 .66997 L
.82713 .67968 L
.83508 .68763 L
.83685 .68939 L
.83685 .69911 L
.83685 .70882 L
.83685 .71853 L
.84479 .72648 L
.84656 .72824 L
.84656 .73796 L
.84656 .74767 L
.85451 .75562 L
.85627 .75738 L
.85627 .76709 L
.85627 .77681 L
.85627 .78652 L
.86422 .79447 L
.86598 .79623 L
.86598 .80594 L
.86598 .81566 L
.86598 .82537 L
.87393 .83332 L
.8757 .83508 L
.8757 .84479 L
.8757 .85451 L
.88364 .86245 L
.88541 .86422 L
.88541 .87393 L
.88541 .88364 L
.88364 .88541 L
.87393 .88541 L
.86422 .88541 L
.86245 .88364 L
.85451 .8757 L
.84479 .8757 L
.83508 .8757 L
.83332 .87393 L
.82537 .86598 L
.81566 .86598 L
Mistroke
.80594 .86598 L
.79623 .86598 L
.79447 .86422 L
.78652 .85627 L
.77681 .85627 L
.76709 .85627 L
.76533 .85451 L
.75738 .84656 L
.74767 .84656 L
.73796 .84656 L
.73619 .84479 L
.72824 .83685 L
.71853 .83685 L
.70882 .83685 L
.69911 .83685 L
.69734 .83508 L
.68939 .82713 L
.67968 .82713 L
.66997 .82713 L
.6682 .82537 L
.66026 .81742 L
.65054 .81742 L
.64083 .81742 L
.63112 .81742 L
.62935 .81566 L
.62141 .80771 L
.61169 .80771 L
.60198 .80771 L
.60022 .80594 L
.59227 .798 L
.58256 .798 L
.57284 .798 L
.57108 .79623 L
.56313 .78828 L
.55342 .78828 L
.54371 .78828 L
.53399 .78828 L
.53223 .78652 L
.52428 .77857 L
.51457 .77857 L
.50486 .77857 L
.50309 .77681 L
.49514 .76886 L
.48543 .76886 L
.47572 .76886 L
.46601 .76886 L
.46424 .76709 L
.45629 .75915 L
.44658 .75915 L
.43687 .75915 L
Mistroke
.4351 .75738 L
.42716 .74943 L
.41744 .74943 L
.40773 .74943 L
.40597 .74767 L
.39802 .73972 L
.38831 .73972 L
.37859 .73972 L
.36888 .73972 L
.36712 .73796 L
.35917 .73001 L
.34946 .73001 L
.33974 .73001 L
.33798 .72824 L
.33003 .7203 L
.32032 .7203 L
.31061 .7203 L
.30089 .7203 L
.29913 .71853 L
.29118 .71058 L
.28147 .71058 L
.27176 .71058 L
.26999 .70882 L
.26204 .70087 L
.25233 .70087 L
.24262 .70087 L
.24085 .69911 L
.23291 .69116 L
.22319 .69116 L
.21348 .69116 L
.20377 .69116 L
.202 .68939 L
.19406 .68145 L
.18434 .68145 L
.17463 .68145 L
.17287 .67968 L
.16492 .67173 L
.15521 .67173 L
.14549 .67173 L
.13578 .67173 L
.13402 .66997 L
.12607 .66202 L
.11636 .66202 L
.10664 .66202 L
.10488 .66026 L
.09693 .65231 L
.08722 .65231 L
.07751 .65231 L
.07574 .65054 L
.06779 .6426 L
Mistroke
.05808 .6426 L
.05632 .64083 L
.05632 .63112 L
.05808 .62935 L
.06603 .62141 L
.06603 .61169 L
.06603 .60198 L
.06779 .60022 L
.07574 .59227 L
.07574 .58256 L
.07574 .57284 L
.07751 .57108 L
.08545 .56313 L
.08545 .55342 L
.08545 .54371 L
.08722 .54194 L
.09517 .53399 L
.09517 .52428 L
.09517 .51457 L
.09693 .5128 L
.10488 .50486 L
.10488 .49514 L
.10488 .48543 L
.10664 .48367 L
.11459 .47572 L
.11459 .46601 L
.11459 .45629 L
.11636 .45453 L
.1243 .44658 L
.1243 .43687 L
.12607 .4351 L
.13402 .42716 L
.13402 .41744 L
.13402 .40773 L
.13578 .40597 L
.14373 .39802 L
.14373 .38831 L
.14549 .38654 L
.15344 .37859 L
.15344 .36888 L
.15344 .35917 L
.15521 .3574 L
.16315 .34946 L
.16315 .33974 L
.16492 .33798 L
.17287 .33003 L
.17287 .32032 L
.17463 .31855 L
.18258 .31061 L
.18258 .30089 L
Mistroke
.18258 .29118 L
.18434 .28942 L
.19229 .28147 L
.19229 .27176 L
.19406 .26999 L
.202 .26204 L
.202 .25233 L
.20377 .25057 L
.21172 .24262 L
.21172 .23291 L
.21348 .23114 L
.22143 .22319 L
.22143 .21348 L
.22319 .21172 L
.23114 .20377 L
.23291 .202 L
.24085 .19406 L
.24085 .18434 L
.24262 .18258 L
.25057 .17463 L
.25057 .16492 L
.25233 .16315 L
.26028 .15521 L
.26204 .15344 L
.26999 .14549 L
.26999 .13578 L
.27176 .13402 L
.2797 .12607 L
.28147 .1243 L
.28942 .11636 L
.29118 .11459 L
.29913 .10664 L
.30089 .10488 L
.30884 .09693 L
.30884 .08722 L
.31061 .08545 L
.31855 .07751 L
.32032 .07574 L
.33003 .07574 L
.33798 .06779 L
.33974 .06603 L
.34769 .05808 L
.34946 .05632 L
.3574 .04837 L
.35917 .0466 L
.36888 .0466 L
.37683 .03866 L
.37859 .03689 L
.38831 .03689 L
.39625 .02894 L
Mistroke
.39802 .0258 L
Mfstroke
1 g
.39802 .02732 m
.40773 .02732 L
.41744 .02732 L
.42716 .02732 L
.43687 .02732 L
.44658 .02732 L
.45629 .02732 L
.46601 .02732 L
.47572 .02732 L
.4765 .02894 L
.48543 .03787 L
.49514 .03787 L
.50486 .03787 L
.50564 .03866 L
.51457 .04758 L
.51535 .04837 L
.52428 .0573 L
.52507 .05808 L
.53399 .06701 L
.54371 .06701 L
.54449 .06779 L
.55342 .07672 L
.5542 .07751 L
.56313 .08643 L
.56392 .08722 L
.56392 .09693 L
.57284 .10586 L
.57363 .10664 L
.58256 .11557 L
.58334 .11636 L
.59227 .12528 L
.59305 .12607 L
.60198 .135 L
.60277 .13578 L
.60277 .14549 L
.61169 .15442 L
.61248 .15521 L
.62141 .16413 L
.62219 .16492 L
.62219 .17463 L
.63112 .18356 L
.6319 .18434 L
.6319 .19406 L
.64083 .20298 L
.64162 .20377 L
.65054 .2127 L
.65133 .21348 L
.65133 .22319 L
.66026 .23212 L
.66104 .23291 L
.66104 .24262 L
.66997 .25155 L
.67075 .25233 L
.67075 .26204 L
.67968 .27097 L
.68047 .27176 L
.68047 .28147 L
.68939 .2904 L
.69018 .29118 L
.69018 .30089 L
.69911 .30982 L
.69989 .31061 L
.69989 .32032 L
.69989 .33003 L
.70882 .33896 L
.7096 .33974 L
.7096 .34946 L
.71853 .35838 L
.71932 .35917 L
.71932 .36888 L
.72824 .37781 L
.72903 .37859 L
.72903 .38831 L
.72903 .39802 L
.73796 .40695 L
.73874 .40773 L
.73874 .41744 L
.74767 .42637 L
.74845 .42716 L
.74845 .43687 L
.74845 .44658 L
.75738 .45551 L
.75817 .45629 L
.75817 .46601 L
.75817 .47572 L
.76709 .48465 L
.76788 .48543 L
.76788 .49514 L
.76788 .50486 L
.77681 .51378 L
.77759 .51457 L
.77759 .52428 L
.77759 .53399 L
.78652 .54292 L
.7873 .54371 L
.7873 .55342 L
.7873 .56313 L
.79623 .57206 L
.79702 .57284 L
.79702 .58256 L
.79702 .59227 L
.80594 .6012 L
.80673 .60198 L
.80673 .61169 L
.80673 .62141 L
.81566 .63033 L
.81644 .63112 L
.81644 .64083 L
.81644 .65054 L
.82537 .65947 L
.82615 .66026 L
.82615 .66997 L
.82615 .67968 L
.83508 .68861 L
.83587 .68939 L
.83587 .69911 L
.83587 .70882 L
.83587 .71853 L
.84479 .72746 L
.84558 .72824 L
.84558 .73796 L
.84558 .74767 L
.85451 .7566 L
.85529 .75738 L
.85529 .76709 L
.85529 .77681 L
.85529 .78652 L
.86422 .79545 L
.865 .79623 L
.865 .80594 L
.865 .81566 L
.865 .82537 L
.87393 .8343 L
.87472 .83508 L
.87472 .84479 L
.87472 .85451 L
.88364 .86343 L
.88443 .86422 L
.88443 .87393 L
.88443 .88364 L
.88364 .88443 L
.87393 .88443 L
.86422 .88443 L
.86343 .88364 L
.85451 .87472 L
.84479 .87472 L
.83508 .87472 L
.8343 .87393 L
.82537 .865 L
.81566 .865 L
.80594 .865 L
.79623 .865 L
.79545 .86422 L
.78652 .85529 L
.77681 .85529 L
.76709 .85529 L
.76631 .85451 L
.75738 .84558 L
.74767 .84558 L
.73796 .84558 L
.73717 .84479 L
.72824 .83587 L
.71853 .83587 L
.70882 .83587 L
.69911 .83587 L
.69832 .83508 L
.68939 .82615 L
.67968 .82615 L
.66997 .82615 L
.66918 .82537 L
.66026 .81644 L
.65054 .81644 L
.64083 .81644 L
.63112 .81644 L
.63033 .81566 L
.62141 .80673 L
.61169 .80673 L
.60198 .80673 L
.6012 .80594 L
.59227 .79702 L
.58256 .79702 L
.57284 .79702 L
.57206 .79623 L
.56313 .7873 L
.55342 .7873 L
.54371 .7873 L
.53399 .7873 L
.53321 .78652 L
.52428 .77759 L
.51457 .77759 L
.50486 .77759 L
.50407 .77681 L
.49514 .76788 L
.48543 .76788 L
.47572 .76788 L
.46601 .76788 L
.46522 .76709 L
.45629 .75817 L
.44658 .75817 L
.43687 .75817 L
.43608 .75738 L
.42716 .74845 L
.41744 .74845 L
.40773 .74845 L
.40695 .74767 L
.39802 .73874 L
.38831 .73874 L
.37859 .73874 L
.36888 .73874 L
.3681 .73796 L
.35917 .72903 L
.34946 .72903 L
.33974 .72903 L
.33896 .72824 L
.33003 .71932 L
.32032 .71932 L
.31061 .71932 L
.30089 .71932 L
.30011 .71853 L
.29118 .7096 L
.28147 .7096 L
.27176 .7096 L
.27097 .70882 L
.26204 .69989 L
.25233 .69989 L
.24262 .69989 L
.24183 .69911 L
.23291 .69018 L
.22319 .69018 L
.21348 .69018 L
.20377 .69018 L
.20298 .68939 L
.19406 .68047 L
.18434 .68047 L
.17463 .68047 L
.17385 .67968 L
.16492 .67075 L
.15521 .67075 L
.14549 .67075 L
.13578 .67075 L
.135 .66997 L
.12607 .66104 L
.11636 .66104 L
.10664 .66104 L
.10586 .66026 L
.09693 .65133 L
.08722 .65133 L
.07751 .65133 L
.07672 .65054 L
.06779 .64162 L
.05808 .64162 L
.0573 .64083 L
.0573 .63112 L
.05808 .63033 L
.06701 .62141 L
.06701 .61169 L
.06701 .60198 L
.06779 .6012 L
.07672 .59227 L
.07672 .58256 L
.07672 .57284 L
.07751 .57206 L
.08643 .56313 L
.08643 .55342 L
.08643 .54371 L
.08722 .54292 L
.09615 .53399 L
.09615 .52428 L
.09615 .51457 L
.09693 .51378 L
.10586 .50486 L
.10586 .49514 L
.10586 .48543 L
.10664 .48465 L
.11557 .47572 L
.11557 .46601 L
.11557 .45629 L
.11636 .45551 L
.12528 .44658 L
.12528 .43687 L
.12607 .43608 L
.135 .42716 L
.135 .41744 L
.135 .40773 L
.13578 .40695 L
.14471 .39802 L
.14471 .38831 L
.14549 .38752 L
.15442 .37859 L
.15442 .36888 L
.15442 .35917 L
.15521 .35838 L
.16413 .34946 L
.16413 .33974 L
.16492 .33896 L
.17385 .33003 L
.17385 .32032 L
.17463 .31953 L
.18356 .31061 L
.18356 .30089 L
.18356 .29118 L
.18434 .2904 L
.19327 .28147 L
.19327 .27176 L
.19406 .27097 L
.20298 .26204 L
.20298 .25233 L
.20377 .25155 L
.2127 .24262 L
.2127 .23291 L
.21348 .23212 L
.22241 .22319 L
.22241 .21348 L
.22319 .2127 L
.23212 .20377 L
.23291 .20298 L
.24183 .19406 L
.24183 .18434 L
.24262 .18356 L
.25155 .17463 L
.25155 .16492 L
.25233 .16413 L
.26126 .15521 L
.26204 .15442 L
.27097 .14549 L
.27097 .13578 L
.27176 .135 L
.28068 .12607 L
.28147 .12528 L
.2904 .11636 L
.29118 .11557 L
.30011 .10664 L
.30089 .10586 L
.30982 .09693 L
.30982 .08722 L
.31061 .08643 L
.31953 .07751 L
.32032 .07672 L
.33003 .07672 L
.33896 .06779 L
.33974 .06701 L
.34867 .05808 L
.34946 .0573 L
.35838 .04837 L
.35917 .04758 L
.36888 .04758 L
.37781 .03866 L
.37859 .03787 L
.38831 .03787 L
.39723 .02894 L
F
0 g
.39802 .02732 m
.40773 .02732 L
.41744 .02732 L
.42716 .02732 L
.43687 .02732 L
.44658 .02732 L
.45629 .02732 L
.46601 .02732 L
.47572 .02732 L
.4765 .02894 L
.48543 .03787 L
.49514 .03787 L
.50486 .03787 L
.50564 .03866 L
.51457 .04758 L
.51535 .04837 L
.52428 .0573 L
.52507 .05808 L
.53399 .06701 L
.54371 .06701 L
.54449 .06779 L
.55342 .07672 L
.5542 .07751 L
.56313 .08643 L
.56392 .08722 L
.56392 .09693 L
.57284 .10586 L
.57363 .10664 L
.58256 .11557 L
.58334 .11636 L
.59227 .12528 L
.59305 .12607 L
.60198 .135 L
.60277 .13578 L
.60277 .14549 L
.61169 .15442 L
.61248 .15521 L
.62141 .16413 L
.62219 .16492 L
.62219 .17463 L
.63112 .18356 L
.6319 .18434 L
.6319 .19406 L
.64083 .20298 L
.64162 .20377 L
.65054 .2127 L
.65133 .21348 L
.65133 .22319 L
.66026 .23212 L
.66104 .23291 L
Mistroke
.66104 .24262 L
.66997 .25155 L
.67075 .25233 L
.67075 .26204 L
.67968 .27097 L
.68047 .27176 L
.68047 .28147 L
.68939 .2904 L
.69018 .29118 L
.69018 .30089 L
.69911 .30982 L
.69989 .31061 L
.69989 .32032 L
.69989 .33003 L
.70882 .33896 L
.7096 .33974 L
.7096 .34946 L
.71853 .35838 L
.71932 .35917 L
.71932 .36888 L
.72824 .37781 L
.72903 .37859 L
.72903 .38831 L
.72903 .39802 L
.73796 .40695 L
.73874 .40773 L
.73874 .41744 L
.74767 .42637 L
.74845 .42716 L
.74845 .43687 L
.74845 .44658 L
.75738 .45551 L
.75817 .45629 L
.75817 .46601 L
.75817 .47572 L
.76709 .48465 L
.76788 .48543 L
.76788 .49514 L
.76788 .50486 L
.77681 .51378 L
.77759 .51457 L
.77759 .52428 L
.77759 .53399 L
.78652 .54292 L
.7873 .54371 L
.7873 .55342 L
.7873 .56313 L
.79623 .57206 L
.79702 .57284 L
.79702 .58256 L
Mistroke
.79702 .59227 L
.80594 .6012 L
.80673 .60198 L
.80673 .61169 L
.80673 .62141 L
.81566 .63033 L
.81644 .63112 L
.81644 .64083 L
.81644 .65054 L
.82537 .65947 L
.82615 .66026 L
.82615 .66997 L
.82615 .67968 L
.83508 .68861 L
.83587 .68939 L
.83587 .69911 L
.83587 .70882 L
.83587 .71853 L
.84479 .72746 L
.84558 .72824 L
.84558 .73796 L
.84558 .74767 L
.85451 .7566 L
.85529 .75738 L
.85529 .76709 L
.85529 .77681 L
.85529 .78652 L
.86422 .79545 L
.865 .79623 L
.865 .80594 L
.865 .81566 L
.865 .82537 L
.87393 .8343 L
.87472 .83508 L
.87472 .84479 L
.87472 .85451 L
.88364 .86343 L
.88443 .86422 L
.88443 .87393 L
.88443 .88364 L
.88364 .88443 L
.87393 .88443 L
.86422 .88443 L
.86343 .88364 L
.85451 .87472 L
.84479 .87472 L
.83508 .87472 L
.8343 .87393 L
.82537 .865 L
.81566 .865 L
Mistroke
.80594 .865 L
.79623 .865 L
.79545 .86422 L
.78652 .85529 L
.77681 .85529 L
.76709 .85529 L
.76631 .85451 L
.75738 .84558 L
.74767 .84558 L
.73796 .84558 L
.73717 .84479 L
.72824 .83587 L
.71853 .83587 L
.70882 .83587 L
.69911 .83587 L
.69832 .83508 L
.68939 .82615 L
.67968 .82615 L
.66997 .82615 L
.66918 .82537 L
.66026 .81644 L
.65054 .81644 L
.64083 .81644 L
.63112 .81644 L
.63033 .81566 L
.62141 .80673 L
.61169 .80673 L
.60198 .80673 L
.6012 .80594 L
.59227 .79702 L
.58256 .79702 L
.57284 .79702 L
.57206 .79623 L
.56313 .7873 L
.55342 .7873 L
.54371 .7873 L
.53399 .7873 L
.53321 .78652 L
.52428 .77759 L
.51457 .77759 L
.50486 .77759 L
.50407 .77681 L
.49514 .76788 L
.48543 .76788 L
.47572 .76788 L
.46601 .76788 L
.46522 .76709 L
.45629 .75817 L
.44658 .75817 L
.43687 .75817 L
Mistroke
.43608 .75738 L
.42716 .74845 L
.41744 .74845 L
.40773 .74845 L
.40695 .74767 L
.39802 .73874 L
.38831 .73874 L
.37859 .73874 L
.36888 .73874 L
.3681 .73796 L
.35917 .72903 L
.34946 .72903 L
.33974 .72903 L
.33896 .72824 L
.33003 .71932 L
.32032 .71932 L
.31061 .71932 L
.30089 .71932 L
.30011 .71853 L
.29118 .7096 L
.28147 .7096 L
.27176 .7096 L
.27097 .70882 L
.26204 .69989 L
.25233 .69989 L
.24262 .69989 L
.24183 .69911 L
.23291 .69018 L
.22319 .69018 L
.21348 .69018 L
.20377 .69018 L
.20298 .68939 L
.19406 .68047 L
.18434 .68047 L
.17463 .68047 L
.17385 .67968 L
.16492 .67075 L
.15521 .67075 L
.14549 .67075 L
.13578 .67075 L
.135 .66997 L
.12607 .66104 L
.11636 .66104 L
.10664 .66104 L
.10586 .66026 L
.09693 .65133 L
.08722 .65133 L
.07751 .65133 L
.07672 .65054 L
.06779 .64162 L
Mistroke
.05808 .64162 L
.0573 .64083 L
.0573 .63112 L
.05808 .63033 L
.06701 .62141 L
.06701 .61169 L
.06701 .60198 L
.06779 .6012 L
.07672 .59227 L
.07672 .58256 L
.07672 .57284 L
.07751 .57206 L
.08643 .56313 L
.08643 .55342 L
.08643 .54371 L
.08722 .54292 L
.09615 .53399 L
.09615 .52428 L
.09615 .51457 L
.09693 .51378 L
.10586 .50486 L
.10586 .49514 L
.10586 .48543 L
.10664 .48465 L
.11557 .47572 L
.11557 .46601 L
.11557 .45629 L
.11636 .45551 L
.12528 .44658 L
.12528 .43687 L
.12607 .43608 L
.135 .42716 L
.135 .41744 L
.135 .40773 L
.13578 .40695 L
.14471 .39802 L
.14471 .38831 L
.14549 .38752 L
.15442 .37859 L
.15442 .36888 L
.15442 .35917 L
.15521 .35838 L
.16413 .34946 L
.16413 .33974 L
.16492 .33896 L
.17385 .33003 L
.17385 .32032 L
.17463 .31953 L
.18356 .31061 L
.18356 .30089 L
Mistroke
.18356 .29118 L
.18434 .2904 L
.19327 .28147 L
.19327 .27176 L
.19406 .27097 L
.20298 .26204 L
.20298 .25233 L
.20377 .25155 L
.2127 .24262 L
.2127 .23291 L
.21348 .23212 L
.22241 .22319 L
.22241 .21348 L
.22319 .2127 L
.23212 .20377 L
.23291 .20298 L
.24183 .19406 L
.24183 .18434 L
.24262 .18356 L
.25155 .17463 L
.25155 .16492 L
.25233 .16413 L
.26126 .15521 L
.26204 .15442 L
.27097 .14549 L
.27097 .13578 L
.27176 .135 L
.28068 .12607 L
.28147 .12528 L
.2904 .11636 L
.29118 .11557 L
.30011 .10664 L
.30089 .10586 L
.30982 .09693 L
.30982 .08722 L
.31061 .08643 L
.31953 .07751 L
.32032 .07672 L
.33003 .07672 L
.33896 .06779 L
.33974 .06701 L
.34867 .05808 L
.34946 .0573 L
.35838 .04837 L
.35917 .04758 L
.36888 .04758 L
.37781 .03866 L
.37859 .03787 L
.38831 .03787 L
.39723 .02894 L
Mistroke
.39802 .02732 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008oooool4o`000003oa0@4?oooooooooo03Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0hooooo`Co000000?o410@ooooooooool0
;Oooool002Gooooo00?o0000ooooooooool0=oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0iooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0>Oooool00ol0
003oooooooooo`0_ooooo`006_ooool6o`0000Gooooo00?o0000ooooooooool0;oooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo037ooooo00Go410@oooo
oooooooooooooa0@400iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02oooooo000Uooooo`03o`000?oooooooooo03Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03;ooooo00Go0000oooooooooooooooo
o`00000iooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0iooooo`03
o`000?oooooooooo02oooooo000Uooooo`03o`000?oooooooooo03Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<oooool01Ol0003ooooooooooooooooo
000003Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
>_ooool00ol0003oooooooooo`0_ooooo`009Oooool00ol0003oooooooooo`0gooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@
4100>Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0_ooooo`009Oooool00ol0003oooooooooo`0gooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0_ooooo`008oooool00omEEEGoIVIVo`00000iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0003Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0iooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003Wooooo00?oEEEEofIVI_l00000<Oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001[oooooool0
001>o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0;Oooool1o`00
007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooo
od[ooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0oooooom:ooooo`7o00000Oooool000oooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo000?ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`00087ooooo6ol0002[ooooo`?o00000Oooool000oooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001oooo
o`003oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooo`00
043o00001_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooOOl0000KooooojOo00001_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooO?l0000MooooojKo00001_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooNol0000OooooojGo00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooMol0000[oooooigo00001_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooM_l0000]oooooico00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooMOl0000_oooooi_o00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooLOl0000coooooi_o00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooL?l0000eoooooi[o00001_ooool1o`00007ooooo000Jooooo`;o00001Ooo
oom_o`0003OoooooVOl00005ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooom^
o`0003WoooooV?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom]o`00
03coooooU_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom/o`0003ko
ooooUOl00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooom[o`00043ooooo
U?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomZo`0004GoooooT?l0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomYo`0004OoooooSol00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomXo`0004WoooooS_l00006oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomSo`0004ooooooSOl00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooomRo`00057oooooS?l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooomQo`0005?oooooRol00006ooooo`7o00000Oooool001[o
oooo0_l00005ooooof7o0000Dooooon;o`0000Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooof7o0000Dooooon;o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooof3o0000EOoooon:o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooeoo0000Eooooon9o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oeko0000FOoooon8o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooego
0000G?oooon6o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeco0000
G_oooon5o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe_o0000H?oo
oon4o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe[o0000H_oooon3
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeWo0000I?oooon2o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeSo0000I_oooon1o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooeKo0000JOoooon0o`0000Kooooo
0Ol00001ooooo`006_ooool2o`0000GoooooEOl0001[ooooogoo00001Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooE?l0001]ooooogko00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooDol0001_oooooggo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooD_l0001aooooogco00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooDOl0001cooooog_o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
D?l0001fooooogWo00001_ooool1o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool01?oooom?o`0007SoooooN?l00006ooooo`7o0000
0Oooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`04ooooodko0000N_oooomgo`0000Kooooo0Ol00001ooooo`00
0oooool00ol@413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00004ooooodko0000
N_oooomgo`0000Cooooo0ol00001ooooo`000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool01?oooom>o`0007[oooooMol00006ooooo`7o00000Ooo
ool000?ooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo00CoooooC_l0001jooooogOo00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooodko0000N_oooomgo`00
00Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool01?oooom=o`0007coooooM_l00006ooooo`7o00000Oooool0
0004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00CoooooC?l0001nooooogGo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooBol00020ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooB_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooB_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
B_l00021ooooogCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooB_l0
0022ooooog?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooBOl00024
ooooog;o00001_ooool1o`00007ooooo000Jooooo`;o00001Ooooom8o`0008KoooooLOl00005oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooom6o`0008WoooooL?l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooom5o`0008_oooooKol00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooom4o`0008goooooK_l00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooom4o`0008koooooKOl00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooom3o`0008ooooooKOl00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooom2o`00097oooooK?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooom1o`0009?oooooJol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooom1o`0009CoooooJ_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooom1o`0009CoooooJ_l00006ooooo`7o00000Oooool001[ooooo0_l00005oooood7o0000U?oo
oomZo`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooood3o0000U_oooomY
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocoo0000V?oooomXo`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooocko0000V_oooomWo`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooocgo0000W?oooomVo`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooocco0000W_oooomUo`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooc_o0000X?oooomTo`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooc[o0000XOoooomTo`0000Kooooo0Ol00001ooooo`006_ooool2o`00
00Gooooo>_l0002QooooofCo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo>_l0002QooooofCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
>Ol0002Sooooof?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo>?l0
002Uooooof;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002W
ooooof7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Woooo
of7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Wooooof7o00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo=ol0002Xooooof3o00001_ooool1
o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool01?oooolgo`000:WoooooGol00006ooooo`7o00000Oooool0
0004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?oooolgo`000:[oooooG_l00006ooooo`7o00000Oooool000?ooooo00?o410@oooo
ooooool02Oooool5o`0000Kooooo0ol00004ooooocKo0000[?oooomMo`0000Cooooo0ol00001oooo
o`000oooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool01?ooooleo`000:goooooGOl00006ooooo`7o00000Oooool000?ooooo00?o0000oooooooo
ool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00Cooooo=?l0002^oooo
oego00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`04ooooocCo0000[_oooomMo`0000Kooooo0Ol00001ooooo`00
00CoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Co
oooo=?l0002^oooooego00001_ooool1o`00007ooooo00001?lb<S;o0000oc8b<_o^k^h=ooooo`03
ogMgMol0003ooooo00Kooooo00?o0000ooooooooool01?ooooldo`000:koooooGOl00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooolco`000;3oooooG?l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooolbo`000;;oooooFol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolao`000;CoooooF_l00006ooooo`7o00000Oooool001[ooooo0_l00005
oooooc3o0000]_oooomIo`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oboo0000^?oooomHo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobko
0000^_oooomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000
^ooooomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000^ooo
oomGo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000^ooooomG
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000_?oooomFo`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000_OoooomEo`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobgo0000__oooomDo`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooobco0000_ooooomDo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooob_o0000`?oooomDo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooob[o0000`OoooomDo`0000Kooooo0Ol00001oooo
o`006_ooool2o`0000Gooooo:_l00031oooooeCo00001Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo:_l00031oooooeCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo:Ol00033oooooe?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo:?l00035oooooe;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
9ol00037oooooe7o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol0
0038oooooe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00038
oooooe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00038oooo
oe3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol00039ooooodoo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo9ol0003:ooooodko0000
1_ooool1o`00007ooooo000Jooooo`;o00001OoooolWo`000<_oooooCOl00005ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolWo`000<_oooooCOl00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolUo`000<goooooCOl00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooolTo`000<koooooCOl00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolSo`000=3oooooC?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooolRo`000=;oooooBol00006ooooo`7o00000Oooool00004oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`04ooooob7o
0000e?oooom:o`0000Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Cooooo8Ol0003Doooo
od[o00001_ooool1o`00007ooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00001?oooolQo`000=CoooooB_l00004ooooo`?o00000Oooool000?o
oooo00?o0000ooooooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool01?oooolQo`000=CoooooB_l00006ooooo`7o00000Oooool000?ooooo00?o0000oooooooo
ool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool01?oooolQo`00
0=CoooooB_l00006ooooo`7o00000Oooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo00Cooooo8Ol0003Doooood[o00001_ooool1o`00007o
oooo00001?nHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool01?oooolQo`000=CoooooB_l00006ooooo`7o00000Oooool00004oc8b<_l0003o<S8bonk^kPco
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`04ooooob7o0000e?oooom:o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooob3o0000e_oooom9o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooaoo0000f?oooom8o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooako0000f_oooom7o`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooago0000fooooom7o`0000Kooooo0Ol00001ooooo`006_oo
ool2o`0000Gooooo7Ol0003KooooodOo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo7Ol0003KooooodOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo7?l0003MooooodKo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo6ol0003OooooodGo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
6_l0003QooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0
003QooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003Q
ooooodCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003Qoooo
odCo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo6_l0003QooooodCo00001_ooool1
o`00007ooooo000Jooooo`;o00001OoooolIo`000>?ooooo@ol00005ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolHo`000>Gooooo@_l00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolGo`000>Oooooo@Ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oolGo`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolG
o`000>Sooooo@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolFo`00
0>[ooooo?ol00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooolEo`000>co
oooo?_l00006ooooo`7o00000Oooool001[ooooo0_l00005oooooaCo0000k_oooolmo`0000Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooaCo0000k_oooolmo`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooa?o0000l?oooollo`0000Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooa;o0000l_oooolko`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooa7o0000m?ooooljo`0000Kooooo0Ol00001ooooo`0000Co<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
00Cooooo4?l0003eoooooc[o00001_ooool1o`00007ooooo00001?nHV9SooooooiRHV?mgMgL5oooo
o`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool01?ooool@
o`000?Gooooo>_l00006ooooo`7o00000Oooool000?ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooool@o`000?Gooooo>_l00006
ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol00004oooooa3o0000mOooooljo`0000Cooooo0ol00001ooooo`000oooool00ol0
003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`04
oooooa3o0000mOooooljo`0000Kooooo0Ol00001ooooo`000oooool00ol@413oooooooooo`09oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`04oooooa3o0000mOoooolj
o`0000Kooooo0Ol00001ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool01?ooool@o`000?Gooooo>_l00006ooooo`7o00000Ooo
ool00004oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo00Cooooo3ol0003gooooocWo00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo3_l0003iooooocSo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
3Ol0003kooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo4Ol0
003gooooocOo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo4_l0003f
ooooocOo00001_ooool1o`00007ooooo000Jooooo`;o00001OoooolCo`000?Gooooo=ol00005oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooolJo`000>kooooo=ol00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooolKo`000>kooooo=_l00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooolLo`000>kooooo=Ol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooolTo`000>Oooooo=?l00006ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooolUo`000>Oooooo<ol00006ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooolVo`000>Kooooo<ol00006ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooolao`000=_ooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooolbo`000=[ooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooolco`000=Wooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooldo`000=Sooooo<ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooolko`000=;ooooo<_l00006ooooo`7o00000Oooool001[ooooo0_l00005ooooocco0000
d_oooolao`0000Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooocgo0000d_oo
ool`o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodSo0000aoooool`
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodSo0000aoooool`o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooodWo0000a_ooool`o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe7o0000__ooool`o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooe;o0000_Oooool`o`0000Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooe?o0000_?ooool`o`0000Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooe_o0000]?ooool`o`0000Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooeco0000/oooool`o`0000Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooego0000/_ooool`o`0000Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooeko0000/Oooool`o`0000Kooooo0Ol00001ooooo`006_ooool2
o`0000GoooooJ?l0002Xoooooboo00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooJOl0002Xooooobko00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooJ_l0002Xooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
LOl0002Qooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooL_l0
002Pooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooLol0002O
ooooobgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO_l0002Doooo
obgo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOol0002Cooooobgo
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?l0002Booooobgo0000
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?l0002:ooooobgo00001_oo
ool1o`00007ooooo000@ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`04
ooooohWo0000R_ooool/o`0000Kooooo0Ol00001ooooo`004_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00CoooooR_l0002:ooooob_o00001_ooool1o`00007ooooo000Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oooonBo`0008?ooooo:_l00006ooooo`7o
00000Oooool001;ooooo00?o0000ooooooooool01Oooool3o`0000CoooooTol00022ooooob[o0000
1?ooool3o`00007ooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
oonDo`00087ooooo:_l00006ooooo`7o00000Oooool001;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04oooooiGo0000P?oooolZo`0000Kooooo0Ol00001ooooo`004_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00CoooooWol0001fooooob[o00001_ooool1o`00
007ooooo000@ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool01?oooonPo`0007Go
oooo:_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQo`0007Cooooo
:_l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXo`0006gooooo:_l0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYo`0006cooooo:_l00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonZo`0006_ooooo:_l00006oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneo`00063ooooo:_l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonfo`00063ooooo:Ol00006ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooongo`00063ooooo:?l00006ooooo`7o00000Ooo
ool001[ooooo0_l00005oooookoo0000FOoooolWo`0000Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04oooool3o0000F?oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool7o0000EooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool;o0000E_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolWo0000CooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooool[o0000C_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ol_o0000COoooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomGo
0000@ooooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomKo0000
@_oooolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomOo0000@Ooo
oolWo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomoo0000>OoooolW
o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3o0000>OoooolVo`00
00Kooooo0Ol00001ooooo`006_ooool2o`0000GooooohOl0000iooooobGo00001Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00Coooook?l0000_ooooobCo00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooookOl0000_ooooob?o00001_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Coooook_l0000^ooooob?o00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooom_l0000Vooooob?o00001_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooomol0000Uooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooon?l0000Tooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooonOl0000Sooooob?o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooooool0000Nooooob;o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooooool00001o`0001kooooo8Ol00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooo`0000;o00007_oooolPo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooooo00003Ol0000Cooooob3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooool0000>o`0001;ooooo8?l00006ooooo`7o00000Oooool001[ooooo0_l00005
oooooooo00003ol0000Aooooob3o00001Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooooool0000Go`0000Wooooo8?l00006ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooo`0001So00002?oooolPo`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooooo00006Ol00007ooooob3o00001_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00
043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o0000
0Oooool000Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool01?oo
ooooo`00043o00001_ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool0
00;ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP06ooooo`?o00001?ooooooo`00
043o00001?ooool3o`00007ooooo0002ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool000;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
ool00010o`0000Kooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o0000
0Oooool00003oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
o`00043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo0_l00005oooo
oooo0000@?l00005ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o
00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooooo0000@?l00006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooo`00043o00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooool0
0010o`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo0000@?l00006
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooo`00043o00001_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooooool00010o`0000Kooooo0Ol00001ooooo`00
6_ooool2o`0000Goooooool00010o`0000Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`3ooooood[ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0;Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Here we have used a technique involving the function ",
  StyleBox["Boole",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available only in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 4.1 or later, that allows one to plot or integrate over complex \
regions defined by inequalities. We will also use this technique in defining \
the inner product over this region. This technique is merely a convenience; \
it is also possible to write out the ranges of integration in the inner \
product explicitly. "
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  "\tWithin this domain, we will solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\)\  = \ 1\)]],
  ", with boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\( | \_S\)\) = 0\)]],
  ". "
}], "Text"],

Cell["\<\
\tThe following module puts the whole Galerkin method together in \
one place:\
\>", "Text",
  CellTags->"i:8"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          define\ the\ curves\ that\ determine\ the\ \(\(boundary\)\(:\)\)\ *) \
\),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(z[1, x_, y_]\  = \ y - \((x/6 + 1)\);\), 
        "\n", \(z[2, x_, y_]\  = \ y - x\^2;\), " ", "\n", 
        StyleBox[\( (*\ define\ the\ charge\ density\ \ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(\[Rho][x_, y_]\  = \ 1;\), "\n", 
        StyleBox[\( (*\ 
            define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", \(u[x_, y_]\  = \ 0;\), "\n", 
        RowBox[{
          StyleBox["(*",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
            StyleBox["define",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["the",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["inner",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["product",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["using",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["Boole",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["notation",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
              StyleBox["(",
                FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
                StyleBox["Mathematica",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox["4.1",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox["only",
                  FontColor->RGBColor[1, 0, 0]]}], 
              StyleBox[")",
                FontColor->RGBColor[1, 0, 0]]}]}], " ", 
          StyleBox["*)",
            FontColor->RGBColor[1, 0, 0]]}], 
        "\n", \(norm[f_, g_]\  := \ 
            Integrate[
                f\ g\ Boole[
                    z[1, x, y]\  \[LessEqual] \ \ 0\  && \ 
                      z[2, x, y] \[GreaterEqual] \ \ 0], {x, \(-Infinity\), 
                  Infinity}, {y, \(-Infinity\), Infinity}]\  // 
              N;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.18"],

Cell[BoxData[
    RowBox[{\(galerkin[Px_, Py_, M_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({v, Lmat, \[Rho]vec, eq, eqns, vars}\), ",", 
          "\[IndentingNewLine]", 
          StyleBox[\( (*\ define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
                y\^j\ \ \ \ Product[z[n, x, y], {n, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[f_]\  := \ 
              D[f, {x, 2}]\  + \ D[f, {y, 2}]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Lmat[i_, j_, k_, l_]\  := \ 
              norm[v[i, j, x, y], \ L[v[k, l, x, y]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ \[Rho]\&_\ onto\ the\ basis\ \
\(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]vec[i_, j_]\  := \ 
              norm[v[i, j, x, y], \ \[Rho][x, y] - L[u[x, y]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                define\ the\ equations\ for\ the\ Fourier\ coefficients\ c[m, 
                    n]\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eq[i_, j_]\  := \(eq[i, j]\  = \ 
                Sum[Lmat[i, j, k, l] c[k, l], {k, 0, Px}, {l, 0, 
                      Py}]\  \[Equal] \ \[Rho]vec[i, j]\)\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ equations\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq\>", {i, j}, "\< = \>", eq[i, j]], {i, 0, Px}, {j, 
                0, Py}]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ 
                create\ lists\ of\ equations\ and\ variables\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Flatten[Table[eq[i, j], {i, 0, Px}, {j, 0, Py}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Flatten[Table[c[k, l], {k, 0, Px}, {l, 0, Py}]]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ solve\ the\ equations\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(Solve[eqns, 
                  vars]\)[\([1]\)]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][x_, y_]\  = \ 
              u[x, y]\  + \ 
                  Sum[c[k, l]\ v[k, l, x, y], {k, 0, Px}, {l, 0, Py}] /. 
                coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.19"],

Cell[TextData[{
  "We will run the module taking ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 4\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(galerkin[4, 4, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.20"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.46064127662665527`\)\ c[0, 0] - 
            0.24861604593388045`\ c[0, 1] - 0.15698115485798506`\ c[0, 2] - 
            0.10948769802719581`\ c[0, 3] - 0.0818455017109958`\ c[0, 4] - 
            0.05003129625843903`\ c[1, 0] - 0.036376358896790424`\ c[1, 1] - 
            0.028569811921014602`\ c[1, 2] - 0.023644789389061865`\ c[1, 3] - 
            0.020328309499613624`\ c[1, 4] - 0.05383493048441987`\ c[2, 0] - 
            0.03514946373175552`\ c[2, 1] - 0.02542509951811765`\ c[2, 2] - 
            0.019753676994491532`\ c[2, 3] - 0.016180741359767898`\ c[2, 4] - 
            0.015880821839381908`\ c[3, 0] - 0.012563587654024454`\ c[3, 1] - 
            0.01048306087485224`\ c[3, 2] - 0.009093921920947861`\ c[3, 3] - 
            0.008127733109395886`\ c[3, 4] - 0.015976413964149252`\ c[4, 0] - 
            0.011760381891013425`\ c[4, 1] - 0.009301716115560361`\ c[4, 2] - 
            0.007756599928090679`\ c[4, 3] - 
            0.006735398953034707`\ c[4, 4] == \(-0.15611691801991245`\)\)\),
      SequenceForm[ "eq", {0, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.46064127662665527, 
              c[ 0, 0]], 
            Times[ -0.24861604593388045, 
              c[ 0, 1]], 
            Times[ -0.15698115485798506, 
              c[ 0, 2]], 
            Times[ -0.10948769802719581, 
              c[ 0, 3]], 
            Times[ -0.081845501710995805, 
              c[ 0, 4]], 
            Times[ -0.05003129625843903, 
              c[ 1, 0]], 
            Times[ -0.036376358896790424, 
              c[ 1, 1]], 
            Times[ -0.028569811921014602, 
              c[ 1, 2]], 
            Times[ -0.023644789389061865, 
              c[ 1, 3]], 
            Times[ -0.020328309499613624, 
              c[ 1, 4]], 
            Times[ -0.053834930484419868, 
              c[ 2, 0]], 
            Times[ -0.035149463731755523, 
              c[ 2, 1]], 
            Times[ -0.025425099518117649, 
              c[ 2, 2]], 
            Times[ -0.019753676994491532, 
              c[ 2, 3]], 
            Times[ -0.016180741359767898, 
              c[ 2, 4]], 
            Times[ -0.015880821839381908, 
              c[ 3, 0]], 
            Times[ -0.012563587654024454, 
              c[ 3, 1]], 
            Times[ -0.01048306087485224, 
              c[ 3, 2]], 
            Times[ -0.009093921920947861, 
              c[ 3, 3]], 
            Times[ -0.0081277331093958863, 
              c[ 3, 4]], 
            Times[ -0.015976413964149252, 
              c[ 4, 0]], 
            Times[ -0.011760381891013425, 
              c[ 4, 1]], 
            Times[ -0.0093017161155603614, 
              c[ 4, 2]], 
            Times[ -0.0077565999280906793, 
              c[ 4, 3]], 
            Times[ -0.0067353989530347068, 
              c[ 4, 4]]], -0.15611691801991245]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          1}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.24861604593388045`\)\ c[0, 0] - 
            0.1825638194777059`\ c[0, 1] - 0.1375848980582567`\ c[0, 2] - 
            0.10773337262158579`\ c[0, 3] - 0.0873648267401352`\ c[0, 4] - 
            0.036376358896790424`\ c[1, 0] - 0.03070170063932467`\ c[1, 1] - 
            0.02664674380223779`\ c[1, 2] - 0.02369658738379547`\ c[1, 3] - 
            0.021506894371527904`\ c[1, 4] - 0.03514946373175552`\ c[2, 0] - 
            0.027584320143072716`\ c[2, 1] - 0.0224807939019594`\ c[2, 2] - 
            0.01898587366661564`\ c[2, 3] - 0.016534433397738375`\ c[2, 4] - 
            0.012563587654024454`\ c[3, 0] - 0.010993256465558921`\ c[3, 1] - 
            0.009862441990431254`\ c[3, 2] - 0.009036608015159785`\ c[3, 3] - 
            0.00842887740212212`\ c[3, 4] - 0.011760381891013425`\ c[4, 0] - 
            0.009784579799622044`\ c[4, 1] - 0.008430303142237104`\ c[4, 2] - 
            0.00748618002259904`\ c[4, 3] - 
            0.006819507989826906`\ c[4, 4] == \(-0.0884180693106603`\)\)\),
      SequenceForm[ "eq", {0, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.24861604593388045, 
              c[ 0, 0]], 
            Times[ -0.18256381947770589, 
              c[ 0, 1]], 
            Times[ -0.13758489805825669, 
              c[ 0, 2]], 
            Times[ -0.10773337262158579, 
              c[ 0, 3]], 
            Times[ -0.087364826740135196, 
              c[ 0, 4]], 
            Times[ -0.036376358896790424, 
              c[ 1, 0]], 
            Times[ -0.030701700639324671, 
              c[ 1, 1]], 
            Times[ -0.026646743802237791, 
              c[ 1, 2]], 
            Times[ -0.023696587383795469, 
              c[ 1, 3]], 
            Times[ -0.021506894371527904, 
              c[ 1, 4]], 
            Times[ -0.035149463731755523, 
              c[ 2, 0]], 
            Times[ -0.027584320143072716, 
              c[ 2, 1]], 
            Times[ -0.022480793901959398, 
              c[ 2, 2]], 
            Times[ -0.018985873666615641, 
              c[ 2, 3]], 
            Times[ -0.016534433397738375, 
              c[ 2, 4]], 
            Times[ -0.012563587654024454, 
              c[ 3, 0]], 
            Times[ -0.010993256465558921, 
              c[ 3, 1]], 
            Times[ -0.0098624419904312539, 
              c[ 3, 2]], 
            Times[ -0.0090366080151597847, 
              c[ 3, 3]], 
            Times[ -0.0084288774021221199, 
              c[ 3, 4]], 
            Times[ -0.011760381891013425, 
              c[ 4, 0]], 
            Times[ -0.0097845797996220438, 
              c[ 4, 1]], 
            Times[ -0.0084303031422371041, 
              c[ 4, 2]], 
            Times[ -0.0074861800225990401, 
              c[ 4, 3]], 
            Times[ -0.006819507989826906, 
              c[ 4, 4]]], -0.088418069310660305]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.15698115485798506`\)\ c[0, 0] - 
            0.1375848980582567`\ c[0, 1] - 0.11636266292511578`\ c[0, 2] - 
            0.09884035203737365`\ c[0, 3] - 0.08515529520972057`\ c[0, 4] - 
            0.028569811921014602`\ c[1, 0] - 0.02664674380223779`\ c[1, 1] - 
            0.02481934667852275`\ c[1, 2] - 0.023263641237353888`\ c[1, 3] - 
            0.02199154114638158`\ c[1, 4] - 0.02542509951811765`\ c[2, 0] - 
            0.0224807939019594`\ c[2, 1] - 0.019920917768898223`\ c[2, 2] - 
            0.01789900835929596`\ c[2, 3] - 0.016347521425702227`\ c[2, 4] - 
            0.01048306087485224`\ c[3, 0] - 0.009862441990431254`\ c[3, 1] - 
            0.009339566317081084`\ c[3, 2] - 0.008923926125826348`\ c[3, 3] - 
            0.00860704236186341`\ c[3, 4] - 0.009301716115560361`\ c[4, 0] - 
            0.008430303142237104`\ c[4, 1] - 0.007736440379120484`\ c[4, 2] - 
            0.007210116265697266`\ c[4, 3] - 
            0.006822869599386631`\ c[4, 4] == \(-0.05766776727643512`\)\)\),
      SequenceForm[ "eq", {0, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.15698115485798506, 
              c[ 0, 0]], 
            Times[ -0.13758489805825669, 
              c[ 0, 1]], 
            Times[ -0.11636266292511578, 
              c[ 0, 2]], 
            Times[ -0.098840352037373652, 
              c[ 0, 3]], 
            Times[ -0.085155295209720566, 
              c[ 0, 4]], 
            Times[ -0.028569811921014602, 
              c[ 1, 0]], 
            Times[ -0.026646743802237791, 
              c[ 1, 1]], 
            Times[ -0.024819346678522751, 
              c[ 1, 2]], 
            Times[ -0.023263641237353888, 
              c[ 1, 3]], 
            Times[ -0.02199154114638158, 
              c[ 1, 4]], 
            Times[ -0.025425099518117649, 
              c[ 2, 0]], 
            Times[ -0.022480793901959398, 
              c[ 2, 1]], 
            Times[ -0.019920917768898223, 
              c[ 2, 2]], 
            Times[ -0.017899008359295959, 
              c[ 2, 3]], 
            Times[ -0.016347521425702227, 
              c[ 2, 4]], 
            Times[ -0.01048306087485224, 
              c[ 3, 0]], 
            Times[ -0.0098624419904312539, 
              c[ 3, 1]], 
            Times[ -0.0093395663170810841, 
              c[ 3, 2]], 
            Times[ -0.008923926125826348, 
              c[ 3, 3]], 
            Times[ -0.0086070423618634095, 
              c[ 3, 4]], 
            Times[ -0.0093017161155603614, 
              c[ 4, 0]], 
            Times[ -0.0084303031422371041, 
              c[ 4, 1]], 
            Times[ -0.0077364403791204839, 
              c[ 4, 2]], 
            Times[ -0.0072101162656972662, 
              c[ 4, 3]], 
            Times[ -0.0068228695993866311, 
              c[ 4, 4]]], -0.05766776727643512]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          3}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.10948769802719581`\)\ c[0, 0] - 
            0.10773337262158579`\ c[0, 1] - 0.09884035203737365`\ c[0, 2] - 
            0.08920441329321976`\ c[0, 3] - 0.08055548566910839`\ c[0, 4] - 
            0.023644789389061865`\ c[1, 0] - 0.02369658738379547`\ c[1, 1] - 
            0.023263641237353888`\ c[1, 2] - 0.022703059942531006`\ c[1, 3] - 
            0.022159557879049115`\ c[1, 4] - 0.019753676994491532`\ c[2, 0] - 
            0.01898587366661564`\ c[2, 1] - 0.01789900835929596`\ c[2, 2] - 
            0.016870230249380235`\ c[2, 3] - 0.01600477856717868`\ c[2, 4] - 
            0.009093921920947861`\ c[3, 0] - 0.009036608015159785`\ c[3, 1] - 
            0.008923926125826348`\ c[3, 2] - 0.008815172038822284`\ c[3, 3] - 
            0.008735578653956227`\ c[3, 4] - 0.007756599928090679`\ c[4, 0] - 
            0.00748618002259904`\ c[4, 1] - 0.007210116265697266`\ c[4, 2] - 
            0.006981427922155477`\ c[4, 3] - 
            0.006813932904362683`\ c[4, 4] == \(-0.04113339957503905`\)\)\),
      SequenceForm[ "eq", {0, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.10948769802719581, 
              c[ 0, 0]], 
            Times[ -0.10773337262158579, 
              c[ 0, 1]], 
            Times[ -0.098840352037373652, 
              c[ 0, 2]], 
            Times[ -0.089204413293219764, 
              c[ 0, 3]], 
            Times[ -0.08055548566910839, 
              c[ 0, 4]], 
            Times[ -0.023644789389061865, 
              c[ 1, 0]], 
            Times[ -0.023696587383795469, 
              c[ 1, 1]], 
            Times[ -0.023263641237353888, 
              c[ 1, 2]], 
            Times[ -0.022703059942531006, 
              c[ 1, 3]], 
            Times[ -0.022159557879049115, 
              c[ 1, 4]], 
            Times[ -0.019753676994491532, 
              c[ 2, 0]], 
            Times[ -0.018985873666615641, 
              c[ 2, 1]], 
            Times[ -0.017899008359295959, 
              c[ 2, 2]], 
            Times[ -0.016870230249380235, 
              c[ 2, 3]], 
            Times[ -0.01600477856717868, 
              c[ 2, 4]], 
            Times[ -0.009093921920947861, 
              c[ 3, 0]], 
            Times[ -0.0090366080151597847, 
              c[ 3, 1]], 
            Times[ -0.008923926125826348, 
              c[ 3, 2]], 
            Times[ -0.0088151720388222835, 
              c[ 3, 3]], 
            Times[ -0.0087355786539562268, 
              c[ 3, 4]], 
            Times[ -0.0077565999280906793, 
              c[ 4, 0]], 
            Times[ -0.0074861800225990401, 
              c[ 4, 1]], 
            Times[ -0.0072101162656972662, 
              c[ 4, 2]], 
            Times[ -0.0069814279221554771, 
              c[ 4, 3]], 
            Times[ -0.0068139329043626828, 
              c[ 4, 4]]], -0.041133399575039052]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.0818455017109958`\)\
\ c[0, 0] - 0.0873648267401352`\ c[0, 1] - 0.08515529520972057`\ c[0, 2] - 
            0.08055548566910839`\ c[0, 3] - 0.07554282471801659`\ c[0, 4] - 
            0.020328309499613624`\ c[1, 0] - 0.021506894371527904`\ c[1, 1] - 
            0.02199154114638158`\ c[1, 2] - 0.022159557879049115`\ c[1, 3] - 
            0.022197565878011704`\ c[1, 4] - 0.016180741359767898`\ c[2, 0] - 
            0.016534433397738375`\ c[2, 1] - 0.016347521425702227`\ c[2, 2] - 
            0.01600477856717868`\ c[2, 3] - 0.015662114696107947`\ c[2, 4] - 
            0.008127733109395886`\ c[3, 0] - 0.00842887740212212`\ c[3, 1] - 
            0.00860704236186341`\ c[3, 2] - 0.008735578653956227`\ c[3, 3] - 
            0.008853244905980365`\ c[3, 4] - 0.006735398953034707`\ c[4, 0] - 
            0.006819507989826906`\ c[4, 1] - 0.006822869599386631`\ c[4, 2] - 
            0.006813932904362683`\ c[4, 3] - 
            0.0068226126066063195`\ c[4, 4] == \(-0.03123761981881394`\)\)\),
      SequenceForm[ "eq", {0, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.081845501710995805, 
              c[ 0, 0]], 
            Times[ -0.087364826740135196, 
              c[ 0, 1]], 
            Times[ -0.085155295209720566, 
              c[ 0, 2]], 
            Times[ -0.08055548566910839, 
              c[ 0, 3]], 
            Times[ -0.075542824718016585, 
              c[ 0, 4]], 
            Times[ -0.020328309499613624, 
              c[ 1, 0]], 
            Times[ -0.021506894371527904, 
              c[ 1, 1]], 
            Times[ -0.02199154114638158, 
              c[ 1, 2]], 
            Times[ -0.022159557879049115, 
              c[ 1, 3]], 
            Times[ -0.022197565878011704, 
              c[ 1, 4]], 
            Times[ -0.016180741359767898, 
              c[ 2, 0]], 
            Times[ -0.016534433397738375, 
              c[ 2, 1]], 
            Times[ -0.016347521425702227, 
              c[ 2, 2]], 
            Times[ -0.01600477856717868, 
              c[ 2, 3]], 
            Times[ -0.015662114696107947, 
              c[ 2, 4]], 
            Times[ -0.0081277331093958863, 
              c[ 3, 0]], 
            Times[ -0.0084288774021221199, 
              c[ 3, 1]], 
            Times[ -0.0086070423618634095, 
              c[ 3, 2]], 
            Times[ -0.0087355786539562268, 
              c[ 3, 3]], 
            Times[ -0.0088532449059803651, 
              c[ 3, 4]], 
            Times[ -0.0067353989530347068, 
              c[ 4, 0]], 
            Times[ -0.006819507989826906, 
              c[ 4, 1]], 
            Times[ -0.0068228695993866311, 
              c[ 4, 2]], 
            Times[ -0.0068139329043626828, 
              c[ 4, 3]], 
            Times[ -0.0068226126066063195, 
              c[ 4, 4]]], -0.031237619818813941]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.05003129625843903`\)\ c[0, 0] - 
            0.036376358896790424`\ c[0, 1] - 0.028569811921014602`\ c[0, 2] - 
            0.023644789389061865`\ c[0, 3] - 0.020328309499613624`\ c[0, 4] - 
            0.07941759510414069`\ c[1, 0] - 0.04919806374728597`\ c[1, 1] - 
            0.03405438982164765`\ c[1, 2] - 0.02549143964311077`\ c[1, 3] - 
            0.020229859443267093`\ c[1, 4] - 0.02014459927600204`\ c[2, 0] - 
            0.01556554206720038`\ c[2, 1] - 0.012728579464306802`\ c[2, 2] - 
            0.010850668786773841`\ c[2, 3] - 0.009550770701694732`\ c[2, 4] - 
            0.022454075839014462`\ c[3, 0] - 0.015851057252215223`\ c[3, 1] - 
            0.012106848422408103`\ c[3, 2] - 0.009803462370427049`\ c[3, 3] - 
            0.008303525424068736`\ c[3, 4] - 0.00913459576150887`\ c[4, 0] - 
            0.007486207632183761`\ c[4, 1] - 0.006401313315192519`\ c[4, 2] - 
            0.0056558321916690855`\ c[4, 3] - 
            0.00512962422980158`\ c[4, 4] == \(-0.01300974316832604`\)\)\),
      SequenceForm[ "eq", {1, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.05003129625843903, 
              c[ 0, 0]], 
            Times[ -0.036376358896790424, 
              c[ 0, 1]], 
            Times[ -0.028569811921014602, 
              c[ 0, 2]], 
            Times[ -0.023644789389061865, 
              c[ 0, 3]], 
            Times[ -0.020328309499613624, 
              c[ 0, 4]], 
            Times[ -0.07941759510414069, 
              c[ 1, 0]], 
            Times[ -0.049198063747285969, 
              c[ 1, 1]], 
            Times[ -0.03405438982164765, 
              c[ 1, 2]], 
            Times[ -0.025491439643110771, 
              c[ 1, 3]], 
            Times[ -0.020229859443267093, 
              c[ 1, 4]], 
            Times[ -0.02014459927600204, 
              c[ 2, 0]], 
            Times[ -0.015565542067200381, 
              c[ 2, 1]], 
            Times[ -0.012728579464306802, 
              c[ 2, 2]], 
            Times[ -0.010850668786773841, 
              c[ 2, 3]], 
            Times[ -0.0095507707016947319, 
              c[ 2, 4]], 
            Times[ -0.022454075839014462, 
              c[ 3, 0]], 
            Times[ -0.015851057252215223, 
              c[ 3, 1]], 
            Times[ -0.012106848422408103, 
              c[ 3, 2]], 
            Times[ -0.009803462370427049, 
              c[ 3, 3]], 
            Times[ -0.0083035254240687358, 
              c[ 3, 4]], 
            Times[ -0.0091345957615088704, 
              c[ 4, 0]], 
            Times[ -0.007486207632183761, 
              c[ 4, 1]], 
            Times[ -0.0064013133151925193, 
              c[ 4, 2]], 
            Times[ -0.0056558321916690855, 
              c[ 4, 3]], 
            Times[ -0.0051296242298015798, 
              c[ 4, 4]]], -0.01300974316832604]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.036376358896790424`\
\)\ c[0, 0] - 0.03070170063932467`\ c[0, 1] - 0.02664674380223779`\ c[0, 2] - 
            0.02369658738379547`\ c[0, 3] - 0.021506894371527904`\ c[0, 4] - 
            0.04919806374728597`\ c[1, 0] - 0.03621361044660272`\ c[1, 1] - 
            0.028218556550578637`\ c[1, 2] - 0.023034991750114836`\ c[1, 3] - 
            0.019528306142544857`\ c[1, 4] - 0.01556554206720038`\ c[2, 0] - 
            0.013238775055013485`\ c[2, 1] - 0.011619188856257236`\ c[2, 2] - 
            0.01045964560745863`\ c[2, 3] - 0.009614290615458888`\ c[2, 4] - 
            0.015851057252215223`\ c[3, 0] - 0.012589712106469787`\ c[3, 1] - 
            0.010477165584573477`\ c[3, 2] - 0.009054306493633068`\ c[3, 3] - 
            0.008069049154051568`\ c[3, 4] - 0.007486207632183761`\ c[4, 0] - 
            0.0065791605132922825`\ c[4, 1] - 
            0.0059377391031358384`\ c[4, 2] - 
            0.0054771057786187054`\ c[4, 3] - 
            0.0051453642139178595`\ c[4, 4] == \(-0.010279303244109464`\)\)\),
      
      SequenceForm[ "eq", {1, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.036376358896790424, 
              c[ 0, 0]], 
            Times[ -0.030701700639324671, 
              c[ 0, 1]], 
            Times[ -0.026646743802237791, 
              c[ 0, 2]], 
            Times[ -0.023696587383795469, 
              c[ 0, 3]], 
            Times[ -0.021506894371527904, 
              c[ 0, 4]], 
            Times[ -0.049198063747285969, 
              c[ 1, 0]], 
            Times[ -0.03621361044660272, 
              c[ 1, 1]], 
            Times[ -0.028218556550578637, 
              c[ 1, 2]], 
            Times[ -0.023034991750114836, 
              c[ 1, 3]], 
            Times[ -0.019528306142544857, 
              c[ 1, 4]], 
            Times[ -0.015565542067200381, 
              c[ 2, 0]], 
            Times[ -0.013238775055013485, 
              c[ 2, 1]], 
            Times[ -0.011619188856257236, 
              c[ 2, 2]], 
            Times[ -0.01045964560745863, 
              c[ 2, 3]], 
            Times[ -0.009614290615458888, 
              c[ 2, 4]], 
            Times[ -0.015851057252215223, 
              c[ 3, 0]], 
            Times[ -0.012589712106469787, 
              c[ 3, 1]], 
            Times[ -0.010477165584573477, 
              c[ 3, 2]], 
            Times[ -0.0090543064936330683, 
              c[ 3, 3]], 
            Times[ -0.0080690491540515684, 
              c[ 3, 4]], 
            Times[ -0.007486207632183761, 
              c[ 4, 0]], 
            Times[ -0.0065791605132922825, 
              c[ 4, 1]], 
            Times[ -0.0059377391031358384, 
              c[ 4, 2]], 
            Times[ -0.0054771057786187054, 
              c[ 4, 3]], 
            Times[ -0.0051453642139178595, 
              c[ 4, 4]]], -0.010279303244109464]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.028569811921014602`\
\)\ c[0, 0] - 0.02664674380223779`\ c[0, 1] - 0.02481934667852275`\ c[0, 2] - 
            0.023263641237353888`\ c[0, 3] - 0.02199154114638158`\ c[0, 4] - 
            0.03405438982164765`\ c[1, 0] - 0.028218556550578637`\ c[1, 1] - 
            0.023970035852397417`\ c[1, 2] - 0.02089288110410244`\ c[1, 3] - 
            0.018646283397467652`\ c[1, 4] - 0.012728579464306802`\ c[2, 0] - 
            0.011619188856257236`\ c[2, 1] - 0.01076260390937993`\ c[2, 2] - 
            0.010109339339163116`\ c[2, 3] - 0.009617585440610052`\ c[2, 4] - 
            0.012106848422408103`\ c[3, 0] - 0.010477165584573477`\ c[3, 1] - 
            0.009304566850154513`\ c[3, 2] - 0.008459657429921929`\ c[3, 3] - 
            0.007851377836638139`\ c[3, 4] - 0.006401313315192519`\ c[4, 0] - 
            0.0059377391031358384`\ c[4, 1] - 
            0.005592932961557747`\ c[4, 2] - 0.005341366861189084`\ c[4, 3] - 
            0.005164329576180986`\ c[4, 4] == \(-0.00857688490232269`\)\)\),
      SequenceForm[ "eq", {1, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.028569811921014602, 
              c[ 0, 0]], 
            Times[ -0.026646743802237791, 
              c[ 0, 1]], 
            Times[ -0.024819346678522751, 
              c[ 0, 2]], 
            Times[ -0.023263641237353888, 
              c[ 0, 3]], 
            Times[ -0.02199154114638158, 
              c[ 0, 4]], 
            Times[ -0.03405438982164765, 
              c[ 1, 0]], 
            Times[ -0.028218556550578637, 
              c[ 1, 1]], 
            Times[ -0.023970035852397417, 
              c[ 1, 2]], 
            Times[ -0.020892881104102441, 
              c[ 1, 3]], 
            Times[ -0.018646283397467652, 
              c[ 1, 4]], 
            Times[ -0.012728579464306802, 
              c[ 2, 0]], 
            Times[ -0.011619188856257236, 
              c[ 2, 1]], 
            Times[ -0.01076260390937993, 
              c[ 2, 2]], 
            Times[ -0.010109339339163116, 
              c[ 2, 3]], 
            Times[ -0.0096175854406100516, 
              c[ 2, 4]], 
            Times[ -0.012106848422408103, 
              c[ 3, 0]], 
            Times[ -0.010477165584573477, 
              c[ 3, 1]], 
            Times[ -0.009304566850154513, 
              c[ 3, 2]], 
            Times[ -0.0084596574299219286, 
              c[ 3, 3]], 
            Times[ -0.0078513778366381386, 
              c[ 3, 4]], 
            Times[ -0.0064013133151925193, 
              c[ 4, 0]], 
            Times[ -0.0059377391031358384, 
              c[ 4, 1]], 
            Times[ -0.0055929329615577467, 
              c[ 4, 2]], 
            Times[ -0.0053413668611890838, 
              c[ 4, 3]], 
            Times[ -0.0051643295761809862, 
              c[ 4, 4]]], -0.0085768849023226904]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.023644789389061865`\
\)\ c[0, 0] - 0.02369658738379547`\ c[0, 1] - 
            0.023263641237353888`\ c[0, 2] - 0.022703059942531006`\ c[0, 3] - 
            0.022159557879049115`\ c[0, 4] - 0.02549143964311077`\ c[1, 0] - 
            0.023034991750114836`\ c[1, 1] - 0.02089288110410244`\ c[1, 2] - 
            0.019168992221145664`\ c[1, 3] - 0.017825944158161824`\ c[1, 4] - 
            0.010850668786773841`\ c[2, 0] - 0.01045964560745863`\ c[2, 1] - 
            0.010109339339163116`\ c[2, 2] - 0.009825715117568924`\ c[2, 3] - 
            0.009614012173747594`\ c[2, 4] - 0.009803462370427049`\ c[3, 0] - 
            0.009054306493633068`\ c[3, 1] - 0.008459657429921929`\ c[3, 2] - 
            0.008009936159406981`\ c[3, 3] - 0.00768386840556921`\ c[3, 4] - 
            0.0056558321916690855`\ c[4, 0] - 
            0.0054771057786187054`\ c[4, 1] - 
            0.005341366861189084`\ c[4, 2] - 0.005249281482429118`\ c[4, 3] - 
            0.005198701693497111`\ c[4, 4] == \(-0.007429339364667458`\)\)\),
      SequenceForm[ "eq", {1, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.023644789389061865, 
              c[ 0, 0]], 
            Times[ -0.023696587383795469, 
              c[ 0, 1]], 
            Times[ -0.023263641237353888, 
              c[ 0, 2]], 
            Times[ -0.022703059942531006, 
              c[ 0, 3]], 
            Times[ -0.022159557879049115, 
              c[ 0, 4]], 
            Times[ -0.025491439643110771, 
              c[ 1, 0]], 
            Times[ -0.023034991750114836, 
              c[ 1, 1]], 
            Times[ -0.020892881104102441, 
              c[ 1, 2]], 
            Times[ -0.019168992221145664, 
              c[ 1, 3]], 
            Times[ -0.017825944158161824, 
              c[ 1, 4]], 
            Times[ -0.010850668786773841, 
              c[ 2, 0]], 
            Times[ -0.01045964560745863, 
              c[ 2, 1]], 
            Times[ -0.010109339339163116, 
              c[ 2, 2]], 
            Times[ -0.0098257151175689238, 
              c[ 2, 3]], 
            Times[ -0.0096140121737475943, 
              c[ 2, 4]], 
            Times[ -0.009803462370427049, 
              c[ 3, 0]], 
            Times[ -0.0090543064936330683, 
              c[ 3, 1]], 
            Times[ -0.0084596574299219286, 
              c[ 3, 2]], 
            Times[ -0.0080099361594069812, 
              c[ 3, 3]], 
            Times[ -0.0076838684055692101, 
              c[ 3, 4]], 
            Times[ -0.0056558321916690855, 
              c[ 4, 0]], 
            Times[ -0.0054771057786187054, 
              c[ 4, 1]], 
            Times[ -0.0053413668611890838, 
              c[ 4, 2]], 
            Times[ -0.0052492814824291181, 
              c[ 4, 3]], 
            Times[ -0.0051987016934971113, 
              c[ 4, 4]]], -0.0074293393646674578]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.020328309499613624`\
\)\ c[0, 0] - 0.021506894371527904`\ c[0, 1] - 
            0.02199154114638158`\ c[0, 2] - 0.022159557879049115`\ c[0, 3] - 
            0.022197565878011704`\ c[0, 4] - 0.020229859443267093`\ c[1, 0] - 
            0.019528306142544857`\ c[1, 1] - 0.018646283397467652`\ c[1, 2] - 
            0.017825944158161824`\ c[1, 3] - 0.01714364597204234`\ c[1, 4] - 
            0.009550770701694732`\ c[2, 0] - 0.009614290615458888`\ c[2, 1] - 
            0.009617585440610052`\ c[2, 2] - 0.009614012173747594`\ c[2, 3] - 
            0.009629745796650418`\ c[2, 4] - 0.008303525424068736`\ c[3, 0] - 
            0.008069049154051568`\ c[3, 1] - 0.007851377836638139`\ c[3, 2] - 
            0.00768386840556921`\ c[3, 3] - 0.0075756649296774455`\ c[3, 4] - 
            0.00512962422980158`\ c[4, 0] - 0.0051453642139178595`\ c[4, 1] - 
            0.005164329576180986`\ c[4, 2] - 0.005198701693497111`\ c[4, 3] - 
            0.005254644949840944`\ c[4, 4] == \(-0.006616124724728609`\)\)\),
      SequenceForm[ "eq", {1, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.020328309499613624, 
              c[ 0, 0]], 
            Times[ -0.021506894371527904, 
              c[ 0, 1]], 
            Times[ -0.02199154114638158, 
              c[ 0, 2]], 
            Times[ -0.022159557879049115, 
              c[ 0, 3]], 
            Times[ -0.022197565878011704, 
              c[ 0, 4]], 
            Times[ -0.020229859443267093, 
              c[ 1, 0]], 
            Times[ -0.019528306142544857, 
              c[ 1, 1]], 
            Times[ -0.018646283397467652, 
              c[ 1, 2]], 
            Times[ -0.017825944158161824, 
              c[ 1, 3]], 
            Times[ -0.017143645972042341, 
              c[ 1, 4]], 
            Times[ -0.0095507707016947319, 
              c[ 2, 0]], 
            Times[ -0.009614290615458888, 
              c[ 2, 1]], 
            Times[ -0.0096175854406100516, 
              c[ 2, 2]], 
            Times[ -0.0096140121737475943, 
              c[ 2, 3]], 
            Times[ -0.0096297457966504178, 
              c[ 2, 4]], 
            Times[ -0.0083035254240687358, 
              c[ 3, 0]], 
            Times[ -0.0080690491540515684, 
              c[ 3, 1]], 
            Times[ -0.0078513778366381386, 
              c[ 3, 2]], 
            Times[ -0.0076838684055692101, 
              c[ 3, 3]], 
            Times[ -0.0075756649296774455, 
              c[ 3, 4]], 
            Times[ -0.0051296242298015798, 
              c[ 4, 0]], 
            Times[ -0.0051453642139178595, 
              c[ 4, 1]], 
            Times[ -0.0051643295761809862, 
              c[ 4, 2]], 
            Times[ -0.0051987016934971113, 
              c[ 4, 3]], 
            Times[ -0.0052546449498409439, 
              c[ 4, 4]]], -0.0066161247247286089]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          0}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.05383493048441987`\)\ c[0, 0] - 
            0.03514946373175552`\ c[0, 1] - 0.02542509951811765`\ c[0, 2] - 
            0.019753676994491532`\ c[0, 3] - 0.016180741359767898`\ c[0, 4] - 
            0.02014459927600204`\ c[1, 0] - 0.01556554206720038`\ c[1, 1] - 
            0.012728579464306802`\ c[1, 2] - 0.010850668786773841`\ c[1, 3] - 
            0.009550770701694732`\ c[1, 4] - 0.02461329646396953`\ c[2, 0] - 
            0.017214615705949156`\ c[2, 1] - 0.013041892524690684`\ c[2, 2] - 
            0.010485749851205841`\ c[2, 3] - 0.008826234247746746`\ c[2, 4] - 
            0.010154986942922238`\ c[3, 0] - 0.008254727701667155`\ c[3, 1] - 
            0.007007229919035119`\ c[3, 2] - 0.006150880915373312`\ c[3, 3] - 
            0.005545883583719328`\ c[3, 4] - 0.010707820741319048`\ c[4, 0] - 
            0.008165387528130017`\ c[4, 1] - 0.006611074427079434`\ c[4, 2] - 
            0.0056049222622869006`\ c[4, 3] - 
            0.00492782211471897`\ c[4, 4] == \(-0.018550930073353795`\)\)\),
      SequenceForm[ "eq", {2, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.053834930484419868, 
              c[ 0, 0]], 
            Times[ -0.035149463731755523, 
              c[ 0, 1]], 
            Times[ -0.025425099518117649, 
              c[ 0, 2]], 
            Times[ -0.019753676994491532, 
              c[ 0, 3]], 
            Times[ -0.016180741359767898, 
              c[ 0, 4]], 
            Times[ -0.02014459927600204, 
              c[ 1, 0]], 
            Times[ -0.015565542067200381, 
              c[ 1, 1]], 
            Times[ -0.012728579464306802, 
              c[ 1, 2]], 
            Times[ -0.010850668786773841, 
              c[ 1, 3]], 
            Times[ -0.0095507707016947319, 
              c[ 1, 4]], 
            Times[ -0.024613296463969529, 
              c[ 2, 0]], 
            Times[ -0.017214615705949156, 
              c[ 2, 1]], 
            Times[ -0.013041892524690684, 
              c[ 2, 2]], 
            Times[ -0.010485749851205841, 
              c[ 2, 3]], 
            Times[ -0.0088262342477467455, 
              c[ 2, 4]], 
            Times[ -0.010154986942922238, 
              c[ 3, 0]], 
            Times[ -0.0082547277016671548, 
              c[ 3, 1]], 
            Times[ -0.0070072299190351191, 
              c[ 3, 2]], 
            Times[ -0.0061508809153733119, 
              c[ 3, 3]], 
            Times[ -0.0055458835837193278, 
              c[ 3, 4]], 
            Times[ -0.010707820741319048, 
              c[ 4, 0]], 
            Times[ -0.0081653875281300168, 
              c[ 4, 1]], 
            Times[ -0.0066110744270794341, 
              c[ 4, 2]], 
            Times[ -0.0056049222622869006, 
              c[ 4, 3]], 
            Times[ -0.0049278221147189697, 
              c[ 4, 4]]], -0.018550930073353795]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          1}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.03514946373175552`\)\ c[0, 0] - 
            0.027584320143072716`\ c[0, 1] - 0.0224807939019594`\ c[0, 2] - 
            0.01898587366661564`\ c[0, 3] - 0.016534433397738375`\ c[0, 4] - 
            0.01556554206720038`\ c[1, 0] - 0.013238775055013485`\ c[1, 1] - 
            0.011619188856257236`\ c[1, 2] - 0.01045964560745863`\ c[1, 3] - 
            0.009614290615458888`\ c[1, 4] - 0.017214615705949156`\ c[2, 0] - 
            0.013524756208752368`\ c[2, 1] - 0.011159453065352268`\ c[2, 2] - 
            0.009577015317311078`\ c[2, 3] - 0.008485562875459788`\ c[2, 4] - 
            0.008254727701667155`\ c[3, 0] - 
            0.0071850771171348814`\ c[3, 1] - 
            0.006432787826840065`\ c[3, 2] - 0.005893365132536453`\ c[3, 3] - 
            0.005503804906830416`\ c[3, 4] - 0.008165387528130017`\ c[4, 0] - 
            0.006772272757480883`\ c[4, 1] - 0.005847177753002358`\ c[4, 2] - 
            0.0052146797712062645`\ c[4, 3] - 
            0.004775382682019783`\ c[4, 4] == \(-0.01241291572499795`\)\)\),
      SequenceForm[ "eq", {2, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.035149463731755523, 
              c[ 0, 0]], 
            Times[ -0.027584320143072716, 
              c[ 0, 1]], 
            Times[ -0.022480793901959398, 
              c[ 0, 2]], 
            Times[ -0.018985873666615641, 
              c[ 0, 3]], 
            Times[ -0.016534433397738375, 
              c[ 0, 4]], 
            Times[ -0.015565542067200381, 
              c[ 1, 0]], 
            Times[ -0.013238775055013485, 
              c[ 1, 1]], 
            Times[ -0.011619188856257236, 
              c[ 1, 2]], 
            Times[ -0.01045964560745863, 
              c[ 1, 3]], 
            Times[ -0.009614290615458888, 
              c[ 1, 4]], 
            Times[ -0.017214615705949156, 
              c[ 2, 0]], 
            Times[ -0.013524756208752368, 
              c[ 2, 1]], 
            Times[ -0.011159453065352268, 
              c[ 2, 2]], 
            Times[ -0.0095770153173110779, 
              c[ 2, 3]], 
            Times[ -0.0084855628754597883, 
              c[ 2, 4]], 
            Times[ -0.0082547277016671548, 
              c[ 3, 0]], 
            Times[ -0.0071850771171348814, 
              c[ 3, 1]], 
            Times[ -0.0064327878268400649, 
              c[ 3, 2]], 
            Times[ -0.0058933651325364534, 
              c[ 3, 3]], 
            Times[ -0.0055038049068304156, 
              c[ 3, 4]], 
            Times[ -0.0081653875281300168, 
              c[ 4, 0]], 
            Times[ -0.0067722727574808829, 
              c[ 4, 1]], 
            Times[ -0.0058471777530023578, 
              c[ 4, 2]], 
            Times[ -0.0052146797712062645, 
              c[ 4, 3]], 
            Times[ -0.0047753826820197834, 
              c[ 4, 4]]], -0.012412915724997951]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.02542509951811765`\)\ c[0, 0] - 
            0.0224807939019594`\ c[0, 1] - 0.019920917768898223`\ c[0, 2] - 
            0.01789900835929596`\ c[0, 3] - 0.016347521425702227`\ c[0, 4] - 
            0.012728579464306802`\ c[1, 0] - 0.011619188856257236`\ c[1, 1] - 
            0.01076260390937993`\ c[1, 2] - 0.010109339339163116`\ c[1, 3] - 
            0.009617585440610052`\ c[1, 4] - 0.013041892524690684`\ c[2, 0] - 
            0.011159453065352268`\ c[2, 1] - 0.009827275673832521`\ c[2, 2] - 
            0.008876171151330148`\ c[2, 3] - 0.008194213915721973`\ c[2, 4] - 
            0.007007229919035119`\ c[3, 0] - 0.006432787826840065`\ c[3, 1] - 
            0.006009192315475497`\ c[3, 2] - 0.005699807554101641`\ c[3, 3] - 
            0.005479260501230088`\ c[3, 4] - 0.006611074427079434`\ c[4, 0] - 
            0.005847177753002358`\ c[4, 1] - 0.005310298990035364`\ c[4, 2] - 
            0.0049324237817421415`\ c[4, 3] - 
            0.0046697952900079265`\ c[4, 4] == \(-0.009120951041058754`\)\)\),
      
      SequenceForm[ "eq", {2, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.025425099518117649, 
              c[ 0, 0]], 
            Times[ -0.022480793901959398, 
              c[ 0, 1]], 
            Times[ -0.019920917768898223, 
              c[ 0, 2]], 
            Times[ -0.017899008359295959, 
              c[ 0, 3]], 
            Times[ -0.016347521425702227, 
              c[ 0, 4]], 
            Times[ -0.012728579464306802, 
              c[ 1, 0]], 
            Times[ -0.011619188856257236, 
              c[ 1, 1]], 
            Times[ -0.01076260390937993, 
              c[ 1, 2]], 
            Times[ -0.010109339339163116, 
              c[ 1, 3]], 
            Times[ -0.0096175854406100516, 
              c[ 1, 4]], 
            Times[ -0.013041892524690684, 
              c[ 2, 0]], 
            Times[ -0.011159453065352268, 
              c[ 2, 1]], 
            Times[ -0.0098272756738325209, 
              c[ 2, 2]], 
            Times[ -0.0088761711513301485, 
              c[ 2, 3]], 
            Times[ -0.0081942139157219727, 
              c[ 2, 4]], 
            Times[ -0.0070072299190351191, 
              c[ 3, 0]], 
            Times[ -0.0064327878268400649, 
              c[ 3, 1]], 
            Times[ -0.0060091923154754973, 
              c[ 3, 2]], 
            Times[ -0.0056998075541016407, 
              c[ 3, 3]], 
            Times[ -0.0054792605012300884, 
              c[ 3, 4]], 
            Times[ -0.0066110744270794341, 
              c[ 4, 0]], 
            Times[ -0.0058471777530023578, 
              c[ 4, 1]], 
            Times[ -0.0053102989900353642, 
              c[ 4, 2]], 
            Times[ -0.0049324237817421415, 
              c[ 4, 3]], 
            Times[ -0.0046697952900079265, 
              c[ 4, 4]]], -0.009120951041058754]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.019753676994491532`\
\)\ c[0, 0] - 0.01898587366661564`\ c[0, 1] - 0.01789900835929596`\ c[0, 2] - 
            0.016870230249380235`\ c[0, 3] - 0.01600477856717868`\ c[0, 4] - 
            0.010850668786773841`\ c[1, 0] - 0.01045964560745863`\ c[1, 1] - 
            0.010109339339163116`\ c[1, 2] - 0.009825715117568924`\ c[1, 3] - 
            0.009614012173747594`\ c[1, 4] - 0.010485749851205841`\ c[2, 0] - 
            0.009577015317311078`\ c[2, 1] - 0.008876171151330148`\ c[2, 2] - 
            0.008352772238490817`\ c[2, 3] - 0.007973846905971384`\ c[2, 4] - 
            0.006150880915373312`\ c[3, 0] - 0.005893365132536453`\ c[3, 1] - 
            0.005699807554101641`\ c[3, 2] - 0.005564212407478219`\ c[3, 3] - 
            0.005480240284468271`\ c[3, 4] - 
            0.0056049222622869006`\ c[4, 0] - 
            0.0052146797712062645`\ c[4, 1] - 
            0.0049324237817421415`\ c[4, 2] - 
            0.004736386012973122`\ c[4, 3] - 
            0.004609784506921807`\ c[4, 4] == \(-0.00715968137984925`\)\)\),
      SequenceForm[ "eq", {2, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.019753676994491532, 
              c[ 0, 0]], 
            Times[ -0.018985873666615641, 
              c[ 0, 1]], 
            Times[ -0.017899008359295959, 
              c[ 0, 2]], 
            Times[ -0.016870230249380235, 
              c[ 0, 3]], 
            Times[ -0.01600477856717868, 
              c[ 0, 4]], 
            Times[ -0.010850668786773841, 
              c[ 1, 0]], 
            Times[ -0.01045964560745863, 
              c[ 1, 1]], 
            Times[ -0.010109339339163116, 
              c[ 1, 2]], 
            Times[ -0.0098257151175689238, 
              c[ 1, 3]], 
            Times[ -0.0096140121737475943, 
              c[ 1, 4]], 
            Times[ -0.010485749851205841, 
              c[ 2, 0]], 
            Times[ -0.0095770153173110779, 
              c[ 2, 1]], 
            Times[ -0.0088761711513301485, 
              c[ 2, 2]], 
            Times[ -0.008352772238490817, 
              c[ 2, 3]], 
            Times[ -0.0079738469059713844, 
              c[ 2, 4]], 
            Times[ -0.0061508809153733119, 
              c[ 3, 0]], 
            Times[ -0.0058933651325364534, 
              c[ 3, 1]], 
            Times[ -0.0056998075541016407, 
              c[ 3, 2]], 
            Times[ -0.0055642124074782194, 
              c[ 3, 3]], 
            Times[ -0.0054802402844682709, 
              c[ 3, 4]], 
            Times[ -0.0056049222622869006, 
              c[ 4, 0]], 
            Times[ -0.0052146797712062645, 
              c[ 4, 1]], 
            Times[ -0.0049324237817421415, 
              c[ 4, 2]], 
            Times[ -0.0047363860129731221, 
              c[ 4, 3]], 
            Times[ -0.0046097845069218071, 
              c[ 4, 4]]], -0.0071596813798492503]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.016180741359767898`\
\)\ c[0, 0] - 0.016534433397738375`\ c[0, 1] - 
            0.016347521425702227`\ c[0, 2] - 0.01600477856717868`\ c[0, 3] - 
            0.015662114696107947`\ c[0, 4] - 0.009550770701694732`\ c[1, 0] - 
            0.009614290615458888`\ c[1, 1] - 0.009617585440610052`\ c[1, 2] - 
            0.009614012173747594`\ c[1, 3] - 0.009629745796650418`\ c[1, 4] - 
            0.008826234247746746`\ c[2, 0] - 0.008485562875459788`\ c[2, 1] - 
            0.008194213915721973`\ c[2, 2] - 0.007973846905971384`\ c[2, 3] - 
            0.007826682370701155`\ c[2, 4] - 0.005545883583719328`\ c[3, 0] - 
            0.005503804906830416`\ c[3, 1] - 0.005479260501230088`\ c[3, 2] - 
            0.005480240284468271`\ c[3, 3] - 0.005510165689203531`\ c[3, 4] - 
            0.00492782211471897`\ c[4, 0] - 0.004775382682019783`\ c[4, 1] - 
            0.0046697952900079265`\ c[4, 2] - 
            0.004609784506921807`\ c[4, 3] - 
            0.004591992972866244`\ c[4, 4] == \(-0.0059052697188147155`\)\)\),
      
      SequenceForm[ "eq", {2, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.016180741359767898, 
              c[ 0, 0]], 
            Times[ -0.016534433397738375, 
              c[ 0, 1]], 
            Times[ -0.016347521425702227, 
              c[ 0, 2]], 
            Times[ -0.01600477856717868, 
              c[ 0, 3]], 
            Times[ -0.015662114696107947, 
              c[ 0, 4]], 
            Times[ -0.0095507707016947319, 
              c[ 1, 0]], 
            Times[ -0.009614290615458888, 
              c[ 1, 1]], 
            Times[ -0.0096175854406100516, 
              c[ 1, 2]], 
            Times[ -0.0096140121737475943, 
              c[ 1, 3]], 
            Times[ -0.0096297457966504178, 
              c[ 1, 4]], 
            Times[ -0.0088262342477467455, 
              c[ 2, 0]], 
            Times[ -0.0084855628754597883, 
              c[ 2, 1]], 
            Times[ -0.0081942139157219727, 
              c[ 2, 2]], 
            Times[ -0.0079738469059713844, 
              c[ 2, 3]], 
            Times[ -0.0078266823707011553, 
              c[ 2, 4]], 
            Times[ -0.0055458835837193278, 
              c[ 3, 0]], 
            Times[ -0.0055038049068304156, 
              c[ 3, 1]], 
            Times[ -0.0054792605012300884, 
              c[ 3, 2]], 
            Times[ -0.0054802402844682709, 
              c[ 3, 3]], 
            Times[ -0.0055101656892035311, 
              c[ 3, 4]], 
            Times[ -0.0049278221147189697, 
              c[ 4, 0]], 
            Times[ -0.0047753826820197834, 
              c[ 4, 1]], 
            Times[ -0.0046697952900079265, 
              c[ 4, 2]], 
            Times[ -0.0046097845069218071, 
              c[ 4, 3]], 
            Times[ -0.0045919929728662438, 
              c[ 4, 4]]], -0.0059052697188147155]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.015880821839381908`\
\)\ c[0, 0] - 0.012563587654024454`\ c[0, 1] - 
            0.01048306087485224`\ c[0, 2] - 0.009093921920947861`\ c[0, 3] - 
            0.008127733109395886`\ c[0, 4] - 0.022454075839014462`\ c[1, 0] - 
            0.015851057252215223`\ c[1, 1] - 0.012106848422408103`\ c[1, 2] - 
            0.009803462370427049`\ c[1, 3] - 0.008303525424068736`\ c[1, 4] - 
            0.010154986942922238`\ c[2, 0] - 0.008254727701667155`\ c[2, 1] - 
            0.007007229919035119`\ c[2, 2] - 0.006150880915373312`\ c[2, 3] - 
            0.005545883583719328`\ c[2, 4] - 0.01119068442538073`\ c[3, 0] - 
            0.008502239135203229`\ c[3, 1] - 0.006861334783600878`\ c[3, 2] - 
            0.0058002264002220815`\ c[3, 3] - 
            0.005086380437487815`\ c[3, 4] - 0.005975716618244462`\ c[4, 0] - 
            0.005055085095407302`\ c[4, 1] - 0.00442629029432368`\ c[4, 2] - 
            0.003984357358829202`\ c[4, 3] - 
            0.0036690876737841076`\ c[4, 4] == \(-0.004457041641000588`\)\)\),
      
      SequenceForm[ "eq", {3, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.015880821839381908, 
              c[ 0, 0]], 
            Times[ -0.012563587654024454, 
              c[ 0, 1]], 
            Times[ -0.01048306087485224, 
              c[ 0, 2]], 
            Times[ -0.009093921920947861, 
              c[ 0, 3]], 
            Times[ -0.0081277331093958863, 
              c[ 0, 4]], 
            Times[ -0.022454075839014462, 
              c[ 1, 0]], 
            Times[ -0.015851057252215223, 
              c[ 1, 1]], 
            Times[ -0.012106848422408103, 
              c[ 1, 2]], 
            Times[ -0.009803462370427049, 
              c[ 1, 3]], 
            Times[ -0.0083035254240687358, 
              c[ 1, 4]], 
            Times[ -0.010154986942922238, 
              c[ 2, 0]], 
            Times[ -0.0082547277016671548, 
              c[ 2, 1]], 
            Times[ -0.0070072299190351191, 
              c[ 2, 2]], 
            Times[ -0.0061508809153733119, 
              c[ 2, 3]], 
            Times[ -0.0055458835837193278, 
              c[ 2, 4]], 
            Times[ -0.01119068442538073, 
              c[ 3, 0]], 
            Times[ -0.0085022391352032288, 
              c[ 3, 1]], 
            Times[ -0.0068613347836008779, 
              c[ 3, 2]], 
            Times[ -0.0058002264002220815, 
              c[ 3, 3]], 
            Times[ -0.0050863804374878148, 
              c[ 3, 4]], 
            Times[ -0.0059757166182444624, 
              c[ 4, 0]], 
            Times[ -0.0050550850954073018, 
              c[ 4, 1]], 
            Times[ -0.0044262902943236803, 
              c[ 4, 2]], 
            Times[ -0.0039843573588292016, 
              c[ 4, 3]], 
            Times[ -0.0036690876737841076, 
              c[ 4, 4]]], -0.0044570416410005878]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.012563587654024454`\
\)\ c[0, 0] - 0.010993256465558921`\ c[0, 1] - 
            0.009862441990431254`\ c[0, 2] - 0.009036608015159785`\ c[0, 3] - 
            0.00842887740212212`\ c[0, 4] - 0.015851057252215223`\ c[1, 0] - 
            0.012589712106469787`\ c[1, 1] - 0.010477165584573477`\ c[1, 2] - 
            0.009054306493633068`\ c[1, 3] - 0.008069049154051568`\ c[1, 4] - 
            0.008254727701667155`\ c[2, 0] - 
            0.0071850771171348814`\ c[2, 1] - 
            0.006432787826840065`\ c[2, 2] - 0.005893365132536453`\ c[2, 3] - 
            0.005503804906830416`\ c[2, 4] - 0.008502239135203229`\ c[3, 0] - 
            0.007022533114002327`\ c[3, 1] - 0.006042481890937538`\ c[3, 2] - 
            0.005373238093975111`\ c[3, 3] - 0.004908346620240498`\ c[3, 4] - 
            0.005055085095407302`\ c[4, 0] - 0.004503483619290428`\ c[4, 1] - 
            0.004111748968859301`\ c[4, 2] - 0.003831489007825308`\ c[4, 3] - 
            0.0036325391913967736`\ c[4, 4] == \(-0.003739702913881226`\)\)\),
      
      SequenceForm[ "eq", {3, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.012563587654024454, 
              c[ 0, 0]], 
            Times[ -0.010993256465558921, 
              c[ 0, 1]], 
            Times[ -0.0098624419904312539, 
              c[ 0, 2]], 
            Times[ -0.0090366080151597847, 
              c[ 0, 3]], 
            Times[ -0.0084288774021221199, 
              c[ 0, 4]], 
            Times[ -0.015851057252215223, 
              c[ 1, 0]], 
            Times[ -0.012589712106469787, 
              c[ 1, 1]], 
            Times[ -0.010477165584573477, 
              c[ 1, 2]], 
            Times[ -0.0090543064936330683, 
              c[ 1, 3]], 
            Times[ -0.0080690491540515684, 
              c[ 1, 4]], 
            Times[ -0.0082547277016671548, 
              c[ 2, 0]], 
            Times[ -0.0071850771171348814, 
              c[ 2, 1]], 
            Times[ -0.0064327878268400649, 
              c[ 2, 2]], 
            Times[ -0.0058933651325364534, 
              c[ 2, 3]], 
            Times[ -0.0055038049068304156, 
              c[ 2, 4]], 
            Times[ -0.0085022391352032288, 
              c[ 3, 0]], 
            Times[ -0.0070225331140023267, 
              c[ 3, 1]], 
            Times[ -0.0060424818909375379, 
              c[ 3, 2]], 
            Times[ -0.0053732380939751113, 
              c[ 3, 3]], 
            Times[ -0.0049083466202404979, 
              c[ 3, 4]], 
            Times[ -0.0050550850954073018, 
              c[ 4, 0]], 
            Times[ -0.0045034836192904279, 
              c[ 4, 1]], 
            Times[ -0.0041117489688593011, 
              c[ 4, 2]], 
            Times[ -0.0038314890078253081, 
              c[ 4, 3]], 
            Times[ -0.0036325391913967736, 
              c[ 4, 4]]], -0.003739702913881226]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.01048306087485224`\)\ c[0, 0] - 
            0.009862441990431254`\ c[0, 1] - 0.009339566317081084`\ c[0, 2] - 
            0.008923926125826348`\ c[0, 3] - 0.00860704236186341`\ c[0, 4] - 
            0.012106848422408103`\ c[1, 0] - 0.010477165584573477`\ c[1, 1] - 
            0.009304566850154513`\ c[1, 2] - 0.008459657429921929`\ c[1, 3] - 
            0.007851377836638139`\ c[1, 4] - 0.007007229919035119`\ c[2, 0] - 
            0.006432787826840065`\ c[2, 1] - 0.006009192315475497`\ c[2, 2] - 
            0.005699807554101641`\ c[2, 3] - 0.005479260501230088`\ c[2, 4] - 
            0.006861334783600878`\ c[3, 0] - 0.006042481890937538`\ c[3, 1] - 
            0.00546885731280421`\ c[3, 2] - 0.005065387719962856`\ c[3, 3] - 
            0.004784347313541393`\ c[3, 4] - 0.00442629029432368`\ c[4, 0] - 
            0.004111748968859301`\ c[4, 1] - 
            0.0038856227858390414`\ c[4, 2] - 
            0.0037268360787244955`\ c[4, 3] - 
            0.0036211656337744895`\ c[4, 
                4] == \(-0.0032606581135811354`\)\)\),
      SequenceForm[ "eq", {3, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.01048306087485224, 
              c[ 0, 0]], 
            Times[ -0.0098624419904312539, 
              c[ 0, 1]], 
            Times[ -0.0093395663170810841, 
              c[ 0, 2]], 
            Times[ -0.008923926125826348, 
              c[ 0, 3]], 
            Times[ -0.0086070423618634095, 
              c[ 0, 4]], 
            Times[ -0.012106848422408103, 
              c[ 1, 0]], 
            Times[ -0.010477165584573477, 
              c[ 1, 1]], 
            Times[ -0.009304566850154513, 
              c[ 1, 2]], 
            Times[ -0.0084596574299219286, 
              c[ 1, 3]], 
            Times[ -0.0078513778366381386, 
              c[ 1, 4]], 
            Times[ -0.0070072299190351191, 
              c[ 2, 0]], 
            Times[ -0.0064327878268400649, 
              c[ 2, 1]], 
            Times[ -0.0060091923154754973, 
              c[ 2, 2]], 
            Times[ -0.0056998075541016407, 
              c[ 2, 3]], 
            Times[ -0.0054792605012300884, 
              c[ 2, 4]], 
            Times[ -0.0068613347836008779, 
              c[ 3, 0]], 
            Times[ -0.0060424818909375379, 
              c[ 3, 1]], 
            Times[ -0.0054688573128042102, 
              c[ 3, 2]], 
            Times[ -0.005065387719962856, 
              c[ 3, 3]], 
            Times[ -0.0047843473135413929, 
              c[ 3, 4]], 
            Times[ -0.0044262902943236803, 
              c[ 4, 0]], 
            Times[ -0.0041117489688593011, 
              c[ 4, 1]], 
            Times[ -0.0038856227858390414, 
              c[ 4, 2]], 
            Times[ -0.0037268360787244955, 
              c[ 4, 3]], 
            Times[ -0.0036211656337744895, 
              c[ 4, 4]]], -0.0032606581135811354]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.009093921920947861`\
\)\ c[0, 0] - 0.009036608015159785`\ c[0, 1] - 
            0.008923926125826348`\ c[0, 2] - 0.008815172038822284`\ c[0, 3] - 
            0.008735578653956227`\ c[0, 4] - 0.009803462370427049`\ c[1, 0] - 
            0.009054306493633068`\ c[1, 1] - 0.008459657429921929`\ c[1, 2] - 
            0.008009936159406981`\ c[1, 3] - 0.00768386840556921`\ c[1, 4] - 
            0.006150880915373312`\ c[2, 0] - 0.005893365132536453`\ c[2, 1] - 
            0.005699807554101641`\ c[2, 2] - 0.005564212407478219`\ c[2, 3] - 
            0.005480240284468271`\ c[2, 4] - 
            0.0058002264002220815`\ c[3, 0] - 
            0.005373238093975111`\ c[3, 1] - 0.005065387719962856`\ c[3, 2] - 
            0.0048509380365065885`\ c[3, 3] - 
            0.004710750728874009`\ c[3, 4] - 0.003984357358829202`\ c[4, 0] - 
            0.003831489007825308`\ c[4, 1] - 
            0.0037268360787244955`\ c[4, 2] - 
            0.0036630908001951687`\ c[4, 3] - 
            0.0036347798659246973`\ c[4, 
                4] == \(-0.0029254909127239635`\)\)\),
      SequenceForm[ "eq", {3, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.009093921920947861, 
              c[ 0, 0]], 
            Times[ -0.0090366080151597847, 
              c[ 0, 1]], 
            Times[ -0.008923926125826348, 
              c[ 0, 2]], 
            Times[ -0.0088151720388222835, 
              c[ 0, 3]], 
            Times[ -0.0087355786539562268, 
              c[ 0, 4]], 
            Times[ -0.009803462370427049, 
              c[ 1, 0]], 
            Times[ -0.0090543064936330683, 
              c[ 1, 1]], 
            Times[ -0.0084596574299219286, 
              c[ 1, 2]], 
            Times[ -0.0080099361594069812, 
              c[ 1, 3]], 
            Times[ -0.0076838684055692101, 
              c[ 1, 4]], 
            Times[ -0.0061508809153733119, 
              c[ 2, 0]], 
            Times[ -0.0058933651325364534, 
              c[ 2, 1]], 
            Times[ -0.0056998075541016407, 
              c[ 2, 2]], 
            Times[ -0.0055642124074782194, 
              c[ 2, 3]], 
            Times[ -0.0054802402844682709, 
              c[ 2, 4]], 
            Times[ -0.0058002264002220815, 
              c[ 3, 0]], 
            Times[ -0.0053732380939751113, 
              c[ 3, 1]], 
            Times[ -0.005065387719962856, 
              c[ 3, 2]], 
            Times[ -0.0048509380365065885, 
              c[ 3, 3]], 
            Times[ -0.0047107507288740094, 
              c[ 3, 4]], 
            Times[ -0.0039843573588292016, 
              c[ 4, 0]], 
            Times[ -0.0038314890078253081, 
              c[ 4, 1]], 
            Times[ -0.0037268360787244955, 
              c[ 4, 2]], 
            Times[ -0.0036630908001951687, 
              c[ 4, 3]], 
            Times[ -0.0036347798659246973, 
              c[ 4, 4]]], -0.0029254909127239635]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.008127733109395886`\
\)\ c[0, 0] - 0.00842887740212212`\ c[0, 1] - 0.00860704236186341`\ c[0, 2] - 
            0.008735578653956227`\ c[0, 3] - 0.008853244905980365`\ c[0, 4] - 
            0.008303525424068736`\ c[1, 0] - 0.008069049154051568`\ c[1, 1] - 
            0.007851377836638139`\ c[1, 2] - 0.00768386840556921`\ c[1, 3] - 
            0.0075756649296774455`\ c[1, 4] - 
            0.005545883583719328`\ c[2, 0] - 0.005503804906830416`\ c[2, 1] - 
            0.005479260501230088`\ c[2, 2] - 0.005480240284468271`\ c[2, 3] - 
            0.005510165689203531`\ c[2, 4] - 0.005086380437487815`\ c[3, 0] - 
            0.004908346620240498`\ c[3, 1] - 0.004784347313541393`\ c[3, 2] - 
            0.004710750728874009`\ c[3, 3] - 0.004682736108486976`\ c[3, 4] - 
            0.0036690876737841076`\ c[4, 0] - 
            0.0036325391913967736`\ c[4, 1] - 
            0.0036211656337744895`\ c[4, 2] - 
            0.0036347798659246973`\ c[4, 3] - 
            0.003672829770052524`\ c[4, 4] == \(-0.0026843759077584874`\)\)\),
      
      SequenceForm[ "eq", {3, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0081277331093958863, 
              c[ 0, 0]], 
            Times[ -0.0084288774021221199, 
              c[ 0, 1]], 
            Times[ -0.0086070423618634095, 
              c[ 0, 2]], 
            Times[ -0.0087355786539562268, 
              c[ 0, 3]], 
            Times[ -0.0088532449059803651, 
              c[ 0, 4]], 
            Times[ -0.0083035254240687358, 
              c[ 1, 0]], 
            Times[ -0.0080690491540515684, 
              c[ 1, 1]], 
            Times[ -0.0078513778366381386, 
              c[ 1, 2]], 
            Times[ -0.0076838684055692101, 
              c[ 1, 3]], 
            Times[ -0.0075756649296774455, 
              c[ 1, 4]], 
            Times[ -0.0055458835837193278, 
              c[ 2, 0]], 
            Times[ -0.0055038049068304156, 
              c[ 2, 1]], 
            Times[ -0.0054792605012300884, 
              c[ 2, 2]], 
            Times[ -0.0054802402844682709, 
              c[ 2, 3]], 
            Times[ -0.0055101656892035311, 
              c[ 2, 4]], 
            Times[ -0.0050863804374878148, 
              c[ 3, 0]], 
            Times[ -0.0049083466202404979, 
              c[ 3, 1]], 
            Times[ -0.0047843473135413929, 
              c[ 3, 2]], 
            Times[ -0.0047107507288740094, 
              c[ 3, 3]], 
            Times[ -0.0046827361084869762, 
              c[ 3, 4]], 
            Times[ -0.0036690876737841076, 
              c[ 4, 0]], 
            Times[ -0.0036325391913967736, 
              c[ 4, 1]], 
            Times[ -0.0036211656337744895, 
              c[ 4, 2]], 
            Times[ -0.0036347798659246973, 
              c[ 4, 3]], 
            Times[ -0.0036728297700525242, 
              c[ 4, 4]]], -0.0026843759077584874]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.015976413964149252`\
\)\ c[0, 0] - 0.011760381891013425`\ c[0, 1] - 
            0.009301716115560361`\ c[0, 2] - 0.007756599928090679`\ c[0, 3] - 
            0.006735398953034707`\ c[0, 4] - 0.00913459576150887`\ c[1, 0] - 
            0.007486207632183761`\ c[1, 1] - 0.006401313315192519`\ c[1, 2] - 
            0.0056558321916690855`\ c[1, 3] - 0.00512962422980158`\ c[1, 4] - 
            0.010707820741319048`\ c[2, 0] - 0.008165387528130017`\ c[2, 1] - 
            0.006611074427079434`\ c[2, 2] - 
            0.0056049222622869006`\ c[2, 3] - 0.00492782211471897`\ c[2, 4] - 
            0.005975716618244462`\ c[3, 0] - 0.005055085095407302`\ c[3, 1] - 
            0.00442629029432368`\ c[3, 2] - 0.003984357358829202`\ c[3, 3] - 
            0.0036690876737841076`\ c[3, 4] - 
            0.006196351317579794`\ c[4, 0] - 0.005006107300323158`\ c[4, 1] - 
            0.004238484430834086`\ c[4, 2] - 0.003723660011025707`\ c[4, 3] - 
            0.003370155517301354`\ c[4, 4] == \(-0.005532061103142007`\)\)\),
      SequenceForm[ "eq", {4, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.015976413964149252, 
              c[ 0, 0]], 
            Times[ -0.011760381891013425, 
              c[ 0, 1]], 
            Times[ -0.0093017161155603614, 
              c[ 0, 2]], 
            Times[ -0.0077565999280906793, 
              c[ 0, 3]], 
            Times[ -0.0067353989530347068, 
              c[ 0, 4]], 
            Times[ -0.0091345957615088704, 
              c[ 1, 0]], 
            Times[ -0.007486207632183761, 
              c[ 1, 1]], 
            Times[ -0.0064013133151925193, 
              c[ 1, 2]], 
            Times[ -0.0056558321916690855, 
              c[ 1, 3]], 
            Times[ -0.0051296242298015798, 
              c[ 1, 4]], 
            Times[ -0.010707820741319048, 
              c[ 2, 0]], 
            Times[ -0.0081653875281300168, 
              c[ 2, 1]], 
            Times[ -0.0066110744270794341, 
              c[ 2, 2]], 
            Times[ -0.0056049222622869006, 
              c[ 2, 3]], 
            Times[ -0.0049278221147189697, 
              c[ 2, 4]], 
            Times[ -0.0059757166182444624, 
              c[ 3, 0]], 
            Times[ -0.0050550850954073018, 
              c[ 3, 1]], 
            Times[ -0.0044262902943236803, 
              c[ 3, 2]], 
            Times[ -0.0039843573588292016, 
              c[ 3, 3]], 
            Times[ -0.0036690876737841076, 
              c[ 3, 4]], 
            Times[ -0.0061963513175797942, 
              c[ 4, 0]], 
            Times[ -0.0050061073003231579, 
              c[ 4, 1]], 
            Times[ -0.0042384844308340861, 
              c[ 4, 2]], 
            Times[ -0.003723660011025707, 
              c[ 4, 3]], 
            Times[ -0.0033701555173013542, 
              c[ 4, 4]]], -0.0055320611031420067]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.011760381891013425`\
\)\ c[0, 0] - 0.009784579799622044`\ c[0, 1] - 
            0.008430303142237104`\ c[0, 2] - 0.00748618002259904`\ c[0, 3] - 
            0.006819507989826906`\ c[0, 4] - 0.007486207632183761`\ c[1, 0] - 
            0.0065791605132922825`\ c[1, 1] - 
            0.0059377391031358384`\ c[1, 2] - 
            0.0054771057786187054`\ c[1, 3] - 
            0.0051453642139178595`\ c[1, 4] - 
            0.008165387528130017`\ c[2, 0] - 0.006772272757480883`\ c[2, 1] - 
            0.005847177753002358`\ c[2, 2] - 
            0.0052146797712062645`\ c[2, 3] - 
            0.004775382682019783`\ c[2, 4] - 0.005055085095407302`\ c[3, 0] - 
            0.004503483619290428`\ c[3, 1] - 0.004111748968859301`\ c[3, 2] - 
            0.003831489007825308`\ c[3, 3] - 
            0.0036325391913967736`\ c[3, 4] - 
            0.005006107300323158`\ c[4, 0] - 0.004306676036986969`\ c[4, 1] - 
            0.0038321717390644543`\ c[4, 2] - 
            0.003504859497603178`\ c[4, 3] - 
            0.0032789042969824044`\ c[4, 4] == \(-0.004126092225661819`\)\)\),
      
      SequenceForm[ "eq", {4, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.011760381891013425, 
              c[ 0, 0]], 
            Times[ -0.0097845797996220438, 
              c[ 0, 1]], 
            Times[ -0.0084303031422371041, 
              c[ 0, 2]], 
            Times[ -0.0074861800225990401, 
              c[ 0, 3]], 
            Times[ -0.006819507989826906, 
              c[ 0, 4]], 
            Times[ -0.007486207632183761, 
              c[ 1, 0]], 
            Times[ -0.0065791605132922825, 
              c[ 1, 1]], 
            Times[ -0.0059377391031358384, 
              c[ 1, 2]], 
            Times[ -0.0054771057786187054, 
              c[ 1, 3]], 
            Times[ -0.0051453642139178595, 
              c[ 1, 4]], 
            Times[ -0.0081653875281300168, 
              c[ 2, 0]], 
            Times[ -0.0067722727574808829, 
              c[ 2, 1]], 
            Times[ -0.0058471777530023578, 
              c[ 2, 2]], 
            Times[ -0.0052146797712062645, 
              c[ 2, 3]], 
            Times[ -0.0047753826820197834, 
              c[ 2, 4]], 
            Times[ -0.0050550850954073018, 
              c[ 3, 0]], 
            Times[ -0.0045034836192904279, 
              c[ 3, 1]], 
            Times[ -0.0041117489688593011, 
              c[ 3, 2]], 
            Times[ -0.0038314890078253081, 
              c[ 3, 3]], 
            Times[ -0.0036325391913967736, 
              c[ 3, 4]], 
            Times[ -0.0050061073003231579, 
              c[ 4, 0]], 
            Times[ -0.0043066760369869688, 
              c[ 4, 1]], 
            Times[ -0.0038321717390644543, 
              c[ 4, 2]], 
            Times[ -0.0035048594976031782, 
              c[ 4, 3]], 
            Times[ -0.0032789042969824044, 
              c[ 4, 4]]], -0.0041260922256618187]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.009301716115560361`\
\)\ c[0, 0] - 0.008430303142237104`\ c[0, 1] - 
            0.007736440379120484`\ c[0, 2] - 0.007210116265697266`\ c[0, 3] - 
            0.006822869599386631`\ c[0, 4] - 0.006401313315192519`\ c[1, 0] - 
            0.0059377391031358384`\ c[1, 1] - 
            0.005592932961557747`\ c[1, 2] - 0.005341366861189084`\ c[1, 3] - 
            0.005164329576180986`\ c[1, 4] - 0.006611074427079434`\ c[2, 0] - 
            0.005847177753002358`\ c[2, 1] - 0.005310298990035364`\ c[2, 2] - 
            0.0049324237817421415`\ c[2, 3] - 
            0.0046697952900079265`\ c[2, 4] - 0.00442629029432368`\ c[3, 0] - 
            0.004111748968859301`\ c[3, 1] - 
            0.0038856227858390414`\ c[3, 2] - 
            0.0037268360787244955`\ c[3, 3] - 
            0.0036211656337744895`\ c[3, 4] - 
            0.004238484430834086`\ c[4, 0] - 
            0.0038321717390644543`\ c[4, 1] - 
            0.0035497608243704516`\ c[4, 2] - 
            0.003355644533674814`\ c[4, 3] - 
            0.003227080832615768`\ c[4, 4] == \(-0.003291410245975625`\)\)\),
      SequenceForm[ "eq", {4, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0093017161155603614, 
              c[ 0, 0]], 
            Times[ -0.0084303031422371041, 
              c[ 0, 1]], 
            Times[ -0.0077364403791204839, 
              c[ 0, 2]], 
            Times[ -0.0072101162656972662, 
              c[ 0, 3]], 
            Times[ -0.0068228695993866311, 
              c[ 0, 4]], 
            Times[ -0.0064013133151925193, 
              c[ 1, 0]], 
            Times[ -0.0059377391031358384, 
              c[ 1, 1]], 
            Times[ -0.0055929329615577467, 
              c[ 1, 2]], 
            Times[ -0.0053413668611890838, 
              c[ 1, 3]], 
            Times[ -0.0051643295761809862, 
              c[ 1, 4]], 
            Times[ -0.0066110744270794341, 
              c[ 2, 0]], 
            Times[ -0.0058471777530023578, 
              c[ 2, 1]], 
            Times[ -0.0053102989900353642, 
              c[ 2, 2]], 
            Times[ -0.0049324237817421415, 
              c[ 2, 3]], 
            Times[ -0.0046697952900079265, 
              c[ 2, 4]], 
            Times[ -0.0044262902943236803, 
              c[ 3, 0]], 
            Times[ -0.0041117489688593011, 
              c[ 3, 1]], 
            Times[ -0.0038856227858390414, 
              c[ 3, 2]], 
            Times[ -0.0037268360787244955, 
              c[ 3, 3]], 
            Times[ -0.0036211656337744895, 
              c[ 3, 4]], 
            Times[ -0.0042384844308340861, 
              c[ 4, 0]], 
            Times[ -0.0038321717390644543, 
              c[ 4, 1]], 
            Times[ -0.0035497608243704516, 
              c[ 4, 2]], 
            Times[ -0.0033556445336748141, 
              c[ 4, 3]], 
            Times[ -0.0032270808326157678, 
              c[ 4, 4]]], -0.0032914102459756251]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.007756599928090679`\
\)\ c[0, 0] - 0.00748618002259904`\ c[0, 1] - 
            0.007210116265697266`\ c[0, 2] - 0.006981427922155477`\ c[0, 3] - 
            0.006813932904362683`\ c[0, 4] - 
            0.0056558321916690855`\ c[1, 0] - 
            0.0054771057786187054`\ c[1, 1] - 
            0.005341366861189084`\ c[1, 2] - 0.005249281482429118`\ c[1, 3] - 
            0.005198701693497111`\ c[1, 4] - 
            0.0056049222622869006`\ c[2, 0] - 
            0.0052146797712062645`\ c[2, 1] - 
            0.0049324237817421415`\ c[2, 2] - 
            0.004736386012973122`\ c[2, 3] - 0.004609784506921807`\ c[2, 4] - 
            0.003984357358829202`\ c[3, 0] - 0.003831489007825308`\ c[3, 1] - 
            0.0037268360787244955`\ c[3, 2] - 
            0.0036630908001951687`\ c[3, 3] - 
            0.0036347798659246973`\ c[3, 4] - 
            0.003723660011025707`\ c[4, 0] - 0.003504859497603178`\ c[4, 1] - 
            0.003355644533674814`\ c[4, 2] - 0.003260751435497525`\ c[4, 3] - 
            0.0032096228313462406`\ c[4, 4] == \(-0.002760710085568981`\)\)\),
      
      SequenceForm[ "eq", {4, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0077565999280906793, 
              c[ 0, 0]], 
            Times[ -0.0074861800225990401, 
              c[ 0, 1]], 
            Times[ -0.0072101162656972662, 
              c[ 0, 2]], 
            Times[ -0.0069814279221554771, 
              c[ 0, 3]], 
            Times[ -0.0068139329043626828, 
              c[ 0, 4]], 
            Times[ -0.0056558321916690855, 
              c[ 1, 0]], 
            Times[ -0.0054771057786187054, 
              c[ 1, 1]], 
            Times[ -0.0053413668611890838, 
              c[ 1, 2]], 
            Times[ -0.0052492814824291181, 
              c[ 1, 3]], 
            Times[ -0.0051987016934971113, 
              c[ 1, 4]], 
            Times[ -0.0056049222622869006, 
              c[ 2, 0]], 
            Times[ -0.0052146797712062645, 
              c[ 2, 1]], 
            Times[ -0.0049324237817421415, 
              c[ 2, 2]], 
            Times[ -0.0047363860129731221, 
              c[ 2, 3]], 
            Times[ -0.0046097845069218071, 
              c[ 2, 4]], 
            Times[ -0.0039843573588292016, 
              c[ 3, 0]], 
            Times[ -0.0038314890078253081, 
              c[ 3, 1]], 
            Times[ -0.0037268360787244955, 
              c[ 3, 2]], 
            Times[ -0.0036630908001951687, 
              c[ 3, 3]], 
            Times[ -0.0036347798659246973, 
              c[ 3, 4]], 
            Times[ -0.003723660011025707, 
              c[ 4, 0]], 
            Times[ -0.0035048594976031782, 
              c[ 4, 1]], 
            Times[ -0.0033556445336748141, 
              c[ 4, 2]], 
            Times[ -0.0032607514354975249, 
              c[ 4, 3]], 
            Times[ -0.0032096228313462406, 
              c[ 4, 4]]], -0.0027607100855689811]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{4, 
          4}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.006735398953034707`\
\)\ c[0, 0] - 0.006819507989826906`\ c[0, 1] - 
            0.006822869599386631`\ c[0, 2] - 0.006813932904362683`\ c[0, 3] - 
            0.0068226126066063195`\ c[0, 4] - 0.00512962422980158`\ c[1, 0] - 
            0.0051453642139178595`\ c[1, 1] - 
            0.005164329576180986`\ c[1, 2] - 0.005198701693497111`\ c[1, 3] - 
            0.005254644949840944`\ c[1, 4] - 0.00492782211471897`\ c[2, 0] - 
            0.004775382682019783`\ c[2, 1] - 
            0.0046697952900079265`\ c[2, 2] - 
            0.004609784506921807`\ c[2, 3] - 0.004591992972866244`\ c[2, 4] - 
            0.0036690876737841076`\ c[3, 0] - 
            0.0036325391913967736`\ c[3, 1] - 
            0.0036211656337744895`\ c[3, 2] - 
            0.0036347798659246973`\ c[3, 3] - 
            0.003672829770052524`\ c[3, 4] - 0.003370155517301354`\ c[4, 0] - 
            0.0032789042969824044`\ c[4, 1] - 
            0.003227080832615768`\ c[4, 2] - 
            0.0032096228313462406`\ c[4, 3] - 
            0.0032226166097433797`\ c[4, 4] == \(-0.002407472758250739`\)\)\),
      
      SequenceForm[ "eq", {4, 4}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.0067353989530347068, 
              c[ 0, 0]], 
            Times[ -0.006819507989826906, 
              c[ 0, 1]], 
            Times[ -0.0068228695993866311, 
              c[ 0, 2]], 
            Times[ -0.0068139329043626828, 
              c[ 0, 3]], 
            Times[ -0.0068226126066063195, 
              c[ 0, 4]], 
            Times[ -0.0051296242298015798, 
              c[ 1, 0]], 
            Times[ -0.0051453642139178595, 
              c[ 1, 1]], 
            Times[ -0.0051643295761809862, 
              c[ 1, 2]], 
            Times[ -0.0051987016934971113, 
              c[ 1, 3]], 
            Times[ -0.0052546449498409439, 
              c[ 1, 4]], 
            Times[ -0.0049278221147189697, 
              c[ 2, 0]], 
            Times[ -0.0047753826820197834, 
              c[ 2, 1]], 
            Times[ -0.0046697952900079265, 
              c[ 2, 2]], 
            Times[ -0.0046097845069218071, 
              c[ 2, 3]], 
            Times[ -0.0045919929728662438, 
              c[ 2, 4]], 
            Times[ -0.0036690876737841076, 
              c[ 3, 0]], 
            Times[ -0.0036325391913967736, 
              c[ 3, 1]], 
            Times[ -0.0036211656337744895, 
              c[ 3, 2]], 
            Times[ -0.0036347798659246973, 
              c[ 3, 3]], 
            Times[ -0.0036728297700525242, 
              c[ 3, 4]], 
            Times[ -0.0033701555173013542, 
              c[ 4, 0]], 
            Times[ -0.0032789042969824044, 
              c[ 4, 1]], 
            Times[ -0.0032270808326157678, 
              c[ 4, 2]], 
            Times[ -0.0032096228313462406, 
              c[ 4, 3]], 
            Times[ -0.0032226166097433797, 
              c[ 4, 4]]], -0.002407472758250739]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "The module returns the approximate solution for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ". We plot the solution in Cell ",
  ButtonBox["6.21",
    ButtonData:>"Cell 6.21",
    ButtonStyle->"Hyperlink"],
  " as a contour plot."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi][x, y]\ Boole[
            z[1, x, y] \[LessEqual] \ 0 && 
              z[2, x, y] \[GreaterEqual] 0], {x, \(-1\), 1.3}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 100, FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        Contours \[Rule] {0, \(- .02\), \(-0.04\), \(-0.06\), \
\(-0.08\)}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437291 0.41806 0.0192308 0.739645 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.22826 -0.0125 -12 -9 ]
[.22826 -0.0125 12 0 ]
[.43729 -0.0125 -3 -9 ]
[.43729 -0.0125 3 0 ]
[.64632 -0.0125 -9 -9 ]
[.64632 -0.0125 9 0 ]
[.85535 -0.0125 -3 -9 ]
[.85535 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16716 -18 -4.5 ]
[-0.0125 .16716 0 4.5 ]
[-0.0125 .31509 -18 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .46302 -18 -4.5 ]
[-0.0125 .46302 0 4.5 ]
[-0.0125 .61095 -18 -4.5 ]
[-0.0125 .61095 0 4.5 ]
[-0.0125 .75888 -6 -4.5 ]
[-0.0125 .75888 0 4.5 ]
[-0.0125 .9068 -18 -4.5 ]
[-0.0125 .9068 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -5 ]
[-0.01875 .5 -18 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.22826 0 m
.22826 .00625 L
s
[(-0.5)] .22826 -0.0125 0 1 Mshowa
.43729 0 m
.43729 .00625 L
s
[(0)] .43729 -0.0125 0 1 Mshowa
.64632 0 m
.64632 .00625 L
s
[(0.5)] .64632 -0.0125 0 1 Mshowa
.85535 0 m
.85535 .00625 L
s
[(1)] .85535 -0.0125 0 1 Mshowa
.125 Mabswid
.06104 0 m
.06104 .00375 L
s
.10284 0 m
.10284 .00375 L
s
.14465 0 m
.14465 .00375 L
s
.18645 0 m
.18645 .00375 L
s
.27007 0 m
.27007 .00375 L
s
.31187 0 m
.31187 .00375 L
s
.35368 0 m
.35368 .00375 L
s
.39548 0 m
.39548 .00375 L
s
.4791 0 m
.4791 .00375 L
s
.5209 0 m
.5209 .00375 L
s
.56271 0 m
.56271 .00375 L
s
.60452 0 m
.60452 .00375 L
s
.68813 0 m
.68813 .00375 L
s
.72993 0 m
.72993 .00375 L
s
.77174 0 m
.77174 .00375 L
s
.81355 0 m
.81355 .00375 L
s
.89716 0 m
.89716 .00375 L
s
.93896 0 m
.93896 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16716 m
.00625 .16716 L
s
[(0.2)] -0.0125 .16716 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(0.4)] -0.0125 .31509 1 0 Mshowa
0 .46302 m
.00625 .46302 L
s
[(0.6)] -0.0125 .46302 1 0 Mshowa
0 .61095 m
.00625 .61095 L
s
[(0.8)] -0.0125 .61095 1 0 Mshowa
0 .75888 m
.00625 .75888 L
s
[(1)] -0.0125 .75888 1 0 Mshowa
0 .9068 m
.00625 .9068 L
s
[(1.2)] -0.0125 .9068 1 0 Mshowa
.125 Mabswid
0 .05621 m
.00375 .05621 L
s
0 .0932 m
.00375 .0932 L
s
0 .13018 m
.00375 .13018 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .5 m
.00375 .5 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .64793 m
.00375 .64793 L
s
0 .68491 m
.00375 .68491 L
s
0 .72189 m
.00375 .72189 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .86982 m
.00375 .86982 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.22826 .99375 m
.22826 1 L
s
.43729 .99375 m
.43729 1 L
s
.64632 .99375 m
.64632 1 L
s
.85535 .99375 m
.85535 1 L
s
.125 Mabswid
.06104 .99625 m
.06104 1 L
s
.10284 .99625 m
.10284 1 L
s
.14465 .99625 m
.14465 1 L
s
.18645 .99625 m
.18645 1 L
s
.27007 .99625 m
.27007 1 L
s
.31187 .99625 m
.31187 1 L
s
.35368 .99625 m
.35368 1 L
s
.39548 .99625 m
.39548 1 L
s
.4791 .99625 m
.4791 1 L
s
.5209 .99625 m
.5209 1 L
s
.56271 .99625 m
.56271 1 L
s
.60452 .99625 m
.60452 1 L
s
.68813 .99625 m
.68813 1 L
s
.72993 .99625 m
.72993 1 L
s
.77174 .99625 m
.77174 1 L
s
.81355 .99625 m
.81355 1 L
s
.89716 .99625 m
.89716 1 L
s
.93896 .99625 m
.93896 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16716 m
1 .16716 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .46302 m
1 .46302 L
s
.99375 .61095 m
1 .61095 L
s
.99375 .75888 m
1 .75888 L
s
.99375 .9068 m
1 .9068 L
s
.125 Mabswid
.99625 .05621 m
1 .05621 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .13018 m
1 .13018 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .5 m
1 .5 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .68491 m
1 .68491 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .86982 m
1 .86982 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.869 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
1 g
.39802 .01923 m
.40773 .01923 L
.41744 .01923 L
.42716 .01923 L
.43687 .01923 L
.44658 .01923 L
.45629 .01923 L
.46601 .01923 L
.47572 .01923 L
.48543 .02894 L
.48543 .02894 L
.49514 .02894 L
.50486 .02894 L
.51457 .03866 L
.51457 .03866 L
.52428 .04837 L
.52428 .04837 L
.53399 .05808 L
.53399 .05808 L
.54371 .05808 L
.55342 .06779 L
.55342 .06779 L
.56313 .07751 L
.56313 .07751 L
.57284 .08722 L
.57284 .09693 L
.57284 .09693 L
.58256 .10664 L
.58256 .10664 L
.59227 .11636 L
.59227 .11636 L
.60198 .12607 L
.60198 .12607 L
.61169 .13578 L
.61169 .14549 L
.61169 .14549 L
.62141 .15521 L
.62141 .15521 L
.63112 .16492 L
.63112 .17463 L
.63112 .17463 L
.64083 .18434 L
.64083 .19406 L
.64083 .19406 L
.65054 .20377 L
.65054 .20377 L
.66026 .21348 L
.66026 .22319 L
.66026 .22319 L
.66997 .23291 L
.66997 .24262 L
.66997 .24262 L
.67968 .25233 L
.67968 .26204 L
.67968 .26204 L
.68939 .27176 L
.68939 .28147 L
.68939 .28147 L
.69911 .29118 L
.69911 .30089 L
.69911 .30089 L
.70882 .31061 L
.70882 .32032 L
.70882 .33003 L
.70882 .33003 L
.71853 .33974 L
.71853 .34946 L
.71853 .34946 L
.72824 .35917 L
.72824 .36888 L
.72824 .36888 L
.73796 .37859 L
.73796 .38831 L
.73796 .39802 L
.73796 .39802 L
.74767 .40773 L
.74767 .41744 L
.74767 .41744 L
.75738 .42716 L
.75738 .43687 L
.75738 .44658 L
.75738 .44658 L
.76709 .45629 L
.76709 .46601 L
.76709 .47572 L
.76709 .47572 L
.77681 .48543 L
.77681 .49514 L
.77681 .50486 L
.77681 .50486 L
.78652 .51457 L
.78652 .52428 L
.78652 .53399 L
.78652 .53399 L
.79623 .54371 L
.79623 .55342 L
.79623 .56313 L
.79623 .56313 L
.80594 .57284 L
.80594 .58256 L
.80594 .59227 L
.80594 .59227 L
.81566 .60198 L
.81566 .61169 L
.81566 .62141 L
.81566 .62141 L
.82537 .63112 L
.82537 .64083 L
.82537 .65054 L
.82537 .65054 L
.83508 .66026 L
.83508 .66997 L
.83508 .67968 L
.83508 .67968 L
.84479 .68939 L
.84479 .69911 L
.84479 .70882 L
.84479 .71853 L
.84479 .71853 L
.85451 .72824 L
.85451 .73796 L
.85451 .74767 L
.85451 .74767 L
.86422 .75738 L
.86422 .76709 L
.86422 .77681 L
.86422 .78652 L
.86422 .78652 L
.87393 .79623 L
.87393 .80594 L
.87393 .81566 L
.87393 .82537 L
.87393 .82537 L
.88364 .83508 L
.88364 .84479 L
.88364 .85451 L
.88364 .85451 L
.89336 .86422 L
.89336 .87393 L
.89336 .88364 L
.88364 .89336 L
.87393 .89336 L
.86422 .89336 L
.85451 .88364 L
.85451 .88364 L
.84479 .88364 L
.83508 .88364 L
.82537 .87393 L
.82537 .87393 L
.81566 .87393 L
.80594 .87393 L
.79623 .87393 L
.78652 .86422 L
.78652 .86422 L
.77681 .86422 L
.76709 .86422 L
.75738 .85451 L
.75738 .85451 L
.74767 .85451 L
.73796 .85451 L
.72824 .84479 L
.72824 .84479 L
.71853 .84479 L
.70882 .84479 L
.69911 .84479 L
.68939 .83508 L
.68939 .83508 L
.67968 .83508 L
.66997 .83508 L
.66026 .82537 L
.66026 .82537 L
.65054 .82537 L
.64083 .82537 L
.63112 .82537 L
.62141 .81566 L
.62141 .81566 L
.61169 .81566 L
.60198 .81566 L
.59227 .80594 L
.59227 .80594 L
.58256 .80594 L
.57284 .80594 L
.56313 .79623 L
.56313 .79623 L
.55342 .79623 L
.54371 .79623 L
.53399 .79623 L
.52428 .78652 L
.52428 .78652 L
.51457 .78652 L
.50486 .78652 L
.49514 .77681 L
.49514 .77681 L
.48543 .77681 L
.47572 .77681 L
.46601 .77681 L
.45629 .76709 L
.45629 .76709 L
.44658 .76709 L
.43687 .76709 L
.42716 .75738 L
.42716 .75738 L
.41744 .75738 L
.40773 .75738 L
.39802 .74767 L
.39802 .74767 L
.38831 .74767 L
.37859 .74767 L
.36888 .74767 L
.35917 .73796 L
.35917 .73796 L
.34946 .73796 L
.33974 .73796 L
.33003 .72824 L
.33003 .72824 L
.32032 .72824 L
.31061 .72824 L
.30089 .72824 L
.29118 .71853 L
.29118 .71853 L
.28147 .71853 L
.27176 .71853 L
.26204 .70882 L
.26204 .70882 L
.25233 .70882 L
.24262 .70882 L
.23291 .69911 L
.23291 .69911 L
.22319 .69911 L
.21348 .69911 L
.20377 .69911 L
.19406 .68939 L
.19406 .68939 L
.18434 .68939 L
.17463 .68939 L
.16492 .67968 L
.16492 .67968 L
.15521 .67968 L
.14549 .67968 L
.13578 .67968 L
.12607 .66997 L
.12607 .66997 L
.11636 .66997 L
.10664 .66997 L
.09693 .66026 L
.09693 .66026 L
.08722 .66026 L
.07751 .66026 L
.06779 .65054 L
.06779 .65054 L
.05808 .65054 L
.04837 .64083 L
.04837 .63112 L
.05808 .62141 L
.05808 .62141 L
.05808 .61169 L
.05808 .60198 L
.06779 .59227 L
.06779 .59227 L
.06779 .58256 L
.06779 .57284 L
.07751 .56313 L
.07751 .56313 L
.07751 .55342 L
.07751 .54371 L
.08722 .53399 L
.08722 .53399 L
.08722 .52428 L
.08722 .51457 L
.09693 .50486 L
.09693 .50486 L
.09693 .49514 L
.09693 .48543 L
.10664 .47572 L
.10664 .47572 L
.10664 .46601 L
.10664 .45629 L
.11636 .44658 L
.11636 .44658 L
.11636 .43687 L
.12607 .42716 L
.12607 .42716 L
.12607 .41744 L
.12607 .40773 L
.13578 .39802 L
.13578 .39802 L
.13578 .38831 L
.14549 .37859 L
.14549 .37859 L
.14549 .36888 L
.14549 .35917 L
.15521 .34946 L
.15521 .34946 L
.15521 .33974 L
.16492 .33003 L
.16492 .33003 L
.16492 .32032 L
.17463 .31061 L
.17463 .31061 L
.17463 .30089 L
.17463 .29118 L
.18434 .28147 L
.18434 .28147 L
.18434 .27176 L
.19406 .26204 L
.19406 .26204 L
.19406 .25233 L
.20377 .24262 L
.20377 .24262 L
.20377 .23291 L
.21348 .22319 L
.21348 .22319 L
.21348 .21348 L
.22319 .20377 L
.22319 .20377 L
.23291 .19406 L
.23291 .19406 L
.23291 .18434 L
.24262 .17463 L
.24262 .17463 L
.24262 .16492 L
.25233 .15521 L
.25233 .15521 L
.26204 .14549 L
.26204 .14549 L
.26204 .13578 L
.27176 .12607 L
.27176 .12607 L
.28147 .11636 L
.28147 .11636 L
.29118 .10664 L
.29118 .10664 L
.30089 .09693 L
.30089 .09693 L
.30089 .08722 L
.31061 .07751 L
.31061 .07751 L
.32032 .06779 L
.33003 .06779 L
.33003 .06779 L
.33974 .05808 L
.33974 .05808 L
.34946 .04837 L
.34946 .04837 L
.35917 .03866 L
.36888 .03866 L
.36888 .03866 L
.37859 .02894 L
.38831 .02894 L
.38831 .02894 L
F
0 g
.39802 .01923 m
.40773 .01923 L
.41744 .01923 L
.42716 .01923 L
.43687 .01923 L
.44658 .01923 L
.45629 .01923 L
.46601 .01923 L
.47572 .01923 L
.48543 .02894 L
.48543 .02894 L
.49514 .02894 L
.50486 .02894 L
.51457 .03866 L
.51457 .03866 L
.52428 .04837 L
.52428 .04837 L
.53399 .05808 L
.53399 .05808 L
.54371 .05808 L
.55342 .06779 L
.55342 .06779 L
.56313 .07751 L
.56313 .07751 L
.57284 .08722 L
.57284 .09693 L
.57284 .09693 L
.58256 .10664 L
.58256 .10664 L
.59227 .11636 L
.59227 .11636 L
.60198 .12607 L
.60198 .12607 L
.61169 .13578 L
.61169 .14549 L
.61169 .14549 L
.62141 .15521 L
.62141 .15521 L
.63112 .16492 L
.63112 .17463 L
.63112 .17463 L
.64083 .18434 L
.64083 .19406 L
.64083 .19406 L
.65054 .20377 L
.65054 .20377 L
.66026 .21348 L
.66026 .22319 L
.66026 .22319 L
.66997 .23291 L
Mistroke
.66997 .24262 L
.66997 .24262 L
.67968 .25233 L
.67968 .26204 L
.67968 .26204 L
.68939 .27176 L
.68939 .28147 L
.68939 .28147 L
.69911 .29118 L
.69911 .30089 L
.69911 .30089 L
.70882 .31061 L
.70882 .32032 L
.70882 .33003 L
.70882 .33003 L
.71853 .33974 L
.71853 .34946 L
.71853 .34946 L
.72824 .35917 L
.72824 .36888 L
.72824 .36888 L
.73796 .37859 L
.73796 .38831 L
.73796 .39802 L
.73796 .39802 L
.74767 .40773 L
.74767 .41744 L
.74767 .41744 L
.75738 .42716 L
.75738 .43687 L
.75738 .44658 L
.75738 .44658 L
.76709 .45629 L
.76709 .46601 L
.76709 .47572 L
.76709 .47572 L
.77681 .48543 L
.77681 .49514 L
.77681 .50486 L
.77681 .50486 L
.78652 .51457 L
.78652 .52428 L
.78652 .53399 L
.78652 .53399 L
.79623 .54371 L
.79623 .55342 L
.79623 .56313 L
.79623 .56313 L
.80594 .57284 L
.80594 .58256 L
Mistroke
.80594 .59227 L
.80594 .59227 L
.81566 .60198 L
.81566 .61169 L
.81566 .62141 L
.81566 .62141 L
.82537 .63112 L
.82537 .64083 L
.82537 .65054 L
.82537 .65054 L
.83508 .66026 L
.83508 .66997 L
.83508 .67968 L
.83508 .67968 L
.84479 .68939 L
.84479 .69911 L
.84479 .70882 L
.84479 .71853 L
.84479 .71853 L
.85451 .72824 L
.85451 .73796 L
.85451 .74767 L
.85451 .74767 L
.86422 .75738 L
.86422 .76709 L
.86422 .77681 L
.86422 .78652 L
.86422 .78652 L
.87393 .79623 L
.87393 .80594 L
.87393 .81566 L
.87393 .82537 L
.87393 .82537 L
.88364 .83508 L
.88364 .84479 L
.88364 .85451 L
.88364 .85451 L
.89336 .86422 L
.89336 .87393 L
.89336 .88364 L
.88364 .89336 L
.87393 .89336 L
.86422 .89336 L
.85451 .88364 L
.85451 .88364 L
.84479 .88364 L
.83508 .88364 L
.82537 .87393 L
.82537 .87393 L
.81566 .87393 L
Mistroke
.80594 .87393 L
.79623 .87393 L
.78652 .86422 L
.78652 .86422 L
.77681 .86422 L
.76709 .86422 L
.75738 .85451 L
.75738 .85451 L
.74767 .85451 L
.73796 .85451 L
.72824 .84479 L
.72824 .84479 L
.71853 .84479 L
.70882 .84479 L
.69911 .84479 L
.68939 .83508 L
.68939 .83508 L
.67968 .83508 L
.66997 .83508 L
.66026 .82537 L
.66026 .82537 L
.65054 .82537 L
.64083 .82537 L
.63112 .82537 L
.62141 .81566 L
.62141 .81566 L
.61169 .81566 L
.60198 .81566 L
.59227 .80594 L
.59227 .80594 L
.58256 .80594 L
.57284 .80594 L
.56313 .79623 L
.56313 .79623 L
.55342 .79623 L
.54371 .79623 L
.53399 .79623 L
.52428 .78652 L
.52428 .78652 L
.51457 .78652 L
.50486 .78652 L
.49514 .77681 L
.49514 .77681 L
.48543 .77681 L
.47572 .77681 L
.46601 .77681 L
.45629 .76709 L
.45629 .76709 L
.44658 .76709 L
.43687 .76709 L
Mistroke
.42716 .75738 L
.42716 .75738 L
.41744 .75738 L
.40773 .75738 L
.39802 .74767 L
.39802 .74767 L
.38831 .74767 L
.37859 .74767 L
.36888 .74767 L
.35917 .73796 L
.35917 .73796 L
.34946 .73796 L
.33974 .73796 L
.33003 .72824 L
.33003 .72824 L
.32032 .72824 L
.31061 .72824 L
.30089 .72824 L
.29118 .71853 L
.29118 .71853 L
.28147 .71853 L
.27176 .71853 L
.26204 .70882 L
.26204 .70882 L
.25233 .70882 L
.24262 .70882 L
.23291 .69911 L
.23291 .69911 L
.22319 .69911 L
.21348 .69911 L
.20377 .69911 L
.19406 .68939 L
.19406 .68939 L
.18434 .68939 L
.17463 .68939 L
.16492 .67968 L
.16492 .67968 L
.15521 .67968 L
.14549 .67968 L
.13578 .67968 L
.12607 .66997 L
.12607 .66997 L
.11636 .66997 L
.10664 .66997 L
.09693 .66026 L
.09693 .66026 L
.08722 .66026 L
.07751 .66026 L
.06779 .65054 L
.06779 .65054 L
Mistroke
.05808 .65054 L
.04837 .64083 L
.04837 .63112 L
.05808 .62141 L
.05808 .62141 L
.05808 .61169 L
.05808 .60198 L
.06779 .59227 L
.06779 .59227 L
.06779 .58256 L
.06779 .57284 L
.07751 .56313 L
.07751 .56313 L
.07751 .55342 L
.07751 .54371 L
.08722 .53399 L
.08722 .53399 L
.08722 .52428 L
.08722 .51457 L
.09693 .50486 L
.09693 .50486 L
.09693 .49514 L
.09693 .48543 L
.10664 .47572 L
.10664 .47572 L
.10664 .46601 L
.10664 .45629 L
.11636 .44658 L
.11636 .44658 L
.11636 .43687 L
.12607 .42716 L
.12607 .42716 L
.12607 .41744 L
.12607 .40773 L
.13578 .39802 L
.13578 .39802 L
.13578 .38831 L
.14549 .37859 L
.14549 .37859 L
.14549 .36888 L
.14549 .35917 L
.15521 .34946 L
.15521 .34946 L
.15521 .33974 L
.16492 .33003 L
.16492 .33003 L
.16492 .32032 L
.17463 .31061 L
.17463 .31061 L
.17463 .30089 L
Mistroke
.17463 .29118 L
.18434 .28147 L
.18434 .28147 L
.18434 .27176 L
.19406 .26204 L
.19406 .26204 L
.19406 .25233 L
.20377 .24262 L
.20377 .24262 L
.20377 .23291 L
.21348 .22319 L
.21348 .22319 L
.21348 .21348 L
.22319 .20377 L
.22319 .20377 L
.23291 .19406 L
.23291 .19406 L
.23291 .18434 L
.24262 .17463 L
.24262 .17463 L
.24262 .16492 L
.25233 .15521 L
.25233 .15521 L
.26204 .14549 L
.26204 .14549 L
.26204 .13578 L
.27176 .12607 L
.27176 .12607 L
.28147 .11636 L
.28147 .11636 L
.29118 .10664 L
.29118 .10664 L
.30089 .09693 L
.30089 .09693 L
.30089 .08722 L
.31061 .07751 L
.31061 .07751 L
.32032 .06779 L
.33003 .06779 L
.33003 .06779 L
.33974 .05808 L
.33974 .05808 L
.34946 .04837 L
.34946 .04837 L
.35917 .03866 L
.36888 .03866 L
.36888 .03866 L
.37859 .02894 L
.38831 .02894 L
.38831 .02894 L
Mistroke
.39802 .01923 L
Mfstroke
.633 g
.40773 .07662 m
.41744 .07444 L
.42716 .07309 L
.43687 .0726 L
.44658 .07295 L
.45629 .07414 L
.46601 .07617 L
.47095 .07751 L
.47572 .07905 L
.48543 .08278 L
.4949 .08722 L
.49514 .08734 L
.50486 .09276 L
.51148 .09693 L
.51457 .09902 L
.52428 .10613 L
.52494 .10664 L
.53399 .1141 L
.53657 .11636 L
.54371 .12292 L
.54696 .12607 L
.55342 .1326 L
.55643 .13578 L
.56313 .14315 L
.56518 .14549 L
.57284 .15457 L
.57336 .15521 L
.58106 .16492 L
.58256 .16687 L
.58835 .17463 L
.59227 .18005 L
.5953 .18434 L
.60193 .19406 L
.60198 .19413 L
.6083 .20377 L
.61169 .20912 L
.61442 .21348 L
.62032 .22319 L
.62141 .22502 L
.62602 .23291 L
.63112 .24186 L
.63155 .24262 L
.6369 .25233 L
.64083 .25965 L
.6421 .26204 L
.64716 .27176 L
.65054 .27841 L
.65208 .28147 L
.65687 .29118 L
.66026 .29818 L
.66155 .30089 L
.66612 .31061 L
.66997 .31899 L
.67057 .32032 L
.67493 .33003 L
.67919 .33974 L
.67968 .34088 L
.68336 .34946 L
.68743 .35917 L
.68939 .36391 L
.69143 .36888 L
.69533 .37859 L
.69911 .38817 L
.69916 .38831 L
.70291 .39802 L
.70658 .40773 L
.70882 .41375 L
.71018 .41744 L
.7137 .42716 L
.71715 .43687 L
.71853 .44083 L
.72052 .44658 L
.72383 .45629 L
.72706 .46601 L
.72824 .46962 L
.73022 .47572 L
.73331 .48543 L
.73632 .49514 L
.73796 .50052 L
.73926 .50486 L
.74212 .51457 L
.74491 .52428 L
.74761 .53399 L
.74767 .53421 L
.75023 .54371 L
.75276 .55342 L
.7552 .56313 L
.75738 .57217 L
.75754 .57284 L
.75978 .58256 L
.7619 .59227 L
.76391 .60198 L
.76578 .61169 L
.76709 .61899 L
.76751 .62141 L
.76907 .63112 L
.77046 .64083 L
.77163 .65054 L
.77258 .66026 L
.77324 .66997 L
.77358 .67968 L
.77352 .68939 L
.77297 .69911 L
.77181 .70882 L
.76985 .71853 L
.76709 .72741 L
.76677 .72824 L
.76209 .73796 L
.75738 .74472 L
.7548 .74767 L
.74767 .75396 L
.74243 .75738 L
.73796 .75972 L
.72824 .76349 L
.71853 .76594 L
.71186 .76709 L
.70882 .76747 L
.69911 .76831 L
.68939 .76862 L
.67968 .7685 L
.66997 .76804 L
.66026 .7673 L
.65799 .76709 L
.65054 .76631 L
.64083 .76512 L
.63112 .76376 L
.62141 .76224 L
.61169 .76059 L
.60198 .75881 L
.59453 .75738 L
.59227 .75694 L
.58256 .75496 L
.57284 .7529 L
.56313 .75076 L
.55342 .74854 L
.54968 .74767 L
.54371 .74626 L
.53399 .74391 L
.52428 .74151 L
.51457 .73905 L
.51033 .73796 L
.50486 .73653 L
.49514 .73397 L
.48543 .73136 L
.47572 .7287 L
.47408 .72824 L
.46601 .72599 L
.45629 .72324 L
.44658 .72045 L
.44001 .71853 L
.43687 .71761 L
.42716 .71473 L
.41744 .7118 L
.40773 .70882 L
.40771 .70882 L
.39802 .7058 L
.38831 .70273 L
.37859 .69961 L
.37703 .69911 L
.36888 .69644 L
.35917 .69321 L
.34946 .68992 L
.34793 .68939 L
.33974 .68656 L
.33003 .68313 L
.32048 .67968 L
.32032 .67962 L
.31061 .67603 L
.30089 .67233 L
.29483 .66997 L
.29118 .66852 L
.28147 .66459 L
.27176 .66051 L
.27117 .66026 L
.26204 .65626 L
.25233 .6518 L
.24969 .65054 L
.24262 .64709 L
.23291 .64208 L
.23058 .64083 L
.22319 .6367 L
.21395 .63112 L
.21348 .63082 L
.20377 .6243 L
.19981 .62141 L
.19406 .61689 L
.18807 .61169 L
.18434 .60815 L
.17853 .60198 L
.17463 .59728 L
.17095 .59227 L
.16507 .58256 L
.16492 .58227 L
.16062 .57284 L
.15736 .56313 L
.15521 .55396 L
.15511 .55342 L
.15368 .54371 L
.15294 .53399 L
.15279 .52428 L
.15312 .51457 L
.15387 .50486 L
.15498 .49514 L
.15521 .49339 L
.1564 .48543 L
.15809 .47572 L
.16002 .46601 L
.16216 .45629 L
.1645 .44658 L
.16492 .44493 L
.16702 .43687 L
.1697 .42716 L
.17253 .41744 L
.17463 .41055 L
.17551 .40773 L
.17862 .39802 L
.18186 .38831 L
.18434 .3811 L
.18523 .37859 L
.18871 .36888 L
.19232 .35917 L
.19406 .3546 L
.19605 .34946 L
.19989 .33974 L
.20377 .33024 L
.20385 .33003 L
.20794 .32032 L
.21215 .31061 L
.21348 .30758 L
.21648 .30089 L
.22094 .29118 L
.22319 .28639 L
.22554 .28147 L
.23028 .27176 L
.23291 .2665 L
.23517 .26204 L
.24021 .25233 L
.24262 .2478 L
.24542 .24262 L
.2508 .23291 L
.25233 .23021 L
.25638 .22319 L
.26204 .21368 L
.26217 .21348 L
.26818 .20377 L
.27176 .19817 L
.27444 .19406 L
.28098 .18434 L
.28147 .18363 L
.28783 .17463 L
.29118 .17005 L
.29504 .16492 L
.30089 .1574 L
.30266 .15521 L
.31061 .14567 L
.31076 .14549 L
.31944 .13578 L
.32032 .13484 L
.32884 .12607 L
.33003 .1249 L
.33916 .11636 L
.33974 .11584 L
.34946 .10765 L
.35073 .10664 L
.35917 .10034 L
.36412 .09693 L
.36888 .09388 L
.37859 .08829 L
.38063 .08722 L
.38831 .08355 L
.39802 .07966 L
.40455 .07751 L
F
0 g
.40773 .07662 m
.41744 .07444 L
.42716 .07309 L
.43687 .0726 L
.44658 .07295 L
.45629 .07414 L
.46601 .07617 L
.47095 .07751 L
.47572 .07905 L
.48543 .08278 L
.4949 .08722 L
.49514 .08734 L
.50486 .09276 L
.51148 .09693 L
.51457 .09902 L
.52428 .10613 L
.52494 .10664 L
.53399 .1141 L
.53657 .11636 L
.54371 .12292 L
.54696 .12607 L
.55342 .1326 L
.55643 .13578 L
.56313 .14315 L
.56518 .14549 L
.57284 .15457 L
.57336 .15521 L
.58106 .16492 L
.58256 .16687 L
.58835 .17463 L
.59227 .18005 L
.5953 .18434 L
.60193 .19406 L
.60198 .19413 L
.6083 .20377 L
.61169 .20912 L
.61442 .21348 L
.62032 .22319 L
.62141 .22502 L
.62602 .23291 L
.63112 .24186 L
.63155 .24262 L
.6369 .25233 L
.64083 .25965 L
.6421 .26204 L
.64716 .27176 L
.65054 .27841 L
.65208 .28147 L
.65687 .29118 L
.66026 .29818 L
Mistroke
.66155 .30089 L
.66612 .31061 L
.66997 .31899 L
.67057 .32032 L
.67493 .33003 L
.67919 .33974 L
.67968 .34088 L
.68336 .34946 L
.68743 .35917 L
.68939 .36391 L
.69143 .36888 L
.69533 .37859 L
.69911 .38817 L
.69916 .38831 L
.70291 .39802 L
.70658 .40773 L
.70882 .41375 L
.71018 .41744 L
.7137 .42716 L
.71715 .43687 L
.71853 .44083 L
.72052 .44658 L
.72383 .45629 L
.72706 .46601 L
.72824 .46962 L
.73022 .47572 L
.73331 .48543 L
.73632 .49514 L
.73796 .50052 L
.73926 .50486 L
.74212 .51457 L
.74491 .52428 L
.74761 .53399 L
.74767 .53421 L
.75023 .54371 L
.75276 .55342 L
.7552 .56313 L
.75738 .57217 L
.75754 .57284 L
.75978 .58256 L
.7619 .59227 L
.76391 .60198 L
.76578 .61169 L
.76709 .61899 L
.76751 .62141 L
.76907 .63112 L
.77046 .64083 L
.77163 .65054 L
.77258 .66026 L
.77324 .66997 L
Mistroke
.77358 .67968 L
.77352 .68939 L
.77297 .69911 L
.77181 .70882 L
.76985 .71853 L
.76709 .72741 L
.76677 .72824 L
.76209 .73796 L
.75738 .74472 L
.7548 .74767 L
.74767 .75396 L
.74243 .75738 L
.73796 .75972 L
.72824 .76349 L
.71853 .76594 L
.71186 .76709 L
.70882 .76747 L
.69911 .76831 L
.68939 .76862 L
.67968 .7685 L
.66997 .76804 L
.66026 .7673 L
.65799 .76709 L
.65054 .76631 L
.64083 .76512 L
.63112 .76376 L
.62141 .76224 L
.61169 .76059 L
.60198 .75881 L
.59453 .75738 L
.59227 .75694 L
.58256 .75496 L
.57284 .7529 L
.56313 .75076 L
.55342 .74854 L
.54968 .74767 L
.54371 .74626 L
.53399 .74391 L
.52428 .74151 L
.51457 .73905 L
.51033 .73796 L
.50486 .73653 L
.49514 .73397 L
.48543 .73136 L
.47572 .7287 L
.47408 .72824 L
.46601 .72599 L
.45629 .72324 L
.44658 .72045 L
.44001 .71853 L
Mistroke
.43687 .71761 L
.42716 .71473 L
.41744 .7118 L
.40773 .70882 L
.40771 .70882 L
.39802 .7058 L
.38831 .70273 L
.37859 .69961 L
.37703 .69911 L
.36888 .69644 L
.35917 .69321 L
.34946 .68992 L
.34793 .68939 L
.33974 .68656 L
.33003 .68313 L
.32048 .67968 L
.32032 .67962 L
.31061 .67603 L
.30089 .67233 L
.29483 .66997 L
.29118 .66852 L
.28147 .66459 L
.27176 .66051 L
.27117 .66026 L
.26204 .65626 L
.25233 .6518 L
.24969 .65054 L
.24262 .64709 L
.23291 .64208 L
.23058 .64083 L
.22319 .6367 L
.21395 .63112 L
.21348 .63082 L
.20377 .6243 L
.19981 .62141 L
.19406 .61689 L
.18807 .61169 L
.18434 .60815 L
.17853 .60198 L
.17463 .59728 L
.17095 .59227 L
.16507 .58256 L
.16492 .58227 L
.16062 .57284 L
.15736 .56313 L
.15521 .55396 L
.15511 .55342 L
.15368 .54371 L
.15294 .53399 L
.15279 .52428 L
Mistroke
.15312 .51457 L
.15387 .50486 L
.15498 .49514 L
.15521 .49339 L
.1564 .48543 L
.15809 .47572 L
.16002 .46601 L
.16216 .45629 L
.1645 .44658 L
.16492 .44493 L
.16702 .43687 L
.1697 .42716 L
.17253 .41744 L
.17463 .41055 L
.17551 .40773 L
.17862 .39802 L
.18186 .38831 L
.18434 .3811 L
.18523 .37859 L
.18871 .36888 L
.19232 .35917 L
.19406 .3546 L
.19605 .34946 L
.19989 .33974 L
.20377 .33024 L
.20385 .33003 L
.20794 .32032 L
.21215 .31061 L
.21348 .30758 L
.21648 .30089 L
.22094 .29118 L
.22319 .28639 L
.22554 .28147 L
.23028 .27176 L
.23291 .2665 L
.23517 .26204 L
.24021 .25233 L
.24262 .2478 L
.24542 .24262 L
.2508 .23291 L
.25233 .23021 L
.25638 .22319 L
.26204 .21368 L
.26217 .21348 L
.26818 .20377 L
.27176 .19817 L
.27444 .19406 L
.28098 .18434 L
.28147 .18363 L
.28783 .17463 L
Mistroke
.29118 .17005 L
.29504 .16492 L
.30089 .1574 L
.30266 .15521 L
.31061 .14567 L
.31076 .14549 L
.31944 .13578 L
.32032 .13484 L
.32884 .12607 L
.33003 .1249 L
.33916 .11636 L
.33974 .11584 L
.34946 .10765 L
.35073 .10664 L
.35917 .10034 L
.36412 .09693 L
.36888 .09388 L
.37859 .08829 L
.38063 .08722 L
.38831 .08355 L
.39802 .07966 L
.40455 .07751 L
.40773 .07662 L
Mfstroke
.397 g
.42716 .13426 m
.43687 .13363 L
.44658 .13393 L
.45629 .13514 L
.45998 .13578 L
.46601 .13727 L
.47572 .14033 L
.48543 .1443 L
.488 .14549 L
.49514 .14919 L
.50486 .15502 L
.50514 .15521 L
.51457 .16178 L
.51868 .16492 L
.52428 .16949 L
.53018 .17463 L
.53399 .17815 L
.54036 .18434 L
.54371 .18777 L
.54957 .19406 L
.55342 .19838 L
.55803 .20377 L
.56313 .20999 L
.5659 .21348 L
.57284 .22262 L
.57326 .22319 L
.58021 .23291 L
.58256 .23631 L
.5868 .24262 L
.59227 .25108 L
.59306 .25233 L
.59904 .26204 L
.60198 .26698 L
.60477 .27176 L
.61026 .28147 L
.61169 .28406 L
.61555 .29118 L
.62063 .30089 L
.62141 .3024 L
.62554 .31061 L
.63027 .32032 L
.63112 .32209 L
.63485 .33003 L
.63927 .33974 L
.64083 .34325 L
.64355 .34946 L
.64769 .35917 L
.65054 .36607 L
.65169 .36888 L
.65556 .37859 L
.65931 .38831 L
.66026 .39082 L
.66293 .39802 L
.66643 .40773 L
.6698 .41744 L
.66997 .41794 L
.67306 .42716 L
.67619 .43687 L
.6792 .44658 L
.67968 .44818 L
.68208 .45629 L
.68484 .46601 L
.68746 .47572 L
.68939 .48321 L
.68995 .48543 L
.6923 .49514 L
.69449 .50486 L
.69653 .51457 L
.69841 .52428 L
.69911 .52815 L
.7001 .53399 L
.7016 .54371 L
.70288 .55342 L
.70393 .56313 L
.70472 .57284 L
.70521 .58256 L
.70537 .59227 L
.70514 .60198 L
.70445 .61169 L
.70321 .62141 L
.70131 .63112 L
.69911 .63917 L
.69856 .64083 L
.69473 .65054 L
.68939 .66024 L
.68939 .66026 L
.68185 .66997 L
.67968 .6722 L
.67067 .67968 L
.66997 .68016 L
.66026 .68579 L
.65179 .68939 L
.65054 .68984 L
.64083 .69277 L
.63112 .69483 L
.62141 .69621 L
.61169 .69704 L
.60198 .69742 L
.59227 .69741 L
.58256 .69706 L
.57284 .69643 L
.56313 .69555 L
.55342 .69444 L
.54371 .69312 L
.53399 .69163 L
.52428 .68996 L
.52119 .68939 L
.51457 .68813 L
.50486 .68616 L
.49514 .68405 L
.48543 .68181 L
.4767 .67968 L
.47572 .67944 L
.46601 .67695 L
.45629 .67433 L
.44658 .6716 L
.44096 .66997 L
.43687 .66876 L
.42716 .66579 L
.41744 .6627 L
.41003 .66026 L
.40773 .65948 L
.39802 .65614 L
.38831 .65266 L
.3826 .65054 L
.37859 .64903 L
.36888 .64524 L
.35917 .64129 L
.35808 .64083 L
.34946 .63714 L
.33974 .63279 L
.33615 .63112 L
.33003 .62819 L
.32032 .62333 L
.31664 .62141 L
.31061 .61815 L
.30089 .61259 L
.29939 .61169 L
.29118 .60658 L
.28429 .60198 L
.28147 .60001 L
.27176 .59273 L
.27118 .59227 L
.26204 .58451 L
.25992 .58256 L
.25233 .57499 L
.25035 .57284 L
.24262 .56354 L
.24231 .56313 L
.23562 .55342 L
.23291 .54888 L
.23013 .54371 L
.22571 .53399 L
.22319 .52727 L
.22222 .52428 L
.21954 .51457 L
.21759 .50486 L
.21627 .49514 L
.21551 .48543 L
.21525 .47572 L
.21543 .46601 L
.21601 .45629 L
.21695 .44658 L
.21822 .43687 L
.21979 .42716 L
.22163 .41744 L
.22319 .4101 L
.22373 .40773 L
.22608 .39802 L
.22865 .38831 L
.23144 .37859 L
.23291 .37377 L
.23444 .36888 L
.23765 .35917 L
.24106 .34946 L
.24262 .3452 L
.24467 .33974 L
.24848 .33003 L
.25233 .32069 L
.25249 .32032 L
.2567 .31061 L
.26113 .30089 L
.26204 .29895 L
.26577 .29118 L
.27065 .28147 L
.27176 .27932 L
.27576 .27176 L
.28114 .26204 L
.28147 .26146 L
.28679 .25233 L
.29118 .24513 L
.29275 .24262 L
.29905 .23291 L
.30089 .23017 L
.30574 .22319 L
.31061 .21649 L
.31286 .21348 L
.32032 .20399 L
.3205 .20377 L
.32875 .19406 L
.33003 .19262 L
.33775 .18434 L
.33974 .18232 L
.34774 .17463 L
.34946 .17308 L
.35908 .16492 L
.35917 .16484 L
.36888 .15761 L
.37242 .15521 L
.37859 .15135 L
.38831 .14605 L
.38942 .14549 L
.39802 .1417 L
.40773 .13829 L
.41744 .13581 L
.41751 .13578 L
F
0 g
.42716 .13426 m
.43687 .13363 L
.44658 .13393 L
.45629 .13514 L
.45998 .13578 L
.46601 .13727 L
.47572 .14033 L
.48543 .1443 L
.488 .14549 L
.49514 .14919 L
.50486 .15502 L
.50514 .15521 L
.51457 .16178 L
.51868 .16492 L
.52428 .16949 L
.53018 .17463 L
.53399 .17815 L
.54036 .18434 L
.54371 .18777 L
.54957 .19406 L
.55342 .19838 L
.55803 .20377 L
.56313 .20999 L
.5659 .21348 L
.57284 .22262 L
.57326 .22319 L
.58021 .23291 L
.58256 .23631 L
.5868 .24262 L
.59227 .25108 L
.59306 .25233 L
.59904 .26204 L
.60198 .26698 L
.60477 .27176 L
.61026 .28147 L
.61169 .28406 L
.61555 .29118 L
.62063 .30089 L
.62141 .3024 L
.62554 .31061 L
.63027 .32032 L
.63112 .32209 L
.63485 .33003 L
.63927 .33974 L
.64083 .34325 L
.64355 .34946 L
.64769 .35917 L
.65054 .36607 L
.65169 .36888 L
.65556 .37859 L
Mistroke
.65931 .38831 L
.66026 .39082 L
.66293 .39802 L
.66643 .40773 L
.6698 .41744 L
.66997 .41794 L
.67306 .42716 L
.67619 .43687 L
.6792 .44658 L
.67968 .44818 L
.68208 .45629 L
.68484 .46601 L
.68746 .47572 L
.68939 .48321 L
.68995 .48543 L
.6923 .49514 L
.69449 .50486 L
.69653 .51457 L
.69841 .52428 L
.69911 .52815 L
.7001 .53399 L
.7016 .54371 L
.70288 .55342 L
.70393 .56313 L
.70472 .57284 L
.70521 .58256 L
.70537 .59227 L
.70514 .60198 L
.70445 .61169 L
.70321 .62141 L
.70131 .63112 L
.69911 .63917 L
.69856 .64083 L
.69473 .65054 L
.68939 .66024 L
.68939 .66026 L
.68185 .66997 L
.67968 .6722 L
.67067 .67968 L
.66997 .68016 L
.66026 .68579 L
.65179 .68939 L
.65054 .68984 L
.64083 .69277 L
.63112 .69483 L
.62141 .69621 L
.61169 .69704 L
.60198 .69742 L
.59227 .69741 L
.58256 .69706 L
Mistroke
.57284 .69643 L
.56313 .69555 L
.55342 .69444 L
.54371 .69312 L
.53399 .69163 L
.52428 .68996 L
.52119 .68939 L
.51457 .68813 L
.50486 .68616 L
.49514 .68405 L
.48543 .68181 L
.4767 .67968 L
.47572 .67944 L
.46601 .67695 L
.45629 .67433 L
.44658 .6716 L
.44096 .66997 L
.43687 .66876 L
.42716 .66579 L
.41744 .6627 L
.41003 .66026 L
.40773 .65948 L
.39802 .65614 L
.38831 .65266 L
.3826 .65054 L
.37859 .64903 L
.36888 .64524 L
.35917 .64129 L
.35808 .64083 L
.34946 .63714 L
.33974 .63279 L
.33615 .63112 L
.33003 .62819 L
.32032 .62333 L
.31664 .62141 L
.31061 .61815 L
.30089 .61259 L
.29939 .61169 L
.29118 .60658 L
.28429 .60198 L
.28147 .60001 L
.27176 .59273 L
.27118 .59227 L
.26204 .58451 L
.25992 .58256 L
.25233 .57499 L
.25035 .57284 L
.24262 .56354 L
.24231 .56313 L
.23562 .55342 L
Mistroke
.23291 .54888 L
.23013 .54371 L
.22571 .53399 L
.22319 .52727 L
.22222 .52428 L
.21954 .51457 L
.21759 .50486 L
.21627 .49514 L
.21551 .48543 L
.21525 .47572 L
.21543 .46601 L
.21601 .45629 L
.21695 .44658 L
.21822 .43687 L
.21979 .42716 L
.22163 .41744 L
.22319 .4101 L
.22373 .40773 L
.22608 .39802 L
.22865 .38831 L
.23144 .37859 L
.23291 .37377 L
.23444 .36888 L
.23765 .35917 L
.24106 .34946 L
.24262 .3452 L
.24467 .33974 L
.24848 .33003 L
.25233 .32069 L
.25249 .32032 L
.2567 .31061 L
.26113 .30089 L
.26204 .29895 L
.26577 .29118 L
.27065 .28147 L
.27176 .27932 L
.27576 .27176 L
.28114 .26204 L
.28147 .26146 L
.28679 .25233 L
.29118 .24513 L
.29275 .24262 L
.29905 .23291 L
.30089 .23017 L
.30574 .22319 L
.31061 .21649 L
.31286 .21348 L
.32032 .20399 L
.3205 .20377 L
.32875 .19406 L
Mistroke
.33003 .19262 L
.33775 .18434 L
.33974 .18232 L
.34774 .17463 L
.34946 .17308 L
.35908 .16492 L
.35917 .16484 L
.36888 .15761 L
.37242 .15521 L
.37859 .15135 L
.38831 .14605 L
.38942 .14549 L
.39802 .1417 L
.40773 .13829 L
.41744 .13581 L
.41751 .13578 L
.42716 .13426 L
Mfstroke
.161 g
.41744 .21158 m
.42716 .20955 L
.43687 .2086 L
.44658 .20874 L
.45629 .20996 L
.46601 .21225 L
.47006 .21348 L
.47572 .21562 L
.48543 .22007 L
.49116 .22319 L
.49514 .22562 L
.50486 .23229 L
.50568 .23291 L
.51457 .2401 L
.51743 .24262 L
.52428 .24908 L
.52751 .25233 L
.53399 .25927 L
.53645 .26204 L
.54371 .27074 L
.54452 .27176 L
.55191 .28147 L
.55342 .28355 L
.55874 .29118 L
.56313 .29781 L
.56511 .30089 L
.57106 .31061 L
.57284 .31365 L
.57665 .32032 L
.58191 .33003 L
.58256 .33126 L
.58688 .33974 L
.59157 .34946 L
.59227 .35094 L
.59601 .35917 L
.6002 .36888 L
.60198 .37318 L
.60416 .37859 L
.60789 .38831 L
.6114 .39802 L
.61169 .39886 L
.61469 .40773 L
.61777 .41744 L
.62062 .42716 L
.62141 .42996 L
.62325 .43687 L
.62566 .44658 L
.62782 .45629 L
.62973 .46601 L
.63112 .47405 L
.63138 .47572 L
.63274 .48543 L
.6338 .49514 L
.63452 .50486 L
.63486 .51457 L
.63478 .52428 L
.63422 .53399 L
.63308 .54371 L
.63127 .55342 L
.63112 .55411 L
.62864 .56313 L
.62496 .57284 L
.62141 .57997 L
.61989 .58256 L
.61287 .59227 L
.61169 .59362 L
.60282 .60198 L
.60198 .60264 L
.59227 .60902 L
.58703 .61169 L
.58256 .61364 L
.57284 .61698 L
.56313 .61934 L
.55342 .62092 L
.54991 .62141 L
.54371 .62185 L
.53399 .62223 L
.52428 .62214 L
.51457 .62163 L
.51141 .62141 L
.50486 .62074 L
.49514 .61951 L
.48543 .61796 L
.47572 .61612 L
.46601 .61398 L
.45677 .61169 L
.45629 .61157 L
.44658 .60888 L
.43687 .60592 L
.42716 .60267 L
.42518 .60198 L
.41744 .59914 L
.40773 .5953 L
.4006 .59227 L
.39802 .59113 L
.38831 .58659 L
.38029 .58256 L
.37859 .58166 L
.36888 .57627 L
.36314 .57284 L
.35917 .57036 L
.34946 .5638 L
.34852 .56313 L
.33974 .55648 L
.33602 .55342 L
.33003 .54815 L
.32536 .54371 L
.32032 .5385 L
.3163 .53399 L
.31061 .52694 L
.30864 .52428 L
.30222 .51457 L
.30089 .51231 L
.29691 .50486 L
.29257 .49514 L
.29118 .49155 L
.2891 .48543 L
.28641 .47572 L
.28443 .46601 L
.28308 .45629 L
.28231 .44658 L
.28207 .43687 L
.28231 .42716 L
.28301 .41744 L
.28412 .40773 L
.28564 .39802 L
.28753 .38831 L
.28979 .37859 L
.29118 .37322 L
.29239 .36888 L
.29535 .35917 L
.29866 .34946 L
.30089 .3434 L
.30231 .33974 L
.30633 .33003 L
.31061 .32055 L
.31071 .32032 L
.31549 .31061 L
.32032 .30158 L
.3207 .30089 L
.32637 .29118 L
.33003 .28534 L
.33257 .28147 L
.33937 .27176 L
.33974 .27125 L
.34689 .26204 L
.34946 .25896 L
.35531 .25233 L
.35917 .24827 L
.36492 .24262 L
.36888 .23902 L
.37623 .23291 L
.37859 .2311 L
.38831 .22445 L
.39036 .22319 L
.39802 .21901 L
.40773 .21473 L
.41104 .21348 L
F
0 g
.41744 .21158 m
.42716 .20955 L
.43687 .2086 L
.44658 .20874 L
.45629 .20996 L
.46601 .21225 L
.47006 .21348 L
.47572 .21562 L
.48543 .22007 L
.49116 .22319 L
.49514 .22562 L
.50486 .23229 L
.50568 .23291 L
.51457 .2401 L
.51743 .24262 L
.52428 .24908 L
.52751 .25233 L
.53399 .25927 L
.53645 .26204 L
.54371 .27074 L
.54452 .27176 L
.55191 .28147 L
.55342 .28355 L
.55874 .29118 L
.56313 .29781 L
.56511 .30089 L
.57106 .31061 L
.57284 .31365 L
.57665 .32032 L
.58191 .33003 L
.58256 .33126 L
.58688 .33974 L
.59157 .34946 L
.59227 .35094 L
.59601 .35917 L
.6002 .36888 L
.60198 .37318 L
.60416 .37859 L
.60789 .38831 L
.6114 .39802 L
.61169 .39886 L
.61469 .40773 L
.61777 .41744 L
.62062 .42716 L
.62141 .42996 L
.62325 .43687 L
.62566 .44658 L
.62782 .45629 L
.62973 .46601 L
.63112 .47405 L
Mistroke
.63138 .47572 L
.63274 .48543 L
.6338 .49514 L
.63452 .50486 L
.63486 .51457 L
.63478 .52428 L
.63422 .53399 L
.63308 .54371 L
.63127 .55342 L
.63112 .55411 L
.62864 .56313 L
.62496 .57284 L
.62141 .57997 L
.61989 .58256 L
.61287 .59227 L
.61169 .59362 L
.60282 .60198 L
.60198 .60264 L
.59227 .60902 L
.58703 .61169 L
.58256 .61364 L
.57284 .61698 L
.56313 .61934 L
.55342 .62092 L
.54991 .62141 L
.54371 .62185 L
.53399 .62223 L
.52428 .62214 L
.51457 .62163 L
.51141 .62141 L
.50486 .62074 L
.49514 .61951 L
.48543 .61796 L
.47572 .61612 L
.46601 .61398 L
.45677 .61169 L
.45629 .61157 L
.44658 .60888 L
.43687 .60592 L
.42716 .60267 L
.42518 .60198 L
.41744 .59914 L
.40773 .5953 L
.4006 .59227 L
.39802 .59113 L
.38831 .58659 L
.38029 .58256 L
.37859 .58166 L
.36888 .57627 L
.36314 .57284 L
Mistroke
.35917 .57036 L
.34946 .5638 L
.34852 .56313 L
.33974 .55648 L
.33602 .55342 L
.33003 .54815 L
.32536 .54371 L
.32032 .5385 L
.3163 .53399 L
.31061 .52694 L
.30864 .52428 L
.30222 .51457 L
.30089 .51231 L
.29691 .50486 L
.29257 .49514 L
.29118 .49155 L
.2891 .48543 L
.28641 .47572 L
.28443 .46601 L
.28308 .45629 L
.28231 .44658 L
.28207 .43687 L
.28231 .42716 L
.28301 .41744 L
.28412 .40773 L
.28564 .39802 L
.28753 .38831 L
.28979 .37859 L
.29118 .37322 L
.29239 .36888 L
.29535 .35917 L
.29866 .34946 L
.30089 .3434 L
.30231 .33974 L
.30633 .33003 L
.31061 .32055 L
.31071 .32032 L
.31549 .31061 L
.32032 .30158 L
.3207 .30089 L
.32637 .29118 L
.33003 .28534 L
.33257 .28147 L
.33937 .27176 L
.33974 .27125 L
.34689 .26204 L
.34946 .25896 L
.35531 .25233 L
.35917 .24827 L
.36492 .24262 L
Mistroke
.36888 .23902 L
.37623 .23291 L
.37859 .2311 L
.38831 .22445 L
.39036 .22319 L
.39802 .21901 L
.40773 .21473 L
.41104 .21348 L
.41744 .21158 L
Mfstroke
.42716 .32878 m
.43687 .32586 L
.44658 .32494 L
.45629 .32589 L
.46601 .3287 L
.46942 .33003 L
.47572 .33339 L
.48503 .33974 L
.48543 .34007 L
.49514 .34895 L
.49563 .34946 L
.50392 .35917 L
.50486 .36042 L
.51072 .36888 L
.51457 .37526 L
.51642 .37859 L
.52124 .38831 L
.52428 .39543 L
.52528 .39802 L
.52862 .40773 L
.53127 .41744 L
.53323 .42716 L
.53399 .43236 L
.53448 .43687 L
.53496 .44658 L
.53454 .45629 L
.53399 .46088 L
.53308 .46601 L
.53028 .47572 L
.52562 .48543 L
.52428 .48755 L
.51806 .49514 L
.51457 .49827 L
.50486 .50445 L
.50408 .50486 L
.49514 .50806 L
.48543 .50987 L
.47572 .51028 L
.46601 .5095 L
.45629 .50764 L
.44693 .50486 L
.44658 .50472 L
.43687 .50073 L
.42716 .49554 L
.4265 .49514 L
.41744 .48895 L
.41308 .48543 L
.40773 .48053 L
.40316 .47572 L
.39802 .46941 L
.3956 .46601 L
.38981 .45629 L
.38831 .45328 L
.38549 .44658 L
.38241 .43687 L
.38044 .42716 L
.37947 .41744 L
.37946 .40773 L
.38036 .39802 L
.38219 .38831 L
.38498 .37859 L
.38831 .37004 L
.38883 .36888 L
.39392 .35917 L
.39802 .35294 L
.40063 .34946 L
.40773 .34168 L
.40978 .33974 L
.41744 .33391 L
.42415 .33003 L
F
.42716 .32878 m
.43687 .32586 L
.44658 .32494 L
.45629 .32589 L
.46601 .3287 L
.46942 .33003 L
.47572 .33339 L
.48503 .33974 L
.48543 .34007 L
.49514 .34895 L
.49563 .34946 L
.50392 .35917 L
.50486 .36042 L
.51072 .36888 L
.51457 .37526 L
.51642 .37859 L
.52124 .38831 L
.52428 .39543 L
.52528 .39802 L
.52862 .40773 L
.53127 .41744 L
.53323 .42716 L
.53399 .43236 L
.53448 .43687 L
.53496 .44658 L
.53454 .45629 L
.53399 .46088 L
.53308 .46601 L
.53028 .47572 L
.52562 .48543 L
.52428 .48755 L
.51806 .49514 L
.51457 .49827 L
.50486 .50445 L
.50408 .50486 L
.49514 .50806 L
.48543 .50987 L
.47572 .51028 L
.46601 .5095 L
.45629 .50764 L
.44693 .50486 L
.44658 .50472 L
.43687 .50073 L
.42716 .49554 L
.4265 .49514 L
.41744 .48895 L
.41308 .48543 L
.40773 .48053 L
.40316 .47572 L
.39802 .46941 L
Mistroke
.3956 .46601 L
.38981 .45629 L
.38831 .45328 L
.38549 .44658 L
.38241 .43687 L
.38044 .42716 L
.37947 .41744 L
.37946 .40773 L
.38036 .39802 L
.38219 .38831 L
.38498 .37859 L
.38831 .37004 L
.38883 .36888 L
.39392 .35917 L
.39802 .35294 L
.40063 .34946 L
.40773 .34168 L
.40978 .33974 L
.41744 .33391 L
.42415 .33003 L
.42716 .32878 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00a_ooool2o`0000;ooooo0_l0002Looooo`00a_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMgIcooooo0037ooooo`04omgMgOl0003o410@olc<c9gooooo0037ooooo`04
onk^k_lQ8B7o410@onk^kYgooooo0037ooooo`04ob4Q8OmgMgOoMgMgoc8b<Ygooooo0036ooooo`;o
00000_ooool2o`0009cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000cooooo`Co000000?o410@ooooooooool0<_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0<?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Gooooo1?l000000ol@413ooooooooo
o`0Zooooo`00=Oooool00ol0003oooooooooo`0dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0;oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0fooooo`03
o`000?oooooooooo02cooooo000Zooooo`Ko00001Oooool00ol0003oooooooooo`0/ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0;_ooool01Ol@413o
oooooooooooooooo410@03Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0;?ooool003Gooooo00?o0000ooooooooool0=?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0;oooool01Ol0003ooooooooooooo
oooo000003Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Kooooo
00?o0000ooooooooool0;?ooool003Gooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00`ooooo`05o`000?oooooooooooooo
ool00000=Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00gooooo`03o`000?oooooooooo02cooooo000eooooo`03o`000?oooooooooo03Cooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo03;ooooo00Go410@oooooooooooooooo
oa0@400eooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02cooooo000eooooo`03o`000?oooooooooo03Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo03;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02cooooo000cooooo`03oeEEEOmVIVKo000003Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co0000=_ooool00omEEEGoIVIVo`00000^ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:oooooooo`0003go00000Ooo
ool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00?ooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00
8?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooliooooo`7o
00000Oooool0023ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
oooo>Oooool1o`00007ooooo000Pooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0007[o
oooo6_l0002Rooooo`?o00000Oooool0023ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00?oooooMooNg]h00ol0003oooooooooo`0Fooooo`03o`000?oNg]kog]kN09co
g]kN1_ooool1o`00007ooooo000Pooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`03ooooogKog]kN00?o0000ooooooooool06?ooool00ol0003og]kNomkNgP2KomkNgPKo
oooo0Ol00001ooooo`008?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool00ooooomeomkNgP03o`000?oooooooooo01[ooooo0_l0002KomkNgPKooooo0Ol00001ooooo`00
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00ooooomaomkNgPCo
00007_ooool7o`0009Gog]kN1_ooool1o`00007ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`03ooooog3og]kN00?o0000ooooooooool09oooool00ol0003o
g]kNomkNgP2BomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooofkog]kN
0_l0000[ooooo`;o0000T_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom[omkNgPCo0000;Oooool00ol0003og]kNomkNgP2@omkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03ooooof[og]kN00?o0000ooooooooool0<?ooool00ol0003og]kNomkNgP2?
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooofSog]kN0_l0000doooo
o`;o0000SooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomXomkNgP03
o`000?oooooooooo03Cooooo00?o0000omkNg_oNg]h0SOoNg]h6ooooo`7o00000Oooool002_ooooo
00?o0000ooooooooool00ooooomWomkNgP03o`000?oooooooooo03Kooooo00?o0000omkNg_oNg]h0
S?oNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooofKog]kN00?o0000ooooooooool0>?oo
ool00ol0003og]kNomkNgP2;omkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03
ooooofGog]kN00?o0000ooooooooool0>_ooool4o`0008Wog]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooI?oNg]h00ol0003oooooooooo`0oooooo`03o`000?oNg]kog]kN
08Kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooHooNg]h00ol0003o
ooooooooo`11ooooo`03o`000?oNg]kog]kN08Gog]kN1_ooool1o`00007ooooo000[ooooo`03o`00
0?oooooooooo00?oooooGooNg]h4o`0004Gooooo0_l00025omkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03oooooekog]kN00?o0000ooooooooool07oooool:o`00023ooooo00?o
0000omkNg_oNg]h0P_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomM
omkNgP03o`000?oooooooooo01gooooo0ol0000:oj:RXPCo00007Oooool00ol0003og]kNomkNgP21
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooecog]kN00?o0000oooo
ooooool06_ooool4o`00017oXZ:R1Ol0000Iooooo`03o`000?oNg]kog]kN083og]kN1_ooool1o`00
007ooooo000[ooooo`03o`000?oooooooooo00?oooooFooNg]h00ol0003oooooooooo`0Hooooo`?o
00006_nRXZ82o`0001Sooooo00?o0000omkNg_oNg]h0OooNg]h6ooooo`7o00000Oooool002_ooooo
00?o0000ooooooooool00ooooomJomkNgP03o`000?oooooooooo01Kooooo0ol0000Ooj:RXP03o`00
0?oooooooooo01Kooooo00?o0000omkNg_oNg]h0O_oNg]h6ooooo`7o00000Oooool002_ooooo00?o
0000ooooooooool00ooooomIomkNgP03o`000?oooooooooo01Cooooo0ol0000Soj:RXP;o00005ooo
ool00ol0003og]kNomkNgP1momkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooeWog]kN00?o0000ooooooooool04oooool00ol0003oXZ:Roj:RXP0Voj:RXP03o`000?oooooo
oooo01Cooooo00?o0000omkNg_oNg]h0OOoNg]h6ooooo`7o00000Oooool002_ooooo0_l00004oooo
oeWog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Xoj:RXP;o00005?ooool00ol0
003og]kNomkNgP1momkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03oooooeWo
g]kN00?o0000ooooooooool04?ooool2o`0002goXZ:R00?o0000ooooooooool04Oooool00ol0003o
g]kNomkNgP1momkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeSog]kN
00?o0000ooooooooool04?ooool00ol0003oXZ:Roj:RXP0^oj:RXP;o00004_ooool00ol0003og]kN
omkNgP1lomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeOog]kN00?o
0000ooooooooool04?ooool00ol0003oXZ:Roj:RXP0aoj:RXP03o`000?oooooooooo013ooooo00?o
0000omkNg_oNg]h0NooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomF
omkNgP03o`000?oooooooooo00oooooo0_l0000eoj:RXP;o00004Oooool00ol0003og]kNomkNgP1j
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooeGog]kN00?o0000oooo
ooooool03oooool00ol0003oXZ:Roj:RXP0goj:RXP03o`000?oooooooooo00oooooo00?o0000omkN
g_oNg]h0NOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooomDomkNgP03
o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ80>OnRXZ800ol0003oooooooooo`0?ooooo`03
o`000?oNg]kog]kN07Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
DooNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R03_oXZ:R00?o0000ooooooooool0
3oooool00ol0003og]kNomkNgP1gomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooe;og]kN00?o0000ooooooooool03oooool00ol0003oXZ:Roj:RXP0moj:RXP03o`000?oo
oooooooo00oooooo00?o0000omkNg_oNg]h0M_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000
ooooooooool00ooooomAomkNgP03o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ80?onRXZ80
0ol0003oooooooooo`0?ooooo`03o`000?oNg]kog]kN07Gog]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooD?oNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R
047oXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP1domkNgPKooooo0Ol00001oooo
o`00:oooool2o`0000CoooooCooNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R04?o
XZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP1comkNgPGooooo0_l00001ooooo`00
:oooool00ol0003oooooooooo`03ooooodkog]kN00?o0000ooooooooool03oooool00ol0003oXZ:R
oj:RXP15oj:RXP03o`000?oooooooooo00oooooo00?o0000omkNg_oNg]h0L_oNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooom=omkNgP03o`000?oooooooooo00oooooo00?o
0000oj:RX_nRXZ806onRXZ8@o`0001coXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkN
gP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodgog]kN00?o0000
ooooooooool03_ooool00ol0003oXZ:Roj:RXP0Hoj:RXPCo00004?mUIFD3o`0001[oXZ:R00?o0000
ooooooooool03_ooool00ol0003og]kNomkNgP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooodgog]kN00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0Foj:R
XP?o00005omUIFD3o`0001SoXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1aomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodgog]kN00?o0000oooooooo
ool03?ooool00ol0003oXZ:Roj:RXP0Doj:RXP?o00007OmUIFD3o`0001KoXZ:R00?o0000oooooooo
ool03?ooool00ol0003og]kNomkNgP1aomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooodcog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0Doj:RXP03o`00
0?mUIFGoIFEU027oIFEU0_l0000Eoj:RXP03o`000?oooooooooo00cooooo00?o0000omkNg_oNg]h0
L?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom;omkNgP03o`000?oo
oooooooo00cooooo00?o0000oj:RX_nRXZ804onRXZ82o`0002KoIFEU00?o0000oj:RX_nRXZ804onR
XZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]kog]kN06oog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?oooooBOoNg]h2o`0000kooooo00?o0000oj:RX_nRXZ804onRXZ80
0ol0003oIFEUofEUI@0WofEUI@;o00005?nRXZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]ko
g]kN06kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooB?oNg]h00ol0
003oooooooooo`0>ooooo`03o`000?nRXZ;oXZ:R017oXZ:R0_l0000/ofEUI@03o`000?nRXZ;oXZ:R
017oXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1]omkNgPKooooo0Ol00001oooo
o`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0
003oooooooooo`03ooooodOog]kN00?o0000ooooooooool03_ooool00ol0003oXZ:Roj:RXP0Aoj:R
XP03o`000?mUIFGoIFEU02goIFEU0_l0000Boj:RXP03o`000?oooooooooo00gooooo00?o0000omkN
g_oNg]h0K?oNg]h6ooooo`7o00000Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00ooooom6
omkNgP03o`000?oooooooooo00kooooo00?o0000oj:RX_nRXZ804OnRXZ800ol0003oIFEUofEUI@0`
ofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP1[
omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01oooool3o`0000?oooooA_oNg]h00ol0003oooooooooo`0>ooooo`03o`000?nRXZ;o
XZ:R013oXZ:R00?o0000ofEUIOmUIFD0<OmUIFD00ol0003oXZ:Roj:RXP0Aoj:RXP03o`000?oooooo
oooo00cooooo00?o0000omkNg_oNg]h0JooNg]h4ooooo`?o00000Oooool0013ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00ooooom6
omkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0c
ofEUI@;o00004OnRXZ800ol0003oooooooooo`0<ooooo`03o`000?oNg]kog]kN06_og]kN1_ooool1
o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo00?oooooA_oNg]h2o`0000gooooo00?o0000oj:RX_nRXZ804?nRXZ80
0ol0003oIFEUofEUI@0fofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool0
0ol0003og]kNomkNgP1[omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooodKog]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?mUIFGoIFEU03OoIFEU00?o0000
oj:RX_nRXZ804?nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN06_og]kN1_ooool1
o`00007ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool00ooooom5omkNgP03o`000?oooooooooo00cooooo00?o
0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0iofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o
0000ooooooooool02_ooool00ol0003og]kNomkNgP1ZomkNgPKooooo0Ol00001ooooo`004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo00?oooooA?oNg]h00ol0003oooooooooo`0<ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R
00?o0000ofEUIOmUIFD0>omUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0JOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom3omkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEU
I@0mofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkN
gP1XomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooood?og]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?mUIFGoIFEU03ooIFEU00?o0000
oj:RX_nRXZ803_nRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN06Sog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo@ooNg]h2o`0000cooooo00?o0000oj:R
X_nRXZ803_nRXZ800ol0003oIFEUofEUI@11ofEUI@03o`000?nRXZ;oXZ:R00koXZ:R0_l0000;oooo
o`03o`000?oNg]kog]kN06Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?o
oooo@ooNg]h00ol0003oooooooooo`0:ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ofEUIOmU
IFD0@_mUIFD00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0J?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom2omkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEUI@14ofEUI@03o`00
0?nRXZ;oXZ:R00goXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1WomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooood7og]kN00?o0000ooooooooool03?oo
ool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU04KoIFEU00?o0000oj:RX_nRXZ803OnR
XZ800ol0003oooooooooo`0:ooooo`;o0000IooNg]h6ooooo`7o00000Oooool002_ooooo0_l00004
oooood3og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGo
IFEU04SoIFEU00?o0000oj:RX_nRXZ803OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]ko
g]kN06Gog]kN1Oooool2o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?ooNg]h00ol0
003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD07_mUIFD:o`00
027oIFEU00?o0000oj:RX_nRXZ803OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN
06Cog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?_oNg]h00ol0003o
ooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD07?mUIFD3o`0000[o
:BTY1?l0000NofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02oooool00ol0003o
g]kNomkNgP1SomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocgog]kN
00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU01WoIFEU
1?l0000AobTY:@Co00006_mUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0H_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oolmomkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEU
I@0HofEUI@;o00006OlY:BT00ol0003oIFEUofEUI@0HofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o
0000ooooooooool02oooool00ol0003og]kNomkNgP1RomkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03ooooocgog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<
oj:RXP03o`000?mUIFGoIFEU01SoIFEU00?o0000obTY:OlY:BT06_lY:BT2o`0001WoIFEU00?o0000
oj:RX_nRXZ803?nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN06;og]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo?OoNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD05_mUIFD3o`0001oo:BTY00?o0000ofEU
IOmUIFD05omUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkN
g_oNg]h0H_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooollomkNgP03
o`000?oooooooooo00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0EofEUI@03
o`000?lY:BWo:BTY027o:BTY0_l0000GofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000oooooooo
ool02_ooool00ol0003og]kNomkNgP1QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03oooooc_og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?mUIFGoIFEU01GoIFEU00?o0000obTY:OlY:BT09?lY:BT00ol0003oIFEUofEUI@0EofEUI@03o`00
0?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1PomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc[og]kN00?o0000ooooooooool03?oo
ool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01GoIFEU0_l0000WobTY:@;o00005_mU
IFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0GooN
g]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooljomkNgP03o`000?oooooo
oooo00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0DofEUI@03o`000?lY:BWo
:BTY02Wo:BTY00?o0000ofEUIOmUIFD05?mUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooo
oooo00_ooooo00?o0000omkNg_oNg]h0GooNg]h6ooooo`7o00000Oooool002_ooooo0_l00004oooo
oc[og]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU
01CoIFEU00?o0000obTY:OlY:BT0:olY:BT00ol0003oIFEUofEUI@0CofEUI@03o`000?nRXZ;oXZ:R
00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1OomkNgPGooooo0_l00001oooo
o`00:oooool00ol0003oooooooooo`03oooooc[og]kN00?o0000ooooooooool02_ooool00ol0003o
XZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01CoIFEU00?o0000obTY:OlY:BT0;OlY:BT00ol0003o
IFEUofEUI@0CofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Oooool00ol0003o
g]kNomkNgP1OomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocWog]kN
00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGoIFEU01?oIFEU
00?o0000obTY:OlY:BT0;olY:BT00ol0003oIFEUofEUI@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1NomkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooocSog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:R
XP0<oj:RXP03o`000?mUIFGoIFEU01?oIFEU00?o0000obTY:OlY:BT0<OlY:BT00ol0003oIFEUofEU
I@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkN
gP1MomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocOog]kN00?o0000
ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU01?oIFEU00?o0000
obTY:OlY:BT0<olY:BT00ol0003oIFEUofEUI@0BofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000
ooooooooool02_ooool00ol0003og]kNomkNgP1LomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooocOog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:R
XP03o`000?mUIFGoIFEU01;oIFEU00?o0000obTY:OlY:BT0=OlY:BT00ol0003oIFEUofEUI@0AofEU
I@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1LomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocOog]kN00?o0000oooooooo
ool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU01;oIFEU00?o0000obTY:OlY
:BT0=olY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000oooooooo
ool02Oooool00ol0003og]kNomkNgP1LomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooocOog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0>OlY:BT00ol0003oIFEUofEUI@0AofEUI@03o`00
0?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1LomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooocKog]kN00?o0000ooooooooool02_oo
ool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0>OlY
:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1KomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooocGog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU017oIFEU00?o0000obTY:OlY:BT0>olY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;o
XZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1JomkNgPKooooo0Ol00001
ooooo`00:oooool00ol0003oooooooooo`03ooooocCog]kN00?o0000ooooooooool03?ooool00ol0
003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0?OlY:BT2o`00
01;oIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN
05Wog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo=?oNg]h00ol0003o
ooooooooo`0<ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o
:BTYobTY:@0nobTY:@03o`000?mUIFGoIFEU013oIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003o
ooooooooo`0:ooooo`03o`000?oNg]kog]kN05Wog]kN1_ooool1o`00007ooooo000[ooooo`;o0000
1?ooooldomkNgP03o`000?oooooooooo00_ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEU
ofEUI@0AofEUI@03o`000?lY:BWo:BTY043o:BTY00?o0000ofEUIOmUIFD04?mUIFD00ol0003oXZ:R
oj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0FOoNg]h5ooooo`;o0000
0Oooool002_ooooo00?o0000ooooooooool00oooooldomkNgP03o`000?oooooooooo00[ooooo00?o
0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0AofEUI@03o`000?lY:BWo:BTY04;o:BTY00?o
0000ofEUIOmUIFD03omUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo00Sooooo0_l0
001JomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc?og]kN00?o0000
ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000
obTY:OlY:BT0@olY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000
ooooooooool02Oooool00ol0003og]kNomkNgP1HomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03oooooc;og]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:R
XP03o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT0A?lY:BT00ol0003oIFEUofEUI@0?ofEU
I@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1GomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc7og]kN00?o0000oooooooo
ool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY
:BT0A_lY:BT00ol0003oIFEUofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooooooo
ool02_ooool00ol0003og]kNomkNgP1FomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03oooooc7og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`00
0?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT0AolY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`00
0?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1FomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooc7og]kN00?o0000ooooooooool02ooo
ool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT0BOlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP1FomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooc7og]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP;o00004OmUIFD0
0ol0003o:BTYobTY:@1:obTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`08ooooo`;o0000EooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00ooooolaomkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0
003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY04[o:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0
003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0EOoNg]h6oooo
o`7o00000Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooooolaomkNgP03o`000?oooooooooo
00Wooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY
04co:BTY00?o0000ofEUIOmUIFD03_mUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?oooooooooo
00Wooooo00?o0000omkNg_oNg]h0E?oNg]h6ooooo`7o00000Oooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo<OoNg]h00ol0003oooooooooo`09ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEU
IOmUIFD03omUIFD00ol0003o:BTYobTY:@1>obTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:R
X_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN05?og]kN1_ooool1o`00
007ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000oooo
ooooool00oooool`omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0
003oIFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY04oo:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0
003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0DooNg]h6oooo
o`7o00000Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo0ol00003oooooboog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;
oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT0D?lY:BT00ol0003oIFEUofEUI@0>
ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP1C
omkNgPCooooo0ol00001ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`03ooooobkog]kN00?o0000ooooooooool02ooo
ool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT0DOlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP1ComkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooobkog]kN00?o
0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o
0000obTY:OlY:BT0DOlY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o
0000ooooooooool02Oooool00ol0003og]kNomkNgP1ComkNgPKooooo0Ol00001ooooo`004?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`03ooooobkog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mU
IFGoIFEU00ooIFEU00?o0000obTY:OlY:BT09OlY:BT:o`0002Co:BTY00?o0000ofEUIOmUIFD03OmU
IFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Sooooo00?o0000omkNg_oNg]h0DooN
g]h6ooooo`7o00000Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool00oooool^omkNgP03o`000?oooooooooo00Wooooo00?o
0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY02;o:BTY3ol0
000RobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003ooooooooo
o`07ooooo`;o0000E?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool^
omkNgP03o`000?oooooooooo00Wooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@
ofEUI@03o`000?lY:BWo:BTY027o:BTY4Ol0000RobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`08ooooo`03o`000?oNg]kog]kN05;og]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo;OoNg]h00ol0003oooooooooo`0:oooo
o`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTYobTY:@0PobTY
:AGo00008?lY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000oooo
ooooool02Oooool00ol0003og]kNomkNgP1AomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobcog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03
o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT07olY:BTGo`00023o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0D?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool[omkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0?ofEUI@03o`00
0?lY:BWo:BTY01oo:BTY6_l0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ80
2OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04oog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo:ooNg]h00ol0003oooooooooo`0;ooooo`03o`000?nR
XZ;oXZ:R00[oXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0NobTY:Aco00007OlY
:BT00ol0003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1?omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooob_og]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGo
IFEU013oIFEU00?o0000obTY:OlY:BT07OlY:BTNo`0001go:BTY00?o0000ofEUIOmUIFD03OmUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0CooNg]h6
ooooo`7o00000Oooool002_ooooo0_l00004ooooob_og]kN00?o0000ooooooooool02_ooool00ol0
003oXZ:Roj:RXP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT07OlY:BTOo`00
01ko:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo
00Wooooo00?o0000omkNg_oNg]h0CooNg]h5ooooo`;o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooolZomkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003o
IFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY01co:BTY8Ol0000MobTY:@03o`000?mUIFGoIFEU00go
IFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04ko
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo:OoNg]h00ol0003ooooo
ooooo`0;ooooo`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTY
obTY:@0MobTY:B;o00007OlY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP1=omkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooobSog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:R
XP0;oj:RXP03o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT07?lY:BTTo`0001co:BTY00?o
0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o
0000omkNg_oNg]h0C?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolX
omkNgP03o`000?oooooooooo00cooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0?
ofEUI@03o`000?lY:BWo:BTY01co:BTY9?l0000LobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04cog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo:?oNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ofEUIOmUIFD03omUIFD00ol0003o:BTYobTY:@0LobTY
:BKo00007?lY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000oooo
ooooool02_ooool00ol0003og]kNomkNgP1<omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobSog]kN00?o0000ooooooooool02_ooool00ol0003oXZ:Roj:RXP0<oj:RXP03
o`000?mUIFGoIFEU00ooIFEU00?o0000obTY:OlY:BT06olY:BTXo`0001_o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0C?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolXomkNgP03o`00
0?oooooooooo00[ooooo00?o0000oj:RX_nRXZ802onRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`00
0?lY:BWo:BTY01_o:BTY:?l0000LobTY:@03o`000?mUIFGoIFEU00coIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04_og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo:?oNg]h00ol0003oooooooooo`09ooooo`03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0JobTY:B[o00006olY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP1:omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooobSog]kN00?o0000ooooooooool02Oooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU00ooIFEU00?o0000obTY:OlY:BT06olY:BT[o`0001[o:BTY00?o0000ofEUIOmUIFD03_mUIFD0
0ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0BOoNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolWomkNgP03o`000?oooooooooo
00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0?ofEUI@03o`000?lY:BWo:BTY
01_o:BTY:ol0000JobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0
003oooooooooo`0;ooooo`03o`000?oNg]kog]kN04Wog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo9_oNg]h00ol0003oooooooooo`0;ooooo`03o`000?nRXZ;oXZ:R00_o
XZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0JobTY:Bgo00006_lY:BT00ol0003o
IFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R00?o0000ooooooooool02_ooool00ol0003o
g]kNomkNgP19omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000Cooooo9OoNg]h00ol0003ooooo
ooooo`0;ooooo`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTY
obTY:@0JobTY:Bgo00006olY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00WoXZ:R
00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP19omkNgPGooooo0_l00001ooooo`00:ooo
ool00ol0003oooooooooo`03ooooobGog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:R
XP0<oj:RXP03o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT06_lY:BT]o`0001_o:BTY00?o
0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:Roj:RXP09oj:RXP03o`000?oooooooooo00[ooooo00?o
0000omkNg_oNg]h0BOoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolU
omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0@
ofEUI@03o`000?lY:BWo:BTY01_o:BTY;_l0000KobTY:@03o`000?mUIFGoIFEU00coIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN04Wog]kN1_ooool1
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo9OoNg]h00ol0003oooooooooo`0:oooo
o`03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0KobTY
:Boo00006_lY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooo
ooooool02?ooool00ol0003og]kNomkNgP19omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooobCog]kN00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0<oj:RXP03
o`000?mUIFGoIFEU013oIFEU00?o0000obTY:OlY:BT06olY:BT_o`0001[o:BTY00?o0000ofEUIOmU
IFD03OmUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oN
g]h0B?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolSomkNgP03o`00
0?oooooooooo00_ooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0AofEUI@03o`00
0?lY:BWo:BTY01_o:BTY<?l0000JobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN04Oog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo8_oNg]h00ol0003oooooooooo`0<ooooo`03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0KobTY:C3o00006_lY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_oo
ool00ol0003og]kNomkNgP16omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooob;og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?mUIFGo
IFEU017oIFEU00?o0000obTY:OlY:BT06olY:BT`o`0001[o:BTY00?o0000ofEUIOmUIFD03OmUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0A_oNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolRomkNgP03o`000?oooooooooo
00cooooo00?o0000oj:RX_nRXZ803?nRXZ800ol0003oIFEUofEUI@0@ofEUI@03o`000?lY:BWo:BTY
01co:BTY<?l0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ802OnRXZ800ol0
003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04Kog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo8_oNg]h00ol0003oooooooooo`0;ooooo`03o`000?nRXZ;oXZ:R00go
XZ:R00?o0000ofEUIOmUIFD04?mUIFD00ol0003o:BTYobTY:@0LobTY:C3o00006olY:BT00ol0003o
IFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003o
g]kNomkNgP16omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooob;og]kN
00?o0000ooooooooool02oooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGoIFEU013oIFEU
00?o0000obTY:OlY:BT07?lY:BT`o`0001_o:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:R
oj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0AOoNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooolRomkNgP03o`000?oooooooooo00[ooooo00?o
0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0AofEUI@03o`000?lY:BWo:BTY01co:BTY<Ol0
000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003ooooooooo
o`0:ooooo`03o`000?oNg]kog]kN04Cog]kN1_ooool1o`00007ooooo000[ooooo`;o00001?oooolR
omkNgP03o`000?oooooooooo00[ooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0A
ofEUI@03o`000?lY:BWo:BTY01co:BTY<Ol0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000
oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN04?og]kN1Oooool2
o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo8OoNg]h00ol0003oooooooooo`0;oooo
o`03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0LobTY
:C7o00006olY:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000oooo
ooooool02oooool00ol0003og]kNomkNgP13omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooob3og]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03
o`000?mUIFGoIFEU017oIFEU00?o0000obTY:OlY:BT07OlY:BT`o`0001_o:BTY00?o0000ofEUIOmU
IFD03_mUIFD00ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oN
g]h0@ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolOomkNgP03o`00
0?oooooooooo00gooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0AofEUI@03o`00
0?lY:BWo:BTY01go:BTY<Ol0000KobTY:@03o`000?mUIFGoIFEU00goIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN04?og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo7ooNg]h00ol0003oooooooooo`0=ooooo`03o`000?nR
XZ;oXZ:R00goXZ:R00?o0000ofEUIOmUIFD04OmUIFD00ol0003o:BTYobTY:@0MobTY:C7o00006olY
:BT00ol0003oIFEUofEUI@0=ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02Ooo
ool00ol0003og]kNomkNgP13omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
oooooaoog]kN00?o0000ooooooooool03?ooool00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?mUIFGo
IFEU01;oIFEU00?o0000obTY:OlY:BT07_lY:BT`o`0001_o:BTY00?o0000ofEUIOmUIFD03_mUIFD0
0ol0003oXZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00Wooooo00?o0000omkNg_oNg]h0@ooNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolOomkNgP03o`000?oooooooooo
00cooooo00?o0000oj:RX_nRXZ803OnRXZ800ol0003oIFEUofEUI@0BofEUI@03o`000?lY:BWo:BTY
01ko:BTY<?l0000KobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0
003oooooooooo`09ooooo`03o`000?oNg]kog]kN04?og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo7_oNg]h00ol0003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00go
XZ:R00?o0000ofEUIOmUIFD04_mUIFD00ol0003o:BTYobTY:@0NobTY:C3o00006olY:BT00ol0003o
IFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02_ooool00ol0003o
g]kNomkNgP12omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooagog]kN
00?o0000ooooooooool03Oooool00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?mUIFGoIFEU01;oIFEU
00?o0000obTY:OlY:BT07_lY:BT`o`0001co:BTY00?o0000ofEUIOmUIFD03OmUIFD00ol0003oXZ:R
oj:RXP0;oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0@OoNg]h6ooooo`7o0000
0Oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool00ooooolLomkNgP03o`000?oooooooooo00ko
oooo00?o0000oj:RX_nRXZ803_nRXZ800ol0003oIFEUofEUI@0BofEUI@03o`000?lY:BWo:BTY01oo
:BTY;ol0000LobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003o
ooooooooo`0;ooooo`03o`000?oNg]kog]kN043og]kN1_ooool1o`00007ooooo000@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo00?ooooo7?oNg]h00ol0003oooooooooo`0>ooooo`03o`000?nRXZ;oXZ:R
00koXZ:R00?o0000ofEUIOmUIFD04_mUIFD00ol0003o:BTYobTY:@0OobTY:Boo00007?lY:BT00ol0
003oIFEUofEUI@0>ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02oooool00ol0
003og]kNomkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000ooooolLomkNgP03o`000?oooooo
oooo00gooooo00?o0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0CofEUI@03o`000?lY:BWo
:BTY01oo:BTY;Ol0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN043og]kN1?ooool3o`00007ooooo000@oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool00ooooolLomkNgP03o`000?oooooooooo00gooooo00?o0000oj:RX_nRXZ803onR
XZ800ol0003oIFEUofEUI@0CofEUI@03o`000?lY:BWo:BTY023o:BTY;?l0000NobTY:@03o`000?mU
IFGoIFEU00koIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oN
g]kog]kN043og]kN1_ooool1o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool00ooooolLomkNgP03o`00
0?oooooooooo00gooooo00?o0000oj:RX_nRXZ803onRXZ800ol0003oIFEUofEUI@0CofEUI@03o`00
0?lY:BWo:BTY023o:BTY;?l0000NobTY:@03o`000?mUIFGoIFEU00koIFEU00?o0000oj:RX_nRXZ80
2_nRXZ800ol0003oooooooooo`0:ooooo`03o`000?oNg]kog]kN043og]kN1_ooool1o`00007ooooo
000@ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo00?ooooo7?oNg]h00ol0003oooooooooo`0=ooooo`03o`000?nRXZ;oXZ:R00ooXZ:R
00?o0000ofEUIOmUIFD04omUIFD00ol0003o:BTYobTY:@0QobTY:B[o00007olY:BT00ol0003oIFEU
ofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool02Oooool00ol0003og]kN
omkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`03oooooa_og]kN0_l0000?ooooo`03o`00
0?nRXZ;oXZ:R00ooXZ:R00?o0000ofEUIOmUIFD04omUIFD00ol0003o:BTYobTY:@0RobTY:BWo0000
7olY:BT00ol0003oIFEUofEUI@0?ofEUI@03o`000?nRXZ;oXZ:R00[oXZ:R00?o0000ooooooooool0
2Oooool00ol0003og]kNomkNgP10omkNgPKooooo0Ol00001ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`03oooooa[o
g]kN00?o0000ooooooooool03oooool00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?mUIFGoIFEU01?o
IFEU00?o0000obTY:OlY:BT08olY:BTXo`0001oo:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0003o
XZ:Roj:RXP0:oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0?ooNg]h6ooooo`7o
00000Oooool000_ooooo0ol000000ol@413oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo
6OoNg]h00ol0003oooooooooo`0?ooooo`03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ofEUIOmUIFD0
5?mUIFD00ol0003o:BTYobTY:@0SobTY:BKo00008OlY:BT00ol0003oIFEUofEUI@0>ofEUI@03o`00
0?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0nomkNgPKooooo
0Ol00001ooooo`003Oooool00ol@413o^[Zjooooo`0Kooooo`03o`000?oooooooooo00?ooooo6?oN
g]h00ol0003oooooooooo`0@ooooo`03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ofEUIOmUIFD05?mU
IFD00ol0003o:BTYobTY:@0TobTY:BGo00008OlY:BT00ol0003oIFEUofEUI@0>ofEUI@;o00003?nR
XZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=
ooooo`03oiRHV?lb<S;ooooo01_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooo
oooo013ooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0DofEUI@03o`000?lY:BWo
:BTY02Go:BTY8ol0000RobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ80
0ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=oooo
o`03omgMgOl0003o^[Zj01_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooooooo
013ooooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY
02Go:BTY8_l0000RobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802_nRXZ800ol0
003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000=ooooo`03
oeEEEOmgMgOoA4A401_ooooo00?o0000ooooooooool00ooooolHomkNgP03o`000?oooooooooo013o
oooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY02Ko
:BTY8?l0000SobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ802onRXZ800ol0003o
ooooooooo`0:ooooo`03o`000?oNg]kog]kN03gog]kN1_ooool1o`00007ooooo000<ooooo`05omgM
gOl@413oooooob4Q8OoMgMd06_ooool00ol0003oooooooooo`03oooooaSog]kN00?o0000oooooooo
ool04?ooool00ol0003oXZ:Roj:RXP0@oj:RXP03o`000?mUIFGoIFEU01GoIFEU00?o0000obTY:OlY
:BT09olY:BTNo`0002Co:BTY00?o0000ofEUIOmUIFD03omUIFD00ol0003oXZ:Roj:RXP0;oj:RXP03
o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0?OoNg]h6ooooo`7o00000Oooool000cooooo
00GoIVIVohN7QoooooooV9RHoeEEE@0Jooooo`;o00001?oooolHomkNgP03o`000?oooooooooo013o
oooo00?o0000oj:RX_nRXZ804?nRXZ800ol0003oIFEUofEUI@0EofEUI@03o`000?lY:BWo:BTY02_o
:BTY6Ol0000UobTY:@03o`000?mUIFGoIFEU00ooIFEU00?o0000oj:RX_nRXZ803?nRXZ800ol0003o
ooooooooo`09ooooo`03o`000?oNg]kog]kN03gog]kN1Oooool2o`00007ooooo000;ooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool06?ooool00ol0003oooooooooo`03oooooaSog]kN
0_l0000@ooooo`03o`000?nRXZ;oXZ:R01;oXZ:R00?o0000ofEUIOmUIFD05OmUIFD00ol0003o:BTY
obTY:@0/obTY:AGo00009olY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R
00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP0momkNgPKooooo0Ol00001ooooo`002ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000ooooooooool0
0ooooolHomkNgP03o`000?oooooooooo00oooooo00?o0000oj:RX_nRXZ804_nRXZ800ol0003oIFEU
ofEUI@0FofEUI@03o`000?lY:BWo:BTY02co:BTY4ol0000XobTY:@03o`000?mUIFGoIFEU013oIFEU
00?o0000oj:RX_nRXZ802onRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN03gog]kN
1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo5ooNg]h00ol0003ooooooooo
o`0@ooooo`03o`000?nRXZ;oXZ:R01;oXZ:R00?o0000ofEUIOmUIFD05_mUIFD00ol0003o:BTYobTY
:@0_obTY:@ko0000:_lY:BT00ol0003oIFEUofEUI@0@ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o
0000ooooooooool02_ooool00ol0003og]kNomkNgP0lomkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03oooooaKog]kN00?o0000ooooooooool04Oooool00ol0003oXZ:Roj:RXP0B
oj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0A
ofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0k
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000oooo
ooooool04_ooool00ol0003oXZ:Roj:RXP0Boj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY
:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00_oXZ:R00?o0000oooo
ooooool02oooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03oooooaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Boj:RXP03
o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0I_lY:BT00ol0003oIFEUofEUI@0AofEUI@03
o`000?nRXZ;oXZ:R00_oXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkNgP0jomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000ooooooooool0
4_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU01OoIFEU00?o0000obTY:OlY:BT0
IOlY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool0
2_ooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mU
IFGoIFEU01SoIFEU00?o0000obTY:OlY:BT0I?lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooaGog]kN00?o0000ooooooooool04_ooool0
0ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU01WoIFEU00?o0000obTY:OlY:BT0HolY:BT0
0ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R00coXZ:R00?o0000ooooooooool02_ooool0
0ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oaGog]kN00?o0000ooooooooool04_ooool00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?mUIFGoIFEU
01[oIFEU00?o0000obTY:OlY:BT0H_lY:BT00ol0003oIFEUofEUI@0AofEUI@03o`000?nRXZ;oXZ:R
00goXZ:R00?o0000ooooooooool02Oooool00ol0003og]kNomkNgP0jomkNgPKooooo0Ol00001oooo
o`00:oooool00ol0003oooooooooo`03oooooaGog]kN0_l0000Cooooo`03o`000?nRXZ;oXZ:R01Co
XZ:R00?o0000ofEUIOmUIFD06_mUIFD00ol0003o:BTYobTY:@1QobTY:@03o`000?mUIFGoIFEU01;o
IFEU00?o0000oj:RX_nRXZ803?nRXZ800ol0003oooooooooo`09ooooo`03o`000?oNg]kog]kN03[o
g]kN1_ooool1o`00007ooooo000[ooooo`;o00001?oooolDomkNgP03o`000?oooooooooo01?ooooo
00?o0000oj:RX_nRXZ805?nRXZ800ol0003oIFEUofEUI@0KofEUI@03o`000?lY:BWo:BTY063o:BTY
00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00[ooooo
00?o0000omkNg_oNg]h0>OoNg]h5ooooo`;o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oolComkNgP03o`000?oooooooooo01Cooooo00?o0000oj:RX_nRXZ805OnRXZ800ol0003oIFEUofEU
I@0KofEUI@03o`000?lY:BWo:BTY05oo:BTY00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:R
XP0=oj:RXP03o`000?oooooooooo00[ooooo00?o0000omkNg_oNg]h0>?oNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Gooooo00?o0000
oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0KofEUI@03o`000?lY:BWo:BTY05ko:BTY00?o0000
ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo00?o0000
omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolBomkN
gP03o`000?oooooooooo01Gooooo00?o0000oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0LofEU
I@03o`000?lY:BWo:BTY05go:BTY00?o0000ofEUIOmUIFD04_mUIFD00ol0003oXZ:Roj:RXP0=oj:R
XP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Kooooo00?o0000oj:RX_nR
XZ805OnRXZ800ol0003oIFEUofEUI@0MofEUI@03o`000?lY:BWo:BTY05_o:BTY00?o0000ofEUIOmU
IFD05?mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oN
g]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolBomkNgP03o`00
0?oooooooooo01Kooooo00?o0000oj:RX_nRXZ805_nRXZ800ol0003oIFEUofEUI@0MofEUI@03o`00
0?lY:BWo:BTY05[o:BTY00?o0000ofEUIOmUIFD05?mUIFD00ol0003oXZ:Roj:RXP0<oj:RXP03o`00
0?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o
0000ooooooooool00ooooolBomkNgP03o`000?oooooooooo01Kooooo00?o0000oj:RX_nRXZ805_nR
XZ800ol0003oIFEUofEUI@0NofEUI@;o0000F_lY:BT00ol0003oIFEUofEUI@0DofEUI@03o`000?nR
XZ;oXZ:R00coXZ:R00?o0000ooooooooool02oooool00ol0003og]kNomkNgP0gomkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooa;og]kN00?o0000ooooooooool05oooool0
0ol0003oXZ:Roj:RXP0Foj:RXP03o`000?mUIFGoIFEU01ooIFEU00?o0000obTY:OlY:BT0E_lY:BT0
0ol0003oIFEUofEUI@0EofEUI@03o`000?nRXZ;oXZ:R00goXZ:R00?o0000ooooooooool02_ooool0
0ol0003og]kNomkNgP0gomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oa;og]kN0_l0000Hooooo`03o`000?nRXZ;oXZ:R01OoXZ:R00?o0000ofEUIOmUIFD07omUIFD2o`00
05Ko:BTY00?o0000ofEUIOmUIFD05OmUIFD00ol0003oXZ:Roj:RXP0=oj:RXP03o`000?oooooooooo
00[ooooo00?o0000omkNg_oNg]h0=ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooolAomkNgP03o`000?oooooooooo01Sooooo00?o0000oj:RX_nRXZ806?nRXZ800ol0003o
IFEUofEUI@0PofEUI@03o`000?lY:BWo:BTY05?o:BTY00?o0000ofEUIOmUIFD05OmUIFD00ol0003o
XZ:Roj:RXP0=oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkNg_oNg]h0=_oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00oooool@omkNgP03o`000?oooooooooo01[ooooo
00?o0000oj:RX_nRXZ806?nRXZ800ol0003oIFEUofEUI@0PofEUI@03o`000?lY:BWo:BTY057o:BTY
00?o0000ofEUIOmUIFD05_mUIFD00ol0003oXZ:Roj:RXP0>oj:RXP03o`000?oooooooooo00_ooooo
00?o0000omkNg_oNg]h0=OoNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooo`oog]kN00?o
0000ooooooooool06oooool00ol0003oXZ:Roj:RXP0Ioj:RXP03o`000?mUIFGoIFEU023oIFEU0_l0
001AobTY:@03o`000?mUIFGoIFEU01KoIFEU00?o0000oj:RX_nRXZ803_nRXZ800ol0003ooooooooo
o`0<ooooo`03o`000?oNg]kog]kN03Cog]kN1Oooool2o`00007ooooo000[ooooo`03o`000?oooooo
oooo00?ooooo3ooNg]h00ol0003oooooooooo`0Kooooo`03o`000?nRXZ;oXZ:R01[oXZ:R00?o0000
ofEUIOmUIFD08OmUIFD2o`0004oo:BTY00?o0000ofEUIOmUIFD05_mUIFD00ol0003oXZ:Roj:RXP0>
oj:RXP03o`000?oooooooooo00cooooo00?o0000omkNg_oNg]h0=?oNg]h6ooooo`7o00000Oooool0
02_ooooo00?o0000ooooooooool00oooool?omkNgP03o`000?oooooooooo01cooooo00?o0000oj:R
X_nRXZ806_nRXZ800ol0003oIFEUofEUI@0RofEUI@03o`000?lY:BWo:BTY04_o:BTY00?o0000ofEU
IOmUIFD05omUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo00_ooooo00?o0000omkN
g_oNg]h0=?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool?omkNgP03
o`000?oooooooooo01cooooo00?o0000oj:RX_nRXZ806onRXZ800ol0003oIFEUofEUI@0RofEUI@?o
0000BOlY:BT00ol0003oIFEUofEUI@0HofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000oooooooo
ool02oooool00ol0003og]kNomkNgP0domkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooo
ooooo`03ooooo`oog]kN00?o0000ooooooooool07?ooool00ol0003oXZ:Roj:RXP0Loj:RXP03o`00
0?mUIFGoIFEU02CoIFEU0_l00017obTY:@03o`000?mUIFGoIFEU01SoIFEU00?o0000oj:RX_nRXZ80
3onRXZ800ol0003oooooooooo`0;ooooo`03o`000?oNg]kog]kN03Cog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo3ooNg]h00ol0003oooooooooo`0Mooooo`03o`000?nR
XZ;oXZ:R01coXZ:R00?o0000ofEUIOmUIFD09OmUIFD00ol0003o:BTYobTY:@13obTY:@03o`000?mU
IFGoIFEU01WoIFEU00?o0000oj:RX_nRXZ803onRXZ800ol0003oooooooooo`0;ooooo`03o`000?oN
g]kog]kN03Cog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo3ooNg]h0
0ol0003oooooooooo`0Nooooo`03o`000?nRXZ;oXZ:R01coXZ:R0_l0000VofEUI@Co0000@?lY:BT0
0ol0003oIFEUofEUI@0JofEUI@03o`000?nRXZ;oXZ:R00ooXZ:R00?o0000ooooooooool02oooool0
0ol0003og]kNomkNgP0domkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
o`kog]kN00?o0000ooooooooool07oooool00ol0003oXZ:Roj:RXP0Noj:RXP03o`000?mUIFGoIFEU
02OoIFEU0ol0000lobTY:@;o00007?mUIFD00ol0003oXZ:Roj:RXP0?oj:RXP03o`000?oooooooooo
00cooooo00?o0000omkNg_oNg]h0<ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00oooool=omkNgP03o`000?oooooooooo027ooooo00?o0000oj:RX_nRXZ807_nRXZ800ol0003o
IFEUofEUI@0YofEUI@;o0000>OlY:BT00ol0003oIFEUofEUI@0LofEUI@03o`000?nRXZ;oXZ:R013o
XZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0bomkNgPKooooo0Ol00001ooooo`00
:oooool00ol0003oooooooooo`03ooooo`cog]kN00?o0000ooooooooool08oooool00ol0003oXZ:R
oj:RXP0Noj:RXP;o0000:omUIFD3o`0003Co:BTY0_l0000OofEUI@03o`000?nRXZ;oXZ:R013oXZ:R
00?o0000ooooooooool03Oooool00ol0003og]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`03ooooo`cog]kN00?o0000ooooooooool09?ooool00ol0003o
XZ:Roj:RXP0Ooj:RXP03o`000?mUIFGoIFEU02_oIFEU00?o0000obTY:OlY:BT0<?lY:BT00ol0003o
IFEUofEUI@0OofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0003o
g]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03oooo
o`cog]kN00?o0000ooooooooool09Oooool00ol0003oXZ:Roj:RXP0Ooj:RXP;o0000;?mUIFD6o`00
02[o:BTY0_l0000RofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool00ol0
003og]kNomkNgP0aomkNgPKooooo0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool<omkNgP03o`000?oooooo
oooo02Kooooo00?o0000oj:RX_nRXZ808?nRXZ800ol0003oIFEUofEUI@0_ofEUI@?o00009_lY:BT0
0ol0003oIFEUofEUI@0RofEUI@03o`000?nRXZ;oXZ:R013oXZ:R00?o0000ooooooooool03Oooool0
0ol0003og]kNomkNgP0aomkNgPCooooo0ol00001ooooo`004?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo00?ooooo3?oN
g]h00ol0003oooooooooo`0Wooooo`03o`000?nRXZ;oXZ:R023oXZ:R0ol0000aofEUI@?o00008OlY
:BT2o`0002GoIFEU00?o0000oj:RX_nRXZ804?nRXZ800ol0003oooooooooo`0=ooooo`03o`000?oN
g]kog]kN037og]kN1_ooool1o`00007ooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool00oooool<omkNgP03o`00
0?oooooooooo02Sooooo0_l0000Soj:RXP;o0000<_mUIFD6o`0001So:BTY0ol0000WofEUI@03o`00
0?nRXZ;oXZ:R017oXZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0aomkNgPKooooo
0Ol00001ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo00?ooooo3?oNg]h00ol0003oooooooooo`0Zooooo`03
o`000?nRXZ;oXZ:R02;oXZ:R00?o0000ofEUIOmUIFD0=OmUIFD9o`0000Oo:BTY2?l0000ZofEUI@03
o`000?nRXZ;oXZ:R017oXZ:R00?o0000ooooooooool03?ooool00ol0003og]kNomkNgP0aomkNgPKo
oooo0Ol00001ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo00?ooooo2ooNg]h00ol0003oooooooooo`0/oooo
o`;o00008onRXZ82o`0003koIFEU1ol0000bofEUI@03o`000?nRXZ;oXZ:R017oXZ:R00?o0000oooo
ooooool03Oooool00ol0003og]kNomkNgP0`omkNgPKooooo0Ol00001ooooo`004?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo00?ooooo2_oNg]h00ol0003oooooooooo`0_ooooo`03o`000?nRXZ;oXZ:R02;oXZ:R00?o0000
ofEUIOmUIFD0LomUIFD00ol0003oXZ:Roj:RXP0Coj:RXP03o`000?oooooooooo00gooooo00?o0000
omkNg_oNg]h0;ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool9omkN
gP03o`000?oooooooooo037ooooo0_l0000Soj:RXP?o0000L_mUIFD00ol0003oXZ:Roj:RXP0Coj:R
XP03o`000?oooooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00oooool9omkNgP03o`000?oooooooooo03?ooooo00?o0000oj:RX_nR
XZ808onRXZ83o`0006ooIFEU00?o0000oj:RX_nRXZ804onRXZ800ol0003oooooooooo`0>ooooo`03
o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
2OoNg]h00ol0003oooooooooo`0dooooo`;o00009_nRXZ82o`0006coIFEU00?o0000oj:RX_nRXZ80
5?nRXZ800ol0003oooooooooo`0>ooooo`03o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooo2OoNg]h00ol0003oooooooooo`0fooooo`03o`000?nR
XZ;oXZ:R02GoXZ:R00?o0000ofEUIOmUIFD0JOmUIFD00ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oo
oooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000
ooooooooool00oooool9omkNgP03o`000?oooooooooo03Oooooo0ol0000Uoj:RXP?o0000J?mUIFD0
0ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oooooooooo00kooooo00?o0000omkNg_oNg]h0;_oNg]h6
ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooool:omkNgP03o`000?oooooooooo
03Wooooo0_l0000Voj:RXP?o0000IOmUIFD00ol0003oXZ:Roj:RXP0Doj:RXP03o`000?oooooooooo
00kooooo00?o0000omkNg_oNg]h0;_oNg]h6ooooo`7o00000Oooool002_ooooo0_l00004ooooo`_o
g]kN00Go0000ooooooooooooooooo`00000hooooo`03o`000?nRXZ;oXZ:R02KoXZ:R0_l0001RofEU
I@03o`000?nRXZ;oXZ:R01GoXZ:R00?o0000ooooooooool03_ooool00ol0003og]kNomkNgP0^omkN
gPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03ooooo`cog]kN1?l0000iooooo`Co
00009_nRXZ84o`0005koIFEU00?o0000oj:RX_nRXZ805OnRXZ800ol0003oooooooooo`0>ooooo`03
o`000?oNg]kog]kN02kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
4?oNg]h00ol0003oooooooooo`0jooooo`03o`000?nRXZ;oXZ:R02OoXZ:R0ol0001KofEUI@03o`00
0?nRXZ;oXZ:R01GoXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP0]omkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooa7og]kN00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0booooo`03o`000?nRXZ;oXZ:R02WoXZ:R0_l0001HofEUI@03o`000?nR
XZ;oXZ:R01OoXZ:R00?o0000ooooooooool03oooool00ol0003og]kNomkNgP0/omkNgPKooooo0Ol0
0001ooooo`00:oooool00ol0003oooooooooo`03oooooa;og]kN2?l0000eooooo`Co0000:?nRXZ86
o`0005;oIFEU00?o0000oj:RX_nRXZ806?nRXZ800ol0003oooooooooo`0@ooooo`03o`000?oNg]ko
g]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo6_oNg]h00ol0
003oooooooooo`0fooooo`?o0000:onRXZ83o`0004ooIFEU00?o0000oj:RX_nRXZ806?nRXZ800ol0
003oooooooooo`0@ooooo`03o`000?oNg]kog]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo6ooNg]h00ol0003oooooooooo`0hooooo`03o`000?nRXZ;oXZ:R02_o
XZ:R00?o0000ofEUIOmUIFD0BomUIFD00ol0003oXZ:Roj:RXP0Ioj:RXP03o`000?oooooooooo013o
oooo00?o0000omkNg_oNg]h0:ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooolLomkNgPOo0000=?ooool4o`0002[oXZ:R1Ol00016ofEUI@;o00007?nRXZ800ol0003ooooo
ooooo`0@ooooo`03o`000?oNg]kog]kN02_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oo
oooooooo00?ooooo8ooNg]h00ol0003oooooooooo`0eooooo`03o`000?nRXZ;oXZ:R02coXZ:R0ol0
0012ofEUI@03o`000?nRXZ;oXZ:R01coXZ:R00?o0000ooooooooool04?ooool00ol0003og]kNomkN
gP0[omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooobCog]kN00?o0000
ooooooooool0=Oooool3o`0002koXZ:R0ol0000nofEUI@03o`000?nRXZ;oXZ:R01goXZ:R00?o0000
ooooooooool04?ooool00ol0003og]kNomkNgP0[omkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03ooooobGog]kN2_l0000`ooooo`?o0000;_nRXZ86o`0003KoIFEU0_l0000Poj:R
XP03o`000?oooooooooo013ooooo0_l0000/omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000Co
oooo;ooNg]h00ol0003oooooooooo`0`ooooo`?o0000<OnRXZ83o`0003;oIFEU00?o0000oj:RX_nR
XZ808?nRXZ800ol0003oooooooooo`0Aooooo`03o`000?oNg]kog]kN02[og]kN1Oooool2o`00007o
oooo000[ooooo`03o`000?oooooooooo00?ooooo<?oNg]h00ol0003oooooooooo`0booooo`?o0000
<OnRXZ85o`0002_oIFEU0_l0000Soj:RXP03o`000?oooooooooo01;ooooo00?o0000omkNg_oNg]h0
:OoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooolaomkNgPOo0000<?oo
ool3o`0003?oXZ:R1?l0000TofEUI@?o00009OnRXZ800ol0003oooooooooo`0Cooooo`03o`000?oN
g]kog]kN02Sog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo>?oNg]h0
0ol0003oooooooooo`0`ooooo`?o0000=?nRXZ89o`0001SoIFEU0ol0000Xoj:RXP03o`000?oooooo
oooo01?ooooo00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00oooooliomkNgP03o`000?oooooooooo03;ooooo0ol0000joj:RXQSo0000:onRXZ800ol0
003oooooooooo`0Cooooo`03o`000?oNg]kog]kN02Sog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooo>_oNg]h;o`0002cooooo0ol0001joj:RXP03o`000?oooooooooo01?o
oooo00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooom4omkNgP03o`000?oooooooooo02gooooo0ol0001goj:RXP03o`000?oooooooooo01?ooooo
00?o0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oom5omkNgP03o`000?oooooooooo02oooooo0ol0001coj:RXP03o`000?oooooooooo01Cooooo00?o
0000omkNg_oNg]h0:?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooom6
omkNgPSo0000;?ooool4o`0006ooXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0X
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodkog]kN00?o0000oooo
ooooool0;Oooool3o`0006coXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0XomkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooodoog]kN00?o0000oooooooo
ool0;oooool3o`0006WoXZ:R00?o0000ooooooooool05?ooool00ol0003og]kNomkNgP0XomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooe3og]kN1ol0000]ooooo`?o0000
I_nRXZ800ol0003oooooooooo`0Dooooo`;o0000:OoNg]h6ooooo`7o00000Oooool002_ooooo0_l0
0004oooooeOog]kN00?o0000ooooooooool0;Oooool3o`0006?oXZ:R00?o0000ooooooooool05Ooo
ool00ol0003og]kNomkNgP0WomkNgPGooooo0_l00001ooooo`00:oooool00ol0003oooooooooo`03
oooooeSog]kN00?o0000ooooooooool0;oooool5o`0005goXZ:R00?o0000ooooooooool05oooool0
0ol0003og]kNomkNgP0VomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooo
oeWog]kN2_l0000/ooooo`Co0000FOnRXZ800ol0003oooooooooo`0Hooooo`03o`000?oNg]kog]kN
02Gog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooHooNg]h00ol0003o
ooooooooo`0]ooooo`?o0000E_nRXZ800ol0003oooooooooo`0Hooooo`03o`000?oNg]kog]kN02Go
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooI?oNg]h00ol0003ooooo
ooooo`0_ooooo`?o0000D_nRXZ800ol0003oooooooooo`0Iooooo`03o`000?oNg]kog]kN02Gog]kN
1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooIOoNg]h7o`0002gooooo1_l0
001;oj:RXP03o`000?oooooooooo01[ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooom/omkNgP03o`000?oooooooooo033ooooo0ol00018
oj:RXP03o`000?oooooooooo01[ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Oooool0
02_ooooo00?o0000ooooooooool00ooooom]omkNgP03o`000?oooooooooo03;ooooo0ol00014oj:R
XP03o`000?oooooooooo01_ooooo00?o0000omkNg_oNg]h09OoNg]h6ooooo`7o00000Oooool002_o
oooo00?o0000ooooooooool00ooooom^omkNgP_o0000;?ooool6o`0003goXZ:R00?o0000oooooooo
ool07?ooool2o`0002Kog]kN1_ooool1o`00007ooooo000Qooooo`Co000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`03ooooogWog]kN00?o0000ooooooooool0;oooool4o`0003SoXZ:R
00?o0000ooooooooool07oooool00ol0003og]kNomkNgP0SomkNgPKooooo0Ol00001ooooo`008ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?oooooN_oNg]h00ol0003ooooooooo
o`0booooo`?o0000<onRXZ82o`0002?ooooo00?o0000omkNg_oNg]h08_oNg]h6ooooo`7o00000Ooo
ool002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooog_og]kN1ol0000`
ooooo`Ko0000;?nRXZ800ol0003oooooooooo`0Tooooo`03o`000?oNg]kog]kN027og]kN1_ooool1
o`00007ooooo000Sooooo`03o`000?oooooooooo00Gooooo0ol00003oooooh;og]kN00?o0000oooo
ooooool0<oooool6o`0002CoXZ:R0_l0000Wooooo`03o`000?oNg]kog]kN027og]kN1?ooool3o`00
007ooooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooooon3omkNgP03
o`000?oooooooooo03Sooooo1_l0000Koj:RXP?o0000:Oooool00ol0003og]kNomkNgP0QomkNgPKo
oooo0Ol00001ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
Q?oNg]h7o`0003Wooooo2Ol0000;oj:RXPOo0000;?ooool00ol0003og]kNomkNgP0QomkNgPKooooo
0Ol00001ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?oooooRooN
g]h00ol0003oooooooooo`0oooooo`_o0000<oooool00ol0003og]kNomkNgP0QomkNgPKooooo0Ol0
0001ooooo`008Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00?oooooS?oNg]h0
0ol0003oooooooooo`1looooo`03o`000?oNg]kog]kN027og]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?oooooSOoNg]h:o`0007Cooooo00?o0000omkNg_oNg]h08OoNg]h6oooo
o`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooonGomkNgP03o`000?oooooooooo077o
oooo00?o0000omkNg_oNg]h08OoNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0ooooonHomkNgP03o`000?oooooooooo073ooooo00?o0000omkNg_oNg]h08OoNg]h6ooooo`7o0000
0Oooool002_ooooo00?o0000ooooooooool00ooooonIomkNgPOo0000Joooool00ol0003og]kNomkN
gP0QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooioog]kN00?o0000
ooooooooool0JOooool00ol0003og]kNomkNgP0QomkNgPKooooo0Ol00001ooooo`00:oooool00ol0
003oooooooooo`03oooooj3og]kN00?o0000ooooooooool0JOooool00ol0003og]kNomkNgP0PomkN
gPKooooo0Ol00001ooooo`00:oooool2o`0000CoooooXOoNg]h00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo05kooooo00?o0000omkNg_oNg]h07ooNg]h5ooooo`;o00000Oooool002_ooooo
00?o0000ooooooooool00ooooonRomkNgP_o0000HOooool00ol0003og]kNomkNgP0NomkNgPKooooo
0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooojgog]kN00?o0000ooooooooool0G_oo
ool00ol0003og]kNomkNgP0NomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03
ooooojkog]kN00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`03o`000?oNg]ko
g]kN01kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo[ooNg]h7o`00
05Sooooo00?o0000omkNg_oNg]h07_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooonfomkNgP03o`000?oooooooooo05Gooooo00?o0000omkNg_oNg]h07_oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00ooooongomkNgP03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0COooool00ol0003og]kNomkNgP0NomkNgPKooooo0Ol00001ooooo`00:ooo
ool00ol0003oooooooooo`03oooookSog]kN1ol0001?ooooo`03o`000?oNg]kog]kN01kog]kN1_oo
ool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo_ooNg]h00ol0003oooooooooo`1<
ooooo`03o`000?oNg]kog]kN01kog]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo
00?ooooo`?oNg]h00ol0003oooooooooo`1;ooooo`03o`000?oNg]kog]kN01kog]kN1_ooool1o`00
007ooooo000[ooooo`03o`000?oooooooooo00?ooooo`OoNg]h:o`0004?ooooo00?o0000omkNg_oN
g]h07_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooo;omkNgP03o`00
0?oooooooooo047ooooo00?o0000omkNg_oNg]h07OoNg]h6ooooo`7o00000Oooool002_ooooo0_l0
0004ooooolcog]kN00?o0000ooooooooool0@Oooool00ol0003og]kNomkNgP0LomkNgPGooooo0_l0
0001ooooo`00:oooool00ol0003oooooooooo`03ooooolgog]kN2?l0000looooo`03o`000?oNg]ko
g]kN01_og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooe?oNg]h00ol0
003oooooooooo`0jooooo`03o`000?oNg]kog]kN01_og]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?oooooeOoNg]h00ol0003oooooooooo`0iooooo`03o`000?oNg]kog]kN01_o
g]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?oooooe_oNg]h;o`00033ooooo
00?o0000omkNg_oNg]h06ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooo
oooQomkNgP03o`000?oooooooooo02gooooo00?o0000omkNg_oNg]h06ooNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00ooooooRomkNgP03o`000?oooooooooo02cooooo00?o0000
omkNg_oNg]h06ooNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooooSomkN
gPOo00009oooool00ol0003og]kNomkNgP0KomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03ooooon[og]kN00?o0000ooooooooool09Oooool00ol0003og]kNomkNgP0JomkNgPKo
oooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooon_og]kN00?o0000ooooooooool0
9Oooool00ol0003og]kNomkNgP0IomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooncog]kN1ol0000Qooooo`03o`000?oNg]kog]kN01Sog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?ooooolooNg]h00ol0003oooooooooo`0Nooooo`03o`000?oNg]ko
g]kN01Sog]kN1_ooool1o`00007ooooo000[ooooo`;o00001?ooooodomkNgP03o`000?oooooooooo
01gooooo00?o0000omkNg_oNg]h06?oNg]h5ooooo`;o00000Oooool002_ooooo00?o0000oooooooo
ool00ooooooeomkNgP[o00005Oooool00ol0003og]kNomkNgP0HomkNgPKooooo0Ol00001ooooo`00
:oooool00ol0003oooooooooo`03oooooooog]kN00?o0000ooooooooool04_ooool00ol0003og]kN
omkNgP0HomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN0OoN
g]h00ol0003oooooooooo`0Aooooo`03o`000?oNg]kog]kN01Sog]kN1_ooool1o`00007ooooo000[
ooooo`03o`000?oooooooooo00?ooooooooNg]h2omkNgPSo00002oooool00ol0003og]kNomkNgP0H
omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN2_oNg]h00ol0
003oooooooooo`07ooooo`03o`000?oNg]kog]kN01Wog]kN1_ooool1o`00007ooooo000[ooooo`03
o`000?oooooooooo00?ooooooooNg]h;omkNgP03o`000?oooooooooo00Gooooo00?o0000omkNg_oN
g]h06_oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00oooooooomkNgPcog]kN
1ol0000MomkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oN
g]h6ooooo`7o00000Oooool0017ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool02oooool00onHV9So8B4Qonk^kP07ooooo`?o00000oooooooomkNgS3og]kN1?ooool3o`00
007ooooo000Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003o
ooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
3Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooooooN
g]h`omkNgPKooooo0Ol00001ooooo`004Oooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Ooo
ool002_ooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[oooo
o`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003o
ooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool0
0oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooooooN
g]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6
ooooo`7o00000Oooool002_ooooo0_l00004oooooooog]kN<?oNg]h5ooooo`;o00000Oooool002_o
oooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`00
0?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool00ol0003ooooooooo
o`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000ooooooooool00ooooooo
omkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkN
gPKooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o
00000Oooool002_ooooo00?o0000ooooooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo
000[ooooo`03o`000?oooooooooo00?ooooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`03oooooooog]kN<?oNg]h6ooooo`7o00000Oooool002_ooooo00?o0000oooo
ooooool00oooooooomkNgS3og]kN1_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?o
oooooooNg]h`omkNgPKooooo0Ol00001ooooo`00:oooool2o`0000CooooooooNg]h`omkNgPGooooo
0_l00001ooooo`00:oooool00ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00:oooool0
0ol0003oooooooooo`3oooooocWooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`3ooooo
ocWooooo0Ol00001ooooo`00:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0:_ooool1o`00007ooooo000[ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`00:oooooooo`0003go00000Oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
We can check how well our approximate solution solves the Poisson \
equation by substituting it into the PDE:\
\>", "Text"],

Cell[BoxData[
    \(\(L[\[Phi][x, y]] - 1\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.22"],

Cell[TextData[{
  "The result deviates only slightly from zero, as shown in Cell ",
  ButtonBox["6.23",
    ButtonData:>"Cell 6.23",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[
        Abs[%]\ Boole[
            z[1, x, y] \[LessEqual] \ 0 && 
              z[2, x, y] \[GreaterEqual] 0], {x, \(-1\), 1}, {y, 0, 1.3}, 
        PlotPoints \[Rule] 50];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.23"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.82364 .18307 0 -6.079 ]
[.82364 .18307 18 2.921 ]
[.92719 .34165 0 -5.93039 ]
[.92719 .34165 6 3.06961 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01428 .32672 -30 -2.79442 ]
[.01428 .32672 0 6.20558 ]
[.00405 .39084 -30 -2.84887 ]
[.00405 .39084 0 6.15113 ]
[-0.0066 .45763 -30 -2.90583 ]
[-0.0066 .45763 0 6.09417 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.81126 .18741 m
.80507 .18959 L
s
[(0.5)] .82364 .18307 -1 .35089 Mshowa
.91468 .34562 m
.90843 .34761 L
s
[(1)] .92719 .34165 -1 .31786 Mshowa
.125 Mabswid
.71502 .0402 m
.71134 .04161 L
s
.74036 .07897 m
.73668 .08035 L
s
.76482 .11638 m
.76112 .11774 L
s
.78844 .15251 m
.78473 .15384 L
s
.83332 .22116 m
.82959 .22244 L
s
.85466 .2538 m
.85093 .25506 L
s
.87531 .28539 m
.87157 .28663 L
s
.89531 .31598 m
.89156 .3172 L
s
.93346 .37435 m
.92971 .37552 L
s
.95168 .40221 m
.94791 .40336 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02655 .32206 m
.03269 .31974 L
s
[(0.002)] .01428 .32672 1 -0.37902 Mshowa
.01637 .38632 m
.02253 .38406 L
s
[(0.004)] .00405 .39084 1 -0.36692 Mshowa
.00576 .45325 m
.01195 .45106 L
s
[(0.006)] -0.0066 .45763 1 -0.35426 Mshowa
.125 Mabswid
.03393 .27554 m
.0376 .27411 L
s
.03149 .29089 m
.03517 .28948 L
s
.02904 .3064 m
.03271 .305 L
s
.02405 .33789 m
.02773 .3365 L
s
.02151 .35387 m
.0252 .35249 L
s
.01896 .37001 m
.02265 .36864 L
s
.01376 .40279 m
.01746 .40145 L
s
.01112 .41944 m
.01483 .4181 L
s
.00846 .43626 m
.01216 .43493 L
s
.00304 .47042 m
.00676 .46912 L
s
.00029 .48778 m
.00401 .48648 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.39889 .59791 .40512 .60371 .41558 .60058 .40937 .59475 Metetra
.664 .741 .908 r
.40937 .59475 .41558 .60058 .42607 .59743 .41989 .59158 Metetra
.664 .741 .908 r
.41989 .59158 .42607 .59743 .4366 .59427 .43045 .5884 Metetra
.664 .741 .908 r
.43045 .5884 .4366 .59427 .44718 .59109 .44106 .5852 Metetra
.664 .741 .908 r
.44106 .5852 .44718 .59109 .4578 .58791 .4517 .582 Metetra
.664 .741 .908 r
.4517 .582 .4578 .58791 .46846 .58471 .46239 .57878 Metetra
.664 .741 .908 r
.46239 .57878 .46846 .58471 .47916 .5815 .47312 .57554 Metetra
.664 .741 .908 r
.47312 .57554 .47916 .5815 .4899 .57828 .48389 .57229 Metetra
.664 .741 .908 r
.48389 .57229 .4899 .57828 .50069 .57504 .4947 .56904 Metetra
.664 .741 .908 r
.4947 .56904 .50069 .57504 .51152 .57179 .50556 .56576 Metetra
.664 .741 .908 r
.50556 .56576 .51152 .57179 .52239 .56853 .51646 .56248 Metetra
.664 .741 .908 r
.51646 .56248 .52239 .56853 .5333 .56526 .5274 .55918 Metetra
.664 .741 .908 r
.5274 .55918 .5333 .56526 .54426 .56197 .53839 .55587 Metetra
.664 .741 .908 r
.53839 .55587 .54426 .56197 .55526 .55867 .54942 .55254 Metetra
.664 .741 .908 r
.54942 .55254 .55526 .55867 .56631 .55536 .56049 .5492 Metetra
.664 .741 .908 r
.56049 .5492 .56631 .55536 .5774 .55203 .57161 .54585 Metetra
.664 .741 .908 r
.57161 .54585 .5774 .55203 .58853 .54869 .58277 .54249 Metetra
.664 .741 .908 r
.58277 .54249 .58853 .54869 .59971 .54534 .59398 .53911 Metetra
.664 .741 .908 r
.59398 .53911 .59971 .54534 .61094 .54197 .60524 .53572 Metetra
.664 .741 .908 r
.60524 .53572 .61094 .54197 .62221 .53859 .61654 .53231 Metetra
.664 .741 .908 r
.61654 .53231 .62221 .53859 .63352 .53519 .62788 .52889 Metetra
.664 .741 .908 r
.62788 .52889 .63352 .53519 .64488 .53178 .63928 .52546 Metetra
.664 .741 .908 r
.63928 .52546 .64488 .53178 .65629 .52836 .65071 .52201 Metetra
.664 .741 .908 r
.65071 .52201 .65629 .52836 .66774 .52493 .6622 .51855 Metetra
.664 .741 .908 r
.6622 .51855 .66774 .52493 .67924 .52148 .67373 .51507 Metetra
.664 .741 .908 r
.67373 .51507 .67924 .52148 .69079 .51801 .68531 .51158 Metetra
.664 .741 .908 r
.68531 .51158 .69079 .51801 .70238 .51453 .69694 .50808 Metetra
.664 .741 .908 r
.69694 .50808 .70238 .51453 .71403 .51104 .70861 .50456 Metetra
.664 .741 .908 r
.70861 .50456 .71403 .51104 .72572 .50753 .72034 .50102 Metetra
.664 .741 .908 r
.72034 .50102 .72572 .50753 .73745 .50401 .73211 .49747 Metetra
.664 .741 .908 r
.73211 .49747 .73745 .50401 .74924 .50048 .74393 .49391 Metetra
.664 .741 .908 r
.74393 .49391 .74924 .50048 .76108 .49693 .7558 .49033 Metetra
.664 .741 .908 r
.7558 .49033 .76108 .49693 .77296 .49336 .76772 .48674 Metetra
.664 .741 .908 r
.76772 .48674 .77296 .49336 .78489 .48978 .77968 .48313 Metetra
.664 .741 .908 r
.77968 .48313 .78489 .48978 .79688 .48619 .7917 .47951 Metetra
.664 .741 .908 r
.7917 .47951 .79688 .48619 .80891 .48258 .80377 .47587 Metetra
.664 .741 .908 r
.80377 .47587 .80891 .48258 .82099 .47895 .81589 .47222 Metetra
.664 .741 .908 r
.81589 .47222 .82099 .47895 .83313 .47531 .82806 .46855 Metetra
.664 .741 .908 r
.82806 .46855 .83313 .47531 .84531 .47166 .84028 .46487 Metetra
.664 .741 .908 r
.84028 .46487 .84531 .47166 .85755 .46799 .85256 .46117 Metetra
.664 .741 .908 r
.85256 .46117 .85755 .46799 .86983 .4643 .86488 .45745 Metetra
.664 .741 .908 r
.86488 .45745 .86983 .4643 .88217 .4606 .87726 .45372 Metetra
.664 .741 .908 r
.87726 .45372 .88217 .4606 .89457 .45688 .88969 .44998 Metetra
.664 .741 .908 r
.88969 .44998 .89457 .45688 .90701 .45315 .90217 .44621 Metetra
.664 .741 .908 r
.90217 .44621 .90701 .45315 .91951 .4494 .91471 .44243 Metetra
.664 .741 .908 r
.91471 .44243 .91951 .4494 .93206 .44563 .9273 .43864 Metetra
.664 .741 .908 r
.9273 .43864 .93206 .44563 .94466 .44185 .93994 .43483 Metetra
.664 .741 .908 r
.93994 .43483 .94466 .44185 .95732 .43805 .95264 .431 Metetra
.664 .741 .908 r
.95264 .431 .95732 .43805 .97003 .43424 .96539 .42716 Metetra
.664 .741 .908 r
.39262 .59207 .39889 .59791 .40937 .59475 .40313 .58889 Metetra
.664 .741 .908 r
.40313 .58889 .40937 .59475 .41989 .59158 .41367 .5857 Metetra
.664 .741 .908 r
.41367 .5857 .41989 .59158 .43045 .5884 .42426 .58249 Metetra
.664 .741 .908 r
.42426 .58249 .43045 .5884 .44106 .5852 .43489 .57927 Metetra
.664 .741 .908 r
.43489 .57927 .44106 .5852 .4517 .582 .44556 .57604 Metetra
.664 .741 .908 r
.44556 .57604 .4517 .582 .46239 .57878 .45627 .5728 Metetra
.664 .741 .908 r
.45627 .5728 .46239 .57878 .47312 .57554 .46703 .56954 Metetra
.664 .741 .908 r
.46703 .56954 .47312 .57554 .48389 .57229 .47782 .56627 Metetra
.664 .741 .908 r
.47782 .56627 .48389 .57229 .4947 .56904 .48867 .56298 Metetra
.664 .741 .908 r
.48867 .56298 .4947 .56904 .50556 .56576 .49955 .55969 Metetra
.664 .741 .908 r
.49955 .55969 .50556 .56576 .51646 .56248 .51048 .55638 Metetra
.664 .741 .908 r
.51048 .55638 .51646 .56248 .5274 .55918 .52145 .55305 Metetra
.664 .741 .908 r
.52145 .55305 .5274 .55918 .53839 .55587 .53246 .54972 Metetra
.664 .741 .908 r
.53246 .54972 .53839 .55587 .54942 .55254 .54352 .54637 Metetra
.664 .741 .908 r
.54352 .54637 .54942 .55254 .56049 .5492 .55463 .54301 Metetra
.664 .741 .908 r
.55463 .54301 .56049 .5492 .57161 .54585 .56578 .53963 Metetra
.664 .741 .908 r
.56578 .53963 .57161 .54585 .58277 .54249 .57697 .53624 Metetra
.664 .741 .908 r
.57697 .53624 .58277 .54249 .59398 .53911 .58821 .53284 Metetra
.664 .741 .908 r
.58821 .53284 .59398 .53911 .60524 .53572 .5995 .52942 Metetra
.664 .741 .908 r
.5995 .52942 .60524 .53572 .61654 .53231 .61083 .52599 Metetra
.664 .741 .908 r
.61083 .52599 .61654 .53231 .62788 .52889 .6222 .52254 Metetra
.664 .741 .908 r
.6222 .52254 .62788 .52889 .63928 .52546 .63363 .51908 Metetra
.664 .741 .908 r
.63363 .51908 .63928 .52546 .65071 .52201 .6451 .51561 Metetra
.664 .741 .908 r
.6451 .51561 .65071 .52201 .6622 .51855 .65661 .51212 Metetra
.664 .741 .908 r
.65661 .51212 .6622 .51855 .67373 .51507 .66818 .50862 Metetra
.664 .741 .908 r
.66818 .50862 .67373 .51507 .68531 .51158 .67979 .5051 Metetra
.664 .741 .908 r
.67979 .5051 .68531 .51158 .69694 .50808 .69145 .50157 Metetra
.664 .741 .908 r
.69145 .50157 .69694 .50808 .70861 .50456 .70316 .49802 Metetra
.664 .741 .908 r
.70316 .49802 .70861 .50456 .72034 .50102 .71492 .49446 Metetra
.664 .741 .908 r
.71492 .49446 .72034 .50102 .73211 .49747 .72672 .49089 Metetra
.664 .741 .908 r
.72672 .49089 .73211 .49747 .74393 .49391 .73858 .48729 Metetra
.664 .741 .908 r
.73858 .48729 .74393 .49391 .7558 .49033 .75048 .48369 Metetra
.664 .741 .908 r
.75048 .48369 .7558 .49033 .76772 .48674 .76243 .48007 Metetra
.664 .741 .908 r
.76243 .48007 .76772 .48674 .77968 .48313 .77444 .47643 Metetra
.664 .741 .908 r
.77444 .47643 .77968 .48313 .7917 .47951 .78649 .47278 Metetra
.664 .741 .908 r
.78649 .47278 .7917 .47951 .80377 .47587 .79859 .46912 Metetra
.664 .741 .908 r
.79859 .46912 .80377 .47587 .81589 .47222 .81075 .46544 Metetra
.664 .741 .908 r
.81075 .46544 .81589 .47222 .82806 .46855 .82296 .46174 Metetra
.664 .741 .908 r
.82296 .46174 .82806 .46855 .84028 .46487 .83522 .45803 Metetra
.664 .741 .908 r
.83522 .45803 .84028 .46487 .85256 .46117 .84753 .4543 Metetra
.664 .741 .908 r
.84753 .4543 .85256 .46117 .86488 .45745 .85989 .45055 Metetra
.664 .741 .908 r
.85989 .45055 .86488 .45745 .87726 .45372 .8723 .44679 Metetra
.664 .741 .908 r
.8723 .44679 .87726 .45372 .88969 .44998 .88477 .44302 Metetra
.664 .741 .908 r
.88477 .44302 .88969 .44998 .90217 .44621 .89729 .43922 Metetra
.664 .741 .908 r
.89729 .43922 .90217 .44621 .91471 .44243 .90987 .43542 Metetra
.664 .741 .908 r
.90987 .43542 .91471 .44243 .9273 .43864 .9225 .43159 Metetra
.664 .741 .908 r
.9225 .43159 .9273 .43864 .93994 .43483 .93518 .42775 Metetra
.664 .741 .908 r
.93518 .42775 .93994 .43483 .95264 .431 .94792 .42389 Metetra
.664 .741 .908 r
.94792 .42389 .95264 .431 .96539 .42716 .96071 .42002 Metetra
.664 .741 .908 r
.3863 .58619 .39262 .59207 .40313 .58889 .39683 .58298 Metetra
.664 .741 .908 r
.39683 .58298 .40313 .58889 .41367 .5857 .4074 .57977 Metetra
.664 .741 .908 r
.4074 .57977 .41367 .5857 .42426 .58249 .41802 .57654 Metetra
.664 .741 .908 r
.41802 .57654 .42426 .58249 .43489 .57927 .42867 .5733 Metetra
.664 .741 .908 r
.42867 .5733 .43489 .57927 .44556 .57604 .43937 .57004 Metetra
.664 .741 .908 r
.43937 .57004 .44556 .57604 .45627 .5728 .45011 .56677 Metetra
.664 .741 .908 r
.45011 .56677 .45627 .5728 .46703 .56954 .46089 .56349 Metetra
.664 .741 .908 r
.46089 .56349 .46703 .56954 .47782 .56627 .47172 .5602 Metetra
.664 .741 .908 r
.47172 .5602 .47782 .56627 .48867 .56298 .48259 .55689 Metetra
.664 .741 .908 r
.48259 .55689 .48867 .56298 .49955 .55969 .4935 .55357 Metetra
.664 .741 .908 r
.4935 .55357 .49955 .55969 .51048 .55638 .50446 .55023 Metetra
.664 .741 .908 r
.50446 .55023 .51048 .55638 .52145 .55305 .51546 .54689 Metetra
.664 .741 .908 r
.51546 .54689 .52145 .55305 .53246 .54972 .5265 .54352 Metetra
.664 .741 .908 r
.5265 .54352 .53246 .54972 .54352 .54637 .53759 .54015 Metetra
.664 .741 .908 r
.53759 .54015 .54352 .54637 .55463 .54301 .54872 .53676 Metetra
.664 .741 .908 r
.54872 .53676 .55463 .54301 .56578 .53963 .5599 .53336 Metetra
.664 .741 .908 r
.5599 .53336 .56578 .53963 .57697 .53624 .57113 .52994 Metetra
.664 .741 .908 r
.57113 .52994 .57697 .53624 .58821 .53284 .58239 .52651 Metetra
.664 .741 .908 r
.58239 .52651 .58821 .53284 .5995 .52942 .59371 .52307 Metetra
.664 .741 .908 r
.59371 .52307 .5995 .52942 .61083 .52599 .60507 .51961 Metetra
.664 .741 .908 r
.60507 .51961 .61083 .52599 .6222 .52254 .61648 .51614 Metetra
.664 .741 .908 r
.61648 .51614 .6222 .52254 .63363 .51908 .62794 .51266 Metetra
.664 .741 .908 r
.62794 .51266 .63363 .51908 .6451 .51561 .63944 .50916 Metetra
.664 .741 .908 r
.63944 .50916 .6451 .51561 .65661 .51212 .65099 .50564 Metetra
.664 .741 .908 r
.65099 .50564 .65661 .51212 .66818 .50862 .66258 .50211 Metetra
.664 .741 .908 r
.66258 .50211 .66818 .50862 .67979 .5051 .67423 .49857 Metetra
.664 .741 .908 r
.67423 .49857 .67979 .5051 .69145 .50157 .68592 .49501 Metetra
.664 .741 .908 r
.68592 .49501 .69145 .50157 .70316 .49802 .69766 .49144 Metetra
.664 .741 .908 r
.69766 .49144 .70316 .49802 .71492 .49446 .70945 .48785 Metetra
.664 .741 .908 r
.70945 .48785 .71492 .49446 .72672 .49089 .72129 .48425 Metetra
.664 .741 .908 r
.72129 .48425 .72672 .49089 .73858 .48729 .73318 .48063 Metetra
.664 .741 .908 r
.73318 .48063 .73858 .48729 .75048 .48369 .74512 .47699 Metetra
.664 .741 .908 r
.74512 .47699 .75048 .48369 .76243 .48007 .75711 .47335 Metetra
.664 .741 .908 r
.75711 .47335 .76243 .48007 .77444 .47643 .76915 .46968 Metetra
.664 .741 .908 r
.76915 .46968 .77444 .47643 .78649 .47278 .78124 .466 Metetra
.664 .741 .908 r
.78124 .466 .78649 .47278 .79859 .46912 .79338 .46231 Metetra
.664 .741 .908 r
.79338 .46231 .79859 .46912 .81075 .46544 .80557 .4586 Metetra
.664 .741 .908 r
.80557 .4586 .81075 .46544 .82296 .46174 .81781 .45487 Metetra
.664 .741 .908 r
.81781 .45487 .82296 .46174 .83522 .45803 .83011 .45113 Metetra
.664 .741 .908 r
.83011 .45113 .83522 .45803 .84753 .4543 .84246 .44737 Metetra
.664 .741 .908 r
.84246 .44737 .84753 .4543 .85989 .45055 .85486 .4436 Metetra
.664 .741 .908 r
.85486 .4436 .85989 .45055 .8723 .44679 .86731 .43981 Metetra
.664 .741 .908 r
.86731 .43981 .8723 .44679 .88477 .44302 .87982 .436 Metetra
.664 .741 .908 r
.87982 .436 .88477 .44302 .89729 .43922 .89238 .43218 Metetra
.664 .741 .908 r
.89238 .43218 .89729 .43922 .90987 .43542 .90499 .42834 Metetra
.664 .741 .908 r
.90499 .42834 .90987 .43542 .9225 .43159 .91766 .42449 Metetra
.664 .741 .908 r
.91766 .42449 .9225 .43159 .93518 .42775 .93038 .42061 Metetra
.664 .741 .908 r
.93038 .42061 .93518 .42775 .94792 .42389 .94316 .41673 Metetra
.664 .741 .908 r
.94316 .41673 .94792 .42389 .96071 .42002 .956 .41282 Metetra
.664 .741 .908 r
.37994 .58026 .3863 .58619 .39683 .58298 .39049 .57704 Metetra
.664 .741 .908 r
.39049 .57704 .39683 .58298 .4074 .57977 .40109 .57379 Metetra
.664 .741 .908 r
.40109 .57379 .4074 .57977 .41802 .57654 .41173 .57054 Metetra
.664 .741 .908 r
.41173 .57054 .41802 .57654 .42867 .5733 .42241 .56727 Metetra
.664 .741 .908 r
.42241 .56727 .42867 .5733 .43937 .57004 .43314 .564 Metetra
.664 .741 .908 r
.43314 .564 .43937 .57004 .45011 .56677 .4439 .5607 Metetra
.664 .741 .908 r
.4439 .5607 .45011 .56677 .46089 .56349 .45471 .5574 Metetra
.664 .741 .908 r
.45471 .5574 .46089 .56349 .47172 .5602 .46557 .55408 Metetra
.664 .741 .908 r
.46557 .55408 .47172 .5602 .48259 .55689 .47646 .55075 Metetra
.664 .741 .908 r
.47646 .55075 .48259 .55689 .4935 .55357 .4874 .5474 Metetra
.664 .741 .908 r
.4874 .5474 .4935 .55357 .50446 .55023 .49839 .54404 Metetra
.664 .741 .908 r
.49839 .54404 .50446 .55023 .51546 .54689 .50942 .54067 Metetra
.664 .741 .908 r
.50942 .54067 .51546 .54689 .5265 .54352 .52049 .53728 Metetra
.664 .741 .908 r
.52049 .53728 .5265 .54352 .53759 .54015 .53161 .53388 Metetra
.664 .741 .908 r
.53161 .53388 .53759 .54015 .54872 .53676 .54277 .53047 Metetra
.664 .741 .908 r
.54277 .53047 .54872 .53676 .5599 .53336 .55398 .52704 Metetra
.664 .741 .908 r
.55398 .52704 .5599 .53336 .57113 .52994 .56524 .5236 Metetra
.664 .741 .908 r
.56524 .5236 .57113 .52994 .58239 .52651 .57654 .52015 Metetra
.664 .741 .908 r
.57654 .52015 .58239 .52651 .59371 .52307 .58788 .51668 Metetra
.664 .741 .908 r
.58788 .51668 .59371 .52307 .60507 .51961 .59927 .51319 Metetra
.664 .741 .908 r
.59927 .51319 .60507 .51961 .61648 .51614 .61071 .50969 Metetra
.664 .741 .908 r
.61071 .50969 .61648 .51614 .62794 .51266 .6222 .50618 Metetra
.664 .741 .908 r
.6222 .50618 .62794 .51266 .63944 .50916 .63373 .50266 Metetra
.664 .741 .908 r
.63373 .50266 .63944 .50916 .65099 .50564 .64532 .49911 Metetra
.664 .741 .908 r
.64532 .49911 .65099 .50564 .66258 .50211 .65694 .49556 Metetra
.664 .741 .908 r
.65694 .49556 .66258 .50211 .67423 .49857 .66862 .49199 Metetra
.664 .741 .908 r
.66862 .49199 .67423 .49857 .68592 .49501 .68035 .4884 Metetra
.664 .741 .908 r
.68035 .4884 .68592 .49501 .69766 .49144 .69212 .4848 Metetra
.664 .741 .908 r
.69212 .4848 .69766 .49144 .70945 .48785 .70395 .48118 Metetra
.664 .741 .908 r
.70395 .48118 .70945 .48785 .72129 .48425 .71582 .47755 Metetra
.664 .741 .908 r
.71582 .47755 .72129 .48425 .73318 .48063 .72774 .47391 Metetra
.664 .741 .908 r
.72774 .47391 .73318 .48063 .74512 .47699 .73972 .47025 Metetra
.664 .741 .908 r
.73972 .47025 .74512 .47699 .75711 .47335 .75174 .46657 Metetra
.664 .741 .908 r
.75174 .46657 .75711 .47335 .76915 .46968 .76382 .46288 Metetra
.664 .741 .908 r
.76382 .46288 .76915 .46968 .78124 .466 .77594 .45917 Metetra
.664 .741 .908 r
.77594 .45917 .78124 .466 .79338 .46231 .78812 .45545 Metetra
.664 .741 .908 r
.78812 .45545 .79338 .46231 .80557 .4586 .80035 .45171 Metetra
.664 .741 .908 r
.80035 .45171 .80557 .4586 .81781 .45487 .81263 .44795 Metetra
.664 .741 .908 r
.81263 .44795 .81781 .45487 .83011 .45113 .82496 .44418 Metetra
.664 .741 .908 r
.82496 .44418 .83011 .45113 .84246 .44737 .83735 .44039 Metetra
.664 .741 .908 r
.83735 .44039 .84246 .44737 .85486 .4436 .84978 .43659 Metetra
.664 .741 .908 r
.84978 .43659 .85486 .4436 .86731 .43981 .86228 .43277 Metetra
.664 .741 .908 r
.86228 .43277 .86731 .43981 .87982 .436 .87482 .42893 Metetra
.664 .741 .908 r
.87482 .42893 .87982 .436 .89238 .43218 .88742 .42508 Metetra
.664 .741 .908 r
.88742 .42508 .89238 .43218 .90499 .42834 .90008 .42121 Metetra
.664 .741 .908 r
.90008 .42121 .90499 .42834 .91766 .42449 .91278 .41732 Metetra
.664 .741 .908 r
.91278 .41732 .91766 .42449 .93038 .42061 .92555 .41342 Metetra
.664 .741 .908 r
.92555 .41342 .93038 .42061 .94316 .41673 .93837 .4095 Metetra
.664 .741 .908 r
.93837 .4095 .94316 .41673 .956 .41282 .95124 .40556 Metetra
.664 .741 .908 r
.37353 .57429 .37994 .58026 .39049 .57704 .38411 .57104 Metetra
.664 .741 .908 r
.38411 .57104 .39049 .57704 .40109 .57379 .39473 .56778 Metetra
.664 .741 .908 r
.39473 .56778 .40109 .57379 .41173 .57054 .4054 .5645 Metetra
.664 .741 .908 r
.4054 .5645 .41173 .57054 .42241 .56727 .41611 .56121 Metetra
.664 .741 .908 r
.41611 .56121 .42241 .56727 .43314 .564 .42686 .55791 Metetra
.664 .741 .908 r
.42686 .55791 .43314 .564 .4439 .5607 .43765 .55459 Metetra
.664 .741 .908 r
.43765 .55459 .4439 .5607 .45471 .5574 .44849 .55126 Metetra
.664 .741 .908 r
.44849 .55126 .45471 .5574 .46557 .55408 .45937 .54792 Metetra
.664 .741 .908 r
.45937 .54792 .46557 .55408 .47646 .55075 .4703 .54456 Metetra
.664 .741 .908 r
.4703 .54456 .47646 .55075 .4874 .5474 .48126 .54119 Metetra
.664 .741 .908 r
.48126 .54119 .4874 .5474 .49839 .54404 .49228 .53781 Metetra
.664 .741 .908 r
.49228 .53781 .49839 .54404 .50942 .54067 .50334 .53441 Metetra
.664 .741 .908 r
.50334 .53441 .50942 .54067 .52049 .53728 .51444 .531 Metetra
.664 .741 .908 r
.51444 .531 .52049 .53728 .53161 .53388 .52558 .52757 Metetra
.664 .741 .908 r
.52558 .52757 .53161 .53388 .54277 .53047 .53678 .52413 Metetra
.664 .741 .908 r
.53678 .52413 .54277 .53047 .55398 .52704 .54802 .52068 Metetra
.664 .741 .908 r
.54802 .52068 .55398 .52704 .56524 .5236 .5593 .51721 Metetra
.664 .741 .908 r
.5593 .51721 .56524 .5236 .57654 .52015 .57063 .51373 Metetra
.664 .741 .908 r
.57063 .51373 .57654 .52015 .58788 .51668 .58201 .51023 Metetra
.664 .741 .908 r
.58201 .51023 .58788 .51668 .59927 .51319 .59343 .50672 Metetra
.664 .741 .908 r
.59343 .50672 .59927 .51319 .61071 .50969 .6049 .5032 Metetra
.664 .741 .908 r
.6049 .5032 .61071 .50969 .6222 .50618 .61642 .49966 Metetra
.664 .741 .908 r
.61642 .49966 .6222 .50618 .63373 .50266 .62799 .49611 Metetra
.664 .741 .908 r
.62799 .49611 .63373 .50266 .64532 .49911 .6396 .49254 Metetra
.664 .741 .908 r
.6396 .49254 .64532 .49911 .65694 .49556 .65126 .48895 Metetra
.664 .741 .908 r
.65126 .48895 .65694 .49556 .66862 .49199 .66297 .48536 Metetra
.664 .741 .908 r
.66297 .48536 .66862 .49199 .68035 .4884 .67473 .48174 Metetra
.664 .741 .908 r
.67473 .48174 .68035 .4884 .69212 .4848 .68654 .47811 Metetra
.664 .741 .908 r
.68654 .47811 .69212 .4848 .70395 .48118 .6984 .47447 Metetra
.664 .741 .908 r
.6984 .47447 .70395 .48118 .71582 .47755 .71031 .47081 Metetra
.664 .741 .908 r
.71031 .47081 .71582 .47755 .72774 .47391 .72227 .46714 Metetra
.664 .741 .908 r
.72227 .46714 .72774 .47391 .73972 .47025 .73427 .46345 Metetra
.664 .741 .908 r
.73427 .46345 .73972 .47025 .75174 .46657 .74633 .45974 Metetra
.664 .741 .908 r
.74633 .45974 .75174 .46657 .76382 .46288 .75844 .45602 Metetra
.664 .741 .908 r
.75844 .45602 .76382 .46288 .77594 .45917 .77061 .45228 Metetra
.664 .741 .908 r
.77061 .45228 .77594 .45917 .78812 .45545 .78282 .44853 Metetra
.664 .741 .908 r
.78282 .44853 .78812 .45545 .80035 .45171 .79508 .44476 Metetra
.664 .741 .908 r
.79508 .44476 .80035 .45171 .81263 .44795 .8074 .44098 Metetra
.664 .741 .908 r
.8074 .44098 .81263 .44795 .82496 .44418 .81977 .43718 Metetra
.664 .741 .908 r
.81977 .43718 .82496 .44418 .83735 .44039 .8322 .43336 Metetra
.664 .741 .908 r
.8322 .43336 .83735 .44039 .84978 .43659 .84467 .42952 Metetra
.664 .741 .908 r
.84467 .42952 .84978 .43659 .86228 .43277 .8572 .42567 Metetra
.664 .741 .908 r
.8572 .42567 .86228 .43277 .87482 .42893 .86979 .42181 Metetra
.664 .741 .908 r
.86979 .42181 .87482 .42893 .88742 .42508 .88243 .41792 Metetra
.664 .741 .908 r
.88243 .41792 .88742 .42508 .90008 .42121 .89512 .41402 Metetra
.664 .741 .908 r
.89512 .41402 .90008 .42121 .91278 .41732 .90787 .41011 Metetra
.664 .741 .908 r
.90787 .41011 .91278 .41732 .92555 .41342 .92067 .40617 Metetra
.664 .741 .908 r
.92067 .40617 .92555 .41342 .93837 .4095 .93353 .40222 Metetra
.664 .741 .908 r
.93353 .40222 .93837 .4095 .95124 .40556 .94645 .39825 Metetra
.664 .741 .908 r
.36707 .56828 .37353 .57429 .38411 .57104 .37768 .56501 Metetra
.664 .741 .908 r
.37768 .56501 .38411 .57104 .39473 .56778 .38833 .56172 Metetra
.664 .741 .908 r
.38833 .56172 .39473 .56778 .4054 .5645 .39902 .55842 Metetra
.664 .741 .908 r
.39902 .55842 .4054 .5645 .41611 .56121 .40975 .5551 Metetra
.664 .741 .908 r
.40975 .5551 .41611 .56121 .42686 .55791 .42053 .55177 Metetra
.664 .741 .908 r
.42053 .55177 .42686 .55791 .43765 .55459 .43135 .54843 Metetra
.664 .741 .908 r
.43135 .54843 .43765 .55459 .44849 .55126 .44222 .54508 Metetra
.664 .741 .908 r
.44222 .54508 .44849 .55126 .45937 .54792 .45313 .54171 Metetra
.664 .741 .908 r
.45313 .54171 .45937 .54792 .4703 .54456 .46408 .53833 Metetra
.664 .741 .908 r
.46408 .53833 .4703 .54456 .48126 .54119 .47508 .53493 Metetra
.664 .741 .908 r
.47508 .53493 .48126 .54119 .49228 .53781 .48612 .53152 Metetra
.664 .741 .908 r
.48612 .53152 .49228 .53781 .50334 .53441 .49721 .5281 Metetra
.664 .741 .908 r
.49721 .5281 .50334 .53441 .51444 .531 .50834 .52466 Metetra
.664 .741 .908 r
.50834 .52466 .51444 .531 .52558 .52757 .51952 .52121 Metetra
.664 .741 .908 r
.51952 .52121 .52558 .52757 .53678 .52413 .53074 .51775 Metetra
.664 .741 .908 r
.53074 .51775 .53678 .52413 .54802 .52068 .54201 .51427 Metetra
.664 .741 .908 r
.54201 .51427 .54802 .52068 .5593 .51721 .55332 .51077 Metetra
.664 .741 .908 r
.55332 .51077 .5593 .51721 .57063 .51373 .56468 .50726 Metetra
.664 .741 .908 r
.56468 .50726 .57063 .51373 .58201 .51023 .57609 .50374 Metetra
.664 .741 .908 r
.57609 .50374 .58201 .51023 .59343 .50672 .58755 .50021 Metetra
.664 .741 .908 r
.58755 .50021 .59343 .50672 .6049 .5032 .59905 .49665 Metetra
.664 .741 .908 r
.59905 .49665 .6049 .5032 .61642 .49966 .6106 .49309 Metetra
.664 .741 .908 r
.6106 .49309 .61642 .49966 .62799 .49611 .6222 .48951 Metetra
.664 .741 .908 r
.6222 .48951 .62799 .49611 .6396 .49254 .63384 .48591 Metetra
.664 .741 .908 r
.63384 .48591 .6396 .49254 .65126 .48895 .64554 .4823 Metetra
.664 .741 .908 r
.64554 .4823 .65126 .48895 .66297 .48536 .65728 .47867 Metetra
.664 .741 .908 r
.65728 .47867 .66297 .48536 .67473 .48174 .66907 .47503 Metetra
.664 .741 .908 r
.66907 .47503 .67473 .48174 .68654 .47811 .68092 .47137 Metetra
.664 .741 .908 r
.68092 .47137 .68654 .47811 .6984 .47447 .69281 .4677 Metetra
.664 .741 .908 r
.69281 .4677 .6984 .47447 .71031 .47081 .70475 .46402 Metetra
.664 .741 .908 r
.70475 .46402 .71031 .47081 .72227 .46714 .71675 .46031 Metetra
.664 .741 .908 r
.71675 .46031 .72227 .46714 .73427 .46345 .72879 .45659 Metetra
.664 .741 .908 r
.72879 .45659 .73427 .46345 .74633 .45974 .74088 .45286 Metetra
.664 .741 .908 r
.74088 .45286 .74633 .45974 .75844 .45602 .75303 .44911 Metetra
.664 .741 .908 r
.75303 .44911 .75844 .45602 .77061 .45228 .76523 .44534 Metetra
.664 .741 .908 r
.76523 .44534 .77061 .45228 .78282 .44853 .77748 .44156 Metetra
.664 .741 .908 r
.77748 .44156 .78282 .44853 .79508 .44476 .78978 .43776 Metetra
.664 .741 .908 r
.78978 .43776 .79508 .44476 .8074 .44098 .80214 .43395 Metetra
.664 .741 .908 r
.80214 .43395 .8074 .44098 .81977 .43718 .81454 .43012 Metetra
.664 .741 .908 r
.81454 .43012 .81977 .43718 .8322 .43336 .827 .42627 Metetra
.664 .741 .908 r
.827 .42627 .8322 .43336 .84467 .42952 .83952 .4224 Metetra
.664 .741 .908 r
.83952 .4224 .84467 .42952 .8572 .42567 .85209 .41852 Metetra
.664 .741 .908 r
.85209 .41852 .8572 .42567 .86979 .42181 .86471 .41462 Metetra
.664 .741 .908 r
.86471 .41462 .86979 .42181 .88243 .41792 .87739 .41071 Metetra
.664 .741 .908 r
.87739 .41071 .88243 .41792 .89512 .41402 .89013 .40678 Metetra
.94 .587 .182 r
.89013 .40678 .89512 .41402 .90787 .41011 .91597 .51423 Metetra
.299 .14 .49 r
.91597 .51423 .90787 .41011 .92067 .40617 .92046 .43758 Metetra
.908 .574 .4 r
.92046 .43758 .92067 .40617 .93353 .40222 .95111 .57373 Metetra
.619 .381 .534 r
.95111 .57373 .93353 .40222 .94645 .39825 .97041 .61284 Metetra
.664 .741 .908 r
.36056 .56222 .36707 .56828 .37768 .56501 .3712 .55892 Metetra
.664 .741 .908 r
.3712 .55892 .37768 .56501 .38833 .56172 .38187 .55561 Metetra
.664 .741 .908 r
.38187 .55561 .38833 .56172 .39902 .55842 .39259 .55229 Metetra
.664 .741 .908 r
.39259 .55229 .39902 .55842 .40975 .5551 .40336 .54895 Metetra
.664 .741 .908 r
.40336 .54895 .40975 .5551 .42053 .55177 .41416 .54559 Metetra
.664 .741 .908 r
.41416 .54559 .42053 .55177 .43135 .54843 .42501 .54223 Metetra
.664 .741 .908 r
.42501 .54223 .43135 .54843 .44222 .54508 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .44222 .54508 .45313 .54171 .44684 .53545 Metetra
.664 .741 .908 r
.44684 .53545 .45313 .54171 .46408 .53833 .45782 .53205 Metetra
.664 .741 .908 r
.45782 .53205 .46408 .53833 .47508 .53493 .46885 .52863 Metetra
.664 .741 .908 r
.46885 .52863 .47508 .53493 .48612 .53152 .47992 .52519 Metetra
.664 .741 .908 r
.47992 .52519 .48612 .53152 .49721 .5281 .49103 .52174 Metetra
.664 .741 .908 r
.49103 .52174 .49721 .5281 .50834 .52466 .50219 .51828 Metetra
.664 .741 .908 r
.50219 .51828 .50834 .52466 .51952 .52121 .5134 .5148 Metetra
.664 .741 .908 r
.5134 .5148 .51952 .52121 .53074 .51775 .52465 .51131 Metetra
.664 .741 .908 r
.52465 .51131 .53074 .51775 .54201 .51427 .53595 .50781 Metetra
.664 .741 .908 r
.53595 .50781 .54201 .51427 .55332 .51077 .5473 .50429 Metetra
.664 .741 .908 r
.5473 .50429 .55332 .51077 .56468 .50726 .55869 .50075 Metetra
.664 .741 .908 r
.55869 .50075 .56468 .50726 .57609 .50374 .57013 .4972 Metetra
.664 .741 .908 r
.57013 .4972 .57609 .50374 .58755 .50021 .58161 .49364 Metetra
.664 .741 .908 r
.58161 .49364 .58755 .50021 .59905 .49665 .59315 .49006 Metetra
.664 .741 .908 r
.59315 .49006 .59905 .49665 .6106 .49309 .60473 .48646 Metetra
.664 .741 .908 r
.60473 .48646 .6106 .49309 .6222 .48951 .61636 .48286 Metetra
.664 .741 .908 r
.61636 .48286 .6222 .48951 .63384 .48591 .62804 .47923 Metetra
.664 .741 .908 r
.62804 .47923 .63384 .48591 .64554 .4823 .63977 .47559 Metetra
.664 .741 .908 r
.63977 .47559 .64554 .4823 .65728 .47867 .65155 .47194 Metetra
.664 .741 .908 r
.65155 .47194 .65728 .47867 .66907 .47503 .66337 .46827 Metetra
.664 .741 .908 r
.66337 .46827 .66907 .47503 .68092 .47137 .67525 .46458 Metetra
.664 .741 .908 r
.67525 .46458 .68092 .47137 .69281 .4677 .68718 .46088 Metetra
.664 .741 .908 r
.68718 .46088 .69281 .4677 .70475 .46402 .69915 .45717 Metetra
.664 .741 .908 r
.69915 .45717 .70475 .46402 .71675 .46031 .71118 .45343 Metetra
.664 .741 .908 r
.71118 .45343 .71675 .46031 .72879 .45659 .72326 .44969 Metetra
.664 .741 .908 r
.72326 .44969 .72879 .45659 .74088 .45286 .73539 .44592 Metetra
.664 .741 .908 r
.73539 .44592 .74088 .45286 .75303 .44911 .74757 .44214 Metetra
.664 .741 .908 r
.74757 .44214 .75303 .44911 .76523 .44534 .75981 .43835 Metetra
.664 .741 .908 r
.75981 .43835 .76523 .44534 .77748 .44156 .77209 .43453 Metetra
.664 .741 .908 r
.77209 .43453 .77748 .44156 .78978 .43776 .78443 .43071 Metetra
.664 .741 .908 r
.78443 .43071 .78978 .43776 .80214 .43395 .79683 .42686 Metetra
.664 .741 .908 r
.79683 .42686 .80214 .43395 .81454 .43012 .80927 .423 Metetra
.664 .741 .908 r
.80927 .423 .81454 .43012 .827 .42627 .82177 .41912 Metetra
.664 .741 .908 r
.82177 .41912 .827 .42627 .83952 .4224 .83433 .41523 Metetra
.967 .641 .294 r
.83433 .41523 .83952 .4224 .85209 .41852 .86891 .63202 Metetra
.56 .34 .538 r
.86891 .63202 .85209 .41852 .86471 .41462 .88249 .62833 Metetra
.556 .337 .538 r
.88249 .62833 .86471 .41462 .87739 .41071 .89586 .62202 Metetra
.395 .221 .523 r
.89586 .62202 .87739 .41071 .89013 .40678 .89796 .51462 Metetra
.156 .038 .456 r
.89796 .51462 .89013 .40678 .91597 .51423 .8991 .40563 Metetra
.336 .225 .577 r
.8991 .40563 .91597 .51423 .92046 .43758 .92085 .47516 Metetra
.803 .48 .443 r
.92085 .47516 .92046 .43758 .95111 .57373 .94222 .53614 Metetra
.583 .447 .661 r
.94222 .53614 .95111 .57373 .97041 .61284 .95624 .53518 Metetra
.664 .741 .908 r
.35401 .55612 .36056 .56222 .3712 .55892 .36467 .5528 Metetra
.664 .741 .908 r
.36467 .5528 .3712 .55892 .38187 .55561 .37537 .54946 Metetra
.664 .741 .908 r
.37537 .54946 .38187 .55561 .39259 .55229 .38612 .54611 Metetra
.664 .741 .908 r
.38612 .54611 .39259 .55229 .40336 .54895 .39691 .54275 Metetra
.664 .741 .908 r
.39691 .54275 .40336 .54895 .41416 .54559 .40774 .53937 Metetra
.664 .741 .908 r
.40774 .53937 .41416 .54559 .42501 .54223 .41862 .53598 Metetra
.664 .741 .908 r
.41862 .53598 .42501 .54223 .4359 .53885 .42954 .53257 Metetra
.664 .741 .908 r
.42954 .53257 .4359 .53885 .44684 .53545 .4405 .52915 Metetra
.664 .741 .908 r
.4405 .52915 .44684 .53545 .45782 .53205 .45151 .52572 Metetra
.664 .741 .908 r
.45151 .52572 .45782 .53205 .46885 .52863 .46257 .52227 Metetra
.664 .741 .908 r
.46257 .52227 .46885 .52863 .47992 .52519 .47367 .51881 Metetra
.664 .741 .908 r
.47367 .51881 .47992 .52519 .49103 .52174 .48481 .51534 Metetra
.664 .741 .908 r
.48481 .51534 .49103 .52174 .50219 .51828 .496 .51185 Metetra
.664 .741 .908 r
.496 .51185 .50219 .51828 .5134 .5148 .50724 .50835 Metetra
.664 .741 .908 r
.50724 .50835 .5134 .5148 .52465 .51131 .51852 .50483 Metetra
.664 .741 .908 r
.51852 .50483 .52465 .51131 .53595 .50781 .52985 .5013 Metetra
.664 .741 .908 r
.52985 .5013 .53595 .50781 .5473 .50429 .54123 .49775 Metetra
.664 .741 .908 r
.54123 .49775 .5473 .50429 .55869 .50075 .55265 .49419 Metetra
.664 .741 .908 r
.55265 .49419 .55869 .50075 .57013 .4972 .56412 .49061 Metetra
.664 .741 .908 r
.56412 .49061 .57013 .4972 .58161 .49364 .57564 .48702 Metetra
.664 .741 .908 r
.57564 .48702 .58161 .49364 .59315 .49006 .5872 .48341 Metetra
.664 .741 .908 r
.5872 .48341 .59315 .49006 .60473 .48646 .59882 .47979 Metetra
.664 .741 .908 r
.59882 .47979 .60473 .48646 .61636 .48286 .61048 .47615 Metetra
.664 .741 .908 r
.61048 .47615 .61636 .48286 .62804 .47923 .62219 .4725 Metetra
.664 .741 .908 r
.62219 .4725 .62804 .47923 .63977 .47559 .63395 .46883 Metetra
.664 .741 .908 r
.63395 .46883 .63977 .47559 .65155 .47194 .64577 .46515 Metetra
.664 .741 .908 r
.64577 .46515 .65155 .47194 .66337 .46827 .65763 .46145 Metetra
.664 .741 .908 r
.65763 .46145 .66337 .46827 .67525 .46458 .66954 .45774 Metetra
.664 .741 .908 r
.66954 .45774 .67525 .46458 .68718 .46088 .6815 .45401 Metetra
.664 .741 .908 r
.6815 .45401 .68718 .46088 .69915 .45717 .69351 .45026 Metetra
.664 .741 .908 r
.69351 .45026 .69915 .45717 .71118 .45343 .70557 .4465 Metetra
.664 .741 .908 r
.70557 .4465 .71118 .45343 .72326 .44969 .71769 .44273 Metetra
.664 .741 .908 r
.71769 .44273 .72326 .44969 .73539 .44592 .72985 .43893 Metetra
.664 .741 .908 r
.72985 .43893 .73539 .44592 .74757 .44214 .74207 .43512 Metetra
.664 .741 .908 r
.74207 .43512 .74757 .44214 .75981 .43835 .75434 .4313 Metetra
.664 .741 .908 r
.75434 .4313 .75981 .43835 .77209 .43453 .76667 .42745 Metetra
.664 .741 .908 r
.76667 .42745 .77209 .43453 .78443 .43071 .77904 .42359 Metetra
.964 .635 .296 r
.77904 .42359 .78443 .43071 .79683 .42686 .80399 .57191 Metetra
.645 .398 .53 r
.80399 .57191 .79683 .42686 .80927 .423 .82174 .62212 Metetra
.577 .351 .536 r
.82174 .62212 .80927 .423 .82177 .41912 .83639 .63258 Metetra
.558 .338 .536 r
.83639 .63258 .82177 .41912 .83433 .41523 .84989 .6289 Metetra
.534 .32 .535 r
.84989 .6289 .83433 .41523 .86891 .63202 .8617 .60736 Metetra
.884 .656 .589 r
.8617 .60736 .86891 .63202 .88249 .62833 .86981 .55034 Metetra
.763 .529 .579 r
.86981 .55034 .88249 .62833 .89586 .62202 .87601 .47891 Metetra
.697 .469 .573 r
.87601 .47891 .89586 .62202 .89796 .51462 .88141 .40473 Metetra
.474 .319 .589 r
.88141 .40473 .89796 .51462 .8991 .40563 .89841 .43632 Metetra
.741 .417 .434 r
.89841 .43632 .8991 .40563 .92085 .47516 .91585 .46856 Metetra
.886 .827 .784 r
.91585 .46856 .92085 .47516 .94222 .53614 .9277 .45238 Metetra
.741 .509 .579 r
.9277 .45238 .94222 .53614 .95624 .53518 .93341 .38829 Metetra
.664 .741 .908 r
.34741 .54998 .35401 .55612 .36467 .5528 .3581 .54663 Metetra
.664 .741 .908 r
.3581 .54663 .36467 .5528 .37537 .54946 .36882 .54327 Metetra
.664 .741 .908 r
.36882 .54327 .37537 .54946 .38612 .54611 .3796 .53989 Metetra
.664 .741 .908 r
.3796 .53989 .38612 .54611 .39691 .54275 .39041 .5365 Metetra
.664 .741 .908 r
.39041 .5365 .39691 .54275 .40774 .53937 .40127 .5331 Metetra
.664 .741 .908 r
.40127 .5331 .40774 .53937 .41862 .53598 .41218 .52968 Metetra
.664 .741 .908 r
.41218 .52968 .41862 .53598 .42954 .53257 .42313 .52625 Metetra
.664 .741 .908 r
.42313 .52625 .42954 .53257 .4405 .52915 .43412 .52281 Metetra
.664 .741 .908 r
.43412 .52281 .4405 .52915 .45151 .52572 .44516 .51935 Metetra
.664 .741 .908 r
.44516 .51935 .45151 .52572 .46257 .52227 .45624 .51587 Metetra
.664 .741 .908 r
.45624 .51587 .46257 .52227 .47367 .51881 .46737 .51239 Metetra
.664 .741 .908 r
.46737 .51239 .47367 .51881 .48481 .51534 .47854 .50889 Metetra
.664 .741 .908 r
.47854 .50889 .48481 .51534 .496 .51185 .48976 .50537 Metetra
.664 .741 .908 r
.48976 .50537 .496 .51185 .50724 .50835 .50103 .50184 Metetra
.664 .741 .908 r
.50103 .50184 .50724 .50835 .51852 .50483 .51234 .49829 Metetra
.664 .741 .908 r
.51234 .49829 .51852 .50483 .52985 .5013 .5237 .49474 Metetra
.664 .741 .908 r
.5237 .49474 .52985 .5013 .54123 .49775 .53511 .49116 Metetra
.664 .741 .908 r
.53511 .49116 .54123 .49775 .55265 .49419 .54656 .48757 Metetra
.664 .741 .908 r
.54656 .48757 .55265 .49419 .56412 .49061 .55806 .48397 Metetra
.664 .741 .908 r
.55806 .48397 .56412 .49061 .57564 .48702 .56961 .48035 Metetra
.664 .741 .908 r
.56961 .48035 .57564 .48702 .5872 .48341 .58121 .47671 Metetra
.664 .741 .908 r
.58121 .47671 .5872 .48341 .59882 .47979 .59286 .47306 Metetra
.664 .741 .908 r
.59286 .47306 .59882 .47979 .61048 .47615 .60455 .4694 Metetra
.664 .741 .908 r
.60455 .4694 .61048 .47615 .62219 .4725 .6163 .46572 Metetra
.664 .741 .908 r
.6163 .46572 .62219 .4725 .63395 .46883 .62809 .46202 Metetra
.664 .741 .908 r
.62809 .46202 .63395 .46883 .64577 .46515 .63994 .45831 Metetra
.664 .741 .908 r
.63994 .45831 .64577 .46515 .65763 .46145 .65183 .45458 Metetra
.664 .741 .908 r
.65183 .45458 .65763 .46145 .66954 .45774 .66378 .45084 Metetra
.664 .741 .908 r
.66378 .45084 .66954 .45774 .6815 .45401 .67578 .44708 Metetra
.664 .741 .908 r
.67578 .44708 .6815 .45401 .69351 .45026 .68782 .44331 Metetra
.664 .741 .908 r
.68782 .44331 .69351 .45026 .70557 .4465 .69992 .43952 Metetra
.664 .741 .908 r
.69992 .43952 .70557 .4465 .71769 .44273 .71207 .43571 Metetra
.664 .741 .908 r
.71207 .43571 .71769 .44273 .72985 .43893 .72427 .43189 Metetra
.962 .629 .299 r
.72427 .43189 .72985 .43893 .74207 .43512 .74412 .5447 Metetra
.27 .107 .467 r
.74412 .5447 .74207 .43512 .75434 .4313 .75183 .46765 Metetra
.258 .04 .381 r
.75183 .46765 .75434 .4313 .76667 .42745 .76276 .44169 Metetra
.867 .516 .383 r
.76276 .44169 .76667 .42745 .77904 .42359 .77947 .4927 Metetra
.677 .406 .503 r
.77947 .4927 .77904 .42359 .80399 .57191 .79551 .52925 Metetra
.42 .326 .643 r
.79551 .52925 .80399 .57191 .82174 .62212 .81032 .54695 Metetra
.584 .407 .608 r
.81032 .54695 .82174 .62212 .83639 .63258 .8235 .54357 Metetra
.643 .442 .596 r
.8235 .54357 .83639 .63258 .84989 .6289 .83485 .51972 Metetra
.666 .453 .586 r
.83485 .51972 .84989 .6289 .8617 .60736 .84448 .47911 Metetra
.672 .453 .579 r
.84448 .47911 .8617 .60736 .86981 .55034 .85283 .42832 Metetra
.63 .424 .584 r
.85283 .42832 .86981 .55034 .87601 .47891 .86336 .40126 Metetra
.404 .281 .598 r
.86336 .40126 .87601 .47891 .88141 .40473 .88063 .43724 Metetra
.64 .335 .438 r
.88063 .43724 .88141 .40473 .89841 .43632 .89572 .45045 Metetra
0 0 .016 r
.89572 .45045 .89841 .43632 .91585 .46856 .90615 .42227 Metetra
.636 .464 .634 r
.90615 .42227 .91585 .46856 .9277 .45238 .91856 .41154 Metetra
.789 .511 0 r
.91856 .41154 .9277 .45238 .93341 .38829 .95465 .58876 Metetra
.664 .741 .908 r
.34076 .54378 .34741 .54998 .3581 .54663 .35147 .54041 Metetra
.664 .741 .908 r
.35147 .54041 .3581 .54663 .36882 .54327 .36223 .53702 Metetra
.664 .741 .908 r
.36223 .53702 .36882 .54327 .3796 .53989 .37303 .53362 Metetra
.664 .741 .908 r
.37303 .53362 .3796 .53989 .39041 .5365 .38387 .53021 Metetra
.664 .741 .908 r
.38387 .53021 .39041 .5365 .40127 .5331 .39476 .52678 Metetra
.664 .741 .908 r
.39476 .52678 .40127 .5331 .41218 .52968 .40569 .52334 Metetra
.664 .741 .908 r
.40569 .52334 .41218 .52968 .42313 .52625 .41667 .51988 Metetra
.664 .741 .908 r
.41667 .51988 .42313 .52625 .43412 .52281 .42769 .51641 Metetra
.664 .741 .908 r
.42769 .51641 .43412 .52281 .44516 .51935 .43875 .51292 Metetra
.664 .741 .908 r
.43875 .51292 .44516 .51935 .45624 .51587 .44986 .50943 Metetra
.664 .741 .908 r
.44986 .50943 .45624 .51587 .46737 .51239 .46102 .50591 Metetra
.664 .741 .908 r
.46102 .50591 .46737 .51239 .47854 .50889 .47223 .50238 Metetra
.664 .741 .908 r
.47223 .50238 .47854 .50889 .48976 .50537 .48348 .49884 Metetra
.664 .741 .908 r
.48348 .49884 .48976 .50537 .50103 .50184 .49477 .49528 Metetra
.664 .741 .908 r
.49477 .49528 .50103 .50184 .51234 .49829 .50612 .49171 Metetra
.664 .741 .908 r
.50612 .49171 .51234 .49829 .5237 .49474 .51751 .48812 Metetra
.664 .741 .908 r
.51751 .48812 .5237 .49474 .53511 .49116 .52894 .48452 Metetra
.664 .741 .908 r
.52894 .48452 .53511 .49116 .54656 .48757 .54043 .48091 Metetra
.664 .741 .908 r
.54043 .48091 .54656 .48757 .55806 .48397 .55196 .47727 Metetra
.664 .741 .908 r
.55196 .47727 .55806 .48397 .56961 .48035 .56354 .47363 Metetra
.664 .741 .908 r
.56354 .47363 .56961 .48035 .58121 .47671 .57517 .46996 Metetra
.664 .741 .908 r
.57517 .46996 .58121 .47671 .59286 .47306 .58685 .46629 Metetra
.664 .741 .908 r
.58685 .46629 .59286 .47306 .60455 .4694 .59858 .46259 Metetra
.664 .741 .908 r
.59858 .46259 .60455 .4694 .6163 .46572 .61036 .45888 Metetra
.664 .741 .908 r
.61036 .45888 .6163 .46572 .62809 .46202 .62219 .45516 Metetra
.664 .741 .908 r
.62219 .45516 .62809 .46202 .63994 .45831 .63407 .45142 Metetra
.664 .741 .908 r
.63407 .45142 .63994 .45831 .65183 .45458 .646 .44766 Metetra
.664 .741 .908 r
.646 .44766 .65183 .45458 .66378 .45084 .65798 .44389 Metetra
.664 .741 .908 r
.65798 .44389 .66378 .45084 .67578 .44708 .67001 .4401 Metetra
.969 .661 .378 r
.67001 .4401 .67578 .44708 .68782 .44331 .69266 .65542 Metetra
.535 .318 .531 r
.69266 .65542 .68782 .44331 .69992 .43952 .70489 .63741 Metetra
.468 .266 .521 r
.70489 .63741 .69992 .43952 .71207 .43571 .71502 .58288 Metetra
.415 .22 .506 r
.71502 .58288 .71207 .43571 .72427 .43189 .72456 .52391 Metetra
.303 .124 .464 r
.72456 .52391 .72427 .43189 .74412 .5447 .73382 .46615 Metetra
.711 .494 .592 r
.73382 .46615 .74412 .5447 .75183 .46765 .74346 .41968 Metetra
.251 .197 .6 r
.74346 .41968 .75183 .46765 .76276 .44169 .75867 .45496 Metetra
.778 .404 .349 r
.75867 .45496 .76276 .44169 .77947 .4927 .77335 .4785 Metetra
.313 .407 .799 r
.77335 .4785 .77947 .4927 .79551 .52925 .78713 .48718 Metetra
.623 .462 .643 r
.78713 .48718 .79551 .52925 .81032 .54695 .79972 .47964 Metetra
.66 .463 .606 r
.79972 .47964 .81032 .54695 .8235 .54357 .811 .45671 Metetra
.674 .463 .592 r
.811 .45671 .8235 .54357 .83485 .51972 .82107 .42157 Metetra
.632 .43 .591 r
.82107 .42157 .83485 .51972 .84448 .47911 .83215 .39909 Metetra
.411 .284 .595 r
.83215 .39909 .84448 .47911 .85283 .42832 .84883 .43381 Metetra
.833 .401 .207 r
.84883 .43381 .85283 .42832 .86336 .40126 .86498 .45979 Metetra
.571 .312 .484 r
.86498 .45979 .86336 .40126 .88063 .43724 .87907 .46376 Metetra
.001 0 .269 r
.87907 .46376 .88063 .43724 .89572 .45045 .88908 .43014 Metetra
.858 .658 .631 r
.88908 .43014 .89572 .45045 .90615 .42227 .89867 .39457 Metetra
.875 .563 .048 r
.89867 .39457 .90615 .42227 .91856 .41154 .93168 .55513 Metetra
.611 .367 .523 r
.93168 .55513 .91856 .41154 .95465 .58876 .94981 .58454 Metetra
.664 .741 .908 r
.33406 .53754 .34076 .54378 .35147 .54041 .3448 .53415 Metetra
.664 .741 .908 r
.3448 .53415 .35147 .54041 .36223 .53702 .35558 .53073 Metetra
.664 .741 .908 r
.35558 .53073 .36223 .53702 .37303 .53362 .36641 .52731 Metetra
.664 .741 .908 r
.36641 .52731 .37303 .53362 .38387 .53021 .37728 .52387 Metetra
.664 .741 .908 r
.37728 .52387 .38387 .53021 .39476 .52678 .38819 .52041 Metetra
.664 .741 .908 r
.38819 .52041 .39476 .52678 .40569 .52334 .39915 .51694 Metetra
.664 .741 .908 r
.39915 .51694 .40569 .52334 .41667 .51988 .41016 .51346 Metetra
.664 .741 .908 r
.41016 .51346 .41667 .51988 .42769 .51641 .42121 .50996 Metetra
.664 .741 .908 r
.42121 .50996 .42769 .51641 .43875 .51292 .4323 .50645 Metetra
.664 .741 .908 r
.4323 .50645 .43875 .51292 .44986 .50943 .44344 .50293 Metetra
.664 .741 .908 r
.44344 .50293 .44986 .50943 .46102 .50591 .45463 .49939 Metetra
.664 .741 .908 r
.45463 .49939 .46102 .50591 .47223 .50238 .46586 .49583 Metetra
.664 .741 .908 r
.46586 .49583 .47223 .50238 .48348 .49884 .47714 .49226 Metetra
.664 .741 .908 r
.47714 .49226 .48348 .49884 .49477 .49528 .48847 .48868 Metetra
.664 .741 .908 r
.48847 .48868 .49477 .49528 .50612 .49171 .49984 .48508 Metetra
.664 .741 .908 r
.49984 .48508 .50612 .49171 .51751 .48812 .51126 .48146 Metetra
.664 .741 .908 r
.51126 .48146 .51751 .48812 .52894 .48452 .52273 .47783 Metetra
.664 .741 .908 r
.52273 .47783 .52894 .48452 .54043 .48091 .53425 .47419 Metetra
.664 .741 .908 r
.53425 .47419 .54043 .48091 .55196 .47727 .54581 .47053 Metetra
.664 .741 .908 r
.54581 .47053 .55196 .47727 .56354 .47363 .55743 .46685 Metetra
.664 .741 .908 r
.55743 .46685 .56354 .47363 .57517 .46996 .56909 .46316 Metetra
.664 .741 .908 r
.56909 .46316 .57517 .46996 .58685 .46629 .5808 .45946 Metetra
.664 .741 .908 r
.5808 .45946 .58685 .46629 .59858 .46259 .59256 .45573 Metetra
.664 .741 .908 r
.59256 .45573 .59858 .46259 .61036 .45888 .60438 .452 Metetra
.664 .741 .908 r
.60438 .452 .61036 .45888 .62219 .45516 .61624 .44824 Metetra
.966 .658 .386 r
.61624 .44824 .62219 .45516 .63407 .45142 .63352 .61424 Metetra
.588 .355 .53 r
.63352 .61424 .63407 .45142 .646 .44766 .64683 .63098 Metetra
.554 .33 .529 r
.64683 .63098 .646 .44766 .65798 .44389 .65959 .62802 Metetra
.525 .307 .526 r
.65959 .62802 .65798 .44389 .67001 .4401 .67167 .60789 Metetra
.493 .281 .519 r
.67167 .60789 .67001 .4401 .69266 .65542 .68308 .57453 Metetra
.697 .484 .595 r
.68308 .57453 .69266 .65542 .70489 .63741 .69389 .53271 Metetra
.68 .465 .587 r
.69389 .53271 .70489 .63741 .71502 .58288 .70427 .48736 Metetra
.686 .471 .589 r
.70427 .48736 .71502 .58288 .72456 .52391 .71446 .44312 Metetra
.637 .439 .599 r
.71446 .44312 .72456 .52391 .73382 .46615 .72591 .42349 Metetra
.342 .268 .627 r
.72591 .42349 .73382 .46615 .74346 .41968 .74015 .44716 Metetra
.651 .336 .426 r
.74015 .44716 .74346 .41968 .75867 .45496 .75391 .46015 Metetra
.373 0 0 r
.75391 .46015 .75867 .45496 .77335 .4785 .76691 .46015 Metetra
.743 .611 .712 r
.76691 .46015 .77335 .4785 .78713 .48718 .77893 .44643 Metetra
.723 .529 .627 r
.77893 .44643 .78713 .48718 .79972 .47964 .7899 .42006 Metetra
.675 .477 .61 r
.7899 .42006 .79972 .47964 .811 .45671 .80092 .39584 Metetra
.352 .254 .602 r
.80092 .39584 .811 .45671 .82107 .42157 .81706 .4297 Metetra
.854 .455 .284 r
.81706 .4297 .82107 .42157 .83215 .39909 .83357 .46355 Metetra
.647 .374 .492 r
.83357 .46355 .83215 .39909 .84883 .43381 .84955 .48827 Metetra
.569 .305 .477 r
.84955 .48827 .84883 .43381 .86498 .45979 .86367 .49185 Metetra
.141 0 .336 r
.86367 .49185 .86498 .45979 .87907 .46376 .87419 .46037 Metetra
.993 .754 .463 r
.87419 .46037 .87907 .46376 .88908 .43014 .87917 .38038 Metetra
0 0 .336 r
.87917 .38038 .88908 .43014 .89867 .39457 .90534 .48984 Metetra
.742 .457 .498 r
.90534 .48984 .89867 .39457 .93168 .55513 .93038 .58123 Metetra
.488 .185 .378 r
.93038 .58123 .93168 .55513 .94981 .58454 .94454 .57731 Metetra
.664 .741 .908 r
.32731 .53126 .33406 .53754 .3448 .53415 .33807 .52784 Metetra
.664 .741 .908 r
.33807 .52784 .3448 .53415 .35558 .53073 .34888 .5244 Metetra
.664 .741 .908 r
.34888 .5244 .35558 .53073 .36641 .52731 .35974 .52094 Metetra
.664 .741 .908 r
.35974 .52094 .36641 .52731 .37728 .52387 .37063 .51748 Metetra
.664 .741 .908 r
.37063 .51748 .37728 .52387 .38819 .52041 .38158 .514 Metetra
.664 .741 .908 r
.38158 .514 .38819 .52041 .39915 .51694 .39256 .5105 Metetra
.664 .741 .908 r
.39256 .5105 .39915 .51694 .41016 .51346 .4036 .50699 Metetra
.664 .741 .908 r
.4036 .50699 .41016 .51346 .42121 .50996 .41468 .50347 Metetra
.664 .741 .908 r
.41468 .50347 .42121 .50996 .4323 .50645 .4258 .49993 Metetra
.664 .741 .908 r
.4258 .49993 .4323 .50645 .44344 .50293 .43697 .49638 Metetra
.664 .741 .908 r
.43697 .49638 .44344 .50293 .45463 .49939 .44819 .49281 Metetra
.664 .741 .908 r
.44819 .49281 .45463 .49939 .46586 .49583 .45945 .48923 Metetra
.664 .741 .908 r
.45945 .48923 .46586 .49583 .47714 .49226 .47076 .48563 Metetra
.664 .741 .908 r
.47076 .48563 .47714 .49226 .48847 .48868 .48211 .48202 Metetra
.664 .741 .908 r
.48211 .48202 .48847 .48868 .49984 .48508 .49352 .47839 Metetra
.664 .741 .908 r
.49352 .47839 .49984 .48508 .51126 .48146 .50497 .47475 Metetra
.664 .741 .908 r
.50497 .47475 .51126 .48146 .52273 .47783 .51647 .47109 Metetra
.664 .741 .908 r
.51647 .47109 .52273 .47783 .53425 .47419 .52802 .46742 Metetra
.664 .741 .908 r
.52802 .46742 .53425 .47419 .54581 .47053 .53962 .46373 Metetra
.664 .741 .908 r
.53962 .46373 .54581 .47053 .55743 .46685 .55126 .46003 Metetra
.664 .741 .908 r
.55126 .46003 .55743 .46685 .56909 .46316 .56296 .45631 Metetra
.556 .073 0 r
.56296 .45631 .56909 .46316 .5808 .45946 .57497 .47026 Metetra
.79 .424 .363 r
.57497 .47026 .5808 .45946 .59256 .45573 .58733 .49296 Metetra
.762 .464 .481 r
.58733 .49296 .59256 .45573 .60438 .452 .60042 .53761 Metetra
.641 .384 .514 r
.60042 .53761 .60438 .452 .61624 .44824 .6135 .56613 Metetra
.584 .345 .52 r
.6135 .56613 .61624 .44824 .63352 .61424 .62636 .57742 Metetra
.613 .465 .656 r
.62636 .57742 .63352 .61424 .64683 .63098 .63884 .57226 Metetra
.659 .468 .616 r
.63884 .57226 .64683 .63098 .65959 .62802 .65083 .55297 Metetra
.673 .469 .601 r
.65083 .55297 .65959 .62802 .67167 .60789 .66232 .52306 Metetra
.68 .469 .594 r
.66232 .52306 .67167 .60789 .68308 .57453 .67338 .48665 Metetra
.682 .469 .592 r
.67338 .48665 .68308 .57453 .69389 .53271 .68414 .448 Metetra
.664 .457 .595 r
.68414 .448 .69389 .53271 .70427 .48736 .69512 .41753 Metetra
.433 .3 .599 r
.69512 .41753 .70427 .48736 .71446 .44312 .70904 .4419 Metetra
.772 .263 0 r
.70904 .4419 .71446 .44312 .72591 .42349 .72277 .45854 Metetra
.589 .298 .442 r
.72277 .45854 .72591 .42349 .74015 .44716 .73603 .46452 Metetra
.383 .053 .276 r
.73603 .46452 .74015 .44716 .75391 .46015 .74858 .45802 Metetra
.945 .905 .751 r
.74858 .45802 .75391 .46015 .76691 .46015 .76023 .43863 Metetra
.826 .636 .646 r
.76023 .43863 .76691 .46015 .77893 .44643 .77094 .40764 Metetra
.589 .443 .651 r
.77094 .40764 .77893 .44643 .7899 .42006 .78378 .4053 Metetra
0 0 .306 r
.78378 .4053 .7899 .42006 .80092 .39584 .80006 .44294 Metetra
.716 .419 .472 r
.80006 .44294 .80092 .39584 .81706 .4297 .81676 .48076 Metetra
.681 .391 .476 r
.81676 .48076 .81706 .4297 .83357 .46355 .8331 .51032 Metetra
.604 .324 .465 r
.8331 .51032 .83357 .46355 .84955 .48827 .8479 .52048 Metetra
.277 .042 .366 r
.8479 .52048 .84955 .48827 .86367 .49185 .85962 .49819 Metetra
.986 .793 .395 r
.85962 .49819 .86367 .49185 .87419 .46037 .86648 .43049 Metetra
.735 .558 .653 r
.86648 .43049 .87419 .46037 .87917 .38038 .87798 .40965 Metetra
.927 .592 .384 r
.87798 .40965 .87917 .38038 .90534 .48984 .91087 .57791 Metetra
.541 .3 .5 r
.91087 .57791 .90534 .48984 .93038 .58123 .92502 .57397 Metetra
.982 .695 .37 r
.92502 .57397 .93038 .58123 .94454 .57731 .91179 .34535 Metetra
.664 .741 .908 r
.32051 .52493 .32731 .53126 .33807 .52784 .3313 .52148 Metetra
.664 .741 .908 r
.3313 .52148 .33807 .52784 .34888 .5244 .34214 .51801 Metetra
.664 .741 .908 r
.34214 .51801 .34888 .5244 .35974 .52094 .35302 .51453 Metetra
.664 .741 .908 r
.35302 .51453 .35974 .52094 .37063 .51748 .36394 .51104 Metetra
.664 .741 .908 r
.36394 .51104 .37063 .51748 .38158 .514 .37491 .50753 Metetra
.664 .741 .908 r
.37491 .50753 .38158 .514 .39256 .5105 .38593 .50401 Metetra
.664 .741 .908 r
.38593 .50401 .39256 .5105 .4036 .50699 .39699 .50048 Metetra
.664 .741 .908 r
.39699 .50048 .4036 .50699 .41468 .50347 .4081 .49693 Metetra
.664 .741 .908 r
.4081 .49693 .41468 .50347 .4258 .49993 .41925 .49336 Metetra
.664 .741 .908 r
.41925 .49336 .4258 .49993 .43697 .49638 .43045 .48978 Metetra
.664 .741 .908 r
.43045 .48978 .43697 .49638 .44819 .49281 .44169 .48619 Metetra
.664 .741 .908 r
.44169 .48619 .44819 .49281 .45945 .48923 .45299 .48258 Metetra
.664 .741 .908 r
.45299 .48258 .45945 .48923 .47076 .48563 .46433 .47895 Metetra
.664 .741 .908 r
.46433 .47895 .47076 .48563 .48211 .48202 .47571 .47531 Metetra
.664 .741 .908 r
.47571 .47531 .48211 .48202 .49352 .47839 .48715 .47166 Metetra
.664 .741 .908 r
.48715 .47166 .49352 .47839 .50497 .47475 .49863 .46799 Metetra
.664 .741 .908 r
.49863 .46799 .50497 .47475 .51647 .47109 .51016 .4643 Metetra
.96 .669 .439 r
.51016 .4643 .51647 .47109 .52802 .46742 .52153 .67815 Metetra
.427 .228 .506 r
.52153 .67815 .52802 .46742 .53962 .46373 .53376 .60783 Metetra
.309 .129 .466 r
.53376 .60783 .53962 .46373 .55126 .46003 .54552 .52912 Metetra
0 0 .308 r
.54552 .52912 .55126 .46003 .56296 .45631 .55688 .46013 Metetra
.862 .473 .305 r
.55688 .46013 .56296 .45631 .57497 .47026 .56912 .48805 Metetra
.809 .477 .428 r
.56912 .48805 .57497 .47026 .58733 .49296 .58179 .52454 Metetra
.692 .388 .456 r
.58179 .52454 .58733 .49296 .60042 .53761 .59449 .5458 Metetra
.6 .164 .186 r
.59449 .5458 .60042 .53761 .6135 .56613 .60704 .55117 Metetra
.722 .628 .752 r
.60704 .55117 .6135 .56613 .62636 .57742 .6193 .54168 Metetra
.718 .535 .642 r
.6193 .54168 .62636 .57742 .63884 .57226 .63117 .51975 Metetra
.712 .51 .614 r
.63117 .51975 .63884 .57226 .65083 .55297 .64264 .48877 Metetra
.706 .497 .603 r
.64264 .48877 .65083 .55297 .66232 .52306 .65376 .45264 Metetra
.7 .489 .599 r
.65376 .45264 .66232 .52306 .67338 .48665 .66463 .41532 Metetra
.416 .286 .594 r
.66463 .41532 .67338 .48665 .68414 .448 .67832 .44211 Metetra
.777 .31 0 r
.67832 .44211 .68414 .448 .69512 .41753 .69209 .46474 Metetra
.626 .346 .473 r
.69209 .46474 .69512 .41753 .70904 .4419 .70566 .47899 Metetra
.566 .28 .442 r
.70566 .47899 .70904 .4419 .72277 .45854 .71877 .48211 Metetra
.376 .082 .332 r
.71877 .48211 .72277 .45854 .73603 .46452 .7312 .47239 Metetra
.733 .849 .411 r
.7312 .47239 .73603 .46452 .74858 .45802 .74276 .44955 Metetra
.934 .76 .643 r
.74276 .44955 .74858 .45802 .76023 .43863 .7534 .41491 Metetra
.757 .59 .67 r
.7534 .41491 .76023 .43863 .77094 .40764 .76495 .39499 Metetra
.767 .395 0 r
.76495 .39499 .77094 .40764 .78378 .4053 .78129 .43692 Metetra
.777 .453 .44 r
.78129 .43692 .78378 .4053 .80006 .44294 .79821 .48047 Metetra
.739 .425 .452 r
.79821 .48047 .80006 .44294 .81676 .48076 .81504 .51792 Metetra
.672 .366 .446 r
.81504 .51792 .81676 .48076 .8331 .51032 .83078 .53892 Metetra
.442 .155 .38 r
.83078 .53892 .8331 .51032 .8479 .52048 .84404 .53101 Metetra
.904 .804 .326 r
.84404 .53101 .8479 .52048 .85962 .49819 .85318 .48124 Metetra
.961 .701 .496 r
.85318 .48124 .85962 .49819 .86648 .43049 .85656 .37899 Metetra
0 0 .313 r
.85656 .37899 .86648 .43049 .87798 .40965 .88244 .49255 Metetra
.74 .451 .491 r
.88244 .49255 .87798 .40965 .91087 .57791 .90541 .57062 Metetra
.645 .763 .934 r
.90541 .57062 .91087 .57791 .92502 .57397 .91961 .56665 Metetra
.982 .695 .37 r
.91961 .56665 .92502 .57397 .91179 .34535 .90668 .33755 Metetra
.664 .741 .908 r
.31365 .51855 .32051 .52493 .3313 .52148 .32447 .51507 Metetra
.664 .741 .908 r
.32447 .51507 .3313 .52148 .34214 .51801 .33534 .51158 Metetra
.664 .741 .908 r
.33534 .51158 .34214 .51801 .35302 .51453 .34625 .50808 Metetra
.664 .741 .908 r
.34625 .50808 .35302 .51453 .36394 .51104 .3572 .50456 Metetra
.664 .741 .908 r
.3572 .50456 .36394 .51104 .37491 .50753 .3682 .50102 Metetra
.664 .741 .908 r
.3682 .50102 .37491 .50753 .38593 .50401 .37924 .49747 Metetra
.664 .741 .908 r
.37924 .49747 .38593 .50401 .39699 .50048 .39033 .49391 Metetra
.664 .741 .908 r
.39033 .49391 .39699 .50048 .4081 .49693 .40147 .49033 Metetra
.664 .741 .908 r
.40147 .49033 .4081 .49693 .41925 .49336 .41265 .48674 Metetra
.664 .741 .908 r
.41265 .48674 .41925 .49336 .43045 .48978 .42388 .48313 Metetra
.664 .741 .908 r
.42388 .48313 .43045 .48978 .44169 .48619 .43515 .47951 Metetra
.664 .741 .908 r
.43515 .47951 .44169 .48619 .45299 .48258 .44647 .47587 Metetra
.664 .741 .908 r
.44647 .47587 .45299 .48258 .46433 .47895 .45784 .47222 Metetra
.956 .67 .456 r
.45784 .47222 .46433 .47895 .47571 .47531 .46559 .68558 Metetra
.55 .326 .527 r
.46559 .68558 .47571 .47531 .48715 .47166 .47781 .68214 Metetra
.55 .326 .527 r
.47781 .68214 .48715 .47166 .49863 .46799 .49008 .67868 Metetra
.523 .303 .523 r
.49008 .67868 .49863 .46799 .51016 .4643 .50251 .65812 Metetra
.387 .194 .492 r
.50251 .65812 .51016 .4643 .52153 .67815 .51505 .58008 Metetra
.738 .511 .586 r
.51505 .58008 .52153 .67815 .53376 .60783 .52711 .50587 Metetra
.701 .482 .587 r
.52711 .50587 .53376 .60783 .54552 .52912 .53881 .45108 Metetra
.277 .176 .555 r
.53881 .45108 .54552 .52912 .55688 .46013 .55098 .49673 Metetra
.726 .429 .475 r
.55098 .49673 .55688 .46013 .56912 .48805 .5634 .52908 Metetra
.649 .362 .47 r
.5634 .52908 .56912 .48805 .58179 .52454 .57591 .54597 Metetra
.536 .209 .36 r
.57591 .54597 .58179 .52454 .59449 .5458 .58832 .54697 Metetra
.873 .991 .813 r
.58832 .54697 .59449 .5458 .60704 .55117 .60049 .53335 Metetra
.819 .65 .673 r
.60049 .53335 .60704 .55117 .6193 .54168 .61233 .50769 Metetra
.774 .574 .628 r
.61233 .50769 .6193 .54168 .63117 .51975 .6238 .47347 Metetra
.752 .542 .612 r
.6238 .47347 .63117 .51975 .64264 .48877 .63495 .43462 Metetra
.602 .43 .621 r
.63495 .43462 .64264 .48877 .65376 .45264 .6471 .42834 Metetra
0 0 .548 r
.6471 .42834 .65376 .45264 .66463 .41532 .6608 .4585 Metetra
.68 .388 .472 r
.6608 .4585 .66463 .41532 .67832 .44211 .67458 .48339 Metetra
.643 .352 .463 r
.67458 .48339 .67832 .44211 .69209 .46474 .68821 .49948 Metetra
.575 .282 .434 r
.68821 .49948 .69209 .46474 .70566 .47899 .70143 .50388 Metetra
.393 .099 .342 r
.70143 .50388 .70566 .47899 .71877 .48211 .71401 .49477 Metetra
.71401 .49477 .71877 .48211 .7312 .47239 .72575 .47171 Metetra
.989 .848 .609 r
.72575 .47171 .7312 .47239 .74276 .44955 .73657 .43585 Metetra
.918 .71 .607 r
.73657 .43585 .74276 .44955 .7534 .41491 .74649 .38993 Metetra
.098 .164 .644 r
.74649 .38993 .7534 .41491 .76495 .39499 .76126 .41412 Metetra
.84 .491 .394 r
.76126 .41412 .76495 .39499 .78129 .43692 .77818 .4625 Metetra
.805 .467 .417 r
.77818 .4625 .78129 .43692 .79821 .48047 .79535 .50791 Metetra
.755 .421 .419 r
.79535 .50791 .79821 .48047 .81504 .51792 .81193 .54094 Metetra
.62 .282 .376 r
.81193 .54094 .81504 .51792 .83078 .53892 .82673 .54986 Metetra
.82673 .54986 .83078 .53892 .84404 .53101 .83822 .52169 Metetra
.975 .736 .511 r
.83822 .52169 .84404 .53101 .85318 .48124 .8448 .44467 Metetra
.849 .612 .58 r
.8448 .44467 .85318 .48124 .85656 .37899 .85234 .38256 Metetra
.959 .621 .298 r
.85234 .38256 .85656 .37899 .88244 .49255 .88573 .56726 Metetra
.533 .286 .487 r
.88573 .56726 .88244 .49255 .90541 .57062 .89991 .56327 Metetra
.645 .763 .934 r
.89991 .56327 .90541 .57062 .91961 .56665 .91415 .55926 Metetra
.982 .695 .37 r
.91415 .55926 .91961 .56665 .90668 .33755 .90152 .32967 Metetra
.664 .741 .908 r
.30675 .51212 .31365 .51855 .32447 .51507 .3176 .50862 Metetra
.664 .741 .908 r
.3176 .50862 .32447 .51507 .33534 .51158 .32849 .5051 Metetra
.664 .741 .908 r
.32849 .5051 .33534 .51158 .34625 .50808 .33942 .50157 Metetra
.664 .741 .908 r
.33942 .50157 .34625 .50808 .3572 .50456 .3504 .49802 Metetra
.664 .741 .908 r
.3504 .49802 .3572 .50456 .3682 .50102 .36143 .49446 Metetra
.664 .741 .908 r
.36143 .49446 .3682 .50102 .37924 .49747 .3725 .49089 Metetra
.664 .741 .908 r
.3725 .49089 .37924 .49747 .39033 .49391 .38362 .48729 Metetra
.664 .741 .908 r
.38362 .48729 .39033 .49391 .40147 .49033 .39478 .48369 Metetra
.664 .741 .908 r
.39478 .48369 .40147 .49033 .41265 .48674 .40599 .48007 Metetra
.664 .741 .908 r
.40599 .48007 .41265 .48674 .42388 .48313 .41725 .47643 Metetra
.953 .667 .458 r
.41725 .47643 .42388 .48313 .43515 .47951 .42342 .64853 Metetra
.618 .378 .533 r
.42342 .64853 .43515 .47951 .44647 .47587 .43431 .68611 Metetra
.549 .324 .526 r
.43431 .68611 .44647 .47587 .45784 .47222 .44645 .68267 Metetra
.549 .324 .526 r
.44645 .68267 .45784 .47222 .46559 .68558 .45864 .67921 Metetra
.645 .763 .934 r
.45864 .67921 .46559 .68558 .47781 .68214 .4709 .67575 Metetra
.91 .765 .688 r
.4709 .67575 .47781 .68214 .49008 .67868 .48351 .64644 Metetra
.864 .636 .591 r
.48351 .64644 .49008 .67868 .50251 .65812 .49642 .56629 Metetra
.747 .52 .586 r
.49642 .56629 .50251 .65812 .51505 .58008 .50883 .49037 Metetra
.656 .45 .594 r
.50883 .49037 .51505 .58008 .52711 .50587 .52071 .46153 Metetra
0 0 .471 r
.52071 .46153 .52711 .50587 .53881 .45108 .53264 .50859 Metetra
.685 .409 .499 r
.53264 .50859 .53881 .45108 .55098 .49673 .5449 .54154 Metetra
.641 .358 .474 r
.5449 .54154 .55098 .49673 .5634 .52908 .55733 .55809 Metetra
.528 .228 .401 r
.55733 .55809 .5634 .52908 .57591 .54597 .56974 .55782 Metetra
.56974 .55782 .57591 .54597 .58832 .54697 .58196 .54207 Metetra
.934 .798 .685 r
.58196 .54207 .58832 .54697 .60049 .53335 .59389 .51355 Metetra
.85 .654 .638 r
.59389 .51355 .60049 .53335 .61233 .50769 .60547 .47593 Metetra
.809 .599 .619 r
.60547 .47593 .61233 .50769 .6238 .47347 .6167 .43328 Metetra
.614 .456 .644 r
.6167 .43328 .6238 .47347 .63495 .43462 .62887 .42711 Metetra
.884 .473 .048 r
.62887 .42711 .63495 .43462 .6471 .42834 .64253 .46179 Metetra
.724 .414 .455 r
.64253 .46179 .6471 .42834 .6608 .4585 .65635 .49155 Metetra
.685 .376 .447 r
.65635 .49155 .6608 .4585 .67458 .48339 .67011 .51267 Metetra
.617 .305 .419 r
.67011 .51267 .67458 .48339 .68821 .49948 .68356 .52194 Metetra
.447 .131 .335 r
.68356 .52194 .68821 .49948 .70143 .50388 .69646 .51716 Metetra
.69646 .51716 .70143 .50388 .71401 .49477 .70858 .4975 Metetra
.99 .889 .587 r
.70858 .4975 .71401 .49477 .72575 .47171 .7198 .46369 Metetra
.952 .756 .601 r
.7198 .46369 .72575 .47171 .73657 .43585 .73009 .41811 Metetra
.875 .676 .63 r
.73009 .41811 .73657 .43585 .74649 .38993 .7406 .37982 Metetra
.883 .501 .035 r
.7406 .37982 .74649 .38993 .76126 .41412 .75724 .43042 Metetra
.858 .503 .377 r
.75724 .43042 .76126 .41412 .77818 .4625 .77443 .48156 Metetra
.827 .472 .385 r
.77443 .48156 .77818 .4625 .79535 .50791 .79152 .52507 Metetra
.761 .392 .355 r
.79152 .52507 .79535 .50791 .81193 .54094 .80754 .55023 Metetra
.237 0 .018 r
.80754 .55023 .81193 .54094 .82673 .54986 .82114 .5445 Metetra
.982 .786 .567 r
.82114 .5445 .82673 .54986 .83822 .52169 .83079 .4953 Metetra
.933 .673 .52 r
.83079 .4953 .83822 .52169 .8448 .44467 .835 .39292 Metetra
.043 .055 .545 r
.835 .39292 .8448 .44467 .85234 .38256 .85463 .45135 Metetra
.806 .499 .47 r
.85463 .45135 .85234 .38256 .88573 .56726 .88012 .55987 Metetra
.645 .763 .934 r
.88012 .55987 .88573 .56726 .89991 .56327 .89435 .55585 Metetra
.983 .696 .377 r
.89435 .55585 .89991 .56327 .91415 .55926 .88297 .32604 Metetra
.565 .363 .565 r
.88297 .32604 .91415 .55926 .90152 .32967 .89632 .32173 Metetra
.664 .741 .908 r
.29979 .50564 .30675 .51212 .3176 .50862 .31067 .50211 Metetra
.664 .741 .908 r
.31067 .50211 .3176 .50862 .32849 .5051 .32158 .49857 Metetra
.664 .741 .908 r
.32158 .49857 .32849 .5051 .33942 .50157 .33255 .49501 Metetra
.664 .741 .908 r
.33255 .49501 .33942 .50157 .3504 .49802 .34356 .49144 Metetra
.664 .741 .908 r
.34356 .49144 .3504 .49802 .36143 .49446 .35461 .48785 Metetra
.664 .741 .908 r
.35461 .48785 .36143 .49446 .3725 .49089 .36571 .48425 Metetra
.948 .671 .481 r
.36571 .48425 .3725 .49089 .38362 .48729 .36717 .69685 Metetra
.548 .322 .524 r
.36717 .69685 .38362 .48729 .39478 .48369 .37907 .69346 Metetra
.059 0 .374 r
.37907 .69346 .39478 .48369 .40599 .48007 .39723 .52737 Metetra
.828 .549 .516 r
.39723 .52737 .40599 .48007 .41725 .47643 .40486 .63451 Metetra
.637 .394 .533 r
.40486 .63451 .41725 .47643 .42342 .64853 .41511 .6832 Metetra
.498 .211 .41 r
.41511 .6832 .42342 .64853 .43431 .68611 .42723 .67975 Metetra
.645 .763 .934 r
.42723 .67975 .43431 .68611 .44645 .68267 .43941 .67628 Metetra
.645 .763 .934 r
.43941 .67628 .44645 .68267 .45864 .67921 .45164 .6728 Metetra
.839 .788 .802 r
.45164 .6728 .45864 .67921 .4709 .67575 .4641 .65909 Metetra
.914 .687 .581 r
.4641 .65909 .4709 .67575 .48351 .64644 .47756 .57278 Metetra
.782 .551 .587 r
.47756 .57278 .48351 .64644 .49642 .56629 .49045 .49045 Metetra
.671 .466 .6 r
.49045 .49045 .49642 .56629 .50883 .49037 .50247 .46106 Metetra
0 0 .16 r
.50247 .46106 .50883 .49037 .52071 .46153 .51409 .51395 Metetra
.709 .427 .496 r
.51409 .51395 .52071 .46153 .53264 .50859 .52616 .55216 Metetra
.663 .376 .475 r
.52616 .55216 .53264 .50859 .5449 .54154 .53852 .57294 Metetra
.558 .259 .417 r
.53852 .57294 .5449 .54154 .55733 .55809 .55098 .57549 Metetra
.082 0 .12 r
.55098 .57549 .55733 .55809 .56974 .55782 .56335 .56096 Metetra
.982 .906 .649 r
.56335 .56096 .56974 .55782 .58196 .54207 .57547 .53205 Metetra
.914 .73 .639 r
.57547 .53205 .58196 .54207 .59389 .51355 .58726 .49254 Metetra
.864 .656 .62 r
.58726 .49254 .59389 .51355 .60547 .47593 .5987 .44673 Metetra
.799 .598 .63 r
.5987 .44673 .60547 .47593 .6167 .43328 .61015 .41101 Metetra
0 0 .327 r
.61015 .41101 .6167 .43328 .62887 .42711 .62367 .45033 Metetra
.782 .452 .429 r
.62367 .45033 .62887 .42711 .64253 .46179 .63745 .4859 Metetra
.747 .416 .424 r
.63745 .4859 .64253 .46179 .65635 .49155 .65129 .51375 Metetra
.689 .351 .398 r
.65129 .51375 .65635 .49155 .67011 .51267 .66497 .5303 Metetra
.548 .192 .316 r
.66497 .5303 .67011 .51267 .68356 .52194 .67823 .53283 Metetra
.67823 .53283 .68356 .52194 .69646 .51716 .69084 .51988 Metetra
.977 .919 .625 r
.69084 .51988 .69646 .51716 .70858 .4975 .7026 .49156 Metetra
.961 .779 .612 r
.7026 .49156 .70858 .4975 .7198 .46369 .71346 .44966 Metetra
.924 .71 .593 r
.71346 .44966 .7198 .46369 .73009 .41811 .72343 .39749 Metetra
.669 .558 .72 r
.72343 .39749 .73009 .41811 .7406 .37982 .736 .38992 Metetra
.89 .524 .342 r
.736 .38992 .7406 .37982 .75724 .43042 .75286 .44333 Metetra
.872 .507 .353 r
.75286 .44333 .75724 .43042 .77443 .48156 .77004 .49384 Metetra
.844 .464 .332 r
.77004 .49384 .77443 .48156 .79152 .52507 .78679 .53217 Metetra
.727 .274 .174 r
.78679 .53217 .79152 .52507 .80754 .55023 .80199 .54675 Metetra
.949 .888 .737 r
.80199 .54675 .80754 .55023 .82114 .5445 .81428 .52494 Metetra
.929 .691 .557 r
.81428 .52494 .82114 .5445 .83079 .4953 .82214 .45528 Metetra
.907 .642 .526 r
.82214 .45528 .83079 .4953 .835 .39292 .82517 .33988 Metetra
.792 .532 0 r
.82517 .33988 .835 .39292 .85463 .45135 .85803 .534 Metetra
.608 .344 .493 r
.85803 .534 .85463 .45135 .88012 .55987 .87447 .55242 Metetra
.645 .763 .934 r
.87447 .55242 .88012 .55987 .89435 .55585 .88874 .54836 Metetra
.983 .696 .377 r
.88874 .54836 .89435 .55585 .88297 .32604 .87768 .31807 Metetra
.664 .741 .908 r
.87768 .31807 .88297 .32604 .89632 .32173 .89107 .31372 Metetra
.664 .741 .908 r
.29278 .49911 .29979 .50564 .31067 .50211 .30368 .49556 Metetra
.664 .741 .908 r
.30368 .49556 .31067 .50211 .32158 .49857 .31463 .49199 Metetra
.943 .671 .493 r
.31463 .49199 .32158 .49857 .33255 .49501 .31264 .7041 Metetra
.546 .32 .523 r
.31264 .7041 .33255 .49501 .34356 .49144 .32437 .70074 Metetra
.546 .32 .523 r
.32437 .70074 .34356 .49144 .35461 .48785 .33615 .69737 Metetra
.546 .32 .523 r
.33615 .69737 .35461 .48785 .36571 .48425 .34798 .69398 Metetra
.546 .32 .523 r
.34798 .69398 .36571 .48425 .36717 .69685 .35987 .69058 Metetra
.934 .719 .589 r
.35987 .69058 .36717 .69685 .37907 .69346 .3752 .60929 Metetra
.614 .421 .597 r
.3752 .60929 .37907 .69346 .39723 .52737 .38734 .59561 Metetra
.769 .497 .523 r
.38734 .59561 .39723 .52737 .40486 .63451 .39584 .68028 Metetra
.511 .241 .441 r
.39584 .68028 .40486 .63451 .41511 .6832 .40794 .67681 Metetra
.645 .763 .934 r
.40794 .67681 .41511 .6832 .42723 .67975 .4201 .67334 Metetra
.645 .763 .934 r
.4201 .67334 .42723 .67975 .43941 .67628 .43231 .66984 Metetra
.645 .763 .934 r
.43231 .66984 .43941 .67628 .45164 .6728 .44457 .66633 Metetra
.939 .732 .596 r
.44457 .66633 .45164 .6728 .4641 .65909 .45809 .60139 Metetra
.819 .587 .586 r
.45809 .60139 .4641 .65909 .47756 .57278 .47165 .51024 Metetra
.776 .551 .594 r
.47165 .51024 .47756 .57278 .49045 .49045 .48434 .44382 Metetra
0 0 .322 r
.48434 .44382 .49045 .49045 .50247 .46106 .4955 .50528 Metetra
.75 .459 .491 r
.4955 .50528 .50247 .46106 .51409 .51395 .50725 .55242 Metetra
.709 .412 .472 r
.50725 .55242 .51409 .51395 .52616 .55216 .51945 .58162 Metetra
.622 .312 .425 r
.51945 .58162 .52616 .55216 .53852 .57294 .53191 .59134 Metetra
.287 0 .218 r
.53191 .59134 .53852 .57294 .55098 .57549 .54442 .58216 Metetra
.933 .944 .602 r
.54442 .58216 .55098 .57549 .56335 .56096 .55679 .55644 Metetra
.95 .783 .64 r
.55679 .55644 .56335 .56096 .57547 .53205 .56888 .51792 Metetra
.901 .699 .62 r
.56888 .51792 .57547 .53205 .58726 .49254 .58063 .471 Metetra
.871 .658 .611 r
.58063 .471 .58726 .49254 .5987 .44673 .59203 .42028 Metetra
.485 .41 .697 r
.59203 .42028 .5987 .44673 .61015 .41101 .6045 .4257 Metetra
.838 .491 .398 r
.6045 .4257 .61015 .41101 .62367 .45033 .6181 .46633 Metetra
.812 .462 .394 r
.6181 .46633 .62367 .45033 .63745 .4859 .63191 .50093 Metetra
.772 .409 .368 r
.63191 .50093 .63745 .4859 .65129 .51375 .64571 .52561 Metetra
.681 .283 .286 r
.64571 .52561 .65129 .51375 .66497 .5303 .65927 .53711 Metetra
.203 0 0 r
.65927 .53711 .66497 .5303 .67823 .53283 .67233 .53328 Metetra
.946 .951 .74 r
.67233 .53328 .67823 .53283 .69084 .51988 .68469 .5134 Metetra
.947 .784 .647 r
.68469 .5134 .69084 .51988 .7026 .49156 .6962 .47845 Metetra
.922 .716 .607 r
.6962 .47845 .7026 .49156 .71346 .44966 .70683 .43102 Metetra
.906 .683 .59 r
.70683 .43102 .71346 .44966 .72343 .39749 .71666 .37514 Metetra
.005 .119 .633 r
.71666 .37514 .72343 .39749 .736 .38992 .73124 .3991 Metetra
.894 .524 .332 r
.73124 .3991 .736 .38992 .75286 .44333 .74811 .45238 Metetra
.882 .503 .317 r
.74811 .45238 .75286 .44333 .77004 .49384 .76506 .4993 Metetra
.851 .429 .228 r
.76506 .4993 .77004 .49384 .78679 .53217 .78123 .5298 Metetra
.042 .579 .852 r
.78123 .5298 .78679 .53217 .80199 .54675 .79548 .53199 Metetra
.903 .712 .633 r
.79548 .53199 .80199 .54675 .81428 .52494 .80642 .49375 Metetra
.906 .654 .545 r
.80642 .49375 .81428 .52494 .82214 .45528 .81266 .40531 Metetra
.623 .45 .627 r
.81266 .40531 .82214 .45528 .82517 .33988 .82556 .39522 Metetra
.872 .552 .441 r
.82556 .39522 .82517 .33988 .85803 .534 .8545 .54898 Metetra
.401 .031 .216 r
.8545 .54898 .85803 .534 .87447 .55242 .86876 .5449 Metetra
.645 .763 .934 r
.86876 .5449 .87447 .55242 .88874 .54836 .88309 .5408 Metetra
.983 .696 .377 r
.88309 .5408 .88874 .54836 .87768 .31807 .87234 .31003 Metetra
.664 .741 .908 r
.87234 .31003 .87768 .31807 .89107 .31372 .88578 .30565 Metetra
.664 .741 .908 r
.28572 .49254 .29278 .49911 .30368 .49556 .29665 .48895 Metetra
.664 .741 .908 r
.29665 .48895 .30368 .49556 .31463 .49199 .30762 .48536 Metetra
.943 .671 .493 r
.30762 .48536 .31463 .49199 .31264 .7041 .30515 .69789 Metetra
.645 .763 .934 r
.30515 .69789 .31264 .7041 .32437 .70074 .31691 .6945 Metetra
.645 .763 .934 r
.31691 .6945 .32437 .70074 .33615 .69737 .32872 .6911 Metetra
.645 .763 .934 r
.32872 .6911 .33615 .69737 .34798 .69398 .34058 .68769 Metetra
.645 .763 .934 r
.34058 .68769 .34798 .69398 .35987 .69058 .3525 .68426 Metetra
.941 .702 .547 r
.3525 .68426 .35987 .69058 .3752 .60929 .37275 .50012 Metetra
.725 .577 0 r
.37275 .50012 .3752 .60929 .38734 .59561 .3765 .67735 Metetra
.53 .283 .486 r
.3765 .67735 .38734 .59561 .39584 .68028 .38858 .67387 Metetra
.645 .763 .934 r
.38858 .67387 .39584 .68028 .40794 .67681 .40072 .67038 Metetra
.645 .763 .934 r
.40072 .67038 .40794 .67681 .4201 .67334 .4129 .66687 Metetra
.645 .763 .934 r
.4129 .66687 .4201 .67334 .43231 .66984 .42515 .66335 Metetra
.843 .786 .796 r
.42515 .66335 .43231 .66984 .44457 .66633 .43772 .64905 Metetra
.917 .686 .573 r
.43772 .64905 .44457 .66633 .45809 .60139 .45211 .54975 Metetra
.831 .598 .585 r
.45211 .54975 .45809 .60139 .47165 .51024 .46572 .45864 Metetra
.378 .27 .602 r
.46572 .45864 .47165 .51024 .48434 .44382 .47715 .47877 Metetra
.798 .499 .483 r
.47715 .47877 .48434 .44382 .4955 .50528 .4884 .53649 Metetra
.768 .461 .467 r
.4884 .53649 .4955 .50528 .50725 .55242 .50028 .57695 Metetra
.708 .384 .427 r
.50028 .57695 .50725 .55242 .51945 .58162 .5126 .59749 Metetra
.5 .132 .273 r
.5126 .59749 .51945 .58162 .53191 .59134 .52515 .59772 Metetra
.812 .954 .616 r
.52515 .59772 .53191 .59134 .54442 .58216 .53772 .57927 Metetra
.956 .811 .66 r
.53772 .57927 .54442 .58216 .55679 .55644 .55012 .54547 Metetra
.916 .722 .626 r
.55012 .54547 .55679 .55644 .56888 .51792 .56223 .50064 Metetra
.892 .682 .612 r
.56223 .50064 .56888 .51792 .58063 .471 .574 .4495 Metetra
.876 .66 .607 r
.574 .4495 .58063 .471 .59203 .42028 .58543 .39667 Metetra
0 0 .347 r
.58543 .39667 .59203 .42028 .6045 .4257 .59862 .43549 Metetra
.861 .499 .364 r
.59862 .43549 .6045 .4257 .6181 .46633 .61222 .47536 Metetra
.841 .463 .336 r
.61222 .47536 .6181 .46633 .63191 .50093 .62597 .50741 Metetra
.797 .378 .252 r
.62597 .50741 .63191 .50093 .64571 .52561 .63968 .528 Metetra
.561 .01 0 r
.63968 .528 .64571 .52561 .65927 .53711 .65309 .53429 Metetra
.808 .929 .914 r
.65309 .53429 .65927 .53711 .67233 .53328 .66597 .52473 Metetra
.903 .769 .702 r
.66597 .52473 .67233 .53328 .68469 .5134 .67815 .49932 Metetra
.901 .708 .633 r
.67815 .49932 .68469 .5134 .6962 .47845 .6895 .45974 Metetra
.896 .681 .603 r
.6895 .45974 .6962 .47845 .70683 .43102 .70003 .40918 Metetra
.889 .666 .594 r
.70003 .40918 .70683 .43102 .71666 .37514 .71001 .35475 Metetra
.703 .396 0 r
.71001 .35475 .71666 .37514 .73124 .3991 .72628 .40666 Metetra
.896 .519 .314 r
.72628 .40666 .73124 .3991 .74811 .45238 .74298 .45724 Metetra
.887 .486 .258 r
.74298 .45724 .74811 .45238 .76506 .4993 .75951 .49812 Metetra
.788 .289 0 r
.75951 .49812 .76506 .4993 .78123 .5298 .77498 .51886 Metetra
.775 .722 .804 r
.77498 .51886 .78123 .5298 .79548 .53199 .7882 .50776 Metetra
.884 .659 .593 r
.7882 .50776 .79548 .53199 .80642 .49375 .79786 .45375 Metetra
.898 .637 .536 r
.79786 .45375 .80642 .49375 .81266 .40531 .80271 .34907 Metetra
0 0 .327 r
.80271 .34907 .81266 .40531 .82556 .39522 .82642 .45814 Metetra
.782 .474 .467 r
.82642 .45814 .82556 .39522 .8545 .54898 .84869 .54143 Metetra
.645 .763 .934 r
.84869 .54143 .8545 .54898 .86876 .5449 .863 .53731 Metetra
.983 .698 .383 r
.863 .53731 .86876 .5449 .88309 .5408 .85355 .30632 Metetra
.562 .358 .562 r
.85355 .30632 .88309 .5408 .87234 .31003 .86696 .30192 Metetra
.664 .741 .908 r
.86696 .30192 .87234 .31003 .88578 .30565 .88044 .2975 Metetra
.664 .741 .908 r
.2786 .48591 .28572 .49254 .29665 .48895 .28956 .4823 Metetra
.664 .741 .908 r
.28956 .4823 .29665 .48895 .30762 .48536 .30056 .47867 Metetra
.943 .671 .493 r
.30056 .47867 .30762 .48536 .30515 .69789 .29759 .69163 Metetra
.645 .763 .934 r
.29759 .69163 .30515 .69789 .31691 .6945 .30939 .68821 Metetra
.645 .763 .934 r
.30939 .68821 .31691 .6945 .32872 .6911 .32123 .68479 Metetra
.645 .763 .934 r
.32123 .68479 .32872 .6911 .34058 .68769 .33313 .68134 Metetra
.931 .722 .599 r
.33313 .68134 .34058 .68769 .3525 .68426 .34863 .60869 Metetra
.587 .403 .599 r
.34863 .60869 .3525 .68426 .37275 .50012 .36053 .60258 Metetra
.703 .443 .528 r
.36053 .60258 .37275 .50012 .3765 .67735 .36914 .67092 Metetra
.645 .763 .934 r
.36914 .67092 .3765 .67735 .38858 .67387 .38126 .66741 Metetra
.645 .763 .934 r
.38126 .66741 .38858 .67387 .40072 .67038 .39343 .66389 Metetra
.645 .763 .934 r
.39343 .66389 .40072 .67038 .4129 .66687 .40565 .66035 Metetra
.645 .763 .934 r
.40565 .66035 .4129 .66687 .42515 .66335 .41793 .6568 Metetra
.933 .739 .619 r
.41793 .6568 .42515 .66335 .43772 .64905 .4316 .60431 Metetra
.853 .618 .582 r
.4316 .60431 .43772 .64905 .45211 .54975 .44609 .50497 Metetra
.819 .593 .596 r
.44609 .50497 .45211 .54975 .46572 .45864 .45935 .43521 Metetra
.932 .62 .159 r
.45935 .43521 .46572 .45864 .47715 .47877 .46993 .50258 Metetra
.822 .509 .46 r
.46993 .50258 .47715 .47877 .4884 .53649 .48127 .55489 Metetra
.794 .46 .424 r
.48127 .55489 .4884 .53649 .50028 .57695 .49324 .58824 Metetra
.702 .312 .306 r
.49324 .58824 .50028 .57695 .5126 .59749 .50566 .60092 Metetra
.429 .846 .682 r
.50566 .60092 .5126 .59749 .52515 .59772 .51829 .59344 Metetra
.928 .816 .715 r
.51829 .59344 .52515 .59772 .53772 .57927 .53093 .56829 Metetra
.905 .723 .644 r
.53093 .56829 .53772 .57927 .55012 .54547 .54339 .52931 Metetra
.892 .687 .619 r
.54339 .52931 .55012 .54547 .56223 .50064 .55555 .48114 Metetra
.884 .671 .609 r
.55555 .48114 .56223 .50064 .574 .4495 .56738 .42851 Metetra
.822 .637 .651 r
.56738 .42851 .574 .4495 .58543 .39667 .57926 .3979 Metetra
.91 .532 .296 r
.57926 .3979 .58543 .39667 .59862 .43549 .59252 .44051 Metetra
.88 .5 .314 r
.59252 .44051 .59862 .43549 .61222 .47536 .60606 .47789 Metetra
.864 .447 .233 r
.60606 .47789 .61222 .47536 .62597 .50741 .61972 .50619 Metetra
.762 .249 0 r
.61972 .50619 .62597 .50741 .63968 .528 .63329 .52209 Metetra
.371 .674 .975 r
.63329 .52209 .63968 .528 .65309 .53429 .64655 .52328 Metetra
.81 .722 .768 r
.64655 .52328 .65309 .53429 .66597 .52473 .65927 .50883 Metetra
.857 .684 .667 r
.65927 .50883 .66597 .52473 .67815 .49932 .67131 .47933 Metetra
.871 .667 .623 r
.67131 .47933 .67815 .49932 .6895 .45974 .68258 .437 Metetra
.878 .659 .602 r
.68258 .437 .6895 .45974 .70003 .40918 .69312 .38542 Metetra
.778 .603 .663 r
.69312 .38542 .70003 .40918 .71001 .35475 .70494 .36226 Metetra
.895 .52 .318 r
.70494 .36226 .71001 .35475 .72628 .40666 .72109 .41201 Metetra
.896 .507 .282 r
.72109 .41201 .72628 .40666 .74298 .45724 .73748 .45773 Metetra
.876 .442 .146 r
.73748 .45773 .74298 .45724 .75951 .49812 .75347 .49071 Metetra
0 .299 .786 r
.75347 .49071 .75951 .49812 .77498 .51886 .76814 .50052 Metetra
.822 .66 .681 r
.76814 .50052 .77498 .51886 .7882 .50776 .78035 .47612 Metetra
.879 .639 .572 r
.78035 .47612 .7882 .50776 .79786 .45375 .78886 .40783 Metetra
.827 .588 .577 r
.78886 .40783 .79786 .45375 .80271 .34907 .7971 .34194 Metetra
.961 .628 .266 r
.7971 .34194 .80271 .34907 .82642 .45814 .82742 .52563 Metetra
.576 .308 .473 r
.82742 .52563 .82642 .45814 .84869 .54143 .84283 .53381 Metetra
.645 .763 .934 r
.84283 .53381 .84869 .54143 .863 .53731 .85718 .52966 Metetra
.983 .698 .383 r
.85718 .52966 .863 .53731 .85355 .30632 .84808 .29819 Metetra
.664 .741 .908 r
.84808 .29819 .85355 .30632 .86696 .30192 .86154 .29375 Metetra
.664 .741 .908 r
.86154 .29375 .86696 .30192 .88044 .2975 .87506 .28929 Metetra
.664 .741 .908 r
.27143 .47923 .2786 .48591 .28956 .4823 .28241 .47559 Metetra
.664 .741 .908 r
.28241 .47559 .28956 .4823 .30056 .47867 .29344 .47194 Metetra
.664 .741 .908 r
.29344 .47194 .30056 .47867 .29759 .69163 .30451 .46827 Metetra
0 0 .293 r
.30451 .46827 .29759 .69163 .30939 .68821 .3018 .68187 Metetra
.645 .763 .934 r
.3018 .68187 .30939 .68821 .32123 .68479 .31368 .67842 Metetra
.645 .763 .934 r
.31368 .67842 .32123 .68479 .33313 .68134 .32561 .67494 Metetra
.94 .703 .553 r
.32561 .67494 .33313 .68134 .34863 .60869 .34634 .50824 Metetra
0 0 .077 r
.34634 .50824 .34863 .60869 .36053 .60258 .35045 .65166 Metetra
.616 .337 .472 r
.35045 .65166 .36053 .60258 .36914 .67092 .36172 .66443 Metetra
.645 .763 .934 r
.36172 .66443 .36914 .67092 .38126 .66741 .37387 .6609 Metetra
.645 .763 .934 r
.37387 .6609 .38126 .66741 .39343 .66389 .38608 .65734 Metetra
.645 .763 .934 r
.38608 .65734 .39343 .66389 .40565 .66035 .39833 .65378 Metetra
.645 .763 .934 r
.39833 .65378 .40565 .66035 .41793 .6568 .41065 .65019 Metetra
.943 .722 .573 r
.41065 .65019 .41793 .6568 .4316 .60431 .4255 .56232 Metetra
.855 .621 .583 r
.4255 .56232 .4316 .60431 .44609 .50497 .43999 .46724 Metetra
.669 .497 .644 r
.43999 .46724 .44609 .50497 .45935 .43521 .45207 .4534 Metetra
.859 .545 .454 r
.45207 .4534 .45935 .43521 .46993 .50258 .46272 .51557 Metetra
.854 .52 .42 r
.46272 .51557 .46993 .50258 .48127 .55489 .47414 .56134 Metetra
.832 .448 .324 r
.47414 .56134 .48127 .55489 .49324 .58824 .48621 .58761 Metetra
.479 0 0 r
.48621 .58761 .49324 .58824 .50566 .60092 .4987 .59349 Metetra
.829 .779 .805 r
.4987 .59349 .50566 .60092 .51829 .59344 .5114 .58021 Metetra
.866 .701 .676 r
.5114 .58021 .51829 .59344 .53093 .56829 .5241 .55076 Metetra
.872 .675 .635 r
.5241 .55076 .53093 .56829 .54339 .52931 .53661 .50923 Metetra
.874 .666 .617 r
.53661 .50923 .54339 .52931 .55555 .48114 .54885 .46026 Metetra
.877 .663 .61 r
.54885 .46026 .55555 .48114 .56738 .42851 .56077 .40842 Metetra
.667 .559 .723 r
.56077 .40842 .56738 .42851 .57926 .3979 .57304 .4012 Metetra
.895 .517 .309 r
.57304 .4012 .57926 .3979 .59252 .44051 .58624 .44107 Metetra
.892 .486 .237 r
.58624 .44107 .59252 .44051 .60606 .47789 .59968 .4746 Metetra
.843 .379 .026 r
.59968 .4746 .60606 .47789 .61972 .50619 .61321 .49827 Metetra
0 .194 .708 r
.61321 .49827 .61972 .50619 .63329 .52209 .62663 .50922 Metetra
.634 .625 .824 r
.62663 .50922 .63329 .52209 .64655 .52328 .63974 .50569 Metetra
.786 .644 .705 r
.63974 .50569 .64655 .52328 .65927 .50883 .65233 .48728 Metetra
.831 .643 .648 r
.65233 .48728 .65927 .50883 .67131 .47933 .66429 .45511 Metetra
.852 .643 .619 r
.66429 .45511 .67131 .47933 .68258 .437 .67556 .41174 Metetra
.865 .645 .603 r
.67556 .41174 .68258 .437 .69312 .38542 .68619 .36095 Metetra
.429 .388 .712 r
.68619 .36095 .69312 .38542 .70494 .36226 .69972 .36889 Metetra
.891 .508 .302 r
.69972 .36889 .70494 .36226 .72109 .41201 .71564 .41465 Metetra
.891 .483 .226 r
.71564 .41465 .72109 .41201 .73748 .45773 .73162 .45383 Metetra
.791 .308 0 r
.73162 .45383 .73748 .45773 .75347 .49071 .747 .47768 Metetra
.585 .604 .837 r
.747 .47768 .75347 .49071 .76814 .50052 .76086 .47615 Metetra
.838 .637 .631 r
.76086 .47615 .76814 .50052 .78035 .47612 .77213 .43919 Metetra
.879 .631 .559 r
.77213 .43919 .78035 .47612 .78886 .40783 .7797 .35873 Metetra
.3 .231 .61 r
.7797 .35873 .78886 .40783 .7971 .34194 .79597 .38834 Metetra
.88 .555 .429 r
.79597 .38834 .7971 .34194 .82742 .52563 .82257 .5303 Metetra
.075 0 0 r
.82257 .5303 .82742 .52563 .84283 .53381 .83691 .52612 Metetra
.982 .699 .39 r
.83691 .52612 .84283 .53381 .85718 .52966 .82911 .29443 Metetra
.559 .354 .559 r
.82911 .29443 .85718 .52966 .84808 .29819 .84256 .28998 Metetra
.664 .741 .908 r
.84256 .28998 .84808 .29819 .86154 .29375 .85606 .2855 Metetra
.664 .741 .908 r
.85606 .2855 .86154 .29375 .87506 .28929 .86963 .28101 Metetra
.664 .741 .908 r
.2642 .4725 .27143 .47923 .28241 .47559 .27521 .46883 Metetra
.664 .741 .908 r
.27521 .46883 .28241 .47559 .29344 .47194 .28627 .46515 Metetra
.664 .741 .908 r
.28627 .46515 .29344 .47194 .30451 .46827 .29737 .46145 Metetra
.944 .671 .49 r
.29737 .46145 .30451 .46827 .3018 .68187 .29416 .67548 Metetra
.645 .763 .934 r
.29416 .67548 .3018 .68187 .31368 .67842 .30606 .67199 Metetra
.645 .763 .934 r
.30606 .67199 .31368 .67842 .32561 .67494 .31803 .66849 Metetra
.941 .7 .546 r
.31803 .66849 .32561 .67494 .34634 .50824 .34128 .46378 Metetra
.987 .716 .397 r
.34128 .46378 .34634 .50824 .35045 .65166 .34244 .6552 Metetra
.458 0 0 r
.34244 .6552 .35045 .65166 .36172 .66443 .35424 .65789 Metetra
.645 .763 .934 r
.35424 .65789 .36172 .66443 .37387 .6609 .36642 .65433 Metetra
.645 .763 .934 r
.36642 .65433 .37387 .6609 .38608 .65734 .37866 .65074 Metetra
.645 .763 .934 r
.37866 .65074 .38608 .65734 .39833 .65378 .39096 .64715 Metetra
.902 .765 .7 r
.39096 .64715 .39833 .65378 .41065 .65019 .40415 .61961 Metetra
.881 .649 .583 r
.40415 .61961 .41065 .65019 .4255 .56232 .41937 .52413 Metetra
.857 .625 .586 r
.41937 .52413 .4255 .56232 .43999 .46724 .43377 .43632 Metetra
0 .037 .554 r
.43377 .43632 .43999 .46724 .45207 .4534 .44483 .46326 Metetra
.883 .554 .421 r
.44483 .46326 .45207 .4534 .46272 .51557 .45557 .51859 Metetra
.891 .525 .342 r
.45557 .51859 .46272 .51557 .47414 .56134 .46709 .55722 Metetra
.826 .35 0 r
.46709 .55722 .47414 .56134 .48621 .58761 .47922 .57679 Metetra
.522 .607 .879 r
.47922 .57679 .48621 .58761 .4987 .59349 .49178 .5771 Metetra
.783 .648 .714 r
.49178 .5771 .4987 .59349 .5114 .58021 .50452 .55987 Metetra
.828 .645 .656 r
.50452 .55987 .5114 .58021 .5241 .55076 .51726 .52828 Metetra
.847 .646 .63 r
.51726 .52828 .5241 .55076 .53661 .50923 .52984 .48644 Metetra
.86 .65 .618 r
.52984 .48644 .53661 .50923 .54885 .46026 .54215 .43876 Metetra
.87 .658 .614 r
.54215 .43876 .54885 .46026 .56077 .40842 .55417 .38951 Metetra
.213 .289 .726 r
.55417 .38951 .56077 .40842 .57304 .4012 .5667 .40178 Metetra
.898 .502 .257 r
.5667 .40178 .57304 .4012 .58624 .44107 .5798 .43755 Metetra
.88 .444 .105 r
.5798 .43755 .58624 .44107 .59968 .4746 .59313 .46627 Metetra
.616 .156 0 r
.59313 .46627 .59968 .4746 .61321 .49827 .60652 .48481 Metetra
.339 .453 .831 r
.60652 .48481 .61321 .49827 .62663 .50922 .61979 .49085 Metetra
.68 .585 .743 r
.61979 .49085 .62663 .50922 .63974 .50569 .63275 .48314 Metetra
.774 .609 .676 r
.63275 .48314 .63974 .50569 .65233 .48728 .64525 .46178 Metetra
.815 .619 .639 r
.64525 .46178 .65233 .48728 .66429 .45511 .65717 .42825 Metetra
.839 .628 .618 r
.65717 .42825 .66429 .45511 .67556 .41174 .66849 .38531 Metetra
.856 .637 .606 r
.66849 .38531 .67556 .41174 .68619 .36095 .67929 .3368 Metetra
0 0 .456 r
.67929 .3368 .68619 .36095 .69972 .36889 .69432 .3739 Metetra
.886 .49 .27 r
.69432 .3739 .69972 .36889 .71564 .41465 .70993 .41421 Metetra
.873 .433 .122 r
.70993 .41421 .71564 .41465 .73162 .45383 .72544 .44568 Metetra
0 .107 .64 r
.72544 .44568 .73162 .45383 .747 .47768 .74017 .45979 Metetra
.737 .623 .732 r
.74017 .45979 .747 .47768 .76086 .47615 .75327 .4472 Metetra
.849 .629 .604 r
.75327 .4472 .76086 .47615 .77213 .43919 .76372 .39908 Metetra
.882 .628 .55 r
.76372 .39908 .77213 .43919 .7797 .35873 .77056 .30895 Metetra
0 0 .164 r
.77056 .30895 .7797 .35873 .79597 .38834 .79466 .43533 Metetra
.824 .5 .441 r
.79466 .43533 .79597 .38834 .82257 .5303 .81655 .52258 Metetra
.645 .763 .934 r
.81655 .52258 .82257 .5303 .83691 .52612 .83094 .51836 Metetra
.982 .699 .39 r
.83094 .51836 .83691 .52612 .82911 .29443 .8235 .28619 Metetra
.664 .741 .908 r
.8235 .28619 .82911 .29443 .84256 .28998 .83699 .2817 Metetra
.664 .741 .908 r
.83699 .2817 .84256 .28998 .85606 .2855 .85054 .27718 Metetra
.664 .741 .908 r
.85054 .27718 .85606 .2855 .86963 .28101 .86416 .27265 Metetra
.664 .741 .908 r
.25692 .46572 .2642 .4725 .27521 .46883 .26796 .46202 Metetra
.664 .741 .908 r
.26796 .46202 .27521 .46883 .28627 .46515 .27904 .45831 Metetra
.664 .741 .908 r
.27904 .45831 .28627 .46515 .29737 .46145 .29017 .45458 Metetra
.944 .671 .49 r
.29017 .45458 .29737 .46145 .29416 .67548 .28645 .66903 Metetra
.645 .763 .934 r
.28645 .66903 .29416 .67548 .30606 .67199 .29839 .66552 Metetra
.645 .763 .934 r
.29839 .66552 .30606 .67199 .31803 .66849 .31038 .66199 Metetra
.94 .7 .547 r
.31038 .66199 .31803 .66849 .34128 .46378 .33406 .45858 Metetra
.947 .664 .47 r
.33406 .45858 .34128 .46378 .34244 .6552 .33622 .62419 Metetra
0 0 .529 r
.33622 .62419 .34244 .6552 .35424 .65789 .3467 .6513 Metetra
.645 .763 .934 r
.3467 .6513 .35424 .65789 .36642 .65433 .35891 .6477 Metetra
.645 .763 .934 r
.35891 .6477 .36642 .65433 .37866 .65074 .37119 .64409 Metetra
.645 .763 .934 r
.37119 .64409 .37866 .65074 .39096 .64715 .38352 .64046 Metetra
.936 .732 .601 r
.38352 .64046 .39096 .64715 .40415 .61961 .39815 .57647 Metetra
.844 .613 .589 r
.39815 .57647 .40415 .61961 .41937 .52413 .41316 .49027 Metetra
.859 .63 .591 r
.41316 .49027 .41937 .52413 .43377 .43632 .42741 .41172 Metetra
.86 .558 .031 r
.42741 .41172 .43377 .43632 .44483 .46326 .43766 .46545 Metetra
.909 .559 .366 r
.43766 .46545 .44483 .46326 .45557 .51859 .44852 .51291 Metetra
.908 .499 .165 r
.44852 .51291 .45557 .51859 .46709 .55722 .46013 .54424 Metetra
0 .139 .685 r
.46013 .54424 .46709 .55722 .47922 .57679 .47232 .55778 Metetra
.627 .549 .747 r
.47232 .55778 .47922 .57679 .49178 .5771 .48491 .5538 Metetra
.756 .596 .678 r
.48491 .5538 .49178 .5771 .50452 .55987 .49768 .53428 Metetra
.802 .613 .646 r
.49768 .53428 .50452 .55987 .51726 .52828 .51045 .5024 Metetra
.828 .626 .629 r
.51045 .5024 .51726 .52828 .52984 .48644 .52307 .46206 Metetra
.847 .639 .622 r
.52307 .46206 .52984 .48644 .54215 .43876 .53545 .41731 Metetra
.862 .655 .62 r
.53545 .41731 .54215 .43876 .55417 .38951 .54757 .37202 Metetra
0 0 .4 r
.54757 .37202 .55417 .38951 .5667 .40178 .56023 .39975 Metetra
.892 .471 .174 r
.56023 .39975 .5667 .40178 .5798 .43755 .57324 .43046 Metetra
.791 .331 0 r
.57324 .43046 .5798 .43755 .59313 .46627 .58644 .45376 Metetra
0 .195 .723 r
.58644 .45376 .59313 .46627 .60652 .48481 .59969 .46703 Metetra
.525 .504 .775 r
.59969 .46703 .60652 .48481 .61979 .49085 .61282 .46843 Metetra
.698 .568 .705 r
.61282 .46843 .61979 .49085 .63275 .48314 .62566 .45723 Metetra
.767 .592 .661 r
.62566 .45723 .63275 .48314 .64525 .46178 .63809 .43392 Metetra
.804 .606 .635 r
.63809 .43392 .64525 .46178 .65717 .42825 .65002 .40021 Metetra
.829 .619 .619 r
.65002 .40021 .65717 .42825 .66849 .38531 .66145 .35893 Metetra
.746 .576 .664 r
.66145 .35893 .66849 .38531 .67929 .3368 .67364 .33901 Metetra
.892 .484 .229 r
.67364 .33901 .67929 .3368 .69432 .3739 .6887 .37667 Metetra
.877 .458 .212 r
.6887 .37667 .69432 .3739 .70993 .41421 .70397 .41047 Metetra
.793 .308 0 r
.70397 .41047 .70993 .41421 .72544 .44568 .71898 .43357 Metetra
.385 .511 .862 r
.71898 .43357 .72544 .44568 .74017 .45979 .73309 .43795 Metetra
.79 .624 .675 r
.73309 .43795 .74017 .45979 .75327 .4472 .74549 .41519 Metetra
.858 .627 .587 r
.74549 .41519 .75327 .4472 .76372 .39908 .75528 .35776 Metetra
.722 .525 .624 r
.75528 .35776 .76372 .39908 .77056 .30895 .7671 .33172 Metetra
.928 .592 .378 r
.7671 .33172 .77056 .30895 .79466 .43533 .79294 .48009 Metetra
.707 .392 .442 r
.79294 .48009 .79466 .43533 .81655 .52258 .81047 .51478 Metetra
.645 .763 .934 r
.81047 .51478 .81655 .52258 .83094 .51836 .82491 .51053 Metetra
.982 .699 .39 r
.82491 .51053 .83094 .51836 .8235 .28619 .81785 .27788 Metetra
.664 .741 .908 r
.81785 .27788 .8235 .28619 .83699 .2817 .83138 .27335 Metetra
.664 .741 .908 r
.83138 .27335 .83699 .2817 .85054 .27718 .84498 .2688 Metetra
.664 .741 .908 r
.84498 .2688 .85054 .27718 .86416 .27265 .85864 .26422 Metetra
.664 .741 .908 r
.24958 .45888 .25692 .46572 .26796 .46202 .26064 .45516 Metetra
.664 .741 .908 r
.26064 .45516 .26796 .46202 .27904 .45831 .27175 .45142 Metetra
.664 .741 .908 r
.27175 .45142 .27904 .45831 .29017 .45458 .28291 .44766 Metetra
.664 .741 .908 r
.28291 .44766 .29017 .45458 .28645 .66903 .29412 .44389 Metetra
0 0 .279 r
.29412 .44389 .28645 .66903 .29839 .66552 .29064 .65899 Metetra
.645 .763 .934 r
.29064 .65899 .29839 .66552 .31038 .66199 .30267 .65542 Metetra
.94 .702 .552 r
.30267 .65542 .31038 .66199 .33406 .45858 .3251 .48081 Metetra
.869 .576 .49 r
.3251 .48081 .33406 .45858 .33622 .62419 .33134 .5703 Metetra
0 0 .139 r
.33134 .5703 .33622 .62419 .3467 .6513 .33909 .64464 Metetra
.645 .763 .934 r
.33909 .64464 .3467 .6513 .35891 .6477 .35134 .64102 Metetra
.645 .763 .934 r
.35134 .64102 .35891 .6477 .37119 .64409 .36365 .63737 Metetra
.902 .763 .698 r
.36365 .63737 .37119 .64409 .38352 .64046 .37707 .60915 Metetra
.859 .635 .598 r
.37707 .60915 .38352 .64046 .39815 .57647 .39216 .53575 Metetra
.837 .609 .594 r
.39216 .53575 .39815 .57647 .41316 .49027 .40686 .46089 Metetra
.833 .62 .615 r
.40686 .46089 .41316 .49027 .42741 .41172 .42033 .40989 Metetra
.93 .582 .351 r
.42033 .40989 .42741 .41172 .43766 .46545 .43058 .46095 Metetra
.927 .549 .264 r
.43058 .46095 .43766 .46545 .44852 .51291 .44159 .50007 Metetra
.705 .31 0 r
.44159 .50007 .44852 .51291 .46013 .54424 .45328 .52435 Metetra
.344 .37 .745 r
.45328 .52435 .46013 .54424 .47232 .55778 .46552 .53266 Metetra
.647 .524 .699 r
.46552 .53266 .47232 .55778 .48491 .5538 .47812 .52562 Metetra
.738 .567 .662 r
.47812 .52562 .48491 .5538 .49768 .53428 .49089 .50525 Metetra
.783 .592 .642 r
.49089 .50525 .49768 .53428 .51045 .5024 .50366 .47457 Metetra
.812 .611 .631 r
.50366 .47457 .51045 .5024 .52307 .46206 .51631 .4371 Metetra
.834 .631 .628 r
.51631 .4371 .52307 .46206 .53545 .41731 .52875 .39647 Metetra
.826 .64 .651 r
.52875 .39647 .53545 .41731 .54757 .37202 .54102 .3655 Metetra
.88 .453 .054 r
.54102 .3655 .54757 .37202 .56023 .39975 .55367 .39528 Metetra
.856 .404 .033 r
.55367 .39528 .56023 .39975 .57324 .43046 .56659 .42034 Metetra
0 0 .48 r
.56659 .42034 .57324 .43046 .58644 .45376 .57967 .438 Metetra
.296 .39 .79 r
.57967 .438 .58644 .45376 .59969 .46703 .59278 .44611 Metetra
.602 .522 .737 r
.59278 .44611 .59969 .46703 .61282 .46843 .60579 .44337 Metetra
.71 .562 .685 r
.60579 .44337 .61282 .46843 .62566 .45723 .61854 .42945 Metetra
.763 .583 .654 r
.61854 .42945 .62566 .45723 .63809 .43392 .63093 .40513 Metetra
.797 .599 .634 r
.63093 .40513 .63809 .43392 .65002 .40021 .64291 .37226 Metetra
.822 .615 .623 r
.64291 .37226 .65002 .40021 .66145 .35893 .65447 .33362 Metetra
.366 .343 .701 r
.65447 .33362 .66145 .35893 .67364 .33901 .66805 .34447 Metetra
.86 .451 .255 r
.66805 .34447 .67364 .33901 .6887 .37667 .68287 .37672 Metetra
.852 .397 .102 r
.68287 .37672 .6887 .37667 .70397 .41047 .69776 .40338 Metetra
0 .032 .552 r
.69776 .40338 .70397 .41047 .71898 .43357 .71227 .41796 Metetra
.647 .6 .788 r
.71227 .41796 .71898 .43357 .73309 .43795 .72581 .41315 Metetra
.816 .624 .643 r
.72581 .41315 .73309 .43795 .74549 .41519 .73764 .38159 Metetra
.866 .628 .576 r
.73764 .38159 .74549 .41519 .75528 .35776 .74696 .31703 Metetra
0 .017 .536 r
.74696 .31703 .75528 .35776 .7671 .33172 .76411 .36285 Metetra
.913 .58 .398 r
.76411 .36285 .7671 .33172 .79294 .48009 .78992 .51119 Metetra
.47 .165 .366 r
.78992 .51119 .79294 .48009 .81047 .51478 .80434 .50692 Metetra
.982 .7 .396 r
.80434 .50692 .81047 .51478 .82491 .51053 .79862 .27405 Metetra
.556 .349 .555 r
.79862 .27405 .82491 .51053 .81785 .27788 .81214 .2695 Metetra
.664 .741 .908 r
.81214 .2695 .81785 .27788 .83138 .27335 .82572 .26493 Metetra
.664 .741 .908 r
.82572 .26493 .83138 .27335 .84498 .2688 .83936 .26033 Metetra
.664 .741 .908 r
.83936 .26033 .84498 .2688 .85864 .26422 .85307 .25572 Metetra
.664 .741 .908 r
.24218 .452 .24958 .45888 .26064 .45516 .25327 .44824 Metetra
.664 .741 .908 r
.25327 .44824 .26064 .45516 .27175 .45142 .26441 .44447 Metetra
.664 .741 .908 r
.26441 .44447 .27175 .45142 .28291 .44766 .2756 .44069 Metetra
.664 .741 .908 r
.2756 .44069 .28291 .44766 .29412 .44389 .28683 .43688 Metetra
.945 .671 .487 r
.28683 .43688 .29412 .44389 .29064 .65899 .28284 .6524 Metetra
.645 .763 .934 r
.28284 .6524 .29064 .65899 .30267 .65542 .2949 .64881 Metetra
.938 .708 .565 r
.2949 .64881 .30267 .65542 .3251 .48081 .31482 .52103 Metetra
.305 .041 .338 r
.31482 .52103 .3251 .48081 .33134 .5703 .32734 .50419 Metetra
0 0 .097 r
.32734 .50419 .33134 .5703 .33909 .64464 .3337 .59699 Metetra
.188 .136 .564 r
.3337 .59699 .33909 .64464 .35134 .64102 .34418 .62505 Metetra
.793 .654 .71 r
.34418 .62505 .35134 .64102 .36365 .63737 .35723 .60625 Metetra
.818 .611 .622 r
.35723 .60625 .36365 .63737 .37707 .60915 .37153 .55892 Metetra
.792 .57 .601 r
.37153 .55892 .37707 .60915 .39216 .53575 .38612 .49839 Metetra
.828 .607 .603 r
.38612 .49839 .39216 .53575 .40686 .46089 .40043 .43587 Metetra
.781 .6 .655 r
.40043 .43587 .40686 .46089 .42033 .40989 .41313 .40937 Metetra
.914 .552 .332 r
.41313 .40937 .42033 .40989 .43058 .46095 .42361 .45095 Metetra
.889 .485 .056 r
.42361 .45095 .43058 .46095 .44159 .50007 .43477 .48175 Metetra
0 .073 .624 r
.43477 .48175 .44159 .50007 .45328 .52435 .44655 .49949 Metetra
.488 .424 .711 r
.44655 .49949 .45328 .52435 .46552 .53266 .45881 .50347 Metetra
.654 .511 .677 r
.45881 .50347 .46552 .53266 .47812 .52562 .47141 .49448 Metetra
.725 .55 .654 r
.47141 .49448 .47812 .52562 .49089 .50525 .48416 .47444 Metetra
.766 .577 .642 r
.48416 .47444 .49089 .50525 .50366 .47457 .49691 .44605 Metetra
.796 .6 .636 r
.49691 .44605 .50366 .47457 .51631 .4371 .50957 .41243 Metetra
.822 .625 .636 r
.50957 .41243 .51631 .4371 .52875 .39647 .52205 .3767 Metetra
.721 .592 .711 r
.52205 .3767 .52875 .39647 .54102 .3655 .53442 .3645 Metetra
.86 .417 .14 r
.53442 .3645 .54102 .3655 .55367 .39528 .54703 .38859 Metetra
.735 .254 0 r
.54703 .38859 .55367 .39528 .56659 .42034 .55986 .40778 Metetra
0 .229 .745 r
.55986 .40778 .56659 .42034 .57967 .438 .57284 .41987 Metetra
.476 .471 .773 r
.57284 .41987 .57967 .438 .59278 .44611 .58584 .42322 Metetra
.644 .534 .714 r
.58584 .42322 .59278 .44611 .60579 .44337 .59874 .41696 Metetra
.718 .561 .675 r
.59874 .41696 .60579 .44337 .61854 .42945 .61142 .40112 Metetra
.762 .58 .651 r
.61142 .40112 .61854 .42945 .63093 .40513 .62381 .37666 Metetra
.792 .597 .637 r
.62381 .37666 .63093 .40513 .64291 .37226 .63585 .34546 Metetra
.778 .593 .649 r
.63585 .34546 .64291 .37226 .65447 .33362 .64794 .31928 Metetra
0 0 .376 r
.64794 .31928 .65447 .33362 .66805 .34447 .66225 .34747 Metetra
.845 .406 .18 r
.66225 .34747 .66805 .34447 .68287 .37672 .67681 .37372 Metetra
.762 .255 0 r
.67681 .37372 .68287 .37672 .69776 .40338 .69132 .39302 Metetra
.232 .459 .873 r
.69132 .39302 .69776 .40338 .71227 .41796 .70538 .39941 Metetra
.738 .618 .726 r
.70538 .39941 .71227 .41796 .72581 .41315 .71843 .38642 Metetra
.833 .626 .623 r
.71843 .38642 .72581 .41315 .73764 .38159 .72981 .34779 Metetra
.855 .62 .584 r
.72981 .34779 .73764 .38159 .74696 .31703 .73958 .28911 Metetra
.838 .534 0 r
.73958 .28911 .74696 .31703 .76411 .36285 .76066 .39021 Metetra
.9 .56 .391 r
.76066 .39021 .76411 .36285 .78992 .51119 .78368 .50329 Metetra
.645 .763 .934 r
.78368 .50329 .78992 .51119 .80434 .50692 .79815 .49898 Metetra
.982 .7 .396 r
.79815 .49898 .80434 .50692 .79862 .27405 .79282 .26563 Metetra
.664 .741 .908 r
.79282 .26563 .79862 .27405 .81214 .2695 .80638 .26104 Metetra
.664 .741 .908 r
.80638 .26104 .81214 .2695 .82572 .26493 .82001 .25643 Metetra
.664 .741 .908 r
.82001 .25643 .82572 .26493 .83936 .26033 .83369 .2518 Metetra
.664 .741 .908 r
.83369 .2518 .83936 .26033 .85307 .25572 .84745 .24714 Metetra
.664 .741 .908 r
.23472 .44505 .24218 .452 .25327 .44824 .24584 .44127 Metetra
.664 .741 .908 r
.24584 .44127 .25327 .44824 .26441 .44447 .25701 .43747 Metetra
.664 .741 .908 r
.25701 .43747 .26441 .44447 .2756 .44069 .26822 .43365 Metetra
.664 .741 .908 r
.26822 .43365 .2756 .44069 .28683 .43688 .27949 .42982 Metetra
.945 .671 .487 r
.27949 .42982 .28683 .43688 .28284 .6524 .27496 .64576 Metetra
.645 .763 .934 r
.27496 .64576 .28284 .6524 .2949 .64881 .28706 .64214 Metetra
.93 .723 .601 r
.28706 .64214 .2949 .64881 .31482 .52103 .30362 .57087 Metetra
.991 .811 .43 r
.30362 .57087 .31482 .52103 .32734 .50419 .32378 .43461 Metetra
0 0 .16 r
.32378 .43461 .32734 .50419 .3337 .59699 .32995 .5234 Metetra
.304 .187 .55 r
.32995 .5234 .3337 .59699 .34418 .62505 .33993 .55566 Metetra
.598 .412 .601 r
.33993 .55566 .34418 .62505 .35723 .60625 .35232 .54671 Metetra
.71 .503 .607 r
.35232 .54671 .35723 .60625 .37153 .55892 .36595 .5121 Metetra
.772 .558 .609 r
.36595 .5121 .37153 .55892 .38612 .49839 .37998 .46493 Metetra
.817 .604 .614 r
.37998 .46493 .38612 .49839 .40043 .43587 .39385 .41495 Metetra
.697 .57 .708 r
.39385 .41495 .40043 .43587 .41313 .40937 .40599 .40463 Metetra
.914 .517 .217 r
.40599 .40463 .41313 .40937 .42361 .45095 .41672 .43672 Metetra
0 0 .326 r
.41672 .43672 .42361 .45095 .43477 .48175 .42805 .45962 Metetra
.249 .286 .705 r
.42805 .45962 .43477 .48175 .44655 .49949 .43991 .47155 Metetra
.547 .446 .691 r
.43991 .47155 .44655 .49949 .45881 .50347 .45219 .47211 Metetra
.656 .505 .667 r
.45219 .47211 .45881 .50347 .47141 .49448 .46476 .46211 Metetra
.713 .539 .652 r
.46476 .46211 .47141 .49448 .48416 .47444 .47747 .44329 Metetra
.752 .566 .645 r
.47747 .44329 .48416 .47444 .49691 .44605 .49019 .41797 Metetra
.782 .592 .644 r
.49019 .41797 .49691 .44605 .50957 .41243 .50283 .38879 Metetra
.809 .621 .648 r
.50283 .38879 .50957 .41243 .52205 .3767 .51534 .35837 Metetra
.473 .463 .766 r
.51534 .35837 .52205 .3767 .53442 .3645 .52774 .36173 Metetra
.803 .311 0 r
.52774 .36173 .53442 .3645 .54703 .38859 .54032 .37995 Metetra
0 .041 .579 r
.54032 .37995 .54703 .38859 .55986 .40778 .55309 .39337 Metetra
.305 .417 .812 r
.55309 .39337 .55986 .40778 .57284 .41987 .56597 .40025 Metetra
.569 .512 .752 r
.56597 .40025 .57284 .41987 .58584 .42322 .57888 .39941 Metetra
.671 .545 .702 r
.57888 .39941 .58584 .42322 .59874 .41696 .5917 .39036 Metetra
.725 .564 .672 r
.5917 .39036 .59874 .41696 .61142 .40112 .60435 .37339 Metetra
.762 .581 .654 r
.60435 .37339 .61142 .40112 .62381 .37666 .61675 .34956 Metetra
.789 .599 .644 r
.61675 .34956 .62381 .37666 .63585 .34546 .62889 .3207 Metetra
.498 .432 .713 r
.62889 .3207 .63585 .34546 .64794 .31928 .64209 .32425 Metetra
.82 .385 .206 r
.64209 .32425 .64794 .31928 .66225 .34747 .65624 .34752 Metetra
.804 .316 .029 r
.65624 .34752 .66225 .34747 .67681 .37372 .67053 .36752 Metetra
0 .098 .593 r
.67053 .36752 .67681 .37372 .69132 .39302 .6847 .37965 Metetra
.568 .591 .837 r
.6847 .37965 .69132 .39302 .70538 .39941 .69836 .3786 Metetra
.778 .623 .688 r
.69836 .3786 .70538 .39941 .71843 .38642 .71102 .35881 Metetra
.845 .629 .611 r
.71102 .35881 .71843 .38642 .72981 .34779 .7221 .31506 Metetra
.623 .481 .667 r
.7221 .31506 .72981 .34779 .73958 .28911 .73539 .3082 Metetra
.914 .567 .37 r
.73539 .3082 .73958 .28911 .76066 .39021 .75663 .41178 Metetra
.889 .537 .372 r
.75663 .41178 .76066 .39021 .78368 .50329 .77738 .49532 Metetra
.645 .763 .934 r
.77738 .49532 .78368 .50329 .79815 .49898 .7919 .49097 Metetra
.982 .7 .396 r
.7919 .49097 .79815 .49898 .79282 .26563 .78697 .25714 Metetra
.664 .741 .908 r
.78697 .25714 .79282 .26563 .80638 .26104 .80057 .25251 Metetra
.664 .741 .908 r
.80057 .25251 .80638 .26104 .82001 .25643 .81424 .24786 Metetra
.664 .741 .908 r
.81424 .24786 .82001 .25643 .83369 .2518 .82798 .24319 Metetra
.664 .741 .908 r
.82798 .24319 .83369 .2518 .84745 .24714 .84178 .23849 Metetra
.664 .741 .908 r
.22721 .43805 .23472 .44505 .24584 .44127 .23835 .43424 Metetra
.664 .741 .908 r
.23835 .43424 .24584 .44127 .25701 .43747 .24955 .43041 Metetra
.664 .741 .908 r
.24955 .43041 .25701 .43747 .26822 .43365 .26079 .42656 Metetra
.664 .741 .908 r
.26079 .42656 .26822 .43365 .27949 .42982 .27209 .4227 Metetra
.664 .741 .908 r
.27209 .4227 .27949 .42982 .27496 .64576 .28343 .41882 Metetra
0 0 .264 r
.28343 .41882 .27496 .64576 .28706 .64214 .27915 .63541 Metetra
.826 .782 .81 r
.27915 .63541 .28706 .64214 .30362 .57087 .29196 .62241 Metetra
.999 .793 .463 r
.29196 .62241 .30362 .57087 .32378 .43461 .31519 .4469 Metetra
.629 .239 .286 r
.31519 .4469 .32378 .43461 .32995 .5234 .32619 .45414 Metetra
.222 .127 .53 r
.32619 .45414 .32995 .5234 .33993 .55566 .33562 .49114 Metetra
.544 .374 .601 r
.33562 .49114 .33993 .55566 .35232 .54671 .34732 .49207 Metetra
.675 .48 .614 r
.34732 .49207 .35232 .54671 .36595 .5121 .36027 .4699 Metetra
.748 .546 .621 r
.36027 .4699 .36595 .5121 .37998 .46493 .3737 .43568 Metetra
.803 .603 .631 r
.3737 .43568 .37998 .46493 .39385 .41495 .38712 .39777 Metetra
.58 .534 .768 r
.38712 .39777 .39385 .41495 .40599 .40463 .39891 .39644 Metetra
.844 .403 0 r
.39891 .39644 .40599 .40463 .41672 .43672 .40991 .41953 Metetra
0 .104 .648 r
.40991 .41953 .41672 .43672 .42805 .45962 .4214 .43525 Metetra
.415 .378 .709 r
.4214 .43525 .42805 .45962 .43991 .47155 .43333 .44223 Metetra
.579 .461 .682 r
.43333 .44223 .43991 .47155 .45219 .47211 .44562 .44023 Metetra
.656 .503 .664 r
.44562 .44023 .45219 .47211 .46476 .46211 .45815 .43001 Metetra
.703 .533 .655 r
.45815 .43001 .46476 .46211 .47747 .44329 .47081 .41304 Metetra
.738 .56 .652 r
.47081 .41304 .47747 .44329 .49019 .41797 .48348 .39124 Metetra
.767 .587 .655 r
.48348 .39124 .49019 .41797 .50283 .38879 .4961 .36676 Metetra
.794 .62 .664 r
.4961 .36676 .50283 .38879 .51534 .35837 .50862 .34182 Metetra
0 .149 .678 r
.50862 .34182 .51534 .35837 .52774 .36173 .52098 .35717 Metetra
.62 .081 0 r
.52098 .35717 .52774 .36173 .54032 .37995 .53355 .36968 Metetra
.078 .362 .83 r
.53355 .36968 .54032 .37995 .55309 .39337 .54627 .37769 Metetra
.486 .506 .803 r
.54627 .37769 .55309 .39337 .56597 .40025 .5591 .37993 Metetra
.625 .539 .737 r
.5591 .37993 .56597 .40025 .57888 .39941 .57193 .37562 Metetra
.691 .556 .697 r
.57193 .37562 .57888 .39941 .5917 .39036 .5847 .36455 Metetra
.732 .571 .673 r
.5847 .36455 .5917 .39036 .60435 .37339 .59733 .3472 Metetra
.762 .587 .66 r
.59733 .3472 .60435 .37339 .61675 .34956 .60978 .32465 Metetra
.737 .577 .675 r
.60978 .32465 .61675 .34956 .62889 .3207 .62229 .30727 Metetra
0 .012 .586 r
.62229 .30727 .62889 .3207 .64209 .32425 .63604 .32621 Metetra
.788 .306 .078 r
.63604 .32621 .64209 .32425 .65624 .34752 .65001 .3443 Metetra
.645 .101 0 r
.65001 .3443 .65624 .34752 .67053 .36752 .66405 .35815 Metetra
.23 .487 .893 r
.66405 .35815 .67053 .36752 .6847 .37965 .67791 .36365 Metetra
.686 .616 .772 r
.67791 .36365 .6847 .37965 .69836 .3786 .69125 .35625 Metetra
.8 .626 .666 r
.69125 .35625 .69836 .3786 .71102 .35881 .70363 .3313 Metetra
.854 .634 .604 r
.70363 .3313 .71102 .35881 .7221 .31506 .71456 .28455 Metetra
0 0 .522 r
.71456 .28455 .7221 .31506 .73539 .3082 .73078 .32318 Metetra
.923 .572 .352 r
.73078 .32318 .73539 .3082 .75663 .41178 .75191 .42574 Metetra
.886 .513 .328 r
.75191 .42574 .75663 .41178 .77738 .49532 .77102 .48727 Metetra
.982 .701 .403 r
.77102 .48727 .77738 .49532 .7919 .49097 .76748 .25323 Metetra
.552 .343 .551 r
.76748 .25323 .7919 .49097 .78697 .25714 .78107 .24858 Metetra
.664 .741 .908 r
.78107 .24858 .78697 .25714 .80057 .25251 .79472 .24391 Metetra
.664 .741 .908 r
.79472 .24391 .80057 .25251 .81424 .24786 .80843 .23922 Metetra
.664 .741 .908 r
.80843 .23922 .81424 .24786 .82798 .24319 .82221 .2345 Metetra
.664 .741 .908 r
.82221 .2345 .82798 .24319 .84178 .23849 .83606 .22976 Metetra
.664 .741 .908 r
.21963 .431 .22721 .43805 .23835 .43424 .23081 .42716 Metetra
.664 .741 .908 r
.23081 .42716 .23835 .43424 .24955 .43041 .24203 .4233 Metetra
.664 .741 .908 r
.24203 .4233 .24955 .43041 .26079 .42656 .2533 .41942 Metetra
.664 .741 .908 r
.2533 .41942 .26079 .42656 .27209 .4227 .26462 .41553 Metetra
.664 .741 .908 r
.26462 .41553 .27209 .4227 .28343 .41882 .27599 .41161 Metetra
.946 .671 .484 r
.27599 .41161 .28343 .41882 .27915 .63541 .27117 .62862 Metetra
.645 .763 .934 r
.27117 .62862 .27915 .63541 .29196 .62241 .28339 .62492 Metetra
.957 .73 .554 r
.28339 .62492 .29196 .62241 .31519 .4469 .30406 .49511 Metetra
.921 .809 .342 r
.30406 .49511 .31519 .4469 .32619 .45414 .32179 .39865 Metetra
.119 .066 .517 r
.32179 .39865 .32619 .45414 .33562 .49114 .33107 .43415 Metetra
.469 .323 .6 r
.33107 .43415 .33562 .49114 .34732 .49207 .34212 .44399 Metetra
.628 .452 .624 r
.34212 .44399 .34732 .49207 .36027 .4699 .3544 .43314 Metetra
.717 .532 .638 r
.3544 .43314 .36027 .4699 .3737 .43568 .36725 .41077 Metetra
.784 .602 .655 r
.36725 .41077 .3737 .43568 .38712 .39777 .38022 .38392 Metetra
.486 .526 .824 r
.38022 .38392 .38712 .39777 .39891 .39644 .39189 .38563 Metetra
0 0 .501 r
.39189 .38563 .39891 .39644 .40991 .41953 .40315 .40057 Metetra
.263 .325 .739 r
.40315 .40057 .40991 .41953 .4214 .43525 .4148 .41006 Metetra
.502 .429 .707 r
.4148 .41006 .4214 .43525 .43333 .44223 .4268 .413 Metetra
.599 .474 .681 r
.4268 .413 .43333 .44223 .44562 .44023 .43908 .40925 Metetra
.655 .504 .667 r
.43908 .40925 .44562 .44023 .45815 .43001 .45156 .39942 Metetra
.694 .53 .662 r
.45156 .39942 .45815 .43001 .47081 .41304 .46415 .38469 Metetra
.725 .557 .662 r
.46415 .38469 .47081 .41304 .48348 .39124 .47676 .3666 Metetra
.752 .586 .67 r
.47676 .3666 .48348 .39124 .4961 .36676 .48934 .34681 Metetra
.649 .552 .732 r
.48934 .34681 .4961 .36676 .50862 .34182 .50176 .3409 Metetra
.649 .092 0 r
.50176 .3409 .50862 .34182 .52098 .35717 .51416 .35087 Metetra
0 .317 .777 r
.51416 .35087 .52098 .35717 .53355 .36968 .52673 .35807 Metetra
.4 .528 .871 r
.52673 .35807 .53355 .36968 .54627 .37769 .53943 .36129 Metetra
.584 .552 .785 r
.53943 .36129 .54627 .37769 .5591 .37993 .55221 .35963 Metetra
.661 .56 .73 r
.55221 .35963 .5591 .37993 .57193 .37562 .565 .35264 Metetra
.706 .569 .698 r
.565 .35264 .57193 .37562 .5847 .36455 .57775 .34035 Metetra
.738 .581 .68 r
.57775 .34035 .5847 .36455 .59733 .3472 .59038 .3233 Metetra
.764 .597 .671 r
.59038 .3233 .59733 .3472 .60978 .32465 .60289 .30257 Metetra
.398 .387 .731 r
.60289 .30257 .60978 .32465 .62229 .30727 .61613 .31 Metetra
.748 .256 .062 r
.61613 .31 .62229 .30727 .63604 .32621 .62978 .32476 Metetra
.676 .127 0 r
.62978 .32476 .63604 .32621 .65001 .3443 .64359 .33769 Metetra
0 .322 .789 r
.64359 .33769 .65001 .3443 .66405 .35815 .6574 .34578 Metetra
.539 .595 .858 r
.6574 .34578 .66405 .35815 .67791 .36365 .67101 .34553 Metetra
.735 .621 .731 r
.67101 .34553 .67791 .36365 .69125 .35625 .6841 .33315 Metetra
.813 .629 .653 r
.6841 .33315 .69125 .35625 .70363 .3313 .69631 .30484 Metetra
.826 .622 .628 r
.69631 .30484 .70363 .3313 .71456 .28455 .70795 .26913 Metetra
.864 .509 .006 r
.70795 .26913 .71456 .28455 .73078 .32318 .72569 .33274 Metetra
.932 .576 .325 r
.72569 .33274 .73078 .32318 .75191 .42574 .74644 .43065 Metetra
.895 .491 .232 r
.74644 .43065 .75191 .42574 .77102 .48727 .7646 .47915 Metetra
.982 .701 .403 r
.7646 .47915 .77102 .48727 .76748 .25323 .76148 .24463 Metetra
.664 .741 .908 r
.76148 .24463 .76748 .25323 .78107 .24858 .77511 .23994 Metetra
.664 .741 .908 r
.77511 .23994 .78107 .24858 .79472 .24391 .78881 .23523 Metetra
.664 .741 .908 r
.78881 .23523 .79472 .24391 .80843 .23922 .80257 .23049 Metetra
.664 .741 .908 r
.80257 .23049 .80843 .23922 .82221 .2345 .8164 .22574 Metetra
.664 .741 .908 r
.8164 .22574 .82221 .2345 .83606 .22976 .83029 .22096 Metetra
.664 .741 .908 r
.212 .42389 .21963 .431 .23081 .42716 .2232 .42002 Metetra
.664 .741 .908 r
.2232 .42002 .23081 .42716 .24203 .4233 .23445 .41613 Metetra
.664 .741 .908 r
.23445 .41613 .24203 .4233 .2533 .41942 .24575 .41222 Metetra
.664 .741 .908 r
.24575 .41222 .2533 .41942 .26462 .41553 .2571 .40829 Metetra
.664 .741 .908 r
.2571 .40829 .26462 .41553 .27599 .41161 .2685 .40435 Metetra
.664 .741 .908 r
.2685 .40435 .27599 .41161 .27117 .62862 .27995 .40039 Metetra
0 0 .257 r
.27995 .40039 .27117 .62862 .28339 .62492 .27538 .61804 Metetra
.934 .719 .588 r
.27538 .61804 .28339 .62492 .30406 .49511 .29324 .53382 Metetra
.981 .83 .432 r
.29324 .53382 .30406 .49511 .32179 .39865 .31149 .43589 Metetra
.31149 .43589 .32179 .39865 .33107 .43415 .32613 .38643 Metetra
.353 .25 .597 r
.32613 .38643 .33107 .43415 .34212 .44399 .3366 .40356 Metetra
.562 .415 .64 r
.3366 .40356 .34212 .44399 .3544 .43314 .34828 .40232 Metetra
.674 .516 .663 r
.34828 .40232 .3544 .43314 .36725 .41077 .3606 .39018 Metetra
.756 .605 .69 r
.3606 .39018 .36725 .41077 .38022 .38392 .37314 .37301 Metetra
.528 .604 .873 r
.37314 .37301 .38022 .38392 .39189 .38563 .3849 .37295 Metetra
.141 .345 .806 r
.3849 .37295 .39189 .38563 .40315 .40057 .39641 .3809 Metetra
.444 .432 .751 r
.39641 .3809 .40315 .40057 .4148 .41006 .4082 .38524 Metetra
.554 .464 .707 r
.4082 .38524 .4148 .41006 .4268 .413 .42025 .38508 Metetra
.613 .487 .685 r
.42025 .38508 .4268 .413 .43908 .40925 .43252 .38028 Metetra
.653 .509 .675 r
.43252 .38028 .43908 .40925 .45156 .39942 .44495 .3713 Metetra
.684 .532 .673 r
.44495 .3713 .45156 .39942 .46415 .38469 .45747 .35902 Metetra
.711 .557 .678 r
.45747 .35902 .46415 .38469 .47676 .3666 .47001 .34459 Metetra
.718 .579 .697 r
.47001 .34459 .47676 .3666 .48934 .34681 .48252 .3314 Metetra
.324 .411 .798 r
.48252 .3314 .48934 .34681 .50176 .3409 .49483 .33789 Metetra
0 .33 .675 r
.49483 .33789 .50176 .3409 .51416 .35087 .50728 .34294 Metetra
.332 .591 .939 r
.50728 .34294 .51416 .35087 .52673 .35807 .51987 .34548 Metetra
.558 .594 .846 r
.51987 .34548 .52673 .35807 .53943 .36129 .53257 .34468 Metetra
.641 .581 .772 r
.53257 .34468 .53943 .36129 .55221 .35963 .54533 .33997 Metetra
.686 .579 .729 r
.54533 .33997 .55221 .35963 .565 .35264 .5581 .33114 Metetra
.718 .584 .704 r
.5581 .33114 .565 .35264 .57775 .34035 .57083 .31838 Metetra
.743 .595 .691 r
.57083 .31838 .57775 .34035 .59038 .3233 .5835 .30226 Metetra
.616 .528 .733 r
.5835 .30226 .59038 .3233 .60289 .30257 .59641 .29829 Metetra
.51 0 0 r
.59641 .29829 .60289 .30257 .61613 .31 .60978 .3092 Metetra
.626 .061 0 r
.60978 .3092 .61613 .31 .62978 .32476 .62333 .31973 Metetra
0 .261 .702 r
.62333 .31973 .62978 .32476 .64359 .33769 .63699 .32776 Metetra
.375 .561 .907 r
.63699 .32776 .64359 .33769 .6574 .34578 .65061 .33077 Metetra
.648 .61 .797 r
.65061 .33077 .6574 .34578 .67101 .34553 .66402 .3259 Metetra
.757 .62 .708 r
.66402 .3259 .67101 .34553 .6841 .33315 .67695 .31007 Metetra
.821 .633 .649 r
.67695 .31007 .6841 .33315 .69631 .30484 .68912 .28028 Metetra
.614 .509 .711 r
.68912 .28028 .69631 .30484 .70795 .26913 .70257 .27574 Metetra
.911 .531 .288 r
.70257 .27574 .70795 .26913 .72569 .33274 .72008 .33579 Metetra
.939 .576 .281 r
.72008 .33579 .72569 .33274 .74644 .43065 .74021 .42559 Metetra
.985 .712 .415 r
.74021 .42559 .74644 .43065 .7646 .47915 .74181 .24066 Metetra
.549 .339 .548 r
.74181 .24066 .7646 .47915 .76148 .24463 .75543 .23595 Metetra
.664 .741 .908 r
.75543 .23595 .76148 .24463 .77511 .23994 .7691 .23122 Metetra
.664 .741 .908 r
.7691 .23122 .77511 .23994 .78881 .23523 .78285 .22647 Metetra
.664 .741 .908 r
.78285 .22647 .78881 .23523 .80257 .23049 .79665 .2217 Metetra
.664 .741 .908 r
.79665 .2217 .80257 .23049 .8164 .22574 .81053 .2169 Metetra
.664 .741 .908 r
.81053 .2169 .8164 .22574 .83029 .22096 .82447 .21208 Metetra
.664 .741 .908 r
.2043 .41673 .212 .42389 .2232 .42002 .21553 .41282 Metetra
.664 .741 .908 r
.21553 .41282 .2232 .42002 .23445 .41613 .22681 .4089 Metetra
.664 .741 .908 r
.22681 .4089 .23445 .41613 .24575 .41222 .23814 .40496 Metetra
.664 .741 .908 r
.23814 .40496 .24575 .41222 .2571 .40829 .24952 .401 Metetra
.664 .741 .908 r
.24952 .401 .2571 .40829 .2685 .40435 .26095 .39703 Metetra
.664 .741 .908 r
.26095 .39703 .2685 .40435 .27995 .40039 .27243 .39303 Metetra
.948 .671 .481 r
.27243 .39303 .27995 .40039 .27538 .61804 .2673 .6111 Metetra
.924 .735 .628 r
.2673 .6111 .27538 .61804 .29324 .53382 .28311 .55882 Metetra
1 .815 .51 r
.28311 .55882 .29324 .53382 .31149 .43589 .30165 .46223 Metetra
.936 .858 .427 r
.30165 .46223 .31149 .43589 .32613 .38643 .31703 .40528 Metetra
.75 .83 .37 r
.31703 .40528 .32613 .38643 .3366 .40356 .3305 .37423 Metetra
.496 .402 .678 r
.3305 .37423 .3366 .40356 .34828 .40232 .34186 .37767 Metetra
.608 .497 .702 r
.34186 .37767 .34828 .40232 .3606 .39018 .35372 .37382 Metetra
.71 .612 .745 r
.35372 .37382 .3606 .39018 .37314 .37301 .3659 .3646 Metetra
.698 .731 .876 r
.3659 .3646 .37314 .37301 .3849 .37295 .37792 .35911 Metetra
.459 .514 .828 r
.37792 .35911 .3849 .37295 .39641 .3809 .38966 .36142 Metetra
.54 .492 .751 r
.38966 .36142 .39641 .3809 .4082 .38524 .40157 .36177 Metetra
.588 .492 .714 r
.40157 .36177 .4082 .38524 .42025 .38508 .41366 .35942 Metetra
.622 .503 .696 r
.41366 .35942 .42025 .38508 .43252 .38028 .42591 .3542 Metetra
.65 .518 .689 r
.42591 .3542 .43252 .38028 .44495 .3713 .43828 .34638 Metetra
.674 .538 .691 r
.43828 .34638 .44495 .3713 .45747 .35902 .45073 .33658 Metetra
.673 .551 .707 r
.45073 .33658 .45747 .35902 .47001 .34459 .46317 .32781 Metetra
.47 .481 .787 r
.46317 .32781 .47001 .34459 .48252 .3314 .47544 .33054 Metetra
.155 0 0 r
.47544 .33054 .48252 .3314 .49483 .33789 .48784 .33273 Metetra
.334 .689 .98 r
.48784 .33273 .49483 .33789 .50728 .34294 .50036 .33352 Metetra
.56 .664 .907 r
.50036 .33352 .50728 .34294 .51987 .34548 .51298 .33223 Metetra
.637 .623 .819 r
.51298 .33223 .51987 .34548 .53257 .34468 .52568 .3283 Metetra
.677 .602 .765 r
.52568 .3283 .53257 .34468 .54533 .33997 .53844 .32145 Metetra
.704 .597 .734 r
.53844 .32145 .54533 .33997 .5581 .33114 .55121 .31163 Metetra
.727 .602 .717 r
.55121 .31163 .5581 .33114 .57083 .31838 .56396 .29911 Metetra
.691 .584 .731 r
.56396 .29911 .57083 .31838 .5835 .30226 .57676 .29003 Metetra
.22 .409 .837 r
.57676 .29003 .5835 .30226 .59641 .29829 .58992 .29717 Metetra
.496 0 0 r
.58992 .29717 .59641 .29829 .60978 .3092 .60325 .30467 Metetra
0 .337 .748 r
.60325 .30467 .60978 .3092 .62333 .31973 .61671 .31112 Metetra
.292 .551 .923 r
.61671 .31112 .62333 .31973 .63699 .32776 .63023 .31478 Metetra
.565 .599 .846 r
.63023 .31478 .63699 .32776 .65061 .33077 .64371 .31363 Metetra
.691 .608 .759 r
.64371 .31363 .65061 .33077 .66402 .3259 .65698 .30543 Metetra
.766 .62 .697 r
.65698 .30543 .66402 .3259 .67695 .31007 .66985 .28779 Metetra
.824 .638 .651 r
.66985 .28779 .67695 .31007 .68912 .28028 .68207 .25836 Metetra
.067 .175 .668 r
.68207 .25836 .68912 .28028 .70257 .27574 .69683 .27773 Metetra
.915 .521 .23 r
.69683 .27773 .70257 .27574 .72008 .33579 .71395 .33163 Metetra
.938 .567 .207 r
.71395 .33163 .72008 .33579 .74021 .42559 .73326 .41035 Metetra
.975 .699 .441 r
.73326 .41035 .74021 .42559 .74181 .24066 .73566 .23195 Metetra
.664 .741 .908 r
.73566 .23195 .74181 .24066 .75543 .23595 .74932 .2272 Metetra
.664 .741 .908 r
.74932 .2272 .75543 .23595 .7691 .23122 .76304 .22243 Metetra
.664 .741 .908 r
.76304 .22243 .7691 .23122 .78285 .22647 .77683 .21764 Metetra
.664 .741 .908 r
.77683 .21764 .78285 .22647 .79665 .2217 .79069 .21282 Metetra
.664 .741 .908 r
.79069 .21282 .79665 .2217 .81053 .2169 .80461 .20798 Metetra
.664 .741 .908 r
.80461 .20798 .81053 .2169 .82447 .21208 .8186 .20311 Metetra
.664 .741 .908 r
.19654 .4095 .2043 .41673 .21553 .41282 .2078 .40556 Metetra
.664 .741 .908 r
.2078 .40556 .21553 .41282 .22681 .4089 .21911 .40161 Metetra
.664 .741 .908 r
.21911 .40161 .22681 .4089 .23814 .40496 .23047 .39764 Metetra
.664 .741 .908 r
.23047 .39764 .23814 .40496 .24952 .401 .24188 .39365 Metetra
.664 .741 .908 r
.24188 .39365 .24952 .401 .26095 .39703 .25334 .38964 Metetra
.664 .741 .908 r
.25334 .38964 .26095 .39703 .27243 .39303 .26485 .38562 Metetra
.664 .741 .908 r
.26485 .38562 .27243 .39303 .2673 .6111 .2764 .38158 Metetra
0 0 .33 r
.2764 .38158 .2673 .6111 .28311 .55882 .27397 .56731 Metetra
.977 .771 .561 r
.27397 .56731 .28311 .55882 .30165 .46223 .29249 .47546 Metetra
.997 .846 .563 r
.29249 .47546 .30165 .46223 .31703 .40528 .30815 .41783 Metetra
.962 .918 .569 r
.30815 .41783 .31703 .40528 .3305 .37423 .32204 .38294 Metetra
.845 .959 .62 r
.32204 .38294 .3305 .37423 .34186 .37767 .33486 .36298 Metetra
.58 .566 .802 r
.33486 .36298 .34186 .37767 .35372 .37382 .34659 .3615 Metetra
.626 .625 .83 r
.34659 .3615 .35372 .37382 .3659 .3646 .35848 .35831 Metetra
.716 .794 .913 r
.35848 .35831 .3659 .3646 .37792 .35911 .37056 .35247 Metetra
.732 .788 .897 r
.37056 .35247 .37792 .35911 .38966 .36142 .38271 .34594 Metetra
.662 .599 .774 r
.38271 .34594 .38966 .36142 .40157 .36177 .39486 .34038 Metetra
.611 .52 .726 r
.39486 .34038 .40157 .36177 .41366 .35942 .40698 .33671 Metetra
.627 .521 .714 r
.40698 .33671 .41366 .35942 .42591 .3542 .41921 .3317 Metetra
.584 .497 .722 r
.41921 .3317 .42591 .3542 .43828 .34638 .43139 .32958 Metetra
.571 .538 .78 r
.43139 .32958 .43828 .34638 .45073 .33658 .44363 .32841 Metetra
.522 .68 .937 r
.44363 .32841 .45073 .33658 .46317 .32781 .45593 .3277 Metetra
.099 .655 .77 r
.45593 .3277 .46317 .32781 .47544 .33054 .46833 .3269 Metetra
.438 .796 .997 r
.46833 .3269 .47544 .33054 .48784 .33273 .48081 .32545 Metetra
.597 .741 .945 r
.48081 .32545 .48784 .33273 .50036 .33352 .49339 .32283 Metetra
.652 .676 .86 r
.49339 .32283 .50036 .33352 .51298 .33223 .50605 .31862 Metetra
.679 .637 .802 r
.50605 .31862 .51298 .33223 .52568 .3283 .51877 .31254 Metetra
.698 .62 .766 r
.51877 .31254 .52568 .3283 .53844 .32145 .53154 .30446 Metetra
.715 .616 .746 r
.53154 .30446 .53844 .32145 .55121 .31163 .54432 .29447 Metetra
.719 .617 .742 r
.54432 .29447 .55121 .31163 .56396 .29911 .55711 .28404 Metetra
.419 .48 .816 r
.55711 .28404 .56396 .29911 .57676 .29003 .57013 .2879 Metetra
.233 0 0 r
.57013 .2879 .57676 .29003 .58992 .29717 .58328 .29232 Metetra
.023 .501 .877 r
.58328 .29232 .58992 .29717 .60325 .30467 .59656 .29645 Metetra
.33 .587 .937 r
.59656 .29645 .60325 .30467 .61671 .31112 .60994 .29917 Metetra
.524 .597 .87 r
.60994 .29917 .61671 .31112 .63023 .31478 .62336 .29919 Metetra
.633 .596 .794 r
.62336 .29919 .63023 .31478 .64371 .31363 .63674 .29496 Metetra
.706 .602 .738 r
.63674 .29496 .64371 .31363 .65698 .30543 .64994 .28483 Metetra
.767 .619 .696 r
.64994 .28483 .65698 .30543 .66985 .28779 .66281 .267 Metetra
.798 .634 .678 r
.66281 .267 .66985 .28779 .68207 .25836 .67541 .24453 Metetra
0 0 .35 r
.67541 .24453 .68207 .25836 .69683 .27773 .69072 .2745 Metetra
.902 .49 .123 r
.69072 .2745 .69683 .27773 .71395 .33163 .70732 .32004 Metetra
.972 .723 .5 r
.70732 .32004 .71395 .33163 .73326 .41035 .71582 .22794 Metetra
.549 .342 .552 r
.71582 .22794 .73326 .41035 .73566 .23195 .72945 .22317 Metetra
.664 .741 .908 r
.72945 .22317 .73566 .23195 .74932 .2272 .74316 .21838 Metetra
.664 .741 .908 r
.74316 .21838 .74932 .2272 .76304 .22243 .75693 .21356 Metetra
.664 .741 .908 r
.75693 .21356 .76304 .22243 .77683 .21764 .77076 .20872 Metetra
.664 .741 .908 r
.77076 .20872 .77683 .21764 .79069 .21282 .78467 .20386 Metetra
.664 .741 .908 r
.78467 .20386 .79069 .21282 .80461 .20798 .79864 .19898 Metetra
.664 .741 .908 r
.79864 .19898 .80461 .20798 .8186 .20311 .81267 .19407 Metetra
.664 .741 .908 r
.18872 .40222 .19654 .4095 .2078 .40556 .20001 .39825 Metetra
.664 .741 .908 r
.20001 .39825 .2078 .40556 .21911 .40161 .21135 .39426 Metetra
.664 .741 .908 r
.21135 .39426 .21911 .40161 .23047 .39764 .22273 .39026 Metetra
.664 .741 .908 r
.22273 .39026 .23047 .39764 .24188 .39365 .23417 .38624 Metetra
.664 .741 .908 r
.23417 .38624 .24188 .39365 .25334 .38964 .24566 .3822 Metetra
.664 .741 .908 r
.24566 .3822 .25334 .38964 .26485 .38562 .2572 .37814 Metetra
.664 .741 .908 r
.2572 .37814 .26485 .38562 .2764 .38158 .26879 .37407 Metetra
.949 .668 .471 r
.26879 .37407 .2764 .38158 .27397 .56731 .26601 .55835 Metetra
.93 .713 .588 r
.26601 .55835 .27397 .56731 .29249 .47546 .28418 .47468 Metetra
.956 .77 .613 r
.28418 .47468 .29249 .47546 .30815 .41783 .29987 .41933 Metetra
.967 .833 .658 r
.29987 .41933 .30815 .41783 .32204 .38294 .31398 .38323 Metetra
.949 .88 .733 r
.31398 .38323 .32204 .38294 .33486 .36298 .3271 .36013 Metetra
.757 .905 .942 r
.3271 .36013 .33486 .36298 .34659 .3615 .33921 .3529 Metetra
.446 .63 .932 r
.33921 .3529 .34659 .3615 .35848 .35831 .3509 .35374 Metetra
.547 .806 .994 r
.3509 .35374 .35848 .35831 .37056 .35247 .36285 .35143 Metetra
.515 .895 .961 r
.36285 .35143 .37056 .35247 .38271 .34594 .37494 .34754 Metetra
.358 .829 .793 r
.37494 .34754 .38271 .34594 .39486 .34038 .38711 .34311 Metetra
.242 .742 .671 r
.38711 .34311 .39486 .34038 .40698 .33671 .39933 .33874 Metetra
.267 .767 .725 r
.39933 .33874 .40698 .33671 .41921 .3317 .41159 .3347 Metetra
.41159 .3347 .41921 .3317 .43139 .32958 .4239 .33104 Metetra
.247 .758 .749 r
.4239 .33104 .43139 .32958 .44363 .32841 .43626 .32761 Metetra
.437 .865 .934 r
.43626 .32761 .44363 .32841 .45593 .3277 .44869 .32419 Metetra
.591 .864 .994 r
.44869 .32419 .45593 .3277 .46833 .3269 .46118 .32048 Metetra
.657 .789 .945 r
.46118 .32048 .46833 .3269 .48081 .32545 .47375 .3162 Metetra
.68 .719 .879 r
.47375 .3162 .48081 .32545 .49339 .32283 .48639 .31109 Metetra
.69 .672 .828 r
.48639 .31109 .49339 .32283 .50605 .31862 .49909 .30496 Metetra
.698 .646 .794 r
.49909 .30496 .50605 .31862 .51877 .31254 .51184 .2977 Metetra
.708 .636 .774 r
.51184 .2977 .51877 .31254 .53154 .30446 .52462 .2893 Metetra
.72 .638 .766 r
.52462 .2893 .53154 .30446 .54432 .29447 .53743 .27987 Metetra
.515 .542 .822 r
.53743 .27987 .54432 .29447 .55711 .28404 .55034 .28056 Metetra
.137 .626 .915 r
.55034 .28056 .55711 .28404 .57013 .2879 .56336 .2822 Metetra
.29 .65 .969 r
.56336 .2822 .57013 .2879 .58328 .29232 .5765 .28382 Metetra
.435 .637 .941 r
.5765 .28382 .58328 .29232 .59656 .29645 .58974 .28479 Metetra
.535 .61 .874 r
.58974 .28479 .59656 .29645 .60994 .29917 .60306 .28435 Metetra
.603 .591 .811 r
.60306 .28435 .60994 .29917 .62336 .29919 .6164 .2816 Metetra
.657 .587 .764 r
.6164 .2816 .62336 .29919 .63674 .29496 .62972 .27549 Metetra
.708 .597 .73 r
.62972 .27549 .63674 .29496 .64994 .28483 .64291 .26484 Metetra
.761 .62 .704 r
.64291 .26484 .64994 .28483 .66281 .267 .65586 .24836 Metetra
.654 .575 .754 r
.65586 .24836 .66281 .267 .67541 .24453 .66926 .24217 Metetra
.808 .323 0 r
.66926 .24217 .67541 .24453 .69072 .2745 .68425 .26578 Metetra
.814 .39 0 r
.68425 .26578 .69072 .2745 .70732 .32004 .70024 .30133 Metetra
.947 .699 .53 r
.70024 .30133 .70732 .32004 .71582 .22794 .70951 .21912 Metetra
.664 .741 .908 r
.70951 .21912 .71582 .22794 .72945 .22317 .72319 .2143 Metetra
.664 .741 .908 r
.72319 .2143 .72945 .22317 .74316 .21838 .73694 .20947 Metetra
.664 .741 .908 r
.73694 .20947 .74316 .21838 .75693 .21356 .75076 .20461 Metetra
.664 .741 .908 r
.75076 .20461 .75693 .21356 .77076 .20872 .76464 .19973 Metetra
.664 .741 .908 r
.76464 .19973 .77076 .20872 .78467 .20386 .77859 .19483 Metetra
.664 .741 .908 r
.77859 .19483 .78467 .20386 .79864 .19898 .79261 .1899 Metetra
.664 .741 .908 r
.79261 .1899 .79864 .19898 .81267 .19407 .80669 .18495 Metetra
.664 .741 .908 r
.18084 .39488 .18872 .40222 .20001 .39825 .19215 .39088 Metetra
.664 .741 .908 r
.19215 .39088 .20001 .39825 .21135 .39426 .20352 .38686 Metetra
.664 .741 .908 r
.20352 .38686 .21135 .39426 .22273 .39026 .21494 .38282 Metetra
.664 .741 .908 r
.21494 .38282 .22273 .39026 .23417 .38624 .2264 .37877 Metetra
.664 .741 .908 r
.2264 .37877 .23417 .38624 .24566 .3822 .23792 .3747 Metetra
.664 .741 .908 r
.23792 .3747 .24566 .3822 .2572 .37814 .24949 .37061 Metetra
.664 .741 .908 r
.24949 .37061 .2572 .37814 .26879 .37407 .26111 .3665 Metetra
.664 .741 .908 r
.26111 .3665 .26879 .37407 .26601 .55835 .27278 .36237 Metetra
.2 .062 .458 r
.27278 .36237 .26601 .55835 .28418 .47468 .27678 .46052 Metetra
.893 .694 .627 r
.27678 .46052 .28418 .47468 .29987 .41933 .29225 .41018 Metetra
.899 .731 .665 r
.29225 .41018 .29987 .41933 .31398 .38323 .30637 .37546 Metetra
.885 .756 .715 r
.30637 .37546 .31398 .38323 .3271 .36013 .31961 .35163 Metetra
.656 .719 .895 r
.31961 .35163 .3271 .36013 .33921 .3529 .33156 .34761 Metetra
.12 .56 .919 r
.33156 .34761 .33921 .3529 .3509 .35374 .34317 .35046 Metetra
.336 .754 .977 r
.34317 .35046 .3509 .35374 .36285 .35143 .35506 .34995 Metetra
.427 .847 .959 r
.35506 .34995 .36285 .35143 .37494 .34754 .36714 .3473 Metetra
.459 .881 .921 r
.36714 .3473 .37494 .34754 .38711 .34311 .37935 .34336 Metetra
.486 .898 .904 r
.37935 .34336 .38711 .34311 .39933 .33874 .39165 .33871 Metetra
.535 .919 .923 r
.39165 .33871 .39933 .33874 .41159 .3347 .40401 .33366 Metetra
.604 .931 .961 r
.40401 .33366 .41159 .3347 .4239 .33104 .41644 .32839 Metetra
.666 .91 .978 r
.41644 .32839 .4239 .33104 .43626 .32761 .42891 .32295 Metetra
.7 .855 .957 r
.42891 .32295 .43626 .32761 .44869 .32419 .44145 .31732 Metetra
.709 .789 .914 r
.44145 .31732 .44869 .32419 .46118 .32048 .45403 .31142 Metetra
.707 .733 .871 r
.45403 .31142 .46118 .32048 .47375 .3162 .46667 .3052 Metetra
.704 .691 .835 r
.46667 .3052 .47375 .3162 .48639 .31109 .47935 .29857 Metetra
.702 .665 .811 r
.47935 .29857 .48639 .31109 .49909 .30496 .49209 .29151 Metetra
.703 .653 .796 r
.49209 .29151 .49909 .30496 .51184 .2977 .50486 .28402 Metetra
.708 .652 .791 r
.50486 .28402 .51184 .2977 .52462 .2893 .51767 .27612 Metetra
.574 .597 .839 r
.51767 .27612 .52462 .2893 .53743 .27987 .53052 .2746 Metetra
.442 .748 .993 r
.53052 .2746 .53743 .27987 .55034 .28056 .54346 .27387 Metetra
.488 .722 .975 r
.54346 .27387 .55034 .28056 .56336 .2822 .5565 .27308 Metetra
.541 .673 .924 r
.5565 .27308 .56336 .2822 .5765 .28382 .56962 .27197 Metetra
.578 .628 .865 r
.56962 .27197 .5765 .28382 .58974 .28479 .58283 .27017 Metetra
.606 .595 .814 r
.58283 .27017 .58974 .28479 .60306 .28435 .59609 .26728 Metetra
.632 .579 .776 r
.59609 .26728 .60306 .28435 .6164 .2816 .60939 .26276 Metetra
.661 .577 .75 r
.60939 .26276 .6164 .2816 .62972 .27549 .62269 .25597 Metetra
.698 .591 .733 r
.62269 .25597 .62972 .27549 .64291 .26484 .63592 .24616 Metetra
.746 .623 .723 r
.63592 .24616 .64291 .26484 .65586 .24836 .64901 .23242 Metetra
.446 .489 .81 r
.64901 .23242 .65586 .24836 .66926 .24217 .66285 .23568 Metetra
.551 .053 0 r
.66285 .23568 .66926 .24217 .68425 .26578 .67746 .25166 Metetra
.911 .723 .636 r
.67746 .25166 .68425 .26578 .70024 .30133 .68948 .21505 Metetra
.56 .37 .581 r
.68948 .21505 .70024 .30133 .70951 .21912 .70315 .21022 Metetra
.664 .741 .908 r
.70315 .21022 .70951 .21912 .72319 .2143 .71687 .20536 Metetra
.664 .741 .908 r
.71687 .20536 .72319 .2143 .73694 .20947 .73067 .20048 Metetra
.664 .741 .908 r
.73067 .20048 .73694 .20947 .75076 .20461 .74453 .19558 Metetra
.664 .741 .908 r
.74453 .19558 .75076 .20461 .76464 .19973 .75846 .19066 Metetra
.664 .741 .908 r
.75846 .19066 .76464 .19973 .77859 .19483 .77246 .18571 Metetra
.664 .741 .908 r
.77246 .18571 .77859 .19483 .79261 .1899 .78653 .18074 Metetra
.664 .741 .908 r
.78653 .18074 .79261 .1899 .80669 .18495 .80066 .17574 Metetra
.664 .741 .908 r
.17289 .38748 .18084 .39488 .19215 .39088 .18423 .38345 Metetra
.664 .741 .908 r
.18423 .38345 .19215 .39088 .20352 .38686 .19563 .37939 Metetra
.664 .741 .908 r
.19563 .37939 .20352 .38686 .21494 .38282 .20708 .37532 Metetra
.664 .741 .908 r
.20708 .37532 .21494 .38282 .2264 .37877 .21857 .37124 Metetra
.664 .741 .908 r
.21857 .37124 .2264 .37877 .23792 .3747 .23012 .36713 Metetra
.664 .741 .908 r
.23012 .36713 .23792 .3747 .24949 .37061 .24172 .36301 Metetra
.664 .741 .908 r
.24172 .36301 .24949 .37061 .26111 .3665 .25337 .35886 Metetra
.664 .741 .908 r
.25337 .35886 .26111 .3665 .27278 .36237 .26507 .3547 Metetra
.951 .641 .409 r
.26507 .3547 .27278 .36237 .27678 .46052 .2702 .43527 Metetra
.834 .632 .63 r
.2702 .43527 .27678 .46052 .29225 .41018 .28524 .39194 Metetra
.836 .657 .661 r
.28524 .39194 .29225 .41018 .30637 .37546 .29918 .36073 Metetra
.825 .675 .697 r
.29918 .36073 .30637 .37546 .31961 .35163 .31238 .33833 Metetra
.206 .381 .817 r
.31238 .33833 .31961 .35163 .33156 .34761 .32366 .34501 Metetra
0 .446 .739 r
.32366 .34501 .33156 .34761 .34317 .35046 .33529 .34802 Metetra
.254 .73 .937 r
.33529 .34802 .34317 .35046 .35506 .34995 .34722 .34768 Metetra
.48 .854 .986 r
.34722 .34768 .35506 .34995 .36714 .3473 .35936 .34493 Metetra
.607 .899 .987 r
.35936 .34493 .36714 .3473 .37935 .34336 .37164 .3405 Metetra
.681 .905 .975 r
.37164 .3405 .37935 .34336 .39165 .33871 .38403 .33491 Metetra
.722 .884 .955 r
.38403 .33491 .39165 .33871 .40401 .33366 .3965 .32856 Metetra
.74 .846 .929 r
.3965 .32856 .40401 .33366 .41644 .32839 .40903 .32172 Metetra
.742 .801 .899 r
.40903 .32172 .41644 .32839 .42891 .32295 .42161 .31459 Metetra
.735 .756 .87 r
.42161 .31459 .42891 .32295 .44145 .31732 .43422 .30732 Metetra
.724 .718 .844 r
.43422 .30732 .44145 .31732 .45403 .31142 .44688 .30001 Metetra
.713 .688 .824 r
.44688 .30001 .45403 .31142 .46667 .3052 .45956 .29274 Metetra
.705 .668 .811 r
.45956 .29274 .46667 .3052 .47935 .29857 .47228 .28556 Metetra
.698 .657 .806 r
.47228 .28556 .47935 .29857 .49209 .29151 .48504 .27852 Metetra
.684 .652 .812 r
.48504 .27852 .49209 .29151 .50486 .28402 .49783 .27225 Metetra
.598 .636 .86 r
.49783 .27225 .50486 .28402 .51767 .27612 .51065 .26982 Metetra
.58 .775 .972 r
.51065 .26982 .51767 .27612 .53052 .2746 .52354 .26712 Metetra
.603 .747 .946 r
.52354 .26712 .53052 .2746 .54346 .27387 .53651 .26416 Metetra
.621 .694 .896 r
.53651 .26416 .54346 .27387 .5565 .27308 .54955 .2609 Metetra
.628 .645 .848 r
.54955 .2609 .5565 .27308 .56962 .27197 .56266 .2573 Metetra
.63 .607 .808 r
.56266 .2573 .56962 .27197 .58283 .27017 .57584 .25329 Metetra
.633 .581 .778 r
.57584 .25329 .58283 .27017 .59609 .26728 .58908 .24876 Metetra
.639 .568 .759 r
.58908 .24876 .59609 .26728 .60939 .26276 .60236 .2435 Metetra
.652 .569 .749 r
.60236 .2435 .60939 .26276 .62269 .25597 .61567 .23722 Metetra
.675 .586 .748 r
.61567 .23722 .62269 .25597 .63592 .24616 .62898 .22946 Metetra
.688 .613 .767 r
.62898 .22946 .63592 .24616 .64901 .23242 .64233 .2216 Metetra
.364 .54 .895 r
.64233 .2216 .64901 .23242 .66285 .23568 .65619 .22497 Metetra
.131 .397 .848 r
.65619 .22497 .66285 .23568 .67746 .25166 .67041 .23272 Metetra
.838 .666 .669 r
.67041 .23272 .67746 .25166 .68948 .21505 .68302 .20611 Metetra
.664 .741 .908 r
.68302 .20611 .68948 .21505 .70315 .21022 .69673 .20124 Metetra
.664 .741 .908 r
.69673 .20124 .70315 .21022 .71687 .20536 .7105 .19634 Metetra
.664 .741 .908 r
.7105 .19634 .71687 .20536 .73067 .20048 .72434 .19142 Metetra
.664 .741 .908 r
.72434 .19142 .73067 .20048 .74453 .19558 .73825 .18647 Metetra
.664 .741 .908 r
.73825 .18647 .74453 .19558 .75846 .19066 .75223 .1815 Metetra
.664 .741 .908 r
.75223 .1815 .75846 .19066 .77246 .18571 .76628 .17651 Metetra
.664 .741 .908 r
.76628 .17651 .77246 .18571 .78653 .18074 .78039 .17149 Metetra
.664 .741 .908 r
.78039 .17149 .78653 .18074 .80066 .17574 .79457 .16645 Metetra
.664 .741 .908 r
.16488 .38002 .17289 .38748 .18423 .38345 .17625 .37595 Metetra
.664 .741 .908 r
.17625 .37595 .18423 .38345 .19563 .37939 .18767 .37187 Metetra
.664 .741 .908 r
.18767 .37187 .19563 .37939 .20708 .37532 .19915 .36776 Metetra
.664 .741 .908 r
.19915 .36776 .20708 .37532 .21857 .37124 .21068 .36364 Metetra
.664 .741 .908 r
.21068 .36364 .21857 .37124 .23012 .36713 .22225 .3595 Metetra
.664 .741 .908 r
.22225 .3595 .23012 .36713 .24172 .36301 .23388 .35535 Metetra
.664 .741 .908 r
.23388 .35535 .24172 .36301 .25337 .35886 .24557 .35117 Metetra
.664 .741 .908 r
.24557 .35117 .25337 .35886 .26507 .3547 .2573 .34697 Metetra
.664 .741 .908 r
.2573 .34697 .26507 .3547 .2702 .43527 .26909 .34276 Metetra
.388 .23 .543 r
.26909 .34276 .2702 .43527 .28524 .39194 .2787 .36737 Metetra
.785 .606 .657 r
.2787 .36737 .28524 .39194 .29918 .36073 .29233 .34099 Metetra
.592 .522 .745 r
.29233 .34099 .29918 .36073 .31238 .33833 .30418 .33849 Metetra
.525 0 0 r
.30418 .33849 .31238 .33833 .32366 .34501 .31555 .34422 Metetra
.124 0 0 r
.31555 .34422 .32366 .34501 .33529 .34802 .3273 .34584 Metetra
.362 .799 .963 r
.3273 .34584 .33529 .34802 .34722 .34768 .33935 .34429 Metetra
.608 .87 .991 r
.33935 .34429 .34722 .34768 .35936 .34493 .3516 .3403 Metetra
.706 .854 .953 r
.3516 .3403 .35936 .34493 .37164 .3405 .364 .33453 Metetra
.743 .819 .911 r
.364 .33453 .37164 .3405 .38403 .33491 .3765 .32749 Metetra
.753 .782 .876 r
.3765 .32749 .38403 .33491 .3965 .32856 .38908 .31964 Metetra
.751 .746 .848 r
.38908 .31964 .3965 .32856 .40903 .32172 .4017 .31134 Metetra
.741 .715 .827 r
.4017 .31134 .40903 .32172 .42161 .31459 .41436 .30291 Metetra
.729 .689 .812 r
.41436 .30291 .42161 .31459 .43422 .30732 .42703 .29461 Metetra
.716 .668 .802 r
.42703 .29461 .43422 .30732 .44688 .30001 .43973 .28665 Metetra
.703 .654 .798 r
.43973 .28665 .44688 .30001 .45956 .29274 .45244 .27919 Metetra
.681 .642 .805 r
.45244 .27919 .45956 .29274 .47228 .28556 .46517 .27296 Metetra
.611 .627 .842 r
.46517 .27296 .47228 .28556 .48504 .27852 .47789 .27002 Metetra
.634 .728 .916 r
.47789 .27002 .48504 .27852 .49783 .27225 .49069 .26638 Metetra
.647 .813 .963 r
.49069 .26638 .49783 .27225 .51065 .26982 .50356 .26205 Metetra
.673 .764 .919 r
.50356 .26205 .51065 .26982 .52354 .26712 .5165 .25716 Metetra
.678 .711 .873 r
.5165 .25716 .52354 .26712 .53651 .26416 .5295 .25182 Metetra
.673 .663 .832 r
.5295 .25182 .53651 .26416 .54955 .2609 .54255 .24623 Metetra
.663 .623 .799 r
.54255 .24623 .54955 .2609 .56266 .2573 .55565 .24056 Metetra
.63 .581 .781 r
.55565 .24056 .56266 .2573 .57584 .25329 .56883 .23617 Metetra
.625 .575 .778 r
.56883 .23617 .57584 .25329 .58908 .24876 .58208 .23199 Metetra
.632 .583 .781 r
.58208 .23199 .58908 .24876 .60236 .2435 .59538 .22745 Metetra
.64 .596 .789 r
.59538 .22745 .60236 .2435 .61567 .23722 .60875 .2226 Metetra
.647 .619 .808 r
.60875 .2226 .61567 .23722 .62898 .22946 .62218 .2177 Metetra
.646 .667 .856 r
.62218 .2177 .62898 .22946 .64233 .2216 .63569 .21329 Metetra
.602 .732 .936 r
.63569 .21329 .64233 .2216 .65619 .22497 .64932 .21026 Metetra
.706 .648 .79 r
.64932 .21026 .65619 .22497 .67041 .23272 .66281 .20199 Metetra
.6 .473 .679 r
.66281 .20199 .67041 .23272 .68302 .20611 .67649 .19709 Metetra
.664 .741 .908 r
.67649 .19709 .68302 .20611 .69673 .20124 .69025 .19218 Metetra
.664 .741 .908 r
.69025 .19218 .69673 .20124 .7105 .19634 .70407 .18723 Metetra
.664 .741 .908 r
.70407 .18723 .7105 .19634 .72434 .19142 .71796 .18227 Metetra
.664 .741 .908 r
.71796 .18227 .72434 .19142 .73825 .18647 .73191 .17728 Metetra
.664 .741 .908 r
.73191 .17728 .73825 .18647 .75223 .1815 .74594 .17226 Metetra
.664 .741 .908 r
.74594 .17226 .75223 .1815 .76628 .17651 .76003 .16722 Metetra
.664 .741 .908 r
.76003 .16722 .76628 .17651 .78039 .17149 .7742 .16216 Metetra
.664 .741 .908 r
.7742 .16216 .78039 .17149 .79457 .16645 .78843 .15707 Metetra
.664 .741 .908 r
.1568 .3725 .16488 .38002 .17625 .37595 .1682 .3684 Metetra
.664 .741 .908 r
.1682 .3684 .17625 .37595 .18767 .37187 .17965 .36428 Metetra
.664 .741 .908 r
.17965 .36428 .18767 .37187 .19915 .36776 .19116 .36014 Metetra
.664 .741 .908 r
.19116 .36014 .19915 .36776 .21068 .36364 .20271 .35599 Metetra
.664 .741 .908 r
.20271 .35599 .21068 .36364 .22225 .3595 .21432 .35181 Metetra
.664 .741 .908 r
.21432 .35181 .22225 .3595 .23388 .35535 .22598 .34762 Metetra
.664 .741 .908 r
.22598 .34762 .23388 .35535 .24557 .35117 .2377 .34341 Metetra
.664 .741 .908 r
.2377 .34341 .24557 .35117 .2573 .34697 .24946 .33918 Metetra
.664 .741 .908 r
.24946 .33918 .2573 .34697 .26909 .34276 .26128 .33493 Metetra
0 .396 .848 r
.26128 .33493 .26909 .34276 .2787 .36737 .27237 .34041 Metetra
.633 .503 .687 r
.27237 .34041 .2787 .36737 .29233 .34099 .28452 .33375 Metetra
0 .242 .72 r
.28452 .33375 .29233 .34099 .30418 .33849 .29568 .34114 Metetra
.419 0 0 r
.29568 .34114 .30418 .33849 .31555 .34422 .30729 .34402 Metetra
.114 .666 .785 r
.30729 .34402 .31555 .34422 .3273 .34584 .31925 .34321 Metetra
.571 .881 .992 r
.31925 .34321 .3273 .34584 .33935 .34429 .33147 .33944 Metetra
.716 .849 .945 r
.33147 .33944 .33935 .34429 .3516 .3403 .34388 .33338 Metetra
.754 .794 .886 r
.34388 .33338 .3516 .3403 .364 .33453 .35643 .32565 Metetra
.76 .749 .843 r
.35643 .32565 .364 .33453 .3765 .32749 .36906 .31682 Metetra
.754 .713 .813 r
.36906 .31682 .3765 .32749 .38908 .31964 .38174 .30739 Metetra
.744 .685 .794 r
.38174 .30739 .38908 .31964 .4017 .31134 .39445 .29782 Metetra
.73 .662 .783 r
.39445 .29782 .4017 .31134 .41436 .30291 .40716 .28851 Metetra
.716 .645 .778 r
.40716 .28851 .41436 .30291 .42703 .29461 .41987 .27977 Metetra
.65 .61 .796 r
.41987 .27977 .42703 .29461 .43973 .28665 .43249 .27483 Metetra
.59 .632 .861 r
.43249 .27483 .43973 .28665 .45244 .27919 .4451 .27261 Metetra
.615 .778 .959 r
.4451 .27261 .45244 .27919 .46517 .27296 .45781 .26922 Metetra
.63 .876 .987 r
.45781 .26922 .46517 .27296 .47789 .27002 .47062 .26466 Metetra
.695 .842 .953 r
.47062 .26466 .47789 .27002 .49069 .26638 .48349 .25898 Metetra
.722 .789 .905 r
.48349 .25898 .49069 .26638 .50356 .26205 .49643 .25237 Metetra
.697 .725 .872 r
.49643 .25237 .50356 .26205 .5165 .25716 .50941 .24633 Metetra
.57 .648 .888 r
.50941 .24633 .5165 .25716 .5295 .25182 .52243 .24461 Metetra
.543 .736 .965 r
.52243 .24461 .5295 .25182 .54255 .24623 .53555 .24282 Metetra
.46 .825 .994 r
.53555 .24282 .54255 .24623 .55565 .24056 .54874 .24056 Metetra
.305 .799 .846 r
.54874 .24056 .55565 .24056 .56883 .23617 .56202 .2374 Metetra
.311 .799 .772 r
.56202 .2374 .56883 .23617 .58208 .23199 .57534 .23299 Metetra
.451 .882 .825 r
.57534 .23299 .58208 .23199 .59538 .22745 .58871 .22709 Metetra
.64 .962 .911 r
.58871 .22709 .59538 .22745 .60875 .2226 .60209 .21965 Metetra
.769 .944 .937 r
.60209 .21965 .60875 .2226 .62218 .2177 .61548 .21088 Metetra
.722 .82 .926 r
.61548 .21088 .62218 .2177 .63569 .21329 .62896 .20411 Metetra
.508 .666 .933 r
.62896 .20411 .63569 .21329 .64932 .21026 .64273 .20355 Metetra
.809 .844 .876 r
.64273 .20355 .64932 .21026 .66281 .20199 .65618 .19293 Metetra
.664 .741 .908 r
.65618 .19293 .66281 .20199 .67649 .19709 .66991 .188 Metetra
.664 .741 .908 r
.66991 .188 .67649 .19709 .69025 .19218 .68371 .18303 Metetra
.664 .741 .908 r
.68371 .18303 .69025 .19218 .70407 .18723 .69758 .17805 Metetra
.664 .741 .908 r
.69758 .17805 .70407 .18723 .71796 .18227 .71151 .17304 Metetra
.664 .741 .908 r
.71151 .17304 .71796 .18227 .73191 .17728 .72552 .168 Metetra
.664 .741 .908 r
.72552 .168 .73191 .17728 .74594 .17226 .73959 .16294 Metetra
.664 .741 .908 r
.73959 .16294 .74594 .17226 .76003 .16722 .75373 .15786 Metetra
.664 .741 .908 r
.75373 .15786 .76003 .16722 .7742 .16216 .76795 .15274 Metetra
.664 .741 .908 r
.76795 .15274 .7742 .16216 .78843 .15707 .78223 .14761 Metetra
.664 .741 .908 r
.14865 .36491 .1568 .3725 .1682 .3684 .16008 .36078 Metetra
.664 .741 .908 r
.16008 .36078 .1682 .3684 .17965 .36428 .17157 .35663 Metetra
.664 .741 .908 r
.17157 .35663 .17965 .36428 .19116 .36014 .1831 .35246 Metetra
.664 .741 .908 r
.1831 .35246 .19116 .36014 .20271 .35599 .19469 .34827 Metetra
.664 .741 .908 r
.19469 .34827 .20271 .35599 .21432 .35181 .20633 .34406 Metetra
.664 .741 .908 r
.20633 .34406 .21432 .35181 .22598 .34762 .21802 .33983 Metetra
.664 .741 .908 r
.21802 .33983 .22598 .34762 .2377 .34341 .22976 .33558 Metetra
.664 .741 .908 r
.22976 .33558 .2377 .34341 .24946 .33918 .24156 .33132 Metetra
.664 .741 .908 r
.24156 .33132 .24946 .33918 .26128 .33493 .25341 .32703 Metetra
.664 .741 .908 r
.25341 .32703 .26128 .33493 .27237 .34041 .26531 .32273 Metetra
0 .011 .584 r
.26531 .32273 .27237 .34041 .28452 .33375 .27568 .33855 Metetra
.526 .011 0 r
.27568 .33855 .28452 .33375 .29568 .34114 .28712 .3428 Metetra
.123 0 0 r
.28712 .3428 .29568 .34114 .30729 .34402 .29899 .34276 Metetra
.494 .882 .964 r
.29899 .34276 .30729 .34402 .31925 .34321 .31119 .33916 Metetra
.726 .875 .951 r
.31119 .33916 .31925 .34321 .33147 .33944 .32362 .33273 Metetra
.772 .802 .878 r
.32362 .33273 .33147 .33944 .34388 .33338 .33623 .32419 Metetra
.775 .745 .826 r
.33623 .32419 .34388 .33338 .35643 .32565 .34894 .31422 Metetra
.766 .704 .793 r
.34894 .31422 .35643 .32565 .36906 .31682 .3617 .30347 Metetra
.752 .673 .773 r
.3617 .30347 .36906 .31682 .38174 .30739 .37448 .29254 Metetra
.737 .649 .762 r
.37448 .29254 .38174 .30739 .39445 .29782 .38725 .28196 Metetra
.665 .605 .778 r
.38725 .28196 .39445 .29782 .40716 .28851 .39985 .27593 Metetra
.533 .59 .858 r
.39985 .27593 .40716 .28851 .41987 .27977 .41229 .27549 Metetra
.482 .803 1 r
.41229 .27549 .41987 .27977 .43249 .27483 .42487 .27361 Metetra
.455 .869 .949 r
.42487 .27361 .43249 .27483 .4451 .27261 .43757 .27011 Metetra
.629 .912 .982 r
.43757 .27011 .4451 .27261 .45781 .26922 .45038 .26495 Metetra
.726 .883 .953 r
.45038 .26495 .45781 .26922 .47062 .26466 .46328 .25823 Metetra
.762 .824 .901 r
.46328 .25823 .47062 .26466 .48349 .25898 .47625 .25017 Metetra
.74 .759 .868 r
.47625 .25017 .48349 .25898 .49643 .25237 .48924 .2424 Metetra
.483 .628 .916 r
.48924 .2424 .49643 .25237 .50941 .24633 .50221 .24265 Metetra
.264 .708 .96 r
.50221 .24265 .50941 .24633 .52243 .24461 .51529 .24291 Metetra
.171 .693 .876 r
.51529 .24291 .52243 .24461 .53555 .24282 .52847 .2426 Metetra
.165 .703 .803 r
.52847 .2426 .53555 .24282 .54874 .24056 .54174 .2411 Metetra
.268 .775 .801 r
.54174 .2411 .54874 .24056 .56202 .2374 .55509 .23782 Metetra
.47 .893 .864 r
.55509 .23782 .56202 .2374 .57534 .23299 .56849 .23227 Metetra
.692 .973 .92 r
.56849 .23227 .57534 .23299 .58871 .22709 .58189 .22415 Metetra
.822 .944 .904 r
.58189 .22415 .58871 .22709 .60209 .21965 .59527 .21341 Metetra
.849 .853 .845 r
.59527 .21341 .60209 .21965 .61548 .21088 .60861 .20042 Metetra
.456 .607 .911 r
.60861 .20042 .61548 .21088 .62896 .20411 .62238 .20139 Metetra
.859 .952 .872 r
.62238 .20139 .62896 .20411 .64273 .20355 .63578 .18876 Metetra
.645 .621 .811 r
.63578 .18876 .64273 .20355 .65618 .19293 .64949 .1838 Metetra
.664 .741 .908 r
.64949 .1838 .65618 .19293 .66991 .188 .66327 .17882 Metetra
.664 .741 .908 r
.66327 .17882 .66991 .188 .68371 .18303 .67711 .17381 Metetra
.664 .741 .908 r
.67711 .17381 .68371 .18303 .69758 .17805 .69103 .16878 Metetra
.664 .741 .908 r
.69103 .16878 .69758 .17805 .71151 .17304 .70501 .16372 Metetra
.664 .741 .908 r
.70501 .16372 .71151 .17304 .72552 .168 .71906 .15864 Metetra
.664 .741 .908 r
.71906 .15864 .72552 .168 .73959 .16294 .73319 .15353 Metetra
.664 .741 .908 r
.73319 .15353 .73959 .16294 .75373 .15786 .74738 .1484 Metetra
.664 .741 .908 r
.74738 .1484 .75373 .15786 .76795 .15274 .76164 .14324 Metetra
.664 .741 .908 r
.76164 .14324 .76795 .15274 .78223 .14761 .77598 .13806 Metetra
.664 .741 .908 r
.14044 .35727 .14865 .36491 .16008 .36078 .1519 .3531 Metetra
.664 .741 .908 r
.1519 .3531 .16008 .36078 .17157 .35663 .16341 .34891 Metetra
.664 .741 .908 r
.16341 .34891 .17157 .35663 .1831 .35246 .17498 .34471 Metetra
.664 .741 .908 r
.17498 .34471 .1831 .35246 .19469 .34827 .18659 .34048 Metetra
.664 .741 .908 r
.18659 .34048 .19469 .34827 .20633 .34406 .19826 .33624 Metetra
.664 .741 .908 r
.19826 .33624 .20633 .34406 .21802 .33983 .20998 .33197 Metetra
.664 .741 .908 r
.20998 .33197 .21802 .33983 .22976 .33558 .22176 .32769 Metetra
.664 .741 .908 r
.22176 .32769 .22976 .33558 .24156 .33132 .23358 .32339 Metetra
.664 .741 .908 r
.23358 .32339 .24156 .33132 .25341 .32703 .24547 .31907 Metetra
.664 .741 .908 r
.24547 .31907 .25341 .32703 .26531 .32273 .2574 .31473 Metetra
.867 .427 .035 r
.2574 .31473 .26531 .32273 .27568 .33855 .26722 .33704 Metetra
.228 0 0 r
.26722 .33704 .27568 .33855 .28712 .3428 .27879 .34005 Metetra
.419 .815 .984 r
.27879 .34005 .28712 .3428 .29899 .34276 .29083 .33821 Metetra
.704 .857 .955 r
.29083 .33821 .29899 .34276 .31119 .33916 .30322 .33243 Metetra
.776 .802 .874 r
.30322 .33243 .31119 .33916 .32362 .33273 .31586 .32364 Metetra
.788 .75 .818 r
.31586 .32364 .32362 .33273 .33623 .32419 .32865 .31276 Metetra
.782 .709 .783 r
.32865 .31276 .33623 .32419 .34894 .31422 .34152 .30066 Metetra
.768 .676 .761 r
.34152 .30066 .34894 .31422 .3617 .30347 .35441 .28816 Metetra
.752 .65 .749 r
.35441 .28816 .3617 .30347 .37448 .29254 .36728 .27596 Metetra
.536 .529 .795 r
.36728 .27596 .37448 .29254 .38725 .28196 .37958 .27574 Metetra
.353 .676 .977 r
.37958 .27574 .38725 .28196 .39985 .27593 .39193 .27652 Metetra
.063 .627 .711 r
.39193 .27652 .39985 .27593 .41229 .27549 .40445 .27549 Metetra
.329 .812 .865 r
.40445 .27549 .41229 .27549 .42487 .27361 .41714 .2724 Metetra
.586 .925 .96 r
.41714 .2724 .42487 .27361 .43757 .27011 .42996 .26716 Metetra
.736 .923 .954 r
.42996 .26716 .43757 .27011 .45038 .26495 .44289 .25984 Metetra
.791 .865 .904 r
.44289 .25984 .45038 .26495 .46328 .25823 .4559 .25069 Metetra
.8 .801 .852 r
.4559 .25069 .46328 .25823 .47625 .25017 .46897 .24012 Metetra
.599 .682 .9 r
.46897 .24012 .47625 .25017 .48924 .2424 .48193 .23743 Metetra
.16 .604 .935 r
.48193 .23743 .48924 .2424 .50221 .24265 .49492 .23969 Metetra
.06 .591 .864 r
.49492 .23969 .50221 .24265 .51529 .24291 .50804 .24147 Metetra
.067 .621 .816 r
.50804 .24147 .51529 .24291 .52847 .2426 .52128 .24197 Metetra
.202 .727 .84 r
.52128 .24197 .52847 .2426 .54174 .2411 .53463 .24043 Metetra
.45 .877 .916 r
.53463 .24043 .54174 .2411 .55509 .23782 .54804 .23614 Metetra
.699 .958 .947 r
.54804 .23614 .55509 .23782 .56849 .23227 .56149 .22858 Metetra
.83 .923 .896 r
.56149 .22858 .56849 .23227 .58189 .22415 .57492 .21752 Metetra
.862 .842 .824 r
.57492 .21752 .58189 .22415 .59527 .21341 .5883 .20314 Metetra
.771 .749 .833 r
.5883 .20314 .59527 .21341 .60861 .20042 .60176 .19292 Metetra
0 .299 .777 r
.60176 .19292 .60861 .20042 .62238 .20139 .6158 .20152 Metetra
.952 .95 .72 r
.6158 .20152 .62238 .20139 .63578 .18876 .62898 .17958 Metetra
.664 .741 .908 r
.62898 .17958 .63578 .18876 .64949 .1838 .64274 .17458 Metetra
.664 .741 .908 r
.64274 .17458 .64949 .1838 .66327 .17882 .65657 .16955 Metetra
.664 .741 .908 r
.65657 .16955 .66327 .17882 .67711 .17381 .67046 .1645 Metetra
.664 .741 .908 r
.67046 .1645 .67711 .17381 .69103 .16878 .68442 .15942 Metetra
.664 .741 .908 r
.68442 .15942 .69103 .16878 .70501 .16372 .69845 .15432 Metetra
.664 .741 .908 r
.69845 .15432 .70501 .16372 .71906 .15864 .71255 .14919 Metetra
.664 .741 .908 r
.71255 .14919 .71906 .15864 .73319 .15353 .72672 .14404 Metetra
.664 .741 .908 r
.72672 .14404 .73319 .15353 .74738 .1484 .74096 .13886 Metetra
.664 .741 .908 r
.74096 .13886 .74738 .1484 .76164 .14324 .75528 .13365 Metetra
.664 .741 .908 r
.75528 .13365 .76164 .14324 .77598 .13806 .76966 .12842 Metetra
.664 .741 .908 r
.13216 .34956 .14044 .35727 .1519 .3531 .14365 .34535 Metetra
.664 .741 .908 r
.14365 .34535 .1519 .3531 .16341 .34891 .15519 .34113 Metetra
.664 .741 .908 r
.15519 .34113 .16341 .34891 .17498 .34471 .16679 .33689 Metetra
.664 .741 .908 r
.16679 .33689 .17498 .34471 .18659 .34048 .17843 .33263 Metetra
.664 .741 .908 r
.17843 .33263 .18659 .34048 .19826 .33624 .19013 .32835 Metetra
.664 .741 .908 r
.19013 .32835 .19826 .33624 .20998 .33197 .20188 .32405 Metetra
.664 .741 .908 r
.20188 .32405 .20998 .33197 .22176 .32769 .21369 .31974 Metetra
.664 .741 .908 r
.21369 .31974 .22176 .32769 .23358 .32339 .22555 .3154 Metetra
.664 .741 .908 r
.22555 .3154 .23358 .32339 .24547 .31907 .23746 .31104 Metetra
.664 .741 .908 r
.23746 .31104 .24547 .31907 .2574 .31473 .24943 .30666 Metetra
.664 .741 .908 r
.24943 .30666 .2574 .31473 .26722 .33704 .26145 .30226 Metetra
0 0 .503 r
.26145 .30226 .26722 .33704 .27879 .34005 .27106 .32847 Metetra
.547 .617 .874 r
.27106 .32847 .27879 .34005 .29083 .33821 .28305 .32747 Metetra
.695 .695 .846 r
.28305 .32747 .29083 .33821 .30322 .33243 .29549 .32133 Metetra
.757 .708 .805 r
.29549 .32133 .30322 .33243 .31586 .32364 .30824 .31143 Metetra
.778 .697 .774 r
.30824 .31143 .31586 .32364 .32865 .31276 .32116 .29907 Metetra
.778 .678 .753 r
.32116 .29907 .32865 .31276 .34152 .30066 .33416 .28547 Metetra
.768 .659 .741 r
.33416 .28547 .34152 .30066 .35441 .28816 .34715 .27169 Metetra
.454 .485 .802 r
.34715 .27169 .35441 .28816 .36728 .27596 .35926 .27405 Metetra
0 .464 .717 r
.35926 .27405 .36728 .27596 .37958 .27574 .37147 .27656 Metetra
.111 0 0 r
.37147 .27656 .37958 .27574 .39193 .27652 .3839 .27703 Metetra
.172 .709 .774 r
.3839 .27703 .39193 .27652 .40445 .27549 .39653 .27505 Metetra
.498 .9 .928 r
.39653 .27505 .40445 .27549 .41714 .2724 .40933 .27043 Metetra
.716 .945 .956 r
.40933 .27043 .41714 .2724 .42996 .26716 .42229 .26319 Metetra
.804 .898 .909 r
.42229 .26319 .42996 .26716 .44289 .25984 .43535 .25357 Metetra
.825 .834 .855 r
.43535 .25357 .44289 .25984 .4559 .25069 .44848 .24202 Metetra
.82 .778 .813 r
.44848 .24202 .4559 .25069 .46897 .24012 .46164 .22914 Metetra
.315 .514 .892 r
.46164 .22914 .46897 .24012 .48193 .23743 .47452 .23288 Metetra
0 .496 .854 r
.47452 .23288 .48193 .23743 .49492 .23969 .48754 .23661 Metetra
0 .535 .83 r
.48754 .23661 .49492 .23969 .50804 .24147 .5007 .23917 Metetra
.137 .66 .88 r
.5007 .23917 .50804 .24147 .52128 .24197 .514 .23963 Metetra
.412 .83 .967 r
.514 .23963 .52128 .24197 .53463 .24043 .52741 .2371 Metetra
.677 .914 .975 r
.52741 .2371 .53463 .24043 .54804 .23614 .54088 .23089 Metetra
.81 .879 .896 r
.54088 .23089 .54804 .23614 .56149 .22858 .55437 .22058 Metetra
.848 .81 .812 r
.55437 .22058 .56149 .22858 .57492 .21752 .56782 .20618 Metetra
.847 .747 .753 r
.56782 .20618 .57492 .21752 .5883 .20314 .58118 .18825 Metetra
.369 .468 .831 r
.58118 .18825 .5883 .20314 .60176 .19292 .59502 .19277 Metetra
.914 .975 .782 r
.59502 .19277 .60176 .19292 .6158 .20152 .60839 .17535 Metetra
.608 .5 .705 r
.60839 .17535 .6158 .20152 .62898 .17958 .62213 .17033 Metetra
.664 .741 .908 r
.62213 .17033 .62898 .17958 .64274 .17458 .63593 .16528 Metetra
.664 .741 .908 r
.63593 .16528 .64274 .17458 .65657 .16955 .6498 .16021 Metetra
.664 .741 .908 r
.6498 .16021 .65657 .16955 .67046 .1645 .66374 .15511 Metetra
.664 .741 .908 r
.66374 .15511 .67046 .1645 .68442 .15942 .67775 .14998 Metetra
.664 .741 .908 r
.67775 .14998 .68442 .15942 .69845 .15432 .69183 .14483 Metetra
.664 .741 .908 r
.69183 .14483 .69845 .15432 .71255 .14919 .70598 .13966 Metetra
.664 .741 .908 r
.70598 .13966 .71255 .14919 .72672 .14404 .7202 .13446 Metetra
.664 .741 .908 r
.7202 .13446 .72672 .14404 .74096 .13886 .73449 .12923 Metetra
.664 .741 .908 r
.73449 .12923 .74096 .13886 .75528 .13365 .74885 .12397 Metetra
.664 .741 .908 r
.74885 .12397 .75528 .13365 .76966 .12842 .76329 .11869 Metetra
.664 .741 .908 r
.12381 .34178 .13216 .34956 .14365 .34535 .13533 .33755 Metetra
.664 .741 .908 r
.13533 .33755 .14365 .34535 .15519 .34113 .1469 .33329 Metetra
.664 .741 .908 r
.1469 .33329 .15519 .34113 .16679 .33689 .15852 .32901 Metetra
.664 .741 .908 r
.15852 .32901 .16679 .33689 .17843 .33263 .1702 .32472 Metetra
.664 .741 .908 r
.1702 .32472 .17843 .33263 .19013 .32835 .18193 .3204 Metetra
.664 .741 .908 r
.18193 .3204 .19013 .32835 .20188 .32405 .19371 .31607 Metetra
.664 .741 .908 r
.19371 .31607 .20188 .32405 .21369 .31974 .20555 .31171 Metetra
.664 .741 .908 r
.20555 .31171 .21369 .31974 .22555 .3154 .21744 .30734 Metetra
.664 .741 .908 r
.21744 .30734 .22555 .3154 .23746 .31104 .22939 .30294 Metetra
.664 .741 .908 r
.22939 .30294 .23746 .31104 .24943 .30666 .24139 .29853 Metetra
.664 .741 .908 r
.24139 .29853 .24943 .30666 .26145 .30226 .25344 .29409 Metetra
0 .167 .667 r
.25344 .29409 .26145 .30226 .27106 .32847 .26447 .30267 Metetra
.444 .39 .703 r
.26447 .30267 .27106 .32847 .28305 .32747 .27599 .30695 Metetra
.598 .524 .743 r
.27599 .30695 .28305 .32747 .29549 .32133 .2882 .30372 Metetra
.694 .602 .749 r
.2882 .30372 .29549 .32133 .30824 .31143 .30087 .29507 Metetra
.743 .637 .742 r
.30087 .29507 .30824 .31143 .32116 .29907 .3138 .28295 Metetra
.762 .648 .735 r
.3138 .28295 .32116 .29907 .33416 .28547 .32684 .26908 Metetra
.497 .512 .802 r
.32684 .26908 .33416 .28547 .34715 .27169 .33897 .27002 Metetra
.304 0 0 r
.33897 .27002 .34715 .27169 .35926 .27405 .35102 .27417 Metetra
.242 0 0 r
.35102 .27417 .35926 .27405 .37147 .27656 .3633 .27649 Metetra
.029 .601 .728 r
.3633 .27649 .37147 .27656 .3839 .27703 .37581 .27627 Metetra
.393 .843 .919 r
.37581 .27627 .3839 .27703 .39653 .27505 .38855 .27309 Metetra
.67 .936 .968 r
.38855 .27309 .39653 .27505 .40933 .27043 .40149 .26682 Metetra
.794 .908 .92 r
.40149 .26682 .40933 .27043 .42229 .26319 .41458 .2576 Metetra
.833 .852 .86 r
.41458 .2576 .42229 .26319 .43535 .25357 .42777 .24587 Metetra
.837 .8 .815 r
.42777 .24587 .43535 .25357 .44848 .24202 .44102 .23226 Metetra
.762 .747 .839 r
.44102 .23226 .44848 .24202 .46164 .22914 .45415 .22283 Metetra
0 .432 .85 r
.45415 .22283 .46164 .22914 .47452 .23288 .46704 .22805 Metetra
0 .459 .834 r
.46704 .22805 .47452 .23288 .48754 .23661 .48008 .23239 Metetra
.091 .583 .901 r
.48008 .23239 .48754 .23661 .5007 .23917 .49329 .23475 Metetra
.37 .753 .989 r
.49329 .23475 .5007 .23917 .514 .23963 .50664 .23411 Metetra
.636 .836 .977 r
.50664 .23411 .514 .23963 .52741 .2371 .5201 .22958 Metetra
.77 .812 .886 r
.5201 .22958 .52741 .2371 .54088 .23089 .53362 .22058 Metetra
.816 .759 .799 r
.53362 .22058 .54088 .23089 .55437 .22058 .54714 .20696 Metetra
.824 .711 .74 r
.54714 .20696 .55437 .22058 .56782 .20618 .56059 .18918 Metetra
.641 .592 .784 r
.56059 .18918 .56782 .20618 .58118 .18825 .5742 .18391 Metetra
.547 0 0 r
.5742 .18391 .58118 .18825 .59502 .19277 .58824 .19607 Metetra
.971 .925 .614 r
.58824 .19607 .59502 .19277 .60839 .17535 .60143 .16606 Metetra
.664 .741 .908 r
.60143 .16606 .60839 .17535 .62213 .17033 .61521 .16099 Metetra
.664 .741 .908 r
.61521 .16099 .62213 .17033 .63593 .16528 .62906 .15589 Metetra
.664 .741 .908 r
.62906 .15589 .63593 .16528 .6498 .16021 .64298 .15077 Metetra
.664 .741 .908 r
.64298 .15077 .6498 .16021 .66374 .15511 .65696 .14563 Metetra
.664 .741 .908 r
.65696 .14563 .66374 .15511 .67775 .14998 .67102 .14045 Metetra
.664 .741 .908 r
.67102 .14045 .67775 .14998 .69183 .14483 .68515 .13526 Metetra
.664 .741 .908 r
.68515 .13526 .69183 .14483 .70598 .13966 .69934 .13003 Metetra
.664 .741 .908 r
.69934 .13003 .70598 .13966 .7202 .13446 .71361 .12478 Metetra
.664 .741 .908 r
.71361 .12478 .7202 .13446 .73449 .12923 .72795 .11951 Metetra
.664 .741 .908 r
.72795 .11951 .73449 .12923 .74885 .12397 .74237 .1142 Metetra
.664 .741 .908 r
.74237 .1142 .74885 .12397 .76329 .11869 .75685 .10887 Metetra
.664 .741 .908 r
.11539 .33394 .12381 .34178 .13533 .33755 .12694 .32967 Metetra
.664 .741 .908 r
.12694 .32967 .13533 .33755 .1469 .33329 .13854 .32538 Metetra
.664 .741 .908 r
.13854 .32538 .1469 .33329 .15852 .32901 .15019 .32107 Metetra
.664 .741 .908 r
.15019 .32107 .15852 .32901 .1702 .32472 .1619 .31673 Metetra
.664 .741 .908 r
.1619 .31673 .1702 .32472 .18193 .3204 .17366 .31238 Metetra
.664 .741 .908 r
.17366 .31238 .18193 .3204 .19371 .31607 .18547 .30801 Metetra
.664 .741 .908 r
.18547 .30801 .19371 .31607 .20555 .31171 .19734 .30362 Metetra
.664 .741 .908 r
.19734 .30362 .20555 .31171 .21744 .30734 .20926 .29921 Metetra
.664 .741 .908 r
.20926 .29921 .21744 .30734 .22939 .30294 .22124 .29477 Metetra
.664 .741 .908 r
.22124 .29477 .22939 .30294 .24139 .29853 .23328 .29032 Metetra
.664 .741 .908 r
.23328 .29032 .24139 .29853 .25344 .29409 .24536 .28585 Metetra
.664 .741 .908 r
.24536 .28585 .25344 .29409 .26447 .30267 .25751 .28135 Metetra
.53 .477 .741 r
.25751 .28135 .26447 .30267 .27599 .30695 .26934 .28134 Metetra
.604 .494 .701 r
.26934 .28134 .27599 .30695 .2882 .30372 .28161 .2769 Metetra
.591 .479 .695 r
.28161 .2769 .2882 .30372 .30087 .29507 .29388 .27319 Metetra
.678 .561 .715 r
.29388 .27319 .30087 .29507 .3138 .28295 .3066 .26402 Metetra
.493 .48 .77 r
.3066 .26402 .3138 .28295 .32684 .26908 .31864 .26532 Metetra
0 .409 .751 r
.31864 .26532 .32684 .26908 .33897 .27002 .33062 .26934 Metetra
.294 0 0 r
.33062 .26934 .33897 .27002 .35102 .27417 .34276 .27273 Metetra
0 .528 .743 r
.34276 .27273 .35102 .27417 .3633 .27649 .35512 .27423 Metetra
.308 .771 .944 r
.35512 .27423 .3633 .27649 .37581 .27627 .36774 .27298 Metetra
.608 .885 .99 r
.36774 .27298 .37581 .27627 .38855 .27309 .38059 .26849 Metetra
.757 .878 .934 r
.38059 .26849 .38855 .27309 .40149 .26682 .39365 .26067 Metetra
.814 .838 .867 r
.39365 .26067 .40149 .26682 .41458 .2576 .40686 .2498 Metetra
.833 .798 .818 r
.40686 .2498 .41458 .2576 .42777 .24587 .42017 .23648 Metetra
.834 .767 .787 r
.42017 .23648 .42777 .24587 .44102 .23226 .43352 .22154 Metetra
.66 .696 .873 r
.43352 .22154 .44102 .23226 .45415 .22283 .44658 .21667 Metetra
0 .412 .832 r
.44658 .21667 .45415 .22283 .46704 .22805 .45948 .22209 Metetra
.074 .52 .9 r
.45948 .22209 .46704 .22805 .48008 .23239 .47257 .22586 Metetra
.341 .669 .975 r
.47257 .22586 .48008 .23239 .49329 .23475 .48583 .22678 Metetra
.591 .745 .95 r
.48583 .22678 .49329 .23475 .50664 .23411 .49924 .22382 Metetra
.723 .735 .861 r
.49924 .22382 .50664 .23411 .5201 .22958 .51275 .21622 Metetra
.775 .699 .779 r
.51275 .21622 .5201 .22958 .53362 .22058 .5263 .20368 Metetra
.791 .665 .724 r
.5263 .20368 .53362 .22058 .54714 .20696 .53983 .18651 Metetra
.675 .577 .738 r
.53983 .18651 .54714 .20696 .56059 .18918 .55339 .178 Metetra
0 .163 .7 r
.55339 .178 .56059 .18918 .5742 .18391 .56729 .19063 Metetra
.919 .93 .559 r
.56729 .19063 .5742 .18391 .58824 .19607 .58065 .16177 Metetra
.59 .454 .664 r
.58065 .16177 .58824 .19607 .60143 .16606 .5944 .15668 Metetra
.664 .741 .908 r
.5944 .15668 .60143 .16606 .61521 .16099 .60823 .15156 Metetra
.664 .741 .908 r
.60823 .15156 .61521 .16099 .62906 .15589 .62212 .14642 Metetra
.664 .741 .908 r
.62212 .14642 .62906 .15589 .64298 .15077 .63609 .14125 Metetra
.664 .741 .908 r
.63609 .14125 .64298 .15077 .65696 .14563 .65012 .13606 Metetra
.664 .741 .908 r
.65012 .13606 .65696 .14563 .67102 .14045 .66423 .13084 Metetra
.664 .741 .908 r
.66423 .13084 .67102 .14045 .68515 .13526 .6784 .12559 Metetra
.664 .741 .908 r
.6784 .12559 .68515 .13526 .69934 .13003 .69265 .12032 Metetra
.664 .741 .908 r
.69265 .12032 .69934 .13003 .71361 .12478 .70697 .11502 Metetra
.664 .741 .908 r
.70697 .11502 .71361 .12478 .72795 .11951 .72136 .1097 Metetra
.664 .741 .908 r
.72136 .1097 .72795 .11951 .74237 .1142 .73582 .10434 Metetra
.664 .741 .908 r
.73582 .10434 .74237 .1142 .75685 .10887 .75036 .09896 Metetra
.664 .741 .908 r
.1069 .32604 .11539 .33394 .12694 .32967 .11848 .32173 Metetra
.664 .741 .908 r
.11848 .32173 .12694 .32967 .13854 .32538 .13011 .3174 Metetra
.664 .741 .908 r
.13011 .3174 .13854 .32538 .15019 .32107 .14179 .31305 Metetra
.664 .741 .908 r
.14179 .31305 .15019 .32107 .1619 .31673 .15353 .30868 Metetra
.664 .741 .908 r
.15353 .30868 .1619 .31673 .17366 .31238 .16532 .3043 Metetra
.664 .741 .908 r
.16532 .3043 .17366 .31238 .18547 .30801 .17717 .29989 Metetra
.664 .741 .908 r
.17717 .29989 .18547 .30801 .19734 .30362 .18906 .29546 Metetra
.664 .741 .908 r
.18906 .29546 .19734 .30362 .20926 .29921 .20102 .29101 Metetra
.664 .741 .908 r
.20102 .29101 .20926 .29921 .22124 .29477 .21303 .28654 Metetra
.664 .741 .908 r
.21303 .28654 .22124 .29477 .23328 .29032 .22509 .28204 Metetra
.664 .741 .908 r
.22509 .28204 .23328 .29032 .24536 .28585 .23722 .27753 Metetra
.664 .741 .908 r
.23722 .27753 .24536 .28585 .25751 .28135 .2494 .273 Metetra
.664 .741 .908 r
.2494 .273 .25751 .28135 .26934 .28134 .26163 .26844 Metetra
.763 .35 0 r
.26163 .26844 .26934 .28134 .28161 .2769 .27176 .29049 Metetra
.27176 .29049 .28161 .2769 .29388 .27319 .28508 .27471 Metetra
.584 .945 .873 r
.28508 .27471 .29388 .27319 .3066 .26402 .29772 .26782 Metetra
.101 0 0 r
.29772 .26782 .3066 .26402 .31864 .26532 .31002 .2663 Metetra
.171 0 0 r
.31002 .2663 .31864 .26532 .33062 .26934 .32224 .2673 Metetra
.015 .576 .807 r
.32224 .2673 .33062 .26934 .34276 .27273 .33455 .26857 Metetra
.312 .727 .976 r
.33455 .26857 .34276 .27273 .35512 .27423 .34704 .26845 Metetra
.557 .792 .987 r
.34704 .26845 .35512 .27423 .36774 .27298 .35977 .26581 Metetra
.695 .794 .926 r
.35977 .26581 .36774 .27298 .38059 .26849 .37273 .26004 Metetra
.764 .777 .863 r
.37273 .26004 .38059 .26849 .39365 .26067 .38589 .25105 Metetra
.798 .758 .816 r
.38589 .25105 .39365 .26067 .40686 .2498 .39919 .23919 Metetra
.813 .743 .786 r
.39919 .23919 .40686 .2498 .42017 .23648 .41258 .22519 Metetra
.819 .734 .771 r
.41258 .22519 .42017 .23648 .43352 .22154 .42598 .21004 Metetra
.505 .611 .892 r
.42598 .21004 .43352 .22154 .44658 .21667 .43894 .20984 Metetra
.082 .5 .9 r
.43894 .20984 .44658 .21667 .45948 .22209 .4519 .21405 Metetra
.339 .621 .955 r
.4519 .21405 .45948 .22209 .47257 .22586 .46505 .21574 Metetra
.565 .677 .914 r
.46505 .21574 .47257 .22586 .48583 .22678 .47837 .21373 Metetra
.686 .669 .828 r
.47837 .21373 .48583 .22678 .49924 .22382 .49184 .20711 Metetra
.738 .644 .755 r
.49184 .20711 .49924 .22382 .51275 .21622 .50539 .19541 Metetra
.759 .619 .704 r
.50539 .19541 .51275 .21622 .5263 .20368 .51896 .17879 Metetra
.559 .477 .72 r
.51896 .17879 .5263 .20368 .53983 .18651 .53253 .17709 Metetra
0 .094 .627 r
.53253 .17709 .53983 .18651 .55339 .178 .5463 .1901 Metetra
.831 .869 .425 r
.5463 .1901 .55339 .178 .56729 .19063 .55977 .15746 Metetra
.592 .459 .669 r
.55977 .15746 .56729 .19063 .58065 .16177 .57351 .15235 Metetra
.664 .741 .908 r
.57351 .15235 .58065 .16177 .5944 .15668 .58731 .14721 Metetra
.664 .741 .908 r
.58731 .14721 .5944 .15668 .60823 .15156 .60118 .14205 Metetra
.664 .741 .908 r
.60118 .14205 .60823 .15156 .62212 .14642 .61512 .13686 Metetra
.664 .741 .908 r
.61512 .13686 .62212 .14642 .63609 .14125 .62914 .13164 Metetra
.664 .741 .908 r
.62914 .13164 .63609 .14125 .65012 .13606 .64322 .1264 Metetra
.664 .741 .908 r
.64322 .1264 .65012 .13606 .66423 .13084 .65737 .12113 Metetra
.664 .741 .908 r
.65737 .12113 .66423 .13084 .6784 .12559 .67159 .11584 Metetra
.664 .741 .908 r
.67159 .11584 .6784 .12559 .69265 .12032 .68589 .11052 Metetra
.664 .741 .908 r
.68589 .11052 .69265 .12032 .70697 .11502 .70026 .10517 Metetra
.664 .741 .908 r
.70026 .10517 .70697 .11502 .72136 .1097 .7147 .09979 Metetra
.664 .741 .908 r
.7147 .09979 .72136 .1097 .73582 .10434 .72922 .09439 Metetra
.664 .741 .908 r
.72922 .09439 .73582 .10434 .75036 .09896 .74381 .08896 Metetra
.664 .741 .908 r
.09834 .31807 .1069 .32604 .11848 .32173 .10995 .31372 Metetra
.664 .741 .908 r
.10995 .31372 .11848 .32173 .13011 .3174 .12161 .30936 Metetra
.664 .741 .908 r
.12161 .30936 .13011 .3174 .14179 .31305 .13332 .30497 Metetra
.664 .741 .908 r
.13332 .30497 .14179 .31305 .15353 .30868 .14509 .30057 Metetra
.664 .741 .908 r
.14509 .30057 .15353 .30868 .16532 .3043 .15691 .29614 Metetra
.664 .741 .908 r
.15691 .29614 .16532 .3043 .17717 .29989 .16879 .29169 Metetra
.664 .741 .908 r
.16879 .29169 .17717 .29989 .18906 .29546 .18072 .28723 Metetra
.664 .741 .908 r
.18072 .28723 .18906 .29546 .20102 .29101 .1927 .28274 Metetra
.664 .741 .908 r
.1927 .28274 .20102 .29101 .21303 .28654 .20475 .27823 Metetra
.664 .741 .908 r
.20475 .27823 .21303 .28654 .22509 .28204 .21684 .2737 Metetra
.664 .741 .908 r
.21684 .2737 .22509 .28204 .23722 .27753 .229 .26915 Metetra
.664 .741 .908 r
.229 .26915 .23722 .27753 .2494 .273 .24121 .26457 Metetra
.664 .741 .908 r
.24121 .26457 .2494 .273 .26163 .26844 .25348 .25998 Metetra
.954 .629 .368 r
.25348 .25998 .26163 .26844 .27176 .29049 .25937 .3318 Metetra
0 0 .071 r
.25937 .3318 .27176 .29049 .28508 .27471 .27443 .29764 Metetra
.27443 .29764 .28508 .27471 .29772 .26782 .28819 .27818 Metetra
.28819 .27818 .29772 .26782 .31002 .2663 .30121 .26809 Metetra
.375 .84 .801 r
.30121 .26809 .31002 .2663 .32224 .2673 .31389 .26327 Metetra
.514 .83 1 r
.31389 .26327 .32224 .2673 .33455 .26857 .32648 .26062 Metetra
.588 .738 .947 r
.32648 .26062 .33455 .26857 .34704 .26845 .33916 .25785 Metetra
.648 .694 .879 r
.33916 .25785 .34704 .26845 .35977 .26581 .35201 .25344 Metetra
.696 .679 .829 r
.35201 .25344 .35977 .26581 .37273 .26004 .36505 .24657 Metetra
.733 .676 .795 r
.36505 .24657 .37273 .26004 .38589 .25105 .37827 .23705 Metetra
.76 .679 .773 r
.37827 .23705 .38589 .25105 .39919 .23919 .3916 .22521 Metetra
.777 .686 .763 r
.3916 .22521 .39919 .23919 .41258 .22519 .40501 .21184 Metetra
.783 .696 .768 r
.40501 .21184 .41258 .22519 .42598 .21004 .4184 .19844 Metetra
.338 .521 .889 r
.4184 .19844 .42598 .21004 .43894 .20984 .43126 .20169 Metetra
.373 .637 .958 r
.43126 .20169 .43894 .20984 .4519 .21405 .44432 .20286 Metetra
.575 .657 .892 r
.44432 .20286 .4519 .21405 .46505 .21574 .45757 .20066 Metetra
.674 .634 .801 r
.45757 .20066 .46505 .21574 .47837 .21373 .47099 .19403 Metetra
.718 .606 .731 r
.47099 .19403 .47837 .21373 .49184 .20711 .48452 .18236 Metetra
.685 .554 .7 r
.48452 .18236 .49184 .20711 .50539 .19541 .49806 .17114 Metetra
.259 .291 .705 r
.49806 .17114 .50539 .19541 .51896 .17879 .51151 .18221 Metetra
.716 .211 .031 r
.51151 .18221 .51896 .17879 .53253 .17709 .52517 .19618 Metetra
.656 .261 .286 r
.52517 .19618 .53253 .17709 .5463 .1901 .53908 .21022 Metetra
.917 .818 .353 r
.53908 .21022 .5463 .1901 .55977 .15746 .55253 .148 Metetra
.664 .741 .908 r
.55253 .148 .55977 .15746 .57351 .15235 .56631 .14284 Metetra
.664 .741 .908 r
.56631 .14284 .57351 .15235 .58731 .14721 .58015 .13766 Metetra
.664 .741 .908 r
.58015 .13766 .58731 .14721 .60118 .14205 .59407 .13245 Metetra
.664 .741 .908 r
.59407 .13245 .60118 .14205 .61512 .13686 .60806 .12721 Metetra
.664 .741 .908 r
.60806 .12721 .61512 .13686 .62914 .13164 .62212 .12195 Metetra
.664 .741 .908 r
.62212 .12195 .62914 .13164 .64322 .1264 .63625 .11666 Metetra
.664 .741 .908 r
.63625 .11666 .64322 .1264 .65737 .12113 .65045 .11134 Metetra
.664 .741 .908 r
.65045 .11134 .65737 .12113 .67159 .11584 .66472 .10599 Metetra
.664 .741 .908 r
.66472 .10599 .67159 .11584 .68589 .11052 .67907 .10062 Metetra
.664 .741 .908 r
.67907 .10062 .68589 .11052 .70026 .10517 .69349 .09522 Metetra
.664 .741 .908 r
.69349 .09522 .70026 .10517 .7147 .09979 .70798 .0898 Metetra
.664 .741 .908 r
.70798 .0898 .7147 .09979 .72922 .09439 .72255 .08434 Metetra
.664 .741 .908 r
.72255 .08434 .72922 .09439 .74381 .08896 .73719 .07886 Metetra
.664 .741 .908 r
.08971 .31003 .09834 .31807 .10995 .31372 .10135 .30565 Metetra
.664 .741 .908 r
.10135 .30565 .10995 .31372 .12161 .30936 .11304 .30125 Metetra
.664 .741 .908 r
.11304 .30125 .12161 .30936 .13332 .30497 .12478 .29682 Metetra
.664 .741 .908 r
.12478 .29682 .13332 .30497 .14509 .30057 .13658 .29238 Metetra
.664 .741 .908 r
.13658 .29238 .14509 .30057 .15691 .29614 .14843 .28791 Metetra
.664 .741 .908 r
.14843 .28791 .15691 .29614 .16879 .29169 .16033 .28343 Metetra
.664 .741 .908 r
.16033 .28343 .16879 .29169 .18072 .28723 .1723 .27892 Metetra
.664 .741 .908 r
.1723 .27892 .18072 .28723 .1927 .28274 .18432 .2744 Metetra
.664 .741 .908 r
.18432 .2744 .1927 .28274 .20475 .27823 .19639 .26985 Metetra
.664 .741 .908 r
.19639 .26985 .20475 .27823 .21684 .2737 .20852 .26528 Metetra
.664 .741 .908 r
.20852 .26528 .21684 .2737 .229 .26915 .22071 .26069 Metetra
.664 .741 .908 r
.22071 .26069 .229 .26915 .24121 .26457 .23296 .25608 Metetra
.664 .741 .908 r
.23296 .25608 .24121 .26457 .25348 .25998 .24526 .25144 Metetra
.664 .741 .908 r
.24526 .25144 .25348 .25998 .25937 .3318 .25762 .24678 Metetra
0 0 .2 r
.25762 .24678 .25937 .3318 .27443 .29764 .26229 .33538 Metetra
.26229 .33538 .27443 .29764 .28819 .27818 .27793 .29537 Metetra
.62 .799 .368 r
.27793 .29537 .28819 .27818 .30121 .26809 .29216 .27122 Metetra
.847 .998 .805 r
.29216 .27122 .30121 .26809 .31389 .26327 .3056 .25688 Metetra
.778 .827 .891 r
.3056 .25688 .31389 .26327 .32648 .26062 .31866 .24794 Metetra
.691 .671 .826 r
.31866 .24794 .32648 .26062 .33916 .25785 .3316 .24124 Metetra
.667 .607 .778 r
.3316 .24124 .33916 .25785 .35201 .25344 .34458 .23466 Metetra
.672 .587 .752 r
.34458 .23466 .35201 .25344 .36505 .24657 .35766 .227 Metetra
.689 .589 .739 r
.35766 .227 .36505 .24657 .37827 .23705 .37086 .21783 Metetra
.707 .602 .737 r
.37086 .21783 .37827 .23705 .3916 .22521 .38415 .20737 Metetra
.722 .622 .745 r
.38415 .20737 .3916 .22521 .40501 .21184 .39747 .19633 Metetra
.616 .598 .809 r
.39747 .19633 .40501 .21184 .4184 .19844 .41054 .19251 Metetra
.45 .748 .992 r
.41054 .19251 .4184 .19844 .43126 .20169 .42358 .19147 Metetra
.634 .704 .897 r
.42358 .19147 .43126 .20169 .44432 .20286 .43681 .18741 Metetra
.699 .64 .787 r
.43681 .18741 .44432 .20286 .45757 .20066 .45021 .17922 Metetra
.65 .555 .735 r
.45021 .17922 .45757 .20066 .47099 .19403 .46363 .17218 Metetra
.308 .344 .736 r
.46363 .17218 .47099 .19403 .48452 .18236 .47685 .18031 Metetra
.668 .116 0 r
.47685 .18031 .48452 .18236 .49806 .17114 .4902 .19317 Metetra
.666 .286 .316 r
.4902 .19317 .49806 .17114 .51151 .18221 .50376 .20936 Metetra
.653 .289 .341 r
.50376 .20936 .51151 .18221 .52517 .19618 .51758 .22613 Metetra
.901 .784 .297 r
.51758 .22613 .52517 .19618 .53908 .21022 .53145 .14364 Metetra
.555 .372 .588 r
.53145 .14364 .53908 .21022 .55253 .148 .54521 .13846 Metetra
.664 .741 .908 r
.54521 .13846 .55253 .148 .56631 .14284 .55904 .13325 Metetra
.664 .741 .908 r
.55904 .13325 .56631 .14284 .58015 .13766 .57293 .12802 Metetra
.664 .741 .908 r
.57293 .12802 .58015 .13766 .59407 .13245 .5869 .12276 Metetra
.664 .741 .908 r
.5869 .12276 .59407 .13245 .60806 .12721 .60093 .11747 Metetra
.664 .741 .908 r
.60093 .11747 .60806 .12721 .62212 .12195 .61504 .11216 Metetra
.664 .741 .908 r
.61504 .11216 .62212 .12195 .63625 .11666 .62921 .10682 Metetra
.664 .741 .908 r
.62921 .10682 .63625 .11666 .65045 .11134 .64346 .10145 Metetra
.664 .741 .908 r
.64346 .10145 .65045 .11134 .66472 .10599 .65779 .09606 Metetra
.664 .741 .908 r
.65779 .09606 .66472 .10599 .67907 .10062 .67218 .09063 Metetra
.664 .741 .908 r
.67218 .09063 .67907 .10062 .69349 .09522 .68665 .08518 Metetra
.664 .741 .908 r
.68665 .08518 .69349 .09522 .70798 .0898 .7012 .0797 Metetra
.664 .741 .908 r
.7012 .0797 .70798 .0898 .72255 .08434 .71581 .0742 Metetra
.664 .741 .908 r
.71581 .0742 .72255 .08434 .73719 .07886 .73051 .06866 Metetra
.664 .741 .908 r
.081 .30192 .08971 .31003 .10135 .30565 .09267 .2975 Metetra
.664 .741 .908 r
.09267 .2975 .10135 .30565 .11304 .30125 .10439 .29306 Metetra
.664 .741 .908 r
.10439 .29306 .11304 .30125 .12478 .29682 .11616 .2886 Metetra
.664 .741 .908 r
.11616 .2886 .12478 .29682 .13658 .29238 .12799 .28412 Metetra
.664 .741 .908 r
.12799 .28412 .13658 .29238 .14843 .28791 .13987 .27962 Metetra
.664 .741 .908 r
.13987 .27962 .14843 .28791 .16033 .28343 .15181 .27509 Metetra
.664 .741 .908 r
.15181 .27509 .16033 .28343 .1723 .27892 .1638 .27055 Metetra
.664 .741 .908 r
.1638 .27055 .1723 .27892 .18432 .2744 .17585 .26598 Metetra
.664 .741 .908 r
.17585 .26598 .18432 .2744 .19639 .26985 .18796 .2614 Metetra
.664 .741 .908 r
.18796 .2614 .19639 .26985 .20852 .26528 .20013 .25679 Metetra
.664 .741 .908 r
.20013 .25679 .20852 .26528 .22071 .26069 .21235 .25216 Metetra
.664 .741 .908 r
.21235 .25216 .22071 .26069 .23296 .25608 .22463 .2475 Metetra
.664 .741 .908 r
.22463 .2475 .23296 .25608 .24526 .25144 .23697 .24283 Metetra
.664 .741 .908 r
.23697 .24283 .24526 .25144 .25762 .24678 .24936 .23813 Metetra
.664 .741 .908 r
.24936 .23813 .25762 .24678 .26229 .33538 .26182 .23341 Metetra
0 0 .288 r
.26182 .23341 .26229 .33538 .27793 .29537 .26664 .32234 Metetra
.818 .835 .365 r
.26664 .32234 .27793 .29537 .29216 .27122 .28278 .27675 Metetra
.971 .928 .674 r
.28278 .27675 .29216 .27122 .3056 .25688 .2974 .24808 Metetra
.861 .771 .762 r
.2974 .24808 .3056 .25688 .31866 .24794 .31115 .22987 Metetra
.734 .624 .736 r
.31115 .22987 .31866 .24794 .3316 .24124 .32446 .21765 Metetra
.669 .549 .709 r
.32446 .21765 .3316 .24124 .34458 .23466 .33758 .20842 Metetra
.644 .519 .696 r
.33758 .20842 .34458 .23466 .35766 .227 .35066 .20038 Metetra
.581 .478 .702 r
.35066 .20038 .35766 .227 .37086 .21783 .36353 .19697 Metetra
.574 .515 .751 r
.36353 .19697 .37086 .21783 .38415 .20737 .37642 .19455 Metetra
.608 .638 .855 r
.37642 .19455 .38415 .20737 .39747 .19633 .38944 .19127 Metetra
.653 .854 .977 r
.38944 .19127 .39747 .19633 .41054 .19251 .4026 .18623 Metetra
.751 .841 .919 r
.4026 .18623 .41054 .19251 .42358 .19147 .41593 .17834 Metetra
.65 .653 .84 r
.41593 .17834 .42358 .19147 .43681 .18741 .42921 .17335 Metetra
.217 .399 .829 r
.42921 .17335 .43681 .18741 .45021 .17922 .44224 .17985 Metetra
.675 .133 0 r
.44224 .17985 .45021 .17922 .46363 .17218 .45531 .19154 Metetra
.681 .291 .302 r
.45531 .19154 .46363 .17218 .47685 .18031 .46851 .2082 Metetra
.678 .317 .354 r
.46851 .2082 .47685 .18031 .4902 .19317 .48192 .22862 Metetra
.662 .317 .377 r
.48192 .22862 .4902 .19317 .50376 .20936 .49562 .2502 Metetra
.911 .768 .28 r
.49562 .2502 .50376 .20936 .51758 .22613 .51029 .13926 Metetra
.544 .349 .567 r
.51029 .13926 .51758 .22613 .53145 .14364 .52403 .13405 Metetra
.664 .741 .908 r
.52403 .13405 .53145 .14364 .54521 .13846 .53783 .12882 Metetra
.664 .741 .908 r
.53783 .12882 .54521 .13846 .55904 .13325 .5517 .12357 Metetra
.664 .741 .908 r
.5517 .12357 .55904 .13325 .57293 .12802 .56564 .11829 Metetra
.664 .741 .908 r
.56564 .11829 .57293 .12802 .5869 .12276 .57965 .11298 Metetra
.664 .741 .908 r
.57965 .11298 .5869 .12276 .60093 .11747 .59373 .10764 Metetra
.664 .741 .908 r
.59373 .10764 .60093 .11747 .61504 .11216 .60789 .10228 Metetra
.664 .741 .908 r
.60789 .10228 .61504 .11216 .62921 .10682 .62211 .09689 Metetra
.664 .741 .908 r
.62211 .09689 .62921 .10682 .64346 .10145 .63641 .09147 Metetra
.664 .741 .908 r
.63641 .09147 .64346 .10145 .65779 .09606 .65078 .08602 Metetra
.664 .741 .908 r
.65078 .08602 .65779 .09606 .67218 .09063 .66523 .08055 Metetra
.664 .741 .908 r
.66523 .08055 .67218 .09063 .68665 .08518 .67975 .07505 Metetra
.664 .741 .908 r
.67975 .07505 .68665 .08518 .7012 .0797 .69435 .06952 Metetra
.664 .741 .908 r
.69435 .06952 .7012 .0797 .71581 .0742 .70902 .06396 Metetra
.664 .741 .908 r
.70902 .06396 .71581 .0742 .73051 .06866 .72376 .05837 Metetra
.664 .741 .908 r
.07222 .29375 .081 .30192 .09267 .2975 .08392 .28929 Metetra
.664 .741 .908 r
.08392 .28929 .09267 .2975 .10439 .29306 .09567 .28481 Metetra
.664 .741 .908 r
.09567 .28481 .10439 .29306 .11616 .2886 .10747 .28031 Metetra
.664 .741 .908 r
.10747 .28031 .11616 .2886 .12799 .28412 .11933 .27579 Metetra
.664 .741 .908 r
.11933 .27579 .12799 .28412 .13987 .27962 .13124 .27125 Metetra
.664 .741 .908 r
.13124 .27125 .13987 .27962 .15181 .27509 .14321 .26669 Metetra
.664 .741 .908 r
.14321 .26669 .15181 .27509 .1638 .27055 .15524 .2621 Metetra
.664 .741 .908 r
.15524 .2621 .1638 .27055 .17585 .26598 .16732 .2575 Metetra
.664 .741 .908 r
.16732 .2575 .17585 .26598 .18796 .2614 .17946 .25287 Metetra
.664 .741 .908 r
.17946 .25287 .18796 .2614 .20013 .25679 .19166 .24822 Metetra
.664 .741 .908 r
.19166 .24822 .20013 .25679 .21235 .25216 .20391 .24355 Metetra
.664 .741 .908 r
.20391 .24355 .21235 .25216 .22463 .2475 .21623 .23885 Metetra
.664 .741 .908 r
.21623 .23885 .22463 .2475 .23697 .24283 .2286 .23414 Metetra
.664 .741 .908 r
.2286 .23414 .23697 .24283 .24936 .23813 .24103 .2294 Metetra
.664 .741 .908 r
.24103 .2294 .24936 .23813 .26182 .23341 .25352 .22464 Metetra
.664 .741 .908 r
.25352 .22464 .26182 .23341 .26664 .32234 .26607 .21985 Metetra
0 0 .401 r
.26607 .21985 .26664 .32234 .28278 .27675 .2729 .28642 Metetra
.995 .864 .583 r
.2729 .28642 .28278 .27675 .2974 .24808 .28927 .23726 Metetra
.896 .738 .678 r
.28927 .23726 .2974 .24808 .31115 .22987 .30403 .20611 Metetra
.288 .309 .709 r
.30403 .20611 .31115 .22987 .32446 .21765 .31591 .21465 Metetra
0 .48 .772 r
.31591 .21465 .32446 .21765 .33758 .20842 .32832 .21749 Metetra
.268 0 0 r
.32832 .21749 .33758 .20842 .35066 .20038 .34114 .21571 Metetra
.252 0 .042 r
.34114 .21571 .35066 .20038 .36353 .19697 .35423 .21076 Metetra
.101 0 0 r
.35423 .21076 .36353 .19697 .37642 .19455 .36752 .20318 Metetra
.36752 .20318 .37642 .19455 .38944 .19127 .38098 .19283 Metetra
.84 .998 .829 r
.38098 .19283 .38944 .19127 .4026 .18623 .39461 .17915 Metetra
.777 .824 .889 r
.39461 .17915 .4026 .18623 .41593 .17834 .40805 .16992 Metetra
0 .026 .537 r
.40805 .16992 .41593 .17834 .42921 .17335 .42076 .1824 Metetra
.744 .307 .212 r
.42076 .1824 .42921 .17335 .44224 .17985 .43354 .20028 Metetra
.726 .346 .329 r
.43354 .20028 .44224 .17985 .45531 .19154 .44644 .22348 Metetra
.706 .355 .378 r
.44644 .22348 .45531 .19154 .46851 .2082 .45959 .25097 Metetra
.684 .349 .401 r
.45959 .25097 .46851 .2082 .48192 .22862 .47306 .28036 Metetra
.931 .764 .287 r
.47306 .28036 .48192 .22862 .49562 .2502 .48904 .13486 Metetra
.534 .329 .548 r
.48904 .13486 .49562 .2502 .51029 .13926 .50275 .12963 Metetra
.664 .741 .908 r
.50275 .12963 .51029 .13926 .52403 .13405 .51653 .12438 Metetra
.664 .741 .908 r
.51653 .12438 .52403 .13405 .53783 .12882 .53038 .1191 Metetra
.664 .741 .908 r
.53038 .1191 .53783 .12882 .5517 .12357 .54429 .1138 Metetra
.664 .741 .908 r
.54429 .1138 .5517 .12357 .56564 .11829 .55828 .10846 Metetra
.664 .741 .908 r
.55828 .10846 .56564 .11829 .57965 .11298 .57234 .1031 Metetra
.664 .741 .908 r
.57234 .1031 .57965 .11298 .59373 .10764 .58647 .09772 Metetra
.664 .741 .908 r
.58647 .09772 .59373 .10764 .60789 .10228 .60067 .0923 Metetra
.664 .741 .908 r
.60067 .0923 .60789 .10228 .62211 .09689 .61495 .08686 Metetra
.664 .741 .908 r
.61495 .08686 .62211 .09689 .63641 .09147 .62929 .08139 Metetra
.664 .741 .908 r
.62929 .08139 .63641 .09147 .65078 .08602 .64372 .0759 Metetra
.664 .741 .908 r
.64372 .0759 .65078 .08602 .66523 .08055 .65821 .07037 Metetra
.664 .741 .908 r
.65821 .07037 .66523 .08055 .67975 .07505 .67278 .06481 Metetra
.664 .741 .908 r
.67278 .06481 .67975 .07505 .69435 .06952 .68743 .05923 Metetra
.664 .741 .908 r
.68743 .05923 .69435 .06952 .70902 .06396 .70215 .05362 Metetra
.664 .741 .908 r
.70215 .05362 .70902 .06396 .72376 .05837 .71695 .04798 Metetra
.664 .741 .908 r
.06337 .2855 .07222 .29375 .08392 .28929 .07509 .28101 Metetra
.664 .741 .908 r
.07509 .28101 .08392 .28929 .09567 .28481 .08687 .27649 Metetra
.664 .741 .908 r
.08687 .27649 .09567 .28481 .10747 .28031 .0987 .27195 Metetra
.664 .741 .908 r
.0987 .27195 .10747 .28031 .11933 .27579 .11059 .26739 Metetra
.664 .741 .908 r
.11059 .26739 .11933 .27579 .13124 .27125 .12254 .26281 Metetra
.664 .741 .908 r
.12254 .26281 .13124 .27125 .14321 .26669 .13454 .25821 Metetra
.664 .741 .908 r
.13454 .25821 .14321 .26669 .15524 .2621 .1466 .25358 Metetra
.664 .741 .908 r
.1466 .25358 .15524 .2621 .16732 .2575 .15871 .24894 Metetra
.664 .741 .908 r
.15871 .24894 .16732 .2575 .17946 .25287 .17088 .24427 Metetra
.664 .741 .908 r
.17088 .24427 .17946 .25287 .19166 .24822 .18312 .23958 Metetra
.664 .741 .908 r
.18312 .23958 .19166 .24822 .20391 .24355 .1954 .23486 Metetra
.664 .741 .908 r
.1954 .23486 .20391 .24355 .21623 .23885 .20775 .23013 Metetra
.664 .741 .908 r
.20775 .23013 .21623 .23885 .2286 .23414 .22016 .22537 Metetra
.664 .741 .908 r
.22016 .22537 .2286 .23414 .24103 .2294 .23262 .22059 Metetra
.664 .741 .908 r
.23262 .22059 .24103 .2294 .25352 .22464 .24515 .21579 Metetra
.664 .741 .908 r
.24515 .21579 .25352 .22464 .26607 .21985 .25774 .21096 Metetra
.664 .741 .908 r
.25774 .21096 .26607 .21985 .2729 .28642 .27038 .20611 Metetra
.368 .215 .539 r
.27038 .20611 .2729 .28642 .28927 .23726 .28116 .2254 Metetra
.742 .706 .818 r
.28116 .2254 .28927 .23726 .30403 .20611 .29436 .21611 Metetra
.768 .36 .278 r
.29436 .21611 .30403 .20611 .31591 .21465 .30544 .23672 Metetra
.572 .194 .286 r
.30544 .23672 .31591 .21465 .32832 .21749 .3177 .24408 Metetra
.416 .059 .248 r
.3177 .24408 .32832 .21749 .34114 .21571 .33073 .24181 Metetra
.249 0 .17 r
.33073 .24181 .34114 .21571 .35423 .21076 .34427 .23233 Metetra
.34427 .23233 .35423 .21076 .36752 .20318 .35816 .21701 Metetra
.35816 .21701 .36752 .20318 .38098 .19283 .37229 .19643 Metetra
.961 .943 .691 r
.37229 .19643 .38098 .19283 .39461 .17915 .38659 .17071 Metetra
.293 .593 .947 r
.38659 .17071 .39461 .17915 .40805 .16992 .39961 .1729 Metetra
.844 .411 .2 r
.39961 .1729 .40805 .16992 .42076 .1824 .41183 .1998 Metetra
.793 .414 .339 r
.41183 .1998 .42076 .1824 .43354 .20028 .4242 .23276 Metetra
.752 .403 .392 r
.4242 .23276 .43354 .20028 .44644 .22348 .43684 .2709 Metetra
.718 .387 .417 r
.43684 .2709 .44644 .22348 .45959 .25097 .44987 .31203 Metetra
.951 .764 .305 r
.44987 .31203 .45959 .25097 .47306 .28036 .4677 .13044 Metetra
.526 .314 .534 r
.4677 .13044 .47306 .28036 .48904 .13486 .48139 .12519 Metetra
.664 .741 .908 r
.48139 .12519 .48904 .13486 .50275 .12963 .49514 .11991 Metetra
.664 .741 .908 r
.49514 .11991 .50275 .12963 .51653 .12438 .50896 .11461 Metetra
.664 .741 .908 r
.50896 .11461 .51653 .12438 .53038 .1191 .52286 .10929 Metetra
.664 .741 .908 r
.52286 .10929 .53038 .1191 .54429 .1138 .53682 .10393 Metetra
.664 .741 .908 r
.53682 .10393 .54429 .1138 .55828 .10846 .55085 .09855 Metetra
.664 .741 .908 r
.55085 .09855 .55828 .10846 .57234 .1031 .56496 .09314 Metetra
.664 .741 .908 r
.56496 .09314 .57234 .1031 .58647 .09772 .57914 .0877 Metetra
.664 .741 .908 r
.57914 .0877 .58647 .09772 .60067 .0923 .59339 .08224 Metetra
.664 .741 .908 r
.59339 .08224 .60067 .0923 .61495 .08686 .60771 .07674 Metetra
.664 .741 .908 r
.60771 .07674 .61495 .08686 .62929 .08139 .62211 .07122 Metetra
.664 .741 .908 r
.62211 .07122 .62929 .08139 .64372 .0759 .63658 .06567 Metetra
.664 .741 .908 r
.63658 .06567 .64372 .0759 .65821 .07037 .65113 .06009 Metetra
.664 .741 .908 r
.65113 .06009 .65821 .07037 .67278 .06481 .66575 .05448 Metetra
.664 .741 .908 r
.66575 .05448 .67278 .06481 .68743 .05923 .68045 .04885 Metetra
.664 .741 .908 r
.68045 .04885 .68743 .05923 .70215 .05362 .69523 .04318 Metetra
.664 .741 .908 r
.69523 .04318 .70215 .05362 .71695 .04798 .71008 .03748 Metetra
.664 .741 .908 r
.05443 .27718 .06337 .2855 .07509 .28101 .06619 .27265 Metetra
.664 .741 .908 r
.06619 .27265 .07509 .28101 .08687 .27649 .078 .26809 Metetra
.664 .741 .908 r
.078 .26809 .08687 .27649 .0987 .27195 .08986 .26352 Metetra
.664 .741 .908 r
.08986 .26352 .0987 .27195 .11059 .26739 .10178 .25892 Metetra
.664 .741 .908 r
.10178 .25892 .11059 .26739 .12254 .26281 .11376 .2543 Metetra
.664 .741 .908 r
.11376 .2543 .12254 .26281 .13454 .25821 .12579 .24965 Metetra
.664 .741 .908 r
.12579 .24965 .13454 .25821 .1466 .25358 .13788 .24499 Metetra
.664 .741 .908 r
.13788 .24499 .1466 .25358 .15871 .24894 .15003 .2403 Metetra
.664 .741 .908 r
.15003 .2403 .15871 .24894 .17088 .24427 .16223 .23559 Metetra
.664 .741 .908 r
.16223 .23559 .17088 .24427 .18312 .23958 .1745 .23086 Metetra
.664 .741 .908 r
.1745 .23086 .18312 .23958 .1954 .23486 .18682 .22611 Metetra
.664 .741 .908 r
.18682 .22611 .1954 .23486 .20775 .23013 .1992 .22133 Metetra
.664 .741 .908 r
.1992 .22133 .20775 .23013 .22016 .22537 .21164 .21653 Metetra
.664 .741 .908 r
.21164 .21653 .22016 .22537 .23262 .22059 .22414 .2117 Metetra
.664 .741 .908 r
.22414 .2117 .23262 .22059 .24515 .21579 .2367 .20686 Metetra
.664 .741 .908 r
.2367 .20686 .24515 .21579 .25774 .21096 .24933 .20199 Metetra
.664 .741 .908 r
.24933 .20199 .25774 .21096 .27038 .20611 .26201 .19709 Metetra
.664 .741 .908 r
.26201 .19709 .27038 .20611 .28116 .2254 .27476 .19218 Metetra
0 0 .215 r
.27476 .19218 .28116 .2254 .29436 .21611 .28394 .23315 Metetra
.805 .442 .371 r
.28394 .23315 .29436 .21611 .30544 .23672 .294 .26834 Metetra
.617 .269 .357 r
.294 .26834 .30544 .23672 .3177 .24408 .30599 .28188 Metetra
.428 .102 .308 r
.30599 .28188 .3177 .24408 .33073 .24181 .31931 .27872 Metetra
.201 0 .212 r
.31931 .27872 .33073 .24181 .34427 .23233 .3335 .26268 Metetra
0 0 .005 r
.3335 .26268 .34427 .23233 .35816 .21701 .34826 .23648 Metetra
.764 .838 .381 r
.34826 .23648 .35816 .21701 .37229 .19643 .36334 .20191 Metetra
.992 .876 .6 r
.36334 .20191 .37229 .19643 .38659 .17071 .37859 .16029 Metetra
.728 .277 0 r
.37859 .16029 .38659 .17071 .39961 .1729 .39076 .1817 Metetra
.874 .497 .325 r
.39076 .1817 .39961 .1729 .41183 .1998 .40226 .22742 Metetra
.813 .464 .395 r
.40226 .22742 .41183 .1998 .4242 .23276 .41403 .28002 Metetra
.766 .435 .425 r
.41403 .28002 .4242 .23276 .43684 .2709 .42625 .33744 Metetra
.966 .765 .327 r
.42625 .33744 .43684 .2709 .44987 .31203 .44627 .126 Metetra
.52 .303 .524 r
.44627 .126 .44987 .31203 .4677 .13044 .45993 .12073 Metetra
.664 .741 .908 r
.45993 .12073 .4677 .13044 .48139 .12519 .47366 .11543 Metetra
.664 .741 .908 r
.47366 .11543 .48139 .12519 .49514 .11991 .48746 .11011 Metetra
.664 .741 .908 r
.48746 .11011 .49514 .11991 .50896 .11461 .50132 .10476 Metetra
.664 .741 .908 r
.50132 .10476 .50896 .11461 .52286 .10929 .51526 .09938 Metetra
.664 .741 .908 r
.51526 .09938 .52286 .10929 .53682 .10393 .52927 .09397 Metetra
.664 .741 .908 r
.52927 .09397 .53682 .10393 .55085 .09855 .54335 .08854 Metetra
.664 .741 .908 r
.54335 .08854 .55085 .09855 .56496 .09314 .55751 .08308 Metetra
.664 .741 .908 r
.55751 .08308 .56496 .09314 .57914 .0877 .57173 .07759 Metetra
.664 .741 .908 r
.57173 .07759 .57914 .0877 .59339 .08224 .58603 .07207 Metetra
.664 .741 .908 r
.58603 .07207 .59339 .08224 .60771 .07674 .60041 .06653 Metetra
.664 .741 .908 r
.60041 .06653 .60771 .07674 .62211 .07122 .61485 .06095 Metetra
.664 .741 .908 r
.61485 .06095 .62211 .07122 .63658 .06567 .62938 .05535 Metetra
.664 .741 .908 r
.62938 .05535 .63658 .06567 .65113 .06009 .64397 .04972 Metetra
.664 .741 .908 r
.64397 .04972 .65113 .06009 .66575 .05448 .65865 .04405 Metetra
.664 .741 .908 r
.65865 .04405 .66575 .05448 .68045 .04885 .6734 .03836 Metetra
.664 .741 .908 r
.6734 .03836 .68045 .04885 .69523 .04318 .68823 .03264 Metetra
.664 .741 .908 r
.68823 .03264 .69523 .04318 .71008 .03748 .70314 .02689 Metetra
.664 .741 .908 r
.04542 .2688 .05443 .27718 .06619 .27265 .05721 .26422 Metetra
.664 .741 .908 r
.05721 .26422 .06619 .27265 .078 .26809 .06905 .25963 Metetra
.664 .741 .908 r
.06905 .25963 .078 .26809 .08986 .26352 .08094 .25501 Metetra
.664 .741 .908 r
.08094 .25501 .08986 .26352 .10178 .25892 .09289 .25037 Metetra
.664 .741 .908 r
.09289 .25037 .10178 .25892 .11376 .2543 .1049 .24571 Metetra
.664 .741 .908 r
.1049 .24571 .11376 .2543 .12579 .24965 .11697 .24102 Metetra
.664 .741 .908 r
.11697 .24102 .12579 .24965 .13788 .24499 .12909 .23632 Metetra
.664 .741 .908 r
.12909 .23632 .13788 .24499 .15003 .2403 .14127 .23159 Metetra
.664 .741 .908 r
.14127 .23159 .15003 .2403 .16223 .23559 .15351 .22684 Metetra
.664 .741 .908 r
.15351 .22684 .16223 .23559 .1745 .23086 .1658 .22206 Metetra
.664 .741 .908 r
.1658 .22206 .1745 .23086 .18682 .22611 .17816 .21727 Metetra
.664 .741 .908 r
.17816 .21727 .18682 .22611 .1992 .22133 .19057 .21245 Metetra
.664 .741 .908 r
.19057 .21245 .1992 .22133 .21164 .21653 .20305 .2076 Metetra
.664 .741 .908 r
.20305 .2076 .21164 .21653 .22414 .2117 .21559 .20274 Metetra
.664 .741 .908 r
.21559 .20274 .22414 .2117 .2367 .20686 .22818 .19785 Metetra
.664 .741 .908 r
.22818 .19785 .2367 .20686 .24933 .20199 .24084 .19293 Metetra
.664 .741 .908 r
.24084 .19293 .24933 .20199 .26201 .19709 .25356 .188 Metetra
.664 .741 .908 r
.25356 .188 .26201 .19709 .27476 .19218 .26634 .18303 Metetra
.664 .741 .908 r
.26634 .18303 .27476 .19218 .28394 .23315 .27919 .17805 Metetra
.556 .381 .6 r
.27919 .17805 .28394 .23315 .294 .26834 .2921 .17304 Metetra
.817 .637 .084 r
.2921 .17304 .294 .26834 .30599 .28188 .293 .33216 Metetra
.432 .125 .342 r
.293 .33216 .30599 .28188 .31931 .27872 .30668 .32783 Metetra
.138 0 .226 r
.30668 .32783 .31931 .27872 .3335 .26268 .32178 .30282 Metetra
.32178 .30282 .3335 .26268 .34826 .23648 .33774 .26194 Metetra
.877 .845 .383 r
.33774 .26194 .34826 .23648 .36334 .20191 .35414 .20902 Metetra
.997 .827 .548 r
.35414 .20902 .36334 .20191 .37859 .16029 .37065 .14719 Metetra
.93 .562 .158 r
.37065 .14719 .37859 .16029 .39076 .1817 .38139 .19765 Metetra
.884 .535 .381 r
.38139 .19765 .39076 .1817 .40226 .22742 .39185 .26753 Metetra
.983 .791 .385 r
.39185 .26753 .40226 .22742 .41403 .28002 .41118 .12681 Metetra
.522 .308 .53 r
.41118 .12681 .41403 .28002 .42625 .33744 .42475 .12154 Metetra
.516 .295 .517 r
.42475 .12154 .42625 .33744 .44627 .126 .43838 .11625 Metetra
.664 .741 .908 r
.43838 .11625 .44627 .126 .45993 .12073 .45209 .11093 Metetra
.664 .741 .908 r
.45209 .11093 .45993 .12073 .47366 .11543 .46586 .10558 Metetra
.664 .741 .908 r
.46586 .10558 .47366 .11543 .48746 .11011 .4797 .10021 Metetra
.664 .741 .908 r
.4797 .10021 .48746 .11011 .50132 .10476 .49362 .09481 Metetra
.664 .741 .908 r
.49362 .09481 .50132 .10476 .51526 .09938 .5076 .08938 Metetra
.664 .741 .908 r
.5076 .08938 .51526 .09938 .52927 .09397 .52166 .08392 Metetra
.664 .741 .908 r
.52166 .08392 .52927 .09397 .54335 .08854 .53578 .07844 Metetra
.664 .741 .908 r
.53578 .07844 .54335 .08854 .55751 .08308 .54998 .07292 Metetra
.664 .741 .908 r
.54998 .07292 .55751 .08308 .57173 .07759 .56426 .06738 Metetra
.664 .741 .908 r
.56426 .06738 .57173 .07759 .58603 .07207 .57861 .06181 Metetra
.664 .741 .908 r
.57861 .06181 .58603 .07207 .60041 .06653 .59303 .05621 Metetra
.664 .741 .908 r
.59303 .05621 .60041 .06653 .61485 .06095 .60753 .05058 Metetra
.664 .741 .908 r
.60753 .05058 .61485 .06095 .62938 .05535 .6221 .04493 Metetra
.664 .741 .908 r
.6221 .04493 .62938 .05535 .64397 .04972 .63675 .03924 Metetra
.664 .741 .908 r
.63675 .03924 .64397 .04972 .65865 .04405 .65148 .03352 Metetra
.664 .741 .908 r
.65148 .03352 .65865 .04405 .6734 .03836 .66628 .02778 Metetra
.664 .741 .908 r
.66628 .02778 .6734 .03836 .68823 .03264 .68117 .022 Metetra
.664 .741 .908 r
.68117 .022 .68823 .03264 .70314 .02689 .69613 .01619 Metetra
.664 .741 .908 r
.03634 .26033 .04542 .2688 .05721 .26422 .04815 .25572 Metetra
.664 .741 .908 r
.04815 .25572 .05721 .26422 .06905 .25963 .06002 .25108 Metetra
.664 .741 .908 r
.06002 .25108 .06905 .25963 .08094 .25501 .07194 .24643 Metetra
.664 .741 .908 r
.07194 .24643 .08094 .25501 .09289 .25037 .08393 .24175 Metetra
.664 .741 .908 r
.08393 .24175 .09289 .25037 .1049 .24571 .09597 .23704 Metetra
.664 .741 .908 r
.09597 .23704 .1049 .24571 .11697 .24102 .10806 .23232 Metetra
.664 .741 .908 r
.10806 .23232 .11697 .24102 .12909 .23632 .12022 .22757 Metetra
.664 .741 .908 r
.12022 .22757 .12909 .23632 .14127 .23159 .13243 .2228 Metetra
.664 .741 .908 r
.13243 .2228 .14127 .23159 .15351 .22684 .1447 .21801 Metetra
.664 .741 .908 r
.1447 .21801 .15351 .22684 .1658 .22206 .15703 .21319 Metetra
.664 .741 .908 r
.15703 .21319 .1658 .22206 .17816 .21727 .16942 .20835 Metetra
.664 .741 .908 r
.16942 .20835 .17816 .21727 .19057 .21245 .18187 .20349 Metetra
.664 .741 .908 r
.18187 .20349 .19057 .21245 .20305 .2076 .19438 .1986 Metetra
.664 .741 .908 r
.19438 .1986 .20305 .2076 .21559 .20274 .20695 .19369 Metetra
.664 .741 .908 r
.20695 .19369 .21559 .20274 .22818 .19785 .21959 .18876 Metetra
.664 .741 .908 r
.21959 .18876 .22818 .19785 .24084 .19293 .23228 .1838 Metetra
.664 .741 .908 r
.23228 .1838 .24084 .19293 .25356 .188 .24504 .17882 Metetra
.664 .741 .908 r
.24504 .17882 .25356 .188 .26634 .18303 .25786 .17381 Metetra
.664 .741 .908 r
.25786 .17381 .26634 .18303 .27919 .17805 .27074 .16878 Metetra
.664 .741 .908 r
.27074 .16878 .27919 .17805 .2921 .17304 .28368 .16372 Metetra
.664 .741 .908 r
.28368 .16372 .2921 .17304 .293 .33216 .29669 .15864 Metetra
.517 .299 .522 r
.29669 .15864 .293 .33216 .30668 .32783 .30977 .15353 Metetra
.517 .299 .522 r
.30977 .15353 .30668 .32783 .32178 .30282 .32291 .1484 Metetra
.52 .304 .527 r
.32291 .1484 .32178 .30282 .33774 .26194 .33611 .14324 Metetra
.526 .318 .54 r
.33611 .14324 .33774 .26194 .35414 .20902 .34938 .13806 Metetra
.543 .355 .576 r
.34938 .13806 .35414 .20902 .37065 .14719 .36272 .13285 Metetra
.646 .639 .829 r
.36272 .13285 .37065 .14719 .38139 .19765 .37612 .12761 Metetra
.544 .357 .577 r
.37612 .12761 .38139 .19765 .39185 .26753 .3896 .12235 Metetra
.521 .307 .53 r
.3896 .12235 .39185 .26753 .41118 .12681 .40314 .11706 Metetra
.664 .741 .908 r
.40314 .11706 .41118 .12681 .42475 .12154 .41674 .11175 Metetra
.664 .741 .908 r
.41674 .11175 .42475 .12154 .43838 .11625 .43042 .10641 Metetra
.664 .741 .908 r
.43042 .10641 .43838 .11625 .45209 .11093 .44417 .10104 Metetra
.664 .741 .908 r
.44417 .10104 .45209 .11093 .46586 .10558 .45799 .09564 Metetra
.664 .741 .908 r
.45799 .09564 .46586 .10558 .4797 .10021 .47187 .09021 Metetra
.664 .741 .908 r
.47187 .09021 .4797 .10021 .49362 .09481 .48583 .08476 Metetra
.664 .741 .908 r
.48583 .08476 .49362 .09481 .5076 .08938 .49986 .07928 Metetra
.664 .741 .908 r
.49986 .07928 .5076 .08938 .52166 .08392 .51397 .07377 Metetra
.664 .741 .908 r
.51397 .07377 .52166 .08392 .53578 .07844 .52814 .06824 Metetra
.664 .741 .908 r
.52814 .06824 .53578 .07844 .54998 .07292 .54239 .06267 Metetra
.664 .741 .908 r
.54239 .06267 .54998 .07292 .56426 .06738 .55671 .05708 Metetra
.664 .741 .908 r
.55671 .05708 .56426 .06738 .57861 .06181 .57111 .05145 Metetra
.664 .741 .908 r
.57111 .05145 .57861 .06181 .59303 .05621 .58558 .0458 Metetra
.664 .741 .908 r
.58558 .0458 .59303 .05621 .60753 .05058 .60013 .04012 Metetra
.664 .741 .908 r
.60013 .04012 .60753 .05058 .6221 .04493 .61476 .0344 Metetra
.664 .741 .908 r
.61476 .0344 .6221 .04493 .63675 .03924 .62946 .02866 Metetra
.664 .741 .908 r
.62946 .02866 .63675 .03924 .65148 .03352 .64424 .02289 Metetra
.664 .741 .908 r
.64424 .02289 .65148 .03352 .66628 .02778 .6591 .01709 Metetra
.664 .741 .908 r
.6591 .01709 .66628 .02778 .68117 .022 .67403 .01125 Metetra
.664 .741 .908 r
.67403 .01125 .68117 .022 .69613 .01619 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00o?ooool4
o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03
o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oo
oooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Kooooo`00o?ooool00omEEEGoIVIVo`000009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo
410@05_ooooo003oooooo`Wooooo00Go0000ooooooooooooooooo`00001Kooooo`00ooooool9oooo
o`05o`000?ooooooooooooooool00000Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo
410@05_ooooo003oooooo`Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Kooooo`00ooooool3oooo
o`;o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^05_ooooo003oooooo`?o000000?oooooo`00
0?ooool0Hoooool00?gooooo0_l00002ooooo`Co0000Hoooool00?[ooooo1ol00002ojVmj003o`00
0?oooooo000006;ooooo003gooooo`?o000000Goooooo`000?l0003oZKgXo`000004ojVmj0?o0000
H_ooool00?Gooooo0_l000001?oooooo0000o`000?l00004ojVmj004o`000?nY_NSoZKgXojVmj0Co
0000HOooool00?;ooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP2o`00063ooooo003`ooooo`;o00000_ooool2o`0000GoZKgX00?o0000ojVm
j?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00;oZKgX00?o0000ooooooooool0G_ooool00>go
oooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00?o0000ojVmj?l000000_l00000
1?nY_NSo0000ojVmj?l00003ojVmj0;o0000Goooool00>_ooooo0_l00002ooooo`;o00001OnY_NP0
0ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o
000005kooooo002cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Oooooo`?o000000Koooooo`000?l0003o0000ojVmj?l00005ojVmj003
o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000CoZKgX00?o0000oooooooo
ool0G?ooool00;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Kooooo`?o00000_ooool2o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?l000001?nY_NP2o`0005gooooo002cooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Hooooo`;o00000oooool2o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
00GoZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0005cooooo002cooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0Fooooo`?o00000oooool2o`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000005cooooo002cooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l000000ooooooo0000
ooooo`03o`000003ojVmj?l0003oZKgX00CoZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o00001OnY_NP2o`0005_ooooo002cooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Dooooo`?o00000_ooool3o`0000Go
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj004o`000?nY_NSo0000o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`000003ojVmj?l0003o000000GoZKgX0ol0001Joooo
o`00/oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`00
00;ooooo0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX
00;oZKgX0_l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00000onY_NP01?l0003oZKgXo`00
0?nY_NP3o`000003ojVmj?l0003o000005[ooooo002cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000kooooo0ol000001_oooooo0000o`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP2o`0000CoZKgX00Go0000ojVmj?nY_NSo0000ojVmj002o`0000GoZKgX0_l0001Iooooo`00dooo
ool3o`0000;ooooo0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY
_NSoZKgXojVmj0?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX
00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o0000FOooool00=7ooooo
0_l00002ooooo`?o000000?oZKgXo`000?nY_NP01?nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00005ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0ol00004ojVmj003o`000?nY_NSoZKgX00Co0000F?ooool00<kooooo0ol0
0002ooooo`;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Ko0000ojVmj?l0003o
0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003o000000CoZKgX0ol00002ojVmj003o`000?oooooo0000
05Oooooo003<ooooo`;o00000oooool2o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;o
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`00
0?nY_NP00onY_NP2o`0005Oooooo0039ooooo`?o00000_ooool3o`0000GoZKgX00Ko0000ojVmj?l0
003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP0
1?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY
_NSoZKgX00?oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o0000E_ooool00<Oooooo0_l0
00000ooooooo0000o`000002o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP00ol0003oZKgXo`000004o`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP2o`0005Gooooo0034ooooo`?o000000Goooooo`000?l0003oZKgXo`000005
ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01?l0003oZKgXo`000?l0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l0
0004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj0;o00000onY_NP3o`0000GoZKgX00?o
0000ooooooooool0Doooool00<;ooooo0_l00002ooooo`;o00001?nY_NP00ol0003oZKgXojVmj002
ojVmj0;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01_l0003o
ZKgXo`000?l0003oZKgXo`0000CoZKgX1Ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol0001C
ooooo`00_oooool3o`000006ooooool0003o0000o`000?nY_NSo00001OnY_NP01?l0003oZKgXo`00
0?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX
0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o
00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00?o0000ojVmj?l0
00000_l000000onY_NSo0000o`00001Cooooo`00_?ooool3o`000004ooooool0003o0000o`0000Go
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj0Co00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o00000_nY_NP01?l0003o
ZKgXojVmj?l00004ojVmj0;o00001OnY_NP00ol0003oooooooooo`1Aooooo`00^_ooool2o`0000?o
oooo0_l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000ojVm
j?l0003o00000_nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSo000000;o000000?oZKgX
o`000?nY_NP01?nY_NP2o`0005;ooooo002gooooo`?o00000_ooool3o`0000GoZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;o
ZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj0;o000000CoZKgXo`000?l0
003o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o0000057ooooo002eooooo`;o
000000?oooooo`000?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003
o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0
003oZKgXo`000002o`000003ojVmj?l0003oZKgX00CoZKgX00Co0000ojVmj?l0003o00000_nY_NP0
0ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP3
o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000GoZKgX00?o0000ooooooooool0Coooool0
08_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Rooooo`?o000000Goooooo`000?l0003oZKgXo`00
0005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01?l0003oZKgXo`00
0?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o0000
1OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj004ojVmj0;o0000D?ooool008_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Pooooo`;o00000_ooool2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX
00Co0000ojVmj?nY_NSoZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP0
1?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?l000000_l0
00000onY_NSo0000ojVmj004ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0;o00001?nY
_NP2o`0000;oZKgX0ol00005ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?l00000Cooo
ool008_ooooo00Go410@oooooooooooooooooa0@400Mooooo`?o00000_ooool2o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
1?l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0Co0000
0onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oooooooooo`1=ooooo`00Rooo
ool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ooooo`;o00001OnY_NP00ol0003oZKgX
ojVmj003o`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj003
o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003
ojVmj?l0003oZKgX00CoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003
o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00Co
ZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj0;o0000C_ooool008_ooooo00Go0000oooo
ooooooooooooo`00000Hooooo`?o00000_ooool3o`000003ojVmj?l0003oZKgX00CoZKgX0ol00002
ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP0
0ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004
ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP2o`0000;oZKgX00Co0000ojVmj?nY_NSo00001?nY_NP2o`0000CoZKgX00Co0000ojVmj?nY
_NSoZKgX1?l0001=ooooo`00Roooool01Ol@413ooooooooooooooooo410@01Gooooo0ol00002oooo
o`?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVm
j?l000000_l000000onY_NSo0000ojVmj004ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVm
j0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP01?l0003oZKgXojVmj?nY_NP3
o`0000CoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj006o`000?nY_NSo
0000o`000?nY_NSo00000_nY_NP01Ol0003oZKgXojVmj?l0003oZKgX00?o000000?oZKgXo`000?nY
_NP00onY_NP4o`0000;oZKgX0_l0001=ooooo`00Roooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo0_l00002ooooo`?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003o
ZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj004ojVmj006
o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY
_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003o`000?nY
_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY_NSo0000ojVmj0?o00001OnY_NP01_l0003oZKgX
o`000?l0003oZKgXo`0000GoZKgX0_l0001<ooooo`00Roooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
013ooooo0ol00002ooooo`;o000000?oQDj7o`000?nY_NP01?nY_NP01?l0003oZKgXo`000?l00002
ohA;Q003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005
ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001OnY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`00
00;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l0001;
ooooo`00W_ooool2o`0000?ooooo0_l00004ohE>Q`04o`000?nY_NSoZKgXojVmj0?o00001On4Bh@0
1_l0003oZKgXo`000?l0003oQDf6o`0000GoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003o
ZKgXojVmj002ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;o
ZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj005o`000?nY_NSo0000o`000?nY_NP00_l00004ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;oZKgX0_l0001;oooo
o`00Voooool3o`0000;ooooo0ol000000on;Fi?o0000ohE>Q`04ohE>Q`?o00000_n5CXL00ol0003o
Q4^4ohA;Q004ohA;Q003o`000?n5CHKoQDf600;oQDf600?o0000ojVmj?nY_NP00_nY_NP2o`0000Go
ZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVm
j?l000000_l000000onY_NSo0000ojVmj004ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVm
j0;o00001?nY_NP2o`0000;oZKgX0ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP2o`0004[ooooo002Hooooo`?o00000_ooool3o`0000CoRe^C00?o0000ohE>Qon5CXL00on5CXL0
0ol0003oQDj7ohE>Q`02ohE>Q`03o`000?n4BhCoQ4^400CoQ4^400?o0000ohE=Q_n5CHH00_n5CHH0
0ol0003oZKgXo`000002o`000003ohI@R?l0003oZKgX00CoZKgX0ol00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003
o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo
000000;o000000?oZKgXo`000?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2
o`0000CoZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0004Wooooo002Fooooo`;o00000_ooool3o`00
00;oYJ?D00?o0000oh]KTon;Fi<00_n;Fi<00ol0003oQDj7ohE>Q`03ohE>Q`03o`000?n5CXOoQDj7
00;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0003oQDf6ohE=QP03ohE=QP03o`000?n6D8SoQU28
00?oQU2800?o0000ojVmj?l000000_l000000on8E8co0000ojVmj003ojVmj003o`000?nY_NSo0000
00;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`00
00?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVm
j005o`000?nY_NSo0000o`000?nY_NP00_l00004ojVmj003o`000?nY_NSo000000;o000000?oZKgX
o`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000004Wooooo002Coooo
o`?o00000_ooool2o`000003oh]JTol0003oYJ?D00;oYJ?D00?o0000oh]KTon;Fi<00_n;Fi<00ol0
003oQDj7ohE>Q`03ohE>Q`03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0
003oQDf6ohE=QP03ohE=QP03o`000?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`00on8E8`00ol0
003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP01?nY_NP01_l0003oZKgXo`000?l0003o
ZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00003ojVmj003o`000?nY
_NSo000000;oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0004Sooooo002A
ooooo`;o00000_ooool3o`0000CoReZC00Co0000ojFSe?nUXmCo00001?n;Fi<00ol0003oQDj7ohE>
Q`03ohE>Q`03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4Bh@01?n4Bh@00ol0003oQDf6ohE=
QP03ohE=QP03o`000?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`01?n8E8`2o`0000?oReVA00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj004o`000?nY
_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX
00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj002ojVmj003o`000?nY_NSo000000;o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0?o0000
Aoooool008kooooo0ol00002ooooo`Go00001?n;FY<01?l0003oYJ?DojFSe?l00004oh]KT`03o`00
0?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4BhCoQ4^400CoQ4^400?o0000ohE=Q_n5CHH0
0on5CHH00ol0003oQU28ohI@R004ohI@R003o`000?n8E8coR5B<00CoR5B<00?o0000oh]ITOn;FI40
0on;FI401?l0003oZKgXo`000?l00002ohiOUP03o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003
o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj003
o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?o
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?l00000Aoooool008cooooo0_l00002ooooo`?o00001?n6DHX00ol0003oReZC
oh]JT`02oh]JT`04o`000?nUXmCoYJ?Do`0000CoRe^C00?o0000ohE>Qon5CXL00_n5CXL2o`0000Co
QDj700?o0000ohA;Q?n4Bh@00on4Bh@2o`0000GoQDf600?o0000ohI@R?n6D8P01?n6D8P00ol0003o
R5B<ohQDS004ohQDS003o`000?n;FI7oReVA00CoReVA00?o0000ohiOU_n>GiH00on>GiH01_l0003o
ZKgXo`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`00
0003ojVmj?l0003oZKgX00;oZKgX00Co0000ojVmj?nY_NSoZKgX0_l00005ojVmj003o`000?nY_NSo
ZKgX00?o00001OnY_NP2o`0004Kooooo0029ooooo`?o000000Coooooo`000?l0003o00000_n5CHH0
0ol0003oQU6:ohIARP02ohIARP03o`000?n;FY?oReZC00?oReZC00Co0000ojFSe?nUXmCo00000on;
Fi<00ol0003oQDj7ohE>Q`02ohE>Q`;o00001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001On5
CHH00ol0003oQU28ohI@R004ohI@R003o`000?n8E8coR5B<00CoR5B<00?o0000oh]ITOn;FI401?n;
FI400ol0003oSUnFohiOUP04ohiOUP03o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?nY_NP00_nY
_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj003o`000?nY_NSo000000;o0000
00?oZKgXo`000?nY_NP01?nY_NP02?l0003oZKgXo`000?l0003oZKgXo`000?nY_NSo00000onY_NP0
1_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00015ooooo`00Q_ooool3o`0000;ooooo0_l000000on4C8Go0000ohE=QP02ohE=QP03o`000?n6
DH[oQU6:00;oQU6:00?o0000oh]JTon;FY<00on;FY<01?l0003oYJ?DojFSe?l00003oh]KT`03o`00
0?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4BhCoQ4^400?oQ4^40_l00005ohE=QP03o`00
0?n6D8SoQU2800CoQU2800?o0000ohQDS?n8E8`01?n8E8`00ol0003oReVAoh]IT@04oh]IT@03o`00
0?n>GiKoSUnF00CoSUnF00?o0000ojVmj?nY_NP00_nY_NP00ol0003oZKgXo`000002o`000003ojVm
j?l0003oZKgX00?oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00005ojVmj004o`00
0?nY_NSoZKgXojVmj0?o00001?nY_NP2o`0000;oZKgX0ol00004ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003o000004Go
oooo0024ooooo`;o00000oooool2o`0000?oQ4b500Go0000ohE=Q_n5CHKoQDf6o`000004ohIARP03
o`000?n;FY?oReZC00?oReZC00Co0000ojFSe?nUXmCo00000on;Fi<00ol0003oQDj7ohE>Q`02ohE>
Q`;o00001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001?n5CHH2o`0000GoQU280_l00005ohQD
S0;o00001_n;FI400ol0003oSUnFohiOUP04ohiOUP;o00000_nY_NP3o`0000GoZKgX00Co0000ojVm
j?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP4o`0000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj0;o0000A?oo
ool0087ooooo0ol00003ooooo`;o000000?oQ4b5o`000?n4C8D00_n4C8D01Ol0003oQDf6ohE=Q_n5
CHKo000000CoQU6:00?o0000oh]JTon;FY<00_n;FY<01Ol0003oom><o`000?nUXmCo000000?oRe^C
00?o0000ohE>Qon5CXL00_n5CXL2o`0000CoQDj700?o0000ohA;Q?n4Bh@00on4Bh@2o`0000CoQDf6
0_l00005ohI@R0;o00001On8E8`2o`0000GoReVA0_l00005ohiOUP03o`000?oZdE[oj]5J00;o0000
0onGMJ/00ol0003oZKgXojVmj002ojVmj0;o00001OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX
00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP01_l0003oZKgXo`000?l0003oZKgXo`0000GoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?o
ZKgX0ol00013ooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`0000?ooooo0ol00003ohA<Q@05o`000?n4C8GoQ4b5
ohA<QOl000000on5CHH00ol0003oQU6:ohIARP02ohIARP03o`000?n;FY?oReZC00;oReZC00Go0000
oooCS?l0003oYJ?Do`000003oh]KT`03o`000?n5CXOoQDj700;oQDj70_l00004ohE>Q`03o`000?n4
BhCoQ4^400?oQ4^40_l00004ohE=QP;o00001On6D8P2o`0000GoR5B<0_l00005oh]IT@;o00001On>
GiH01?l0003oj]5Jon[AF_l00005oiMeZ`06o`000?nY_NSo0000o`000?nGM:Wo00001OnY_NP3o`00
00;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003
ojVmj0;o00000onY_NP3o`0000CoZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003
ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?l00000@oooool004Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o00000_ooool3
o`0000;oZKgX00Go0000ohA<QOn4C8GoQ4b5o`000003ohA<Q@05o`000?n5CHKoQDf6ohE=Q_l00000
1?n6DHX00ol0003oReZCoh]JT`02oh]JT`05o`000?oodhco0000ojFSe?l000000on;Fi<01ol0003o
QDj7ohE>Qon5CXOo0000oo_:H_l000001?n5CXL00ol0003oQ4^4ohA;Q003ohA;Q0;o00001?n5CHH2
o`0000GoQU280_l00005ohQDS003o`000?oYa4Oo000000CoReVA00?o0000onK8C?l000001?n>GiH0
1?l0003oj]5Jo`000?l00006oiMeZ`03o`000?nGM:WoUgBY00;oUgBY00?o0000ojVmj?l000000_l0
00000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY
_NP4o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1Ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX
0_l00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0004;ooooo0011ooooo`Ko00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0000?ooooo
0_l000000onY_NSo0000ojVmj002ojVmj005o`000?n4C8GoQ4b5ohA<QOl000000on4C8D01Ol0003o
QDf6ohE=Q_n5CHKo000000CoQU6:00?o0000oh]JTon;FY<00_n;FY<01Ol0003oom><o`000?nUXmCo
000000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;Q?n4Bh@0
0on4Bh@2o`0000CoQDf60_l00005ohI@R003o`000?o^`dWo000000CoR5B<00?o0000onW4Aol00000
1?n;FI400ol0003oi/Q<o`000004ohiOUP04o`000?oZdE[o0000o`0000KoUgF[00?o0000oiMdZOnG
M:T00onGM:T00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP01_l0003o
ZKgXo`000?l0003oZKgXo`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`00
0?nY_NSo0000o`000?nY_NSo00001OnY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP2o`00
04;ooooo0019ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Goooo
o`?o00000_ooool3o`0000CoZKgX00Co0000ojVmj?nY_NSo00000on4C8D01Ol0003oQ4b5ohA<QOn4
C8Go000000?oQDf600?o0000ohIAR_n6DHX00_n6DHX01Ol0003oReZCoh]JTon;FY?o000000?oom><
0_l00003oh]KT`07o`000?n5CXOoQDj7ohE>Qol0003onlYRo`000004ohE>Q`03o`000?n4BhCoQ4^4
00?oQ4^40_l00004ohE=QP;o00001On6D8P00ol0003ok/=9o`000004ohQDS003o`000?oYa4Oo0000
00CoReVA00?o0000onK8C?l000000on>GiH01_l0003oj]5Jon[AF_l0003oe=i/o`0000CoUgF[0_l0
0005oiMdZ@03o`000?nY_NSoZKgX00?oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l0
0004ojVmj004o`000?nY_NSoZKgXojVmj0?o000000GoZKgXo`000?nY_NSoZKgXo`000003ojVmj0?o
00001?nY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l0
00000_l000000onY_NSo0000o`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`00BOooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`?o000000?oooooo`000?l000000_l0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ohA<Q@02ohA<Q@05o`000?n4
C8GoQ4b5ohA<QOl000000on5CHH00ol0003oQU6:ohIARP02ohIARP05o`000?n;FY?oReZCoh]JTol0
00000ooodh`2o`0000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000
ohA;Q?n4Bh@00on4Bh@2o`0000CoQDf600?o0000oo?3C_l000001?n6D8P00ol0003ok/=9o`000004
ohQDS003o`000?oYa4Oo000000?oReVA00Co0000onK8C?oVb4co00000on>GiH00ol0003oj]5Jo`00
0002omCNK003o`000?nGMJ_oUgF[00;oUgF[00?o0000on_^Sol000000onGM:T01?l0003on>bMo`00
0?nY_NP3o`000003oi]o]?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000
ojVmj003ojVmj0Co00000_nY_NP00ol0003oZKgXo`000002ojVmj0Co00000onY_NP00ol0003oZKgX
ojVmj003o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj0;o00001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02;ooooo0019ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Eooooo`;o00000_ooool2o`0000;o
ZKgX00?o0000ojVmj?nY_NP00_nY_NP02?l0003oZKgXo`000?l0003oSV6Io`000?nY_NSo00000on4
C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX01?l0003oReZC
oh]JTol00002oooCS0?o00000on;Fi<01ol0003oQDj7ohE>Qon5CXOo0000oo_:H_l000001?n5CXL0
0ol0003oQ4^4ohA;Q002ohA;Q003o`000?og`e?o000000CoQDf600?o0000oo?3C_l000001?n6D8P0
0ol0003ok/=9o`000003ohQDS004o`000?oYa4OojLA7o`0000?oReVA00Co0000onK8C?oVb4co0000
0on>GiH00ol0003oj]5Jo`000002omCNK005o`000?nGMJ_oUgF[oiMeZol000000_o[kXl01Ol0003o
UgBYoiMdZOnGM:Wo000000;on>bM00?o0000oi]o]?nKOk@00onKOk@00ol0003oZKgXojVmj003o`00
00GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo
00001OnY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000;oZKgX00?o0000ojVmj?nY
_NP00onY_NP2o`0000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
027ooooo0019ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Boooo
o`?o00000_ooool2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00003ohiQV@03o`000?nY_NSo0000
00?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:00Co0000
oh]JTon;FY?o00000_oodh`3o`0000?oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000Co
QDj700?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=Co`000004ohE=QP03o`000?oc`dko000000Co
QU2800?o0000onk3BOl000000on8E8`01?l0003ojLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<
o`0000?oSUnF00?o0000on[AF_l000000_oDgV`01?l0003oUgF[oiMeZol00003on_^S`04o`000?nG
M:WoUgBYo`0000?on>bM00?o0000oi]o]?nKOk@01?nKOk@2o`0000?oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP2o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l00003ojVmj003o`000?nY_NSo000000;o
000000?oZKgXo`000?nY_NP00onY_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?o
ZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000o`000006ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0Rooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000?ooooo`;o00000oooool2o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00;oZKgX00Oo0000ohiQVOn>HIWoSV6Io`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5
o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:00?o0000oh]JTol000000_oodh`00ol0003ooN2I
oogPV@02o`0000;oRe^C00Oo0000ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;
Q?n4Bh@00_n4Bh@00ol0003oml=Co`000004ohE=QP03o`000?oc`dko000000?oQU2800Co0000onk3
BOo^`dWo00000on8E8`01?l0003ojLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<o`0000;oSUnF
00?o0000on[AF_l000000_l000001OoDgVco0000oiMeZonGMJ_o000000?ojnj?00Co0000oiMdZOnG
M:Wo00000_ohk9d00ol0003ojOW8o`000005oi]o]003o`000?nY_NSoZKgX00?oZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00004ojVmj0Co00000_nY_NP2o`0000?oZKgX0_l00005ojVmj003o`000?nY
_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX0_l00005ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo001Zooooo`?o0000
0_ooool4o`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgXojVmj?l00003ohiQ
V@03o`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000003ohE=QP03o`000?n6DH[o
QU6:00?oQU6:00?o0000oh]JTol000000_oodh`00ol0003ooN2IoogPV@02o`0000;oRe^C00Oo0000
ohE>Qon5CXOoQDj7o`000?okbV;o000000CoQDj700?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=C
o`000004ohE=QP03o`000?oc`dko000000?oQU2800Co0000onk3BOo^`dWo00000on8E8`01?l0003o
jLA7onW4Aol00003oh]IT@04o`000?oVb4coi/Q<o`0000;oSUnF00Co0000on[AF_l0003o[9>l0_l0
00000ooDgVco0000o`000003o`000007on_^Sol0003oUgBYoiMdZOl0003on>bMo`000002onWib003
o`000?nKOkCoVgnd00;oVgnd00?o0000oo?c^?l000000onY_NP3o`0000CoZKgX00Co0000ojVmj?l0
003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY
_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00onY
_NP2o`0000Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02Gooooo
001Xooooo`;o00000_ooool3o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY
_NSo000000?oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf6
00?o0000ohIAR_n6DHX00on6DHX00ol0003oReZCo`000002oooCS003o`000?omh9WooN2I00;o0000
0_n;Fi<01?l0003oQDj7ohE>Qol00002oo_:HP03o`000?n5CXOoQDj700;oQDj700?o0000ohA;Q?n4
Bh@00_n4Bh@00ol0003oml=Co`000003ohE=QP04o`000?oc`dkoll=>o`0000?oQU2800Co0000onk3
BOo^`dWo00000on8E8`01?l0003ojLA7onW4Aol00002oh]IT@05o`000?oVb4coi/Q<onK8C?l00000
0_n>GiH00ol0003oj]5Jo`000002ojbC_0Co00000onTUlP01_l0003ojnj?o`000?l0003on>bMo`00
00?ojOW800?o0000oi]o]?nKOk@00_nKOk@00ol0003olo>hoo?c^003o`0000?oYIk?00?o0000ojVm
j?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXo`000002o`00
0003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVm
j003o`000?nY_NSo000000;o000000?oZKgXo`000?l000001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool09Oooool006Gooooo0ol00002ooooo`;o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00000on>HIT00ol0
003oZKgXo`000003ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000000on5CHH00ol0003oQU6:ohIARP03
ohIARP05o`000?n;FY?o0000oooCS?l000000_omh9T3o`0000;oRe^C00Co0000ohE>Qon5CXOo0000
0_okbV800ol0003oQDj7ohE>Q`02ohE>Q`03o`000?n4BhCoQ4^400;oQ4^400?o0000ooO3Dol00000
0on5CHH01?l0003oll=>oo?3C_l00003ohI@R004o`000?o^`dWok/=9o`0000?oR5B<00Co0000onW4
AooYa4Oo00000_n;FI401Ol0003oi/Q<onK8C?oVb4co000000;oSUnF0_l00003ojbC_003o`000?nT
UlSo000000CoY9O82?l00002onWib004o`000?nKOkCoVgndo`0000;olo>h0_l00005ojFNc`?o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj0?o000000?oZKgXo`000?l000001?nY_NP2o`0000GoZKgX
00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP2o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00009?ooool006?ooooo0_l00002ooooo`?o0000
1OnY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00So0000ojVmj?l0
003o0000ojVmj?l0003oZKgXo`0000;oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX2o`0000;oom><00?o0000oogPVOomh9T0
0ol00002oh]KT`04o`000?n5CXOoQDj7o`0000;onlYR00?o0000ohE>Qon5CXL00_n5CXL00ol0003o
Q4^4ohA;Q002ohA;Q003o`000?og`e?o000000?oQDf600Co0000oo?3C_oc`dko00000on6D8P01?l0
003ok/=9onk3BOl00003ohQDS004o`000?oYa4OojLA7o`0000;oReVA00Wo0000onK8C?oVb4coi/Q<
o`000?n>GiKo0000on[AF_l000000_n/Tk`00ol0003od[Jmo`000004ojBGb004o`000?oH_l3o0000
o`0000;oGWOD0_l000001_l0C<Ko0000o`000?l0003oVgndo`0000;olo>h00Co0000om_cgooKlmoo
00000onUW/l00ol0003ocmSPo`000004ojVmj003o`000?nY_NSo000000;o000000SoZKgXo`000?nY
_NSoZKgXo`000?nY_NSo0000ojVmj0;o000000?oZKgXo`000?nY_NP01?nY_NP3o`0000;oZKgX00?o
0000ojVmj?nY_NP00onY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSoZKgX0ol0000looooo`00H?oo
ool7o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000GoZKgX00?o0000ojVmj?nY_NP00ol0
0003ojVmj003o`000?nY_NSo000000;oSV6I00?o0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX2o`0000;oom><1?l000001OnKXm[o0000
oh]KTon;Fi?o000000;oQDj700Co0000oo_:H_okbV;o00001?n5CXL00ol0003oQ4^4ohA;Q002ohA;
Q003o`000?og`e?o000000?oQDf600Co0000oo?3C_oc`dko00000on6D8P01?l0003ok/=9onk3BOl0
0002ohQDS005o`000?oYa4OojLA7onW4Aol000000_n;FI42o`0000?oi/Q<0ol00002ojbC_004o`00
0?oB][god[Jmo`0000?oY9O800Co0000omRo`?oH_l3o00000_mNMm@01?l0003oaKoEolFoeOl00002
o`1<aP05o`000?nKOkCo0000oo?c^?l000000ooKlml01?l0003oYIk?ojFNcol00003oloHh003o`00
0?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXo`000003o`0000CoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVmj003ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP0
0onY_NP4o`0000;oZKgX0_l0000kooooo`00GOooool3o`0000;ooooo0ol000000onY_NSo0000ojVm
j003ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX
00Co0000ojVmj?nY_NSoZKgX0ol00002ohiQV@03o`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4
C8GoQ4b5o`000003ohE=QP03o`000?n6DH[oQU6:00?oQU6:0_l000001_oodhco0000o`000?o3eV7o
0000oi:3`0;o00000_n;Fi<01?l0003oQDj7ohE>Qol00002oo_:HP03o`000?n5CXOoQDj700;oQDj7
00?o0000ohA;Q?n4Bh@00_n4Bh@00ol0003oml=Co`000003ohE=QP04o`000?oc`dkoll=>o`0000?o
QU2800Co0000onk3BOo^`dWo00000_n8E8`01Ol0003ojLA7onW4AooYa4Oo000000;oReVA0ol00002
onK8C0?o00000_n/Tk`01?l0003od[Jmom:f_Ol00002ojBGb007o`000?oH_l3of;o0omRo`?l0003o
GWODo`000004olFoe@Oo00000ooKlml00ol0003oYIk?o`000004oloHh0?o00000_nINJd00ol0003o
ZKgXojVmj003ojVmj0?o00000onY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY
_NP00ol00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP2o`0003[ooooo001Koooo
o`;o00000_ooool3o`0000GoZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj006o`000?nY_NSo0000
o`000?nY_NSo00001?nY_NP01?l0003oZKgXojVmj?nY_NP2o`0000;oSV6I00?o0000ojVmj?l00000
0on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000?oQDf600?o0000ohIAR_n6DHX00on6DHX4o`000003
ol?FHOl0003oTX?000;oTX?000Co0000oh]KTon;Fi?o00000_n5CXL01Ol0003onlYRoo_:H_okbV;o
000000?oQDj700Go0000ohA;Q?n4BhCoQ4^4o`000002ooO3D`05o`000?n5CHKoQDf6ohE=Q_l00000
0_oc`dh01Ol0003oQU28ohI@R?n6D8So000000;ok/=900Co0000ohQDS?n8E8co00000ooYa4L00ol0
003oReVAo`000002o`000003olZZ^Ol0003oi/Q<00;o000000?obZZio`000?l000001?oB][d2o`00
00Gof;o000?o0000olFoeOo5_mD00_o5_mD00ol0003ofM[Ho`000004ogBKj@Ko00000oo?f>02o`00
0003okBUb_l0003oVGV]00?oVGV]00?o0000ojVmj?l000000_l000000onY_NSo0000o`000003ojVm
j0?o00000_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj003ojVm
j0;o00001?nY_NP01?l0003oZKgXojVmj?nY_NP3o`0003[ooooo001Hooooo`?o000000Coooooo`00
0?l0003o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003
o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o00000_n>HIT00ol0003oZKgXo`000003
ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000001?n5CHH00ol0003oQU6:ohIARP02ohIARP?o000000?o
`mIQo`000?nBPl000onBPl001?l0003oRe^Coh]KTol00002ohE>Q`05o`000?okbV;onlYRoo_:H_l0
00000on5CXL01Ol0003oQ4^4ohA;Q?n4BhCo000000;oml=C00Go0000ohE=Q_n5CHKoQDf6o`000002
oo?3CP05o`000?n6D8SoQU28ohI@R?l000000_o^`dT01?l0003oR5B<ohQDS?l00004onW4A`Co0000
0_o:Z[T3o`000003olZZ^Ol0003od[Jm00Cod[Jm00?o0000omRo`?oH_l000ooH_l02o`0000?oaKoE
00Ko0000omWJf?oIf]SofM[Ho`000?mdVnT2o`000003okSAkOl0003oPZ[^00?oPZ[^00?o0000oloH
h?l000000ondYLX00ol0003oVGV]oiUi[@03oiUi[@03o`000?nY_NSoZKgX00?oZKgX00Ko0000ojVm
j?l0003o0000ojVmj?l00004ojVmj003o`000?nY_NSo000000;o000000?oZKgXo`000?nY_NP00onY
_NP00ol0003oZKgXo`000002o`000003ojVmj?l0003oZKgX00?oZKgX1?l00002ojVmj0;o0000>Ooo
ool005Kooooo0_l000001?oooooo0000o`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Co
0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002o`0000;oSV6I00?o0000ojVmj?l00000
0on4C8D01Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600?o0000ohIAR_n6DHX00_n6DHX01?l0003o
h=QRo`000?o3eV42o`0000;oTX?00_l00002oh]KT`03o`000?n5CXOo000000ConlYR00Go0000ohE>
Qon5CXOoQDj7o`000003ohA;Q004o`000?og`e?oml=Co`0000?oQDf600Co0000oo?3C_oc`dko0000
0_n6D8P01Ol0003ok/=9onk3BOo^`dWo000000;oR5B<0_l00003onW4A`?o000000Koa[;7o`000?o:
Z[WobZZio`000?o:Z[T2o`0000Cod[Jm00?o0000omW?col000000ooH_l001_l0003og=OBomcGd_l0
003oaKoEo`0000CofM[H0_l00004okSAk@03o`000?n2Z^koPZ[^00?o00001OndYLX00ol0003oVGV]
oiUi[@02oiUi[@03o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX00?o0000
1OnY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00005ojVm
j0;o0000>?ooool005?ooooo0ol00002ooooo`;o00001OnY_NP00ol0003oZKgXojVmj003o`0000Go
ZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o
0000ojVmj?nY_NP00_l000000onY_NSo0000o`000002ohiQV@03o`000?nY_NSo000000?oQ4b500Go
0000ohA<QOn4C8GoQ4b5o`000004ohE=QP03o`000?n6DH[oQU6:00;oQU6:0_l000001_o3eV7o0000
oiAj/ol0003oTX?0o`0000;o]9Zl00Go0000oh]KTol0003oQDj7o`000004oo_:HP05o`000?n5CXOo
QDj7ohE>Qol000000on4Bh@01?l0003oml=CooO3Dol00003ohE=QP04o`000?oc`dkoll=>o`0000;o
QU2800Go0000onk3BOo^`dWok/=9o`000002ohQDS0;o00000ooYa4L2o`0000?oa[;700Co0000olZZ
^Oo:Z[Wo00000_o@`/`01?l0003od[Jmom:f_Ol00003omW?c`03o`000?oH_l3o000000?og=OB0_l0
0003omWJf0;o00000_o4lNl00ol0003o^=7]okSAk@04o`0000;oV[__00?o0000okBUb_ndYLX00ond
YLX02?l0003oVGV]oiUi[OnINJgo0000omJZZol0003oZKgX1Ol00004ojVmj0?o00000_nY_NP00ol0
003oZKgXojVmj003ojVmj0?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00?o0000
ojVmj?nY_NP01?l0000hooooo`00DOooool2o`0000?ooooo0_l00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00004ojVmj003o`000?nY_NSoZKgX
00?o00001OnY_NP01?l0003oZKgXo`000?mN=hT3o`0000;oSV6I00?o0000ojVmj?l000000on4C8D0
1Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600?o0000ohIAR_n6DHX00_n6DHX3o`0000;oU7Zc0_l0
0003okBJ_005o`000?n;Fi?o0000ohE>Qol000001?okbV801Ol0003oQDj7ohE>Qon5CXOo000000?o
Q4^400Co0000ooO3Doog`e?o00000on5CHH01?l0003oll=>oo?3C_l00002ohI@R005o`000?o^`dWo
k/=9onk3BOl000000_n8E8`3o`0000;ojLA70_l00003olJba`03o`000?o:Z[Wo000000?od<;<00?o
0000om:f_Ol000001?oIcll2o`0000?og=OB00Ko0000om;aiooBlNOo0000omWJf?l00004olCak`?o
00000_nUZ]/00ol0003oV[__oiZkk`02oiZkk`03o`000?ndYL[o]:G:00;o]:G:00Go0000oiUi[OnI
NJgoVGV]o`000002omJZZ`08o`000?n?GYCoSejDohmNU?l0003oSejDo`000?nY_NP2o`000003ojVm
j?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0Co0000
0_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP2o`0003Oooooo000Zooooo`Co000000?o
410@ooooooooool07Oooool3o`0000;ooooo1?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX
00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol00003ojVm
j003o`000?nY_NSoZKgX00;oZKgX0ol000001?mN=hWo0000ojVmj?l00002ohiQV@03o`000?nY_NSo
000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP04o`000?n6DH[oQU6:ohIARP;o0000
00Ko`mIQo`000?l0003o0000ok2F_Ol00003okBJ_005o`000?n;Fi?o0000ohE>Qol000001?okbV80
1Ol0003oQDj7ohE>Qon5CXOo000000?oQ4^400Co0000ooO3Doog`e?o00000on5CHH01?l0003oll=>
oo?3C_l00002ohI@R006o`000?o^`dWok/=9onk3BOl0003oR5B<1Ol000000ooYa4Oo0000o`000003
olJba`;o00001Oo@`/`00ol0003ofLo?omW?c`02omW?c`06o`000?oDk>Goe>cUo`000?oLem;o0000
0ooBlNL4o`000005olCakol0003o0000ojFNc_l000001?nUZ]/00ol0003oV[__oiZkk`02oiZkk`05
o`000?ndYL[o]:G:okBUb_l000000_nINJd01Ol0003oeZZ[omJZZooFZZ_o000000?oSejD00Co0000
ohmNU?n?GYCo00001?nY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00Ko0000ojVmj?l0003o0000
ojVmj?l00005ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP3o`0003Kooooo000/oooo
o`03o`000?oooooooooo01cooooo0ol00002ooooo`?o00001?nY_NP00ol0003oZKgXojVmj003o`00
00GoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000
ojVmj?nY_NP00_nY_NP01Ol0003oZKgXo`000?l0003oZKgX00;o00000_mN=hT3o`000004ohiQVOl0
003oZKgXo`0000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP04o`000?n6DH[oQU6:ohIA
RPCo00000on`U[d02Ol0003o]9ZlokBJ_?ndV[co0000oh]KTol0003oQDj7o`000004oo_:HP05o`00
0?n5CXOoQDj7ohE>Qol000000on4Bh@01Ol0003oml=CooO3Doog`e?o000000;oQDf600Co0000oo?3
C_oc`dko00000_n6D8P01_l0003ok/=9onk3BOo^`dWo0000ohQDS0;o00000oni_=`2o`0000;oa[;7
0_l000000oo5cn;o0000om32c003om32c0;o00000ooIcll01?l0003oe>cUomC/iOoDk>D3o`000003
om;aiol0003o000000?oXoKY0_l00004ojFNcP04o`000?nUZ]_oYJ[KojFZf`Ko00000ondYLX01?l0
003oVGV]oiUi[Ol00002omJZZ`;o00001?n?GY@00ol0003oSejDo`000004ojVmj0?o00000onY_NP0
1?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj005o`00
0?nY_NSo0000o`000?nY_NP00_l0000fooooo`008Oooool6o`0000Gooooo00?o0000ooooooooool0
6_ooool2o`0000Cooooo00Co0000ojVmj?nY_NSo00001?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY
_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00Co
00000_nY_NP2o`0000?oGSN90_l000001?n>HIWo0000ojVmj?l00003ohA<Q@05o`000?n4C8GoQ4b5
ohA<QOl000001?n5CHH01?l0003oQU6:ohIAR_n6DHX3o`0000Go/9Jm00So0000okBJ_?ndV[co0000
oh]KTol0003oQDj7o`0000ConlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007o`000?og`e?o
ml=CooO3Dol0003oQDf6o`000003oo?3CP04o`000?n6D8SoQU28o`0000Cok/=90ol00004okVlg003
o`000?o6//Oo000000CoaLoR00Co0000om32c?o@`/co00000_o?hND00ol0003ofLo?o`000003omC/
i@03o`000?nanN_o/OW[00?o000000KoXoKYo`000?l0003o0000oj>HbOl00004ojFNcP06o`000?nU
Z]_o0000o`000?n`W<Co00000omMR^D3o`0000;o]:G:0_l00003omJZZ`;o00001?n?GY@01Ol0003o
SejDo`000?l0003oZKgX00;o000000?oS5N=o`000?nY_NP00onY_NP4o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP4o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00004ojVmj0;o0000=Oooool0
02cooooo00?o0000ooooooooool05oooool3o`0000?ooooo0ol00004ojVmj004o`000?nY_NSo0000
o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01?l0003oZKgXo`000?l00002ojVmj004o`000?nY
_NSoZKgXojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP01?l0003oZKgX
o`000?l00003oehgR@;o000000CoSV6Io`000?nY_NSo00000on4C8D01Ol0003oQ4b5ohA<QOn4C8Go
000000CoQDf600?o0000ohIAR_n6DHX01?l00005ok2F_@0:o`000?ndV[co]9Zlo`000?n;Fi?o0000
ohE>Qol0003onlYRo`0000;onlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007o`000?og`e?o
ml=CooO3Dol0003oQDf6o`000003oo?3CP03o`000?n6D8SoQU2800;o00000oo^`dT4o`0000?o^KcL
0_l00005olG?hP03o`000?o@`/co000000?ocn7U1?l000000ooDk>Go0000ok7ij`02o`000004og?Q
dol0003o0000o`0000GoXiS900Co0000ojFNc_nUW/koYIk>0_l00004ok2La006o`000?mMR^GoGH[U
oef:iOl0003o8FGI1?l00003omJZZ`03o`000?oY^J;o000000?oSejD00Go0000ohmNU?l0003ol[:7
o`000004ohaGS@06o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01_l0003oZKgXo`000?l0003o
ZKgXo`0000CoZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol0000dooooo`00;?ooool0
0ol0003oooooooooo`0Eooooo`?o00000_ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00005
ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSo
ZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co00001?mN
=hT01Ol0003oSV6Io`000?nY_NSo000000?oQ4b500Go0000ohA<QOn4C8GoQ4b5o`000004ohE=QP03
o`000?n6DH[oQU6:00;o00000_n/U/000ol0003o/9Jmok2F_@02ok2F_@0:o`000?ndV[co]9Zlo`00
0?n;Fi?o0000ohE>Qol0003onlYRo`0000;onlYR00Go0000ohE>Qon5CXOoQDj7o`000003ohA;Q007
o`000?og`e?oml=CooO3Dol0003oQDf6o`000003oo?3CP03o`000?n6D8SoQU2800;o00000oo^`dT2
o`000003oiNnlol0003o^KcL00;o00000_nRe_X00ol0003oaLoRolG?hP02olG?hP?o000000?ocn7U
o`000?l000000onbmO87o`0000;oXIG700?o0000oj>HbOnSV<T00onSV<T01_l0003oYIk>ojFNc_l0
003o[9Joo`0000Go/9c41Ol00002ob5Uf@05o`000?oFZZ_oeZZ[omJZZol000000_oY^J802Ol0003o
SejDohmNU?n?GYCo0000ohmNU?l0003ol[:7o`000005ohaGS@03o`000?nY_NSoZKgX00;oZKgX00Co
0000ojVmj?nY_NSoZKgX0ol00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP01Ol0
003oZKgXo`000?l0003oZKgX00;o0000=?ooool002cooooo00?o0000ooooooooool04_ooool3o`00
00?ooooo0_l000000onY_NSo0000ojVmj003ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004ojVm
j005o`000?nY_NSo0000o`000?nY_NP00ol00004oehgR@05o`000?n>HIWo0000ojVmj?l000000on4
C8D01Ol0003oQ4b5ohA<QOn4C8Go000000CoQDf600Co0000ohIAR_n6DH[o00000on/U/000ol0003o
/9Jmok2F_@03ok2F_@;o000000Go`Zg5o`000?l0003o0000oo_:HP02o`0000;onlYR00Go0000ohE>
Qon5CXOoQDj7o`000002ohA;Q003o`000?og`e?oml=C00;oml=C00?o0000ohE=Q_l000000ooc`dh0
0ol0003oQU28ohI@R003o`0000;ok/=91_l00004oj;FnP04o`000?o5cn;o0000o`0000;o[NWi0ol0
00000onbmO;o0000o`000004o`0000;oWi?700?o0000oj6EaonQULL00_nQULL00ol0003oXiS9oj>H
b@02oj>Hb@03o`000?nUW/ko000000?o[9Jo00Co0000ok2La?n`W<Co/9c40_l00003og9mc`;o0000
00?o8FGIo`000?oFZZ/00_oFZZ/01?l0003ojKVRonViX_l00003ohmNU0;o00000_ob/XL00ol0003o
S5N=ohaGS@03ohaGS@03o`000?nY_NSoZKgX00;oZKgX1?l00002ojVmj003o`000?nY_NSoZKgX00;o
ZKgX0_l00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP2o`0003?ooooo000/ooooo`03
o`000?oooooooooo013ooooo0_l00003ooooo`Co00000onY_NP01?l0003oZKgXo`000?l00002ojVm
j003o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003
o`0000?oZKgX0ol00004oehgR@05o`000?n>HIWo0000ojVmj?l000000on4C8D01Ol0003oQ4b5ohA<
QOn4C8Go000000CoQDf600Co0000ohIAR_l0003o00001?n/U/001?l0003o/9Jmok2F_On`U[d2o`00
00;o`Zg50ol000000ookbV;o0000o`000002oo_:HP05o`000?n5CXOoQDj7ohE>Qol000000_n4Bh@0
0ol0003oml=CooO3D`02ooO3D`03o`000?n5CHKo000000?oll=>00Co0000ohI@R?l0003ok/=90_l0
0002onk3B@go000000Co[NWio`000?l0003oLn3Z1_l000000onQU<Oo0000oinCa`03oinCa`05o`00
0?nQULOoXIG7oj6Eaol000001?nSV<T2o`0000Co[9Jo00Co0000ok2La?n`W<Co00000_nnWkT01Ol0
003oLWg?og9mcombOLoo000000;o8FGI00Co0000omJZZooFZZ_o00000_oY^J801?l0003oSejDohmN
U?n?GY@2o`0000;ol[:700?o0000ohaGSOn<Ehd00on<Ehd2o`000005ojVmj?l0003o0000ohaFS?l0
00001OnY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX1?l00002ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0ol0000booooo`00:_ooool00omEEEGoIVIVo`00000?ooooo`?o00000_ooool3o`00
00CoZKgX00?o0000ojVmj?nY_NP00_l00005ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01_l0
003oZKgXo`000?l0003oZKgXo`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000GoGSN90_l000000onY_NSo
0000ohA<Q@02ohA<Q@05o`000?n4C8GoQ4b5ohA<QOl000001?n5CHH01?l0003oQU6:o`000?l00004
ojbF`006o`000?n`U[go/9Jmo`000?nk[L_o00000_o2[LD3o`000006oo_:H_l0003od;k9o`000?ok
bV;o00000on5CXL01?l0003oQ4^4ohA;Q?l00004ooO3D`03o`000?n5CHKo000000?oll=>00Go0000
ohI@R?l0003o0000oiV^iP02o`000003onk3BOl0003o000001?o00001?nQU<L01Ol0003oWi?7oinC
aonOTlOo000000?oXIG700?o0000oj>HbOl000000_l000000onVTKoo0000ojbF_`03ojbF_`03o`00
0?n`W<Co000000Co_Yni00Wo0000og9mcombOLooLWg?o`000?lQIMWo0000omJZZol000000ooY^J80
1?l0003oSejDohmNU?n?GY@2o`0000;ol[:700?o0000ohaGSOn<Ehd00on<Ehd00ol0003onK9`o`00
0004ohaFS004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00GoZKgX00Go0000ojVmj?l0003o0000ojVmj002o`0003;ooooo000iooooo`Co00000_ooool2o`00
00;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01_l0
003oZKgXo`000?l0003oZKgXo`0000CoZKgX00?o0000ojVmj?nY_NP00ol00005oehgR@;o000000Go
ZKgXo`000?n4C8GoQ4b5o`000004ohA<Q@03o`000?n5CHKoQDf600;oQDf600Co0000ohIAR_l0003o
00001?n/U/000ol0003o/9Jmo`000003ok^]b`03o`000?o2[LGo000000?o000000Goc<;@o`000?l0
003onlYRo`000003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00?o0000ohE=Q_l000001?oc`dh4
o`0000;o_L;N0ol00002og^PjP03o`000?m3]OGo@kGe00Co00000on;_?L00ol0003oMM?no`000002
o`000003ojVOc?l0003oXIC700?oXIC700Go0000oinCaonOTlOoWi?7o`000002oj6Ea`?o00001OnV
TKl00ol0003o[9JoojbF_`02ojbF_`03o`000?nnWkWo_Yni00?o_Yni00Go0000og9mcol0003o0000
ojNC`@02o`000003omJZZol0003ojKVR00;ojKVR00?o0000ohmNU?n?GY@00ol00002oo:bQ`03o`00
0?n<EhgoS5N=00?oS5N=00?o0000ooVbL?l000001On<EX`3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0ol00004ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP2o`00037ooooo000gooooo`;o0000
0oooool4o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj004o`000?nY_NSo0000
o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?l000000_l00004oehgR@?o00000on4C8D00ol0003oQ4b5ohA<Q@02ohA<Q@03o`000?n5CHKo
QDf600;oQDf600Go0000ohIAR_l0003oZY_7o`000003ojbF`0;o00001?nk[L/00ol0003o`Zg5o`00
0003o`000005olc2d?l0003o0000oo_:H_l000000on5CXL01?l0003oQ4^4ohA;Q?l00004ooO3D`03
o`000?n5CHKo000000Coll=>0ol00003okg2gP;o00000_mkX>X4o`0000?oTJGS00?o0000oh^lmon;
_?L00ol00005ojVOc005o`000?nQU<OoXIC7oj6Daol000000onOTlL3o`0000;oXi7200?o0000ojJA
_onVTKl00onVTKl01?l0003o[9JoojbF_on/U[l2o`0000Ko_Yni00?o0000ojNC`OnWTl400_nWTl43
o`0000?ojKVR0ol000001?n?GYCo0000o`000?ob/XL2o`0000GoS5N=00?o0000ooVbL?l000001On<
EX`00ol0003oZKgXojVmj003ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co00000_nY
_NP01?l0003oZKgXojVmj?nY_NP4o`00033ooooo000dooooo`?o00000_ooool3o`0000CoZKgX00?o
0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01?l0003oZKgXo`00
0?l00002ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l00002ojVmj003o`000?nY_NSoZKgX
00;oZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00000_nY_NP00ol0003oZKgXo`000003
o`0000CoGSN90ol00003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500?o0000ohE=Q_n5CHH00_n5CHH2
o`0000;oZY_700Ko0000ojbF`?l0003o0000ok:]e?l00004ok^]b`Ko000000Goc<;@o`000?l0003o
nlYRo`000003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00Co0000ohE=Q_l0003o00000ooc`dh3
o`0000Co_L;N0ol00002ok:ig`03o`000?nAYN?oTJGS00;oTJGS0ol00002ojbYe003o`000?nYWlco
ZIo<00?oZIo<00?o0000oj6DaonQU<L00_nQU<L3o`000003oj:Daol0003oXi7200?oXi7200?o0000
ojJA_onVTKl00_nVTKl01?l0003o[9JoojbF_ol00002ok:G^`03o`000?nnWkWo_Yni00;o_Yni0_l0
0004ojNC`@;o000000KojKVRo`000?l0003o0000onViX_l00003ohmNU005o`000?ob/XOo0000ooRi
Ool000001?n<Ehd00ol0003onK9`o`000005ohaFS0;o000000KoZKgXo`000?l0003o0000oheGSOl0
0004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP4o`0000;oZKgX0_l0000`ooooo`00
<oooool2o`0000;ooooo0_l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj004o`00
0?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY
_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0
003oZKgXo`000002ojVmj005o`000?nY_NSoZKgXo`000?nY_NP01?l00003oehgR@04o`000?ongIGo
0000o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D00ol0003oQDf6ohE=QP02ohE=QP;o000000Co
ZY_7o`000?l0003o00001?nb[M@01?l0003o^jg;ok^]bol00002ol?6g0?o000000Koc<;@o`000?o@
e]go0000oo_:H_l00003ohE>Q`04o`000?n4BhCoQ4^4o`0000Coml=C00Co0000ohE=Q_l0003o0000
0ooc`dh3o`0000?o_L;N00?o0000okS9iol000001?nb^Ml01_l0003oTJGSo`000?l0003o[KKOo`00
00Co[:WD00?o0000ojVOc?nYWl`00_nYWl`00ol0003oXIC7oj6Da`03o`0000CoXYC700Go0000oj>A
`_nSTL;oXi72o`000005ojJA_`;o00000onbUk/01Ol0003o_YniokjO^OnnWkWo000000;o`Yjd00Co
0000ojNC`OnWTl7oYi?10ol00004onViXP04o`000?n?GYCoSejDohmNU0?o000000?on;Uoo`000?n<
Ehd00on<Ehd00ol0003onK9`o`000005ohaFS003o`000?ok/fOo000000GoSEN=00?o0000ojVmj?nY
_NP00ol00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001OnY_NP2o`0002oooooo000coooo
o`Go00001?nY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000
ojVmj?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj002
ojVmj0?o00000onY_NP00ol0003oZKgXojVmj003o`0000GoZKgX00?o0000ojVmj?nY_NP00ol00004
ojVmj004o`000?nY_NSo0000ojVmj0Co00000omN=hT01?l0003oo]fEo`000?l00003ohA<Q@03o`00
0?n4C8GoQ4b500;oQ4b500?o0000ohE=Q_n5CHH00_n5CHH3o`0000;oYK7Q00?o0000ok:]e?nb[M@0
0_nb[M@00ol0003o^jg;o`000004ol?6g0?o00000oo@e]d2o`0000?oQDj700Co0000ohA;Q?n4BhCo
00001?og`e<00ol0003oQDf6o`000002o`0000;oll=>0_l000001?o3d^Ko0000okg2g_l00003okS9
i`04o`000?nb^Moo/[WOok:ig`;o00001?n]]]l00ol0003o[:WDojbYe002ojbYe003o`000?nYWlco
ZIo<00Co00000_nQVlh00ol0003oXYC7oj:Da`02oj:Da`03o`000?nSTL;oXi7200;oXi7200Co0000
ojJA_onVTKooYY6o0_l00004ok:G^`04o`000?nnWkWo_Ynio`0000?o`Yjd1?l00002olbR[@03o`00
0?oY^J;ojKVR00;ojKVR00Wo0000ohmNU?n?GYCoSejDo`000?ob/XOo0000ooRiOol000001?n<Ehd0
0ol0003onK9`o`000005ohaFS003o`000?ok/fOo000000GoSEN=0ol00003ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP01?l0003oZKgXojVmj?nY_NP4o`0002kooooo000cooooo`?o00000_nY_NP0
0ol0003oZKgXojVmj004o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo
0000o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000Co
ZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co
000000?oZKgXo`000?l000000_l00002oehgR@03o`000?ongIGoo]fE00;o00000on4C8D00ol0003o
Q4b5ohA<Q@02ohA<Q@03o`000?n5CHKoQDf600;oQDf600?o0000ojFahOnU/N400onU/N401?l0003o
/ZgDok:]e?nb[M@2o`0000Go`lKL0_l00003om3Fg@?o00000on5CXL01?l0003oQ4^4ohA;Q?l00004
ooO3D`03o`000?n5CHKo000000;o00000_oc`dh5o`0000Co^<WW00Ko0000ok:igol0003o0000ojc3
jol00004ojffg`04o`000?n/ZMCo[:WDojbYe0Co00000_nPYMT00ol0003oXI_>oj6KcP02oj6KcP05
o`000?nRU<OoXYC7oj:Daol000001?nSTL801_l0003oYY6oo`000?l0003oZI>oo`0000Go/YNk0_l0
0002ol:N]0?o000000?oYi?1o`000?o<XZd00_o<XZd2o`0000?ojKVR00Wo0000ohmNU?n?GYCoSejD
o`000?ob/XOo0000ooRiOol000001?n<Ehd01?l0003onK9`o`000?l00004ohaFS003o`000?ok/fOo
000000GoSEN=00?o0000ojVmj?nY_NP00onY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01Ol00002
ojVmj0;o0000;_ooool003?ooooo0_l00003ojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004o`00
00?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP01?l0
003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj0?o00000_nY_NP2o`000003ojVmj?l0003o000000;o00000_mN=hT00ol0003oo]fE
o`000002o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D00ol0003oQDf6ohE=QP02ohE=QP;o0000
1?nU/N401?l0003o/ZgDo`000?l00002ok7;k@04o`000?o3a]co`lKLol?6g0;o000000Go`N3_o`00
0?o@e]go0000ol_Xj`02o`0000?oQDj700Co0000ohA;Q?n4BhCo00001?og`e<3o`0000;o^N;c00Co
0000oo?3C_l0003o00000onaeo<00ol0003o^<WWokS9i`03o`0000Co[<?[00?o0000ojffgon]]]l0
1Ol00002oijai@03o`000?nPYMWoX:GI00;oX:GI00Go0000oj6Kc_nQVlkoXI_>o`000004oj:Da`03
o`000?nSTL;oXi7200?o00001?nYTkl00ol0003o/YNkok:G^`02ok:G^`Co00000oo2W[@2o`0000?o
c::]0_l00003onViXP04o`000?n?GYCoSejDo`0000;ol[:70ol00004ohaGS@04o`000?oi/W3o0000
o`0000CoS5J<00?o0000oo^cIol000001On=Ehd2o`000006ojVmj?l0003o0000o`000?nY_NSo0000
1?nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0002gooooo000Xooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool01_l0003oooooooooool0003oZKgXo`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000?oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00?o00001OnY_NP00ol0003oZKgXojVmj003
o`0000CoZKgX00Co0000ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002o`000003ojVmj?l0
003o000000;o00000_mN=hT01Ol0003oo]fEo`000?ohkJco000000?oQ4b500?o0000ohA<QOn4C8D0
0_n4C8D00ol0003oQDf6ohE=QP02ohE=QP03o`000?nF_?;o000000;oYK7Q1?l00004ok7;k@06o`00
0?o3a]co0000ol7Pkol0003o`N3_1_l00003ohE>Q`03o`000?n4BhCo000000Goml=C1_l000000ooc
`dko0000o`000002ok7Gl`Co00000onUd?H00ol0003o[<?[ojc3j`04o`0000?oV[ob00?o0000oija
iOnN/ND00_nN/ND01Ol0003oX:GIoj2UfOnPYMWo000000?oXI_>00?o0000oj:DaonRU<L01Ol00002
oj6DaP03o`000?nYTkooZI>o00;oZI>o00?o0000ok:G^onbUk/00ol00006ol:N]003o`000?o<XZgo
c::]00;oc::]00?o0000om:SY_l000000_oY^J801?l0003oSejDohmNU?l00002oo:bQ`03o`000?oh
^Goo000000CoS5N=00Co0000ooVbL?l0003o00001?n<EX`00ol0003onk=Wo`000005oheGS@03o`00
0?ok/fGo000000GoZKgX1?l000000onY_NSo0000ojVmj003ojVmj008o`000?nY_NSo0000o`000?nY
_NSo0000ooooool0000/ooooo`00:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000
ooooooooooooooooo`000004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00?o0000ojVmj?nY_NP0
0_nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o
00000_nY_NP01?l0003oZKgXojVmj?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`00
00?oZKgX00?o0000ojVmj?nY_NP00ol00005ojVmj005o`000?nY_NSo0000o`000?nY_NP01?l00000
0omN=hWo0000ookMU@04o`0000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D01?l0003oQDf6ohE=Q_n5
CHH7o`0000?oS/[l00?o0000ok7;kOnabnd01?l000000oo1h>oo0000o`000003oj__m`?o00000on5
CXL01Ol0003oQ4^4o`000?og`e?o000000?oml=C1_l000000ooc`dko0000o`000002o`0000?oX[[Z
00?o0000ojG@m_nUd?H01?l00003oiC6n003o`000?nJ_o;oV[ob00;oV[ob00Go0000oijaiOnN/NGo
W[7Uo`000003oj2Uf@03o`000?nQVlkoXI_>00Co00000_nKV=000ol0003oXIC6oj6DaP03oj6DaP04
o`000?nYTkooZI>oojVC_`Co00000_neV;X00ol0003o`Yjdol:N]003ol:N]003o`000?o<XZgoc::]
00;oc::]00?o0000om:SY_l000000_oY^J801?l0003oSejDohmNU?l00002oo:bQ`03o`000?oh^Goo
000000CoS5N=00Co0000ooVbL?l0003o00001?n<EX`00ol0003onk=Wo`000005oheGS@04o`000?ok
/fGo0000o`0000;oZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP2o`0002cooooo
000Xooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000?ooooo00?o0000ojVmj?nY_NP0
0ol00005ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj004o`0000CoZKgX
00?o0000ojVmj?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;o
ZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00;oZKgX1ol000001ol0
06Ko0000oehgROl0003oo]fEo`000?oAeEd00_l00003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500Ko
0000ohE=Q_n5CHKoQDf6o`000?moPld;o`0000;oVn;m1Ol000001?n[koOo0000o`000?moi^d2o`00
00?oQDj700Go0000ohA;Q?l0003oml=Co`000003ooO3D`?o000000?oWLOeo`000?l000000_l00000
0onLX=Oo0000oj:jjP03oj:jjP?o00000onIX]`00ol0003oU<KhoiC6n002oiC6n003o`000?nJ_o;o
V[ob00co00000_nCX=d00ol0003oViS@oi^Hd002oi^Hd003o`000?nQU<KoXIC600;oXIC600Go0000
ojVC_ol0003o0000ojVC_`02o`0000?o]IRj00?o0000ol:N]?o2W[@00_o2W[@2o`0000?oc::]00?o
0000om:SY_oBXjH00_l00002onViXP03o`000?n?GYCo000000;ol[:700Co0000ooRiOol0003o0000
0on<Ehd01?l0003onK9`o`000?l00004ohaFS004o`000?ok/fOo0000o`0000CoSEN=00Co0000oo^c
IOl0003onk=U0_l00002ohiISP03o`000?nY_NSoZKgX00?oZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00Co0000:oooool002Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSo
ZKgX00Co00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01Ol0003oZKgXo`000?l0
003oZKgX00Ko000000Ko001Vo`000?l0003oo]fEo`000?oAeEd3o`0000?oQ4b500?o0000ohA<QOn4
C8D00_n4C8D01Ol0003oQDf6ohE=Q_n5CHKo000000;oOh?=0_l00003ogAlcA;o00000on5CXL01Ol0
003oQ4^4o`000?og`e?o000000?oml=C1?l000001?n^Y<ko0000o`000?l00002oibPe`06o`000?nR
^^[o0000o`000?n_Y/oo00001?nIX]`8o`0000?oLKon00Co0000ogbhnOml^?Wo00000on:[>`00ol0
003oTj3Moi>Pg@02oi>Pg@05o`000?nKV=3oViS@oi^Hd?l000000onQU<H3o`0000;oZI>o0_l00005
okFH^P04o`000?o2W[Co`Yjdo`0000;oa9jb00Co0000olbR[Oo<XZgo00000ooBXjH02?l0003ojKVR
onViX_l0003oSejDo`000?ob/XOo00000_oh^Gl00ol0003oS5N=o`000002ohaGS@04o`000?oi/W3o
0000o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0003onk=Uo`000?ok/fGo000000Co
SUV>00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj003ojVmj0?o00000_nY_NP2o`0002_o
oooo000Xooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03
o`000?nY_NSoZKgX00;oZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgXojVmj?nY_NP3
o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX1Ol00000
0ol006Ko0000o`000002o`000004om7EGOl0003oUgZao`0000?oQ4b500?o0000ohA<QOn4C8D00_n4
C8D01?l0003oQDf6ohE=Q_l00002ogn3c@04o`000?o4Z;goa:Rmo`0000?oM7c=0_l00005ohV7b`06
o`000?mJ[O[o0000o`000?nZV/Oo00000on8Um/02?l0003oQDj7ohE>Qon5CXOo0000ohA;Q?l0003o
ml=C0_l00002ooO3D`?o00000on^Y<h2o`0000;oW:3G0_l00004ojnVc`06o`000?nIX]coVJ;Lo`00
0?neY/[o00001OnBV=H9o`0000?oRZc/00Go0000oi>PgOnCX=goTj3Mo`000004oi^Hd0?o00000_nQ
U<H3o`000003ojRF`ol0003o]IRj00Co]IRj00Co0000ol:N]?o2W[Co00000_o4W[800ol0003oc::]
o`000004om:SYP;o000000KojKVRo`000?n?GYCo0000oo:bQol00002ooRiO`07o`000?n<EhgoS5N=
o`000?n<Ehgo0000ooVbL002o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0003onk=U
o`000?ok/fGo000000GoSUV>00?o0000ojVmj?nY_NP00onY_NP4o`000003ojVmj?l0003oZKgX00?o
ZKgX0_l0000Zooooo`00:?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oZKgXojVmj004o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP00ol0003o
ZKgXojVmj002ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX0ol00003
ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP0
0ol0003oZKgXojVmj006o`000005o`00I_l0003o0000o`000?oAeEd00_l000000onGN[7o0000ohA<
Q@02ohA<Q@03o`000?n4C8GoQ4b500;oQ4b500Ko0000ohE=Q_n5CHKo0000ogn3cOl00003olBX_@04
o`000?mdO<goM7c=o`0000;o`:Jo00?o0000ohV7bon9Ql/00_n9Ql/2o`0000CoZY[700Co0000ohRG
fon8Um_o00000on5CXL00ol0003oQ4^4o`000003o`0000;oml=C0ol00003ojjTcP06o`000?nLX=Oo
0000o`000?nbZ<ko00001?n_Y/l00ol0003oVJ;Lo`000003okFVbP07o`000?nBV=KoTYSFoi:He_l0
003o^:?4o`000004oh>:dP03o`000?lSX>[o000000Co00000onCX=d00ol0003oViS@o`000003o`00
00;oXIC60ol00004ojRF``03o`000?neV;[o]IRj00;o]IRj00?o0000ol:N]?l000000oo4W[800ol0
003oc::]o`000004om:SYP;o000000KojKVRo`000?n?GYCo0000oo:bQol00002ooRiO`07o`000?n<
EhgoS5N=o`000?n<Ehgo0000ooVbL002o`0000CoS5J<00Co0000oo^cIol0003o00001?n=Ehd01Ol0
003onk=Uo`000?ok/fGo000000GoSUV>0_l00002ojVmj0?o00001OnY_NP00ol0003oZKgXojVmj004
o`0002Wooooo000Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07
ooooo`;o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP01?l00004
ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0
003oZKgXo`0000CoZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00000_nY_NP4o`000006
o`00I_l0003o001Vo`000?oAeEgo00000_nGN[401Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500Go
0000ohE=Q_l0003o`jFlo`000004olBX_@03o`000?mdO<go000000Co`:Jo00Ko0000ohV7bon9Ql_o
0000okbV`ol00004ojZJa`04o`000?n8Um_o0000o`0000?oQDj700?o0000ohA;Q?l000000ol00002
ooO3D`?o00000on^Y<h2o`0000Co/ZS>00Co0000ojnVcon_Y/oo[jK?0_l00005okFVbP03o`000?nB
V=Ko000000?o^:?400Co0000oh>:d_n3R];oPh[B1Ol000000om:Y_So0000o`00000:o`0000;oVYO?
00?o0000ojRF`onXU/<00_nXU/<00ol0003o]IRjokFH^P02okFH^P;o00001Oo4W[82o`0000?odZ>V
00?o0000om:RY_l000000_l000001?n?GYCo0000oo:bQol00003ooRiO`03o`000?n<EhgoS5N=00;o
000000?onK9`o`000?l000001?n<EX`01?l0003onk=Wo`000?l00004oheGS@05o`000?ok/fGo0000
oo^cIOl000001On>FHh01?l0003onk9So`000?l00003ojVmj004o`000?nY_NSoZKgXojVmj0Co0000
0onY_NP2o`0002Sooooo000Xooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`0000Wooooo
00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj003o`00
0?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Co0000ojVmj?l0003o
00000_nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY
_NP01?l00003o`00IP?o00000_nGN[401Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500?o0000ohE=
Q_l000000_l00005olBX_@03o`000?o0Y[oo`:Jo00?o`:Jo00?o0000ohV7bol000000onlY/<01?l0
003oZY[7ojZJaonZV/L2o`0000;o]jG700Go0000ohE>Qon5CXOo0000ohA;Q002o`000004okN[cOl0
003o0000ooO3D`?o000000Go[ZC>o`000?l0003o]:_?o`000004ok:XcP06o`000?n_Y/oo0000o`00
0?ncYl_o00001OneY/X2o`0000Co^:?400Ko0000oh>:d_n3R];o0000okRM_Ol00002of]jd0Go0000
0_m_Xo000ol0003oR9cOohRLg`02ohRLg`03o`000?nJUlooVYO?00;oVYO?00Go0000ojRF`onXU/?o
Z9K3o`000002okFH^P;o000000?o]9Zlo`000?o4W[801?o4W[800ol0003odZ>Vom:SYP02om:SYP03
o`000?oBXZKo000000;o000000CoSejDo`000?ob/XOo00000ooh^Gl01_l0003oS5N=ohaGSOn<Ehgo
0000ooVbL0;o00001?n<EX`01?l0003onk=Wo`000?l00004oheGS@04o`000?ok/fGo0000oo^cI@;o
00001?n>FHh00ol0003onk9So`000004ojVmj0Co00000_nY_NP00ol0003oZKgXojVmj002ojVmj0;o
0000:?ooool0037ooooo00?o0000ooooooooool02Oooool01?l0003oZKgXo`000?l00002ojVmj004
o`000?nY_NSoZKgXojVmj0?o00000onY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0
003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00004ojVmj003o`000?nY_NSoZKgX
00?o00001?nY_NP00ol0003oZKgXo`000003o`0000;o001V00Co0000om7EGOl0003o00000_nGN[40
1Ol0003oQ4b5ohA<QOn4C8Go000000CoQ4b500?o0000ohE=Q_l000000_o7[L001?l0003oa:RmolBX
_Oo4Z;d2o`0000Ko`:Jo00?o0000okbV`onlY/<00_nlY/<01_l0003oZY[7ojZJaol0003o^ZW8o`00
00;o]jG700Go0000ohE>Qon5CXOo0000ohA;Q002o`0000;o]j_=00?o0000ooO3Dol000000ol00004
okB[c`04o`000?nbZ<ko/ZS>ok:XcP;o00001?ncYl/01ol0003o]JK:okFVb_neY/[o0000okFRa_l0
00001?nhXl@00ol0003oPh[Bo`000003okRM_@Wo000000?oKj?`o`000?n8W=l00on8W=l01Ol0003o
VYO?oiZGconJUloo000000CoZ9K30_l00004okBJ_003o`000?o4W[;oa9jb00;oa9jb00?o0000om:S
Y_oBXjH00_oBXjH00ol0003odZ:Vo`000003o`0000;ol[:700Go0000ooRiOooh^Goon;Uoo`000003
ohaGS@Co00001?n<EX`01?l0003onk=Wo`000?l00004oheGS@04o`000?ok/fGo0000oo^cI@;o0000
1?n>FHh01Ol0003onk9So`000?l0003oZKgX00;o000000?oSeZ?o`000?nY_NP01?nY_NP4o`000003
ojVmj?l0003o000002Oooooo000aooooo`03o`000?oooooooooo00[ooooo0_l00004ojVmj003o`00
0?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00CoZKgX0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj004
o`0000?oZKgX00?o0000ojVmj?nY_NP01ol00002o`00IP;o000000GoVWjco`000?nGN[7oUgZao`00
0003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b50_l00003olN]`004o`000?o4Z;goa:Rmo`0000;oa:g2
00?o0000ol2V_oo0Y[l00_o0Y[l2o`0000Co_:K300?o0000ojZJaol000000onjZLP00ol0003o]jG7
o`000002ohE>Q`;o000000Koml=Co`000?ngZlgo]j_=o`000?og`e<2o`000003okJ`d_l0003o]:_?
00?o]:_?00Ko0000ok:Xc_l0003o0000ok>Zcol00005ok>Wb`03o`000?neY/[o000000?o]J;600Co
0000okRSa?nhXlCo^:?40_l00002okRM_@?o000000KoJg[@o`000?l0003o/9Fko`000?lhJ=H5o`00
00?oR9cO00Go0000oiZGconJUlooVYO?o`000002ojRF``?o00001OndV[`01?l0003oa9jbolBN/_o4
W[82o`0000?odZ>V00Co0000om:RY_oBXZKodZ:V0ol00002oo:bQ`05o`000?oh^Goon;UoooRiOol0
00000on<Ehd3o`000003oobfJ_l0003oS5J<00;oS5J<00Co0000oo^cIol0003o00001?n=Ehd01?l0
003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000004ohmJS`03o`000?nY
_NSoZKgX00?o00001OnY_NP00ol0003oooooooooo`0Uooooo`00<Oooool00ol0003oooooooooo`0<
ooooo`03o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00Co0000
ojVmj?l0003o00000_nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o
0000ojVmj?nY_NP00_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3o`0000?oZKgX1?l0
0002o`00IP;o000000GoVWjco`000?nGN[7oUgZao`000003ohA<Q@03o`000?n4C8GoQ4b500;oQ4b5
0_l00003olN]`003o`000?o4Z;go000000Coa:g200Co0000ol2V_oo0Y[oo00000_o0[<D01?l0003o
_:K3okbV`onlY/<2o`0000Co^ZW800?o0000okNUaol000000_n5CXL3o`0000?o]j_=00Co0000ooO3
Dol0003o00000_nf/=801?l0003o]:_?okB[condZll2o`0000Co/j[?00?o0000ok>WboncYl/00_nc
Yl/2o`0000Co]J;600Go0000okRSa?nhXlCo0000okNM_P03o`0000?o^9fm00?o0000ok2E^on`UK/0
0_n`UK/01?l0003o>6SFocQXe_lhJ=H<o`0000;oXYS;00?o0000okBJ_?ndV[`00ondV[`01?l0003o
a9jbolBN/_l00002olBN/P04o`000?oBXjKodZ>Vo`0000?odZ:V0ol00002oo:bQ`05o`000?oh^Goo
n;UoooRiOol000000on<Ehd01Ol0003onK9`o`000?ol]V[o000000?oS5J<00Co0000oo^cIol0003o
00001?n=Ehd01?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005
ohmJS`;o00000onY_NP00ol0003oZKgXojVmj004o`0002Kooooo000aooooo`03o`000?oooooooooo
00gooooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP00ol0003oZKgXojVmj003o`00
00CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Ko0000
ojVmj?nY_NSoZKgXo`000?nY_NP2o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1?l000000ol006Ko
0000o`000003oiYn/`?o00000on4C8D00ol0003oQ4b5ohA<Q@02ohA<Q@;o00001?o7[L000ol0003o
a:g2olB]`P03olB]`P03o`000?o0Y[oo000000?o`:c500Ko0000okbV`onlY/?o0000okj_bol00004
okZYb003o`000?ngYLOo000000;oQDj70ol00003okN[c@Co00000_nf/=801_l0003o]:_?o`000?l0
003o];3Eo`0000Go/j[?00Ko0000ok>Wbol0003o0000ok:Ubol00004okFRaP03o`000?nhXlCo0000
00Co00000onhWKd2o`0000Go/9Fk0ol00002oif7^`;o00000_mDU^l01Ol0003oQYSNohJHg_n6V=ko
000000CoXYS;00?o0000okBJ_?ndV[`00ondV[`2o`0000?oa9jb00?o0000om:SY_l000001?oBXZH3
o`0000;ol[:700Go0000ooRiOooh^Goon;Uoo`000003ohaGS@03o`000?oi/W3o000000;o00000on<
EX`01Ol0003onk=Wo`000?ok/fOo000000?oSEN=00Co0000oo^cIOl0003onk=U0_l00004ohiISP05
o`000?ok/V?o0000oo^bHol000001On?FXl00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP2o`00
02Gooooo000aooooo`;o00003oooool01?l0003oZKgXojVmj?nY_NP3o`0000?oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX
00Co00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?l000001?l000001?l0
06Ko0000o`000?nJO[<3o`000003ok6J_ol0003oQ4b500;oQ4b500?o0000ohA<QOn4C8D00_n4C8D2
o`0000?oajg00_l00005olB]`P;o00001?o0[<D00ol0003o_:K3o`000003okj_b`04o`000?njZLSo
^ZW8okZYb0;o000000?o^[3?o`000?n5CXL00ol000001?ngZlgo0000o`000?ni]mP3o`0000;o][3B
0_l00004okB`e@03o`000?ncZ/oo/j[?00;o/j[?0_l00004ok:Ub`04o`000?neX/Ko]J;6okFRaP?o
00000ongWKh01_l0003o^9fmokRM_Ol0003o^YZgo`0000Go/9Fk00?o0000oif7^onMQk/01?nMQk/2
o`000003oeBFkol0003oQYSN00;oQYSN00Go0000oj:HbonRV<_oXYS;o`000004okBJ_0;o00001?o4
W[800ol0003odZ>Vo`000005om:RYP;o00000_ob/XL01Ol0003on;UoooRiOooh^Goo000000?oS5N=
00?o0000ooVbL?l000000_l00003ohaFS005o`000?ok/fOo0000oo^cIol000000on=Ehd01?l0003o
nk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005ohmJS`;o000000GoZKgX
o`000?l0003oSe^?o`000004ojVmj0;o00009Oooool0033ooooo00?o0000ooooooooool04?ooool0
0ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj0?o00000onY_NP01?l0003oZKgXojVmj?nY_NP3o`0000CoZKgX00?o0000ojVmj?nY
_NP01?l00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000000_l000001?l006Ko
0000o`000?l00002oiV6_P03o`000?naV[oo000000?oQ4b500?o0000ohA<QOn4C8D00_n4C8D2o`00
00;oajg000Co0000olReb?o8]LSo00000oo4[L800ol0003oa;C;o`000004ol2/a@;o00001?nn[l/0
1?l0003o^ZW8o`000?l00002okfgd`;o000000?oQDj7o`000?l000000_l00003okVgf0;o000000Go
][3Bo`000?l0003o];_No`000004okB`e@03o`000?ncZ/oo000000;o000000?o/:cCo`000?nbYL/0
0onbYL/4o`000003ok:Na?l0003o]ifn00?o]ifn00?o0000okRM_Ol000000onjV[L01ol0003o/9Fk
ok2E^on`UK_o0000okjH/?l000001OnMQk/4o`0000?oQYSN00?o0000oj:HbonRV</00_nRV</01_l0
003o]9ZlokBJ_?l0003o/9_2o`0000Goa9jb0_l00005om:RYPCo00001?oh^Gl02Ol0003oS5N=ohaG
SOn<Ehgo0000ooVbL?l0003oo;IZo`000003ohaFS005o`000?ok/fOo0000oo^cIol000000on=Ehd0
1?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Go0000oo^bHol0003onk9So`000005ohmJS`03o`00
0?ok/V;o000000CoSe^?00Go0000ojVmj?l0003o0000ojVmj002o`0002Cooooo000`ooooo`03o`00
0?oooooooooo017ooooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP01?l0003oZKgX
o`000?l00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVmj?l000000_nY_NP00ol0003o
ZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP8o`0000Co
VHJn0_l00003ohA<Q@09o`000?n4C8GoQ4b5ohA<QOl0003oak;6o`000?o7[L3o000000Cob;G800?o
0000olB]`_l000000oo4]</01_l0003o`:c5ol2/aOl0003o`KK@o`0000Co_Zo;0_l00005okfgd`03
o`000?n5CXOo000000?o00001?ni]mP2o`0000Co];_N00Co0000okB`eOnd/=Go];3E0_l00005ok2/
d`03o`000?nbYL_o000000;o000000?o]J;6o`000?nbW/@00_nbW/@00ol0003o]ifnokNM_P02okNM
_P03o`000?njV[Oo^YZg00;o^YZg00Co0000ok2E^on`UK_o00000_nnV;000ol0003oWHNkoif7^`02
oif7^`;o000000?oIF>ko`000?l000001?l00004oj:Hb`03o`000?ndV[co000000;o/9_200?o0000
olBN/_o4W[800oo4W[800ol0003odZ:Vom:RYP03om:RYP;o000000?odinPo`000?l000001?oh^Gl0
2?l0003oS5N=ohaGSOn<Ehgo0000ooVbL?l0003oo;IZ0_l00002ohaFS005o`000?ok/fOo0000oo^c
Iol000000on=Ehd01?l0003onk=Uo`000?ok/fD2o`0000CoSUV>00Co0000oo^bHol0003onk9S0_l0
0004ohmJS`03o`000?ok/V;o000000GoSe^?00?o0000ojVmj?nY_NP00_nY_NP2o`0002?ooooo000`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX1ol000000oma
Hk?o0000oiV6_P02oiV6_P;o00000on4C8D01?l0003oQ4b5ohA<QOl00002olNbaP;o00001Oo8]LP2
o`0000Coa;C;00?o0000ol2/aOl000000oo1]]001_l0003o_Zo;okj_bol0003o`;kIo`0000Go_KOC
00?o0000ohE>Qol000000_l000000onl`Mko0000okVgf004o`0000Co];_N00Ko0000okB`eOl0003o
0000ojjhhOl00004ok2/d`?o00000_nbYL/2o`0000Co/Yk400Co0000okNM__ngWKko]ifn0_l00004
okZJ]`04o`000?n`UK_o/9Fko`0000?o_YR`00Co0000oif7^onMQk_o00000_o3V:/01?l0003oIF>k
ofES^ol00002odZ=k0Oo00001?n`Vl800ol0003oa9jbolBN/P02olBN/P03o`000?oBXZKodZ:V00?o
dZ:V00?o0000om2QYol000000_l00004ooRiO`0Ao`000?n<EhgoS5N=ohaGSOl0003onK9`o`000?ol
]V[o0000ohaFS?l0003oS5J<o`000?ok/fOo0000oo^cIol000000on=Ehd01?l0003onk=Uo`000?ok
/fD2o`0000CoSUV>00Co0000oo^bHol0003onk9S0_l00004ohmJS`03o`000?ok/V;o000000GoSe^?
00Co0000ojVmj?nY_NSoZKgX0ol0000Sooooo`00<?ooool00ol0003oooooooooo`0Dooooo`;o0000
0_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX
00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Co00001?nY_NP01?l0003oZKgX
o`000?nY_NP5o`0000;oLF>c00Co0000oiV6__nIQ[koVHJn0_l00003ohA<Q@08o`000?n4C8GoQ4b5
o`000?o7//Ko0000olVodOl00003olReb0;o000000?oa[kCo`000?o4]</00oo4]</2o`0000Co`KK@
00?o0000okj_bol000000oo0_]T01?l0003o_KOCokfgdonm]m<2o`000003ohE>Qol0003o000000;o
_<7N0_l00004okG9j@03o`000?nd^mko];_N00?o00001?n^^>44o`000003ok2/dol0003o/ZG;00;o
000000?o[J?=o`000?nbW/@00onbW/@01_l0003o]ifnokNM__l0003o]9Rko`0000Go^YZg0_l00004
okjH/004o`000?nMQk_oWHNko`0000;o`iR[00?o0000ofES^omUHk/00_l00002odZ=k003o`000?n@
VMSoT9WH00;oT9WH00?o0000ok2K`_n`Vl800_n`Vl801ol0003oa9jbolBN/_o4W[;o0000ol6N]Ol0
00000ooBXZH00ol0003od:6Wom2QY`03o`0000Con;Uo017o0000ohaGSOn<EhgoS5N=o`000?oi/W3o
0000oobfJ_l0003oS5J<o`000?n<EXco0000oo^cIol0003onk=Wo`000003oheGS@07o`000?ok/fGo
0000oo^cIOl0003onk=Uo`000003ohiISP04o`000?ok/V?o0000oo^bH`;o00001?n?FXl00ol0003o
nk9Ro`000005ohmKS`Co00000_nY_NP2o`0002;ooooo000`ooooo`?o00005?ooool00ol0003oZKgX
ojVmj002ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP3o`0000;oZKgX00?o0000ojVm
j?nY_NP00_nY_NP3o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY_NSoZKgX
00?o00000onY_NP4o`0000?oLF>c00Go0000oiV6__nIQ[koVHJno`000003ohA<Q@05o`000?n4C8Go
0000olNba_l000000oo9_m400ol0003ob;G8o`000004olJnd`06o`000?o4]<_oa;C;o`000?o2_mOo
00001?o1]]02o`0000Go`;kI00?o0000okfgdol000000_nmcNH5o`0000;o/m[d00?o0000okG9jOne
bNT01?l00003ojS9l@03o`000?n^^>7o000000?o00000_n`[=<3o`0000Co[J?=00?o0000ok:Na?nb
W/@00_nbW/@2o`0000?o]9Rk00?o0000okZJ]onjV[L00_njV[L00ol0003o_YR`okjH/003okjH/003
o`000?nMQk_o000000?o`iR[00Go0000ofES^omUHk_o0000okbC[002o`000003odZ=k?l0003oT9WH
00?oT9WH00Go0000ok2K`_n`Vl;o/9_2o`000002olBN/P04o`000?o1W[Go`Ijeo`0000?odZ:V00Ko
0000om2QYoo@XJOo0000om>OX?l00004ooRiO`09o`000?n<EhgoS5N=ohaGSOl0003onK9`o`000?ol
]V[o000000;oS5J<0_l000001?ok/fOo0000oo^cIol00004oheGS@;o000000Conk=Uo`000?ok/fGo
00001?n>FHh2o`000003oo^bHol0003o000000CoSeZ?00?o0000oo^bH_l000001On?Fhl2o`0000Go
ZKgX0_l0000Qooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?nY_NSoZKgX00Co0000
0onY_NP01?l0003oZKgXo`000?l00002ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l00002
ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003
ojVmj003o`000?nY_NSoZKgX00Co00000omaHk<00ol0003oVHJnoiV6_P02o`0000?oQ4b500Co0000
ohA<QOl0003o00001?o9_m42o`0000Goa[kC00?o0000olBdbol000000oo2_mL01?l0003o`KK@o`00
0?l00002ol38h003o`000?o0_]Wo`;kI00;o`;kI0_l00003okg=iP?o00001?ncf_@3o`0000CoUmgn
00?o0000ojS9lOl000000_l00002ojjhh@Co00000_nV[M`00ol0003o[J?=ojfSc@02ojfSc@04o`00
0?nbW/Co/Yk4ok:Na0;o00001?ndV;/01?l0003o^YZgokZJ]onjV[L2o`0000Ko_YR`00?o0000ol>H
Zoo3V:/00oo3V:/2o`0000?o_9>/1?l00003oi2If003o`000?n`Vl;o/9_200;o/9_20_l00004ol6N
]@04o`000?oBXZKodZ:Vo`0000;od:6W00?o0000om>OX?l000001Ooh^Gl00ol0003oS5N=o`000002
ooVbL003o`000?ol]V[o000000?oS5J<00Go0000oo^cIol0003onk=Wo`000004oheGS@;o000000Co
nk=Uo`000?ok/fGo00001?n>FHh2o`000003oo^bHol0003o000000CoSeZ?00Co0000oo^bH_l0003o
00001?n?Fhl3o`0000;oZKgX1?l0000Qooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo1Ol00005ooooo`03o`000?oooooooooo01Oooooo0_l00004ojVmj003o`000?nY_NSo
ZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVm
j?l00004ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP6o`000003o`00P?l0003oLF>c
00Co000000?o/K7Ho`000?n4C8D00_n4C8D2o`000003olK=gol0003obKoA00;obKoA00Co0000olG=
h?o5cN3o00001?o6_]<2o`0000Co`[oG0_l00005ol38h004o`000?o0_]Wo0000o`0000;o_MS]00?o
0000okg=i_l000001?l000000oncf_Co0000o`000003ofoMk`03o`000?nGgOkoUmgn00So00000_nH
_O400ol0003oYZgLojJ]g002ojJ]g006o`000?n]Xlgo[J?=ojfScOl0003o/Yk40_l000000on]V/?o
0000okBH^`03okBH^`04o`000?njV[Oo^YZgo`0000;o]iFd00?o0000okjH/?nnV;000onnV;000ol0
003o`iR[ol>HZ`03ol>HZ`03o`000?nlTjco_9>/00;o_9>/1?l00003oi2If004o`000?n`Vl;o/9_2
ok2K`P;o00001Oo1W[D00ol0003odZ:Vo`000003om2QY`;o000000?ofZ:Jo`000?oh^Gl00ooh^Gl0
0ol0003oS5N=o`000002ooVbL003o`000?ol]V[o000000?oS5J<00Go0000oo^cIol0003onk=Wo`00
0004oheGS@06o`000?ok/fGo0000o`000?ok/fGo00001?n>FHh00ol0003onk9So`000002o`0000Co
SeZ?00Co0000oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000?oT5b@0_l00009oooo
o`Co000000?o410@ooooooooool04?ooool000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgX
ojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj004o`000?nY_NSo0000o`0000;o
ZKgX1?l000000ol0083o0000o`000002ohbMg`05o`000?na/MSo/K7Ho`000?n4C8D00ol00003olK=
g`03o`000?o9_m7o000000CoaLgP00Ko0000olJndol0003o0000ol7;h_l00003ol:oe`04o`000?nn
dNWo_]7Yo`0000Co`<SP0ol00002okgHkAWo00000onH_O401Ol0003oYZgLojJ]g?nV[Mco000000;o
[J?=0ol00004ojfJ``03o`000?ndV;_o]9Rk00;o]9Rk0_l00003okNE]003o`000?nnV;3o_YR`00;o
_YR`0_l00005ol>HZ`03o`000?nlTjco_9>/00;o_9>/00?o0000olVIY?l000001?l000001_n@VMSo
0000o`000?l0003oYIc<o`0000Go`Ije00?o0000om:RY_l000001?o@XJL00ol0003ofZ:Jo`000004
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`3o`000003oo^cIol0
003oSEN=00?oSEN=00Ko0000oo^cIOl0003o0000oo^cIOl00004ohiISP03o`000?ok/V?o000000;o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G902o`00
00[ooooo00?o0000ooooooooool04_ooool000Gooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
V9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Iooooo`06o`000?nY_NSo0000o`000?nY_NSo
00001?nY_NP3o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Co
00000onY_NP00ol0003oZKgXojVmj004o`0000CoZKgX0ol000000ol0083o0000ohbMg`03ohbMg`03
o`000?na/MSo000000Co00000oo6cMl3o`0000CoaLgP0_l00004ol7;hP03o`000?o2_mOo000000Co
_]7Y00Co0000ol38h?l0003o00000_nhh_@4o`0000;oV^kf1Ol00004oi:9a`Co000000?o[8fdo`00
0?mhNlT01?mhNlT<o`0000;oXioA00?o0000ojfJ`on]V/<00_n]V/<01?l0003o]9RkokBH^ondV;/2
o`0000Go]iFd00Co0000okjH/?nnV;3o00000_nlU:h01?l0003o`iR[ol>HZoo3V:/2o`0000Co_9>/
00Go0000olVIY?l0003oOfjfo`000002oen?j0;o00001?nUW<`00ol0003o`Ijeol6N]@02ol6N]@;o
00001Oo@XJL01?l0003ofZ:JomZRV_l00003ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobf
J_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`06o`000?n=EhgoSEN=oheGSOl0003onk=U
0_l000000ook/fGo0000ohiISP03ohiISP03o`000?ok/V?o000000;o00001?n?FXl01?l0003onk9R
o`000?l00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G902o`0000[ooooo00?o0000oooooooo
ool04_ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool2
o`0001_ooooo0_l00003ojVmj004o`000?nY_NSo0000o`0000;oZKgX00Co0000ojVmj?nY_NSoZKgX
0ol00003ojVmj004o`000?nY_NSoZKgXojVmj0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000Co
ZKgX00?o0000ojVmj?nY_NP01?l00002o`00P006o`000?n<WMooS9gOohbMgol0003o/K7H0_l00003
okCKm003o`000?o6cMoo000000?o^Moc00Ko0000olG=h?l0003o0000okOIlOl00004ol7;hP?o0000
1?nndNT3o`000003okSRm?l0003o000000;oR>_/1Ol000001?nEOkSo0000oiEo^?nEOkP4o`000003
oi:9aol0003o[8fd00?o[8fd00Co0000ogQkbOmhNlWoN7_90_l000000omBJLco0000o`000002oeF`
nP05o`000?n?ZNSoSjWXohnYj?l000001?nSWm401_l0003o[I[3ojfJ`on]V/?o0000okBH^`;o0000
00?o[iBjo`000?ngUK@01?ngUK@01?l0003o_YR`okjH/?l00002okbD[P07o`000?o3V:_o`iR[ol>H
Zol0003o`iJXo`000002okbC[004o`000?o9VJCobIVTo`0000;oOfjf00Co0000oen?j?mOSnSo0000
1?nUW<`01ol0003o`Ijeol6N]Oo1W[Go0000okbN^ol000001Oo@XJL01?l0003ofZ:JomZRV_l00003
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`01_l0003onk=Wo`00
0?l0003onk=Wo`0000?oSEN=00Co0000oo^cIOl0003onk=U0_l00004ohiISP06o`000?ok/V?o0000
o`000?ok/V?o00000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G900
1?n@G903o`0000Wooooo00?o0000ooooooooool04_ooool000Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?nY_NSoZKgX
00?o00001?nY_NP00ol0003oZKgXo`000002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000ojVm
j?l000000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVm
j0?o00000onY_NP;o`0000;o]=_d1?l00002okWOl`?o00001?ngfO401?l0003o`L_Ro`000?l00003
okCJl`04o`000?nndNWo0000o`0000;o[^Oi1ol00003oj25]P03o`000?nEOkSo000000?o00000onB
RLL2o`0000Co[8fd00Co0000ogQkbOmhNlWo00000_ngU;800ol0003oDVW<oe9Yc004o`0000?oSjWX
00Go0000oj>OdOnSWm7oXioAo`000003ojfJ``;o00001?n_U;X00ol0003o]iFdokNE]002okNE]003
o`000?nnV;3o000000?o_9B^00Co0000ol>HZoo3V:_o00000_o3UZP01?l0003o_9>/okbC[?l00002
olVIY004o`000?moK[Ko0000olNGYP;o000000?oGhoXo`000?nUW<`00_nUW<`01?l0003o`Ijeol6N
]Ol00002okbN^`03o`000?o@XJOod:6W00;od:6W0_l00002omZRVP07o`000?oh^Goon;UoooRiOol0
003oS5N=o`000002ooVbL004o`000?ol]V[oo;IZo`0000;oS5J<00Ko0000oo^cIol0003o0000oo^c
Iol00003oheGS@04o`000?ok/fGo0000oo^cI@;o00001?n>FHh01_l0003onk9So`000?l0003onk9S
o`0000CoSeZ?0ol00004ohmKS`;o000000?onk9Po`000?n@G9001?n@G9001?l0003onk5No`000?l0
0008ooooo`03o`000?oooooooooo01;ooooo0005ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool2o`0000?oZKgX00?o0000ojVmj?nY
_NP00ol00004ojVmj003o`000?nY_NSoZKgX00?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgX
o`0000CoZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj0?o00000onRP:l7o`0000;oO^7f
1Ol00002oi;Qo@03o`000?ngfO7o]mWa00Go00000_ndf_<4o`000003ojkWnOl0003o000000?o0000
0onLQKT01?l0003oX8Ffoj25]_nPQKH3o`0000;oUGnh00Ko0000oi:9aonBRLOo0000ojb9/?l00004
ojb=]003o`000?mhNlWo000000?o]iBb00Co0000oe9Yc?mBJLcoDVW<1ol00003oj>Od@06o`000?n]
V/?o0000o`000?nTU<Go00001?n_U;X00ol0003o]iFdokNE]003okNE]003o`000?nlU:ko_9B^00;o
_9B^00?o0000ol>HZol000000oo3UZP00ol0003o_9>/o`000004olVIY0;o00000_o7UjH3o`0000Co
YIc<0_l00004okbN^`07o`000?o@XJOod:6Wom2QYol0003oc:2Zo`000002omZRVP06o`000?oh^Goo
n;Uoo`000?n<Ehgo00000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS004o`000?ok/fOo0000oo^c
I`;o00000on=Ehd01ol0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01_l0003onk9So`00
0?l0003onk9So`0000CoSeZ?0ol00004ohmKS`;o000000?onk9Po`000?l000001?n@G9001?l0003o
nk5No`000?l00008ooooo`03o`000?oooooooooo01;ooooo0005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgX
ojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj005o`000?nY_NSo0000o`000?nY
_NP00_l00005oj:0[`03o`000?nGQKkoUhFn00;oUhFn3Ol00002oi_No@Co00000_nKi_`5o`0000;o
ZIW600?o0000oib5^OnLQKT00_nLQKT3o`000003oj25]_l0003oUGnh00?oUGnh0_l00003ojb9/003
o`000?n/SKCo[8fd00;o[8fd00?o0000okND/_ngU;800_ngU;801?l0003oDVW<o`000?l00003ojJ=
^`03o`000?mDUo3oE9O`00Ko00000onTU<D00ol0003o[iBjojnD^P03ojnD^P04o`000?ngUKCo]iFd
okNE]0;o00001OnlU:h2o`0000?o`iJX00?o0000okbC[?l000001?o9VJ@00ol0003oaiNVolNGYP02
olNGYP03o`000?l0D/Wo000000Co00001OnlW[/01?l0003od:6Wom2QYol00002olbPZP04o`000?oJ
XY[o0000o`0000;on;Uo00?o0000ohaGSOl000000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS003
o`000?ok/fOo000000;onk=W00_o0000oheGSOn=EhgoSEN=o`000?ok/fGo0000oo^cIOl0003onk=U
o`000003ohiISP06o`000?ok/V?o0000o`000?ok/V?o00001?n?FXl3o`0000CoSe^?0_l000000ook
/V3o0000o`000004oi1LT003o`000?ok/Eko000000;o00001oooool00ol0003oooooooooo`0Boooo
o`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?o0000ooooooooool07oooool01?l0003oZKgXo`000?l00002ojVmj004o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVm
j003o`000?nY_NSoZKgX00?o00000_nY_NP2o`0000CoXX2_00?o0000olRKZ?l000001?nGQKh00ol0
003odjbbo`000002ocAQd@[o00000_mjf_`5o`000003ok_9iOl0003oZIW600?oZIW61Ol00003oj25
]P04o`000?nEOkSoUGnhoiEo^0;o00001?n/RK000ol0003o[8fdojb=]002ojb=]003o`000?ngU;;o
]iBb00?o]iBb00?o0000ojJ=^onVSK/00onVSK/2o`0000;oE9O`00Go0000ohjHf?n>V=SoSYSHo`00
0004ojBDa@03o`000?n_U;[o[iBj00;o[iBj00Ko0000okNE]?ngUKCo0000okBA/_l00005okbD[P03
o`000?o3UZSo`iJX00?o`iJX0_l00004olVIY003o`000?o7UjKoaiNV00;oaiNV0ol00003ohVHf`03
o`000?nlW[_o_9jk00?o_9jk00Co0000om2QYoo@XJOo00000_o<X:X01?l0003ofZ:Jo`000?l00002
ooRiO`03o`000?n<Ehgo000000;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`00
0002oo^cI`;o00000_n=Ehd01ol0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01_l0003o
nk9So`000?l0003onk9So`0000CoSeZ?00Co0000oo^bH_l0003o00000on?Fhl00ol0003onk9Po`00
0002o`0000CoT5b@00Ko0000oo^aG_l0003o0000ooooool00004ooooo`03oeEEEOmVIVKo000001Co
oooo000^ooooo`;o00008Oooool2o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP00ol0003oZKgX
ojVmj002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj002ojVmj0?o00000onY_NP00ol0003oZKgX
ojVmj004o`0000?oZKgX00?o0000ojVmj?l000000_l00003oj:0[`03o`000?o8VjSo000000?oUhFn
00Co0000om>//_oC[;;odjbb0_l00003ojNhi@03o`000?lNSn_o000000Wo00001?nkbND00ol0003o
ZIW6o`000002o`0000?oW8Fi00?o0000oj25]_nPQKH00_nPQKH3o`000003ojJ4/?l0003o[8V`00?o
[8V`00Co0000ojb=]?n/SKCo[8fd0_l00005okND/P03o`000?nVSK_oYXfk00?oYXfk00Ko0000ol^N
ZOl0003o0000oeBGl?l00003ohjHf005o`000?nTU<GoY9C5ojBDaOl000001?n_U;X00ol0003o]iFd
o`000003okBA/P03o`000?nlU:ko_9B^00;o_9B^00?o0000ol>FZ?o3UZP00oo3UZP00ol0003obIVT
olVIY002olVIY0;o00000oo7UjH00ol0003odYfOom:MW`02o`0000?oRISK00?o0000okbN^onlW[/0
0_nlW[/00ol0003od:6Wo`000003olbPZP04o`000?oJXY[o0000o`0000;on;Uo00?o0000ohaGSOl0
00000_oi/W001?l0003oo;IZoobfJ_l00002ohaFS003o`000?ok/fOo000000;onk=W0_l00002oheG
S@07o`000?ok/fGo0000oo^cIOl0003onk=Uo`000003ohiISP06o`000?ok/V?o0000o`000?ok/V?o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`Co00001?n@G9001_l0003onk5No`000?l0003o
ooooo`0001_ooooo000^ooooo`03o`000?oooooooooo02;ooooo00?o0000ojVmj?nY_NP00ol00004
ojVmj006o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`00
00CoZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Ko00000_nRP:l01ol0003ob9^XolRKZ?o8VjSo
0000oiN5__l000001?oC[;82o`0000?oYkSU2?l000001On<c_ko0000okO;jOngbnWo000000?o^lWU
0_l00002ojVIaP05o`000?nLQKWoW8Fioib5^Ol000000onPQKH2o`0000?oYXB`00?o0000ojb9/?n/
RK000_n/RK001?l0003o[8fdojb=]?l00002okJ>[@07o`000?ngU;;o]iBbokND/_l0003o`9J[o`00
0003ojJ=^`05o`000?o;WZWobijYo`000?l09Zd00_l00003ohjHf005o`000?nTU<GoY9C5ojBDaOl0
00001?n_U;X2o`0000Co]96b00Co0000okbD[_nlU:ko_9B^0_l00005ol>FZ003o`000?o9VJCobIVT
00;obIVT00?o0000olZHXol000000_o7UjH00ol0003odYfOom:MW`02o`0000?oRISK00?o0000okbN
^onlW[/00onlW[/2o`0000Coc:2Z00So0000omRQW?oHXIco0000ooRiOol0003oS5N=o`0000;onK9`
00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`0;o`000?n=Ehgo0000oheG
SOl0003onk=Uo`000?ok/fGo0000oo^cIOl000000on>FHh01?l0003onk9So`000?ok/V<2o`0000Co
SeZ?00Co0000oo^bH_l0003o00001?n?Fhl4o`0000CoT5b@00Co0000oo^aG_l0003o00000_ooool0
0ol0003oooooooooo`0Hooooo`00;_ooool00ol0003oooooooooo`0Sooooo`;o00000onY_NP00ol0
003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj006o`000?nY_NSo0000
o`000?nY_NSo00001?nY_NP3o`0000;oZKgX0_l000001OmS>X_o0000oj:0[onRP:oo000000?ob9^X
00?o0000oiN5__l000000ooC[;801_l0003oh/6gon;1]ol0003oYkSUo`0000?o`NOa00?o0000og:Q
k_mbXNh00ol00004okO;j@?o000000?o^lWUo`000?nYVLH00_nYVLH01?l0003oW8Fioib5^OnLQKT3
o`000003oin0/_l0003oYXB`00?oYXB`00?o0000ojb9/?n/RK000_n/RK02o`0000?o]Xj]00Co0000
okND/_ngU;;o00000_o0UZ/01Ol0003oYXfkojJ=^onVSK_o000000?obijY1ol00004ojBDa@Co0000
00?oZHnjo`000?ndTK800ondTK801?l0003o_9B^okbD[_l00002ok^B[004o`000?o3UZSo`iJXol>F
Z0;o00001?o9VJ@00ol0003obYRSo`000002olNGYP04o`000?oBWIoodYfOom:MW`?o00000_n9V=/0
1?l0003o_9jkokbN^onlW[/2o`0000Goc:2Z00So0000omRQW?oHXIco0000ooRiOol0003oS5N=o`00
00;onK9`00Co0000oobfJ_ol]V[o00000_n<EX`00ol0003onk=Wo`000002oo^cI`03o`000?n=Ehgo
SEN=00;o000000Konk=Uo`000?ok/fGo0000oo^cIOl00003ohiISP04o`000?ok/V?o0000oo^bH`;o
00001?n?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?n@G9000on@G9000ol0
003onk5No`000002o`0000;ooooo00?o0000ooooooooool05oooool002kooooo00?o0000oooooooo
ool09Oooool00ol0003oZKgXojVmj003o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003
o`000?nY_NSoZKgX00Co00000onY_NP01?l0003oZKgXo`000?l00002ojVmj003o`000?nY_NSoZKgX
00;o000000CoHcZ;o`000?nRP:oo00001Oo8VjP00ol0003odjbbom>//P02om>//P04o`000?oR`KOo
h/6gon;1]`;o00000_o1io44o`0000?oX9oD4Ol00003oin0/P03o`000?nVQ;3oYXB`00;oYXB`00Co
0000ojb9/?n/RK3o[8V`0_l00004okJ>[@04o`000?ngU;;o]iBbo`0000?o`9J[00?o0000ojJ=^ol0
00001?o;WZT01?l0003oNGK4ogUfa?l00002ofJ7gPKo00001?nYSkX00ol0003o]96bokBA/P03okBA
/P;o00000onkTZ`01ol0003o`iJXol>FZ?o3UZSo0000ol>DYol000000_o9VJ@01_l0003obYRSolZH
Xol0003oaiNVo`0000CodYfO0_l000001OljO>Co0000o`000?l0003o_9jk00;o000000?o[ig5o`00
0?o<X:X01?o<X:X01?l0003of:6LomRQW?l00002ooRiO`;o00000_oi/W001?l0003oo;IZoobfJ_l0
0002ohaFS003o`000?ok/fOo000000?onk=W00[o0000oheGSOl0003o0000oo^cIOl0003onk=Uo`00
0?ok/fGo00000on>FHh01?l0003onk9So`000?ok/V<2o`0000CoSeZ?00Co0000oo^bH_l0003o0000
1?n?Fhl2o`000003oo^bH?l0003oT5b@00CoT5b@1?l00002ooooo`03o`000?oooooooooo01Oooooo
000]ooooo`03o`000?oooooooooo02Oooooo0_l00002ojVmj004o`000?nY_NSoZKgXojVmj0?o0000
1?nY_NP00ol0003oZKgXojVmj003o`0000CoZKgX00?o0000ojVmj?nY_NP00ol00004ojVmj005o`00
0?nY_NSo0000o`000?mS>X/00ol00005olRKZ005o`000?oC[;;odjbbom>//_l000001?oR`KL01?l0
003ol^6ko`000?l00002oiB@c@03o`000?nPWmCoX9oD00Go00000_nb^n001Ol0003oMH?CogF3dome
Pm?o000000;oRWg000Go0000oiIm]_nFOKKoUWffo`000004oin0/P05o`000?nVQ;3oYXB`ojJ4/?l0
00000_n/RK000ol0003o[hR/o`000005okJ>[@;o00001?o0UZ/00ol0003oYXfko`000003ol^NZ@03
o`000?o?WZGo000000;oNGK400Co0000ofJ7g_mVQmko00000onESLP00ol0003oZHnjojV?^P03ojV?
^P03o`000?ndTK;o]96b00;o]96b00?o0000ok^B[?nkTZ`00_nkTZ`01?l0003o`iJXol>FZ?l00002
ol>DY`04o`000?o9VJCobIVTo`0000;obYRS00?o0000olNGY_l000001?oBWIl00ol0003o_Y>Yo`00
0003ocYli005o`000?n_WLGo[ig5ojnMaOl000001?o<X:X01Ol0003oain`o`000?oHXIco000000;o
n;Uo0_l00002ooVbL005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`2o`0000?onk=W00[o0000oheG
SOn=Ehgo0000oo^cIOl0003onk=Uo`000?ok/fGo00000on>FHh01ol0003onk9So`000?ok/V?o0000
oo^bHol000000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?l000001?n@
G904o`0000?ooooo00?o0000ooooooooool05_ooool002gooooo00?o0000ooooooooool09oooool0
0ol0003oZKgXojVmj002ojVmj003o`000?nY_NSo000000;oZKgX00?o0000ojVmj?nY_NP00_nY_NP3
o`0000?oZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00Go00000_mS>X/0
0ol0003ob9^XolRKZ003olRKZ003o`000?oFZ:Wo000000;odjbb00Go0000on;1]ooR`KOoh/6go`00
0002oo;Q^`04o`000?nDT<goU93=oiB@c@?o000000CoX9oDo`000?neW;ko00001?nb^n001?l0003o
MH?CogF3dol00002ohYm`005o`000?nFOKKoUWffoiIm]_l000001?nOP;800ol0003oYXB`ojJ4/002
ojJ4/0;o00000_n_R:`00ol0003o]Xj]okJ>[@03okJ>[@03o`000?o0UZ_o`9J[00Co`9J[00?o0000
ol^NZOo;WZT00_o;WZT00ol0003ocijUo`000003ogUfa004o`000?mVQmkoIXONo`0000?oUHg800?o
0000ojV?^_nYSkX00_nYSkX01?l0003o]96bokBA/_ndTK82o`0000Co^i:/00?o0000ol>FZ?l00000
0oo3U:L00ol0003obIVTo`000003olZHX`03o`000?o7UjKo000000CodYfO0_l000001OnnTjWo0000
o`000?ljO>Co000000Co[ig500Oo0000olbPZ_o<X:[oc:2Zo`000?o7Wk3o000000;of:6L00Co0000
ooRiOol0003o00000_oi/W001Ol0003oo;IZoobfJ_ol]V[o000000;oS5J<0_l00003oo^cI`03o`00
0?n=EhgoSEN=00?o000000Conk=Uo`000?ok/fGo00000on>FHh01ol0003onk9So`000?ok/V?o0000
oo^bHol000000on?FXl01?l0003onk9Ro`000?l00004ohmKS`;o000000?onk9Po`000?l000001?n@
G904o`0000Cooooo00?o0000ooooooooool05Oooool002gooooo0_l0000Yooooo`03o`000?nY_NSo
ZKgX00?o00001?nY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol00002ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0ol00003ojVmj0;o00000_mS>X/00ol0003ob9^XolRKZ003olRKZ005o`00
0?oFZ:Wo0000om>//_l000000ooR`KL01Ol0003ol^6koo;Q^ol0003of?FN00?o000000CoU93=o`00
0?nPWmCo00000oneW;h01Ol0003o/[_Pok:kh?nb^n3o000000?oMH?C00Co0000ohYm`?n:OL3o0000
0onFOKH01Ol0003oWh2boin0/_nOP;;o000000?oYXB`0_l00004ojn8[003o`000?nfSZgo]Xj]00;o
]Xj]00?o0000ol2FZoo0UZ/01?o0UZ/00ol0003obijYol^NZ@02ol^NZ@03o`000?o?WZGo000000;o
NGK400?o0000okRG]_l000000_l00003oiF=b003o`000?nYSk[oZHnj00;oZHnj00Ko0000okBA/_nd
TK;o0000ok2>/_l00005ok^B[0;o00000oo3U:L00ol0003obIVTo`000004olZHX`03o`000?oBWIoo
dYfO00;odYfO00?o0000omBNW_l000000_nnTjT2o`000003ocYli?l0003o[ig500;o[ig500Co0000
olbPZ_o<X:[o00000_o7Wk001Ol0003of:6LomRQW?l0003on;Uo00;o00000_oi/W001Ol0003oo;IZ
oobfJ_ol]V[o000000;oS5J<0_l00003oo^cI`08o`000?n=EhgoSEN=o`000?ok/fGo0000oo^cIOl0
0002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0003onk9So`0000?oSeZ?00Co0000
oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000CoT5b@00Co0000oo^aG_l0003o0000
1?ooool00ol0003oooooooooo`0Eooooo`00;Oooool00ol0003oooooooooo`0Yooooo`;o00000onY
_NP00ol0003oZKgXojVmj004o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj006
o`000?nY_NSo0000o`000?nY_NSo00001?nY_NP2o`0000;oHcZ;00?o0000olRKZ?o8VjP00_o8VjP0
1_l0003oeZRYomJXZOl0003odjbbo`0000;oh/6g00?o0000oo;Q^oobhK/01?l00002oiB@c@?o0000
1OneW;h6o`000005ogF3dol0003oRWg0ohYm`?l000000onFOKH01Ol0003oWh2boin0/_nOP;;o0000
00;oYXB`00?o0000ojN2[?l000001?n_R:`01ol0003o]Xj]okJ>[OnfSZgo0000okV>ZOl000001?o0
UZ/2o`0000?obijY00Co0000olnNYOo?WZGocijU0_l00002okRG]P04o`000?lCG=Co0000o`0000?o
UHg800?o0000ojV?^_nYSkX00_nYSkX2o`0000?o/8jb00?o0000ok^B[?nkTZ`00_nkTZ`00ol0003o
`iBWol>DY`03ol>DY`;o00001?o:V:<00ol0003odYfOom:MW`02om:MW`03o`000?oDWYko000000;o
_Y>Y1?l00003ojnMa@03o`000?o<X:[o000000Coain`00Co0000omRQW?l0003on;Uo0_l00002ooVb
L005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`08o`000?n=Ehgo
SEN=o`000?ok/fGo0000oo^cIOl00002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0
003onk9So`0000?oSeZ?00Co0000oo^bH_l0003o00001?n?Fhl2o`000003oo^bH?l0003o000000Co
T5b@00Co0000oo^aG_l0003o00001Oooool00ol0003oooooooooo`0Dooooo`00;Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?nY_NSoZKgX00?o00001?nY_NP00ol0003oZKgXojVmj003o`0000?o
ZKgX00?o0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSo000000?o00000omS>X/01Ol0003o
b9^XolRKZ?o8VjSo000000?oeZRY00Co0000on;1]ooR`KOoh/6g1Ol00002ogiV[@;o00000_nKOk<0
0ol0003o]IbnokFL_P03okFL_P;o00000_n7V]l01?l0003o95S>o`000?l00002ohYm`005o`000?nF
OKKoUWffoiIm]_l000001?nOP;82o`0000;oYh:/00?o0000ojn8[?n_R:`00_n_R:`01?l0003o]Xj]
okJ>[Ol00002okV>Z@03o`000?o0UZ_o`9J[00;o`9J[00?o0000olBFYol000000_o;WZT01Ol0003o
cijUolnNYOo?WZGo000000Co^9Nf00?o0000oa=Le?l000000onESLP00ol0003oZHnjojV?^P03o`00
00Co/8jb00?o0000ok^B[?nkTZ`00_nkTZ`00ol0003o`iBWol>DY`03ol>DY`03o`000?o:V:?obYRS
00?obYRS00?o0000om:MWooBWIl00_oBWIl01Ol0003oe9jNomBNW_l0003o_Y>Y00;o000000?o01VG
o`000?n_WLD00on_WLD2o`0000Coain`00Co0000omRQW?l0003on;Uo0_l00002ooVbL005o`000?ol
]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`05o`000?n=EhgoSEN=o`000?ok
/fD00ol00002oo^cI@0:o`000?n>FHkoSUV>o`000?ok/V?o0000oo^bHol0003onk9So`0000?oSeZ?
00Go0000oo^bH_l0003onk9Ro`000003ohmKS`;o000000?onk9Po`000?l000001?n@G9001?l0003o
nk5No`000?l00004ooooo`03o`000?oooooo000001Gooooo000]ooooo`03o`000?oooooooooo02co
oooo0_l00003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgXojVmj003o`0000Co
ZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`000003of<jR`04o`000?o8VjSob9^Xo`00
00CoeZRY1?l00002oo;Q^`?o00000_mnIZd00ol0003oVgncoi]o/`02oi]o/`05o`000?neW;ko]Ibn
okFL__l000000_o1V[001Ol0003oQi[OohNJgol0003o95S>00;o000000?oRWg0o`000?nFOKH00_nF
OKH01?l0003oWh2boin0/_nOP;82o`0000CoYh:/00Go0000ojn8[?n_R:co[hR/o`000002okJ>[@04
o`000?niSZWo^HjYo`0000?o`9J[00Ko0000olBFYoo4UZOo0000ol^NZOl00004olnNY@03o`000?nh
UkKo^9Nf00;o^9Nf0_l000000olCG=Co0000o`000004o`0000;oWhVl00?o0000ok2>/_n`S[800_n`
S[801?l0003o^i:/ok^B[?nkTZ`2o`0000Go`iBW00?o0000olZHXoo:V:<00oo:V:<2o`0000?odYfO
00?o0000omBNW_oDWYh00_l00002om^SV`03o`000?l06IOo000000Co00001Oo7Wk001?l0003of:6L
o`000?oh^Gl2o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo0000
00;onk=W00So0000oheGSOn=Ehgo0000oo^cIOl0003onk=Uo`0000;onk=U00[o0000ohiIS_n>FHko
0000oo^bHol0003onk9So`000?ok/V?o00000on?FXl01Ol0003onk9Ro`000?ok/V;o000000?oSe^?
0_l000000ook/V3o0000o`000004oi1LT003o`000?ok/Eko000000;o00001Oooool00ol0003ooooo
ooooo`0Cooooo`00;Oooool00ol0003oooooooooo`0/ooooo`03o`000?nY_NSoZKgX00;oZKgX0ol0
0003ojVmj003o`000?nY_NSoZKgX00Co00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX0ol0
0003of<jR`04o`000?o8VjSob9^Xo`0000?oeZRY1ol000001_ofji7o0000okoDG_l0003oOVJ]o`00
00CoVgnc00Co0000okFL__neW;ko00001?o1V[03o`0000;o95S>1?l00003oiIm]P?o000000?oW7b_
o`000?nWPZ`00onWPZ`00ol0003o[hR/ojn8[002ojn8[0;o00001?niSZT01?l0003o`9J[ol2FZol0
0002olBFY`03o`000?o;WZWo000000?ocijU0_l00003okRG]P05o`000?oCXjKo0000oa=Le?l00000
0omlPLd01Ol0003oWhVloin9_?nORKco000000Co/8jb00Co0000ok^B[?nkTZco00000_niT:`01ol0
003o`iBWol>DYoo3U:Oo0000ol>DY_l000000oo:V:<00ol0003oc9VRo`000002om:MW`04o`000?oD
WYkoe9jNomBNWP;o00000ooKXi/2o`0000?oTIOF00?o0000olNO/?o7Wk001?o7Wk000ol0003oeJ2O
o`000002o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000;o
nk=W00Oo0000oheGSOn=Ehgo0000oo^cIOl0003onk=U00;o000000_onk=Uo`000?n>FHkoSUV>o`00
0?ok/V?o0000oo^bHol0003onk9So`000003ohmJS`05o`000?ok/V;o0000oo^bH_l000000on?Fhl2
o`000003oo^bH?l0003o000000CoT5b@00?o0000oo^aG_l000000_l00006ooooo`03o`000?oooooo
oooo01;ooooo000/ooooo`?o0000;_ooool01_l0003oZKgXo`000?l0003oZKgXo`0000CoZKgX0ol0
0002ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol00003ojVmj003o`000?nY_NSoZKgX00Co00000omS
>X/01?l0003ob9^Xo`000?oFZ:T4o`0000;oi[^Z00?o0000ooOEZ?ogeJP00_l00002okoDGP04o`00
0?mnIZgoOVJ]o`0000?oVgnc00?o0000okFL__l000001Oo1V[001_l0003oO8KBogb6d_l0003o95S>
o`0000;oLFk01Ol00003oial[`03o`000?nWPZcoYh:/00;oYh:/00?o0000ojn8[?n_R:`00_n_R:`0
0ol0003o^HjYokV>Z@03okV>Z@03o`000?o0UZ_o000000Coa9JW0_l00003olnNY@03o`000?oBWj;o
000000;o^9Nf00Ko0000om>SY_oCXjKo0000oa=Le?l00002ogb1c@03o`000?nORKcoWhVl00;oWhVl
00Go0000ok2>/_n`S[;o/8jbo`000002ok^B[004o`000?niT:co^I2/o`0000?o`iBW00?o0000ol>D
Y_l000000oo:V:<00ol0003oc9VRo`000002om:MW`03o`000?oDWYkoe9jN00;oe9jN00Co0000om^S
VooKXi_ofj>K0ol00003oi6GeP03o`000?o7Wk3oain`00;oain`0_l000001?oEX9oo0000o`000?l0
0002ooVbL005o`000?ol]V[oo;IZoobfJ_l000000_n<EX`00ol0003onk=Wo`000002oo^cI`07o`00
0?n=EhgoSEN=o`000?ok/fGo0000oo^cI@02o`00000;oo^cIOl0003oSUV>ohiIS_l0003onk9So`00
0?ok/V?o0000oo^bHol000000on?FXl01Ol0003onk9Ro`000?ok/V;o000000?oSe^?0_l000001?ok
/V3o0000oo^bH?l00003oi1LT003o`000?ok/Eko000000;o00001_ooool00ol0003oooooooooo`0B
ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`;o00000onY_NP01?l0003oZKgXo`000?l00002
ojVmj006o`000?nY_NSoZKgXojVmj?l0003oZKgX0_l000000onY_NSo0000ojVmj003ojVmj0?o0000
0_nY_NP2o`0000CoHcZ;0ol00002omJXZ@04o`000?oV^j[oi[^Zo`0000;ommFX00?o0000ooK[TOl0
00000_noe5h01?l0003oOVJ]ogiV[Ol00004oi]o/`03o`000?o1V[3o`IZ`00?o`IZ`00Go0000olRJ
Yol0003oO8KBo`000002obAHcP03o`000?maK/3o000000?oSGJd00?o0000oial[onLO:l00_nLO:l0
1Ol0003oYh:/ojN2[?nWPZco000000?o[hR/0_l00005okV>Z@03o`000?o0UZ_o000000Coa9JW00?o
0000olnNYOo?WZD00_o?WZD01Ol0003odYnRo`000?nhUkKo000000?odj>V0ol00003ogb1c@05o`00
0?nORKcoWhVloin9_?l000001?n`S[82o`0000?o^I2/00Co0000ol>DYoo3U:Oo00000_o3U:H01Ol0
003obYRSolZHXoo:V:?o000000;oc9VR00?o0000om:MWol000001?oDWYh01?l0003ofj>Kom^SVol0
0002omfUVP05o`000?nAUmKoTIOFoi6Ge_l000000oo7Wk001?l0003o_9jio`000?oEX9l3o`0000;o
nK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000;onk=W00Wo0000oheG
SOn=Ehgo0000oo^cIOl0003onk=Uo`000?ok/fD00_l00002ohiISP05o`000?ok/V?o0000oo^bHol0
00000_ok/V<02?l0003oSeZ?ohmJSol0003onk9Ro`000?ok/V;o00000on?Fhl2o`000004oo^bH?l0
003onk9Po`0000?oT5b@00?o0000oo^aG_l000000_l00004ooooo`04o`000?ooooooooooo`0001?o
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo037ooooo00?o0000ojVmj?nY_NP00ol00004ojVmj003o`000?nY
_NSoZKgX00?o00000onY_NP01_l0003oZKgXo`000?l0003oZKgXo`0000?oZKgX0_l000000omS>X_o
0000o`000002o`0000CoeZRY00Co0000onJkZ_oV^j[o00000_ogeJP4o`000005okoDG_l0003oOVJ]
ogiV[Ol000000onKOk<2o`0000Go`IZ`00?o0000olRJYol000000_mlQ]800ol0003o95S>o`000002
og5^`004o`000?n=M[CoSGJdo`0000CoW7b_00Go0000ojN2[?nWPZcoYh:/o`000002ojn8[003o`00
0?naQjWo000000Ko^HjY00?o0000olBFYoo4UZL00oo4UZL01Ol0003ocijUolnNYOo?WZGo000000;o
dYnR00?o0000okRG]_l000000_oCXjH01?l0003og:NNo`000?l00003ogb1c@05o`000?nORKcoWhVl
oin9_?l000000on`S[82o`0000Co^I2/00Co0000ol>DYoo3U:Oo00000oo3U:H00ol0003obYRSo`00
0003olbIXP03o`000?oBWIoo000000Coe9jN00Co0000om^SVooKXi_o00000ooMYIX2o`000005oi6G
e_l0003oain`olNO/?l000000_nlW[T00ol0003oeJ2Oo`000002o`0000;onK9`00Go0000oobfJ_ol
]V[oo;IZo`000002ohaFS003o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok
/fGo000000;onk=U00So0000ohiIS_n>FHko0000oo^bHol0003onk9So`0000;onk9S00So0000ohmJ
Son?FXoo0000oo^bH_l0003onk9Ro`0000?oSe^?0_l000001?ok/V3o0000oo^bH?l00003oi1LT003
o`000?ok/Eko000000;o00001?ooool01Ol0003ooooooooooooooooo000001;ooooo00001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0booooo`;o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP0
0ol00003ojVmj003o`000?nY_NSo000000?o00000omS>X/01Ol0003oeZRYomJXZOoFZ:Wo000000?o
i[^Z00?o0000ooOEZ?ogeJP00ol000000omJ?iSo0000o`000002ogiV[@06o`000?nKOk?oVgnco`00
0?n/Q:Wo00001?o1V[001?l0003ob9ZWolRJYol00002ogb6dP?o00000_maK/001Ol0003oSGJdohef
]?n=M[Co000000?oW7b_00?o0000ojN2[?nWPZ`00_nWPZ`2o`0000?o/HNY00?o0000okV>ZOniSZT0
0oniSZT00ol0003oa9JWolBFY`02olBFY`;o00000oo?WZD01?l0003odYnRom:OX_oBWj82o`0000;o
dj>V00?o0000ombWW_oLYih00ol000000omlPLgo0000oin9_003oin9_0?o000000?oZh^co`000?ni
T:`00oniT:`00ol0003o`iBWo`000004ol>DYP03o`000?o:V:?o000000?oc9VR00?o0000om:MWol0
00000ooDWYh01Ol0003oeZ2No`000?oKXi_o000000?ogJFJ00?o0000oc]egol000000ol00004okbN
^@04o`000?oEX9oo0000o`0000;onK9`00Go0000oobfJ_ol]V[oo;IZo`000002ohaFS003o`000?ok
/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000;onk=U0_l000001_n>FHko
0000oo^bHol0003onk9So`0000;onk9S00So0000ohmJSon?FXoo0000oo^bH_l0003onk9Ro`0000?o
Se^?0_l000001?ok/V3o0000oo^bH?l00003oi1LT003o`000?ok/Eko000000;o00001?ooool01Ol0
003ooooooooooooooooo000001;ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool5o`0000Kooooo00?o0000ooooooooool0<oooool00ol0003oZKgXojVmj004o`0000?oZKgX00?o
0000ojVmj?nY_NP01?l00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?mS>X/00_mS
>X/00ol0003oeJ6Qo`000002omJXZ@04o`000?oV^j[oi[^Zo`0000;ommFX1?l000001?mJ?iSo0000
okoDG_l00002ogiV[@;o00000on/Q:T01?l0003o`IZ`ol6J/?l00004olRJY`;o00000_nDR<@2o`00
0003og5^`?l0003oSGJd00;oSGJd00Go0000oial[onLO:ooW7b_o`000004ojN2[003o`000?naQjWo
/HNY00;o/HNY00?o0000okV>ZOniSZT00_niSZT2o`0000Coa9JW00?o0000olRGY?l000000_o?WZD0
1Ol0003odYnRom:OX_oBWj;o000000?odj>V00?o0000ombWW_oLYih00_l000001Om>J/oo0000o`00
0?l0003oWhVl00?o00000on[Rk<00ol0003o^I2/okV@[003okV@[0;o00001?o3U:H00ol0003obYRS
o`000004olbIXP03o`000?oDWYkoe9jN00;oe9jN00Go0000omJPW_l0003ofj>Ko`000002omfUVP03
o`000?oPZ9[o000000;o>gGO00?o0000okbN^OnlW[T00onlW[T01?l0003oeJ2Oo`000?l00002ooVb
L003o`000?ol]V[oo;IZ00;oo;IZ00Go0000ohaFS?l0003onk=Wo`000003oo^cI`07o`000?n=Ehgo
0000oo^cIOl0003onk=Uo`000003oo^cI@03o`000?n>FHkoSUV>00;o000000Gonk9So`000?ok/V?o
nk9So`000002ohmJS`05o`000?ok/V;o0000oo^bH_l000000on?Fhl2o`000004oo^bH?l0003onk9P
o`0000?oT5b@00?o0000oo^aG_l000000_l00004ooooo`03o`000?oooooo000000?o00004Oooool0
0003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Oooooo
0_l0000eooooo`;o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP0
1?l00003ojVmj0;o00000omS>X/00ol0003oeJ6Qo`000002omJXZ@04o`000?oV^j[oi[^Zo`0000;o
mmFX1Ol000001?mJ?iSo0000o`000?mnIZd2o`0000Co[8BY00Co0000ol6J/?o1V[3o00001?o8VZL0
0ol0003oU8S4oiB8a002oiB8a0;o000000GoLFk0o`000?n=M[CoSGJdo`000003oial[`04o`000?nW
PZcoYh:/ojN2[0;o00001?naQjT01Ol0003o^HjYokV>ZOniSZWo000000;o_8nV00Co0000olBFYoo4
UZOo00000_o8Uj@00ol0003ocijUo`000004om:OXP05o`000?oCXjKodj>Vom>SY_l000000_oLYih3
o`0000;oCV[?0_l00002oi63`003o`000?n[Rk?oZh^c00;oZh^c00?o0000okV@[?niT:`00_niT:`0
0ol0003o`iBVol>DYP04ol>DYP03o`000?o<VJ;oc9VR00?oc9VR00?o0000omBNW_oDWYh00_oDWYh0
1Ol0003oeZ2No`000?oKXi_o000000;ogJFJ00?o0000on2XV_l000000_lkMMl00ol0003o_9jiokbN
^@03okbN^@04o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX00_ol]VX01Ol0003oS5J<
o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U0_l00000
1On>FHko0000o`000?ok/V?o000000;onk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03
o`000?n?FhooSe^?00;o000000Conk9Po`000?ok/V3o00000on@G9001_l0003onk5No`000?l0003o
nk5No`0000;ooooo0ol00002oiiQR0?o00004?ooool00003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04omgMgOmEEEGoooooo`0000Kooooo0_l0000gooooo`04o`000?nY_NSoZKgXojVm
j0?o00001?nY_NP00ol0003oZKgXojVmj004o`0000;oZKgX00?o0000ojVmj?nY_NP00ol00003of<j
R`05o`000?oEXJ7o0000omJXZOl000000ooV^jX01Ol0003ommFXooOEZ?l0003okm]]00?o00000_mJ
?iP2o`000003ohmZXol0003o[8BY00?o[8BY00?o0000ol6J/?l000001?o8VZL00ol0003ocIZQo`00
0003oiB8a004o`000?m3Dkgo0000o`0000;oSGJd00?o0000oial[onLO:l00_nLO:l01Ol0003oYh:/
o`000?nWPJ[o000000Co/HNY00Co0000okV>ZOniSZWo00000onlSjH01?l0003oa9JWolBFYol00002
olRGY003o`000?o?WZGo000000?odYnR00Go0000omFQX?l0003odj>Vo`000003ombWWP03o`000?oN
Z9go000000;oCV[?00Go0000oi63`?nAPl3oTH?0o`000004oj^;/`03o`000?niT:co^I2/00;o^I2/
00?o0000ol>DY_o3U:H01?o3U:H00ol0003oc9VRolbIXP03olbIXP05o`000?oDWYkoe9jNomBNW_l0
00000_oFX9h2o`0000?ogJFJ00?o0000on2XV_oPZ9X00_l000000olkMMoo0000okbN^@03okbN^@04
o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX00_ol]VX01Ol0003oS5J<o`000?ok/fOo
000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U00Go0000ohiIS_l0003o
0000oo^bH`02o`0000;onk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03o`000?n?Fhoo
Se^?00;o000000Conk9Po`000?ok/V3o00000on@G9001Ol0003onk5No`000?l0003onk5N00?o0000
00?oj99Vo`000?l000000_nNHHP3o`00013ooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo03Oooooo00?o0000ojVmj?l0
00000_nY_NP00ol0003oZKgXojVmj002ojVmj0Co000000?oZKgXo`000?nY_NP00_nY_NP3o`0000;o
ZKgX00Co0000of<jRomS>X_o00000ooEXJ42o`0000;oi[^Z00?o0000ooOEZ?ogeJP01_l00002oeXo
V004o`000?n?JZ?oSfZSo`0000Go[8BY0_l00004olRJY`03o`000?o=VZ7o000000;oU8S40ol00000
1Om3Dkgo0000ohef]?n=M[Co000000CoW7b_0_l00003ojN1ZP05o`000?naQjWo/HNYok67ZOl00000
0_niSZT01Ol0003o_8nVokb?Y_nlSjKo000000;oa9JW00Ko0000olRGY?o8UjCo0000olnNYOl00003
om:OXP05o`000?oEXJ3o0000om>SY_l000000ooLYih01?l0003ogZRMomjXWOl00002odiZc`05o`00
0?nAPl3oTH?0oi63`?l000000on[Rk<01ol0003o^I2/okV@[?niT:co0000okN?[?l000001Oo3U:H0
0ol0003oc9VRolbIXP02olbIXP;o00000ooDWYh01Ol0003oeZ2NomJPW_oFX9ko000000?ogJFJ00?o
0000on2XV_oPZ9X01?l00004okbN^@04o`000?oEX9oo0000o`0000;onK9`00?o0000oobfJ_ol]VX0
0_ol]VX01Ol0003oS5J<o`000?ok/fOo000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo
000000?onk=U00Go0000ohiIS_l0003o0000oo^bH`02o`0000;onk9S00Ko0000ohmJSon?FXoo0000
oo^bH_l00002oo^bHP05o`000?n?FhooSe^?o`000?ok/V000_l000000ook/V3o0000oi1LT002oi1L
T006o`000?ok/Eko0000o`000?ok/Eko00000_oXTVH00ol0003obH80o`000002oiiQR004o`000?nY
_NSo0000o`0000oooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo03Sooooo00?o0000ojVmj?nY_NP00_nY_NP00ol0003oZKgXo`000003
o`0000CoZKgX00?o0000ojVmj?l000000_nY_NP01?l0003oZKgXojVmj?l00002of<jR`05o`000?oE
XJ7oeJ6QomFQXOl000000ooV^jX00ol0003ommFXooOEZ006o`0000;oFSnH00Go0000ohmZXon?JZ?o
SfZSo`000004ojb4Z@03o`000?o8VZOob9ZW00?ob9ZW00Go0000olfJXOl0003oU8S4o`000002ok:A
]@03o`000?m3Dkgo@e>m00Co000000CoW7b_o`000?l0003o00001?nWPJX00ol0003o/HNYok67Z@02
ok67Z@;o00001?nlSjH00ol0003oa9JWo`000004olRGY003o`000?oBWj;odYnR00;odYnR00Go0000
omFQX?l0003odj>Vo`000002ombWWP04o`000?oNZ9gogZRMomjXW@;o000000?oCV[?o`000?nAPl00
0_nAPl001Ol0003oZh^coj^;/on[Rk?o000000;o^I2/00Co0000okN?[?ngSjco00001?o3U:H2o`00
00Coc9VR00?o0000olfKX_l000000_oDWYh01Ol0003oeZ2NomJPW_oFX9ko000000?ogJFJ00Co0000
on2XV_oPZ9[oh:RJ1?l00004okbN^@?o00000_oi/W000ol0003oo;IZoobfJP02oobfJP05o`000?n<
EXco0000oo^cIol000000ook/fL01ol0003oSEN=o`000?ok/fGo0000oo^cIOl000000ook/fD01Ol0
003oSUV>ohiIS_l0003onk9S00;o00000_ok/V<01_l0003oSeZ?ohmJSol0003onk9Ro`0000;onk9R
00Go0000ohmKSon?Fhoo0000oo^bH002o`0000;onk9P00Go0000oi1LT?n@G93o0000oo^aGP02o`00
0007oo^aG_l0003oj99VonRBI_l0003obH80o`000002oiiQR003o`000?nY_NSoZKgX00;o00003_oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Gooooo00?o0000oooo
ooooool0>Oooool00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP00ol00004ojVm
j003o`000?nY_NSo000000;oHcZ;00Co0000omFQXOoEXJ7oeJ6Q0_l00002onJkZP05o`000?ogeJSo
mmFXo`000?o_ffd01?l00002oeXoV005o`000?n?JZ?oSfZSohmZXol000001?n/Q:T00ol0003ob9ZW
olRJY`02olRJY`05o`000?o=VZ7ocIZQolfJXOl000000onbTKD01?l0003o@e>mod=C_Ol00002oh1]
]0;o00000_nINJh00ol0003oYh6ZojN1ZP02ojN1ZP03o`000?naQjWo/HNY00;o/HNY00?o0000okb?
Y_nlSjH01?nlSjH2o`0000Cob9NT00Go0000om:OX_oBWj;odYnRo`000003omFQX005o`000?oLYiko
g:NNombWW_l000000ooNZ9d4o`0000?oTH?000?o0000oj^;/on[Rk<00_n[Rk<2o`0000?o]hn/00?o
0000ol>DY_o3U:H00_o3U:H00ol0003o`iFWo`000003olbIXP03o`000?o=Vj;o000000;oe9jN00Go
0000omJPW_oFX9koeZ2No`000002omfUVP03o`000?oPZ9[oh:RJ00;oh:RJ0_l000001?l028go0000
okbN^OnlW[T3o`000005om2OY?l0003onK9`ooVbL?l000001?ol]VX01Ol0003oS5J<o`000?ok/fOo
000000?onk=W00Oo0000oheGSOl0003onk=Uo`000?ok/fGo000000?onk=U00?o0000ohiIS_n>FHh0
1?l00003oo^bH`05o`000?n?FXoo0000oo^bH_l000000_ok/V802_l0003oSe^?ohmKSol0003onk9P
o`000?ok/V3o0000oo^bH?l00002oi1LT006o`000?ok/Eko0000o`000?ok/Eko00000_oXTVH00ol0
003obH80o`000003oiiQR0Co00003_ooool002_ooooo0_l0000kooooo`?o00000_nY_NP00ol0003o
ZKgXojVmj004o`0000?oZKgX00?o0000ojVmj?nY_NP01?l000000omS>X_o0000omFQX@03omFQX@05
o`000?oT/J3o0000o`000?ogeJP00ol000000oo_ffgo0000o`000002o`0000;oFSnH00Go0000ohmZ
Xon?JZ?oSfZSo`000003ojb4Z@;o00001?o8VZL01Ol0003ocIZQolfJXOo=VZ7o000000?o/Y6e0_l0
00001Om3Dkgo0000oh1]]?n0KKCo000000?oVGV^00?o0000ojN1Z_nWPJX00_nWPJX00ol0003o/HNY
ok67Z@02ok67Z@03o`000?nlSjKo_8nV00Co_8nV00?o0000olRGY?o8Uj@00oo8Uj@01Ol0003odYnR
om:OX_oBWj;o000000?oeJ6P00Go0000ombWW_oLYikog:NNo`000002omjXW@04o`000?oPZIco0000
o`0j_P;o00000_nAPl001?l0003oZh^coj^;/on[Rk<2o`0000Go]hn/00Co0000ol>DY_o3U:Ko0000
0_o3UJL01?l0003oc9VRolbIX_l00002olfKXP03o`000?oDWYko000000CoeZ2N00Co0000omfUV_oM
YI[o00001?oPZ9X01?l0003ohjZHo`000?l028d2o`0000;oYIW900Ko0000om2OY?o@WjCo0000ooVb
L?l00004oobfJP05o`000?n<EXco0000oo^cIol000000ook/fL01ol0003oSEN=o`000?ok/fGo0000
oo^cIOl000000ook/fD01Ol0003oSUV>ohiIS_l0003onk9S00;o00000ook/V<00ol0003oSeZ?ohmJ
S`02o`0000;onk9R00[o0000ohmKSon?Fhoo0000oo^bH?l0003onk9Po`000?ok/V3o00000on@G902
o`000003oo^aG_l0003o000000;oj99V00?o0000olV20?l000000onNHHP00ol0003oZKgXojVmj002
o`0000gooooo000[ooooo`03o`000?oooooooooo03Oooooo0ol00002ooooo`03o`000?nY_NSoZKgX
00?o00000onY_NP00ol0003oZKgXojVmj004o`0000?oZKgX00?o0000of<jRol000000ooEXJ401?l0
003oi;6PonBaX?oT/J02o`000003ooC5W?l0003o000000?o000000Go7Q24o`000?mJ?iSoFSnHo`00
0003ohmZX`07o`000?n/Q:Wo[8BYojb4ZOl0003o]hRSo`000002olRJY`03o`000?o=VZ7ocIZQ00;o
cIZQ00?o0000ok:A]OnbTKD00_nbTKD01?l0003o@e>mod=C_Ol00002oh1]]005o`000?nINJkoVGV^
oiUi[_l000000onWPJX01ol0003o/HNYok67ZOnaQjWo0000ok>8Yol000001OnlSjH00ol0003ob9NT
olRGY002olRGY0;o00000ooBWj801Ol0003oeJ6PomFQX?oEXJ3o000000?og:NN00Go0000omjXWOoN
Z9go0000on2YW002o`000005o`0j__l0003o0000o`000?nAPl000ol000000onTR;Ko0000okN?[004
okN?[004o`000?o3U:Ko`iBVo`0000;o`iFW00Co0000olbIX_o<VJ;o00000_o=Vj800ol0003oe9jN
o`000003omJPWP05o`000?oJY9ko0000omfUV_l000000ooPZ9X01?l0003oiJjJo`000?oSZYP2o`00
00?oYIW900Co0000om2OY?o@WjCod9nT0_l00004oobfJP05o`000?n<EXco0000oo^cIol000001?ok
/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00003oo^bH`03
o`000?n?FXooSeZ?00;o00000_ok/V802_l0003oSe^?ohmKSol0003onk9Po`000?ok/V3o0000oo^b
H?l00003oi1LT0;o000000?onk5No`000?l000000_oXTVH01?l0003obH80o`000?l00002oiiQR003
o`000?nY_NSo000000?o00003?ooool002[ooooo00?o0000ooooooooool0=Oooool3o`0000Kooooo
0_l00003ojVmj003o`000?nY_NSoZKgX00?o00000onY_NP00ol0003oZKgXojVmj002o`000003of<j
Rol0003oeJ6Q00;oeJ6Q00Go0000onBaX?oT/J3oi;6Po`000002ooC5W0Go000000Go7Q24o`000?mJ
?iSoFSnHo`000003ohmZX`04o`000?n/Q:Wo[8BYo`0000;o]hRS00Co0000olRJYoo8VZOo00000oo=
VZ400ol0003odIZMo`000002ok:A]@;o00000_m3Dkd01?l0003oP6fdoh1]]?l00003oiUi[P03o`00
0?nWPJ[oYh6Z00;oYh6Z00?o0000ok67ZOl000000_ncR:L00ol0003o_8nVokb?YP02okb?YP;o0000
1?o8Uj@01Ol0003obiVRo`000?oBWj;o000000CoeJ6P00Co0000ombWW_oLYiko00000ooNZ9d01_l0
003oh:VLo`000?l0003o03Zno`0000;oNGS50_l00004ojB8]P03o`000?ngSjco]hn/00;o]hn/00?o
0000ol>DY_l000000oo3UJL00ol0003oc9VRo`000003olfKXP03o`000?oDWYko000000?oeZ2N00Go
0000omZTW_l0003ogJFJo`000003on2XVP04o`000?oU[Y[o0000on>ZV0?o00000onUVLT00ol0003o
d9nTom2OY002o`0000Coo;IZ00Go0000ohaFS?l0003onk=Wo`000004oo^cI`;o000000Conk=Uo`00
0?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<2o`0000?onk9S00So0000ohmJSon?FXoo0000
oo^bH_l0003onk9Ro`0000;oSe^?00Oo0000oo^bH?l0003onk9Po`000?ok/V3o000000?oT5b@0_l0
00001ook/Eko0000oo^aG_l0003oj99Vo`000?o9PP000_l00002oiiQR0;o00000_nY_NP2o`0000co
oooo000Zooooo`03o`000?oooooooooo03;ooooo0ol00009ooooo`03o`000?nY_NSoZKgX00;oZKgX
0ol00003ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?l000001?oEXJ401_l0003oi;6P
onBaX?oT/J3o0000ooC5W0;o000000Gokm]]o`000?o[ceOo0000oah@Q002o`0000;oFSnH00Co0000
ohmZXon?JZ?oSfZS0_l00003okN8X`03o`000?o8VZOo000000CocIZQ00?o0000om6JWOl000000_nb
TKD01Ol0003oaiVWo`000?m3Dkgo000000;oP6fd00Go0000oiUi[_nINJkoVGV^o`000004ojN1ZP;o
00000oncR:L00ol0003o_8nVokb?YP02okb?YP03o`000?o0T:Go000000?ob9NT00Go0000ol^IX_l0
003odYnRo`000003omFQX005o`000?oHXioo0000ombWW_l000000ooNZ9d00ol0003oh:VLon2YW002
o`000005o`0j__l0003oNGS5ogUhaOl000001?nTR;H00ol0003o]hn/okN?[003okN?[0;o00000oo3
UJL00ol0003oc9VRo`000004olfKXP03o`000?oFX9koeZ2N00;oeZ2N00Go0000omZTW_l0003ogJFJ
o`000003on2XVP05o`000?oU[Y[o0000o`000?oW[YL00_l00003ojFIb@03o`000?o@WjCod9nT00?o
00000ool]VX01Ol0003oS5J<o`000?ok/fOo000000Conk=W0_l000001?ok/fGo0000oo^cIOl00004
oo^cI@04o`000?n>FHko0000oo^bH`?o00000_ok/V<01_l0003oSeZ?ohmJSol0003onk9Ro`0000;o
nk9R00Wo0000ohmKSol0003onk9Po`000?ok/V3o0000oo^bH?l000000on@G9002Ol0003onk5No`00
0?l0003onk5No`000?oXTVKo0000olV20002o`0000;oWV6800Co0000ojVmj?nY_NSoZKgX0ol0000;
ooooo`00:_ooool00ol0003oooooooooo`0_ooooo`?o00003Oooool01_l0003oZKgXo`000?l0003o
ZKgXo`0000CoZKgX0ol00003ojVmj0?o00001?oEXJ401?l0003oi;6PonBaX?l00002ooC5W0;o0000
00Cokm]]o`000?o[ceOojlmG0ol00002oeXoV004o`000?n?JZ?oSfZSohmZX`;o00000ongR:<00ol0
003ob9ZWo`000004olfJX@05o`000?oAVYgo0000ok:A]Ol000000_o7VJL3o`0000?oP6fd00Co0000
oiUi[_nINJko00000onWPJX2o`0000Go/hRW00Co0000okb?Y_nlSjKo00000_o0T:D01?l0003ob9NT
olRGY?l00002ol^IXP03o`000?oBWj;o000000?oeJ6P00Go0000omRSWol0003og:NNo`000002omjX
W@06o`000?oPZIcoh:VLon2YW?l0003odZ>V0_l00002ogUha@03o`000?nTR;KoY8Rf00;oY8Rf00?o
0000okN?[?ngSj`00ongSj`00ol0003o`iFWol>EY`03ol>EY`;o00001?o=Vj801Ol0003oeZ2NomJP
W_oFX9ko000000;ofZBN0_l00004on2XVP04o`000?oU[Y[oiJjJo`0000;oijjG00Go0000ojFIbOnU
VLWoYIW9o`000002om2OY004o`000?o:WjcobYn/o`0000;oo;IZ00Go0000ohaFS?l0003onk=Wo`00
0004oo^cI`;o000000Conk=Uo`000?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<3o`0000;o
nk9S00Ko0000ohmJSon?FXoo0000oo^bH_l00002oo^bHP03o`000?n?FhooSe^?00;o000000Conk9P
o`000?ok/V3o00000on@G9002Ol0003onk5No`000?l0003onk5No`000?oXTVKo0000olV20002o`00
00;oWV681?l000001?nY_NSo0000o`000?l0000:ooooo`00:_ooool00ol0003oooooooooo`0/oooo
o`?o00004Oooool2o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004ojVmj0?o00000ooE
XJ401Ol0003oi;6PonBaX?oT/J3o000000;om<FL1?l00002on_?E`03o`000?lN48Co000000;oFSnH
00Go0000ohmZXon?JZ?oSfZSo`000005okN8X`;o00000oo=VZ401?l0003odIZMom6JWOoAVYd2o`00
00;oaiVW00Co0000o`0JYOl0003o00000_n0KK@01?l0003oVGV^oiUi[_l00002ojN1ZP03o`000?nW
P:Wo000000Go/hRW00Co0000okb?Y_nlSjKo00000_o0T:D01?l0003ob9NTolRGY?l00003ol^IXP03
o`000?oEXJ3oeJ6P00;oeJ6P00Go0000omRSWol0003og:NNo`000002omjXW@06o`000?oPZIcoh:VL
on2YW?l0003odZ>V0_l00003ogUha@03o`000?nTR;KoY8Rf00;oY8Rf00Co0000okN?[?ngSjco]hn/
0_l00005ol>EY`03o`000?o=Vj;ocI^R00?ocI^R00Go0000omJPW_oFX9koeZ2No`000003omZTWP05
o`000?oPZ9[oh:RJon2XV_l000000ooU[YX00ol0003oijjGonN^U`03o`000004ojFIbOl0003od9nT
o`0000?obYn/00Co0000oobfJ_ol]V[oo;IZ0_l000000ook/fOo0000oo^cI`03oo^cI`;o000000Co
nk=Uo`000?ok/fGo00001?ok/fD01?l0003oSUV>o`000?ok/V<2o`000004oo^bHol0003onk9So`00
00;oSeZ?00?o0000oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0003onk9P
oo^bH?l000000_n@G9002Ol0003onk5No`000?l0003onk5No`000?oXTVKo0000olV20002o`0000;o
WV680_l00004ojVmj0;o00002_ooool002[ooooo0_l0000[ooooo`;o00005_ooool00ol0003oZKgX
ojVmj003o`0000?oZKgX00Ko0000ojVmj?l0003o0000ojVmj?l00004omFQX@05o`000?oT/J3oi;6P
onBaX?l000000_odaI`01?l0003okm]]o`000?l00002on_?E`03o`000?lN48Co000000;oFSnH00?o
0000ohmZXon?JZ<00_l00005okN8X`03o`000?o=VZ7ocIZQ00;ocIZQ00Go0000om6JWOoAVYgodIZM
o`000003olNIY`;o000000Go01ZUo`000?l0003oP6fdo`000003oiUi[P;o00000_nWP:T00ol0003o
/hRWok>8Y`03ok>8Y`03o`000?nlSjKo000000?o`92U00?o0000olRGY?l000001?o;VJ801Ol0003o
eJ6PomFQX?oEXJ3o000000?of:>O00Go0000omjXWOoNZ9gogZRMo`000003on2YW0;o000000?odZ>V
o`000?l000000_miN<D00ol0003oY8RfojB8]P02ojB8]P06o`000?ngSjco]hn/o`000?neSjoo0000
1Oo3UJL00ol0003ocI^RolfKXP02olfKXP;o00000ooFX9h01Ol0003ofZBNomZTW_oJY9ko000000?o
h:RJ00Go0000onF^V_oU[Y[oiJjJo`000002onN^U`;o000000?oHX;Lo`000?l000000_l00003olZO
[004o`000?ol]V[oo;IZoobfJP;o000000?onk=Wo`000?ok/fL00ook/fL01_l0003oSEN=o`000?l0
003onk=Uo`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00002oo^bH`;o00000_n?FXl00ol0003o
nk9Ro`000002oo^bHP03o`000?n?FhooSe^?00;o000000Gonk9Po`000?ok/V3onk9Po`000002oi1L
T008o`000?ok/Eko0000o`000?ok/Eko0000onRBI_l00002olV20006o`000?nNHHSoWV68o`000?nY
_NSo00000_nY_NP3o`0000[ooooo000Zooooo`03o`000?oooooooooo02Oooooo0ol0000Iooooo`;o
00000onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000omFQXOoEXJ400_oEXJ401?l0003o
i;6PonBaX?l00002ooC5W0;o000000?okm]]o`000?l000000_o[ceL02_l0003o7Q24o`000?l0003o
FSnHo`000?n?JZ?o0000oj1cWol00005okN8X`03o`000?o=VZ7ocIZQ00;ocIZQ00Go0000om6JWOoA
VYgodIZMo`000003olNIY`;o000000?o01ZUo`000?mZH;D00ol000000onINJko0000o`000004ojN0
Z@03o`000?ncR:Oo/hRW00?o/hRW0_l00003ol2@Y@03o`000?o8UjCo000000CobiVR00Go0000omFQ
X?oEXJ3oeJ6Po`000003omRSW`05o`000?oNZ9gogZRMomjXWOl000000ooPZI`2o`000006om:SY_l0
003o0000o`000?miN<Go00001?nTR;H00ol0003o]hn/o`000003okF?[`04o`000?o3UJOo`iFWol>E
Y`;o00001?o=Vj800ol0003od9jSo`000002omJPWP05o`000?oJY9kofZBNomZTW_l000000ooPZ9X0
1?l0003oiJjJonF^V_oU[YX2o`000004onN^Uol0003ok;FGo`0000;oHX;L00?o0000olZO[?o:Wj`0
0oo:Wj`00ol0003oo;IZoobfJP02o`000003oo^cIol0003onk=W00?onk=W00Ko0000oheGSOl0003o
0000oo^cIOl00004oo^cI@04o`000?n>FHko0000oo^bH`;o00000ook/V<01_l0003oSeZ?ohmJSol0
003onk9Ro`0000;onk9R00?o0000ohmKSon?Fhl00_l000001Ook/V3o0000oo^bH?ok/V3o000000;o
T5b@00Go0000oo^aG_l0003o0000oo^aGP02o`0000?obH800_l000000onNHHSo0000o`000003o`00
00;ooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000ooooooooool09Oooool3o`0001go
oooo00?o0000ojVmj?nY_NP01?l00003ojVmj004o`000?nY_NSo0000o`0000?oeJ6Q00Co0000onBa
X?oT/J3o00000_odaI`4o`0000?ojlmG00Co0000oah@Q?l0003oN5:I0ol00002oj1cW`03o`000?ng
R:?o]hRS00;o]hRS0_l00003olfJX@03o`000?oAVYgodIZM00;odIZM00Ko0000olNIYoo7VJOoaiVW
o`000?oEWYd2o`0000?oJV2e0_l000000onDMZko0000ojN0Z@03ojN0Z@03o`000?ncR:Oo/hRW00?o
/hRW00?o0000ol2@YOo0T:D00oo0T:D2o`0000?obiVR0_l00003omFQX005o`000?oHXioof:>OomRS
Wol000000ooNZ9d01ol0003oh:VLon2YW?l0003ohZ^Ko`000?oBXjH00_l000001?m;Hl[o0000o`00
0?l00002ojB8]P?o00001?neSjl01ol0003o`iFWol>EYoo3UJOo0000olBGZOl000000oo=Vj801Ol0
003od9jSo`000?oFX9ko000000CofZBN00Go0000on2XV_oPZ9[oh:RJo`000002onF^VP04o`000?o/
]i_o0000o`0000;ok;FG00Co0000of:2g?mRP]co00001Oo:Wj`00ol0003oo;IZoobfJP02o`000003
oo^cIol0003onk=W00?onk=W00Co0000oheGSOl0003onk=U0_l00004oo^cI@04o`000?n>FHko0000
oo^bH`;o00000ook/V<2o`000004ohmJSol0003onk9Ro`0000;onk9R00?o0000ohmKSon?Fhl00_l0
00001Ook/V3o0000oo^bH?ok/V3o000000;oT5b@00Co0000oo^aG_l0003o00000_ok/Eh01?l0003o
bH80olV20?o9PP02o`0000;oWV6800?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`00:Oooool00ol0003oooooooooo`0Rooooo`?o00008Oooool2o`0000?oZKgX00?o0000ojVmj?nY
_NP01Ol00002omFQX@05o`000?oT/J3oi;6PonBaX?l000000_odaI`4o`0000?ojlmG00?o0000oah@
Q?l000000_mhDYT00ol0003oX7>Ooj1cW`02oj1cW`07o`000?ngR:?o]hRSokN8Xol0003o_h^No`00
0002olfJX@09o`000?oAVYgodIZMom6JWOl0003odi^Jo`000?o7VJOo000000;oeIjM00?o0000o`0J
YOl000000_mZH;D01?l0003oU7J^oiAf[_l00004ojN0Z@03o`000?ncR:Oo/hRW00?o/hRW00?o0000
ol2@YOo0T:D00oo0T:D00ol0003obiVRol^IXP02ol^IXP03o`000?o?W:7o000000;oeJ6P00Go0000
omRSWooHXioof:>Oo`000002omjXW@05o`000?oPZIcoh:VLon2YW?l000000_oRZi/01?l0003oh:RK
o`000?l00002od]SbP?o00000_nJQK`00ol0003o]Hn_okF?[`02okF?[`04o`000?o3UJOo`iFWo`00
00;oa9NY00Co0000olfKX_o=Vj;o00000_o@WZ<00ol0003oeZ2No`000003omZTWP05o`000?oNZYoo
0000on2XV_l000000ooU[YX01?l0003ok;NKo`000?l00002onbeU`;o00000_mRP]`00ol0003obYn/
olZO[002olZO[003o`000?ol]V[oo;IZ00;o000000?onk=Wo`000?ok/fL00ook/fL01?l0003oSEN=
o`000?ok/fD2o`0000Conk=U00Co0000ohiIS_l0003onk9S0_l00004oo^bH`05o`000?n?FXoo0000
oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0003onk9Poo^bH?l000000_n@
G9001?l0003onk5No`000?l00002oo^aGP04o`000?o9PP3obH80olV200;o00000_nNHHP00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo01oooooo
0ol0000Uooooo`03o`000?nY_NSoZKgX00Co00000onY_NP2o`0000;oeJ6Q00Co0000onBaX?oT/J3o
00000_odaI`7o`000004on_?Eol0003o7Q24o`0000;oN5:I00?o0000oj1cWonPLil00_nPLil01ol0
003o]hRSokN8XongR:?o0000okn;W_l000000_o=VZ402Ol0003odIZMom6JWOoAVYgo0000om>KV_l0
003oaiVWo`000002omFNW@?o00000_mZH;D01Ol0003oU7J^oiAf[_nDMZko000000CoYh2Y00Co0000
ok>8YoncR:Oo/hRW0_l00005ol2@Y@03o`000?o;VJ;obiVR00;obiVR00Go0000olnLXOl0003oeJ6P
o`000003omRSW`05o`000?oLYYko0000omjXWOl000000ooPZI`01?l0003ohZ^Kon:[Vol00002on2X
V`04o`000?m;Hl[oBf?:o`0000CoVXFl00?o0000okF?[oneSjl00_neSjl01?l0003o`iFWol>EYol0
0002olBGZ@04o`000?o=Vj;ocI^Ro`0000;od9jS00?o0000omJPW_l000000ooJY9h01Ol0003ogZZO
o`000?oPZ9[o000000?oiJjJ00Co0000onbgVoo/]i_o00000_o/]IL3o`000003of:2g?l0003obYn/
00CobYn/00Ko0000oobfJ_l0003o0000oo^cIol00004oo^cI`04o`000?n=Ehgo0000oo^cI@;o0000
1Ook/fD2o`000003oo^bHol0003o000000Conk9S0ol000001Ook/V;o0000oo^bH_ok/V;o000000;o
Se^?0_l000001Ook/V3o0000oo^bH?ok/V3o000000;oT5b@00Co0000oo^aG_l0003o00000_ok/Eh0
1?l0003obH80olV20?o9PP02o`0000;oWV6800?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`00:Oooool3o`0001cooooo0ol0000Yooooo`;o00000onY_NP00ol0003oZKgXojVmj002
o`000004oc<?MOl0003oeJ6Qo`0000;oi;6P00?o0000ooC5W?odaI`01_l000001OoobgKo0000o`00
0?lN48Co000000;oN5:I00?o0000oj1cWonPLil00_nPLil01?l0003o]hRSokN8Xol00002okn;WP03
o`000?o=VZ7o000000CodIZM00Go0000om>KV_l0003oaiVWo`000002omFNW@?o00000omZH;D01?l0
003oU7J^oiAf[_l00004ojN0Z@04o`000?ncR:Oo/hRWo`0000;o]XVV00Co0000ol2@YOo0T:Go`92U
0_l00003ol^IXP06o`000?o?W:7ocibQo`000?oEXJ3o00000ooHXil01Ol0003og:JNo`000?oNZ9go
000000?oh:VL00Co0000on:[VooRZi_o00000_oPZ9/01Ol0003oBf?:od]Sb_m;Hl[o000000CoVXFl
00Oo0000okF?[oneSjoo]Hn_o`000?o3UJOo000000?oa9NY00?o0000olfKX_l000001?o@WZ<00ol0
003ofZBNomZTWP02omZTWP05o`000?oNZYoo0000on2XV_l000000ooU[YX01?l0003ok;NKonbgVol0
0002onbeU`06o`000?oc`IWo0000o`000?mRP]co00000oo:Wj`2o`000005oobfJ_l0003o0000oo^c
Iol000001Ook/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000_ok/V800ol0003oSe^?ohmKS`02o`000005oo^bH?l0
003onk9Poo^bH?l000000_n@G9001?l0003onk5No`000?l00002oo^aGP04o`000?o9PP3obH80olV2
00;o00000_nNHHP00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03
o`000?oooooooooo01Wooooo0ol0000^ooooo`03o`000?nY_NSoZKgX00?o000000KoZKgXo`000?lc
3gGo0000omFQXOl00002onBaX003o`000?odaIcom<FL00Ko000000Gool]fo`000?l0003o7Q24o`00
0002ogQBV@03o`000?nPLiooX7>O00;oX7>O00Co0000okN8XongR:?o00000_noRih00ol0003ocIZQ
o`000004om6JW@05o`000?oCVi[o0000olNIYol000000_oEWYd3o`0000?oJV2e00Co0000oiAf[_nD
MZko00001?nWP:T01?l0003o/hRWok>8Yol00002okJ9YP07o`000?o0T:Go`92Uol2@YOl0003oa9>T
o`000002ol^IXP06o`000?o?W:7ocibQo`000?oEXJ3o00000ooHXil01Ol0003og:JNo`000?oNZ9go
000000?oh:VL00?o0000on:[VooRZi/00_l00002on2XV`;o000000?oBf?:o`000?nJQK`00onJQK`0
0ol0003o]Hn_okF?[`02okF?[`;o00000oo4UjT00ol0003ocI^Ro`000004om2NX`03o`000?oJY9ko
fZBN00;ofZBN00Go0000omjZWol0003oh:RJo`000002onF^VP04o`000?o/]i_ok;NKonbgV`;o0000
00Cok;FGo`000?oc`IWoll6I0ol00002olZO[004o`000?nlWk_o0000oobfJP;o000000?onk=Wo`00
0?ok/fL01?ok/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000ook/V801_l0003oSe^?o`000?l0003onk9Po`0000;o
nk9P00Go0000oi1LT?n@G93o0000oo^aGP02o`0000;onk5N00Co0000olV20?o9PP3obH800_l00002
oiiQR003o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00003o`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01Kooooo
0ol0000booooo`;o00000onY_NP2o`000003oc<?MOl0003o000000?oi;6P00?o0000ooC5W?odaI`0
0_l000001Oood8;o0000o`000?l0003ool]f00;o000000Go7Q24o`000?mhDYWoN5:Io`000004oj1c
W`04o`000?ngR:?o]hRSo`0000;o_h^N00?o0000olfJXOl000000ooAVYd01Ol0003odi^Jom>KV_oC
Vi[o000000?oeIjM00Co0000om^QUol0003o00000_mZH;D01Ol0003oU7J^oiAf[_nDMZko000000Co
Yh2Y0_l00003okJ9YP04o`000?o0T:Go`92Uo`0000;oa9>T00Co0000ol^IX_o;VJ;o00000oo?W:40
0ol0003of:>OomRSW`02omRSW`04o`000?oLYYkog:JNo`0000?oh:VL00Co0000on:[VooRZi_ohZ^K
0_l00002on2XV`05o`000?l0<KWo0000od]Sb_l000000onJQK`01?l0003o]Hn_okF?[oneSjl2o`00
00Goa9NY0_l00004om2NX`03o`000?oJY9kofZBN00;ofZBN00Co0000omjZWooNZYoo00000ooU[YX0
1Ol0003ok;NKonbgVol0003om/NL00;o00000_oc`IT2o`000004o`0KXol0003obYn/o`0000?o_9nk
0ol000000ook/fOo0000oo^cI`04oo^cI`;o000000Conk=Uo`000?ok/fGo00001?ok/fD2o`000003
oo^bHol0003o000000Conk9S00?o0000ohmJSol000000_l00003oo^bHP06o`000?n?Fhoo0000o`00
0?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000;onk5N00Wo0000olV20?o9PP3obH80
o`000?nmPYCo0000oiiQR?l000001_ooool00ol0003oooooooooo`07ooooo`0000?ooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool05?oo
ool2o`0003Gooooo00?o0000ojVmj?nY_NP00_nY_NP2o`0000;o<`me00Co0000onBaX?oT/J3o0000
0_odaI`3o`000003ooo@P_l0003o000000;ool]f0_l000000olN48Co0000ogQBV@02ogQBV@07o`00
0?nPLiooX7>Ooj1cWol0003o]hRSo`000004okn;WP03o`000?oAVYgodIZM00;odIZM00Go0000om>K
V_oCVi[odi^Jo`000003omFNW@03o`000?oKXIOo000000;o000000?oJV2eo`000?nDMZh00_nDMZh0
0ol0003oYh2YojN0Z@02ojN0Z@03o`000?nfRJKo]XVV00;o]XVV00Co0000ol2@YOo0T:Go00000_o4
Tj@00ol0003obiVRo`000004olnLX@05o`000?oHXioof:>OomRSWol000000ooLYYh01Ol0003oh:VL
on2YW?oPZIco000000;ohZ^K00Go0000onB^W?oT[Yco0000on2XV`02o`000003o`0a^Ol0003o0000
00?oVXFl00Ko0000okF?[oneSjoo0000ok:A]?l00005olBGZ@03o`000?o@WZ?od9jS00;od9jS00?o
0000omBTYOl000000_oJY9h01Ol0003ogZZOomjZWooNZYoo000000?oiJjJ00Go0000onbgVoo/]i_o
0000ooK7W002o`0000;oll6I00Go0000oogIVol0003o01^So`000004okbO^`?o000000?onk=Wo`00
0?ok/fL01?ok/fL2o`000004oo^cIOl0003onk=Uo`0000Conk=U0_l000000ook/V?o0000o`000004
oo^bH`05o`000?n?FXoo0000oo^bH_l000000ook/V801_l0003oSe^?o`000?l0003onk9Po`0000?o
nk9P00Wo0000oi1LT?l0003onk5No`000?ok/Eko0000oo^aG_l000000oo9PP001Ol0003o_H:Do`00
0?nNHHSo000000Kooooo00?o0000ooooooooool01oooool000;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Booooo`?o0000>?ooool01_l0
003oZKgXo`000?l0003oZKgXo`0000;o<`me00Co0000onBaX?oT/J3o00000_odaI`2o`000004ooo@
P_l0003o0000o`0000;ool]f1?l00003ogQBV@03o`000?nPLiooX7>O00;oX7>O0_l00004okn;WP03
o`000?oAVYgodIZM00;odIZM00Go0000om>KV_oCVi[odi^Jo`000003omFNW@05o`000?oKXIOo0000
o`000?loBK@00_l00003oiAf[P04o`000?nWP:WoYh2YojN0Z@;o00001?nfRJH01?l0003o`92Uol2@
YOl00002olBCY003o`000?o;VJ;o000000CocibQ00Go0000omRSWooHXioof:>Oo`000003ombVWP05
o`000?oPZIcoh:VLon2YW?l000000_oRZi/00ol0003oi:jLonB^W002o`0000;ogZRL00?o0000o`0a
^Ol000001?nJQK`2o`0000;o/Y6d00?o0000olBGZOo4UjT00oo4UjT00ol0003od9jSom2NX`02om2N
X`03o`000?oDY:Go000000;ofZBN00Go0000omjZWooNZYoogZZOo`000002onF^VP05o`000?o/]i_o
k;NKonbgVol000000_ofai`01Ol0003oll6Ioo?1VOl0003ooMVK00?o00001?nlWk/3o`000003oo^c
Iol0003onk=W00Conk=W0_l000001?ok/fGo0000oo^cIOl00004oo^cI@;o000000?onk9So`000?l0
00001?ok/V<01Ol0003oSeZ?o`000?ok/V;o000000?onk9R00Co0000ohmKSol0003onk9P0_l00003
oo^bH007o`000?n@G93o0000oo^aG_l0003onk5No`000002oo^aGP04o`000?o9PP3obH80olV200;o
000000?oWV68o`000?ooool01Oooool00ol0003oooooooooo`07ooooo`000_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo00oooooo0ol0000l
ooooo`03o`000?nY_NSoZKgX00;o00000olc3gD00ol0003oi;6Po`000002ooC5W0;o000000Ooom22
o`000?l0003o0000ooo;M_l0003ooLm^00;o000000Go7Q24o`000?mhDYWoN5:Io`000004oj1cW`;o
00001?noRih00ol0003odIZMom6JW@02om6JW@05o`000?oCVi[odi^Jom>KV_l000000_oEWYd01Ol0
003ofj6Gom^QUooKXIOo000000;o?dVd0_l00002oiAf[P06o`000?nWP:WoYh2Yo`000?nWPJ[o0000
1OnfRJH2o`0000?oa9>T00?o0000ol^IX_l000001?o?W:401Ol0003of:>OomRSWooHXioo000000?o
g:JN0_l00002on2YW004o`000?oRZi_ohZ^Ko`0000;oi:jL0_l00003omjXW003o`000?l0<KWo0000
00Co00001?nbTK@01?l0003oa9NYolBGZOo4UjT2o`0000Cod9jS00?o0000omBTYOl000000_oJY9h0
1?l0003ogZZOomjZWooNZYl2o`000003onF^V_l0003ok;NK00;ok;NK00Co0000ooK7W?ofaico0000
0_oc`IT01?l0003ooMVKo`000?nfOYL2o`0000?o_9nk0ol000000ook/fOo0000oo^cI`04oo^cI`;o
000000Conk=Uo`000?ok/fGo00001?ok/fD2o`000003oo^bHol0003o000000Gonk9S0_l000000ook
/V;o0000o`000002oo^bHP04o`000?n?Fhoo0000oo^bH0;o00000ook/V001ol0003oT5b@o`000?ok
/Eko0000oo^aG_l000000_ok/Eh01?l0003obH80olV20?o9PP02o`000003oiiQR?l0003ooooo00Ko
oooo00?o0000ooooooooool01_ooool000;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01Oooool2o`0000gooooo0ol00010ooooo`04o`000?nY_NSo0000o`0000?o<`me0_l0
0003ooC5W0;o000000Ooom22o`000?l0003o0000ooo;M_l0003ooLm^00;o000000Go7Q24o`000?mh
DYWoN5:Io`000004oj1cW`03o`000?noRiko_h^N00?o_h^N00Go0000om6JWOoAVYgodIZMo`000003
om>KVP05o`000?oFViSo0000omFNWOl000000ooKXIL2o`0000;o?dVd0ol000000onDMZko0000o`00
0002ojN1ZP03o`000?nfRJKo]XVV00?o]XVV0_l00004olBCY003o`000?o?W:7ocibQ00;ocibQ00Go
0000om>PXOl0003of:>Oo`000003ombVWP03o`000?oOZYgo000000;oh:VL00Co0000on:[VooRZi_o
00000ooT[Y`01ol0003ogZRLomjXW?oNZ9co0000o`0a^Ol000000on6PLH00ol0003o/Y6dok:A]002
ok:A]007o`000?o4UjWoa9NYolBGZOl0003oaY^]o`000002om2NX`07o`000?oDY:Goe:BUomBTYOl0
003ofZBNo`000002omjZW`05o`000?oV]J;o0000onF^V_l000000oo/]i/01?l0003om/NLo`000?om
hiH2o`0000;ooMVK00Co0000okInUol0003o00000onlWk/3o`000003oo^cIol0003onk=W00Conk=W
0_l000001?ok/fGo0000oo^cIOl00004oo^cI@;o000000Conk9So`000?ok/V?o00001?ok/V<2o`00
0009oo^bH_l0003onk9Ro`000?ok/V;o0000ohmKSol0003onk9P00;o00000ook/V001ol0003oT5b@
o`000?ok/Eko0000oo^aG_l000000_ok/Eh01?l0003obH80olV20?o9PP02o`0000;oWV6800?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`000_ooool00ol@413oooooooooo`09oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
EEEEohN7Qoooool01oooool00ol0003oooooooooo`09ooooo`?o0000A?ooool3o`0000Co<`me1_l0
00001oood8;o0000o`000?l0003ool]fo`000?omcfh00_l000001OlN48Co0000ogQBVOmhDYWo0000
00CoX7>O00?o0000okn;W_noRih00_noRih2o`0000?odIZM00Wo0000om>KV_oCVi[odi^Jo`000?oF
ViSo0000omFNWOl000000ooKXIL2o`0000;o?dVd00?o0000ohab/?n<L[000_l00004ojN1ZP03o`00
0?nfRJKo]XVV00;o]XVV00?o0000olBCY?o4Tj@00oo4Tj@00ol0003ocibQolnLX@02olnLX@05o`00
0?oCX:7o0000omRSWol000000ooLYYh01_l0003ogjZMomnZWOl0003oh:VLo`0000;ohZ^K00Go0000
onB^W?oT[Ycoi:jLo`000002omjXW005o`000?oMYiko0000o`0a^Ol000000_n6PLH00ol0003o/Y6d
ok:A]002ok:A]004o`000?o4UjWoa9NYo`0000;oaY^]00Co0000om2NXoo@WZ?o00000ooDY:D00ol0
003ofZBNo`000002omjZW`05o`000?oV]J;o0000onF^V_l000000_o/]i/01?l0003om/NLooK7W?l0
0002oogSUP?o00000onfOYL00ol0003o_9nkokbO^`02okbO^`;o000000?onk=Wo`000?ok/fL01?ok
/fL2o`000004oo^cIOl0003onk=Uo`0000Gonk=U00Go0000oo^bHol0003onk9So`000004oo^bH`;o
000000Conk9Ro`000?ok/V;onk9R0_l000001_n?Fhoo0000oo^bH?l0003onk9Po`0000;onk9P00Oo
0000oi1LT?l0003onk5No`000?ok/Eko000000;onk5N00Wo0000olV20?o9PP3obH80o`000?nmPYCo
0000oiiQR?l000001_ooool00ol0003oooooooooo`06ooooo`0000?ooooooiRHV?mgMgL02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgM
gOl@413oV9RH00Oooooo00?o0000ooooooooool01_ooool3o`0004Sooooo0_l00004oc<?M@03o`00
0?o^]YKok[JF00;o00000_ood883o`000005ooo;M_l0003ooLm^o`000?lh88L00_l00002ogQBV@04
o`000?nPLiooX7>Ooj1cW`;o00001?noRih00ol0003oaHjKo`000002om6JW@09o`000?oCVi[odi^J
om>KV_l0003oeY^Ho`000?oEWYgo000000?ofj6G0_l00002ocm9]005o`000?n<L[3oS7:`ohab/?l0
00001?nWPJX00ol0003o]XVVokJ9YP02okJ9YP03o`000?o4TjCoa9>T00?oa9>T00?o0000olnLXOo?
W:400_o?W:401Ol0003odj2Qo`000?oHXioo000000?og:JN00?o0000omnZWOoOZYd00_l00002on:[
V`03o`000?oT[Ycoi:jL00;oi:jL00Co0000omjXW?oNZ9co00000_oMYih2o`0000?oQX7600Oo0000
ok:A]?nbTKCo/Y6do`000?o4UjWo000000?oaY^]00Co0000om2NXoo@WZ?o00000ooDY:D2o`0000?o
gZZO00Co0000onJeX_oV]J;o00000oo/]i/01?l0003om/NLooK7W?l00002oogSUP03o`000?nSL9Wo
000000Co]WjG1_l000000ook/fOo0000oo^cI`04oo^cI`;o000000Conk=Uo`000?ok/fGo00001Ook
/fD3o`000003oo^bHol0003onk9S00?onk9S0_l000001?ok/V;o0000oo^bH_ok/V82o`000006ohmK
Sol0003onk9Po`000?ok/V3o00000_ok/V000ol0003oT5b@oi1LT002o`000005oo^aG_l0003onk5N
oo^aG_l000000oo9PP001Ol0003o_H:Do`000?nNHHSo000000Kooooo00?o0000ooooooooool01_oo
ool00003o`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo00?o
oooo0ol0001;ooooo`;o00001?lc3gD00ol0003ok[JFonjfUP02o`00000:ooo@P_l0003o0000ooBj
SOl0003ool]fo`000?omcfko0000ocPPQ`;o00000_mhDYT01?l0003oX7>Ooj1cWonPLil2o`0000Co
_h^N00?o0000olF>Vol000000_oAVYd02Ol0003odi^Jom>KV_oCVi[o0000omJKV?l0003oeIjMo`00
0003om^QU`?o00000_loBK@01?l0003oS7:`ohab/?l00004ojN1ZP04o`000?nfRJKo]XVVokJ9YP;o
00001?o4Tj@2o`0000?ocibQ00Ko0000om>PXOoCX:7o0000omRSWol00003ombVWP03o`000?oOZYgo
gjZM00;o00000_oRZi/02Ol0003oi:jLonB^W?oT[Yco0000onJbW_l0003ogZRLo`000002omfWWP;o
00000on6PLH00ol0003o/Y6dok:A]002ok:A]0;o00000oo6Vjd00ol0003od9jSo`000005omBTY@05
o`000?oNZYoogZZOomjZWol000000_oV]J801ol0003ok;NKonbgVoo/]i_o0000ooK7W?l000000_om
hiH00ol0003oXg2Ioj=`V@02o`0000?o]WjG00Co0000oiFJe_nEV]KoUI[F0_l000000ook/fOo0000
oo^cI`05oo^cI`05o`000?ok/fGo0000oo^cIOl000001Ook/fD3o`000003oo^bHol0003onk9S00?o
nk9S0_l000000ook/V;o0000oo^bHP02oo^bHP?o000000Conk9Po`000?ok/V3o00000ook/V001_l0
003oT5b@o`000?l0003onk5No`0000;onk5N0_l00002olV20005o`000?nmPYCo0000oiiQR?l00000
1_ooool00ol0003oooooooooo`06ooooo`009oooool01?l0003oooooooooooooool3o`0004kooooo
0_l00003oc<?M@04o`000?o^]YKok[JFonjfUP;o000000Coom22o`000?l0003o00000_oobgH01?l0
003ooLm^o`000?lh88L2o`0000?oN5:I00?o0000oj1cWol000000_n/NYd02Ol0003o_h^Nokn;W_no
Riko0000olF>Vol0003odIZMo`000004om>KVP04o`000?oFViSo0000o`0000?ofj6G00Co0000om^O
U_oKWiKo00000_loBK@01Ol0003oS7:`ohab/?n<L[3o000000?oYh6Z00Oo0000okJ9Y_nfRJKo]XVV
o`000?niS:Oo000000?oa9>T00?o0000olRGY?l000000_o?W:401Ol0003odj2Qom>PXOoCX:7o0000
00?og:JN00?o0000omnZWOoOZYd00_oOZYd01?l0003ohZ^Kon:[Vol00003onB^W005o`000?oV/Yko
0000omjXW?l000000ooMYih2o`0000;oQX7600Co0000ok:A]?nbTKCo/Y6d0_l00004olJK[@03o`00
0?o@WZ?o000000Goe:BU00Co0000omjZWooNZYoo00000ooV]J801ol0003ok;NKonbgVoo/]i_o0000
ooK7W?l000000_omhiH00ol0003oXg2Io`000002o`0000?o]WjG0_l00002oiFJeP;o000000?onk=W
o`000?ok/fL01Ook/fL01Ol0003onk=Uo`000?ok/fGo000000Gonk=U0_l000000ook/V?o0000o`00
0004oo^bH`;o000000?onk9Ro`000?ok/V800ook/V82o`000004oo^bH?l0003onk9Po`0000?onk9P
00Ko0000oi1LT?l0003o0000oo^aG_l00002oo^aGP;o00000_o9PP001Ol0003o_H:Do`000?nNHHSo
000000Kooooo00?o0000ooooooooool01_ooool002Oooooo1?l0001Aooooo`;o00000olc3gD01ol0
003ok[JFonjfU_l0003on/F?o`000?ood8800ol000001_oobgKo0000oog?K_omcfko0000ocPPQ`;o
00000omhDYT2o`0000?o[7ZM00Co0000okn;W_noRiko00000_o5SY/00ol0003odIZMo`000003om>K
VP05o`000?oFViSoeY^HomJKV?l000000ooKXIL01?l0003ofinFom^OU_l00002ocm9]005o`000?n<
L[3oS7:`ohab/?l000000onWPJX01?l0003o]XVVokJ9Y_l00002okV<Y`07o`000?o4TjCoa9>TolBC
Y?l0003ob9NTo`000002olnLX@05o`000?oCX:7odj2Qom>PXOl000000ooLYYh00ol0003ogjZMomnZ
W@02omnZW@04o`000?oRZi_ohZ^Ko`0000?oi:jL00Go0000onJbW_l0003ogZRLo`000002omfWWP06
o`000?oIYj?o0000o`000?n6PLKo00000_nbTK@00ol0003o[YFno`000005olJK[@;o00001?oDY:D0
1Ol0003ofjnZo`000?oNZYoo000000?oi[FR0_l00002onbgV`05o`000?ofaico0000oogSU_l00000
0_nSL9T3o`0000Co]WjG00Co0000oiFJe_nEV]KoUI[F0ol00006oo^cI`05o`000?ok/fGo0000oo^c
IOl000001Ook/fD2o`000003oo^bHol0003o000000Conk9S0_l000000ook/V;o0000oo^bHP03oo^b
HP;o000000Conk9Po`000?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000?onk5N00So
0000olV20?o9PP3o0000okf2U?l0003oWV68o`0000Kooooo00?o0000ooooooooool01_ooool002Oo
oooo0_l0001Cooooo`;o00000olc3gD01ol0003ok[JFonjfU_l0003on/F?o`000?ood8800ol00000
1OoobgKo0000oog?K_omcfko000000;o>22700Co0000ogQBVOmhDYWoN5:I0_l00003ojajW@04o`00
0?noRiko_h^No`0000;oaHjK00?o0000om6JWOl000000ooCViX01Ol0003oeY^HomJKV?oFViSo0000
00?ofj6G00Oo0000om^OU_oKWiKofinFo`000?loBKCo000000?oS7:`00?o0000ojN1Z_nWPJX00_nW
PJX2o`0000?o^HbW00Co0000olBCY?o4TjCo00000_o8Uj@00ol0003ocibQo`000004om>PX@05o`00
0?oLYYkog:JNombVW_l000001?oOZYd2o`000003on:[Vol0003oi:jL00;oi:jL00Co0000onJbW_oV
/Yko00000ooMYih01?l0003ofJNSo`000?mFLm@4o`0000;o[YFn00?o0000olJK[Oo6Vjd00oo6Vjd0
0ol0003oe:BUomBTY@03omBTY@05o`000?oK[j[o0000omjZWol000000_oV]J800ol0003ol/RUoo;8
Y@02o`000003ooK7W?l0003ooN>F00;o00000_nSL9T3o`0000?o]WjG0_l00003oiFJeP03o`000?oF
Xj7o000000Konk=W00Go0000oo^cIOl0003onk=Uo`000005oo^cI@;o000000?onk9So`000?l00000
1?ok/V<2o`000003oo^bH_l0003onk9R00?onk9R0_l000001?ok/V3o0000oo^bH?l00003oo^bH004
o`000?n@G93o0000oo^aGP;o00000ook/Eh02?l0003obH80olV20?l0003o_H:Do`000?nNHHSo0000
1oooool00ol0003oooooooooo`05ooooo`00:Oooool00ol0003oooooooooo`1@ooooo`;o00000olc
3gD03?l0003ok[JFonjfU_l0003on/F?o`000?ood8;o0000ooBjSOl0003ool]fo`0000?ooLm^00?o
0000ocPPQol000001?l00004ojajW@04o`000?noRiko_h^No`0000?oaHjK0_l00003om>KVP05o`00
0?oFViSoeY^HomJKV?l000000ooKXIL01?l0003ofinFom^OU_oKWiH3o`0000?oS7:`00?o0000ojN1
Z_nWPJX00_nWPJX2o`0000?o^HbW00Co0000olBCY?o4TjCo00000_o8Uj@00ol0003ocibQo`000004
om>PX@05o`000?oLYYkog:JNombVW_l000000ooOZYd01Ol0003oi:nNo`000?oRZi_o000000;oi:jL
00Go0000onJbW_oV/Ykoi[:No`000003omfWWP04o`000?oIYj?o0000o`0000;oEW?D00?o0000ojjE
__n^UKh00_n^UKh00ol0003oaY^]olJK[@02olJK[@03o`000?oDY:Goe:BU00;oe:BU00Ko0000om^_
Z_oK[j[o0000omjZWol00002onJeXP08o`000?obb:Gol/RUoo;8YOl0003om/NLo`000?omhiH2o`00
00;oXg2I00?o0000ojVmj?l000000onfOYL4o`000005oiFJe_l0003oeZ>QomJSXOl000000ook/fL3
o`000004oo^cIOl0003onk=Uo`0000Gonk=U0_l000000ook/V?o0000o`000005oo^bH`03o`000?ok
/V;o000000Conk9R1?l000000ook/V3o0000oo^bH002oo^bH004o`000?n@G93o0000oo^aGP;o0000
0ook/Eh01_l0003obH80olV20?o9PP3o0000okf2U0;o00001oooool00ol0003oooooooooo`05oooo
o`00:_ooool00ol0003oooooooooo`1?ooooo`;o00000olc3gD00ol0003ok[JFonjfUP02o`000007
ooo@P_l0003o0000ooBjSOl0003ool]fo`000003oog?KP03o`000?lh88Oo000000?oRenI00?o0000
ojajWOn/NYd00_n/NYd00ol0003o_h^No`000004olF>V`03o`000?oCVi[odi^J00;odi^J00Go0000
omJKV?oFViSoeY^Ho`000003om^QU`06o`000?oKWiKofinFom^OU_l0003o01:O0_l00002ohab/004
o`000?nWPJ[oYh6ZojN1ZP;o00001?niS:L00ol0003oa9>To`000003olRGY003o`000?o?W:7o0000
00?odj2Q00Go0000omRUXOl0003og:JNo`000004omnZW@04o`000?oT[iko0000o`0000?oi:jL00Go
0000onJbW_oV/Ykoi[:No`000003omfWWP04o`000?oIYj?ofJNSo`0000;oEW?D00?o0000ojjE__n^
UKh00_n^UKh01ol0003oaY^]olJK[Oo6Vjgo0000olVT]?l000000ooDY:D01Ol0003ofjnZom^_Z_oK
[j[o000000?oi[FR00Ko0000oo;8YOobb:Gol/RUo`000?ofai`2o`0000;o[gRF00Go0000oj=`VOl0
003oZKgXo`000003okInU`03o`000?nY_NSoZKgX00?o000000?oeZ>Qo`000?oBZ:h00ol00003ojG3
k`;o000000?onk=Uo`000?ok/fD01?ok/fD2o`000003oo^bHol0003o000000Gonk9S0ol00004oo^b
HP;o000000Conk9Po`000?ok/V3o00000ook/V001?l0003oT5b@o`000?ok/Eh2o`0000?onk5N0_l0
0002olV20005o`000?nmPYCo0000oiiQR?l000001_ooool00ol0003oooooooooo`05ooooo`00:ooo
ool00ol0003oooooooooo`1>ooooo`;o00000_lc3gD01?l0003ok[JFonjfU_o^]YH2o`000007ooo@
P_l0003o0000ooBjSOl0003ool]fo`000003oog?KP03o`000?lh88Oo000000?oRenI00?o0000ojaj
WOn/NYd00_n/NYd00ol0003o_h^No`000004olF>V`03o`000?oCVi[odi^J00;odi^J00Go0000omJK
V?oFViSoeY^Ho`000003om^QU`07o`000?oKWiKofinFo`000?oJWYGo0000o`0BW`02o`0000;oS7:`
00Go0000ojN1Z_l0003oYh:]o`000005okV<Y`;o00001?o8Uj@00ol0003odj2Qom>PX@02om>PX@05
o`000?oHYJ7o0000ombVW_l000001?oOZYd01?l0003oi:nNonB_W_l00003onB^W005o`000?oV/Yko
i[:NonJbW_l000000_oMYih01?l0003ofJNSomVWXooIYj<2o`0000;oEW?D00Go0000ojjE__n^UKko
[YFno`000002olJK[@04o`000?o9Y;CobJBdo`0000?oe:BU00Go0000om^_Z_oK[j[ofjnZo`000002
onJeXP07o`000?obb:Gol/RUoo;8YOl0003on^^Oo`000004ojmhUP03o`000?nSL9Wo000000?o0000
0_nfOYL00ol0003oZKgXo`000005o`000003om:X[_l0003oYL?_00CoYL?_0_l000000ook/fGo0000
oo^cI@04oo^cI@;o000000?onk9So`000?l000001Ook/V<3o`0000Conk9R0_l000001?ok/V3o0000
oo^bH?l00003oo^bH004o`000?n@G93o0000oo^aGP;o00000ook/Eh2o`0000;obH8000Go0000okf2
U?l0003oWV68o`000006ooooo`03o`000?oooooooooo00Gooooo000/ooooo`;o0000C_ooool2o`00
00;o<`me00Oo0000onjfU_o^]YKo0000oo[5Sol0003oom2200;o000000Com;Z=o`000?oobgKo0000
0oomcfh00ol0003o>227o`000003oh]OV@03o`000?n/NYgo[7ZM00;o[7ZM00?o0000okn;W_l00000
1?o5SY/01Ol0003odi^Jom>KV_oCVi[o000000?oeY^H00Go0000omRLU_l0003ofj6Go`000003om^O
UP06o`000?oJWYGo0000o`0BWol0003oO6bf1?l00002ojN2[@03o`000?niS:Oo^HbW00?o^HbW0_l0
0004olRGY003o`000?oCX:7odj2Q00;odj2Q00Go0000omRUXOl0003og:JNo`000004omnZW@04o`00
0?oT[ikoi:nNo`0000;oi:jL00Wo0000onJbW_oV/Ykoi[:No`000?oY^Z?o0000omfWW_l000000ooI
Yj<3o`000003oeIce?l0003o[YFn00?o[YFn0_l00004olVT]003o`000?oDY:Go000000CofjnZ00Co
0000onJeX_oV]J;o00000oobb:D00ol0003on^^Oo`000004ojmhUP04o`000?nSL9Wo0000ojVmj0;o
00000_nfOYL2o`0000;ooooo00?o0000o`1<bOl000000ooBZ:h00ol0003oYL?_o`000002o`000004
ojG3kol0003onk=Uo`0000Konk=U00Co0000oo^bHol0003o00001Ook/V<2o`000003oo^bH_l0003o
nk9R00;onk9R0_l000001?ok/V3o0000o`000?l00004oo^bH0;o000000?onk5No`000?l000000ook
/Eh2o`0000;obH8000Go0000okf2U?l0003oWV68o`000006ooooo`03o`000?oooooooooo00Gooooo
000^ooooo`03o`000?oooooooooo04_ooooo0_l00002oc<?M@07o`000?o^]YKok[JFo`000?ojaHoo
0000ooo@PP03o`000003ooo;M_l0003ooLm^00?ooLm^00?o0000ocPPQol000000on;GiT00ol0003o
[7ZMojajW@03ojajW@;o00001?o5SY/01Ol0003odi^Jom>KV_oCVi[o000000?oeY^H00Go0000omRL
U_l0003ofj6Go`000003om^OUP05o`000?oJWYGo0000o`0BWol000000omlK;H00ol0003oYh:]ojN2
[@02ojN2[@03o`000?niS:Oo^HbW00;o^HbW00?o0000olRGY?o8Uj@00oo8Uj@01Ol0003odj2Qom>P
XOoCX:7o000000;of:FQ00?o0000ombVW_l000000ooOZYd01Ol0003oi:nNonB_W_oT[iko000000;o
i:jL00Wo0000onJbW_oV/Ykoi[:No`000?oY^Z?o0000omfWW_l000001?oIYj<4o`0000?o[YFn0_l0
0005olVT]003o`000?oDY:Go000000?ofjnZ00Go0000onO4/ol0003oi[FRo`000002oo;8Y@03o`00
0?ojjioo000000Go[gRF00?o0000oj=`VOl000000ol00002okInU`03o`000?oooooooooo00;ooooo
0_l00004om:X[P03o`000?nU`nooYL?_00?oYL?_0_l00006oo^cI@04o`000?ok/V?o0000o`0000Go
nk9S0_l000000ook/V;o0000oo^bHP03oo^bHP05o`000?ok/V3o0000oo^bH?l000001?ok/V02o`00
0003oo^aG_l0003o000000Conk5N00So0000olV20?o9PP3o0000okf2U?l0003oWV68o`0000Kooooo
00?o0000ooooooooool01Oooool002oooooo00?o0000ooooooooool0B_ooool2o`0000;o<`me00co
0000onjfU_o^]YKo0000oo[5Sol0003oom22o`000?od^Xgo0000ooo;M_l00004oog?KP03o`000?lh
88Oo000000CoRenI00?o0000ojajWOn/NYd00_n/NYd00ol0003oaHjKolF>V`02olF>V`;o00000ooC
ViX02Ol0003oeY^HomJKV?oFViSo0000omRLU_l0003ofj6Go`000003om^OUP06o`000?oJWYGofYjE
o`000?l04Yoo00000_mlK;H00ol0003oYh:]ojN2[@02ojN2[@03o`000?niS:Oo^HbW00;o^HbW00?o
0000olRGY?o8Uj@00_o8Uj@2o`0000?odj2Q00Go0000omRUXOoHYJ7of:FQo`000004omnZW@04o`00
0?oT[ikoi:nNonB_WP;o000000?oi:jLo`000?oV/Yh00_oV/Yh01Ol0003ojKZSo`000?oMYiko0000
00CofJNS00?o0000olJBX?l000001?l000000onRWm;o0000olVT]005olVT]003o`000?oK[j[ofjnZ
00;ofjnZ00Go0000onO4/ol0003oi[FRo`000002oo;8Y@04o`000?ojjioo0000o`0000Co[gRF00?o
0000oj=`VOl000000_ooool01?l0003o]WjGokInUol00005ooooo`;o00001?oBZ:h01?l0003oYL?_
ojG3konU`nl3o`0000Konk=U00Co0000oo^bHol0003o00001Ook/V<2o`000003oo^bH_l0003onk9R
00?onk9R0ol000000ook/V3o0000o`000003oo^bH0;o000000Conk5No`000?ok/Eko00000ook/Eh0
2?l0003obH80olV20?l0003o_H:Do`000?nNHHSo00001_ooool00ol0003oooooooooo`05ooooo`00
<?ooool00ol0003oooooooooo`19ooooo`04o`000?lc3gGo<`meo`0000?ok[JF00?o0000oo[5Sol0
00000_l000001?od^Xgo0000ooo;M_l00003oog?KP;o00000_lh88L01Ol0003oRenIoh]OVOn;GiWo
000000Co[7ZM00?o0000olF>Voo5SY/00_o5SY/00ol0003obY6Io`000002om>KVP09o`000?oFViSo
eY^HomJKV?l0003of9bFo`000?oKXIOo000000?ofinF00Ko0000omZNUOoJWYGo0000o`0BWol00002
oga/]P03o`000?nWPZgoYh:]00;oYh:]00Co0000okV<YoniS:Oo^HbW0_l00004olRGY003o`000?o=
W:Go000000;odj2Q00Go0000omRUXOoHYJ7of:FQo`000004omnZW@08o`000?oT[ikoi:nNo`000?oZ
^:3o0000onB^W?l00002onJbWP05o`000?oY^Z?ojKZSonVjXol000001OoIYj<01Ol0003oaY:Po`00
0?l0<KGo000000CoXYoB00?o0000olVT]?o9Y;@00oo9Y;@01Ol0003ofjnZom^_Z_oK[j[o000000;o
ilBc0_l00003oo;8Y@;o000000?o[WNFo`000?n_N9H00on_N9H2o`0000?ooooo00Co0000okInUonf
OYOo00001_ooool00ol0003odZR^om:X[P02om:X[PCo000000CohZRGo`000?oW]Z;o00000ook/fD3
o`000003oo^bHol0003o000000Gonk9S0_l000000ook/V;o0000oo^bHP03oo^bHP?o000000?onk9P
o`000?l000000ook/V02o`000004oo^aG_l0003onk5No`0000?onk5N0_l000001?o9PP3o0000okf2
U?nmPY@2o`0000Oooooo00?o0000ooooooooool01?ooool0037ooooo00?o0000ooooooooool0B?oo
ool01?l0003o<`meoc<?MOl00003onjfUP;o000000Ooom22o`000?l0003om;Z=o`000?oobgKo0000
00;ooLm^00?o0000oo2cSOl000000_lh88L01Ol0003oRenIoh]OVOn;GiWo000000Co[7ZM00?o0000
olF>Voo5SY/00_o5SY/00ol0003obY6Io`000002om>KVP09o`000?oFViSoeY^HomJKV?l0003of9bF
o`000?oKXIOo000000?ofinF00Co0000omZNUOoJWYGofYjE0_l00003oga/]P05o`000?nWPZgoYh:]
ojN2[Ol000000oniS:L00ol0003o_96Yo`000003olRGY003o`000?o=W:Go000000;odj2Q00Go0000
omRUXOoHYJ7of:FQo`000003omnZW@06o`000?oT[ikoi:nNonB_W_l0003oj[RP0_l00003onJbWP05
o`000?oY^Z?ojKZSonVjXol000001?oIYj<2o`0000;oaY:P0_l00004oj:OdP03o`000?o9Y;CobJBd
00;obJBd00?o0000olnha?l000000_oK[jX01Ol0003oilBconO4/ooWa;?o000000;ol/RU00Go0000
oo[[Wol0003o[WNFo`000004ojmhUP;o00000oooool01?l0003o]WjGokInUol00006ooooo`;o0000
0_oBZ:h00ol0003oa[S=o`000003on:XU`03o`000?oW]Z;oikJR00?o00000onU`nl3o`0000Gonk9S
0_l000000ook/V;o0000oo^bHP03oo^bHP?o000000Conk9Po`000?ok/V3o00000_ok/V02o`000004
oo^aG_l0003onk5No`0000?onk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Oooooo00?o0000
ooooooooool01?ooool003;ooooo0_l00018ooooo`04o`000?lc3gGo<`meo`0000;ok[JF00Co0000
oo[5Sol0003oom220_l000001Ood^Xgo0000ooo;M_l0003ooLm^00;o000000Gol;>=o`000?lh88Oo
>227o`000003oh]OV@04o`000?n/NYgo[7ZMojajW@;o00001?o5SY/01Ol0003obY6Io`000?oCVi[o
000000?oeY^H00Go0000omRLU_oHW9Kof9bFo`000003om^OUP04o`000?oJWYGofYjEomZNU@?o0000
0omlK;H01Ol0003oYh:]ojN2[OnWPZgo000000;o^HbW00Co0000okbAZOnlTJWo00000_o8Uj@01_l0
003ocIbUolfLYOl0003odj2Qo`0000Cof:FQ0_l00002omnZW@05o`000?oT[ikoi:nNonB_W_l00000
0_oZ^:001Ol0003oi[:NonJbW_oV/Yko000000?ojKZS00?o0000omVWXooIYj<00_oIYj<2o`0000?o
aY:P0_l00004oj:OdP04o`000?o9Y;CobJBdo`0000;ockS400?o0000om^_Z_l000001?oWa;<2o`00
0003oo;8YOl0003o000000;o[WNF00?o0000ojmhU_n_N9H00on_N9H01Ol0003ooooooooooooooooo
000000;o]WjG00?o0000ooooooooool01Oooool00ol0003odZR^o`000003olJhc@04o`000?oRZ9Oo
hZRGo`0000;oikJR00?o0000ojG3konU`nl00onU`nl3o`0000Gonk9S0_l000000ook/V;o0000oo^b
HP03oo^bHP?o000000Konk9Po`000?ok/V3onk9Po`000?ok/V02o`000004oo^aG_l0003onk5No`00
00?onk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Oooooo00?o0000ooooooooool01?ooool0
03Cooooo00?o0000ooooooooool0AOooool01?l0003o<`meoc<?MOl00002onjfUP04o`000?ojaHoo
0000ooo@PP;o000000?om;Z=o`000?oobgH00ol00002oo2cS@04o`000?lh88Oo>227o`0000?oRenI
00Co0000ojajWOn/NYgo[7ZM0_l00004olF>V`05o`000?o:TIWo0000om>KV_l000000ooFViP01Ol0
003of9bFomRLU_oHW9Ko000000?ofinF00Ko0000omZNUOoJWYGofYjEo`000?oJWY@2o`0000;oO6bf
00?o0000ojN2[OnWPZd00_nWPZd2o`0000?o_96Y00Co0000olRGY?o8UjCo00000_o=W:D00ol0003o
dj2Qo`000003omRUX@03o`000?oO[:;o000000;ogjZM00Co0000onB_W_oT[iko00000ooZ^:001?l0
003oi[:NonJbW_l00003onVjX`03o`000?o_c:oo000000;ofJNS00Co0000om6V[?oAYZco00000oo6
TZ000ol0003oXYoBoj:OdP02oj:OdP03o`000?o9Y;Co000000?ockS400?o0000om^_Z_l000000ooW
a;<00ol0003ol_>moo;c_@03o`0000;o[WNF00?o0000ojmhU_n_N9H00on_N9H01?l0003ooooooooo
ooooool2o`000003okInUol0003ooooo00Oooooo00?o0000olJhcOo6^<d00_o6^<d00ol0003ohZRG
o`000004onNfXP03o`000?nU`noo000000;o000000?oYL?_o`000?l000001_ok/V<00ol0003onk9R
o`000004oo^bHP?o000000Konk9Po`000?ok/V3onk9Po`000?ok/V02o`000004oo^aG_l0003onk5N
o`0000?onk5N0_l00002olV20004o`000?nmPYCo0000o`0000Oooooo00?o0000ooooooooool01?oo
ool003Gooooo00?o0000ooooooooool0A?ooool01?l0003o<`meoc<?MOl00002onjfUP04o`000?oj
aHoo0000ooo@PP;o000000?om;Z=o`000?oobgH00ol000000oo`/hgo0000o`000002ocPPQ`05o`00
0?n;GiWoRenIoh]OVOl000000on/NYd2o`0000?oaHjK00Ko0000olZAVOo:TIWo0000om>KV_l00003
omJKV005o`000?oHW9Kof9bFomRLU_l000000ooKWiH01_l0003ofYjEomZNUOoJWYGo0000omZNU0?o
000000?oO6bfo`000?nWPZd00onWPZd2o`0000?o_96Y00Co0000olRGY?o8UjCo00000_o=W:D00ol0
003odj2Qo`000003omRUX@06o`000?oO[:;ogjbRo`000?oOZYgo00000_oT[ih01?l0003oj[RPonZh
X?oZ^:02o`000003onJbW_l0003ojKZS00;ojKZS00?o0000ono<[ol000000_oIYj<01?l0003odJJ/
om6V[?l00004olJBX0Ko00001Oo?^<@01Ol0003oilBconO4/ooWa;?o000000;ol_>m00Co0000ojih
Uol0003o00000_n^MiH00ol0003o[gRFojmhUP03ojmhUP03o`000?oooooooooo00;ooooo00?o0000
okInUol000002?ooool00ol0003oa[S=olJhc@02olJhc@03o`000?oRZ9Oo000000CoikJR0_l00005
ojG3k`03o`000?ok/V?onk9S00Conk9S00?o0000oo^bH_l000001?ok/V82o`000003oo^bH?l0003o
000000?onk9P0ol000001?ok/Eko0000oo^aG_l00003oo^aGP;o00000_o9PP001Ol0003o_H:Do`00
0?nNHHSo000000Kooooo00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool0@ooo
ool00ol0003o<`meo`000003onjfUP03o`000?ojaHoo000000Co000000?ool]fo`000?omcfh00_l0
00000oo`/hgo0000o`000002ocPPQ`05o`000?n;GiWoRenIoh]OVOl000000_n/NYd01?l0003o]H2K
okF0Vol00002olF>V`06o`000?o:TIWobY6Io`000?oCVi[o00000ooFViP01Ol0003of9bFomRLU_oH
W9Ko000000?ofinF00Ko0000omZNUOoJWYGofYjEo`000?oJWY@2o`000003oeQN__l0003o000000?o
Yh:]0_l00004okbAZ@03o`000?o8UjCo000000CocIbU00?o0000omRUXOoHYJ400_oHYJ400ol0003o
gjbRomn/XP02o`0000?oi:nN00So0000onZhX?oZ^:3o0000oo?8Xol0003oi[:No`0000;ojKZS00Ko
0000ono<[oo_c:oo0000omVWXol00003om6V[004o`000?o6TZ3oaY:PolJBX0?o00000omN[?T00ol0
003ockS4olnha002olnha0;o00000ooWa;<00ol0003ol_>mo`000002ojihU`;o00000_n^MiH00ol0
003o[gRFojmhUP03ojmhUP03o`000?oooooooooo00;ooooo00?o0000okInUol000002Oooool01ol0
003oa[S=olJhcOo6^<go0000on:XUol000001?oW]Z800ol0003okK2>o`000002ojG3k`?o00001_ok
/V<00ol0003onk9Ro`000004oo^bHP;o000000?onk9Po`000?l000001?ok/V02o`000004oo^aG_l0
003onk5No`0000Conk5N0_l000001_o9PP3o0000okf2U?l0003oWV68o`0000Kooooo00?o0000oooo
ooooool01?ooool003Oooooo0_l00013ooooo`03o`000?lc3gGo000000?ok[JF00?o0000oo[5Sol0
00000_l000000ood^Xgo0000ooo;MP04o`000006oo2cSOl0003o0000o`000?lh88Oo00000on;GiT0
1?l0003o[7ZMojajWOl00002okF0V`04o`000?o5SY_oaHjKo`0000?obY6I0_l00003omJKV005o`00
0?oHW9Kof9bFomRLU_l000000ooKWiH01_l0003ofYjEomZNUOoJWYGo0000omZNU0;o00000_mHG[h4
o`000003ojF6/_l0003o_96Y00Co_96Y0_l00004olfLY@03o`000?oHYJ7of:FQ00;of:FQ00Go0000
omn/X_oO[:;ogjbRo`000003onB_WP05o`000?oZ^:3oj[RPo`000?ocb:<00_l00003onVjX`04o`00
0?o_c:ooklb_ono<[`;o00000ooAYZ`01?l0003oaY:PolJBX?o6TZ02o`000003okJ2WOl0003o0000
00;oGZci00Co0000olnha?o?^<Co00000_o>kNT01Ol0003oilBco`000?oblkgo000000?o[WRG00Go
0000ojigU_n^MiKo[WNFo`000005ojmhUP03o`000?oooooooooo00;ooooo0_l0000;ooooo`?o0000
00?oa[S=o`000?oW]Z801?oW]Z800ol0003okK2>onf`SP02o`000004oo_9TOl0003o0000o`0000?o
nk9S0ol000000ook/V;o0000oo^bHP03oo^bHP;o000000Conk9Po`000?ok/V3o00001?ok/V001Ol0
003onk5No`000?ok/Eko000000Conk5N0_l000001?o9PP3o0000okf2U?nmPY@2o`0000Kooooo00?o
0000ooooooooool01?ooool003Wooooo00?o0000ooooooooool0@?ooool00ol0003o<`meo`000002
onjfUP04o`000?ojaHoo0000ooo@PP;o000000?om;Z=o`000?oobgH00_l000000oo`]I3o0000oo2c
S@03o`000003ocPPQol0003oRenI00;oRenI00Co0000ojajWOn/NYgo00000_neP9/01?l0003oaHjK
olF>Vol00003olZAV@03o`000?oFViSoeY^H00;oeY^H00Go0000omRLU_oHW9Kof9bFo`000003om^O
UP06o`000?oJWYGofYjEomZNUOl0003ofYjD0ol00002oeQN_P05o`000?nUQ[;oYHJbojF6/_l00000
1OnlTJT2o`0000CocIbU00Go0000omRUXOoHYJ7of:FQo`000004omn/XP04o`000?oT[ikoi:nNo`00
00?oj[RP00Co0000oo?8Xoocb:?o00000ooY^Z<01Ol0003oklb_ono<[oo_c:oo000000CodJJ/00Ko
0000olJBX?o6TZ3o0000okN8Y?l00003okJ2W@?o000000CockS4o`000?o>kNWoc^gY1Ol00004ojih
U`05o`000?n^MiKo[WNFojigU_l000001?n_N9H00ol0003oooooooooo`03ooooo`;o00003?ooool4
o`0000CoikJR00Go0000oo;S_?l0003okK2>o`000002oo_9T@Ko00000onU`nl2o`0000Gonk9R00Go
0000oo^bH?l0003onk9Po`000004oo^bH0?o000000?onk5No`000?ok/Eh00ook/Eh2o`000004olV2
0?l0003o_H:Dokf2U0;o00001oooool00ol0003oooooooooo`03ooooo`00>_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?lc3gGo000000;ok[JF00Co0000oo[5Sol0003oom220_l000000ood^Xgo
0000ooo;MP02o`000003oo2eT?l0003ol;>=00?o000000?o>227o`000?n;GiT00on;GiT2o`0000?o
]H2K00Co0000olF>Voo5SY_o00000oo:TIT01Ol0003oeY^HomJKV?oFViSo000000?of9bF00Go0000
on6VUOl0003ofinFo`000004omZNU@05o`000?oJWYCo0000om6GV?l000000_mHG[h00ol0003oYHJb
ojF6/P02ojF6/P03o`000?nlTJWo_96Y00;o_96Y00?o0000olfLYOo=W:D00_o=W:D00ol0003odjFW
o`000002omRUX@09o`000?oO[:;ogjbRomn/X_l0003oikVTo`000?oT[iko000000;oj[RP00Go0000
oo?8Xoocb:?ollRSo`000002onVjX`03o`000?o_c:ooklb_00;oklb_00?o0000om6V[?oAYZ`00ooA
YZ`2o`0000?o]hRT00Ko0000okJ2WOnfPYgo]X:Mo`000?ndOiX4o`0000Co[WRH00?o0000ojihUon^
N9L00_n^N9L01Ol0003o[WNFojigU_n^MiKo000000Co[gRF00?o0000ooooooooool00oooool2o`00
00kooooo0_l00003onNfXP06o`000?obhkcol^>lo`000?o]/8ko00000_okbI401?l0003oY76Ho`00
0?l00005ojG3k`;o00001Ook/V801Ol0003onk9Po`000?ok/V3o000000Conk9P0ol000000ook/Eko
0000oo^aGP03oo^aGP;o000000?obH80o`000?l000000ol00007ooooo`03o`000?oooooooooo00?o
oooo000kooooo`03o`000?oooooooooo03kooooo0_l00003onjfUP03o`000?ojaHoo000000?o0000
00?om;Z=o`000?oobgH00_l000000oo`]I3o0000oo2cS@02o`000003odd_S?l0003o000000CoRenI
0_l00003okF0V`03o`000?o5SY_o000000CobY6I00Go0000omJKV?oFViSoeY^Ho`000003omRLUP05
o`000?oQYYGo0000om^OU_l000000ooJWYD01?l0003ofYjDomZNU?oJWY@2o`0000;oF5jn00?o0000
ojF6/_nUQ[800_nUQ[800ol0003o_96YokbAZ@02okbAZ@03o`000?o=W:GocIbU00;ocIbU00?o0000
om>UYol000000_oHYJ402Ol0003ogjbRomn/X_oO[:;o0000onNiY?l0003oi:nNo`000002onZhX008
o`000?ocb:?ollRSo`000?okijKo0000onVjXol00003ono<[`03o`000?oOoM3o000000CodJJ/0_l0
0003okN8Y005o`000?nfPYgo]X:MokJ2WOl000000_ndOiX01?l0003o[7RIojahVOl00003ojihV003
o`000?n^N9Oo[WRG00;o[WRG00?o0000ojigU_n^MiH00_n^MiH01Ol0003o[gRFojmhU_n_N9Ko0000
00Kooooo00?o0000ooooooooool03Oooool2o`0000;oikJR00?o0000oo;S_?obhk`00_l00003oo_9
T@06o`000?nTLISo0000ojYcU_l0003oYL?_0ol000000onU`noo0000oo^bHP04oo^bHP05o`000?ok
/V3o0000oo^bH?l000001?ok/V03o`000003oo^aG_l0003onk5N00?onk5N00Co0000oiaMQOl0003o
00000_nELZT2o`0000Oooooo00?o0000ooooooooool00oooool003cooooo0_l0000nooooo`;o0000
0oo^]YH02Ol0003on/F?o`000?l0003okkRFo`000?od^Xgo0000ooo;MP02o`000003oo2eT?l0003o
l;>=00;o000000CoCBn<o`000?lh88Oo00000on;GiT2o`0000?o]H2K00?o0000olF>Vol000001?o:
TIT01Ol0003oeY^HomJKV?oFViSo000000?of9bF00Go0000on6VUOl0003ofinFo`000003omZNU@04
o`000?oJWYCofYjDomZNU0?o00000_mHG[h01Ol0003oYHJbojF6/_nUQ[;o000000?o_96Y0_l00004
olfLY@06o`000?oCYJOodjFWo`000?oHYJ7o00000ooO[:801?l0003oikVTo`000?l00003onZhX004
o`000?ocb:?ollRSo`0000;onnNV00Go0000ono<[oo_c:ooklb_o`000002omomd004o`000?oAYZco
dJJ/om6V[0;o00001?ngR:@01Ol0003o]X:MokJ2WOnfPYgo000000;o]7nJ00Co0000ojahVOn/N9Wo
00000on^N9P01?l0003o[WRGojihUon^N9L2o`0000Co[WNF00Go0000ojmhU_n_N9Ko[gRFo`000006
ooooo`03o`000?oooooooooo00kooooo00?o0000onNfX_l000001?obhk`01?l0003onlVAoo_9TOl0
0002ojAaV004o`000?nZLiKoZW>Fo`0000GoYL?_00?o0000oo^bH_ok/V800ol000001?ok/V3o0000
oo^bH?l00004oo^bH0;o000000?onk5No`000?l000001?ok/Eh01?l0003oW5f5o`000?l00002oiEb
Z@;o00001oooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003oooooooooo`0kooooo`;o
00000oo^]YH01ol0003on/F?o`000?l0003okkRFo`000?od^Xd01Ol00002oo2cS@?o000000?oCBn<
o`000?l000000_n;GiT2o`0000Co]H2K00?o0000olF>Vol000001?o:TIT01Ol0003oeY^HomJKV?oF
ViSo000000?of9bF00Go0000on6VUOl0003ofinFo`000003omZNU@07o`000?oJWYCofYjDomZNU?l0
003oe9VEo`000002oeQN_P05o`000?nUQ[;oYHJbojF6/_l000000_nlTJT01?l0003o`IR]ol6H[Ol0
0002olfLY@07o`000?oCYJOodjFWom>UYol0003of:FQo`000002omn/XP05o`000?oW^JCoikVTonNi
Y?l000000_oZ^:001?l0003ollRSoo?8Xol00003oo_WYP;o000000Koklb_o`000?l0003o0000omom
d?l00002om6V[003o`000?nhX<3o000000Co]hRT00?o0000okJ2WOnfPYd00_nfPYd2o`0000?o[7RI
00Go0000ojihV?n^N9So[WRHo`000003ojihU`;o00001?n^MiH01Ol0003o[gRFojmhU_n_N9Ko0000
00Kooooo00?o0000ooooooooool03_ooool2o`0000Col^>l0ol000001OokbI7o0000ojAaV?nTLISo
000000?oZW>F00Co0000ojG3konU`nooYL?_1?l00003ojG3k`;o000000?onk9Po`000?ok/V000ook
/V02o`000003oo^aG_l0003o000000Conk5N00Co0000oiaMQOl0003o00000_nELZT2o`0000Oooooo
00?o0000ooooooooool00oooool003oooooo00?o0000ooooooooool0>_ooool2o`0000;ok[JF00?o
0000oo[5SoojaHl00_l000001?o_^9Ko0000o`000?oobgH4o`000003oo2cSOl0003ol;><00;o0000
00OoCBn<o`000?l0003oRenIo`000?nIJIWo000000Go]H2K0_l00003olZAV@03o`000?oKXYWo0000
00;oeY^H00Wo0000omRLU_oHW9Kof9bFo`000?oQYYGo0000om^OU_l000000ooJWYD01_l0003ofYjD
omZNU?oJWYCo0000omBIU@;o000000?oF5jno`000?nUQ[800_nUQ[801?l0003o_96YokbAZOl00002
ol6H[@04o`000?o=W:GocIbUo`0000?odjFW0_l00003omn/XP05o`000?oW^JCoikVTonNiY?l00000
0_oZ^:001?l0003ollRSoo?8Xol00002oo_WYP03o`000?nY_NSo000000;o00000_ooool4o`0000;o
^:3000?o0000okN8Y?ngR:@00_ngR:@00ol0003o]X:MokJ2W@02okJ2W@;o00000on/N9T01Ol0003o
[WRHojihV?n^N9So000000?o[WRG0_l00004ojigUP04o`000?n_N9Ko[gRFo`0001Sooooo00Co0000
of]CY?l0003ol^>l0_l00002oiEXV`;o00000onTLIP00ol0003oZW>FojYcUP02ojYcUP?o00000_n/
Li@01?l0003oYL?_ojG3konU`nl3o`000003oo^bH?l0003onk9P00Conk9P00Co0000oo^aG_l0003o
00001Ook/Eh2o`000004olV20?l0003oUG:YoiEbZ@;o00001_ooool00ol0003oooooooooo`03oooo
o`00@?ooool00ol0003oooooooooo`0iooooo`;o00000_o^]YH00ol0003on/F?o`000003o`000003
ooBjSOl0003ool]f00;o000000Col;F@o`000?o`/hgo00000_o`/h`00ol0003oCBn<o`000002o`00
00;oVFVI00?o0000okF0VoneP9/00oneP9/2o`0000?obY6I00?o0000om^RVOl000000_oFViP02Ol0
003of9bFomRLU_oHW9Ko0000on6VUOl0003ofinFo`000003omZNU@05o`000?oJWYCofYjDomZNU?l0
00000_oDVID3o`0000CoYHJb0_l00003ol6H[@03o`000?o=W:Go000000GodjFW00Go0000omn/X_oO
[:;ogjbRo`000002onNiY005o`000?odcjSo0000onZhX?l000000_ocb:<00ol0003onnNVo`000002
o`0000Oooooo00Go0000okRP`?nhX<3o^:30o`000004okN8Y003o`000?nfPYgo]X:M00;o]X:M00?o
0000ojahVOn/N9T00_n/N9T01Ol0003o[WRHojihV?n^N9So000000;o[WRG00Co0000ok9kV?nbNiSo
00000on^MiH01?l0003o[gRFojmhU_l0000Hooooo`03o`000?m[DjCoJe>T00;o00000onEJ9/00ol0
003oY76HojAaV002ojAaV003o`000?nZLiKoZW>F00;oZW>F00?o0000ojacU?n/Li@00_n/Li@4o`00
00?oYL?_0_l00005oo^bH003o`000?ok/Eko000000;o00001?ok/Eh2o`000004olV20?l0003oUG:Y
oiEbZ@;o00001_ooool00ol0003oooooooooo`03ooooo`00@Oooool2o`0003Wooooo00Ko0000onjf
U_o^]YKok[JFo`000?ojaHl4o`000003ooBjSOl0003ool]f00;o000000Col;F@o`000?o`/hgo0000
0_o`/h`01?l0003oCBn<odd_S?l00003oiUYV@03o`000?neP9_o]H2K00?o]H2K00?o0000olZAVOo:
TIT00_o:TIT01Ol0003ofj:Io`000?oFViSo000000?of9bF00Go0000on6VUOoQYYGohJJEo`000004
omZNU@05o`000?oJWYCofYjDomZNU?l000000_oDVID01Ol0003o02>_o`000?l0003oYHJb00?o0000
1?o1V:d00ol0003ocIbUo`000005om>UY`04o`000?oO[:;ogjbRo`0000?oikVT00Co0000ooC?Z?l0
003o00000_ocb:<00ol0003onnNVo`00000:ooooo`03o`000?nhX<3o^:3000;o^:3000Go0000okN8
Y?ngR:Co]hRTo`000004okJ2W@03o`000?n/N9Wo[7RI00;o[7RI00Go0000ojihV?n^N9So[WRHo`00
0002ojihU`04o`000?nbNiSo/W^Ho`0000?o[WNF00Co0000ojmhU_n_N9Ko00006Oooool01?l0003o
Je>Tof]CY?l00003oiEXV`03o`000?nTLISoY76H00?oY76H00Go0000ojYcU_nZLiKoZW>Fo`000004
ojacU0;o00001OnU`nl2o`0000Gonk9P00Go0000oo^aG_l0003onk5No`000004oo^aGP04o`000?nL
GHGo0000o`0000;oUG:Y0_l00006ooooo`03o`000?oooooooooo00?ooooo0013ooooo`03o`000?oo
oooooooo03Kooooo00Ko0000onjfU_o^]YKok[JFo`000?ojaHl2o`000005onnhU_l0003om;Z=o`00
0?oobgH00_l000001?o`]I3o0000oo2cSOl00002oo2cS004o`000?m=;hcoCBn<o`0000?oVFVI00?o
0000okF0VoneP9/00oneP9/00ol0003obY6IolZAV@02olZAV@05o`000?oKXYWo0000omJKV?l00000
0ooHW9H01Ol0003ohJJEon6VUOoQYYGo000000?ofYjE00?o0000omZNU?oJWY@00_oJWY@00ol0003o
e9VEomBIU@02o`000003o`0S[ol0003o000000;oX8bo00?o0000ol6H[Oo1V:d00oo1V:d2o`0000Co
djFW00Go0000omfc[Ol0003ogjbRo`000003onNiY003o`000?odcjSom<nX00;o000000?ollRSo`00
0?l000002oooool2o`0000?o^:3000Go0000okN8Y?ngR:Co]hRTo`000003okJ2W@;o00001?n/N9T0
1Ol0003o[WRHojihV?n^N9So000000;o[WRG00Co0000ok9kV?nbNiSo00000on^MiH01?l0003o[gRF
ojmhU_l0000Iooooo`04o`000?m[DjCoJe>To`0000CoUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0
003oZW>FojYcU_nZLiKo000000Co[7>D00Co0000ol>7U?l0003oYL?_0ol000000onU`noo0000oo^b
H003oo^bH0;o000000?onk5No`000?ok/Eh00_l00003oo^aGP04o`000?nLGHGo0000o`0000;oUG:Y
0_l00007ooooo`03o`000?oooooooooo00;ooooo0014ooooo`03o`000?oooooooooo03Gooooo0_l0
0002onjfUPCo000000GokkRFo`000?od^Xgo0000ooo;MP02o`000004oo2eT?l0003ol;>=o`0000;o
l;><00Co0000odd_S?m=;hco00000onIJIT00ol0003o]H2KokF0V`03okF0V`03o`000?o:TIWobY6I
00;obY6I00Go0000om^RVOl0003oeY^Ho`000003omRLUP05o`000?oQYYGohJJEon6VUOl000000ooJ
WYD01?l0003ofYjDomZNU?oJWY@2o`0000;oe9VE0_l000000ol08joo0000oj2<_`02oj2<_`03o`00
0?o1V:go`IR]00?o`IR]00?o0000om>UYooCYJL00ooCYJL01Ol0003ogK>]o`000?oO[:;o000000;o
ikVT00Oo0000ooC?Z?odcjSom<nXo`000?o^lI[o000000kooooo00Go0000okRP`?nhX<3o^:30o`00
0003okN8Y004o`000?nfPYgo]X:MokJ2W@;o00001?n/N9T00ol0003o[WRHojihV002ojihV0;o0000
0onbNiP01Ol0003o[WNFojigU_n^MiKo000000;o[gRF00?o0000ooooooooool05oooool01Ol0003o
Je>Tof]CY?m[DjCo000000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0003oZW>FojYcU_nZLiKo
000000Co[7>D00Co0000ol>7U?o3QiCo00001OnU`nl03?l0003onk9Po`000?l0003oYL?_o`000?ok
/Eko0000oo^aG_l0003onk5No`0000;onk5N00Co0000oiaMQOl0003o00000_nELZT2o`0000Oooooo
00?o0000ooooooooool00_ooool004Gooooo00?o0000ooooooooool0=?ooool6o`000005onblX?l0
003okkRFo`000?od^Xd01?l000001?o`]I3o0000oo2cSOl00002oo2cS004o`000?m=;hcoCBn<o`00
00?oVFVI00?o0000okF0VoneP9/00oneP9/00ol0003obY6IolZAV@02olZAV@05o`000?oKXYWo0000
omJKV?l000000ooHW9H01Ol0003ohJJEon6VUOoQYYGo000000?ofYjE00Co0000omZNU?oJWYCofYjD
0_l00002omBIU@05o`000?oAUYKo0000o`0S[ol000000onPS;l00ol0003o`IR]ol6H[@02ol6H[@03
o`000?oCYJOodjFW00;odjFW00?o0000omfc[OoM/jd00_l00003onNiY004o`000?odcjSom<nXo`00
00;ok_6J00?o0000ooooooooool03?ooool01Ol0003o^:30okRP`?nhX<3o000000Co]hRT00Go0000
okJ2WOl0003oZ7NMo`000004ojahV@03o`000?n^N9So[WRH00;o[WRH0_l00003ok9kV007o`000?n^
MiKo[WNFojigU_l0003o[gRFo`00000Jooooo`05o`000?m[DjCoJe>Tof]CY?l000000onEJ9/00ol0
003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000000on/Li@00ol0003ohZNFo`000002
ol>7U004o`000?nU`nooYL?_ojG3k`?o00001?nU`nl2o`000008oo^aG_l0003onk5Noo^aG_l0003o
nk5No`000?nLGHD2o`0000;oUG:Y0_l00007ooooo`03o`000?oooooooooo00;ooooo0016ooooo`03
o`000?oooooooooo03?ooooo0_l000002Ol005Co0000o`00E?l0003ok;bPo`000?o_^9Ko0000ooBj
S@02o`000007onjiVOl0003ol;F@o`000?o`/hgo0000oo2cS002o`0000;oCBn<00Go0000oiUYVOnI
JIWoVFVIo`000004okF0V`;o00000oo:TIT01_l0003ofj:Iom^RVOl0003oeY^Ho`0000?of9bF00Go
0000on6VUOoQYYGohJJEo`000003omZNU@04o`000?oJWYCofYjDomZNU0;o00000_oDVID00ol0003o
dIJFom6FUP02o`0000?oX8bo00Oo0000ol6H[Oo1V:go`IR]o`000?o8YKKo000000;odjFW00?o0000
omfc[OoM/jd00_oM/jd01Ol0003oikVTonNiY?oW^JCo000000;om<nX00?o0000onkaV_l000004?oo
ool2o`000003okRP`?l0003o]hRT00?o]hRT0_l00003ojQgW@03o`000?n/N9Wo[7RI00;o[7RI00Co
0000ojihV?n^N9So[WRH0_l00003ok9kV007o`000?n^MiKo[WNFojigU_l0003o[gRFo`00000Joooo
o`05o`000?m[DjCoJe>Tof]CY?l000000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKo
ZW>FojYcU_l000000on/Li@00ol0003ohZNFo`000003ol>7U0?o000000?o/WRBo`000?l000000onU
`nl3o`000008oo^aG_l0003onk5Noo^aG_l0003onk5No`000?nLGHD2o`0000?oUG:Y00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`00Aoooool2o`0003?ooooo0_l00003o`00E0;o
00000_o_^9H2o`000005ooo;M_l0003o0000oo2eT?l000000_o`/hd01?l0003ol;><o`000?l00002
odd_S005o`000?nIJIWoVFVIoiUYVOl000001?neP9/2o`0000?obY6I00Go0000om^RVOoKXYWofj:I
o`000004omRLUP05o`000?oQYYGohJJEon6VUOl000000ooJWYD01?l0003ofYjDomZNU?oJWY@2o`00
00;oe9VE00?o0000om6FU_oAUYH00_l00003oj2<_`04o`000?o1V:go`IR]o`0000;ob:Ff00Co0000
om>UYooCYJOo00001?oM/jd01?l0003oikVTonNiY?l00002ooC?Z003o`000?o^lI[o000001?ooooo
00?o0000okRP`?l000000ongR:@2o`0000?oZ7NM00?o0000ojahVOn/N9T00_n/N9T01Ol0003o[WRH
ojihV?n^N9So000000Co/W^H00?o0000ojigU_n^MiH00_n^MiH2o`0001_ooooo00Co0000of]CY?m[
DjCo00000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000000on/Li@0
0ol0003ohZNFo`000004ol>7U003o`000?nbN9;o000000;ooooo0ol00003ojG3k`;o00000ook/Eh0
1Ol0003onk5No`000?nLGHGo000000?oUG:Y00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`00BOooool00ol0003oooooooooo`0`ooooo`;o00000_l005@02?l0003ok;bPo`000?o_
^9Ko0000ooBjSOl0003ool]f0_l000001_o`]I3o0000oo2cSOo`/hgo0000oo2cS0;o00000_m=;h`0
1Ol0003oVFVIoiUYVOnIJIWo000000Co]H2K00?o0000om6LWol000000_o:TIT01Ol0003ofj:Iom^R
VOoKXYWo000000?of9bF00Oo0000on6VUOoQYYGohJJEo`000?oa^9;o000000;ofYjE00Co0000omZN
U?oJWYCofYjD0_l00002omBIU@04o`000?oAUYKodIJFom6FUP;o00000onPS;l2o`0000?ob:Ff00?o
0000om>UYol000001?oM/jd01Ol0003okM2go`000?oW^JCo000000;om<nX0_l0000Eooooo`;o0000
00Co]hRTo`000?l0003o00001?nXMid00ol0003o[7RIojahV@02ojahV@05o`000?n^N9So[WRHojih
V?l000001?nbNiP00ol0003o[WNFojigUP02ojigUP;o00006oooool01?l0003oJe>Tof]CY?l00003
oiEXV`03o`000?nTLISoY76H00;oY76H00?o0000ojYcU_nZLiH00_nZLiH01_l0003o[7>DojacU?l0
003ohZNFo`0000Co`hND00?o0000ok9hT_l000000oooool01?l0003oYL?_ojG3konU`nl3o`0000Co
nk5N0_l000000onLGHGo0000oiEbZ@02oiEbZ@03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool004[ooooo00?o0000ooooooooool0;oooool03?l0003o001Do`00E?l005Co0000onbl
X?l0003okkRFo`000?od^Xgo0000ooo;MP;o000000Col;F@o`000?o`/hgo00000_o`/h`2o`0000;o
CBn<00Go0000oiUYVOnIJIWoVFVIo`000003okF0V`04o`000?oAW9oodIbOo`0000;obY6I00Go0000
om^RVOoKXYWofj:Io`000003omRLUP09o`000?oQYYGohJJEon6VUOl0003olKRBo`000?oJWYGo0000
00CofYjD00Co0000onZ_T_l0003o00001OoAUYH5o`0000Gob:Ff0_l00004omfc[@06o`000?o]d;Oo
0000onNiY?l0003om<nX0_l0000Gooooo`;o00000_nLMjL00ol0003oZ7NMojQgW@02ojQgW@03o`00
0?n/N9Wo[7RI00;o[7RI00Go0000ojihV?n^N9So[WRHo`000004ok9kV003o`000?n^MiKo[WNF00;o
[WNF0_l0000Kooooo`04o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00onTLIP01Ol0
003oZW>FojYcU_nZLiKo000000;o[7>D00?o0000on:WU_l000001?o3Qi@00ol0003o/WRBo`000004
ooooo`?o00000_ooool00ol0003onk5Noo^aGP02oo^aGP;o000000?oW5f5o`000?l000000_nELZT2
o`0000Kooooo00?o0000ooooooooool00_ooool004_ooooo00?o0000ooooooooool0;_ooool02_l0
003o001Do`00E?l005Co0000onblX?l0003okkRFo`000?od^Xd2o`000006onjiVOl0003ol;F@o`00
0?o`/hgo00000_o`/h`2o`0000;oCBn<00?o0000oiUYVOnIJIT00_nIJIT01?l0003o]H2KokF0Vol0
0002om6LW`04o`000?o:TIWobY6Io`0000?ofj:I00Go0000omRLU_oHW9Kof9bFo`000003on6VU@05
o`000?oa^9;o0000omZNUOl000001?oJWY@01?l0003ojZnBo`000?l00005om6FUP05o`000?n5Vn7o
QI_QohFKhOl000001Oo8YKH00ol0003ogK>]omfc[@02omfc[@04o`000?o]d;OokM2gong@]`;o0000
00?om<nXo`000?ooool05oooool01Ol0003oW7NWoiagYonLMjOo000000CoZ7NM00?o0000ojahVOn/
N9T00_n/N9T01Ol0003o[WRHojihV?n^N9So000000Co/W^H00?o0000ojigU_n^MiH00_n^MiH00ol0
003oooooooooo`0Kooooo`04o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP0
1Ol0003oZW>FojYcU_nZLiKo000000;o[7>D00?o0000on:WU_l000001?o3Qi@00ol0003o/WRBo`00
000:ooooo`Co000000?oooooo`000?nLGHD00_l00002oiEbZ@;o00001oooool00ol0003ooooooooo
o`01ooooo`00C?ooool2o`0002kooooo00Co0000o`00E?l005Co00000_o/_:001?l0003okkRFo`00
0?od^Xd2o`000006onjiVOl0003ol;F@o`000?o`/hgo00000_o`/h`3o`000003odd_S?l0003oVFVI
00?oVFVI00Co0000okF0VoneP9_o00000_oAW9l00ol0003obY6Io`000004om^RV@05o`000?oHW9Ko
f9bFomRLU_l000000ooQYYD01Ol0003olKRBo`000?oJWYGo000000?ofYjD00?o0000onZ_T_oZ[i80
0_l00005om6FUP;o00000on5Vn401?l0003ob:FfolRU]_o8YKH2o`0000CogK>]00Co0000ong@]oo]
d;OokM2g0ol0000Iooooo`05o`000?nLMjOoW7NWoiagYol000001?nXMid00ol0003o[7RIojahV@02
ojahV@03o`000?n^N9So[WRH00;o00001?nbNiP00ol0003o[WNFojigUP02ojigUP03o`000?oooooo
oooo01_ooooo00Co0000of]CY?m[DjCo00000onEJ9/00ol0003oY76HojAaV002ojAaV007o`000?nZ
LiKoZW>FojYcU_l0003o[7>Do`000003on:WUP07o`000?o3QiCo`hNDol>7U?l0003o/WRBo`00000:
ooooo`03o`000?oooooooooo00;ooooo1?l00002oiEbZ@;o00001oooool00ol0003oooooooooo`01
ooooo`00C_ooool00ol0003oooooooooo`0[ooooo`06o`000?l005Co001Do`000?o/_:3o00000_o_
^9H00ol0003om;Z=o`000002o`0000;ol;F@00?o0000oo2cSOl000000_o`/h`3o`000003odd_S?l0
003oVFVI00?oVFVI00?o0000okF0Vol000000ooAW9l00ol0003obY6Io`000003om^RV@;o00000ooH
W9H02Ol0003ohJJEon6VUOoQYYGo0000oo6hT_l0003ofYjEo`000003omZNU003o`000?oZ[i;ojZnB
00;o00001?oAUYH3o`0000?oQI_Q00Co0000olRU]_o8YKKo00000_oDalh01?l0003ogK>]omfc[Ol0
0003ong@]`;o00006oooool00ol0003oW7NWoiagY`02oiagY`05o`000?nXMigoZ7NMojQgWOl00000
1?n/N9T00ol0003o[WRHojihV002o`0000Go/W^H00Go0000ojigU_n^MiKo[WNFo`00000Mooooo`04
o`000?m[DjCoJe>To`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01ol0003oZW>FojYcU_nZLiKo
0000ojacU?l000000ooRYiH01ol0003o`hNDol>7U?o3QiCo0000ok9hT_l000004?ooool4o`000003
oiEbZOl0003o000000Oooooo00?o0000ooooooooool00Oooool004oooooo00?o0000ooooooooool0
:_ooool01_l0003o001Do`00E?l0003ok;bPo`0000;okkRF00?o0000ooBjSOl000000_l00002oo2e
T003o`000?o`/hgo000000;ol;><0ol000000om=;hco0000oiUYV@03oiUYV@03o`000?neP9_o0000
00?odIbO00?o0000olZAVOl000000ooKXYT00ol0003okk^Io`000002omRLUP09o`000?oQYYGohJJE
on6VUOl0003olKRBo`000?oJWYGo000000?ofYjD00?o0000onZ_T_oZ[i800_l00004om6FUP;o0000
00?ob8fFo`000?l000000_l000000oo8YKKo0000omC7cP03omC7cP03o`000?oM/jgo000000;okM2g
0ol0000Looooo`05o`000?nLMjOoW7NWoiagYol000000onXMid00ol0003o[7RIojahV@02ojahV@06
o`000?n^N9So[WRHo`000?oooooo00001?nbNiP01Ol0003o[WNFojigU_n^MiKo000001kooooo00?o
0000of]CY?l000000onEJ9/00ol0003oY76HojAaV002ojAaV007o`000?nZLiKoZW>FojYcU_l0003o
[7>Do`000003on:WUP03o`000?o3QiCo`hND00;o`hND0_l0000Aooooo`?o00000_nELZT00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo007ooooo001@ooooo`03o`000?oooooooooo02Wooooo
00?o0000o`00E?l000000_o/_:000ol0003okkRFonnhUP05o`0000;ol;F@00?o0000oo2cSOl00000
0_o`/h`3o`0000;oCBn<00Oo0000oiUYVOnIJIWoVFVIo`000?neP9_o000000?odIbO00?o0000olZA
VOl000000ooKXYT00ol0003okk^Io`000002omRLUP04o`000?oQYYGohJJEo`0000;olKRB00?o0000
omZNUOl000000ooJWY@00ol0003ojZnBonZ_TP02o`0000CodIJF0_l00004olR=UP;o00001OoDalh2
o`0000?okM2g0ol0000Looooo`05o`000?nLMjOoW7NWoiagYol000001?nXMid01ol0003o[7RIojah
VOn/N9Wo0000ojihV?l000000_ooool00ol0003o/W^Hok9kV002ok9kV005o`000?n^MiKo[WNFojig
U_l000007_ooool00ol0003oJe>To`000003oiEXV`03o`000?nTLISoY76H00;oY76H00Oo0000ojYc
U_nZLiKoZW>Fo`000?n/LiCo000000?ohZNF00?o0000ol>7U?o3Qi@00_o3Qi@2o`0001;ooooo00Go
0000ooooool0003oUG:Yo`000007ooooo`03o`000?oooooooooo007ooooo001Aooooo`;o0000:Ooo
ool00ol0003o001Do`000002onblX004o`000?o_^9Ko0000ooBjS@;o000000Cok[VIo`000?o`]I3o
00000_o`/hd00ol0003ol;><oo2cS003o`0000;oCBn<00Co0000oiUYVOnIJIWoVFVI0_l00004om6L
W`03o`000?o:TIWo000000?ofj:I00Go0000onnkVOl0003of9bFo`000003on6VU@04o`000?oa^9;o
lKRBoo6hTP;o00000ooJWY@01?l0003ojZnBonZ_T_l00005om6FUP03o`000?oY[iCo000000?ob8fF
00?o0000omfRUol000000ooDalh01ol0003oKMR^ofgH[_l0003okM2go`000?nlPYH00_l0000Loooo
o`05o`000?nLMjOoW7NWoiagYol000001?nXMid00ol0003o[7RIojahV@02ojahV@;o00000_ooool0
0ol0003o/W^Hok9kV002ok9kV004o`000?n^MiKo[WNFo`0001oooooo00?o0000of]CY?l000000onE
J9/00ol0003oY76HojAaV002ojAaV007o`000?nZLiKoZW>FojYcU_l0003o[7>Do`000003on:WUP03
o`000?o3QiCo`hND00;o`hND0_l0000Cooooo`;o000000?oUG:Yo`000?ooool01_ooool00ol0003o
ooooooooo`01ooooo`00Doooool00ol0003oooooooooo`0Vooooo`05o`000?l005Co0000onblX?l0
00000_o_^9H02?l0003om;Z=o`000?l0003ok[VIo`000?o`]I3o00000_o`/hd00ol0003ol;><o`00
0002oo2cR`04o`000?m=;hcoCBn<o`0000?oVFVI0_l00005om6LW`;o00000ooKXYT01Ol0003okk^I
o`000?oHW9Ko000000?ohJJE00Go0000oo6hT_oa^9;olKRBo`000004omZNU004o`000?oZ[i;ojZnB
o`0000GodIJF00?o0000onV_U?l000000_o8SIH00ol0003ogJ:GomfRU`02o`000003omC7c_l0003o
000000Co00000_nlPYH00ol0003oooooooooo`0Kooooo`05o`000?nLMjOoW7NWoiagYol000001?nX
Mid00ol0003o[7RIojahV@02ojahV@;o00000_ooool00ol0003o/W^Hok9kV002ok9kV004o`000?n^
MiKo[WNFo`00023ooooo00?o0000of]CY?l000000_nEJ9/00ol0003oY76HojAaV003ojAaV004o`00
0?nZLiKoZW>FojYcUP;o00000ooRYiH00ol0003o`hNDol>7U002ol>7U0;o00005?ooool00ol0003o
UG:Yo`000007ooooo`03o`000?oooooooooo007ooooo001Dooooo`03o`000?oooooooooo02Gooooo
0_l00002onblX005o`000?o_^9KokkRFo`000?od^Xd00_l000001_o^^IWo0000oo2eT?l0003ol;>=
o`0000;ol;><00Co0000oo2cRoo`/h_o00000_m=;h`01?l0003oVFVIoiUYVOnIJIT2o`0000GodIbO
00Go0000om^RVOoKXYWofj:Io`000002onnkV@03o`000?oHW9Ko000000?ohJJE00Go0000oo6hT_oa
^9;olKRBo`000003omZNU005o`000?oZ[i;ojZnBonZ_T_l000001?oAUYH01?l0003ojJnDonV_U?l0
0002olR=UP07o`000?oMXYOogJ:Go`000?noQIKo0000okn5UP02o`0000Go_8:F00?o0000oooooooo
ool06oooool01Ol0003oW7NWoiagYonLMjOo000000CoZ7NM00?o0000ojahVOn/N9T00_n/N9T2o`00
00;ooooo00?o0000ok9kV?nbNiP00_nbNiP01?l0003o[WNFojigU_l0000Pooooo`03o`000?m[DjCo
000000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP01Ol0003oZW>FojYcU_nZLiKo000000CohZNF00?o
0000ol>7U?o3Qi@00_o3Qi@2o`0001Cooooo0ol00008ooooo`7o00000Oooool1ooooo`00EOooool0
0ol0003oooooooooo`0Tooooo`;o00000_o/_:001Ol0003okkRFonnhU_l0003om;Z=00?o00000_o`
]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;00;o000000?oCBn<o`000?nIJIT00_nI
JIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:Iom^RVOl000000_o_^iT00ol0003of9bF
o`000003on6VU@05o`000?oa^9;olKRBoo6hT_l000000ooJWY@01Ol0003ojZnBonZ_T_oZ[i;o0000
00CodIJF00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfRUol00003okn5UP;o00001Onl
PYH00ol0003oooooooooo`0Kooooo`03o`000?nLMjOoW7NW00;oW7NW00Go0000ojQgWOnXMigoZ7NM
o`000004ojahV@05o`000?ooooooooooooooool000001?nbNiP01?l0003o[WNFojigU_l0000Qoooo
o`;o00000onEJ9/00ol0003oY76HojAaV002ojAaV005o`000?nZLiKoZW>FojYcU_l000001OoRYiH0
1?l0003o`hNDol>7U?o3Qi@2o`0001Gooooo0ol00007ooooo`7o00000Oooool1ooooo`00E_ooool0
0ol0003oooooooooo`0Sooooo`;o00000_o/_:002?l0003okkRFonnhU_l0003om;Z=o`000?o^^IWo
00000_o`]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;00;o000000?oCBn<o`000?nI
JIT00_nIJIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:Iom^RVOl000000_o_^iT00ol0
003of9bFo`000002on6VU@03o`000?oa^9;olKRB00;olKRB00Go0000omZNU?oJWYCofYjDo`000003
onZ_TP03o`000?oAUYKodIJF00;odIJF00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfR
Uol00003okn5UP03o`000?oooooo000000Co_8:F00?o0000ooooooooool07?ooool01Ol0003oW7NW
oiagYonLMjOo000000?oZ7NM00?o0000ojahVOn/N9T00_n/N9T01Ol0003ooooooooooooooooo0000
00Co/W^H00Co0000ojigU_n^MiKo00008Oooool2o`0000?oUFRK00?o0000ojAaV?nTLIP00_nTLIP0
1Ol0003oZW>FojYcU_nZLiKo000000GohZNF00Co0000ol>7U?o3QiCo`hND0_l0000Fooooo`;o0000
1oooool1o`00007ooooo0Oooool005Oooooo0_l0000Sooooo`;o00000_o/_:002?l0003okkRFonnh
U_l0003om;Z=o`000?o^^IWo00000_o`]I000ol0003ol;>=o`000002oo2cS003o`000?o`/h_ol;>;
00;o000000?oCBn<o`000?nIJIT00_nIJIT00ol0003odIbOom6LW`04om6LW`05o`000?oKXYWofj:I
om^RVOl000000oo_^iT2o`0000;ohJJE00?o0000oo6hT_oa^9800_oa^9801Ol0003ofYjDomZNU?oJ
WYCo000000?ojZnB00?o0000om6FU_oAUYH00_oAUYH01?l0003ojJnDonV_U?l00002olR=UP04o`00
0?oMXYOogJ:Go`0000;o_hFF00Co0000oooooooooooo00001?nlPYH00ol0003oooooooooo`0Loooo
o`05o`000?nLMjOoW7NWoiagYol000000onXMid00ol0003o[7RIojahV@02ojahV@05o`000?oooooo
ooooooooool000001?nbNiP00ol0003o[WNFo`00000Rooooo`;o00000onEJ9/00ol0003oY76HojAa
V002ojAaV005o`000?nZLiKoZW>FojYcU_l000001OoRYiH01?l0003o`hNDol>7U?o3Qi@2o`0001Ko
oooo0_l00007ooooo`7o00000Oooool1ooooo`00FOooool00ol0003oooooooooo`0Rooooo`;o0000
0oo_^9H3o`000007onjiVOl0003ol;F@oo2eT?l0003ol;>=o`000002oo2cS005o`000?o`/h_ol;>;
o`000?l`8Y000_l00002oiUYV@;o00001OoAW9l2o`0000?ofj:I00Go0000onnkVOo_^iWokk^Io`00
0003on6VU@04o`000?oa^9;olKRBoo6hTP;o00000ooJWY@00ol0003ojZnBonZ_TP02o`0000CodIJF
00Co0000onV_U?oY[iCo00000_o8SIH01?l0003ogJ:GomfRUol00002okn5UP04o`000?oooooooooo
o`0000Co_8:F00?o0000ooooooooool07?ooool01Ol0003oW7NWoiagYonLMjOo000000?oZ7NM00Go
0000ojahVOn/N9Wo[7RIo`000004ooooo`03o`000?nbNiSo/W^H00;o/W^H00?o0000ojigU_l00000
8oooool01Ol0003oUFRKoiEXVonEJ9_o000000CoY76H00Ko0000ojYcU_nZLiKo0000ooooool00004
on:WUP03o`000?o3QiCo`hND00;o`hND00?o0000ooooooooool05Oooool00ol0003oooooooooo`05
ooooo`7o00000Oooool1ooooo`00F_ooool00ol0003oooooooooo`0Qooooo`?o000000?okkRFo`00
0?od^Xd00_l000001oo^^IWo0000oo2eT?o`]I3o0000oo2cSOl000000_o`/h`01Ol0003ol;>;o`00
0?l0003o<2:@00;o000000GoVFVIo`000?o;YkGobjNeo`000004om6LW`05o`000?oV`k;o0000om^R
VOl000001?o_^iT01Ol0003ohJJEon6VUOoQYYGo000000?olKRB00?o0000onjmW_l000000_oJWY@0
1_l0003ojZnBonZ_T_l0003ol;^Ho`0000;odIJF00Go0000onV_U?oY[iCojJnDo`000002olR=UP04
o`000?oMXYOogJ:Go`0000;o_hFF00Co0000oooooooooooo00001?nlPYH00ol0003oooooooooo`0M
ooooo`04o`000?nLMjOoW7NWo`0000CoZ7NM00?o0000ojahVOl000001_ooool01ol0003o/W^Hok9k
V?nbNiSo0000ojigU_l000008oooool2o`0000;oUFRK00?o0000ojAaV?nTLIP00_nTLIP01_l0003o
ZW>FojYcU_l0003oooooo`0000CohZNF00?o0000ol>7U?o3Qi@00_o3Qi@00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Kooooo`03o`000?oooooooooo
023ooooo00?o0000o`00@Ol004400_l000001ood^Xgo0000o`000?o^^IWo0000oo2eT?l000000_o`
/hd01Ol0003ol;><oo2cS?l0003ol;>;00;o000000Go<2:@o`000?l0003oVFVIo`000002ol^W]@05
o`000?oAW9oodIbOom6LWol000000_oV`k800ol0003ofj:Io`000004onnkV@05o`000?oQYYGohJJE
on6VUOl000000ooa^9801Ol0003ok[fNo`000?oJWYCo000000?ojZnB00?o0000oo2kV?l000000_oA
UYH01ol0003ojJnDonV_U?oY[iCo0000olR=U_l000000ooMXYL01?l0003o_hFFokn5U_l00002oooo
o`05o`000?nlPYKo_8:Fokb2U_l000008Oooool00ol0003oW7NWo`000004ojQgW@03o`000?n/N9Wo
000000Kooooo00?o0000ok9kV?nbNiP00_nbNiP2o`0002?ooooo0_l00002oiEXV`03o`000?nTLISo
Y76H00?oY76H0_l00002ooooo`03o`000?oRYiKohZNF00;ohZNF00?o0000ol>7U?o3Qi@00_o3Qi@0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Loooo
o`;o00008?ooool00ol0003o0011o`00@@04o`000005onjiVOl0003ol;F@oo2eT?l000000_o`/hd0
1Ol0003ol;><oo2cS?l0003ol;>;00?o000000?o<2:@o`000?l000000oo;YkD01?l0003odIbOom6L
Wol00003onK3/P03o`000?oKXYWo000000Cokk^I00Go0000on6VUOoQYYGohJJEo`000003oo6hTP05
o`000?o^_Iko0000omZNU?l000000ooZ[i800ol0003ol;^Ho`000002om6FUP07o`000?oY[iCojJnD
onV_U?l0003ob8fFo`000003omfRU`04o`000?noQIKo_hFFo`0000;ooooo00Go0000okb2U_nlPYKo
_8:Fo`00000Rooooo`03o`000?nLMjOo000000?oZ7NM0_l00007ooooo`03o`000?nbNiSo/W^H00;o
/W^H0_l0000Tooooo`;o00000_nEJ9/00ol0003oY76HojAaV002ojAaV0;o00000oooool00ol0003o
hZNFon:WUP02on:WUP03o`000?o3QiCo`hND00;o00006Oooool00ol0003oooooooooo`04ooooo`7o
00000Oooool005kooooo00?o0000ooooooooool07Oooool3o`0000;oYL?_0_l000001oo^^IWo0000
oo2eT?o`]I3o0000oo2cSOl000000_o`/h`00ol0003ol;>;oo2cR`03o`000003oc0RT?l0003objNe
00?objNe00Co0000om6LWooAW9oo00000ooV`k800ol0003ofj:Io`000003onnkV@;o00000_oQYYD0
1Ol0003olKRBoo6hT_oa^9;o000000;ok[fN00?o0000omZNU?l000000ooZ[i800ol0003ol;^Ho`00
0002om6FUP07o`000?oY[iCojJnDonV_U?l0003ob8fFo`000003omfRU`04o`000?noQIKo_hFFo`00
00;ooooo00Go0000okb2U_nlPYKo_8:Fo`00000Sooooo`;o000000CoZ7NMo`000?l0003o00002?oo
ool00ol0003o/W^Hok9kV002ok9kV0;o00009_ooool00ol0003oUFRKo`000004ojAaV0;o00000ooo
ool00ol0003ohZNFon:WUP02on:WUP?o00007?ooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool005oooooo00?o0000ooooooooool07?ooool02Ol0003oYL?_ojG3konU`noo0000om?8col0003o
k[VIo`000002oo2eT003o`000?o`/hgo000000;ol;><00?o0000oo2cRoo`/h/00ol000000ol`8Y3o
0000ol^W]@03ol^W]@03o`000?oAW9oo000000Coi/>b00?o0000om^RVOl000000oo_^iT01Ol0003o
i/>co`000?oQYYGo000000?olKRB00Ko0000onjmW_o^_Iko0000omZNU?l00002onZ_TP04o`000?o`
^iSol;^Ho`0000;odIJF00?o0000onV_U?oY[i@00_oY[i@2o`0000?ogJ:G00Co0000okn5U_noQIKo
00000_ooool01Ol0003o_8:Fokb2U_nlPYKo000002Cooooo0_l0000;ooooo`03o`000?nbNiSo/W^H
00;o/W^H00?o0000ooooooooool09_ooool2o`0000;oY76H0ol00004ooooo`03o`000?oRYiKohZNF
00?o00007oooool00ol0003oooooooooo`02ooooo`7o00000Oooool0063ooooo00?o0000oooooooo
ool07?ooool00ol0003oYL?_o`000002om?8c`03o`000?o^^IWo000000;ol;F@00?o0000oo2cSOl0
00000_o`/h`01_l0003ol;>;oo2cRol0003ol;>=o`0000;o<2:@00?o0000ol^W]Oo;YkD00_o;YkD2
o`0000Goi/>b00Go0000onnkVOo_^iWokk^Io`000002onK3/`03o`000?oQYYGo000000?olKRB00Ko
0000onjmW_o^_Iko0000omZNU?l00002onZ_TP04o`000?o`^iSol;^Ho`0000;odIJF00?o0000onV_
U?oY[i@00_oY[i@2o`0000?ogJ:G00?o0000okn5U_l000000oooool01Ol0003o_8:Fokb2U_nlPYKo
0000037ooooo00?o0000ok9kV?nbNiP00_nbNiP00ol0003oooooooooo`0Wooooo`?o00002?ooool2
o`0002?ooooo00Go0000ooooooooooooooooo`000001ooooo`00HOooool2o`0001cooooo0ol00002
om?8c`03o`000?o^^IWo000000;ol;F@00?o0000oo2cSOl000000_o`/h`01_l0003ol;>;oo2cRol0
003ol;>=o`0000;o<2:@00Co0000ol^W]Oo;YkGobjNe0_l00006onK3/P05o`000?o_^iWokk^Ionnk
VOl000000_oV`k<00ol0003ohJJEo`000003oo6hTP06o`000?o^_Ikok[fNo`000?oJWYCo00000_oZ
[i801_l0003ol;^Hoo2kV?l0003odIJFo`0000GojJnD0_l00003omfRU`03o`000?noQIKo000000?o
oooo00Co0000okb2U_nlPYKo0000<_ooool00ol0003o/W^Hok9kV002ok9kV003o`000?oooooooooo
05Oooooo00Go0000ooooooooooooooooo`000001ooooo`00Hoooool00ol0003oooooooooo`0Ioooo
o`03o`000?l004?o001300;o00000_o^^IT01_l0003ol;F@oo2eT?l0003ol;>=o`0000;ol;><00Ko
0000oo2cRoo`/h_o0000oo2cSOl00002oc0RT004o`000?o;YkGo0000o`0000;oYL?_00?o0000onK3
/_oV`k800_oV`k82o`0000?okk^I00Ko0000onK3/ooV`k?o0000on6VUOl00003oo6hTP04o`000?o^
_Ikok[fNonjmWP;o00000_oZ[i801_l0003ol;^Hoo2kV?l0003odIJFo`0000GojJnD00?o0000omfR
UooMXYL00ooMXYL2o`0000?ooooo00Co0000okb2U_nlPYKo0000<_ooool00ol0003o/W^Hok9kV002
ok9kV003o`000?oooooooooo05Sooooo00Co0000oooooooooooo00000Oooool006Cooooo00?o0000
ooooooooool06?ooool00ol0003o0013o`000002o`000003onjiVOl0003ol;F@00;ol;F@00?o0000
oo2cSOl000000_o`/h`00ol0003ol;>;o`000002oo2cS@03o`000?l`8Y3o000000?o00001?nU`nl0
1_l0003oi/>bo`000?l0003oYL?_o`0000;okk^I00Oo0000onK3/ooV`k?oi/>co`000?oQYYGo0000
00;olKRB00?o0000onjmW_o^_Ih00_o^_Ih01Ol0003ojZnBonZ_T_oZ[i;o000000;ol;^H00?o0000
om6FU_l000001OoY[i@00ol0003ogJ:GomfRU`03omfRU`;o00000oooool01?l0003o_8:Fokb2U_l0
000booooo`05o`000?nbNiSo/W^Hok9kV?l00000G?ooool00ol0003oooooo`000001ooooo`00IOoo
ool00ol0003oooooooooo`0Gooooo`;o00000onU`nl2o`0000;ol;F@00Co0000oo2cSOo`/hgo0000
0_o`/h`00ol0003ol;>;o`000002oo2cS@;o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_
00?o0000onnkVOl000001?oV`k<01Ol0003olKRBoo6hT_oa^9;o000000Cok[fN00Co0000onZ_T_oZ
[i;o00001?o`^iP2o`0000GojJnD00?o0000omfRUooMXYL00ooMXYL2o`0000?ooooo00Co0000okb2
U_nlPYKo0000<oooool00ol0003o/W^Ho`00001Mooooo`03o`000?oooooooooo007o0000001Voooo
o`;o00006?ooool00ol0003oYL?_ojG3k`04o`000005oo2eT?l0003ol;>=oo2cSOl000000_o`/h`0
0ol0003ol;>;o`000003oo2cS@;o00000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005
onK3/`05o`000?oa^9;olKRBoo6hT_l000001?o^_Ih01?l0003ojZnBonZ_T_l00004oo2kV0;o0000
1OoY[i@00ol0003ogJ:GomfRU`03omfRU`;o00000oooool01?l0003o_8:Fokb2U_l0000cooooo`03
o`000?nbNiSo000005kooooo0Ol00001ooooo`7o0000001Xooooo`03o`000?oooooooooo01Kooooo
0_l00004ojG3k`;o000000?ol;>=o`000?o`/h`00_o`/h`00ol0003ol;>;o`000003oo2cS@04o`00
0?l008Oo0000o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?oV`k?oi/>c00Co
00000_oa^9800ol0003ok[fNonjmWP02onjmWP04o`000?oZ[i;ojZnBo`0000Col;^H00?o0000onV_
U?oY[i@00ooY[i@2o`0000GogJ:G00?o0000ooooooooool00_ooool01?l0003o_8:Fokb2U_l0000c
ooooo`;o0000H?ooool2o`000000JOooool00ol0003oooooooooo`0Gooooo`03o`000?nU`nooYL?_
00?o000000Gol;>=o`000?o`/hcol;><o`000002oo2cR`03o`000?o`/hgol;>=00Go00000_nU`nl4
o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`;o00001?o^_Ih01Ol0003oelW;o`000?oZ
[i;o000000Col;^H00?o0000onV_U?oY[i@00ooY[i@2o`0000GogJ:G00?o0000ooooooooool00ooo
ool2o`0003Cooooo00?o0000ooooooooool0G_ooool3o`000000J_ooool00ol0003oooooooooo`0F
ooooo`?o00000onU`nl2o`0000;ol;><00Co0000oo2cRoo`/h_o00000_o`/hd01?l0003ok[RIonjh
VOo^^9T3o`0000CoYL?_00?o0000ojG3konU`nl00ol00004ojG3k`03o`000?nU`nooYL?_00?o0000
0oo^_Ih01_l0003oelW;omO9bol0003ojZnBo`0000Col;^H00?o0000onV_U?oY[i@00ooY[i@00ol0
003oj<>`o`000004omfRU`03o`000?oooooooooo00?ooooo0_l0002Aooooo`Co00000oooool006_o
oooo00?o0000ooooooooool05Oooool00ol0003o0017o`000002ojG3k`Co000000Gol;><o`000?o`
/h_ol;>;o`000002oo2cS@06o`000?o^^9Wok[RIonjhVOl0003oUVNI0_l00002ojG3k`Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000onjmW_l000000ooGbL/2o`0000Gol;^H00?o
0000onV_U?oY[i@00_oY[i@01?l0003oj<>`onS3/?l00004omfRU`03o`000?oooooooooo00?ooooo
0_l0002=ooooo`Co00001oooool006cooooo0_l0000Eooooo`03o`000?l004Oo000000;o00001?nU
`nl2o`000003oo2cRol0003ol;>=00;ol;>=00So0000onjhVOo^^9Wok[RIo`000?nFIiWo0000oo2c
S0;o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005omO9
b`03o`000?o`^iSol;^H00;ol;^H00?o0000omK9cOl000000ooY[i@01?l0003oj<>`onS3/?l00003
omfRU`03o`000?oooooooooo00Cooooo0_l00029ooooo`Co00002oooool006kooooo00?o0000oooo
ooooool04_ooool2o`0000?oYL?_00?o0000ojG3konU`nl00ol000000oo`/h_o0000oo2cS@02oo2c
S@03o`000?o^^9Wok[RI00;ok[RI0_l000000oo`/hco0000o`000002ojG3k`Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000omO9booGbL/00ol00003oo2kV004o`000?oFbLgoe/W=
o`0000;ojJnD00Go0000onS3/?oX`k3oj<>`o`000003omfRU`03o`000?oooooooooo00Cooooo0_l0
0026ooooo`?o00003oooool006oooooo00?o0000ooooooooool04Oooool00ol0003oYL?_ojG3k`02
ojG3k`?o00000onU`nl2o`0000?ol;>=00?o0000onjhVOo^^9T00_o^^9T01Ol0003ol;><oo2cS?l0
003okkRF00;o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?o`^iSo000000Coe/W=00?o0000onV_U?l000000ooX`k001?l0003ogJ:GomfR
Uol00007ooooo`03o`000?oooooooooo087ooooo1?l0000Booooo`00L?ooool00ol0003ooooooooo
o`0Aooooo`06o`000?nU`noo0000o`000?nU`noo00001?nU`nl3o`000003oo2cSOl0003ok[RI00Co
k[RI00Co0000oo2cS?o`/hco00000_o_^9H00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?oFbLd00ol0003ojJnDo`000004onS3
/0;o00002?ooool00ol0003oooooooooo`1mooooo`Co00005_ooool0077ooooo0_l0000Booooo`;o
00000onU`nl01?l0003oYL?_o`000?l00003ojG3k`;o00001Oo^^9T01?l0003ol;><oo2cS?l00003
onnhUP?o00000oooool00ol0003oYL?_ojG3k`03o`0000CoYL?_00?o0000ojG3konU`nl00ol00004
ojG3k`03o`000?oFbLgoe/W=00?o00001OoX`k02o`0000Sooooo00?o0000ooooooooool0NOooool4
o`0001[ooooo001cooooo`03o`000?oooooooooo013ooooo0_l00002ojG3k`?o00001?nU`nl2o`00
00Gok[RI00Co0000oo2cS?o`/hco00001?o_^9H2o`0000Cooooo0ol00002ooooo`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000onS3/?oX`k000ol00021
ooooo`Co00007_ooool007Cooooo00?o0000ooooooooool03oooool01?l0003o001;o`000?l00003
ojG3k`06o`000?nU`noo0000o`000?nU`noo00001?o^^9T2o`000003oo2cS?l0003okkRF00CokkRF
00?o0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ojG3konU
`nl01?l00003ooooo`03o`000?nU`nooYL?_00Co0000P?ooool4o`0002;ooooo001eooooo`03o`00
0?oooooooooo00kooooo00Co0000o`00Bol004_o00000_nU`nl3o`0000CoYL?_00Co0000onjhVOl0
003o00000_nU`nl2o`0000GokkRF00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`;o00002?ooool2o`00083ooooo1?l0000Vooooo`00M_ooool2o`0000kooooo00?o0000o`00Bol0
00000ol00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl2o`0000GokkRF00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2@ooooo`?o0000:_ooool007Sooooo00?o0000ooooooooool0
2oooool2o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`noo0000o`0000;o
oooo00?o0000onnhU_o_^9H00ol00007ooooo`03o`000?oooooooooo08cooooo1?l0000]ooooo`00
NOooool00ol0003oooooooooo`0<ooooo`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_
ojG3k`03o`0000Gooooo0_l0000:ooooo`03o`000?oooooooooo08Sooooo1?l0000aooooo`00N_oo
ool00ol0003oooooooooo`0<ooooo`;o00000onU`nl00ol0003oYL?_ojG3k`03o`0001Cooooo00?o
0000ooooooooool0Q?ooool4o`0003Gooooo001kooooo`03o`000?oooooooooo00cooooo00?o0000
ojG3konU`nl01?l0000Gooooo`03o`000?oooooooooo083ooooo1?l0000iooooo`00O?ooool2o`00
00gooooo0_l0000Kooooo`03o`000?oooooooooo07cooooo1?l0000mooooo`00O_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo1?l00011ooooo`00Ooooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Kooooo0ol00015ooooo`00P?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo07;ooooo1?l00018ooooo`00POooool2o`0002Cooooo00?o0000
ooooooooool0K_ooool4o`0004cooooo0023ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0J_ooool4o`00053ooooo0024ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0I_ooool4o`0005Cooooo0025ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
H_ooool4o`0005Sooooo0026ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Co0000G?oo
ool008Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Kooooo`?o0000H?ooool0
08Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`Co0000Hoooool008[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Cooooo`Co0000Ioooool008_ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000Joooool008cooooo0_l0
000Iooooo`03o`000?oooooooooo04_ooooo1?l0001_ooooo`00S_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Oooooo1?l0001cooooo`00Soooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04?ooooo1?l0001gooooo`00T?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo043ooooo0ol0001kooooo`00TOooool2o`0001Cooooo00?o0000ooooooooool0
??ooool4o`0007kooooo002Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool4o`0008;ooooo002Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool4
o`0008Kooooo002Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool4o`00
08[ooooo002Fooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000S_ooool009Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000T_ooool009Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`?o0000U_ooool009[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000VOooool009_ooooo0_l00009oooo
o`03o`000?oooooooooo01kooooo1?l0002Mooooo`00WOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01[ooooo1?l0002Qooooo`00W_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Kooooo1?l0002Uooooo`00Woooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo1?l0002Yooooo`00X?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo1?l0002]ooooo`00XOooool2o`0000?ooooo00?o0000ooooooooool02oooool3o`00
0;7ooooo002Sooooo`04o`000?ooooooooooo`0000Wooooo1?l0002dooooo`00Y?ooool00ol0003o
ooooo`000005ooooo`Co0000^?ooool00:Gooooo0_l000000ooooooo0000o`000002o`000;cooooo
002Vooooo`;o0000`?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The error is largest near the cusps in the domain, where the \
solution is expected to vary most rapidly. Of course, one could improve the \
solution by keeping more terms in the expansion. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  "In this example, we consider the solution of Laplaces equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ", in a domain that has a concave cusp of the type discussed in relation to \
Fig. ",
  ButtonBox["6.1 (b)",
    ButtonData:>"Fig. 6.1",
    ButtonStyle->"Hyperlink"],
  ". The domain boundary is defined by the following two equations:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_1\)(x, y) = \ 
        x\^2 + y\^2 - 1, \[IndentingNewLine]\(z\_2\)(x, 
          y)\  = \ \(\(y\)\(-\)\) | x |  . \)]]
}], "Text"],

Cell[TextData[{
  " The domain is shown in Cell ",
  ButtonBox["6.24",
    ButtonData:>"Cell 6.24",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Calculus`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(z[1, x_, y_]\  = \ x\^2 + y\^2 - 1;\)\), "\[IndentingNewLine]", 
    \(\(z[2, x_, y_]\  = \ \ y - Abs[x]\ ;\)\ \n\), "\[IndentingNewLine]", 
    \(\(ContourPlot[\ 
        Boole[z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
            z[2, x, y] \[LessEqual] \ \ \ 0\ ], {x, \(-1.3\), 
          1.3}, {y, \(-1.3\), 1.3}, PlotPoints \[Rule] 100];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.24"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.369822 0.5 0.369822 [
[.13018 -0.0125 -6 -9 ]
[.13018 -0.0125 6 0 ]
[.31509 -0.0125 -12 -9 ]
[.31509 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68491 -0.0125 -9 -9 ]
[.68491 -0.0125 9 0 ]
[.86982 -0.0125 -3 -9 ]
[.86982 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13018 -12 -4.5 ]
[-0.0125 .13018 0 4.5 ]
[-0.0125 .31509 -24 -4.5 ]
[-0.0125 .31509 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .68491 -18 -4.5 ]
[-0.0125 .68491 0 4.5 ]
[-0.0125 .86982 -6 -4.5 ]
[-0.0125 .86982 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13018 0 m
.13018 .00625 L
s
[(-1)] .13018 -0.0125 0 1 Mshowa
.31509 0 m
.31509 .00625 L
s
[(-0.5)] .31509 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68491 0 m
.68491 .00625 L
s
[(0.5)] .68491 -0.0125 0 1 Mshowa
.86982 0 m
.86982 .00625 L
s
[(1)] .86982 -0.0125 0 1 Mshowa
.125 Mabswid
.16716 0 m
.16716 .00375 L
s
.20414 0 m
.20414 .00375 L
s
.24112 0 m
.24112 .00375 L
s
.27811 0 m
.27811 .00375 L
s
.35207 0 m
.35207 .00375 L
s
.38905 0 m
.38905 .00375 L
s
.42604 0 m
.42604 .00375 L
s
.46302 0 m
.46302 .00375 L
s
.53698 0 m
.53698 .00375 L
s
.57396 0 m
.57396 .00375 L
s
.61095 0 m
.61095 .00375 L
s
.64793 0 m
.64793 .00375 L
s
.72189 0 m
.72189 .00375 L
s
.75888 0 m
.75888 .00375 L
s
.79586 0 m
.79586 .00375 L
s
.83284 0 m
.83284 .00375 L
s
.0932 0 m
.0932 .00375 L
s
.05621 0 m
.05621 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.9068 0 m
.9068 .00375 L
s
.94379 0 m
.94379 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13018 m
.00625 .13018 L
s
[(-1)] -0.0125 .13018 1 0 Mshowa
0 .31509 m
.00625 .31509 L
s
[(-0.5)] -0.0125 .31509 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .68491 m
.00625 .68491 L
s
[(0.5)] -0.0125 .68491 1 0 Mshowa
0 .86982 m
.00625 .86982 L
s
[(1)] -0.0125 .86982 1 0 Mshowa
.125 Mabswid
0 .16716 m
.00375 .16716 L
s
0 .20414 m
.00375 .20414 L
s
0 .24112 m
.00375 .24112 L
s
0 .27811 m
.00375 .27811 L
s
0 .35207 m
.00375 .35207 L
s
0 .38905 m
.00375 .38905 L
s
0 .42604 m
.00375 .42604 L
s
0 .46302 m
.00375 .46302 L
s
0 .53698 m
.00375 .53698 L
s
0 .57396 m
.00375 .57396 L
s
0 .61095 m
.00375 .61095 L
s
0 .64793 m
.00375 .64793 L
s
0 .72189 m
.00375 .72189 L
s
0 .75888 m
.00375 .75888 L
s
0 .79586 m
.00375 .79586 L
s
0 .83284 m
.00375 .83284 L
s
0 .0932 m
.00375 .0932 L
s
0 .05621 m
.00375 .05621 L
s
0 .01923 m
.00375 .01923 L
s
0 .9068 m
.00375 .9068 L
s
0 .94379 m
.00375 .94379 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.13018 .99375 m
.13018 1 L
s
.31509 .99375 m
.31509 1 L
s
.5 .99375 m
.5 1 L
s
.68491 .99375 m
.68491 1 L
s
.86982 .99375 m
.86982 1 L
s
.125 Mabswid
.16716 .99625 m
.16716 1 L
s
.20414 .99625 m
.20414 1 L
s
.24112 .99625 m
.24112 1 L
s
.27811 .99625 m
.27811 1 L
s
.35207 .99625 m
.35207 1 L
s
.38905 .99625 m
.38905 1 L
s
.42604 .99625 m
.42604 1 L
s
.46302 .99625 m
.46302 1 L
s
.53698 .99625 m
.53698 1 L
s
.57396 .99625 m
.57396 1 L
s
.61095 .99625 m
.61095 1 L
s
.64793 .99625 m
.64793 1 L
s
.72189 .99625 m
.72189 1 L
s
.75888 .99625 m
.75888 1 L
s
.79586 .99625 m
.79586 1 L
s
.83284 .99625 m
.83284 1 L
s
.0932 .99625 m
.0932 1 L
s
.05621 .99625 m
.05621 1 L
s
.01923 .99625 m
.01923 1 L
s
.9068 .99625 m
.9068 1 L
s
.94379 .99625 m
.94379 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .13018 m
1 .13018 L
s
.99375 .31509 m
1 .31509 L
s
.99375 .5 m
1 .5 L
s
.99375 .68491 m
1 .68491 L
s
.99375 .86982 m
1 .86982 L
s
.125 Mabswid
.99625 .16716 m
1 .16716 L
s
.99625 .20414 m
1 .20414 L
s
.99625 .24112 m
1 .24112 L
s
.99625 .27811 m
1 .27811 L
s
.99625 .35207 m
1 .35207 L
s
.99625 .38905 m
1 .38905 L
s
.99625 .42604 m
1 .42604 L
s
.99625 .46302 m
1 .46302 L
s
.99625 .53698 m
1 .53698 L
s
.99625 .57396 m
1 .57396 L
s
.99625 .61095 m
1 .61095 L
s
.99625 .64793 m
1 .64793 L
s
.99625 .72189 m
1 .72189 L
s
.99625 .75888 m
1 .75888 L
s
.99625 .79586 m
1 .79586 L
s
.99625 .83284 m
1 .83284 L
s
.99625 .0932 m
1 .0932 L
s
.99625 .05621 m
1 .05621 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .9068 m
1 .9068 L
s
.99625 .94379 m
1 .94379 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.43687 .12685 m
.44658 .12685 L
.45629 .12685 L
.46601 .12685 L
.47572 .12685 L
.48543 .12685 L
.49514 .12685 L
.50486 .12685 L
.51457 .12685 L
.52428 .12685 L
.53399 .12685 L
.54371 .12685 L
.55342 .12685 L
.56313 .12685 L
.57206 .13578 L
.57284 .13657 L
.58256 .13657 L
.59227 .13657 L
.60198 .13657 L
.61091 .14549 L
.61169 .14628 L
.62141 .14628 L
.63112 .14628 L
.64005 .15521 L
.64083 .15599 L
.65054 .15599 L
.65947 .16492 L
.66026 .1657 L
.66997 .1657 L
.6789 .17463 L
.67968 .17542 L
.68939 .17542 L
.69832 .18434 L
.69911 .18513 L
.70803 .19406 L
.70882 .19484 L
.71853 .19484 L
.72746 .20377 L
.72824 .20455 L
.73717 .21348 L
.73796 .21427 L
.74688 .22319 L
.74767 .22398 L
.7566 .23291 L
.75738 .23369 L
.76631 .24262 L
.76709 .2434 L
.77602 .25233 L
.77681 .25312 L
.78573 .26204 L
.78652 .26283 L
.79545 .27176 L
.79623 .27254 L
.80516 .28147 L
.80516 .29118 L
.80594 .29197 L
.81487 .30089 L
.81566 .30168 L
.82458 .31061 L
.82458 .32032 L
.82537 .3211 L
.8343 .33003 L
.8343 .33974 L
.83508 .34053 L
.84401 .34946 L
.84401 .35917 L
.84479 .35995 L
.85372 .36888 L
.85372 .37859 L
.85372 .38831 L
.85451 .38909 L
.86343 .39802 L
.86343 .40773 L
.86343 .41744 L
.86343 .42716 L
.86422 .42794 L
.87315 .43687 L
.87315 .44658 L
.87315 .45629 L
.87315 .46601 L
.87315 .47572 L
.87315 .48543 L
.87315 .49514 L
.87315 .50486 L
.87315 .51457 L
.87315 .52428 L
.87315 .53399 L
.87315 .54371 L
.87315 .55342 L
.87315 .56313 L
.86422 .57206 L
.86343 .57284 L
.86343 .58256 L
.86343 .59227 L
.86343 .60198 L
.85451 .61091 L
.85372 .61169 L
.85372 .62141 L
.85372 .63112 L
.84479 .64005 L
.84401 .64083 L
.84401 .65054 L
.83508 .65947 L
.8343 .66026 L
.8343 .66997 L
.82537 .6789 L
.82458 .67968 L
.82458 .68939 L
.81566 .69832 L
.81487 .69911 L
.80594 .70803 L
.80516 .70882 L
.80516 .71853 L
.79623 .72746 L
.79545 .72824 L
.78652 .73717 L
.78573 .73796 L
.77681 .74688 L
.77602 .74767 L
.76709 .7566 L
.76643 .75738 L
.75738 .76631 L
.74833 .75738 L
.74767 .7566 L
.73874 .74767 L
.73796 .74688 L
.72903 .73796 L
.72824 .73717 L
.71932 .72824 L
.71853 .72746 L
.7096 .71853 L
.70882 .71775 L
.69989 .70882 L
.69911 .70803 L
.69018 .69911 L
.68939 .69832 L
.68047 .68939 L
.67968 .68861 L
.67075 .67968 L
.66997 .6789 L
.66104 .66997 L
.66026 .66918 L
.65133 .66026 L
.65054 .65947 L
.64162 .65054 L
.64083 .64976 L
.6319 .64083 L
.63112 .64005 L
.62219 .63112 L
.62141 .63033 L
.61248 .62141 L
.61169 .62062 L
.60277 .61169 L
.60198 .61091 L
.59305 .60198 L
.59227 .6012 L
.58334 .59227 L
.58256 .59148 L
.57363 .58256 L
.57284 .58177 L
.56392 .57284 L
.56313 .57206 L
.5542 .56313 L
.55342 .56235 L
.54449 .55342 L
.54371 .55263 L
.53478 .54371 L
.53399 .54292 L
.52507 .53399 L
.52428 .53321 L
.51535 .52428 L
.51457 .5235 L
.50564 .51457 L
.50486 .51378 L
.49514 .51378 L
.49436 .51457 L
.48543 .5235 L
.48465 .52428 L
.47572 .53321 L
.47493 .53399 L
.46601 .54292 L
.46522 .54371 L
.45629 .55263 L
.45551 .55342 L
.44658 .56235 L
.4458 .56313 L
.43687 .57206 L
.43608 .57284 L
.42716 .58177 L
.42637 .58256 L
.41744 .59148 L
.41666 .59227 L
.40773 .6012 L
.40695 .60198 L
.39802 .61091 L
.39723 .61169 L
.38831 .62062 L
.38752 .62141 L
.37859 .63033 L
.37781 .63112 L
.36888 .64005 L
.3681 .64083 L
.35917 .64976 L
.35838 .65054 L
.34946 .65947 L
.34867 .66026 L
.33974 .66918 L
.33896 .66997 L
.33003 .6789 L
.32925 .67968 L
.32032 .68861 L
.31953 .68939 L
.31061 .69832 L
.30982 .69911 L
.30089 .70803 L
.30011 .70882 L
.29118 .71775 L
.2904 .71853 L
.28147 .72746 L
.28068 .72824 L
.27176 .73717 L
.27097 .73796 L
.26204 .74688 L
.26126 .74767 L
.25233 .7566 L
.25167 .75738 L
.24262 .76631 L
.23357 .75738 L
.23291 .7566 L
.22398 .74767 L
.22319 .74688 L
.21427 .73796 L
.21348 .73717 L
.20455 .72824 L
.20377 .72746 L
.19484 .71853 L
.19484 .70882 L
.19406 .70803 L
.18513 .69911 L
.18434 .69832 L
.17542 .68939 L
.17542 .67968 L
.17463 .6789 L
.1657 .66997 L
.1657 .66026 L
.16492 .65947 L
.15599 .65054 L
.15599 .64083 L
.15521 .64005 L
.14628 .63112 L
.14628 .62141 L
.14628 .61169 L
.14549 .61091 L
.13657 .60198 L
.13657 .59227 L
.13657 .58256 L
.13657 .57284 L
.13578 .57206 L
.12685 .56313 L
.12685 .55342 L
.12685 .54371 L
.12685 .53399 L
.12685 .52428 L
.12685 .51457 L
.12685 .50486 L
.12685 .49514 L
.12685 .48543 L
.12685 .47572 L
.12685 .46601 L
.12685 .45629 L
.12685 .44658 L
.12685 .43687 L
.13578 .42794 L
.13657 .42716 L
.13657 .41744 L
.13657 .40773 L
.13657 .39802 L
.14549 .38909 L
.14628 .38831 L
.14628 .37859 L
.14628 .36888 L
.15521 .35995 L
.15599 .35917 L
.15599 .34946 L
.16492 .34053 L
.1657 .33974 L
.1657 .33003 L
.17463 .3211 L
.17542 .32032 L
.17542 .31061 L
.18434 .30168 L
.18513 .30089 L
.19406 .29197 L
.19484 .29118 L
.19484 .28147 L
.20377 .27254 L
.20455 .27176 L
.21348 .26283 L
.21427 .26204 L
.22319 .25312 L
.22398 .25233 L
.23291 .2434 L
.23369 .24262 L
.24262 .23369 L
.2434 .23291 L
.25233 .22398 L
.25312 .22319 L
.26204 .21427 L
.26283 .21348 L
.27176 .20455 L
.27254 .20377 L
.28147 .19484 L
.29118 .19484 L
.29197 .19406 L
.30089 .18513 L
.30168 .18434 L
.31061 .17542 L
.32032 .17542 L
.3211 .17463 L
.33003 .1657 L
.33974 .1657 L
.34053 .16492 L
.34946 .15599 L
.35917 .15599 L
.35995 .15521 L
.36888 .14628 L
.37859 .14628 L
.38831 .14628 L
.38909 .14549 L
.39802 .13657 L
.40773 .13657 L
.41744 .13657 L
.42716 .13657 L
.42794 .13578 L
F
0 g
.43687 .12685 m
.44658 .12685 L
.45629 .12685 L
.46601 .12685 L
.47572 .12685 L
.48543 .12685 L
.49514 .12685 L
.50486 .12685 L
.51457 .12685 L
.52428 .12685 L
.53399 .12685 L
.54371 .12685 L
.55342 .12685 L
.56313 .12685 L
.57206 .13578 L
.57284 .13657 L
.58256 .13657 L
.59227 .13657 L
.60198 .13657 L
.61091 .14549 L
.61169 .14628 L
.62141 .14628 L
.63112 .14628 L
.64005 .15521 L
.64083 .15599 L
.65054 .15599 L
.65947 .16492 L
.66026 .1657 L
.66997 .1657 L
.6789 .17463 L
.67968 .17542 L
.68939 .17542 L
.69832 .18434 L
.69911 .18513 L
.70803 .19406 L
.70882 .19484 L
.71853 .19484 L
.72746 .20377 L
.72824 .20455 L
.73717 .21348 L
.73796 .21427 L
.74688 .22319 L
.74767 .22398 L
.7566 .23291 L
.75738 .23369 L
.76631 .24262 L
.76709 .2434 L
.77602 .25233 L
.77681 .25312 L
.78573 .26204 L
Mistroke
.78652 .26283 L
.79545 .27176 L
.79623 .27254 L
.80516 .28147 L
.80516 .29118 L
.80594 .29197 L
.81487 .30089 L
.81566 .30168 L
.82458 .31061 L
.82458 .32032 L
.82537 .3211 L
.8343 .33003 L
.8343 .33974 L
.83508 .34053 L
.84401 .34946 L
.84401 .35917 L
.84479 .35995 L
.85372 .36888 L
.85372 .37859 L
.85372 .38831 L
.85451 .38909 L
.86343 .39802 L
.86343 .40773 L
.86343 .41744 L
.86343 .42716 L
.86422 .42794 L
.87315 .43687 L
.87315 .44658 L
.87315 .45629 L
.87315 .46601 L
.87315 .47572 L
.87315 .48543 L
.87315 .49514 L
.87315 .50486 L
.87315 .51457 L
.87315 .52428 L
.87315 .53399 L
.87315 .54371 L
.87315 .55342 L
.87315 .56313 L
.86422 .57206 L
.86343 .57284 L
.86343 .58256 L
.86343 .59227 L
.86343 .60198 L
.85451 .61091 L
.85372 .61169 L
.85372 .62141 L
.85372 .63112 L
.84479 .64005 L
Mistroke
.84401 .64083 L
.84401 .65054 L
.83508 .65947 L
.8343 .66026 L
.8343 .66997 L
.82537 .6789 L
.82458 .67968 L
.82458 .68939 L
.81566 .69832 L
.81487 .69911 L
.80594 .70803 L
.80516 .70882 L
.80516 .71853 L
.79623 .72746 L
.79545 .72824 L
.78652 .73717 L
.78573 .73796 L
.77681 .74688 L
.77602 .74767 L
.76709 .7566 L
.76643 .75738 L
.75738 .76631 L
.74833 .75738 L
.74767 .7566 L
.73874 .74767 L
.73796 .74688 L
.72903 .73796 L
.72824 .73717 L
.71932 .72824 L
.71853 .72746 L
.7096 .71853 L
.70882 .71775 L
.69989 .70882 L
.69911 .70803 L
.69018 .69911 L
.68939 .69832 L
.68047 .68939 L
.67968 .68861 L
.67075 .67968 L
.66997 .6789 L
.66104 .66997 L
.66026 .66918 L
.65133 .66026 L
.65054 .65947 L
.64162 .65054 L
.64083 .64976 L
.6319 .64083 L
.63112 .64005 L
.62219 .63112 L
.62141 .63033 L
Mistroke
.61248 .62141 L
.61169 .62062 L
.60277 .61169 L
.60198 .61091 L
.59305 .60198 L
.59227 .6012 L
.58334 .59227 L
.58256 .59148 L
.57363 .58256 L
.57284 .58177 L
.56392 .57284 L
.56313 .57206 L
.5542 .56313 L
.55342 .56235 L
.54449 .55342 L
.54371 .55263 L
.53478 .54371 L
.53399 .54292 L
.52507 .53399 L
.52428 .53321 L
.51535 .52428 L
.51457 .5235 L
.50564 .51457 L
.50486 .51378 L
.49514 .51378 L
.49436 .51457 L
.48543 .5235 L
.48465 .52428 L
.47572 .53321 L
.47493 .53399 L
.46601 .54292 L
.46522 .54371 L
.45629 .55263 L
.45551 .55342 L
.44658 .56235 L
.4458 .56313 L
.43687 .57206 L
.43608 .57284 L
.42716 .58177 L
.42637 .58256 L
.41744 .59148 L
.41666 .59227 L
.40773 .6012 L
.40695 .60198 L
.39802 .61091 L
.39723 .61169 L
.38831 .62062 L
.38752 .62141 L
.37859 .63033 L
.37781 .63112 L
Mistroke
.36888 .64005 L
.3681 .64083 L
.35917 .64976 L
.35838 .65054 L
.34946 .65947 L
.34867 .66026 L
.33974 .66918 L
.33896 .66997 L
.33003 .6789 L
.32925 .67968 L
.32032 .68861 L
.31953 .68939 L
.31061 .69832 L
.30982 .69911 L
.30089 .70803 L
.30011 .70882 L
.29118 .71775 L
.2904 .71853 L
.28147 .72746 L
.28068 .72824 L
.27176 .73717 L
.27097 .73796 L
.26204 .74688 L
.26126 .74767 L
.25233 .7566 L
.25167 .75738 L
.24262 .76631 L
.23357 .75738 L
.23291 .7566 L
.22398 .74767 L
.22319 .74688 L
.21427 .73796 L
.21348 .73717 L
.20455 .72824 L
.20377 .72746 L
.19484 .71853 L
.19484 .70882 L
.19406 .70803 L
.18513 .69911 L
.18434 .69832 L
.17542 .68939 L
.17542 .67968 L
.17463 .6789 L
.1657 .66997 L
.1657 .66026 L
.16492 .65947 L
.15599 .65054 L
.15599 .64083 L
.15521 .64005 L
.14628 .63112 L
Mistroke
.14628 .62141 L
.14628 .61169 L
.14549 .61091 L
.13657 .60198 L
.13657 .59227 L
.13657 .58256 L
.13657 .57284 L
.13578 .57206 L
.12685 .56313 L
.12685 .55342 L
.12685 .54371 L
.12685 .53399 L
.12685 .52428 L
.12685 .51457 L
.12685 .50486 L
.12685 .49514 L
.12685 .48543 L
.12685 .47572 L
.12685 .46601 L
.12685 .45629 L
.12685 .44658 L
.12685 .43687 L
.13578 .42794 L
.13657 .42716 L
.13657 .41744 L
.13657 .40773 L
.13657 .39802 L
.14549 .38909 L
.14628 .38831 L
.14628 .37859 L
.14628 .36888 L
.15521 .35995 L
.15599 .35917 L
.15599 .34946 L
.16492 .34053 L
.1657 .33974 L
.1657 .33003 L
.17463 .3211 L
.17542 .32032 L
.17542 .31061 L
.18434 .30168 L
.18513 .30089 L
.19406 .29197 L
.19484 .29118 L
.19484 .28147 L
.20377 .27254 L
.20455 .27176 L
.21348 .26283 L
.21427 .26204 L
.22319 .25312 L
Mistroke
.22398 .25233 L
.23291 .2434 L
.23369 .24262 L
.24262 .23369 L
.2434 .23291 L
.25233 .22398 L
.25312 .22319 L
.26204 .21427 L
.26283 .21348 L
.27176 .20455 L
.27254 .20377 L
.28147 .19484 L
.29118 .19484 L
.29197 .19406 L
.30089 .18513 L
.30168 .18434 L
.31061 .17542 L
.32032 .17542 L
.3211 .17463 L
.33003 .1657 L
.33974 .1657 L
.34053 .16492 L
.34946 .15599 L
.35917 .15599 L
.35995 .15521 L
.36888 .14628 L
.37859 .14628 L
.38831 .14628 L
.38909 .14549 L
.39802 .13657 L
.40773 .13657 L
.41744 .13657 L
.42716 .13657 L
.42794 .13578 L
.43687 .12685 L
Mfstroke
.2 g
.43687 .12783 m
.44658 .12783 L
.45629 .12783 L
.46601 .12783 L
.47572 .12783 L
.48543 .12783 L
.49514 .12783 L
.50486 .12783 L
.51457 .12783 L
.52428 .12783 L
.53399 .12783 L
.54371 .12783 L
.55342 .12783 L
.56313 .12783 L
.57108 .13578 L
.57284 .13755 L
.58256 .13755 L
.59227 .13755 L
.60198 .13755 L
.60993 .14549 L
.61169 .14726 L
.62141 .14726 L
.63112 .14726 L
.63907 .15521 L
.64083 .15697 L
.65054 .15697 L
.65849 .16492 L
.66026 .16668 L
.66997 .16668 L
.67792 .17463 L
.67968 .1764 L
.68939 .1764 L
.69734 .18434 L
.69911 .18611 L
.70705 .19406 L
.70882 .19582 L
.71853 .19582 L
.72648 .20377 L
.72824 .20553 L
.73619 .21348 L
.73796 .21525 L
.7459 .22319 L
.74767 .22496 L
.75562 .23291 L
.75738 .23467 L
.76533 .24262 L
.76709 .24438 L
.77504 .25233 L
.77681 .2541 L
.78475 .26204 L
.78652 .26381 L
.79447 .27176 L
.79623 .27352 L
.80418 .28147 L
.80418 .29118 L
.80594 .29295 L
.81389 .30089 L
.81566 .30266 L
.8236 .31061 L
.8236 .32032 L
.82537 .32208 L
.83332 .33003 L
.83332 .33974 L
.83508 .34151 L
.84303 .34946 L
.84303 .35917 L
.84479 .36093 L
.85274 .36888 L
.85274 .37859 L
.85274 .38831 L
.85451 .39007 L
.86245 .39802 L
.86245 .40773 L
.86245 .41744 L
.86245 .42716 L
.86422 .42892 L
.87217 .43687 L
.87217 .44658 L
.87217 .45629 L
.87217 .46601 L
.87217 .47572 L
.87217 .48543 L
.87217 .49514 L
.87217 .50486 L
.87217 .51457 L
.87217 .52428 L
.87217 .53399 L
.87217 .54371 L
.87217 .55342 L
.87217 .56313 L
.86422 .57108 L
.86245 .57284 L
.86245 .58256 L
.86245 .59227 L
.86245 .60198 L
.85451 .60993 L
.85274 .61169 L
.85274 .62141 L
.85274 .63112 L
.84479 .63907 L
.84303 .64083 L
.84303 .65054 L
.83508 .65849 L
.83332 .66026 L
.83332 .66997 L
.82537 .67792 L
.8236 .67968 L
.8236 .68939 L
.81566 .69734 L
.81389 .69911 L
.80594 .70705 L
.80418 .70882 L
.80418 .71853 L
.79623 .72648 L
.79447 .72824 L
.78652 .73619 L
.78475 .73796 L
.77681 .7459 L
.77504 .74767 L
.76709 .75562 L
.76558 .75738 L
.75738 .76533 L
.74918 .75738 L
.74767 .75562 L
.73972 .74767 L
.73796 .7459 L
.73001 .73796 L
.72824 .73619 L
.7203 .72824 L
.71853 .72648 L
.71058 .71853 L
.70882 .71677 L
.70087 .70882 L
.69911 .70705 L
.69116 .69911 L
.68939 .69734 L
.68145 .68939 L
.67968 .68763 L
.67173 .67968 L
.66997 .67792 L
.66202 .66997 L
.66026 .6682 L
.65231 .66026 L
.65054 .65849 L
.6426 .65054 L
.64083 .64878 L
.63288 .64083 L
.63112 .63907 L
.62317 .63112 L
.62141 .62935 L
.61346 .62141 L
.61169 .61964 L
.60375 .61169 L
.60198 .60993 L
.59403 .60198 L
.59227 .60022 L
.58432 .59227 L
.58256 .5905 L
.57461 .58256 L
.57284 .58079 L
.5649 .57284 L
.56313 .57108 L
.55518 .56313 L
.55342 .56137 L
.54547 .55342 L
.54371 .55165 L
.53576 .54371 L
.53399 .54194 L
.52605 .53399 L
.52428 .53223 L
.51633 .52428 L
.51457 .52252 L
.50662 .51457 L
.50486 .5128 L
.49514 .5128 L
.49338 .51457 L
.48543 .52252 L
.48367 .52428 L
.47572 .53223 L
.47395 .53399 L
.46601 .54194 L
.46424 .54371 L
.45629 .55165 L
.45453 .55342 L
.44658 .56137 L
.44482 .56313 L
.43687 .57108 L
.4351 .57284 L
.42716 .58079 L
.42539 .58256 L
.41744 .5905 L
.41568 .59227 L
.40773 .60022 L
.40597 .60198 L
.39802 .60993 L
.39625 .61169 L
.38831 .61964 L
.38654 .62141 L
.37859 .62935 L
.37683 .63112 L
.36888 .63907 L
.36712 .64083 L
.35917 .64878 L
.3574 .65054 L
.34946 .65849 L
.34769 .66026 L
.33974 .6682 L
.33798 .66997 L
.33003 .67792 L
.32827 .67968 L
.32032 .68763 L
.31855 .68939 L
.31061 .69734 L
.30884 .69911 L
.30089 .70705 L
.29913 .70882 L
.29118 .71677 L
.28942 .71853 L
.28147 .72648 L
.2797 .72824 L
.27176 .73619 L
.26999 .73796 L
.26204 .7459 L
.26028 .74767 L
.25233 .75562 L
.25082 .75738 L
.24262 .76533 L
.23442 .75738 L
.23291 .75562 L
.22496 .74767 L
.22319 .7459 L
.21525 .73796 L
.21348 .73619 L
.20553 .72824 L
.20377 .72648 L
.19582 .71853 L
.19582 .70882 L
.19406 .70705 L
.18611 .69911 L
.18434 .69734 L
.1764 .68939 L
.1764 .67968 L
.17463 .67792 L
.16668 .66997 L
.16668 .66026 L
.16492 .65849 L
.15697 .65054 L
.15697 .64083 L
.15521 .63907 L
.14726 .63112 L
.14726 .62141 L
.14726 .61169 L
.14549 .60993 L
.13755 .60198 L
.13755 .59227 L
.13755 .58256 L
.13755 .57284 L
.13578 .57108 L
.12783 .56313 L
.12783 .55342 L
.12783 .54371 L
.12783 .53399 L
.12783 .52428 L
.12783 .51457 L
.12783 .50486 L
.12783 .49514 L
.12783 .48543 L
.12783 .47572 L
.12783 .46601 L
.12783 .45629 L
.12783 .44658 L
.12783 .43687 L
.13578 .42892 L
.13755 .42716 L
.13755 .41744 L
.13755 .40773 L
.13755 .39802 L
.14549 .39007 L
.14726 .38831 L
.14726 .37859 L
.14726 .36888 L
.15521 .36093 L
.15697 .35917 L
.15697 .34946 L
.16492 .34151 L
.16668 .33974 L
.16668 .33003 L
.17463 .32208 L
.1764 .32032 L
.1764 .31061 L
.18434 .30266 L
.18611 .30089 L
.19406 .29295 L
.19582 .29118 L
.19582 .28147 L
.20377 .27352 L
.20553 .27176 L
.21348 .26381 L
.21525 .26204 L
.22319 .2541 L
.22496 .25233 L
.23291 .24438 L
.23467 .24262 L
.24262 .23467 L
.24438 .23291 L
.25233 .22496 L
.2541 .22319 L
.26204 .21525 L
.26381 .21348 L
.27176 .20553 L
.27352 .20377 L
.28147 .19582 L
.29118 .19582 L
.29295 .19406 L
.30089 .18611 L
.30266 .18434 L
.31061 .1764 L
.32032 .1764 L
.32208 .17463 L
.33003 .16668 L
.33974 .16668 L
.34151 .16492 L
.34946 .15697 L
.35917 .15697 L
.36093 .15521 L
.36888 .14726 L
.37859 .14726 L
.38831 .14726 L
.39007 .14549 L
.39802 .13755 L
.40773 .13755 L
.41744 .13755 L
.42716 .13755 L
.42892 .13578 L
F
0 g
.43687 .12783 m
.44658 .12783 L
.45629 .12783 L
.46601 .12783 L
.47572 .12783 L
.48543 .12783 L
.49514 .12783 L
.50486 .12783 L
.51457 .12783 L
.52428 .12783 L
.53399 .12783 L
.54371 .12783 L
.55342 .12783 L
.56313 .12783 L
.57108 .13578 L
.57284 .13755 L
.58256 .13755 L
.59227 .13755 L
.60198 .13755 L
.60993 .14549 L
.61169 .14726 L
.62141 .14726 L
.63112 .14726 L
.63907 .15521 L
.64083 .15697 L
.65054 .15697 L
.65849 .16492 L
.66026 .16668 L
.66997 .16668 L
.67792 .17463 L
.67968 .1764 L
.68939 .1764 L
.69734 .18434 L
.69911 .18611 L
.70705 .19406 L
.70882 .19582 L
.71853 .19582 L
.72648 .20377 L
.72824 .20553 L
.73619 .21348 L
.73796 .21525 L
.7459 .22319 L
.74767 .22496 L
.75562 .23291 L
.75738 .23467 L
.76533 .24262 L
.76709 .24438 L
.77504 .25233 L
.77681 .2541 L
.78475 .26204 L
Mistroke
.78652 .26381 L
.79447 .27176 L
.79623 .27352 L
.80418 .28147 L
.80418 .29118 L
.80594 .29295 L
.81389 .30089 L
.81566 .30266 L
.8236 .31061 L
.8236 .32032 L
.82537 .32208 L
.83332 .33003 L
.83332 .33974 L
.83508 .34151 L
.84303 .34946 L
.84303 .35917 L
.84479 .36093 L
.85274 .36888 L
.85274 .37859 L
.85274 .38831 L
.85451 .39007 L
.86245 .39802 L
.86245 .40773 L
.86245 .41744 L
.86245 .42716 L
.86422 .42892 L
.87217 .43687 L
.87217 .44658 L
.87217 .45629 L
.87217 .46601 L
.87217 .47572 L
.87217 .48543 L
.87217 .49514 L
.87217 .50486 L
.87217 .51457 L
.87217 .52428 L
.87217 .53399 L
.87217 .54371 L
.87217 .55342 L
.87217 .56313 L
.86422 .57108 L
.86245 .57284 L
.86245 .58256 L
.86245 .59227 L
.86245 .60198 L
.85451 .60993 L
.85274 .61169 L
.85274 .62141 L
.85274 .63112 L
.84479 .63907 L
Mistroke
.84303 .64083 L
.84303 .65054 L
.83508 .65849 L
.83332 .66026 L
.83332 .66997 L
.82537 .67792 L
.8236 .67968 L
.8236 .68939 L
.81566 .69734 L
.81389 .69911 L
.80594 .70705 L
.80418 .70882 L
.80418 .71853 L
.79623 .72648 L
.79447 .72824 L
.78652 .73619 L
.78475 .73796 L
.77681 .7459 L
.77504 .74767 L
.76709 .75562 L
.76558 .75738 L
.75738 .76533 L
.74918 .75738 L
.74767 .75562 L
.73972 .74767 L
.73796 .7459 L
.73001 .73796 L
.72824 .73619 L
.7203 .72824 L
.71853 .72648 L
.71058 .71853 L
.70882 .71677 L
.70087 .70882 L
.69911 .70705 L
.69116 .69911 L
.68939 .69734 L
.68145 .68939 L
.67968 .68763 L
.67173 .67968 L
.66997 .67792 L
.66202 .66997 L
.66026 .6682 L
.65231 .66026 L
.65054 .65849 L
.6426 .65054 L
.64083 .64878 L
.63288 .64083 L
.63112 .63907 L
.62317 .63112 L
.62141 .62935 L
Mistroke
.61346 .62141 L
.61169 .61964 L
.60375 .61169 L
.60198 .60993 L
.59403 .60198 L
.59227 .60022 L
.58432 .59227 L
.58256 .5905 L
.57461 .58256 L
.57284 .58079 L
.5649 .57284 L
.56313 .57108 L
.55518 .56313 L
.55342 .56137 L
.54547 .55342 L
.54371 .55165 L
.53576 .54371 L
.53399 .54194 L
.52605 .53399 L
.52428 .53223 L
.51633 .52428 L
.51457 .52252 L
.50662 .51457 L
.50486 .5128 L
.49514 .5128 L
.49338 .51457 L
.48543 .52252 L
.48367 .52428 L
.47572 .53223 L
.47395 .53399 L
.46601 .54194 L
.46424 .54371 L
.45629 .55165 L
.45453 .55342 L
.44658 .56137 L
.44482 .56313 L
.43687 .57108 L
.4351 .57284 L
.42716 .58079 L
.42539 .58256 L
.41744 .5905 L
.41568 .59227 L
.40773 .60022 L
.40597 .60198 L
.39802 .60993 L
.39625 .61169 L
.38831 .61964 L
.38654 .62141 L
.37859 .62935 L
.37683 .63112 L
Mistroke
.36888 .63907 L
.36712 .64083 L
.35917 .64878 L
.3574 .65054 L
.34946 .65849 L
.34769 .66026 L
.33974 .6682 L
.33798 .66997 L
.33003 .67792 L
.32827 .67968 L
.32032 .68763 L
.31855 .68939 L
.31061 .69734 L
.30884 .69911 L
.30089 .70705 L
.29913 .70882 L
.29118 .71677 L
.28942 .71853 L
.28147 .72648 L
.2797 .72824 L
.27176 .73619 L
.26999 .73796 L
.26204 .7459 L
.26028 .74767 L
.25233 .75562 L
.25082 .75738 L
.24262 .76533 L
.23442 .75738 L
.23291 .75562 L
.22496 .74767 L
.22319 .7459 L
.21525 .73796 L
.21348 .73619 L
.20553 .72824 L
.20377 .72648 L
.19582 .71853 L
.19582 .70882 L
.19406 .70705 L
.18611 .69911 L
.18434 .69734 L
.1764 .68939 L
.1764 .67968 L
.17463 .67792 L
.16668 .66997 L
.16668 .66026 L
.16492 .65849 L
.15697 .65054 L
.15697 .64083 L
.15521 .63907 L
.14726 .63112 L
Mistroke
.14726 .62141 L
.14726 .61169 L
.14549 .60993 L
.13755 .60198 L
.13755 .59227 L
.13755 .58256 L
.13755 .57284 L
.13578 .57108 L
.12783 .56313 L
.12783 .55342 L
.12783 .54371 L
.12783 .53399 L
.12783 .52428 L
.12783 .51457 L
.12783 .50486 L
.12783 .49514 L
.12783 .48543 L
.12783 .47572 L
.12783 .46601 L
.12783 .45629 L
.12783 .44658 L
.12783 .43687 L
.13578 .42892 L
.13755 .42716 L
.13755 .41744 L
.13755 .40773 L
.13755 .39802 L
.14549 .39007 L
.14726 .38831 L
.14726 .37859 L
.14726 .36888 L
.15521 .36093 L
.15697 .35917 L
.15697 .34946 L
.16492 .34151 L
.16668 .33974 L
.16668 .33003 L
.17463 .32208 L
.1764 .32032 L
.1764 .31061 L
.18434 .30266 L
.18611 .30089 L
.19406 .29295 L
.19582 .29118 L
.19582 .28147 L
.20377 .27352 L
.20553 .27176 L
.21348 .26381 L
.21525 .26204 L
.22319 .2541 L
Mistroke
.22496 .25233 L
.23291 .24438 L
.23467 .24262 L
.24262 .23467 L
.24438 .23291 L
.25233 .22496 L
.2541 .22319 L
.26204 .21525 L
.26381 .21348 L
.27176 .20553 L
.27352 .20377 L
.28147 .19582 L
.29118 .19582 L
.29295 .19406 L
.30089 .18611 L
.30266 .18434 L
.31061 .1764 L
.32032 .1764 L
.32208 .17463 L
.33003 .16668 L
.33974 .16668 L
.34151 .16492 L
.34946 .15697 L
.35917 .15697 L
.36093 .15521 L
.36888 .14726 L
.37859 .14726 L
.38831 .14726 L
.39007 .14549 L
.39802 .13755 L
.40773 .13755 L
.41744 .13755 L
.42716 .13755 L
.42892 .13578 L
.43687 .12783 L
Mfstroke
.3 g
.43687 .12875 m
.44658 .12875 L
.45629 .12875 L
.46601 .12875 L
.47572 .12875 L
.48543 .12875 L
.49514 .12875 L
.50486 .12875 L
.51457 .12875 L
.52428 .12875 L
.53399 .12875 L
.54371 .12875 L
.55342 .12875 L
.56313 .12875 L
.57016 .13578 L
.57284 .13846 L
.58256 .13846 L
.59227 .13846 L
.60198 .13846 L
.60901 .14549 L
.61169 .14818 L
.62141 .14818 L
.63112 .14818 L
.63815 .15521 L
.64083 .15789 L
.65054 .15789 L
.65757 .16492 L
.66026 .1676 L
.66997 .1676 L
.677 .17463 L
.67968 .17731 L
.68939 .17731 L
.69642 .18434 L
.69911 .18703 L
.70614 .19406 L
.70882 .19674 L
.71853 .19674 L
.72556 .20377 L
.72824 .20645 L
.73527 .21348 L
.73796 .21616 L
.74499 .22319 L
.74767 .22588 L
.7547 .23291 L
.75738 .23559 L
.76441 .24262 L
.76709 .2453 L
.77412 .25233 L
.77681 .25501 L
.78384 .26204 L
.78652 .26473 L
.79355 .27176 L
.79623 .27444 L
.80326 .28147 L
.80326 .29118 L
.80594 .29386 L
.81297 .30089 L
.81566 .30358 L
.82269 .31061 L
.82269 .32032 L
.82537 .323 L
.8324 .33003 L
.8324 .33974 L
.83508 .34243 L
.84211 .34946 L
.84211 .35917 L
.84479 .36185 L
.85182 .36888 L
.85182 .37859 L
.85182 .38831 L
.85451 .39099 L
.86154 .39802 L
.86154 .40773 L
.86154 .41744 L
.86154 .42716 L
.86422 .42984 L
.87125 .43687 L
.87125 .44658 L
.87125 .45629 L
.87125 .46601 L
.87125 .47572 L
.87125 .48543 L
.87125 .49514 L
.87125 .50486 L
.87125 .51457 L
.87125 .52428 L
.87125 .53399 L
.87125 .54371 L
.87125 .55342 L
.87125 .56313 L
.86422 .57016 L
.86154 .57284 L
.86154 .58256 L
.86154 .59227 L
.86154 .60198 L
.85451 .60901 L
.85182 .61169 L
.85182 .62141 L
.85182 .63112 L
.84479 .63815 L
.84211 .64083 L
.84211 .65054 L
.83508 .65757 L
.8324 .66026 L
.8324 .66997 L
.82537 .677 L
.82269 .67968 L
.82269 .68939 L
.81566 .69642 L
.81297 .69911 L
.80594 .70614 L
.80326 .70882 L
.80326 .71853 L
.79623 .72556 L
.79355 .72824 L
.78652 .73527 L
.78384 .73796 L
.77681 .74499 L
.77412 .74767 L
.76709 .7547 L
.76477 .75738 L
.75738 .76441 L
.75 .75738 L
.74767 .7547 L
.74064 .74767 L
.73796 .74499 L
.73093 .73796 L
.72824 .73527 L
.72121 .72824 L
.71853 .72556 L
.7115 .71853 L
.70882 .71585 L
.70179 .70882 L
.69911 .70614 L
.69208 .69911 L
.68939 .69642 L
.68236 .68939 L
.67968 .68671 L
.67265 .67968 L
.66997 .677 L
.66294 .66997 L
.66026 .66729 L
.65323 .66026 L
.65054 .65757 L
.64351 .65054 L
.64083 .64786 L
.6338 .64083 L
.63112 .63815 L
.62409 .63112 L
.62141 .62844 L
.61438 .62141 L
.61169 .61872 L
.60466 .61169 L
.60198 .60901 L
.59495 .60198 L
.59227 .5993 L
.58524 .59227 L
.58256 .58959 L
.57553 .58256 L
.57284 .57987 L
.56581 .57284 L
.56313 .57016 L
.5561 .56313 L
.55342 .56045 L
.54639 .55342 L
.54371 .55074 L
.53668 .54371 L
.53399 .54102 L
.52696 .53399 L
.52428 .53131 L
.51725 .52428 L
.51457 .5216 L
.50754 .51457 L
.50486 .51189 L
.49514 .51189 L
.49246 .51457 L
.48543 .5216 L
.48275 .52428 L
.47572 .53131 L
.47304 .53399 L
.46601 .54102 L
.46332 .54371 L
.45629 .55074 L
.45361 .55342 L
.44658 .56045 L
.4439 .56313 L
.43687 .57016 L
.43419 .57284 L
.42716 .57987 L
.42447 .58256 L
.41744 .58959 L
.41476 .59227 L
.40773 .5993 L
.40505 .60198 L
.39802 .60901 L
.39534 .61169 L
.38831 .61872 L
.38562 .62141 L
.37859 .62844 L
.37591 .63112 L
.36888 .63815 L
.3662 .64083 L
.35917 .64786 L
.35649 .65054 L
.34946 .65757 L
.34677 .66026 L
.33974 .66729 L
.33706 .66997 L
.33003 .677 L
.32735 .67968 L
.32032 .68671 L
.31764 .68939 L
.31061 .69642 L
.30792 .69911 L
.30089 .70614 L
.29821 .70882 L
.29118 .71585 L
.2885 .71853 L
.28147 .72556 L
.27879 .72824 L
.27176 .73527 L
.26907 .73796 L
.26204 .74499 L
.25936 .74767 L
.25233 .7547 L
.25 .75738 L
.24262 .76441 L
.23523 .75738 L
.23291 .7547 L
.22588 .74767 L
.22319 .74499 L
.21616 .73796 L
.21348 .73527 L
.20645 .72824 L
.20377 .72556 L
.19674 .71853 L
.19674 .70882 L
.19406 .70614 L
.18703 .69911 L
.18434 .69642 L
.17731 .68939 L
.17731 .67968 L
.17463 .677 L
.1676 .66997 L
.1676 .66026 L
.16492 .65757 L
.15789 .65054 L
.15789 .64083 L
.15521 .63815 L
.14818 .63112 L
.14818 .62141 L
.14818 .61169 L
.14549 .60901 L
.13846 .60198 L
.13846 .59227 L
.13846 .58256 L
.13846 .57284 L
.13578 .57016 L
.12875 .56313 L
.12875 .55342 L
.12875 .54371 L
.12875 .53399 L
.12875 .52428 L
.12875 .51457 L
.12875 .50486 L
.12875 .49514 L
.12875 .48543 L
.12875 .47572 L
.12875 .46601 L
.12875 .45629 L
.12875 .44658 L
.12875 .43687 L
.13578 .42984 L
.13846 .42716 L
.13846 .41744 L
.13846 .40773 L
.13846 .39802 L
.14549 .39099 L
.14818 .38831 L
.14818 .37859 L
.14818 .36888 L
.15521 .36185 L
.15789 .35917 L
.15789 .34946 L
.16492 .34243 L
.1676 .33974 L
.1676 .33003 L
.17463 .323 L
.17731 .32032 L
.17731 .31061 L
.18434 .30358 L
.18703 .30089 L
.19406 .29386 L
.19674 .29118 L
.19674 .28147 L
.20377 .27444 L
.20645 .27176 L
.21348 .26473 L
.21616 .26204 L
.22319 .25501 L
.22588 .25233 L
.23291 .2453 L
.23559 .24262 L
.24262 .23559 L
.2453 .23291 L
.25233 .22588 L
.25501 .22319 L
.26204 .21616 L
.26473 .21348 L
.27176 .20645 L
.27444 .20377 L
.28147 .19674 L
.29118 .19674 L
.29386 .19406 L
.30089 .18703 L
.30358 .18434 L
.31061 .17731 L
.32032 .17731 L
.323 .17463 L
.33003 .1676 L
.33974 .1676 L
.34243 .16492 L
.34946 .15789 L
.35917 .15789 L
.36185 .15521 L
.36888 .14818 L
.37859 .14818 L
.38831 .14818 L
.39099 .14549 L
.39802 .13846 L
.40773 .13846 L
.41744 .13846 L
.42716 .13846 L
.42984 .13578 L
F
0 g
.43687 .12875 m
.44658 .12875 L
.45629 .12875 L
.46601 .12875 L
.47572 .12875 L
.48543 .12875 L
.49514 .12875 L
.50486 .12875 L
.51457 .12875 L
.52428 .12875 L
.53399 .12875 L
.54371 .12875 L
.55342 .12875 L
.56313 .12875 L
.57016 .13578 L
.57284 .13846 L
.58256 .13846 L
.59227 .13846 L
.60198 .13846 L
.60901 .14549 L
.61169 .14818 L
.62141 .14818 L
.63112 .14818 L
.63815 .15521 L
.64083 .15789 L
.65054 .15789 L
.65757 .16492 L
.66026 .1676 L
.66997 .1676 L
.677 .17463 L
.67968 .17731 L
.68939 .17731 L
.69642 .18434 L
.69911 .18703 L
.70614 .19406 L
.70882 .19674 L
.71853 .19674 L
.72556 .20377 L
.72824 .20645 L
.73527 .21348 L
.73796 .21616 L
.74499 .22319 L
.74767 .22588 L
.7547 .23291 L
.75738 .23559 L
.76441 .24262 L
.76709 .2453 L
.77412 .25233 L
.77681 .25501 L
.78384 .26204 L
Mistroke
.78652 .26473 L
.79355 .27176 L
.79623 .27444 L
.80326 .28147 L
.80326 .29118 L
.80594 .29386 L
.81297 .30089 L
.81566 .30358 L
.82269 .31061 L
.82269 .32032 L
.82537 .323 L
.8324 .33003 L
.8324 .33974 L
.83508 .34243 L
.84211 .34946 L
.84211 .35917 L
.84479 .36185 L
.85182 .36888 L
.85182 .37859 L
.85182 .38831 L
.85451 .39099 L
.86154 .39802 L
.86154 .40773 L
.86154 .41744 L
.86154 .42716 L
.86422 .42984 L
.87125 .43687 L
.87125 .44658 L
.87125 .45629 L
.87125 .46601 L
.87125 .47572 L
.87125 .48543 L
.87125 .49514 L
.87125 .50486 L
.87125 .51457 L
.87125 .52428 L
.87125 .53399 L
.87125 .54371 L
.87125 .55342 L
.87125 .56313 L
.86422 .57016 L
.86154 .57284 L
.86154 .58256 L
.86154 .59227 L
.86154 .60198 L
.85451 .60901 L
.85182 .61169 L
.85182 .62141 L
.85182 .63112 L
.84479 .63815 L
Mistroke
.84211 .64083 L
.84211 .65054 L
.83508 .65757 L
.8324 .66026 L
.8324 .66997 L
.82537 .677 L
.82269 .67968 L
.82269 .68939 L
.81566 .69642 L
.81297 .69911 L
.80594 .70614 L
.80326 .70882 L
.80326 .71853 L
.79623 .72556 L
.79355 .72824 L
.78652 .73527 L
.78384 .73796 L
.77681 .74499 L
.77412 .74767 L
.76709 .7547 L
.76477 .75738 L
.75738 .76441 L
.75 .75738 L
.74767 .7547 L
.74064 .74767 L
.73796 .74499 L
.73093 .73796 L
.72824 .73527 L
.72121 .72824 L
.71853 .72556 L
.7115 .71853 L
.70882 .71585 L
.70179 .70882 L
.69911 .70614 L
.69208 .69911 L
.68939 .69642 L
.68236 .68939 L
.67968 .68671 L
.67265 .67968 L
.66997 .677 L
.66294 .66997 L
.66026 .66729 L
.65323 .66026 L
.65054 .65757 L
.64351 .65054 L
.64083 .64786 L
.6338 .64083 L
.63112 .63815 L
.62409 .63112 L
.62141 .62844 L
Mistroke
.61438 .62141 L
.61169 .61872 L
.60466 .61169 L
.60198 .60901 L
.59495 .60198 L
.59227 .5993 L
.58524 .59227 L
.58256 .58959 L
.57553 .58256 L
.57284 .57987 L
.56581 .57284 L
.56313 .57016 L
.5561 .56313 L
.55342 .56045 L
.54639 .55342 L
.54371 .55074 L
.53668 .54371 L
.53399 .54102 L
.52696 .53399 L
.52428 .53131 L
.51725 .52428 L
.51457 .5216 L
.50754 .51457 L
.50486 .51189 L
.49514 .51189 L
.49246 .51457 L
.48543 .5216 L
.48275 .52428 L
.47572 .53131 L
.47304 .53399 L
.46601 .54102 L
.46332 .54371 L
.45629 .55074 L
.45361 .55342 L
.44658 .56045 L
.4439 .56313 L
.43687 .57016 L
.43419 .57284 L
.42716 .57987 L
.42447 .58256 L
.41744 .58959 L
.41476 .59227 L
.40773 .5993 L
.40505 .60198 L
.39802 .60901 L
.39534 .61169 L
.38831 .61872 L
.38562 .62141 L
.37859 .62844 L
.37591 .63112 L
Mistroke
.36888 .63815 L
.3662 .64083 L
.35917 .64786 L
.35649 .65054 L
.34946 .65757 L
.34677 .66026 L
.33974 .66729 L
.33706 .66997 L
.33003 .677 L
.32735 .67968 L
.32032 .68671 L
.31764 .68939 L
.31061 .69642 L
.30792 .69911 L
.30089 .70614 L
.29821 .70882 L
.29118 .71585 L
.2885 .71853 L
.28147 .72556 L
.27879 .72824 L
.27176 .73527 L
.26907 .73796 L
.26204 .74499 L
.25936 .74767 L
.25233 .7547 L
.25 .75738 L
.24262 .76441 L
.23523 .75738 L
.23291 .7547 L
.22588 .74767 L
.22319 .74499 L
.21616 .73796 L
.21348 .73527 L
.20645 .72824 L
.20377 .72556 L
.19674 .71853 L
.19674 .70882 L
.19406 .70614 L
.18703 .69911 L
.18434 .69642 L
.17731 .68939 L
.17731 .67968 L
.17463 .677 L
.1676 .66997 L
.1676 .66026 L
.16492 .65757 L
.15789 .65054 L
.15789 .64083 L
.15521 .63815 L
.14818 .63112 L
Mistroke
.14818 .62141 L
.14818 .61169 L
.14549 .60901 L
.13846 .60198 L
.13846 .59227 L
.13846 .58256 L
.13846 .57284 L
.13578 .57016 L
.12875 .56313 L
.12875 .55342 L
.12875 .54371 L
.12875 .53399 L
.12875 .52428 L
.12875 .51457 L
.12875 .50486 L
.12875 .49514 L
.12875 .48543 L
.12875 .47572 L
.12875 .46601 L
.12875 .45629 L
.12875 .44658 L
.12875 .43687 L
.13578 .42984 L
.13846 .42716 L
.13846 .41744 L
.13846 .40773 L
.13846 .39802 L
.14549 .39099 L
.14818 .38831 L
.14818 .37859 L
.14818 .36888 L
.15521 .36185 L
.15789 .35917 L
.15789 .34946 L
.16492 .34243 L
.1676 .33974 L
.1676 .33003 L
.17463 .323 L
.17731 .32032 L
.17731 .31061 L
.18434 .30358 L
.18703 .30089 L
.19406 .29386 L
.19674 .29118 L
.19674 .28147 L
.20377 .27444 L
.20645 .27176 L
.21348 .26473 L
.21616 .26204 L
.22319 .25501 L
Mistroke
.22588 .25233 L
.23291 .2453 L
.23559 .24262 L
.24262 .23559 L
.2453 .23291 L
.25233 .22588 L
.25501 .22319 L
.26204 .21616 L
.26473 .21348 L
.27176 .20645 L
.27444 .20377 L
.28147 .19674 L
.29118 .19674 L
.29386 .19406 L
.30089 .18703 L
.30358 .18434 L
.31061 .17731 L
.32032 .17731 L
.323 .17463 L
.33003 .1676 L
.33974 .1676 L
.34243 .16492 L
.34946 .15789 L
.35917 .15789 L
.36185 .15521 L
.36888 .14818 L
.37859 .14818 L
.38831 .14818 L
.39099 .14549 L
.39802 .13846 L
.40773 .13846 L
.41744 .13846 L
.42716 .13846 L
.42984 .13578 L
.43687 .12875 L
Mfstroke
.4 g
.43687 .12963 m
.44658 .12963 L
.45629 .12963 L
.46601 .12963 L
.47572 .12963 L
.48543 .12963 L
.49514 .12963 L
.50486 .12963 L
.51457 .12963 L
.52428 .12963 L
.53399 .12963 L
.54371 .12963 L
.55342 .12963 L
.56313 .12963 L
.56928 .13578 L
.57284 .13935 L
.58256 .13935 L
.59227 .13935 L
.60198 .13935 L
.60813 .14549 L
.61169 .14906 L
.62141 .14906 L
.63112 .14906 L
.63727 .15521 L
.64083 .15877 L
.65054 .15877 L
.65669 .16492 L
.66026 .16848 L
.66997 .16848 L
.67612 .17463 L
.67968 .1782 L
.68939 .1782 L
.69554 .18434 L
.69911 .18791 L
.70525 .19406 L
.70882 .19762 L
.71853 .19762 L
.72468 .20377 L
.72824 .20733 L
.73439 .21348 L
.73796 .21705 L
.7441 .22319 L
.74767 .22676 L
.75382 .23291 L
.75738 .23647 L
.76353 .24262 L
.76709 .24618 L
.77324 .25233 L
.77681 .2559 L
.78295 .26204 L
.78652 .26561 L
.79267 .27176 L
.79623 .27532 L
.80238 .28147 L
.80238 .29118 L
.80594 .29475 L
.81209 .30089 L
.81566 .30446 L
.8218 .31061 L
.8218 .32032 L
.82537 .32388 L
.83152 .33003 L
.83152 .33974 L
.83508 .34331 L
.84123 .34946 L
.84123 .35917 L
.84479 .36273 L
.85094 .36888 L
.85094 .37859 L
.85094 .38831 L
.85451 .39187 L
.86065 .39802 L
.86065 .40773 L
.86065 .41744 L
.86065 .42716 L
.86422 .43072 L
.87037 .43687 L
.87037 .44658 L
.87037 .45629 L
.87037 .46601 L
.87037 .47572 L
.87037 .48543 L
.87037 .49514 L
.87037 .50486 L
.87037 .51457 L
.87037 .52428 L
.87037 .53399 L
.87037 .54371 L
.87037 .55342 L
.87037 .56313 L
.86422 .56928 L
.86065 .57284 L
.86065 .58256 L
.86065 .59227 L
.86065 .60198 L
.85451 .60813 L
.85094 .61169 L
.85094 .62141 L
.85094 .63112 L
.84479 .63727 L
.84123 .64083 L
.84123 .65054 L
.83508 .65669 L
.83152 .66026 L
.83152 .66997 L
.82537 .67612 L
.8218 .67968 L
.8218 .68939 L
.81566 .69554 L
.81209 .69911 L
.80594 .70525 L
.80238 .70882 L
.80238 .71853 L
.79623 .72468 L
.79267 .72824 L
.78652 .73439 L
.78295 .73796 L
.77681 .7441 L
.77324 .74767 L
.76709 .75382 L
.76397 .75738 L
.75738 .76353 L
.75079 .75738 L
.74767 .75382 L
.74152 .74767 L
.73796 .7441 L
.73181 .73796 L
.72824 .73439 L
.7221 .72824 L
.71853 .72468 L
.71238 .71853 L
.70882 .71497 L
.70267 .70882 L
.69911 .70525 L
.69296 .69911 L
.68939 .69554 L
.68325 .68939 L
.67968 .68583 L
.67353 .67968 L
.66997 .67612 L
.66382 .66997 L
.66026 .6664 L
.65411 .66026 L
.65054 .65669 L
.6444 .65054 L
.64083 .64698 L
.63468 .64083 L
.63112 .63727 L
.62497 .63112 L
.62141 .62755 L
.61526 .62141 L
.61169 .61784 L
.60555 .61169 L
.60198 .60813 L
.59583 .60198 L
.59227 .59842 L
.58612 .59227 L
.58256 .5887 L
.57641 .58256 L
.57284 .57899 L
.5667 .57284 L
.56313 .56928 L
.55698 .56313 L
.55342 .55957 L
.54727 .55342 L
.54371 .54985 L
.53756 .54371 L
.53399 .54014 L
.52785 .53399 L
.52428 .53043 L
.51813 .52428 L
.51457 .52072 L
.50842 .51457 L
.50486 .511 L
.49514 .511 L
.49158 .51457 L
.48543 .52072 L
.48187 .52428 L
.47572 .53043 L
.47215 .53399 L
.46601 .54014 L
.46244 .54371 L
.45629 .54985 L
.45273 .55342 L
.44658 .55957 L
.44302 .56313 L
.43687 .56928 L
.4333 .57284 L
.42716 .57899 L
.42359 .58256 L
.41744 .5887 L
.41388 .59227 L
.40773 .59842 L
.40417 .60198 L
.39802 .60813 L
.39445 .61169 L
.38831 .61784 L
.38474 .62141 L
.37859 .62755 L
.37503 .63112 L
.36888 .63727 L
.36532 .64083 L
.35917 .64698 L
.3556 .65054 L
.34946 .65669 L
.34589 .66026 L
.33974 .6664 L
.33618 .66997 L
.33003 .67612 L
.32647 .67968 L
.32032 .68583 L
.31675 .68939 L
.31061 .69554 L
.30704 .69911 L
.30089 .70525 L
.29733 .70882 L
.29118 .71497 L
.28762 .71853 L
.28147 .72468 L
.2779 .72824 L
.27176 .73439 L
.26819 .73796 L
.26204 .7441 L
.25848 .74767 L
.25233 .75382 L
.24921 .75738 L
.24262 .76353 L
.23603 .75738 L
.23291 .75382 L
.22676 .74767 L
.22319 .7441 L
.21705 .73796 L
.21348 .73439 L
.20733 .72824 L
.20377 .72468 L
.19762 .71853 L
.19762 .70882 L
.19406 .70525 L
.18791 .69911 L
.18434 .69554 L
.1782 .68939 L
.1782 .67968 L
.17463 .67612 L
.16848 .66997 L
.16848 .66026 L
.16492 .65669 L
.15877 .65054 L
.15877 .64083 L
.15521 .63727 L
.14906 .63112 L
.14906 .62141 L
.14906 .61169 L
.14549 .60813 L
.13935 .60198 L
.13935 .59227 L
.13935 .58256 L
.13935 .57284 L
.13578 .56928 L
.12963 .56313 L
.12963 .55342 L
.12963 .54371 L
.12963 .53399 L
.12963 .52428 L
.12963 .51457 L
.12963 .50486 L
.12963 .49514 L
.12963 .48543 L
.12963 .47572 L
.12963 .46601 L
.12963 .45629 L
.12963 .44658 L
.12963 .43687 L
.13578 .43072 L
.13935 .42716 L
.13935 .41744 L
.13935 .40773 L
.13935 .39802 L
.14549 .39187 L
.14906 .38831 L
.14906 .37859 L
.14906 .36888 L
.15521 .36273 L
.15877 .35917 L
.15877 .34946 L
.16492 .34331 L
.16848 .33974 L
.16848 .33003 L
.17463 .32388 L
.1782 .32032 L
.1782 .31061 L
.18434 .30446 L
.18791 .30089 L
.19406 .29475 L
.19762 .29118 L
.19762 .28147 L
.20377 .27532 L
.20733 .27176 L
.21348 .26561 L
.21705 .26204 L
.22319 .2559 L
.22676 .25233 L
.23291 .24618 L
.23647 .24262 L
.24262 .23647 L
.24618 .23291 L
.25233 .22676 L
.2559 .22319 L
.26204 .21705 L
.26561 .21348 L
.27176 .20733 L
.27532 .20377 L
.28147 .19762 L
.29118 .19762 L
.29475 .19406 L
.30089 .18791 L
.30446 .18434 L
.31061 .1782 L
.32032 .1782 L
.32388 .17463 L
.33003 .16848 L
.33974 .16848 L
.34331 .16492 L
.34946 .15877 L
.35917 .15877 L
.36273 .15521 L
.36888 .14906 L
.37859 .14906 L
.38831 .14906 L
.39187 .14549 L
.39802 .13935 L
.40773 .13935 L
.41744 .13935 L
.42716 .13935 L
.43072 .13578 L
F
0 g
.43687 .12963 m
.44658 .12963 L
.45629 .12963 L
.46601 .12963 L
.47572 .12963 L
.48543 .12963 L
.49514 .12963 L
.50486 .12963 L
.51457 .12963 L
.52428 .12963 L
.53399 .12963 L
.54371 .12963 L
.55342 .12963 L
.56313 .12963 L
.56928 .13578 L
.57284 .13935 L
.58256 .13935 L
.59227 .13935 L
.60198 .13935 L
.60813 .14549 L
.61169 .14906 L
.62141 .14906 L
.63112 .14906 L
.63727 .15521 L
.64083 .15877 L
.65054 .15877 L
.65669 .16492 L
.66026 .16848 L
.66997 .16848 L
.67612 .17463 L
.67968 .1782 L
.68939 .1782 L
.69554 .18434 L
.69911 .18791 L
.70525 .19406 L
.70882 .19762 L
.71853 .19762 L
.72468 .20377 L
.72824 .20733 L
.73439 .21348 L
.73796 .21705 L
.7441 .22319 L
.74767 .22676 L
.75382 .23291 L
.75738 .23647 L
.76353 .24262 L
.76709 .24618 L
.77324 .25233 L
.77681 .2559 L
.78295 .26204 L
Mistroke
.78652 .26561 L
.79267 .27176 L
.79623 .27532 L
.80238 .28147 L
.80238 .29118 L
.80594 .29475 L
.81209 .30089 L
.81566 .30446 L
.8218 .31061 L
.8218 .32032 L
.82537 .32388 L
.83152 .33003 L
.83152 .33974 L
.83508 .34331 L
.84123 .34946 L
.84123 .35917 L
.84479 .36273 L
.85094 .36888 L
.85094 .37859 L
.85094 .38831 L
.85451 .39187 L
.86065 .39802 L
.86065 .40773 L
.86065 .41744 L
.86065 .42716 L
.86422 .43072 L
.87037 .43687 L
.87037 .44658 L
.87037 .45629 L
.87037 .46601 L
.87037 .47572 L
.87037 .48543 L
.87037 .49514 L
.87037 .50486 L
.87037 .51457 L
.87037 .52428 L
.87037 .53399 L
.87037 .54371 L
.87037 .55342 L
.87037 .56313 L
.86422 .56928 L
.86065 .57284 L
.86065 .58256 L
.86065 .59227 L
.86065 .60198 L
.85451 .60813 L
.85094 .61169 L
.85094 .62141 L
.85094 .63112 L
.84479 .63727 L
Mistroke
.84123 .64083 L
.84123 .65054 L
.83508 .65669 L
.83152 .66026 L
.83152 .66997 L
.82537 .67612 L
.8218 .67968 L
.8218 .68939 L
.81566 .69554 L
.81209 .69911 L
.80594 .70525 L
.80238 .70882 L
.80238 .71853 L
.79623 .72468 L
.79267 .72824 L
.78652 .73439 L
.78295 .73796 L
.77681 .7441 L
.77324 .74767 L
.76709 .75382 L
.76397 .75738 L
.75738 .76353 L
.75079 .75738 L
.74767 .75382 L
.74152 .74767 L
.73796 .7441 L
.73181 .73796 L
.72824 .73439 L
.7221 .72824 L
.71853 .72468 L
.71238 .71853 L
.70882 .71497 L
.70267 .70882 L
.69911 .70525 L
.69296 .69911 L
.68939 .69554 L
.68325 .68939 L
.67968 .68583 L
.67353 .67968 L
.66997 .67612 L
.66382 .66997 L
.66026 .6664 L
.65411 .66026 L
.65054 .65669 L
.6444 .65054 L
.64083 .64698 L
.63468 .64083 L
.63112 .63727 L
.62497 .63112 L
.62141 .62755 L
Mistroke
.61526 .62141 L
.61169 .61784 L
.60555 .61169 L
.60198 .60813 L
.59583 .60198 L
.59227 .59842 L
.58612 .59227 L
.58256 .5887 L
.57641 .58256 L
.57284 .57899 L
.5667 .57284 L
.56313 .56928 L
.55698 .56313 L
.55342 .55957 L
.54727 .55342 L
.54371 .54985 L
.53756 .54371 L
.53399 .54014 L
.52785 .53399 L
.52428 .53043 L
.51813 .52428 L
.51457 .52072 L
.50842 .51457 L
.50486 .511 L
.49514 .511 L
.49158 .51457 L
.48543 .52072 L
.48187 .52428 L
.47572 .53043 L
.47215 .53399 L
.46601 .54014 L
.46244 .54371 L
.45629 .54985 L
.45273 .55342 L
.44658 .55957 L
.44302 .56313 L
.43687 .56928 L
.4333 .57284 L
.42716 .57899 L
.42359 .58256 L
.41744 .5887 L
.41388 .59227 L
.40773 .59842 L
.40417 .60198 L
.39802 .60813 L
.39445 .61169 L
.38831 .61784 L
.38474 .62141 L
.37859 .62755 L
.37503 .63112 L
Mistroke
.36888 .63727 L
.36532 .64083 L
.35917 .64698 L
.3556 .65054 L
.34946 .65669 L
.34589 .66026 L
.33974 .6664 L
.33618 .66997 L
.33003 .67612 L
.32647 .67968 L
.32032 .68583 L
.31675 .68939 L
.31061 .69554 L
.30704 .69911 L
.30089 .70525 L
.29733 .70882 L
.29118 .71497 L
.28762 .71853 L
.28147 .72468 L
.2779 .72824 L
.27176 .73439 L
.26819 .73796 L
.26204 .7441 L
.25848 .74767 L
.25233 .75382 L
.24921 .75738 L
.24262 .76353 L
.23603 .75738 L
.23291 .75382 L
.22676 .74767 L
.22319 .7441 L
.21705 .73796 L
.21348 .73439 L
.20733 .72824 L
.20377 .72468 L
.19762 .71853 L
.19762 .70882 L
.19406 .70525 L
.18791 .69911 L
.18434 .69554 L
.1782 .68939 L
.1782 .67968 L
.17463 .67612 L
.16848 .66997 L
.16848 .66026 L
.16492 .65669 L
.15877 .65054 L
.15877 .64083 L
.15521 .63727 L
.14906 .63112 L
Mistroke
.14906 .62141 L
.14906 .61169 L
.14549 .60813 L
.13935 .60198 L
.13935 .59227 L
.13935 .58256 L
.13935 .57284 L
.13578 .56928 L
.12963 .56313 L
.12963 .55342 L
.12963 .54371 L
.12963 .53399 L
.12963 .52428 L
.12963 .51457 L
.12963 .50486 L
.12963 .49514 L
.12963 .48543 L
.12963 .47572 L
.12963 .46601 L
.12963 .45629 L
.12963 .44658 L
.12963 .43687 L
.13578 .43072 L
.13935 .42716 L
.13935 .41744 L
.13935 .40773 L
.13935 .39802 L
.14549 .39187 L
.14906 .38831 L
.14906 .37859 L
.14906 .36888 L
.15521 .36273 L
.15877 .35917 L
.15877 .34946 L
.16492 .34331 L
.16848 .33974 L
.16848 .33003 L
.17463 .32388 L
.1782 .32032 L
.1782 .31061 L
.18434 .30446 L
.18791 .30089 L
.19406 .29475 L
.19762 .29118 L
.19762 .28147 L
.20377 .27532 L
.20733 .27176 L
.21348 .26561 L
.21705 .26204 L
.22319 .2559 L
Mistroke
.22676 .25233 L
.23291 .24618 L
.23647 .24262 L
.24262 .23647 L
.24618 .23291 L
.25233 .22676 L
.2559 .22319 L
.26204 .21705 L
.26561 .21348 L
.27176 .20733 L
.27532 .20377 L
.28147 .19762 L
.29118 .19762 L
.29475 .19406 L
.30089 .18791 L
.30446 .18434 L
.31061 .1782 L
.32032 .1782 L
.32388 .17463 L
.33003 .16848 L
.33974 .16848 L
.34331 .16492 L
.34946 .15877 L
.35917 .15877 L
.36273 .15521 L
.36888 .14906 L
.37859 .14906 L
.38831 .14906 L
.39187 .14549 L
.39802 .13935 L
.40773 .13935 L
.41744 .13935 L
.42716 .13935 L
.43072 .13578 L
.43687 .12963 L
Mfstroke
.5 g
.43687 .1305 m
.44658 .1305 L
.45629 .1305 L
.46601 .1305 L
.47572 .1305 L
.48543 .1305 L
.49514 .1305 L
.50486 .1305 L
.51457 .1305 L
.52428 .1305 L
.53399 .1305 L
.54371 .1305 L
.55342 .1305 L
.56313 .1305 L
.56842 .13578 L
.57284 .14021 L
.58256 .14021 L
.59227 .14021 L
.60198 .14021 L
.60727 .14549 L
.61169 .14992 L
.62141 .14992 L
.63112 .14992 L
.6364 .15521 L
.64083 .15963 L
.65054 .15963 L
.65583 .16492 L
.66026 .16935 L
.66997 .16935 L
.67525 .17463 L
.67968 .17906 L
.68939 .17906 L
.69468 .18434 L
.69911 .18877 L
.70439 .19406 L
.70882 .19848 L
.71853 .19848 L
.72382 .20377 L
.72824 .2082 L
.73353 .21348 L
.73796 .21791 L
.74324 .22319 L
.74767 .22762 L
.75295 .23291 L
.75738 .23733 L
.76267 .24262 L
.76709 .24705 L
.77238 .25233 L
.77681 .25676 L
.78209 .26204 L
.78652 .26647 L
.7918 .27176 L
.79623 .27618 L
.80152 .28147 L
.80152 .29118 L
.80594 .29561 L
.81123 .30089 L
.81566 .30532 L
.82094 .31061 L
.82094 .32032 L
.82537 .32475 L
.83065 .33003 L
.83065 .33974 L
.83508 .34417 L
.84037 .34946 L
.84037 .35917 L
.84479 .3636 L
.85008 .36888 L
.85008 .37859 L
.85008 .38831 L
.85451 .39273 L
.85979 .39802 L
.85979 .40773 L
.85979 .41744 L
.85979 .42716 L
.86422 .43158 L
.8695 .43687 L
.8695 .44658 L
.8695 .45629 L
.8695 .46601 L
.8695 .47572 L
.8695 .48543 L
.8695 .49514 L
.8695 .50486 L
.8695 .51457 L
.8695 .52428 L
.8695 .53399 L
.8695 .54371 L
.8695 .55342 L
.8695 .56313 L
.86422 .56842 L
.85979 .57284 L
.85979 .58256 L
.85979 .59227 L
.85979 .60198 L
.85451 .60727 L
.85008 .61169 L
.85008 .62141 L
.85008 .63112 L
.84479 .6364 L
.84037 .64083 L
.84037 .65054 L
.83508 .65583 L
.83065 .66026 L
.83065 .66997 L
.82537 .67525 L
.82094 .67968 L
.82094 .68939 L
.81566 .69468 L
.81123 .69911 L
.80594 .70439 L
.80152 .70882 L
.80152 .71853 L
.79623 .72382 L
.7918 .72824 L
.78652 .73353 L
.78209 .73796 L
.77681 .74324 L
.77238 .74767 L
.76709 .75295 L
.76317 .75738 L
.75738 .76267 L
.75159 .75738 L
.74767 .75295 L
.74238 .74767 L
.73796 .74324 L
.73267 .73796 L
.72824 .73353 L
.72296 .72824 L
.71853 .72382 L
.71325 .71853 L
.70882 .7141 L
.70353 .70882 L
.69911 .70439 L
.69382 .69911 L
.68939 .69468 L
.68411 .68939 L
.67968 .68497 L
.6744 .67968 L
.66997 .67525 L
.66468 .66997 L
.66026 .66554 L
.65497 .66026 L
.65054 .65583 L
.64526 .65054 L
.64083 .64612 L
.63555 .64083 L
.63112 .6364 L
.62583 .63112 L
.62141 .62669 L
.61612 .62141 L
.61169 .61698 L
.60641 .61169 L
.60198 .60727 L
.5967 .60198 L
.59227 .59755 L
.58698 .59227 L
.58256 .58784 L
.57727 .58256 L
.57284 .57813 L
.56756 .57284 L
.56313 .56842 L
.55785 .56313 L
.55342 .5587 L
.54813 .55342 L
.54371 .54899 L
.53842 .54371 L
.53399 .53928 L
.52871 .53399 L
.52428 .52957 L
.519 .52428 L
.51457 .51985 L
.50928 .51457 L
.50486 .51014 L
.49514 .51014 L
.49072 .51457 L
.48543 .51985 L
.481 .52428 L
.47572 .52957 L
.47129 .53399 L
.46601 .53928 L
.46158 .54371 L
.45629 .54899 L
.45187 .55342 L
.44658 .5587 L
.44215 .56313 L
.43687 .56842 L
.43244 .57284 L
.42716 .57813 L
.42273 .58256 L
.41744 .58784 L
.41302 .59227 L
.40773 .59755 L
.4033 .60198 L
.39802 .60727 L
.39359 .61169 L
.38831 .61698 L
.38388 .62141 L
.37859 .62669 L
.37417 .63112 L
.36888 .6364 L
.36445 .64083 L
.35917 .64612 L
.35474 .65054 L
.34946 .65583 L
.34503 .66026 L
.33974 .66554 L
.33532 .66997 L
.33003 .67525 L
.3256 .67968 L
.32032 .68497 L
.31589 .68939 L
.31061 .69468 L
.30618 .69911 L
.30089 .70439 L
.29647 .70882 L
.29118 .7141 L
.28675 .71853 L
.28147 .72382 L
.27704 .72824 L
.27176 .73353 L
.26733 .73796 L
.26204 .74324 L
.25762 .74767 L
.25233 .75295 L
.24841 .75738 L
.24262 .76267 L
.23683 .75738 L
.23291 .75295 L
.22762 .74767 L
.22319 .74324 L
.21791 .73796 L
.21348 .73353 L
.2082 .72824 L
.20377 .72382 L
.19848 .71853 L
.19848 .70882 L
.19406 .70439 L
.18877 .69911 L
.18434 .69468 L
.17906 .68939 L
.17906 .67968 L
.17463 .67525 L
.16935 .66997 L
.16935 .66026 L
.16492 .65583 L
.15963 .65054 L
.15963 .64083 L
.15521 .6364 L
.14992 .63112 L
.14992 .62141 L
.14992 .61169 L
.14549 .60727 L
.14021 .60198 L
.14021 .59227 L
.14021 .58256 L
.14021 .57284 L
.13578 .56842 L
.1305 .56313 L
.1305 .55342 L
.1305 .54371 L
.1305 .53399 L
.1305 .52428 L
.1305 .51457 L
.1305 .50486 L
.1305 .49514 L
.1305 .48543 L
.1305 .47572 L
.1305 .46601 L
.1305 .45629 L
.1305 .44658 L
.1305 .43687 L
.13578 .43158 L
.14021 .42716 L
.14021 .41744 L
.14021 .40773 L
.14021 .39802 L
.14549 .39273 L
.14992 .38831 L
.14992 .37859 L
.14992 .36888 L
.15521 .3636 L
.15963 .35917 L
.15963 .34946 L
.16492 .34417 L
.16935 .33974 L
.16935 .33003 L
.17463 .32475 L
.17906 .32032 L
.17906 .31061 L
.18434 .30532 L
.18877 .30089 L
.19406 .29561 L
.19848 .29118 L
.19848 .28147 L
.20377 .27618 L
.2082 .27176 L
.21348 .26647 L
.21791 .26204 L
.22319 .25676 L
.22762 .25233 L
.23291 .24705 L
.23733 .24262 L
.24262 .23733 L
.24705 .23291 L
.25233 .22762 L
.25676 .22319 L
.26204 .21791 L
.26647 .21348 L
.27176 .2082 L
.27618 .20377 L
.28147 .19848 L
.29118 .19848 L
.29561 .19406 L
.30089 .18877 L
.30532 .18434 L
.31061 .17906 L
.32032 .17906 L
.32475 .17463 L
.33003 .16935 L
.33974 .16935 L
.34417 .16492 L
.34946 .15963 L
.35917 .15963 L
.3636 .15521 L
.36888 .14992 L
.37859 .14992 L
.38831 .14992 L
.39273 .14549 L
.39802 .14021 L
.40773 .14021 L
.41744 .14021 L
.42716 .14021 L
.43158 .13578 L
F
0 g
.43687 .1305 m
.44658 .1305 L
.45629 .1305 L
.46601 .1305 L
.47572 .1305 L
.48543 .1305 L
.49514 .1305 L
.50486 .1305 L
.51457 .1305 L
.52428 .1305 L
.53399 .1305 L
.54371 .1305 L
.55342 .1305 L
.56313 .1305 L
.56842 .13578 L
.57284 .14021 L
.58256 .14021 L
.59227 .14021 L
.60198 .14021 L
.60727 .14549 L
.61169 .14992 L
.62141 .14992 L
.63112 .14992 L
.6364 .15521 L
.64083 .15963 L
.65054 .15963 L
.65583 .16492 L
.66026 .16935 L
.66997 .16935 L
.67525 .17463 L
.67968 .17906 L
.68939 .17906 L
.69468 .18434 L
.69911 .18877 L
.70439 .19406 L
.70882 .19848 L
.71853 .19848 L
.72382 .20377 L
.72824 .2082 L
.73353 .21348 L
.73796 .21791 L
.74324 .22319 L
.74767 .22762 L
.75295 .23291 L
.75738 .23733 L
.76267 .24262 L
.76709 .24705 L
.77238 .25233 L
.77681 .25676 L
.78209 .26204 L
Mistroke
.78652 .26647 L
.7918 .27176 L
.79623 .27618 L
.80152 .28147 L
.80152 .29118 L
.80594 .29561 L
.81123 .30089 L
.81566 .30532 L
.82094 .31061 L
.82094 .32032 L
.82537 .32475 L
.83065 .33003 L
.83065 .33974 L
.83508 .34417 L
.84037 .34946 L
.84037 .35917 L
.84479 .3636 L
.85008 .36888 L
.85008 .37859 L
.85008 .38831 L
.85451 .39273 L
.85979 .39802 L
.85979 .40773 L
.85979 .41744 L
.85979 .42716 L
.86422 .43158 L
.8695 .43687 L
.8695 .44658 L
.8695 .45629 L
.8695 .46601 L
.8695 .47572 L
.8695 .48543 L
.8695 .49514 L
.8695 .50486 L
.8695 .51457 L
.8695 .52428 L
.8695 .53399 L
.8695 .54371 L
.8695 .55342 L
.8695 .56313 L
.86422 .56842 L
.85979 .57284 L
.85979 .58256 L
.85979 .59227 L
.85979 .60198 L
.85451 .60727 L
.85008 .61169 L
.85008 .62141 L
.85008 .63112 L
.84479 .6364 L
Mistroke
.84037 .64083 L
.84037 .65054 L
.83508 .65583 L
.83065 .66026 L
.83065 .66997 L
.82537 .67525 L
.82094 .67968 L
.82094 .68939 L
.81566 .69468 L
.81123 .69911 L
.80594 .70439 L
.80152 .70882 L
.80152 .71853 L
.79623 .72382 L
.7918 .72824 L
.78652 .73353 L
.78209 .73796 L
.77681 .74324 L
.77238 .74767 L
.76709 .75295 L
.76317 .75738 L
.75738 .76267 L
.75159 .75738 L
.74767 .75295 L
.74238 .74767 L
.73796 .74324 L
.73267 .73796 L
.72824 .73353 L
.72296 .72824 L
.71853 .72382 L
.71325 .71853 L
.70882 .7141 L
.70353 .70882 L
.69911 .70439 L
.69382 .69911 L
.68939 .69468 L
.68411 .68939 L
.67968 .68497 L
.6744 .67968 L
.66997 .67525 L
.66468 .66997 L
.66026 .66554 L
.65497 .66026 L
.65054 .65583 L
.64526 .65054 L
.64083 .64612 L
.63555 .64083 L
.63112 .6364 L
.62583 .63112 L
.62141 .62669 L
Mistroke
.61612 .62141 L
.61169 .61698 L
.60641 .61169 L
.60198 .60727 L
.5967 .60198 L
.59227 .59755 L
.58698 .59227 L
.58256 .58784 L
.57727 .58256 L
.57284 .57813 L
.56756 .57284 L
.56313 .56842 L
.55785 .56313 L
.55342 .5587 L
.54813 .55342 L
.54371 .54899 L
.53842 .54371 L
.53399 .53928 L
.52871 .53399 L
.52428 .52957 L
.519 .52428 L
.51457 .51985 L
.50928 .51457 L
.50486 .51014 L
.49514 .51014 L
.49072 .51457 L
.48543 .51985 L
.481 .52428 L
.47572 .52957 L
.47129 .53399 L
.46601 .53928 L
.46158 .54371 L
.45629 .54899 L
.45187 .55342 L
.44658 .5587 L
.44215 .56313 L
.43687 .56842 L
.43244 .57284 L
.42716 .57813 L
.42273 .58256 L
.41744 .58784 L
.41302 .59227 L
.40773 .59755 L
.4033 .60198 L
.39802 .60727 L
.39359 .61169 L
.38831 .61698 L
.38388 .62141 L
.37859 .62669 L
.37417 .63112 L
Mistroke
.36888 .6364 L
.36445 .64083 L
.35917 .64612 L
.35474 .65054 L
.34946 .65583 L
.34503 .66026 L
.33974 .66554 L
.33532 .66997 L
.33003 .67525 L
.3256 .67968 L
.32032 .68497 L
.31589 .68939 L
.31061 .69468 L
.30618 .69911 L
.30089 .70439 L
.29647 .70882 L
.29118 .7141 L
.28675 .71853 L
.28147 .72382 L
.27704 .72824 L
.27176 .73353 L
.26733 .73796 L
.26204 .74324 L
.25762 .74767 L
.25233 .75295 L
.24841 .75738 L
.24262 .76267 L
.23683 .75738 L
.23291 .75295 L
.22762 .74767 L
.22319 .74324 L
.21791 .73796 L
.21348 .73353 L
.2082 .72824 L
.20377 .72382 L
.19848 .71853 L
.19848 .70882 L
.19406 .70439 L
.18877 .69911 L
.18434 .69468 L
.17906 .68939 L
.17906 .67968 L
.17463 .67525 L
.16935 .66997 L
.16935 .66026 L
.16492 .65583 L
.15963 .65054 L
.15963 .64083 L
.15521 .6364 L
.14992 .63112 L
Mistroke
.14992 .62141 L
.14992 .61169 L
.14549 .60727 L
.14021 .60198 L
.14021 .59227 L
.14021 .58256 L
.14021 .57284 L
.13578 .56842 L
.1305 .56313 L
.1305 .55342 L
.1305 .54371 L
.1305 .53399 L
.1305 .52428 L
.1305 .51457 L
.1305 .50486 L
.1305 .49514 L
.1305 .48543 L
.1305 .47572 L
.1305 .46601 L
.1305 .45629 L
.1305 .44658 L
.1305 .43687 L
.13578 .43158 L
.14021 .42716 L
.14021 .41744 L
.14021 .40773 L
.14021 .39802 L
.14549 .39273 L
.14992 .38831 L
.14992 .37859 L
.14992 .36888 L
.15521 .3636 L
.15963 .35917 L
.15963 .34946 L
.16492 .34417 L
.16935 .33974 L
.16935 .33003 L
.17463 .32475 L
.17906 .32032 L
.17906 .31061 L
.18434 .30532 L
.18877 .30089 L
.19406 .29561 L
.19848 .29118 L
.19848 .28147 L
.20377 .27618 L
.2082 .27176 L
.21348 .26647 L
.21791 .26204 L
.22319 .25676 L
Mistroke
.22762 .25233 L
.23291 .24705 L
.23733 .24262 L
.24262 .23733 L
.24705 .23291 L
.25233 .22762 L
.25676 .22319 L
.26204 .21791 L
.26647 .21348 L
.27176 .2082 L
.27618 .20377 L
.28147 .19848 L
.29118 .19848 L
.29561 .19406 L
.30089 .18877 L
.30532 .18434 L
.31061 .17906 L
.32032 .17906 L
.32475 .17463 L
.33003 .16935 L
.33974 .16935 L
.34417 .16492 L
.34946 .15963 L
.35917 .15963 L
.3636 .15521 L
.36888 .14992 L
.37859 .14992 L
.38831 .14992 L
.39273 .14549 L
.39802 .14021 L
.40773 .14021 L
.41744 .14021 L
.42716 .14021 L
.43158 .13578 L
.43687 .1305 L
Mfstroke
.6 g
.43687 .13135 m
.44658 .13135 L
.45629 .13135 L
.46601 .13135 L
.47572 .13135 L
.48543 .13135 L
.49514 .13135 L
.50486 .13135 L
.51457 .13135 L
.52428 .13135 L
.53399 .13135 L
.54371 .13135 L
.55342 .13135 L
.56313 .13135 L
.56756 .13578 L
.57284 .14107 L
.58256 .14107 L
.59227 .14107 L
.60198 .14107 L
.60641 .14549 L
.61169 .15078 L
.62141 .15078 L
.63112 .15078 L
.63555 .15521 L
.64083 .16049 L
.65054 .16049 L
.65497 .16492 L
.66026 .1702 L
.66997 .1702 L
.6744 .17463 L
.67968 .17992 L
.68939 .17992 L
.69382 .18434 L
.69911 .18963 L
.70353 .19406 L
.70882 .19934 L
.71853 .19934 L
.72296 .20377 L
.72824 .20905 L
.73267 .21348 L
.73796 .21877 L
.74238 .22319 L
.74767 .22848 L
.7521 .23291 L
.75738 .23819 L
.76181 .24262 L
.76709 .2479 L
.77152 .25233 L
.77681 .25762 L
.78123 .26204 L
.78652 .26733 L
.79095 .27176 L
.79623 .27704 L
.80066 .28147 L
.80066 .29118 L
.80594 .29647 L
.81037 .30089 L
.81566 .30618 L
.82008 .31061 L
.82008 .32032 L
.82537 .3256 L
.8298 .33003 L
.8298 .33974 L
.83508 .34503 L
.83951 .34946 L
.83951 .35917 L
.84479 .36445 L
.84922 .36888 L
.84922 .37859 L
.84922 .38831 L
.85451 .39359 L
.85893 .39802 L
.85893 .40773 L
.85893 .41744 L
.85893 .42716 L
.86422 .43244 L
.86865 .43687 L
.86865 .44658 L
.86865 .45629 L
.86865 .46601 L
.86865 .47572 L
.86865 .48543 L
.86865 .49514 L
.86865 .50486 L
.86865 .51457 L
.86865 .52428 L
.86865 .53399 L
.86865 .54371 L
.86865 .55342 L
.86865 .56313 L
.86422 .56756 L
.85893 .57284 L
.85893 .58256 L
.85893 .59227 L
.85893 .60198 L
.85451 .60641 L
.84922 .61169 L
.84922 .62141 L
.84922 .63112 L
.84479 .63555 L
.83951 .64083 L
.83951 .65054 L
.83508 .65497 L
.8298 .66026 L
.8298 .66997 L
.82537 .6744 L
.82008 .67968 L
.82008 .68939 L
.81566 .69382 L
.81037 .69911 L
.80594 .70353 L
.80066 .70882 L
.80066 .71853 L
.79623 .72296 L
.79095 .72824 L
.78652 .73267 L
.78123 .73796 L
.77681 .74238 L
.77152 .74767 L
.76709 .7521 L
.76236 .75738 L
.75738 .76181 L
.7524 .75738 L
.74767 .7521 L
.74324 .74767 L
.73796 .74238 L
.73353 .73796 L
.72824 .73267 L
.72382 .72824 L
.71853 .72296 L
.7141 .71853 L
.70882 .71325 L
.70439 .70882 L
.69911 .70353 L
.69468 .69911 L
.68939 .69382 L
.68497 .68939 L
.67968 .68411 L
.67525 .67968 L
.66997 .6744 L
.66554 .66997 L
.66026 .66468 L
.65583 .66026 L
.65054 .65497 L
.64612 .65054 L
.64083 .64526 L
.6364 .64083 L
.63112 .63555 L
.62669 .63112 L
.62141 .62583 L
.61698 .62141 L
.61169 .61612 L
.60727 .61169 L
.60198 .60641 L
.59755 .60198 L
.59227 .5967 L
.58784 .59227 L
.58256 .58698 L
.57813 .58256 L
.57284 .57727 L
.56842 .57284 L
.56313 .56756 L
.5587 .56313 L
.55342 .55785 L
.54899 .55342 L
.54371 .54813 L
.53928 .54371 L
.53399 .53842 L
.52957 .53399 L
.52428 .52871 L
.51985 .52428 L
.51457 .519 L
.51014 .51457 L
.50486 .50928 L
.49514 .50928 L
.48986 .51457 L
.48543 .519 L
.48015 .52428 L
.47572 .52871 L
.47043 .53399 L
.46601 .53842 L
.46072 .54371 L
.45629 .54813 L
.45101 .55342 L
.44658 .55785 L
.4413 .56313 L
.43687 .56756 L
.43158 .57284 L
.42716 .57727 L
.42187 .58256 L
.41744 .58698 L
.41216 .59227 L
.40773 .5967 L
.40245 .60198 L
.39802 .60641 L
.39273 .61169 L
.38831 .61612 L
.38302 .62141 L
.37859 .62583 L
.37331 .63112 L
.36888 .63555 L
.3636 .64083 L
.35917 .64526 L
.35388 .65054 L
.34946 .65497 L
.34417 .66026 L
.33974 .66468 L
.33446 .66997 L
.33003 .6744 L
.32475 .67968 L
.32032 .68411 L
.31503 .68939 L
.31061 .69382 L
.30532 .69911 L
.30089 .70353 L
.29561 .70882 L
.29118 .71325 L
.2859 .71853 L
.28147 .72296 L
.27618 .72824 L
.27176 .73267 L
.26647 .73796 L
.26204 .74238 L
.25676 .74767 L
.25233 .7521 L
.2476 .75738 L
.24262 .76181 L
.23764 .75738 L
.23291 .7521 L
.22848 .74767 L
.22319 .74238 L
.21877 .73796 L
.21348 .73267 L
.20905 .72824 L
.20377 .72296 L
.19934 .71853 L
.19934 .70882 L
.19406 .70353 L
.18963 .69911 L
.18434 .69382 L
.17992 .68939 L
.17992 .67968 L
.17463 .6744 L
.1702 .66997 L
.1702 .66026 L
.16492 .65497 L
.16049 .65054 L
.16049 .64083 L
.15521 .63555 L
.15078 .63112 L
.15078 .62141 L
.15078 .61169 L
.14549 .60641 L
.14107 .60198 L
.14107 .59227 L
.14107 .58256 L
.14107 .57284 L
.13578 .56756 L
.13135 .56313 L
.13135 .55342 L
.13135 .54371 L
.13135 .53399 L
.13135 .52428 L
.13135 .51457 L
.13135 .50486 L
.13135 .49514 L
.13135 .48543 L
.13135 .47572 L
.13135 .46601 L
.13135 .45629 L
.13135 .44658 L
.13135 .43687 L
.13578 .43244 L
.14107 .42716 L
.14107 .41744 L
.14107 .40773 L
.14107 .39802 L
.14549 .39359 L
.15078 .38831 L
.15078 .37859 L
.15078 .36888 L
.15521 .36445 L
.16049 .35917 L
.16049 .34946 L
.16492 .34503 L
.1702 .33974 L
.1702 .33003 L
.17463 .3256 L
.17992 .32032 L
.17992 .31061 L
.18434 .30618 L
.18963 .30089 L
.19406 .29647 L
.19934 .29118 L
.19934 .28147 L
.20377 .27704 L
.20905 .27176 L
.21348 .26733 L
.21877 .26204 L
.22319 .25762 L
.22848 .25233 L
.23291 .2479 L
.23819 .24262 L
.24262 .23819 L
.2479 .23291 L
.25233 .22848 L
.25762 .22319 L
.26204 .21877 L
.26733 .21348 L
.27176 .20905 L
.27704 .20377 L
.28147 .19934 L
.29118 .19934 L
.29647 .19406 L
.30089 .18963 L
.30618 .18434 L
.31061 .17992 L
.32032 .17992 L
.3256 .17463 L
.33003 .1702 L
.33974 .1702 L
.34503 .16492 L
.34946 .16049 L
.35917 .16049 L
.36445 .15521 L
.36888 .15078 L
.37859 .15078 L
.38831 .15078 L
.39359 .14549 L
.39802 .14107 L
.40773 .14107 L
.41744 .14107 L
.42716 .14107 L
.43244 .13578 L
F
0 g
.43687 .13135 m
.44658 .13135 L
.45629 .13135 L
.46601 .13135 L
.47572 .13135 L
.48543 .13135 L
.49514 .13135 L
.50486 .13135 L
.51457 .13135 L
.52428 .13135 L
.53399 .13135 L
.54371 .13135 L
.55342 .13135 L
.56313 .13135 L
.56756 .13578 L
.57284 .14107 L
.58256 .14107 L
.59227 .14107 L
.60198 .14107 L
.60641 .14549 L
.61169 .15078 L
.62141 .15078 L
.63112 .15078 L
.63555 .15521 L
.64083 .16049 L
.65054 .16049 L
.65497 .16492 L
.66026 .1702 L
.66997 .1702 L
.6744 .17463 L
.67968 .17992 L
.68939 .17992 L
.69382 .18434 L
.69911 .18963 L
.70353 .19406 L
.70882 .19934 L
.71853 .19934 L
.72296 .20377 L
.72824 .20905 L
.73267 .21348 L
.73796 .21877 L
.74238 .22319 L
.74767 .22848 L
.7521 .23291 L
.75738 .23819 L
.76181 .24262 L
.76709 .2479 L
.77152 .25233 L
.77681 .25762 L
.78123 .26204 L
Mistroke
.78652 .26733 L
.79095 .27176 L
.79623 .27704 L
.80066 .28147 L
.80066 .29118 L
.80594 .29647 L
.81037 .30089 L
.81566 .30618 L
.82008 .31061 L
.82008 .32032 L
.82537 .3256 L
.8298 .33003 L
.8298 .33974 L
.83508 .34503 L
.83951 .34946 L
.83951 .35917 L
.84479 .36445 L
.84922 .36888 L
.84922 .37859 L
.84922 .38831 L
.85451 .39359 L
.85893 .39802 L
.85893 .40773 L
.85893 .41744 L
.85893 .42716 L
.86422 .43244 L
.86865 .43687 L
.86865 .44658 L
.86865 .45629 L
.86865 .46601 L
.86865 .47572 L
.86865 .48543 L
.86865 .49514 L
.86865 .50486 L
.86865 .51457 L
.86865 .52428 L
.86865 .53399 L
.86865 .54371 L
.86865 .55342 L
.86865 .56313 L
.86422 .56756 L
.85893 .57284 L
.85893 .58256 L
.85893 .59227 L
.85893 .60198 L
.85451 .60641 L
.84922 .61169 L
.84922 .62141 L
.84922 .63112 L
.84479 .63555 L
Mistroke
.83951 .64083 L
.83951 .65054 L
.83508 .65497 L
.8298 .66026 L
.8298 .66997 L
.82537 .6744 L
.82008 .67968 L
.82008 .68939 L
.81566 .69382 L
.81037 .69911 L
.80594 .70353 L
.80066 .70882 L
.80066 .71853 L
.79623 .72296 L
.79095 .72824 L
.78652 .73267 L
.78123 .73796 L
.77681 .74238 L
.77152 .74767 L
.76709 .7521 L
.76236 .75738 L
.75738 .76181 L
.7524 .75738 L
.74767 .7521 L
.74324 .74767 L
.73796 .74238 L
.73353 .73796 L
.72824 .73267 L
.72382 .72824 L
.71853 .72296 L
.7141 .71853 L
.70882 .71325 L
.70439 .70882 L
.69911 .70353 L
.69468 .69911 L
.68939 .69382 L
.68497 .68939 L
.67968 .68411 L
.67525 .67968 L
.66997 .6744 L
.66554 .66997 L
.66026 .66468 L
.65583 .66026 L
.65054 .65497 L
.64612 .65054 L
.64083 .64526 L
.6364 .64083 L
.63112 .63555 L
.62669 .63112 L
.62141 .62583 L
Mistroke
.61698 .62141 L
.61169 .61612 L
.60727 .61169 L
.60198 .60641 L
.59755 .60198 L
.59227 .5967 L
.58784 .59227 L
.58256 .58698 L
.57813 .58256 L
.57284 .57727 L
.56842 .57284 L
.56313 .56756 L
.5587 .56313 L
.55342 .55785 L
.54899 .55342 L
.54371 .54813 L
.53928 .54371 L
.53399 .53842 L
.52957 .53399 L
.52428 .52871 L
.51985 .52428 L
.51457 .519 L
.51014 .51457 L
.50486 .50928 L
.49514 .50928 L
.48986 .51457 L
.48543 .519 L
.48015 .52428 L
.47572 .52871 L
.47043 .53399 L
.46601 .53842 L
.46072 .54371 L
.45629 .54813 L
.45101 .55342 L
.44658 .55785 L
.4413 .56313 L
.43687 .56756 L
.43158 .57284 L
.42716 .57727 L
.42187 .58256 L
.41744 .58698 L
.41216 .59227 L
.40773 .5967 L
.40245 .60198 L
.39802 .60641 L
.39273 .61169 L
.38831 .61612 L
.38302 .62141 L
.37859 .62583 L
.37331 .63112 L
Mistroke
.36888 .63555 L
.3636 .64083 L
.35917 .64526 L
.35388 .65054 L
.34946 .65497 L
.34417 .66026 L
.33974 .66468 L
.33446 .66997 L
.33003 .6744 L
.32475 .67968 L
.32032 .68411 L
.31503 .68939 L
.31061 .69382 L
.30532 .69911 L
.30089 .70353 L
.29561 .70882 L
.29118 .71325 L
.2859 .71853 L
.28147 .72296 L
.27618 .72824 L
.27176 .73267 L
.26647 .73796 L
.26204 .74238 L
.25676 .74767 L
.25233 .7521 L
.2476 .75738 L
.24262 .76181 L
.23764 .75738 L
.23291 .7521 L
.22848 .74767 L
.22319 .74238 L
.21877 .73796 L
.21348 .73267 L
.20905 .72824 L
.20377 .72296 L
.19934 .71853 L
.19934 .70882 L
.19406 .70353 L
.18963 .69911 L
.18434 .69382 L
.17992 .68939 L
.17992 .67968 L
.17463 .6744 L
.1702 .66997 L
.1702 .66026 L
.16492 .65497 L
.16049 .65054 L
.16049 .64083 L
.15521 .63555 L
.15078 .63112 L
Mistroke
.15078 .62141 L
.15078 .61169 L
.14549 .60641 L
.14107 .60198 L
.14107 .59227 L
.14107 .58256 L
.14107 .57284 L
.13578 .56756 L
.13135 .56313 L
.13135 .55342 L
.13135 .54371 L
.13135 .53399 L
.13135 .52428 L
.13135 .51457 L
.13135 .50486 L
.13135 .49514 L
.13135 .48543 L
.13135 .47572 L
.13135 .46601 L
.13135 .45629 L
.13135 .44658 L
.13135 .43687 L
.13578 .43244 L
.14107 .42716 L
.14107 .41744 L
.14107 .40773 L
.14107 .39802 L
.14549 .39359 L
.15078 .38831 L
.15078 .37859 L
.15078 .36888 L
.15521 .36445 L
.16049 .35917 L
.16049 .34946 L
.16492 .34503 L
.1702 .33974 L
.1702 .33003 L
.17463 .3256 L
.17992 .32032 L
.17992 .31061 L
.18434 .30618 L
.18963 .30089 L
.19406 .29647 L
.19934 .29118 L
.19934 .28147 L
.20377 .27704 L
.20905 .27176 L
.21348 .26733 L
.21877 .26204 L
.22319 .25762 L
Mistroke
.22848 .25233 L
.23291 .2479 L
.23819 .24262 L
.24262 .23819 L
.2479 .23291 L
.25233 .22848 L
.25762 .22319 L
.26204 .21877 L
.26733 .21348 L
.27176 .20905 L
.27704 .20377 L
.28147 .19934 L
.29118 .19934 L
.29647 .19406 L
.30089 .18963 L
.30618 .18434 L
.31061 .17992 L
.32032 .17992 L
.3256 .17463 L
.33003 .1702 L
.33974 .1702 L
.34503 .16492 L
.34946 .16049 L
.35917 .16049 L
.36445 .15521 L
.36888 .15078 L
.37859 .15078 L
.38831 .15078 L
.39359 .14549 L
.39802 .14107 L
.40773 .14107 L
.41744 .14107 L
.42716 .14107 L
.43244 .13578 L
.43687 .13135 L
Mfstroke
.7 g
.43687 .13222 m
.44658 .13222 L
.45629 .13222 L
.46601 .13222 L
.47572 .13222 L
.48543 .13222 L
.49514 .13222 L
.50486 .13222 L
.51457 .13222 L
.52428 .13222 L
.53399 .13222 L
.54371 .13222 L
.55342 .13222 L
.56313 .13222 L
.5667 .13578 L
.57284 .14193 L
.58256 .14193 L
.59227 .14193 L
.60198 .14193 L
.60555 .14549 L
.61169 .15164 L
.62141 .15164 L
.63112 .15164 L
.63468 .15521 L
.64083 .16135 L
.65054 .16135 L
.65411 .16492 L
.66026 .17107 L
.66997 .17107 L
.67353 .17463 L
.67968 .18078 L
.68939 .18078 L
.69296 .18434 L
.69911 .19049 L
.70267 .19406 L
.70882 .2002 L
.71853 .2002 L
.7221 .20377 L
.72824 .20992 L
.73181 .21348 L
.73796 .21963 L
.74152 .22319 L
.74767 .22934 L
.75123 .23291 L
.75738 .23905 L
.76095 .24262 L
.76709 .24877 L
.77066 .25233 L
.77681 .25848 L
.78037 .26204 L
.78652 .26819 L
.79008 .27176 L
.79623 .2779 L
.7998 .28147 L
.7998 .29118 L
.80594 .29733 L
.80951 .30089 L
.81566 .30704 L
.81922 .31061 L
.81922 .32032 L
.82537 .32647 L
.82893 .33003 L
.82893 .33974 L
.83508 .34589 L
.83865 .34946 L
.83865 .35917 L
.84479 .36532 L
.84836 .36888 L
.84836 .37859 L
.84836 .38831 L
.85451 .39445 L
.85807 .39802 L
.85807 .40773 L
.85807 .41744 L
.85807 .42716 L
.86422 .4333 L
.86778 .43687 L
.86778 .44658 L
.86778 .45629 L
.86778 .46601 L
.86778 .47572 L
.86778 .48543 L
.86778 .49514 L
.86778 .50486 L
.86778 .51457 L
.86778 .52428 L
.86778 .53399 L
.86778 .54371 L
.86778 .55342 L
.86778 .56313 L
.86422 .5667 L
.85807 .57284 L
.85807 .58256 L
.85807 .59227 L
.85807 .60198 L
.85451 .60555 L
.84836 .61169 L
.84836 .62141 L
.84836 .63112 L
.84479 .63468 L
.83865 .64083 L
.83865 .65054 L
.83508 .65411 L
.82893 .66026 L
.82893 .66997 L
.82537 .67353 L
.81922 .67968 L
.81922 .68939 L
.81566 .69296 L
.80951 .69911 L
.80594 .70267 L
.7998 .70882 L
.7998 .71853 L
.79623 .7221 L
.79008 .72824 L
.78652 .73181 L
.78037 .73796 L
.77681 .74152 L
.77066 .74767 L
.76709 .75123 L
.76153 .75738 L
.75738 .76095 L
.75324 .75738 L
.74767 .75123 L
.7441 .74767 L
.73796 .74152 L
.73439 .73796 L
.72824 .73181 L
.72468 .72824 L
.71853 .7221 L
.71497 .71853 L
.70882 .71238 L
.70525 .70882 L
.69911 .70267 L
.69554 .69911 L
.68939 .69296 L
.68583 .68939 L
.67968 .68325 L
.67612 .67968 L
.66997 .67353 L
.6664 .66997 L
.66026 .66382 L
.65669 .66026 L
.65054 .65411 L
.64698 .65054 L
.64083 .6444 L
.63727 .64083 L
.63112 .63468 L
.62755 .63112 L
.62141 .62497 L
.61784 .62141 L
.61169 .61526 L
.60813 .61169 L
.60198 .60555 L
.59842 .60198 L
.59227 .59583 L
.5887 .59227 L
.58256 .58612 L
.57899 .58256 L
.57284 .57641 L
.56928 .57284 L
.56313 .5667 L
.55957 .56313 L
.55342 .55698 L
.54985 .55342 L
.54371 .54727 L
.54014 .54371 L
.53399 .53756 L
.53043 .53399 L
.52428 .52785 L
.52072 .52428 L
.51457 .51813 L
.511 .51457 L
.50486 .50842 L
.49514 .50842 L
.489 .51457 L
.48543 .51813 L
.47928 .52428 L
.47572 .52785 L
.46957 .53399 L
.46601 .53756 L
.45986 .54371 L
.45629 .54727 L
.45015 .55342 L
.44658 .55698 L
.44043 .56313 L
.43687 .5667 L
.43072 .57284 L
.42716 .57641 L
.42101 .58256 L
.41744 .58612 L
.4113 .59227 L
.40773 .59583 L
.40158 .60198 L
.39802 .60555 L
.39187 .61169 L
.38831 .61526 L
.38216 .62141 L
.37859 .62497 L
.37245 .63112 L
.36888 .63468 L
.36273 .64083 L
.35917 .6444 L
.35302 .65054 L
.34946 .65411 L
.34331 .66026 L
.33974 .66382 L
.3336 .66997 L
.33003 .67353 L
.32388 .67968 L
.32032 .68325 L
.31417 .68939 L
.31061 .69296 L
.30446 .69911 L
.30089 .70267 L
.29475 .70882 L
.29118 .71238 L
.28503 .71853 L
.28147 .7221 L
.27532 .72824 L
.27176 .73181 L
.26561 .73796 L
.26204 .74152 L
.2559 .74767 L
.25233 .75123 L
.24676 .75738 L
.24262 .76095 L
.23847 .75738 L
.23291 .75123 L
.22934 .74767 L
.22319 .74152 L
.21963 .73796 L
.21348 .73181 L
.20992 .72824 L
.20377 .7221 L
.2002 .71853 L
.2002 .70882 L
.19406 .70267 L
.19049 .69911 L
.18434 .69296 L
.18078 .68939 L
.18078 .67968 L
.17463 .67353 L
.17107 .66997 L
.17107 .66026 L
.16492 .65411 L
.16135 .65054 L
.16135 .64083 L
.15521 .63468 L
.15164 .63112 L
.15164 .62141 L
.15164 .61169 L
.14549 .60555 L
.14193 .60198 L
.14193 .59227 L
.14193 .58256 L
.14193 .57284 L
.13578 .5667 L
.13222 .56313 L
.13222 .55342 L
.13222 .54371 L
.13222 .53399 L
.13222 .52428 L
.13222 .51457 L
.13222 .50486 L
.13222 .49514 L
.13222 .48543 L
.13222 .47572 L
.13222 .46601 L
.13222 .45629 L
.13222 .44658 L
.13222 .43687 L
.13578 .4333 L
.14193 .42716 L
.14193 .41744 L
.14193 .40773 L
.14193 .39802 L
.14549 .39445 L
.15164 .38831 L
.15164 .37859 L
.15164 .36888 L
.15521 .36532 L
.16135 .35917 L
.16135 .34946 L
.16492 .34589 L
.17107 .33974 L
.17107 .33003 L
.17463 .32647 L
.18078 .32032 L
.18078 .31061 L
.18434 .30704 L
.19049 .30089 L
.19406 .29733 L
.2002 .29118 L
.2002 .28147 L
.20377 .2779 L
.20992 .27176 L
.21348 .26819 L
.21963 .26204 L
.22319 .25848 L
.22934 .25233 L
.23291 .24877 L
.23905 .24262 L
.24262 .23905 L
.24877 .23291 L
.25233 .22934 L
.25848 .22319 L
.26204 .21963 L
.26819 .21348 L
.27176 .20992 L
.2779 .20377 L
.28147 .2002 L
.29118 .2002 L
.29733 .19406 L
.30089 .19049 L
.30704 .18434 L
.31061 .18078 L
.32032 .18078 L
.32647 .17463 L
.33003 .17107 L
.33974 .17107 L
.34589 .16492 L
.34946 .16135 L
.35917 .16135 L
.36532 .15521 L
.36888 .15164 L
.37859 .15164 L
.38831 .15164 L
.39445 .14549 L
.39802 .14193 L
.40773 .14193 L
.41744 .14193 L
.42716 .14193 L
.4333 .13578 L
F
0 g
.43687 .13222 m
.44658 .13222 L
.45629 .13222 L
.46601 .13222 L
.47572 .13222 L
.48543 .13222 L
.49514 .13222 L
.50486 .13222 L
.51457 .13222 L
.52428 .13222 L
.53399 .13222 L
.54371 .13222 L
.55342 .13222 L
.56313 .13222 L
.5667 .13578 L
.57284 .14193 L
.58256 .14193 L
.59227 .14193 L
.60198 .14193 L
.60555 .14549 L
.61169 .15164 L
.62141 .15164 L
.63112 .15164 L
.63468 .15521 L
.64083 .16135 L
.65054 .16135 L
.65411 .16492 L
.66026 .17107 L
.66997 .17107 L
.67353 .17463 L
.67968 .18078 L
.68939 .18078 L
.69296 .18434 L
.69911 .19049 L
.70267 .19406 L
.70882 .2002 L
.71853 .2002 L
.7221 .20377 L
.72824 .20992 L
.73181 .21348 L
.73796 .21963 L
.74152 .22319 L
.74767 .22934 L
.75123 .23291 L
.75738 .23905 L
.76095 .24262 L
.76709 .24877 L
.77066 .25233 L
.77681 .25848 L
.78037 .26204 L
Mistroke
.78652 .26819 L
.79008 .27176 L
.79623 .2779 L
.7998 .28147 L
.7998 .29118 L
.80594 .29733 L
.80951 .30089 L
.81566 .30704 L
.81922 .31061 L
.81922 .32032 L
.82537 .32647 L
.82893 .33003 L
.82893 .33974 L
.83508 .34589 L
.83865 .34946 L
.83865 .35917 L
.84479 .36532 L
.84836 .36888 L
.84836 .37859 L
.84836 .38831 L
.85451 .39445 L
.85807 .39802 L
.85807 .40773 L
.85807 .41744 L
.85807 .42716 L
.86422 .4333 L
.86778 .43687 L
.86778 .44658 L
.86778 .45629 L
.86778 .46601 L
.86778 .47572 L
.86778 .48543 L
.86778 .49514 L
.86778 .50486 L
.86778 .51457 L
.86778 .52428 L
.86778 .53399 L
.86778 .54371 L
.86778 .55342 L
.86778 .56313 L
.86422 .5667 L
.85807 .57284 L
.85807 .58256 L
.85807 .59227 L
.85807 .60198 L
.85451 .60555 L
.84836 .61169 L
.84836 .62141 L
.84836 .63112 L
.84479 .63468 L
Mistroke
.83865 .64083 L
.83865 .65054 L
.83508 .65411 L
.82893 .66026 L
.82893 .66997 L
.82537 .67353 L
.81922 .67968 L
.81922 .68939 L
.81566 .69296 L
.80951 .69911 L
.80594 .70267 L
.7998 .70882 L
.7998 .71853 L
.79623 .7221 L
.79008 .72824 L
.78652 .73181 L
.78037 .73796 L
.77681 .74152 L
.77066 .74767 L
.76709 .75123 L
.76153 .75738 L
.75738 .76095 L
.75324 .75738 L
.74767 .75123 L
.7441 .74767 L
.73796 .74152 L
.73439 .73796 L
.72824 .73181 L
.72468 .72824 L
.71853 .7221 L
.71497 .71853 L
.70882 .71238 L
.70525 .70882 L
.69911 .70267 L
.69554 .69911 L
.68939 .69296 L
.68583 .68939 L
.67968 .68325 L
.67612 .67968 L
.66997 .67353 L
.6664 .66997 L
.66026 .66382 L
.65669 .66026 L
.65054 .65411 L
.64698 .65054 L
.64083 .6444 L
.63727 .64083 L
.63112 .63468 L
.62755 .63112 L
.62141 .62497 L
Mistroke
.61784 .62141 L
.61169 .61526 L
.60813 .61169 L
.60198 .60555 L
.59842 .60198 L
.59227 .59583 L
.5887 .59227 L
.58256 .58612 L
.57899 .58256 L
.57284 .57641 L
.56928 .57284 L
.56313 .5667 L
.55957 .56313 L
.55342 .55698 L
.54985 .55342 L
.54371 .54727 L
.54014 .54371 L
.53399 .53756 L
.53043 .53399 L
.52428 .52785 L
.52072 .52428 L
.51457 .51813 L
.511 .51457 L
.50486 .50842 L
.49514 .50842 L
.489 .51457 L
.48543 .51813 L
.47928 .52428 L
.47572 .52785 L
.46957 .53399 L
.46601 .53756 L
.45986 .54371 L
.45629 .54727 L
.45015 .55342 L
.44658 .55698 L
.44043 .56313 L
.43687 .5667 L
.43072 .57284 L
.42716 .57641 L
.42101 .58256 L
.41744 .58612 L
.4113 .59227 L
.40773 .59583 L
.40158 .60198 L
.39802 .60555 L
.39187 .61169 L
.38831 .61526 L
.38216 .62141 L
.37859 .62497 L
.37245 .63112 L
Mistroke
.36888 .63468 L
.36273 .64083 L
.35917 .6444 L
.35302 .65054 L
.34946 .65411 L
.34331 .66026 L
.33974 .66382 L
.3336 .66997 L
.33003 .67353 L
.32388 .67968 L
.32032 .68325 L
.31417 .68939 L
.31061 .69296 L
.30446 .69911 L
.30089 .70267 L
.29475 .70882 L
.29118 .71238 L
.28503 .71853 L
.28147 .7221 L
.27532 .72824 L
.27176 .73181 L
.26561 .73796 L
.26204 .74152 L
.2559 .74767 L
.25233 .75123 L
.24676 .75738 L
.24262 .76095 L
.23847 .75738 L
.23291 .75123 L
.22934 .74767 L
.22319 .74152 L
.21963 .73796 L
.21348 .73181 L
.20992 .72824 L
.20377 .7221 L
.2002 .71853 L
.2002 .70882 L
.19406 .70267 L
.19049 .69911 L
.18434 .69296 L
.18078 .68939 L
.18078 .67968 L
.17463 .67353 L
.17107 .66997 L
.17107 .66026 L
.16492 .65411 L
.16135 .65054 L
.16135 .64083 L
.15521 .63468 L
.15164 .63112 L
Mistroke
.15164 .62141 L
.15164 .61169 L
.14549 .60555 L
.14193 .60198 L
.14193 .59227 L
.14193 .58256 L
.14193 .57284 L
.13578 .5667 L
.13222 .56313 L
.13222 .55342 L
.13222 .54371 L
.13222 .53399 L
.13222 .52428 L
.13222 .51457 L
.13222 .50486 L
.13222 .49514 L
.13222 .48543 L
.13222 .47572 L
.13222 .46601 L
.13222 .45629 L
.13222 .44658 L
.13222 .43687 L
.13578 .4333 L
.14193 .42716 L
.14193 .41744 L
.14193 .40773 L
.14193 .39802 L
.14549 .39445 L
.15164 .38831 L
.15164 .37859 L
.15164 .36888 L
.15521 .36532 L
.16135 .35917 L
.16135 .34946 L
.16492 .34589 L
.17107 .33974 L
.17107 .33003 L
.17463 .32647 L
.18078 .32032 L
.18078 .31061 L
.18434 .30704 L
.19049 .30089 L
.19406 .29733 L
.2002 .29118 L
.2002 .28147 L
.20377 .2779 L
.20992 .27176 L
.21348 .26819 L
.21963 .26204 L
.22319 .25848 L
Mistroke
.22934 .25233 L
.23291 .24877 L
.23905 .24262 L
.24262 .23905 L
.24877 .23291 L
.25233 .22934 L
.25848 .22319 L
.26204 .21963 L
.26819 .21348 L
.27176 .20992 L
.2779 .20377 L
.28147 .2002 L
.29118 .2002 L
.29733 .19406 L
.30089 .19049 L
.30704 .18434 L
.31061 .18078 L
.32032 .18078 L
.32647 .17463 L
.33003 .17107 L
.33974 .17107 L
.34589 .16492 L
.34946 .16135 L
.35917 .16135 L
.36532 .15521 L
.36888 .15164 L
.37859 .15164 L
.38831 .15164 L
.39445 .14549 L
.39802 .14193 L
.40773 .14193 L
.41744 .14193 L
.42716 .14193 L
.4333 .13578 L
.43687 .13222 L
Mfstroke
.8 g
.43687 .1331 m
.44658 .1331 L
.45629 .1331 L
.46601 .1331 L
.47572 .1331 L
.48543 .1331 L
.49514 .1331 L
.50486 .1331 L
.51457 .1331 L
.52428 .1331 L
.53399 .1331 L
.54371 .1331 L
.55342 .1331 L
.56313 .1331 L
.56581 .13578 L
.57284 .14281 L
.58256 .14281 L
.59227 .14281 L
.60198 .14281 L
.60466 .14549 L
.61169 .15252 L
.62141 .15252 L
.63112 .15252 L
.6338 .15521 L
.64083 .16224 L
.65054 .16224 L
.65323 .16492 L
.66026 .17195 L
.66997 .17195 L
.67265 .17463 L
.67968 .18166 L
.68939 .18166 L
.69208 .18434 L
.69911 .19137 L
.70179 .19406 L
.70882 .20109 L
.71853 .20109 L
.72121 .20377 L
.72824 .2108 L
.73093 .21348 L
.73796 .22051 L
.74064 .22319 L
.74767 .23022 L
.75035 .23291 L
.75738 .23994 L
.76006 .24262 L
.76709 .24965 L
.76978 .25233 L
.77681 .25936 L
.77949 .26204 L
.78652 .26907 L
.7892 .27176 L
.79623 .27879 L
.79891 .28147 L
.79891 .29118 L
.80594 .29821 L
.80863 .30089 L
.81566 .30792 L
.81834 .31061 L
.81834 .32032 L
.82537 .32735 L
.82805 .33003 L
.82805 .33974 L
.83508 .34677 L
.83776 .34946 L
.83776 .35917 L
.84479 .3662 L
.84748 .36888 L
.84748 .37859 L
.84748 .38831 L
.85451 .39534 L
.85719 .39802 L
.85719 .40773 L
.85719 .41744 L
.85719 .42716 L
.86422 .43419 L
.8669 .43687 L
.8669 .44658 L
.8669 .45629 L
.8669 .46601 L
.8669 .47572 L
.8669 .48543 L
.8669 .49514 L
.8669 .50486 L
.8669 .51457 L
.8669 .52428 L
.8669 .53399 L
.8669 .54371 L
.8669 .55342 L
.8669 .56313 L
.86422 .56581 L
.85719 .57284 L
.85719 .58256 L
.85719 .59227 L
.85719 .60198 L
.85451 .60466 L
.84748 .61169 L
.84748 .62141 L
.84748 .63112 L
.84479 .6338 L
.83776 .64083 L
.83776 .65054 L
.83508 .65323 L
.82805 .66026 L
.82805 .66997 L
.82537 .67265 L
.81834 .67968 L
.81834 .68939 L
.81566 .69208 L
.80863 .69911 L
.80594 .70179 L
.79891 .70882 L
.79891 .71853 L
.79623 .72121 L
.7892 .72824 L
.78652 .73093 L
.77949 .73796 L
.77681 .74064 L
.76978 .74767 L
.76709 .75035 L
.76064 .75738 L
.75738 .76006 L
.75412 .75738 L
.74767 .75035 L
.74499 .74767 L
.73796 .74064 L
.73527 .73796 L
.72824 .73093 L
.72556 .72824 L
.71853 .72121 L
.71585 .71853 L
.70882 .7115 L
.70614 .70882 L
.69911 .70179 L
.69642 .69911 L
.68939 .69208 L
.68671 .68939 L
.67968 .68236 L
.677 .67968 L
.66997 .67265 L
.66729 .66997 L
.66026 .66294 L
.65757 .66026 L
.65054 .65323 L
.64786 .65054 L
.64083 .64351 L
.63815 .64083 L
.63112 .6338 L
.62844 .63112 L
.62141 .62409 L
.61872 .62141 L
.61169 .61438 L
.60901 .61169 L
.60198 .60466 L
.5993 .60198 L
.59227 .59495 L
.58959 .59227 L
.58256 .58524 L
.57987 .58256 L
.57284 .57553 L
.57016 .57284 L
.56313 .56581 L
.56045 .56313 L
.55342 .5561 L
.55074 .55342 L
.54371 .54639 L
.54102 .54371 L
.53399 .53668 L
.53131 .53399 L
.52428 .52696 L
.5216 .52428 L
.51457 .51725 L
.51189 .51457 L
.50486 .50754 L
.49514 .50754 L
.48811 .51457 L
.48543 .51725 L
.4784 .52428 L
.47572 .52696 L
.46869 .53399 L
.46601 .53668 L
.45898 .54371 L
.45629 .54639 L
.44926 .55342 L
.44658 .5561 L
.43955 .56313 L
.43687 .56581 L
.42984 .57284 L
.42716 .57553 L
.42013 .58256 L
.41744 .58524 L
.41041 .59227 L
.40773 .59495 L
.4007 .60198 L
.39802 .60466 L
.39099 .61169 L
.38831 .61438 L
.38128 .62141 L
.37859 .62409 L
.37156 .63112 L
.36888 .6338 L
.36185 .64083 L
.35917 .64351 L
.35214 .65054 L
.34946 .65323 L
.34243 .66026 L
.33974 .66294 L
.33271 .66997 L
.33003 .67265 L
.323 .67968 L
.32032 .68236 L
.31329 .68939 L
.31061 .69208 L
.30358 .69911 L
.30089 .70179 L
.29386 .70882 L
.29118 .7115 L
.28415 .71853 L
.28147 .72121 L
.27444 .72824 L
.27176 .73093 L
.26473 .73796 L
.26204 .74064 L
.25501 .74767 L
.25233 .75035 L
.24588 .75738 L
.24262 .76006 L
.23936 .75738 L
.23291 .75035 L
.23022 .74767 L
.22319 .74064 L
.22051 .73796 L
.21348 .73093 L
.2108 .72824 L
.20377 .72121 L
.20109 .71853 L
.20109 .70882 L
.19406 .70179 L
.19137 .69911 L
.18434 .69208 L
.18166 .68939 L
.18166 .67968 L
.17463 .67265 L
.17195 .66997 L
.17195 .66026 L
.16492 .65323 L
.16224 .65054 L
.16224 .64083 L
.15521 .6338 L
.15252 .63112 L
.15252 .62141 L
.15252 .61169 L
.14549 .60466 L
.14281 .60198 L
.14281 .59227 L
.14281 .58256 L
.14281 .57284 L
.13578 .56581 L
.1331 .56313 L
.1331 .55342 L
.1331 .54371 L
.1331 .53399 L
.1331 .52428 L
.1331 .51457 L
.1331 .50486 L
.1331 .49514 L
.1331 .48543 L
.1331 .47572 L
.1331 .46601 L
.1331 .45629 L
.1331 .44658 L
.1331 .43687 L
.13578 .43419 L
.14281 .42716 L
.14281 .41744 L
.14281 .40773 L
.14281 .39802 L
.14549 .39534 L
.15252 .38831 L
.15252 .37859 L
.15252 .36888 L
.15521 .3662 L
.16224 .35917 L
.16224 .34946 L
.16492 .34677 L
.17195 .33974 L
.17195 .33003 L
.17463 .32735 L
.18166 .32032 L
.18166 .31061 L
.18434 .30792 L
.19137 .30089 L
.19406 .29821 L
.20109 .29118 L
.20109 .28147 L
.20377 .27879 L
.2108 .27176 L
.21348 .26907 L
.22051 .26204 L
.22319 .25936 L
.23022 .25233 L
.23291 .24965 L
.23994 .24262 L
.24262 .23994 L
.24965 .23291 L
.25233 .23022 L
.25936 .22319 L
.26204 .22051 L
.26907 .21348 L
.27176 .2108 L
.27879 .20377 L
.28147 .20109 L
.29118 .20109 L
.29821 .19406 L
.30089 .19137 L
.30792 .18434 L
.31061 .18166 L
.32032 .18166 L
.32735 .17463 L
.33003 .17195 L
.33974 .17195 L
.34677 .16492 L
.34946 .16224 L
.35917 .16224 L
.3662 .15521 L
.36888 .15252 L
.37859 .15252 L
.38831 .15252 L
.39534 .14549 L
.39802 .14281 L
.40773 .14281 L
.41744 .14281 L
.42716 .14281 L
.43419 .13578 L
F
0 g
.43687 .1331 m
.44658 .1331 L
.45629 .1331 L
.46601 .1331 L
.47572 .1331 L
.48543 .1331 L
.49514 .1331 L
.50486 .1331 L
.51457 .1331 L
.52428 .1331 L
.53399 .1331 L
.54371 .1331 L
.55342 .1331 L
.56313 .1331 L
.56581 .13578 L
.57284 .14281 L
.58256 .14281 L
.59227 .14281 L
.60198 .14281 L
.60466 .14549 L
.61169 .15252 L
.62141 .15252 L
.63112 .15252 L
.6338 .15521 L
.64083 .16224 L
.65054 .16224 L
.65323 .16492 L
.66026 .17195 L
.66997 .17195 L
.67265 .17463 L
.67968 .18166 L
.68939 .18166 L
.69208 .18434 L
.69911 .19137 L
.70179 .19406 L
.70882 .20109 L
.71853 .20109 L
.72121 .20377 L
.72824 .2108 L
.73093 .21348 L
.73796 .22051 L
.74064 .22319 L
.74767 .23022 L
.75035 .23291 L
.75738 .23994 L
.76006 .24262 L
.76709 .24965 L
.76978 .25233 L
.77681 .25936 L
.77949 .26204 L
Mistroke
.78652 .26907 L
.7892 .27176 L
.79623 .27879 L
.79891 .28147 L
.79891 .29118 L
.80594 .29821 L
.80863 .30089 L
.81566 .30792 L
.81834 .31061 L
.81834 .32032 L
.82537 .32735 L
.82805 .33003 L
.82805 .33974 L
.83508 .34677 L
.83776 .34946 L
.83776 .35917 L
.84479 .3662 L
.84748 .36888 L
.84748 .37859 L
.84748 .38831 L
.85451 .39534 L
.85719 .39802 L
.85719 .40773 L
.85719 .41744 L
.85719 .42716 L
.86422 .43419 L
.8669 .43687 L
.8669 .44658 L
.8669 .45629 L
.8669 .46601 L
.8669 .47572 L
.8669 .48543 L
.8669 .49514 L
.8669 .50486 L
.8669 .51457 L
.8669 .52428 L
.8669 .53399 L
.8669 .54371 L
.8669 .55342 L
.8669 .56313 L
.86422 .56581 L
.85719 .57284 L
.85719 .58256 L
.85719 .59227 L
.85719 .60198 L
.85451 .60466 L
.84748 .61169 L
.84748 .62141 L
.84748 .63112 L
.84479 .6338 L
Mistroke
.83776 .64083 L
.83776 .65054 L
.83508 .65323 L
.82805 .66026 L
.82805 .66997 L
.82537 .67265 L
.81834 .67968 L
.81834 .68939 L
.81566 .69208 L
.80863 .69911 L
.80594 .70179 L
.79891 .70882 L
.79891 .71853 L
.79623 .72121 L
.7892 .72824 L
.78652 .73093 L
.77949 .73796 L
.77681 .74064 L
.76978 .74767 L
.76709 .75035 L
.76064 .75738 L
.75738 .76006 L
.75412 .75738 L
.74767 .75035 L
.74499 .74767 L
.73796 .74064 L
.73527 .73796 L
.72824 .73093 L
.72556 .72824 L
.71853 .72121 L
.71585 .71853 L
.70882 .7115 L
.70614 .70882 L
.69911 .70179 L
.69642 .69911 L
.68939 .69208 L
.68671 .68939 L
.67968 .68236 L
.677 .67968 L
.66997 .67265 L
.66729 .66997 L
.66026 .66294 L
.65757 .66026 L
.65054 .65323 L
.64786 .65054 L
.64083 .64351 L
.63815 .64083 L
.63112 .6338 L
.62844 .63112 L
.62141 .62409 L
Mistroke
.61872 .62141 L
.61169 .61438 L
.60901 .61169 L
.60198 .60466 L
.5993 .60198 L
.59227 .59495 L
.58959 .59227 L
.58256 .58524 L
.57987 .58256 L
.57284 .57553 L
.57016 .57284 L
.56313 .56581 L
.56045 .56313 L
.55342 .5561 L
.55074 .55342 L
.54371 .54639 L
.54102 .54371 L
.53399 .53668 L
.53131 .53399 L
.52428 .52696 L
.5216 .52428 L
.51457 .51725 L
.51189 .51457 L
.50486 .50754 L
.49514 .50754 L
.48811 .51457 L
.48543 .51725 L
.4784 .52428 L
.47572 .52696 L
.46869 .53399 L
.46601 .53668 L
.45898 .54371 L
.45629 .54639 L
.44926 .55342 L
.44658 .5561 L
.43955 .56313 L
.43687 .56581 L
.42984 .57284 L
.42716 .57553 L
.42013 .58256 L
.41744 .58524 L
.41041 .59227 L
.40773 .59495 L
.4007 .60198 L
.39802 .60466 L
.39099 .61169 L
.38831 .61438 L
.38128 .62141 L
.37859 .62409 L
.37156 .63112 L
Mistroke
.36888 .6338 L
.36185 .64083 L
.35917 .64351 L
.35214 .65054 L
.34946 .65323 L
.34243 .66026 L
.33974 .66294 L
.33271 .66997 L
.33003 .67265 L
.323 .67968 L
.32032 .68236 L
.31329 .68939 L
.31061 .69208 L
.30358 .69911 L
.30089 .70179 L
.29386 .70882 L
.29118 .7115 L
.28415 .71853 L
.28147 .72121 L
.27444 .72824 L
.27176 .73093 L
.26473 .73796 L
.26204 .74064 L
.25501 .74767 L
.25233 .75035 L
.24588 .75738 L
.24262 .76006 L
.23936 .75738 L
.23291 .75035 L
.23022 .74767 L
.22319 .74064 L
.22051 .73796 L
.21348 .73093 L
.2108 .72824 L
.20377 .72121 L
.20109 .71853 L
.20109 .70882 L
.19406 .70179 L
.19137 .69911 L
.18434 .69208 L
.18166 .68939 L
.18166 .67968 L
.17463 .67265 L
.17195 .66997 L
.17195 .66026 L
.16492 .65323 L
.16224 .65054 L
.16224 .64083 L
.15521 .6338 L
.15252 .63112 L
Mistroke
.15252 .62141 L
.15252 .61169 L
.14549 .60466 L
.14281 .60198 L
.14281 .59227 L
.14281 .58256 L
.14281 .57284 L
.13578 .56581 L
.1331 .56313 L
.1331 .55342 L
.1331 .54371 L
.1331 .53399 L
.1331 .52428 L
.1331 .51457 L
.1331 .50486 L
.1331 .49514 L
.1331 .48543 L
.1331 .47572 L
.1331 .46601 L
.1331 .45629 L
.1331 .44658 L
.1331 .43687 L
.13578 .43419 L
.14281 .42716 L
.14281 .41744 L
.14281 .40773 L
.14281 .39802 L
.14549 .39534 L
.15252 .38831 L
.15252 .37859 L
.15252 .36888 L
.15521 .3662 L
.16224 .35917 L
.16224 .34946 L
.16492 .34677 L
.17195 .33974 L
.17195 .33003 L
.17463 .32735 L
.18166 .32032 L
.18166 .31061 L
.18434 .30792 L
.19137 .30089 L
.19406 .29821 L
.20109 .29118 L
.20109 .28147 L
.20377 .27879 L
.2108 .27176 L
.21348 .26907 L
.22051 .26204 L
.22319 .25936 L
Mistroke
.23022 .25233 L
.23291 .24965 L
.23994 .24262 L
.24262 .23994 L
.24965 .23291 L
.25233 .23022 L
.25936 .22319 L
.26204 .22051 L
.26907 .21348 L
.27176 .2108 L
.27879 .20377 L
.28147 .20109 L
.29118 .20109 L
.29821 .19406 L
.30089 .19137 L
.30792 .18434 L
.31061 .18166 L
.32032 .18166 L
.32735 .17463 L
.33003 .17195 L
.33974 .17195 L
.34677 .16492 L
.34946 .16224 L
.35917 .16224 L
.3662 .15521 L
.36888 .15252 L
.37859 .15252 L
.38831 .15252 L
.39534 .14549 L
.39802 .14281 L
.40773 .14281 L
.41744 .14281 L
.42716 .14281 L
.43419 .13578 L
.43687 .1331 L
Mfstroke
.9 g
.43687 .13402 m
.44658 .13402 L
.45629 .13402 L
.46601 .13402 L
.47572 .13402 L
.48543 .13402 L
.49514 .13402 L
.50486 .13402 L
.51457 .13402 L
.52428 .13402 L
.53399 .13402 L
.54371 .13402 L
.55342 .13402 L
.56313 .13402 L
.5649 .13578 L
.57284 .14373 L
.58256 .14373 L
.59227 .14373 L
.60198 .14373 L
.60375 .14549 L
.61169 .15344 L
.62141 .15344 L
.63112 .15344 L
.63288 .15521 L
.64083 .16315 L
.65054 .16315 L
.65231 .16492 L
.66026 .17287 L
.66997 .17287 L
.67173 .17463 L
.67968 .18258 L
.68939 .18258 L
.69116 .18434 L
.69911 .19229 L
.70087 .19406 L
.70882 .202 L
.71853 .202 L
.7203 .20377 L
.72824 .21172 L
.73001 .21348 L
.73796 .22143 L
.73972 .22319 L
.74767 .23114 L
.74943 .23291 L
.75738 .24085 L
.75915 .24262 L
.76709 .25057 L
.76886 .25233 L
.77681 .26028 L
.77857 .26204 L
.78652 .26999 L
.78828 .27176 L
.79623 .2797 L
.798 .28147 L
.798 .29118 L
.80594 .29913 L
.80771 .30089 L
.81566 .30884 L
.81742 .31061 L
.81742 .32032 L
.82537 .32827 L
.82713 .33003 L
.82713 .33974 L
.83508 .34769 L
.83685 .34946 L
.83685 .35917 L
.84479 .36712 L
.84656 .36888 L
.84656 .37859 L
.84656 .38831 L
.85451 .39625 L
.85627 .39802 L
.85627 .40773 L
.85627 .41744 L
.85627 .42716 L
.86422 .4351 L
.86598 .43687 L
.86598 .44658 L
.86598 .45629 L
.86598 .46601 L
.86598 .47572 L
.86598 .48543 L
.86598 .49514 L
.86598 .50486 L
.86598 .51457 L
.86598 .52428 L
.86598 .53399 L
.86598 .54371 L
.86598 .55342 L
.86598 .56313 L
.86422 .5649 L
.85627 .57284 L
.85627 .58256 L
.85627 .59227 L
.85627 .60198 L
.85451 .60375 L
.84656 .61169 L
.84656 .62141 L
.84656 .63112 L
.84479 .63288 L
.83685 .64083 L
.83685 .65054 L
.83508 .65231 L
.82713 .66026 L
.82713 .66997 L
.82537 .67173 L
.81742 .67968 L
.81742 .68939 L
.81566 .69116 L
.80771 .69911 L
.80594 .70087 L
.798 .70882 L
.798 .71853 L
.79623 .7203 L
.78828 .72824 L
.78652 .73001 L
.77857 .73796 L
.77681 .73972 L
.76886 .74767 L
.76709 .74943 L
.75966 .75738 L
.75738 .75915 L
.7551 .75738 L
.74767 .74943 L
.7459 .74767 L
.73796 .73972 L
.73619 .73796 L
.72824 .73001 L
.72648 .72824 L
.71853 .7203 L
.71677 .71853 L
.70882 .71058 L
.70705 .70882 L
.69911 .70087 L
.69734 .69911 L
.68939 .69116 L
.68763 .68939 L
.67968 .68145 L
.67792 .67968 L
.66997 .67173 L
.6682 .66997 L
.66026 .66202 L
.65849 .66026 L
.65054 .65231 L
.64878 .65054 L
.64083 .6426 L
.63907 .64083 L
.63112 .63288 L
.62935 .63112 L
.62141 .62317 L
.61964 .62141 L
.61169 .61346 L
.60993 .61169 L
.60198 .60375 L
.60022 .60198 L
.59227 .59403 L
.5905 .59227 L
.58256 .58432 L
.58079 .58256 L
.57284 .57461 L
.57108 .57284 L
.56313 .5649 L
.56137 .56313 L
.55342 .55518 L
.55165 .55342 L
.54371 .54547 L
.54194 .54371 L
.53399 .53576 L
.53223 .53399 L
.52428 .52605 L
.52252 .52428 L
.51457 .51633 L
.5128 .51457 L
.50486 .50662 L
.49514 .50662 L
.4872 .51457 L
.48543 .51633 L
.47748 .52428 L
.47572 .52605 L
.46777 .53399 L
.46601 .53576 L
.45806 .54371 L
.45629 .54547 L
.44835 .55342 L
.44658 .55518 L
.43863 .56313 L
.43687 .5649 L
.42892 .57284 L
.42716 .57461 L
.41921 .58256 L
.41744 .58432 L
.4095 .59227 L
.40773 .59403 L
.39978 .60198 L
.39802 .60375 L
.39007 .61169 L
.38831 .61346 L
.38036 .62141 L
.37859 .62317 L
.37065 .63112 L
.36888 .63288 L
.36093 .64083 L
.35917 .6426 L
.35122 .65054 L
.34946 .65231 L
.34151 .66026 L
.33974 .66202 L
.3318 .66997 L
.33003 .67173 L
.32208 .67968 L
.32032 .68145 L
.31237 .68939 L
.31061 .69116 L
.30266 .69911 L
.30089 .70087 L
.29295 .70882 L
.29118 .71058 L
.28323 .71853 L
.28147 .7203 L
.27352 .72824 L
.27176 .73001 L
.26381 .73796 L
.26204 .73972 L
.2541 .74767 L
.25233 .74943 L
.2449 .75738 L
.24262 .75915 L
.24034 .75738 L
.23291 .74943 L
.23114 .74767 L
.22319 .73972 L
.22143 .73796 L
.21348 .73001 L
.21172 .72824 L
.20377 .7203 L
.202 .71853 L
.202 .70882 L
.19406 .70087 L
.19229 .69911 L
.18434 .69116 L
.18258 .68939 L
.18258 .67968 L
.17463 .67173 L
.17287 .66997 L
.17287 .66026 L
.16492 .65231 L
.16315 .65054 L
.16315 .64083 L
.15521 .63288 L
.15344 .63112 L
.15344 .62141 L
.15344 .61169 L
.14549 .60375 L
.14373 .60198 L
.14373 .59227 L
.14373 .58256 L
.14373 .57284 L
.13578 .5649 L
.13402 .56313 L
.13402 .55342 L
.13402 .54371 L
.13402 .53399 L
.13402 .52428 L
.13402 .51457 L
.13402 .50486 L
.13402 .49514 L
.13402 .48543 L
.13402 .47572 L
.13402 .46601 L
.13402 .45629 L
.13402 .44658 L
.13402 .43687 L
.13578 .4351 L
.14373 .42716 L
.14373 .41744 L
.14373 .40773 L
.14373 .39802 L
.14549 .39625 L
.15344 .38831 L
.15344 .37859 L
.15344 .36888 L
.15521 .36712 L
.16315 .35917 L
.16315 .34946 L
.16492 .34769 L
.17287 .33974 L
.17287 .33003 L
.17463 .32827 L
.18258 .32032 L
.18258 .31061 L
.18434 .30884 L
.19229 .30089 L
.19406 .29913 L
.202 .29118 L
.202 .28147 L
.20377 .2797 L
.21172 .27176 L
.21348 .26999 L
.22143 .26204 L
.22319 .26028 L
.23114 .25233 L
.23291 .25057 L
.24085 .24262 L
.24262 .24085 L
.25057 .23291 L
.25233 .23114 L
.26028 .22319 L
.26204 .22143 L
.26999 .21348 L
.27176 .21172 L
.2797 .20377 L
.28147 .202 L
.29118 .202 L
.29913 .19406 L
.30089 .19229 L
.30884 .18434 L
.31061 .18258 L
.32032 .18258 L
.32827 .17463 L
.33003 .17287 L
.33974 .17287 L
.34769 .16492 L
.34946 .16315 L
.35917 .16315 L
.36712 .15521 L
.36888 .15344 L
.37859 .15344 L
.38831 .15344 L
.39625 .14549 L
.39802 .14373 L
.40773 .14373 L
.41744 .14373 L
.42716 .14373 L
.4351 .13578 L
F
0 g
.43687 .13402 m
.44658 .13402 L
.45629 .13402 L
.46601 .13402 L
.47572 .13402 L
.48543 .13402 L
.49514 .13402 L
.50486 .13402 L
.51457 .13402 L
.52428 .13402 L
.53399 .13402 L
.54371 .13402 L
.55342 .13402 L
.56313 .13402 L
.5649 .13578 L
.57284 .14373 L
.58256 .14373 L
.59227 .14373 L
.60198 .14373 L
.60375 .14549 L
.61169 .15344 L
.62141 .15344 L
.63112 .15344 L
.63288 .15521 L
.64083 .16315 L
.65054 .16315 L
.65231 .16492 L
.66026 .17287 L
.66997 .17287 L
.67173 .17463 L
.67968 .18258 L
.68939 .18258 L
.69116 .18434 L
.69911 .19229 L
.70087 .19406 L
.70882 .202 L
.71853 .202 L
.7203 .20377 L
.72824 .21172 L
.73001 .21348 L
.73796 .22143 L
.73972 .22319 L
.74767 .23114 L
.74943 .23291 L
.75738 .24085 L
.75915 .24262 L
.76709 .25057 L
.76886 .25233 L
.77681 .26028 L
.77857 .26204 L
Mistroke
.78652 .26999 L
.78828 .27176 L
.79623 .2797 L
.798 .28147 L
.798 .29118 L
.80594 .29913 L
.80771 .30089 L
.81566 .30884 L
.81742 .31061 L
.81742 .32032 L
.82537 .32827 L
.82713 .33003 L
.82713 .33974 L
.83508 .34769 L
.83685 .34946 L
.83685 .35917 L
.84479 .36712 L
.84656 .36888 L
.84656 .37859 L
.84656 .38831 L
.85451 .39625 L
.85627 .39802 L
.85627 .40773 L
.85627 .41744 L
.85627 .42716 L
.86422 .4351 L
.86598 .43687 L
.86598 .44658 L
.86598 .45629 L
.86598 .46601 L
.86598 .47572 L
.86598 .48543 L
.86598 .49514 L
.86598 .50486 L
.86598 .51457 L
.86598 .52428 L
.86598 .53399 L
.86598 .54371 L
.86598 .55342 L
.86598 .56313 L
.86422 .5649 L
.85627 .57284 L
.85627 .58256 L
.85627 .59227 L
.85627 .60198 L
.85451 .60375 L
.84656 .61169 L
.84656 .62141 L
.84656 .63112 L
.84479 .63288 L
Mistroke
.83685 .64083 L
.83685 .65054 L
.83508 .65231 L
.82713 .66026 L
.82713 .66997 L
.82537 .67173 L
.81742 .67968 L
.81742 .68939 L
.81566 .69116 L
.80771 .69911 L
.80594 .70087 L
.798 .70882 L
.798 .71853 L
.79623 .7203 L
.78828 .72824 L
.78652 .73001 L
.77857 .73796 L
.77681 .73972 L
.76886 .74767 L
.76709 .74943 L
.75966 .75738 L
.75738 .75915 L
.7551 .75738 L
.74767 .74943 L
.7459 .74767 L
.73796 .73972 L
.73619 .73796 L
.72824 .73001 L
.72648 .72824 L
.71853 .7203 L
.71677 .71853 L
.70882 .71058 L
.70705 .70882 L
.69911 .70087 L
.69734 .69911 L
.68939 .69116 L
.68763 .68939 L
.67968 .68145 L
.67792 .67968 L
.66997 .67173 L
.6682 .66997 L
.66026 .66202 L
.65849 .66026 L
.65054 .65231 L
.64878 .65054 L
.64083 .6426 L
.63907 .64083 L
.63112 .63288 L
.62935 .63112 L
.62141 .62317 L
Mistroke
.61964 .62141 L
.61169 .61346 L
.60993 .61169 L
.60198 .60375 L
.60022 .60198 L
.59227 .59403 L
.5905 .59227 L
.58256 .58432 L
.58079 .58256 L
.57284 .57461 L
.57108 .57284 L
.56313 .5649 L
.56137 .56313 L
.55342 .55518 L
.55165 .55342 L
.54371 .54547 L
.54194 .54371 L
.53399 .53576 L
.53223 .53399 L
.52428 .52605 L
.52252 .52428 L
.51457 .51633 L
.5128 .51457 L
.50486 .50662 L
.49514 .50662 L
.4872 .51457 L
.48543 .51633 L
.47748 .52428 L
.47572 .52605 L
.46777 .53399 L
.46601 .53576 L
.45806 .54371 L
.45629 .54547 L
.44835 .55342 L
.44658 .55518 L
.43863 .56313 L
.43687 .5649 L
.42892 .57284 L
.42716 .57461 L
.41921 .58256 L
.41744 .58432 L
.4095 .59227 L
.40773 .59403 L
.39978 .60198 L
.39802 .60375 L
.39007 .61169 L
.38831 .61346 L
.38036 .62141 L
.37859 .62317 L
.37065 .63112 L
Mistroke
.36888 .63288 L
.36093 .64083 L
.35917 .6426 L
.35122 .65054 L
.34946 .65231 L
.34151 .66026 L
.33974 .66202 L
.3318 .66997 L
.33003 .67173 L
.32208 .67968 L
.32032 .68145 L
.31237 .68939 L
.31061 .69116 L
.30266 .69911 L
.30089 .70087 L
.29295 .70882 L
.29118 .71058 L
.28323 .71853 L
.28147 .7203 L
.27352 .72824 L
.27176 .73001 L
.26381 .73796 L
.26204 .73972 L
.2541 .74767 L
.25233 .74943 L
.2449 .75738 L
.24262 .75915 L
.24034 .75738 L
.23291 .74943 L
.23114 .74767 L
.22319 .73972 L
.22143 .73796 L
.21348 .73001 L
.21172 .72824 L
.20377 .7203 L
.202 .71853 L
.202 .70882 L
.19406 .70087 L
.19229 .69911 L
.18434 .69116 L
.18258 .68939 L
.18258 .67968 L
.17463 .67173 L
.17287 .66997 L
.17287 .66026 L
.16492 .65231 L
.16315 .65054 L
.16315 .64083 L
.15521 .63288 L
.15344 .63112 L
Mistroke
.15344 .62141 L
.15344 .61169 L
.14549 .60375 L
.14373 .60198 L
.14373 .59227 L
.14373 .58256 L
.14373 .57284 L
.13578 .5649 L
.13402 .56313 L
.13402 .55342 L
.13402 .54371 L
.13402 .53399 L
.13402 .52428 L
.13402 .51457 L
.13402 .50486 L
.13402 .49514 L
.13402 .48543 L
.13402 .47572 L
.13402 .46601 L
.13402 .45629 L
.13402 .44658 L
.13402 .43687 L
.13578 .4351 L
.14373 .42716 L
.14373 .41744 L
.14373 .40773 L
.14373 .39802 L
.14549 .39625 L
.15344 .38831 L
.15344 .37859 L
.15344 .36888 L
.15521 .36712 L
.16315 .35917 L
.16315 .34946 L
.16492 .34769 L
.17287 .33974 L
.17287 .33003 L
.17463 .32827 L
.18258 .32032 L
.18258 .31061 L
.18434 .30884 L
.19229 .30089 L
.19406 .29913 L
.202 .29118 L
.202 .28147 L
.20377 .2797 L
.21172 .27176 L
.21348 .26999 L
.22143 .26204 L
.22319 .26028 L
Mistroke
.23114 .25233 L
.23291 .25057 L
.24085 .24262 L
.24262 .24085 L
.25057 .23291 L
.25233 .23114 L
.26028 .22319 L
.26204 .22143 L
.26999 .21348 L
.27176 .21172 L
.2797 .20377 L
.28147 .202 L
.29118 .202 L
.29913 .19406 L
.30089 .19229 L
.30884 .18434 L
.31061 .18258 L
.32032 .18258 L
.32827 .17463 L
.33003 .17287 L
.33974 .17287 L
.34769 .16492 L
.34946 .16315 L
.35917 .16315 L
.36712 .15521 L
.36888 .15344 L
.37859 .15344 L
.38831 .15344 L
.39625 .14549 L
.39802 .14373 L
.40773 .14373 L
.41744 .14373 L
.42716 .14373 L
.4351 .13578 L
.43687 .13402 L
Mfstroke
1 g
.43687 .135 m
.44658 .135 L
.45629 .135 L
.46601 .135 L
.47572 .135 L
.48543 .135 L
.49514 .135 L
.50486 .135 L
.51457 .135 L
.52428 .135 L
.53399 .135 L
.54371 .135 L
.55342 .135 L
.56313 .135 L
.56392 .13578 L
.57284 .14471 L
.58256 .14471 L
.59227 .14471 L
.60198 .14471 L
.60277 .14549 L
.61169 .15442 L
.62141 .15442 L
.63112 .15442 L
.6319 .15521 L
.64083 .16413 L
.65054 .16413 L
.65133 .16492 L
.66026 .17385 L
.66997 .17385 L
.67075 .17463 L
.67968 .18356 L
.68939 .18356 L
.69018 .18434 L
.69911 .19327 L
.69989 .19406 L
.70882 .20298 L
.71853 .20298 L
.71932 .20377 L
.72824 .2127 L
.72903 .21348 L
.73796 .22241 L
.73874 .22319 L
.74767 .23212 L
.74845 .23291 L
.75738 .24183 L
.75817 .24262 L
.76709 .25155 L
.76788 .25233 L
.77681 .26126 L
.77759 .26204 L
.78652 .27097 L
.7873 .27176 L
.79623 .28068 L
.79702 .28147 L
.79702 .29118 L
.80594 .30011 L
.80673 .30089 L
.81566 .30982 L
.81644 .31061 L
.81644 .32032 L
.82537 .32925 L
.82615 .33003 L
.82615 .33974 L
.83508 .34867 L
.83587 .34946 L
.83587 .35917 L
.84479 .3681 L
.84558 .36888 L
.84558 .37859 L
.84558 .38831 L
.85451 .39723 L
.85529 .39802 L
.85529 .40773 L
.85529 .41744 L
.85529 .42716 L
.86422 .43608 L
.865 .43687 L
.865 .44658 L
.865 .45629 L
.865 .46601 L
.865 .47572 L
.865 .48543 L
.865 .49514 L
.865 .50486 L
.865 .51457 L
.865 .52428 L
.865 .53399 L
.865 .54371 L
.865 .55342 L
.865 .56313 L
.86422 .56392 L
.85529 .57284 L
.85529 .58256 L
.85529 .59227 L
.85529 .60198 L
.85451 .60277 L
.84558 .61169 L
.84558 .62141 L
.84558 .63112 L
.84479 .6319 L
.83587 .64083 L
.83587 .65054 L
.83508 .65133 L
.82615 .66026 L
.82615 .66997 L
.82537 .67075 L
.81644 .67968 L
.81644 .68939 L
.81566 .69018 L
.80673 .69911 L
.80594 .69989 L
.79702 .70882 L
.79702 .71853 L
.79623 .71932 L
.7873 .72824 L
.78652 .72903 L
.77759 .73796 L
.77681 .73874 L
.76788 .74767 L
.76709 .74845 L
.75851 .75738 L
.75738 .75817 L
.75626 .75738 L
.74767 .74845 L
.74688 .74767 L
.73796 .73874 L
.73717 .73796 L
.72824 .72903 L
.72746 .72824 L
.71853 .71932 L
.71775 .71853 L
.70882 .7096 L
.70803 .70882 L
.69911 .69989 L
.69832 .69911 L
.68939 .69018 L
.68861 .68939 L
.67968 .68047 L
.6789 .67968 L
.66997 .67075 L
.66918 .66997 L
.66026 .66104 L
.65947 .66026 L
.65054 .65133 L
.64976 .65054 L
.64083 .64162 L
.64005 .64083 L
.63112 .6319 L
.63033 .63112 L
.62141 .62219 L
.62062 .62141 L
.61169 .61248 L
.61091 .61169 L
.60198 .60277 L
.6012 .60198 L
.59227 .59305 L
.59148 .59227 L
.58256 .58334 L
.58177 .58256 L
.57284 .57363 L
.57206 .57284 L
.56313 .56392 L
.56235 .56313 L
.55342 .5542 L
.55263 .55342 L
.54371 .54449 L
.54292 .54371 L
.53399 .53478 L
.53321 .53399 L
.52428 .52507 L
.5235 .52428 L
.51457 .51535 L
.51378 .51457 L
.50486 .50564 L
.49514 .50564 L
.48622 .51457 L
.48543 .51535 L
.4765 .52428 L
.47572 .52507 L
.46679 .53399 L
.46601 .53478 L
.45708 .54371 L
.45629 .54449 L
.44737 .55342 L
.44658 .5542 L
.43765 .56313 L
.43687 .56392 L
.42794 .57284 L
.42716 .57363 L
.41823 .58256 L
.41744 .58334 L
.40852 .59227 L
.40773 .59305 L
.3988 .60198 L
.39802 .60277 L
.38909 .61169 L
.38831 .61248 L
.37938 .62141 L
.37859 .62219 L
.36967 .63112 L
.36888 .6319 L
.35995 .64083 L
.35917 .64162 L
.35024 .65054 L
.34946 .65133 L
.34053 .66026 L
.33974 .66104 L
.33082 .66997 L
.33003 .67075 L
.3211 .67968 L
.32032 .68047 L
.31139 .68939 L
.31061 .69018 L
.30168 .69911 L
.30089 .69989 L
.29197 .70882 L
.29118 .7096 L
.28225 .71853 L
.28147 .71932 L
.27254 .72824 L
.27176 .72903 L
.26283 .73796 L
.26204 .73874 L
.25312 .74767 L
.25233 .74845 L
.24374 .75738 L
.24262 .75817 L
.24149 .75738 L
.23291 .74845 L
.23212 .74767 L
.22319 .73874 L
.22241 .73796 L
.21348 .72903 L
.2127 .72824 L
.20377 .71932 L
.20298 .71853 L
.20298 .70882 L
.19406 .69989 L
.19327 .69911 L
.18434 .69018 L
.18356 .68939 L
.18356 .67968 L
.17463 .67075 L
.17385 .66997 L
.17385 .66026 L
.16492 .65133 L
.16413 .65054 L
.16413 .64083 L
.15521 .6319 L
.15442 .63112 L
.15442 .62141 L
.15442 .61169 L
.14549 .60277 L
.14471 .60198 L
.14471 .59227 L
.14471 .58256 L
.14471 .57284 L
.13578 .56392 L
.135 .56313 L
.135 .55342 L
.135 .54371 L
.135 .53399 L
.135 .52428 L
.135 .51457 L
.135 .50486 L
.135 .49514 L
.135 .48543 L
.135 .47572 L
.135 .46601 L
.135 .45629 L
.135 .44658 L
.135 .43687 L
.13578 .43608 L
.14471 .42716 L
.14471 .41744 L
.14471 .40773 L
.14471 .39802 L
.14549 .39723 L
.15442 .38831 L
.15442 .37859 L
.15442 .36888 L
.15521 .3681 L
.16413 .35917 L
.16413 .34946 L
.16492 .34867 L
.17385 .33974 L
.17385 .33003 L
.17463 .32925 L
.18356 .32032 L
.18356 .31061 L
.18434 .30982 L
.19327 .30089 L
.19406 .30011 L
.20298 .29118 L
.20298 .28147 L
.20377 .28068 L
.2127 .27176 L
.21348 .27097 L
.22241 .26204 L
.22319 .26126 L
.23212 .25233 L
.23291 .25155 L
.24183 .24262 L
.24262 .24183 L
.25155 .23291 L
.25233 .23212 L
.26126 .22319 L
.26204 .22241 L
.27097 .21348 L
.27176 .2127 L
.28068 .20377 L
.28147 .20298 L
.29118 .20298 L
.30011 .19406 L
.30089 .19327 L
.30982 .18434 L
.31061 .18356 L
.32032 .18356 L
.32925 .17463 L
.33003 .17385 L
.33974 .17385 L
.34867 .16492 L
.34946 .16413 L
.35917 .16413 L
.3681 .15521 L
.36888 .15442 L
.37859 .15442 L
.38831 .15442 L
.39723 .14549 L
.39802 .14471 L
.40773 .14471 L
.41744 .14471 L
.42716 .14471 L
.43608 .13578 L
F
0 g
.43687 .135 m
.44658 .135 L
.45629 .135 L
.46601 .135 L
.47572 .135 L
.48543 .135 L
.49514 .135 L
.50486 .135 L
.51457 .135 L
.52428 .135 L
.53399 .135 L
.54371 .135 L
.55342 .135 L
.56313 .135 L
.56392 .13578 L
.57284 .14471 L
.58256 .14471 L
.59227 .14471 L
.60198 .14471 L
.60277 .14549 L
.61169 .15442 L
.62141 .15442 L
.63112 .15442 L
.6319 .15521 L
.64083 .16413 L
.65054 .16413 L
.65133 .16492 L
.66026 .17385 L
.66997 .17385 L
.67075 .17463 L
.67968 .18356 L
.68939 .18356 L
.69018 .18434 L
.69911 .19327 L
.69989 .19406 L
.70882 .20298 L
.71853 .20298 L
.71932 .20377 L
.72824 .2127 L
.72903 .21348 L
.73796 .22241 L
.73874 .22319 L
.74767 .23212 L
.74845 .23291 L
.75738 .24183 L
.75817 .24262 L
.76709 .25155 L
.76788 .25233 L
.77681 .26126 L
.77759 .26204 L
Mistroke
.78652 .27097 L
.7873 .27176 L
.79623 .28068 L
.79702 .28147 L
.79702 .29118 L
.80594 .30011 L
.80673 .30089 L
.81566 .30982 L
.81644 .31061 L
.81644 .32032 L
.82537 .32925 L
.82615 .33003 L
.82615 .33974 L
.83508 .34867 L
.83587 .34946 L
.83587 .35917 L
.84479 .3681 L
.84558 .36888 L
.84558 .37859 L
.84558 .38831 L
.85451 .39723 L
.85529 .39802 L
.85529 .40773 L
.85529 .41744 L
.85529 .42716 L
.86422 .43608 L
.865 .43687 L
.865 .44658 L
.865 .45629 L
.865 .46601 L
.865 .47572 L
.865 .48543 L
.865 .49514 L
.865 .50486 L
.865 .51457 L
.865 .52428 L
.865 .53399 L
.865 .54371 L
.865 .55342 L
.865 .56313 L
.86422 .56392 L
.85529 .57284 L
.85529 .58256 L
.85529 .59227 L
.85529 .60198 L
.85451 .60277 L
.84558 .61169 L
.84558 .62141 L
.84558 .63112 L
.84479 .6319 L
Mistroke
.83587 .64083 L
.83587 .65054 L
.83508 .65133 L
.82615 .66026 L
.82615 .66997 L
.82537 .67075 L
.81644 .67968 L
.81644 .68939 L
.81566 .69018 L
.80673 .69911 L
.80594 .69989 L
.79702 .70882 L
.79702 .71853 L
.79623 .71932 L
.7873 .72824 L
.78652 .72903 L
.77759 .73796 L
.77681 .73874 L
.76788 .74767 L
.76709 .74845 L
.75851 .75738 L
.75738 .75817 L
.75626 .75738 L
.74767 .74845 L
.74688 .74767 L
.73796 .73874 L
.73717 .73796 L
.72824 .72903 L
.72746 .72824 L
.71853 .71932 L
.71775 .71853 L
.70882 .7096 L
.70803 .70882 L
.69911 .69989 L
.69832 .69911 L
.68939 .69018 L
.68861 .68939 L
.67968 .68047 L
.6789 .67968 L
.66997 .67075 L
.66918 .66997 L
.66026 .66104 L
.65947 .66026 L
.65054 .65133 L
.64976 .65054 L
.64083 .64162 L
.64005 .64083 L
.63112 .6319 L
.63033 .63112 L
.62141 .62219 L
Mistroke
.62062 .62141 L
.61169 .61248 L
.61091 .61169 L
.60198 .60277 L
.6012 .60198 L
.59227 .59305 L
.59148 .59227 L
.58256 .58334 L
.58177 .58256 L
.57284 .57363 L
.57206 .57284 L
.56313 .56392 L
.56235 .56313 L
.55342 .5542 L
.55263 .55342 L
.54371 .54449 L
.54292 .54371 L
.53399 .53478 L
.53321 .53399 L
.52428 .52507 L
.5235 .52428 L
.51457 .51535 L
.51378 .51457 L
.50486 .50564 L
.49514 .50564 L
.48622 .51457 L
.48543 .51535 L
.4765 .52428 L
.47572 .52507 L
.46679 .53399 L
.46601 .53478 L
.45708 .54371 L
.45629 .54449 L
.44737 .55342 L
.44658 .5542 L
.43765 .56313 L
.43687 .56392 L
.42794 .57284 L
.42716 .57363 L
.41823 .58256 L
.41744 .58334 L
.40852 .59227 L
.40773 .59305 L
.3988 .60198 L
.39802 .60277 L
.38909 .61169 L
.38831 .61248 L
.37938 .62141 L
.37859 .62219 L
.36967 .63112 L
Mistroke
.36888 .6319 L
.35995 .64083 L
.35917 .64162 L
.35024 .65054 L
.34946 .65133 L
.34053 .66026 L
.33974 .66104 L
.33082 .66997 L
.33003 .67075 L
.3211 .67968 L
.32032 .68047 L
.31139 .68939 L
.31061 .69018 L
.30168 .69911 L
.30089 .69989 L
.29197 .70882 L
.29118 .7096 L
.28225 .71853 L
.28147 .71932 L
.27254 .72824 L
.27176 .72903 L
.26283 .73796 L
.26204 .73874 L
.25312 .74767 L
.25233 .74845 L
.24374 .75738 L
.24262 .75817 L
.24149 .75738 L
.23291 .74845 L
.23212 .74767 L
.22319 .73874 L
.22241 .73796 L
.21348 .72903 L
.2127 .72824 L
.20377 .71932 L
.20298 .71853 L
.20298 .70882 L
.19406 .69989 L
.19327 .69911 L
.18434 .69018 L
.18356 .68939 L
.18356 .67968 L
.17463 .67075 L
.17385 .66997 L
.17385 .66026 L
.16492 .65133 L
.16413 .65054 L
.16413 .64083 L
.15521 .6319 L
.15442 .63112 L
Mistroke
.15442 .62141 L
.15442 .61169 L
.14549 .60277 L
.14471 .60198 L
.14471 .59227 L
.14471 .58256 L
.14471 .57284 L
.13578 .56392 L
.135 .56313 L
.135 .55342 L
.135 .54371 L
.135 .53399 L
.135 .52428 L
.135 .51457 L
.135 .50486 L
.135 .49514 L
.135 .48543 L
.135 .47572 L
.135 .46601 L
.135 .45629 L
.135 .44658 L
.135 .43687 L
.13578 .43608 L
.14471 .42716 L
.14471 .41744 L
.14471 .40773 L
.14471 .39802 L
.14549 .39723 L
.15442 .38831 L
.15442 .37859 L
.15442 .36888 L
.15521 .3681 L
.16413 .35917 L
.16413 .34946 L
.16492 .34867 L
.17385 .33974 L
.17385 .33003 L
.17463 .32925 L
.18356 .32032 L
.18356 .31061 L
.18434 .30982 L
.19327 .30089 L
.19406 .30011 L
.20298 .29118 L
.20298 .28147 L
.20377 .28068 L
.2127 .27176 L
.21348 .27097 L
.22241 .26204 L
.22319 .26126 L
Mistroke
.23212 .25233 L
.23291 .25155 L
.24183 .24262 L
.24262 .24183 L
.25155 .23291 L
.25233 .23212 L
.26126 .22319 L
.26204 .22241 L
.27097 .21348 L
.27176 .2127 L
.28068 .20377 L
.28147 .20298 L
.29118 .20298 L
.30011 .19406 L
.30089 .19327 L
.30982 .18434 L
.31061 .18356 L
.32032 .18356 L
.32925 .17463 L
.33003 .17385 L
.33974 .17385 L
.34867 .16492 L
.34946 .16413 L
.35917 .16413 L
.3681 .15521 L
.36888 .15442 L
.37859 .15442 L
.38831 .15442 L
.39723 .14549 L
.39802 .14471 L
.40773 .14471 L
.41744 .14471 L
.42716 .14471 L
.43608 .13578 L
.43687 .135 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00C_ooool4o`000003oa0@4?oooooooooo02cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0_ooooo`Co000000?o410@ooooooooool09oooool0053ooooo
00?o0000ooooooooool0;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`0Y
ooooo`00AOooool6o`0000Gooooo00?o0000ooooooooool09_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooooooooa0@
400_ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02Wooooo001@ooooo`03o`000?oooooooooo02kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo02Wooooo00Go0000ooooooooooooooooo`00000_ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0`ooooo`03o`000?oooooooooo
02Wooooo001@ooooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0:_ooool01Ol0003ooooooooooooooooo000002oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ol0003o
ooooooooo`0Yooooo`00D?ooool00ol0003oooooooooo`0^ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0/ooooo`05oa0@4?ooooooooooooooool@4100;oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Y
ooooo`00D?ooool00ol0003oooooooooo`0^ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`00C_oo
ool00omEEEGoIVIVo`00000`ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0_ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
033ooooo00?oEEEEofIVI_l00000:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool002;oooooool00016o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09oooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo0?oooooo@_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo0?oooooo@_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo0?oooooo@_ooool1o`00007ooooo000Rooooo`03o`00
0?oooooooooo0?oooooo@_ooool1o`00007ooooo000Rooooo`;o0000oooooom2ooooo`;o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Coooooool0000io`00
00Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000
>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`;o0000
1?ooooooo`0003Wo00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooo
oooo0000>Ol00006ooooo`7o00000Oooool001Sooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`003ooo
ool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol0
0006ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01Oooool3o`0000?oooooool0000i
o`0000Cooooo0ol00001ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?oooooool0000io`0000Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?oooooQol0000[ooooohKo00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00ooooon6o`0002goooooQOl00006ooooo`7o0000
0Oooool001Sooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03ooooohGo0000;ooo
oon4o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooogco0000@Ooooomk
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog[o0000AOoooomio`00
00Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooogWo0000Aooooomho`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog;o0000EOoooomao`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooog7o0000Eooooom`o`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooog3o0000FOoooom_o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooofoo0000Fooooom^o`0000Kooooo0Ol00001oooo
o`008_ooool2o`0000CoooooJol0001Sooooof[o00001Oooool2o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?oooooJ_l0001UooooofWo00001_ooool1o`00007ooooo000Rooooo`03o`000?oo
oooooooo00?oooooJOl0001WooooofSo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooo
oooo00?oooooIOl0001_ooooofCo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo
00?oooooI?l0001aooooof?o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooHol0001cooooof;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo
G_l0001moooooego00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooGOl0
001ooooooeco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooG?l00021
oooooe_o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooFol00023oooo
oe[o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooF_l00025oooooeWo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooFOl00027oooooeSo0000
1_ooool1o`00007ooooo000Rooooo`;o00001?oooomEo`0008ooooooE?l00005ooooo`;o00000Ooo
ool002;ooooo00?o0000ooooooooool00ooooomDo`00097oooooDol00006ooooo`7o00000Oooool0
02;ooooo00?o0000ooooooooool00ooooomCo`0009?oooooD_l00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00ooooomCo`0009?oooooD_l00006ooooo`7o00000Oooool002;ooooo
00?o0000ooooooooool00ooooomAo`0009OoooooD?l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooom@o`0009WoooooCol00006ooooo`7o00000Oooool002;ooooo00?o0000
ooooooooool00ooooom?o`0009[oooooCol00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00ooooom?o`0009_oooooC_l00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00ooooom>o`0009goooooCOl00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0ooooom=o`0009ooooooC?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
oom;o`000:?oooooB_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooom:
o`000:GoooooBOl00006ooooo`7o00000Oooool002;ooooo0_l00004ooooodWo0000Yooooom8o`00
00Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03ooooodSo0000ZOoooom7o`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodOo0000Zooooom6o`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodKo0000[Ooooom5o`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooodGo0000[ooooom4o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooodCo0000/Ooooom3o`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooood?o0000/ooooom2o`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03oooood;o0000]Ooooom1o`0000Kooooo0Ol00001ooooo`008_oo
ool00ol0003oooooooooo`03oooood7o0000]ooooom0o`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooood3o0000^Oooooloo`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03oooood3o0000^Oooooloo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03ooooocko0000_Ooooolmo`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Cooooo
?Ol0002oooooocco00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l0
0030ooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030
ooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030oooo
occo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00030ooooocco
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l00031oooooc_o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>ol00033oooooc[o00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>_l00035ooooocWo00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo>?l00038ooooocSo00001_ooool1o`00
007ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo=ol0003:ooooocOo00001_ooool1
o`00007ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`03ooooocKo0000c?oooolfo`0000Kooooo0Ol00001
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo=_l0003=ooooocGo00001_ooool1o`00007ooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o00000ooooolf
o`000<gooooo=Ol00004ooooo`?o00000Oooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocKo0000cOoo
ooleo`0000Kooooo0Ol00001ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooocGo0000coooooldo`0000Kooooo0Ol0
0001ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooocCo0000dOoooolco`0000Kooooo0Ol00001ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo<ol0
003Coooooc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003C
oooooc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooo
oc;o00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooooc;o
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<ol0003Coooooc;o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<_l0003Eoooooc7o00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<Ol0003Goooooc3o00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<?l0003Ioooooboo00001_ooool1o`00
007ooooo000Rooooo`;o00001?ooool`o`000=Wooooo;ol00005ooooo`;o00000Oooool002;ooooo
00?o0000ooooooooool00oooool`o`000=Wooooo;ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooool`o`000=Wooooo;ol00006ooooo`7o00000Oooool002;ooooo00?o0000
ooooooooool00oooool_o`000=_ooooo;_l00006ooooo`7o00000Oooool002;ooooo00?o0000oooo
ooooool00oooool^o`000=gooooo;Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00oooool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ool]o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]
o`000=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`00
0=oooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`000=oo
oooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`000=oooooo
;?l00006ooooo`7o00000Oooool002;ooooo0_l00004ooooobco0000hOooool[o`0000Gooooo0_l0
0001ooooo`008_ooool00ol0003oooooooooo`03ooooob_o0000hooooolZo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`00
8_ooool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_oo
ool00ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooooooo
o`03ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03
ooooob[o0000iOoooolYo`0000Kooooo0Ol00001ooooo`008_ooool2o`0000Cooooo:_l0003Uoooo
obWo00001Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:Ol0003WooooobSo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:?l0003YooooobOo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9ol0003[ooooobKo00001_oo
ool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1
o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Rooooo`;o0000
1?oooolVo`000>cooooo9_l00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00ooo
oolVo`000>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolV
o`000>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
0>cooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>co
oooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo
9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l0
0006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`000>cooooo9_l00006oooo
o`7o00000Oooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
00?ooooo9_l0003/ooooobKo00001_ooool1o`00007ooooo000Gooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`03ooooobKo0000k?oooolVo`0000Kooooo0Ol00001oooo
o`005oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00ooooolVo`00
0>cooooo9_l00006ooooo`7o00000Oooool001Oooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00000ooooolVo`000>cooooo9_l00004ooooo`?o00000Oooool001Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo9_l0001dooooo`Go0000LooooolVo`00
00Kooooo0Ol00001ooooo`005oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool00ooooolVo`0007?ooooo1_l0001cooooobKo00001_ooool1o`00007ooooo000Gooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooobKo0000L_ooool8o`00
07;ooooo9_l00006ooooo`7o00000Oooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00?ooooo9_l0001aooooo`[o0000LOoooolVo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooobKo0000LOooool;o`00073ooooo9_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00073ooooo3Ol0001_ooooobKo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0001_ooooo`oo0000K_oo
oolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobKo0000K_oooolA
o`0006gooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
06gooooo4ol0001/ooooobKo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo9_l0001/oooooaGo0000JooooolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobKo0000JooooolGo`0006[ooooo9_l00006ooooo`7o00000Oooool002;ooooo0_l0
0004ooooobKo0000J_oooolIo`0006Wooooo9_l00005ooooo`;o00000Oooool002;ooooo00?o0000
ooooooooool00ooooolVo`0006Wooooo6ol0001XooooobKo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo9_l0001Xoooooago0000IooooolVo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03ooooobKo0000IooooolOo`0006Kooooo9_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`0006Kooooo8Ol0001UooooobKo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo9_l0001Uooooob?o0000I?oo
oolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobKo0000I?oooolU
o`0006?ooooo9_l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolVo`00
06?ooooo9ol0001RooooobKo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo9ol0001Pooooob[o0000HOoooolVo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobSo0000Goooool[o`0005oooooo9ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolYo`0005gooooo;Ol0001MooooobSo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo:_l0001Koooooboo0000FooooolYo`0000Kooooo0Ol00001
ooooo`008_ooool2o`0000Cooooo:_l0001Ioooooc?o0000FOoooolYo`0000Gooooo0_l00001oooo
o`008_ooool00ol0003oooooooooo`03ooooob[o0000F?ooooleo`0005Sooooo:Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolZo`0005Oooooo=ol0001GooooobWo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo:_l0001GooooocOo0000Eooo
oolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooob[o0000E_ooooli
o`0005Kooooo:Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolZo`00
05Gooooo>ol0001EooooobWo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo:_l0001Dooooocgo0000E?oooolYo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooob[o0000Doooooloo`0005?ooooo:Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolZo`0005;ooooo@Ol0001BooooobWo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo:_l0001Aoooood?o0000DOoooolYo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03ooooob_o0000Cooooom5o`0004oooooo:_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool/o`0004goooooAol0001=ooooob_o
00001_ooool1o`00007ooooo000Rooooo`;o00001?ooool]o`0004_oooooBOl0001;ooooobco0000
1Oooool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo;Ol0001:oooood_o0000B_oo
ool/o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooobgo0000BOoooom=
o`0004Wooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool]o`00
04SoooooCol00018ooooobco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo;Ol00017oooooe7o0000Aoooool/o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooobgo0000A_oooomCo`0004Kooooo;?l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00oooool]o`0004CoooooEol00014ooooobco00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo;_l00012oooooeSo0000@oooool]o`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooboo0000@?oooomJo`00047ooooo;_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooool`o`0003koooooG?l0000ooooooboo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo<?l0000noooooego0000
?_ooool_o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooc3o0000?Ooo
oomOo`0003gooooo;ol00006ooooo`7o00000Oooool002;ooooo0_l00004oooooc3o0000??oooomQ
o`0003cooooo;ol00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00oooool`o`00
03_oooooHol0000koooooboo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo<Ol0000iooooofGo0000>Oooool`o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooc;o0000=ooooomWo`0003Oooooo<Ol00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooolco`0003GoooooJOl0000eoooooc;o00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?ooooo<ol0000dooooof_o0000=?oooolbo`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooc?o0000<ooooom]o`0003?ooooo<_l00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooolco`0003;oooooKol0000boooooc;o
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo=?l0000`ooooog7o0000
<?oooolco`0000Kooooo0Ol00001ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooocGo
0000;_oooomco`0002kooooo=?l00006ooooo`7o00000Oooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?o
oooo=_l0000/ooooogGo0000;?ooooleo`0000Kooooo0Ol00001ooooo`001oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooocKo
0000:ooooomgo`0002_ooooo=Ol00006ooooo`7o00000Oooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003ooooocKo0000:_oooomio`0002[o
oooo=Ol00004ooooo`?o00000Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocKo0000:?oooomlo`00
02Sooooo=_l00006ooooo`7o00000Oooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooooolgo`0002OoooooOOl0000Woooo
ocKo00001_ooool1o`00007ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo>?l0000Uooooogoo00009Ooooolgo`00
00Kooooo0Ol00001ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006oooo
o`03o`000?oooooooooo00?ooooo>Ol0000Soooooh7o00008ooooolho`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooooc[o00008?oooon5o`0001oooooo>_l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooolko`0001koooooQol0000Moooooc_o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo??l0000LooooohWo00006ooo
oollo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooocco00007?oooon9
o`0001_ooooo??l00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooollo`00
01_oooooRol0000Jooooocco00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
oooo??l0000Jooooohgo00006Ooooollo`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooocgo00006?oooon?o`0001Sooooo??l00006ooooo`7o00000Oooool002;ooooo0_l0
0004ooooocko00005_oooonAo`0001Kooooo?Ol00005ooooo`;o00000Oooool002;ooooo00?o0000
ooooooooool00oooooloo`0001CoooooTol0000Dooooocko00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?ooooo@?l0000BoooooiGo00004_ooooloo`0000Kooooo0Ol00001oooo
o`008_ooool00ol0003oooooooooo`03oooood7o00004?oooonGo`00013ooooo@?l00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00ooooom2o`0000koooooVOl0000>oooood7o0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo@ol0000<oooooi_o00003?oo
oom2o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03ooooodCo00002_oooonM
o`0000[ooooo@ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooom5o`00
00SoooooWol00008ooooodCo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?o
ooooA_l00006oooooj7o00001_oooom5o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03ooooodOo00001?oooonSo`0000CoooooA_l00006ooooo`7o00000Oooool002;ooooo00?o
0000ooooooooool00ooooom8o`0000;oooooYOl00002ooooodOo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool2o`00
00Coooooool0000io`0000Gooooo0_l00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo0000
1_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol0
0001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool0
02;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000i
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007o
oooo000Rooooo`;o00001?ooooooo`0003Wo00001Oooool2o`00007ooooo000Rooooo`03o`000?oo
oooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03
oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`00
03Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Ko
oooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o0000
0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0
003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000oooooooo
ool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol0
0006ooooo`7o00000Oooool002;ooooo0_l00004oooooooo0000>Ol00005ooooo`;o00000Oooool0
02;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03
o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooo
ooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000i
o`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006oooo
o`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooooooo
o`0003Wo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Go
oooo0ol00003oooooooo0000>Ol00004ooooo`?o00000Oooool001[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool001Sooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03oooo
oooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`;o00001?ooooooo`0003Wo00001Ooo
ool2o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;o
oooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`00
0?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003ooooooooo
o`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00ooooooo
o`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`00
00Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o
00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo0_l00004oooo
oooo0000>Ol00005ooooo`;o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo
00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo
0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00007ooooo000Roooo
o`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`03oooooooo0000>Ol00006ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0003Wo00001_ooool1o`00007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0
000io`0000Kooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`03oooooooo0000>Ol00006
ooooo`7o00000Oooool002;ooooo00?o0000ooooooooool00oooooooo`0003Wo00001_ooool1o`00
007ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000io`0000Kooooo0Ol00001ooooo`00
8_ooool2o`0000Coooooool0000io`0000Gooooo0_l00001ooooo`008_ooool00ol0003ooooooooo
o`3ooooood;ooooo0Ol00001ooooo`008_ooool00ol0003oooooooooo`3ooooood;ooooo0Ol00001
ooooo`008_ooool00ol0003oooooooooo`3ooooood;ooooo0Ol00001ooooo`008_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09oooool1o`00007o
oooo000Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`008_ooooooo`0004Ko00000Ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "For boundary conditions,  on the edges of the cusp we take  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x = y, y) = \(\[Phi](x = \(-y\), y) = 
          1 - x\^\(\(2\)\(\ \)\) - y\^2\)\)]],
  ". This boundary condition matches continuously onto the boundary condition \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  ",  applied to the circular part of the boundary. "
}], "Text"],

Cell[TextData[{
  "\tThis problem is analytically tractable. The solution was developed as an \
exercise in Chapter 4 [Sec. ",
  ButtonBox["4.3",
    ButtonData:>{"Chapter4.nb", "c:32"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (9)] and is given below in cylindrical coordinates:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(\[Epsilon] \[Rule] \ 0\)\(\[Sum]\+\(n = 1\)\%\
\[Infinity] A\_n\ \((\[Epsilon])\)\ \(sin(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\
\) \(log(r)\))\) {sinh[\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \((\[Theta] - \
\[Beta])\)] - \ 
                sinh[\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \((\[Theta] - \
\[Beta] - \[Alpha])\)]}\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.14)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " runs between  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 3  \[Pi]/4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  + \ \[Alpha]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 3\ \[Pi]/2\)]],
  " is the opening angle of the domain. The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " are determined according to the equation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(sinh(\(n\ \[Pi]\)\/\(log(\[Epsilon])\))\) \(\(A\_n\
\)(\[Epsilon])\) = \ \[Integral]\_\[Epsilon]\%1\( 
              sin(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \(Log(r)\))\) \((1 - 
                r\^2)\) \(\[DifferentialD]r\/r\)/\(\[Integral]\_\[Epsilon]\%1\
\(\( sin\^2\)(\(\(n\ \[Pi]\)\/\(log(\[Epsilon])\)\) \(log(
                        r)\))\) \[DifferentialD]r\/r\)\)]],
  "."
}], "Text"],

Cell["This analytic solution is constructed below:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[n_]\  = 
      Simplify[\ 
        Integrate[
            Sin[n\ Pi\ Log[r]\ /Log[\[Epsilon]]] \((1 - r\^2)\)/
                r, {r, \[Epsilon], 1}]/
          Integrate[
            Sin[n\ Pi\ Log[r]\ /Log[\[Epsilon]]]^2/r, {r, \[Epsilon], 1}], 
        n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.25"],

Cell[BoxData[
    \(\(2\ \((\(-1\))\)\^n\ n\^2\ \[Pi]\^2\ \((\(-1\) + \[Epsilon]\^2)\) - 8\ \
\((\(-1\) + \((\(-1\))\)\^n)\)\ Log[\[Epsilon]]\^2\)\/\(n\^3\ \[Pi]\^3 + 4\ n\
\ \[Pi]\ Log[\[Epsilon]]\^2\)\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\[Epsilon]\  = \ 10. ^\(-8\); \[Alpha]\  = \ 3\ Pi/2. ; \[Beta]\  = \ 
      3  Pi/4;\[IndentingNewLine]\), "\n", 
    \(\(\[Phi][r_, \[Theta]_]\  = \ 
        Sum[A[n]\ Sin[\ 
              n\ Pi\ Log[r]/
                  Log[\[Epsilon]]]\ \((Sinh[
                    n\ Pi\ \((\[Theta] - \[Beta])\)/Log[\[Epsilon]]] + 
                  Sinh[n\ Pi\ \((\[Alpha] + \[Beta] - \[Theta])\)/
                        Log[\[Epsilon]]])\)/
              Sinh[n\ \[Pi]\ \[Alpha]/Log[\[Epsilon]]], {n, 1, 
            150}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.26"],

Cell[TextData[{
  "Along the edges of the cusp at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \[Beta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\  = \ \[Beta]\  + \ \[Alpha]\)]],
  ", this analytic solution can be seen to match the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\  = \ 1\  - \ r\^2\)]],
  ", as shown in Cell ",
  ButtonBox["6.27",
    ButtonData:>"Cell 6.27",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{\[Phi][r, \[Beta]], \[Phi][r, \[Beta] + \[Alpha]], 
          1 - r^2}, {r, 0.0001, 1}, PlotRange \[Rule] All, 
        AxesLabel \[Rule] {"\<r\>", "\<\>"}, 
        PlotLabel -> "\<\[Phi] along edges of cusp\>"];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.27"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237142 0.952476 0.014715 0.587363 [
[.21421 .00222 -9 -9 ]
[.21421 .00222 9 0 ]
[.4047 .00222 -9 -9 ]
[.4047 .00222 9 0 ]
[.5952 .00222 -9 -9 ]
[.5952 .00222 9 0 ]
[.7857 .00222 -9 -9 ]
[.7857 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01121 .13219 -18 -4.5 ]
[.01121 .13219 0 4.5 ]
[.01121 .24966 -18 -4.5 ]
[.01121 .24966 0 4.5 ]
[.01121 .36713 -18 -4.5 ]
[.01121 .36713 0 4.5 ]
[.01121 .48461 -18 -4.5 ]
[.01121 .48461 0 4.5 ]
[.01121 .60208 -6 -4.5 ]
[.01121 .60208 0 4.5 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21421 .01472 m
.21421 .02097 L
s
[(0.2)] .21421 .00222 0 1 Mshowa
.4047 .01472 m
.4047 .02097 L
s
[(0.4)] .4047 .00222 0 1 Mshowa
.5952 .01472 m
.5952 .02097 L
s
[(0.6)] .5952 .00222 0 1 Mshowa
.7857 .01472 m
.7857 .02097 L
s
[(0.8)] .7857 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07134 .01472 m
.07134 .01847 L
s
.11896 .01472 m
.11896 .01847 L
s
.16659 .01472 m
.16659 .01847 L
s
.26183 .01472 m
.26183 .01847 L
s
.30946 .01472 m
.30946 .01847 L
s
.35708 .01472 m
.35708 .01847 L
s
.45233 .01472 m
.45233 .01847 L
s
.49995 .01472 m
.49995 .01847 L
s
.54758 .01472 m
.54758 .01847 L
s
.64282 .01472 m
.64282 .01847 L
s
.69045 .01472 m
.69045 .01847 L
s
.73807 .01472 m
.73807 .01847 L
s
.83332 .01472 m
.83332 .01847 L
s
.88094 .01472 m
.88094 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02371 .13219 m
.02996 .13219 L
s
[(0.2)] .01121 .13219 1 0 Mshowa
.02371 .24966 m
.02996 .24966 L
s
[(0.4)] .01121 .24966 1 0 Mshowa
.02371 .36713 m
.02996 .36713 L
s
[(0.6)] .01121 .36713 1 0 Mshowa
.02371 .48461 m
.02996 .48461 L
s
[(0.8)] .01121 .48461 1 0 Mshowa
.02371 .60208 m
.02996 .60208 L
s
[(1)] .01121 .60208 1 0 Mshowa
.125 Mabswid
.02371 .04408 m
.02746 .04408 L
s
.02371 .07345 m
.02746 .07345 L
s
.02371 .10282 m
.02746 .10282 L
s
.02371 .16156 m
.02746 .16156 L
s
.02371 .19092 m
.02746 .19092 L
s
.02371 .22029 m
.02746 .22029 L
s
.02371 .27903 m
.02746 .27903 L
s
.02371 .3084 m
.02746 .3084 L
s
.02371 .33776 m
.02746 .33776 L
s
.02371 .3965 m
.02746 .3965 L
s
.02371 .42587 m
.02746 .42587 L
s
.02371 .45524 m
.02746 .45524 L
s
.02371 .51397 m
.02746 .51397 L
s
.02371 .54334 m
.02746 .54334 L
s
.02371 .57271 m
.02746 .57271 L
s
.25 Mabswid
.02371 0 m
.02371 .61803 L
s
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(along) show
111.000 13.000 moveto
(edges) show
147.000 13.000 moveto
(of) show
165.000 13.000 moveto
(cusp) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .60332 m
.06244 .60044 L
.08255 .59895 L
.08383 .5985 L
.08447 .59841 L
.08518 .59842 L
.08594 .59854 L
.08666 .59874 L
.08802 .59928 L
.0893 .5998 L
.09052 .60017 L
.09118 .60029 L
.09192 .60033 L
.0932 .60016 L
.09398 .59993 L
.09469 .59964 L
.09629 .59884 L
.09767 .5981 L
.09839 .59775 L
.09916 .59743 L
.09985 .59719 L
.10061 .59701 L
.1013 .59691 L
.10195 .59687 L
.10322 .59696 L
.10393 .59709 L
.10458 .59723 L
.10702 .59792 L
.10826 .59821 L
.10896 .59833 L
.10962 .5984 L
.11033 .59843 L
.11099 .59841 L
.11171 .59833 L
.11247 .59819 L
.11372 .59782 L
.1151 .59728 L
.11758 .59614 L
.11992 .59516 L
.12121 .59476 L
.12194 .59459 L
.12262 .59448 L
.12381 .59437 L
.12507 .59437 L
.12624 .59446 L
.1275 .59463 L
.12977 .59502 L
.13044 .59512 L
.13116 .59522 L
.13248 .59535 L
Mistroke
.13376 .59538 L
.13495 .59531 L
.13616 .59515 L
.13729 .59491 L
.13831 .59463 L
.13941 .59426 L
.14415 .59232 L
.14653 .59141 L
.14784 .59099 L
.14908 .59068 L
.15024 .59045 L
.15149 .59028 L
.15263 .59019 L
.15368 .59016 L
.15493 .59017 L
.15609 .59021 L
.15737 .59029 L
.15875 .59038 L
.16012 .59046 L
.16081 .59049 L
.16156 .59051 L
.1622 .59051 L
.16289 .5905 L
.16413 .59043 L
.16482 .59037 L
.16555 .59028 L
.16686 .59007 L
.16827 .58977 L
.16982 .58934 L
.17518 .58736 L
.17998 .58546 L
.18251 .58463 L
.18521 .58393 L
.1865 .58368 L
.18792 .58346 L
.18922 .5833 L
.19044 .58319 L
.19168 .5831 L
.19282 .58304 L
.1954 .58295 L
.19653 .58291 L
.19774 .58285 L
.19888 .58279 L
.19992 .58272 L
.20109 .58261 L
.2022 .58248 L
.20469 .58209 L
.20723 .58153 L
.20991 .58075 L
.21472 .579 L
Mistroke
.2204 .57665 L
.2256 .57465 L
.23043 .57315 L
.23502 .57211 L
.23986 .57132 L
.24515 .57059 L
.24975 .56984 L
.25464 .56876 L
.25927 .56738 L
.26345 .56585 L
.30354 .55128 L
.34211 .53634 L
.38313 .5185 L
.42264 .49956 L
.46063 .47729 L
.50108 .45563 L
.54001 .42965 L
.58139 .39949 L
.62125 .37149 L
.6596 .34145 L
.7004 .305 L
.73969 .2689 L
.77746 .23433 L
.81768 .19538 L
.85639 .15402 L
.89755 .10662 L
.9372 .05989 L
.97532 .0157 L
.97619 .01472 L
Mfstroke
.02381 .60332 m
.06244 .60044 L
.08255 .59895 L
.08383 .5985 L
.08447 .59841 L
.08518 .59842 L
.08594 .59854 L
.08666 .59874 L
.08802 .59928 L
.0893 .5998 L
.09052 .60017 L
.09118 .60029 L
.09192 .60033 L
.0932 .60016 L
.09398 .59993 L
.09469 .59964 L
.09629 .59884 L
.09767 .5981 L
.09839 .59775 L
.09916 .59743 L
.09985 .59719 L
.10061 .59701 L
.1013 .59691 L
.10195 .59687 L
.10322 .59696 L
.10393 .59709 L
.10458 .59723 L
.10702 .59792 L
.10826 .59821 L
.10896 .59833 L
.10962 .5984 L
.11033 .59843 L
.11099 .59841 L
.11171 .59833 L
.11247 .59819 L
.11372 .59782 L
.1151 .59728 L
.11758 .59614 L
.11992 .59516 L
.12121 .59476 L
.12194 .59459 L
.12262 .59448 L
.12381 .59437 L
.12507 .59437 L
.12624 .59446 L
.1275 .59463 L
.12977 .59502 L
.13044 .59512 L
.13116 .59522 L
.13248 .59535 L
Mistroke
.13376 .59538 L
.13495 .59531 L
.13616 .59515 L
.13729 .59491 L
.13831 .59463 L
.13941 .59426 L
.14415 .59232 L
.14653 .59141 L
.14784 .59099 L
.14908 .59068 L
.15024 .59045 L
.15149 .59028 L
.15263 .59019 L
.15368 .59016 L
.15493 .59017 L
.15609 .59021 L
.15737 .59029 L
.15875 .59038 L
.16012 .59046 L
.16081 .59049 L
.16156 .59051 L
.1622 .59051 L
.16289 .5905 L
.16413 .59043 L
.16482 .59037 L
.16555 .59028 L
.16686 .59007 L
.16827 .58977 L
.16982 .58934 L
.17518 .58736 L
.17998 .58546 L
.18251 .58463 L
.18521 .58393 L
.1865 .58368 L
.18792 .58346 L
.18922 .5833 L
.19044 .58319 L
.19168 .5831 L
.19282 .58304 L
.1954 .58295 L
.19653 .58291 L
.19774 .58285 L
.19888 .58279 L
.19992 .58272 L
.20109 .58261 L
.2022 .58248 L
.20469 .58209 L
.20723 .58153 L
.20991 .58075 L
.21472 .579 L
Mistroke
.2204 .57665 L
.2256 .57465 L
.23043 .57315 L
.23502 .57211 L
.23986 .57132 L
.24515 .57059 L
.24975 .56984 L
.25464 .56876 L
.25927 .56738 L
.26345 .56585 L
.30354 .55128 L
.34211 .53634 L
.38313 .5185 L
.42264 .49956 L
.46063 .47729 L
.50108 .45563 L
.54001 .42965 L
.58139 .39949 L
.62125 .37149 L
.6596 .34145 L
.7004 .305 L
.73969 .2689 L
.77746 .23433 L
.81768 .19538 L
.85639 .15402 L
.89755 .10662 L
.9372 .05989 L
.97532 .0157 L
.97619 .01472 L
Mfstroke
.02381 .60208 m
.02499 .60208 L
.02605 .60207 L
.02729 .60207 L
.02846 .60206 L
.03053 .60205 L
.03279 .60202 L
.03527 .60199 L
.0379 .60195 L
.04262 .60185 L
.04749 .60171 L
.05205 .60156 L
.06244 .60111 L
.07305 .6005 L
.08274 .59982 L
.10458 .59784 L
.12357 .59562 L
.14429 .59267 L
.18493 .58525 L
.22406 .57609 L
.26565 .56418 L
.30571 .55059 L
.34426 .53555 L
.38527 .51745 L
.42475 .49795 L
.46273 .4773 L
.50315 .45326 L
.54206 .42812 L
.58342 .39926 L
.62326 .36935 L
.66159 .33864 L
.70238 .30388 L
.74164 .26837 L
.77939 .23236 L
.8196 .19197 L
.85828 .15113 L
.89942 .10558 L
.93905 .05963 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Coooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;oooool4o`000003oa0@4?oooooooooo01gooooo001?ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<Oooool00ol0003oooooooooo`0Oooooo`00Coooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Vooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Ko
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<Oooool0
0ol0003oooooooooo`0Oooooo`00Coooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Voooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b037ooooo00?o
0000ooooooooool07oooool004oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00aooooo`03o`00
0?oooooooooo01oooooo001?ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Xooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@037ooooo00?o0000ooooooooool07ooo
ool004oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000aooooo`03o`000?oooooooooo01oooooo001?
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;oooool00omEEEGoIVIVo`00000Qooooo`00oooo
oomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooolhooooo`03oa0@4?l0003o000000?o
00002_ooool001kooooo00?o0000ooooooooool0ooooooljooooo`03o`000?oooooooooo00_ooooo
000Goooooooo0000>Ol0000;ooooo`03o`000?oooooooooo00_ooooo000Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00_ooooo000Nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=oooool2o`00
01?ooooo00?o0000oc8b<_oMgMd02oooool001kooooo00?o0000ooooooooool0oooooolTooooo`;o
00004oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Wooooo000Nooooo`03o`000?oooooooooo0?oo
oooo8oooool2o`0002?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool2o`0002Cooooo
000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0Sooooo`007_ooool0
0ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000oooo
ooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`?o0000oooooolOooooo`03
o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool2o`0002Sooooo
000Nooooo`03o`000?oooooooooo0?oooooo7Oooool2o`0002Wooooo000Nooooo`03o`000?oooooo
oooo0?oooooo7?ooool2o`0002[ooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool2o`00
02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool2o`0002cooooo000Nooooo`03o`00
0?oooooooooo0?oooooo6_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo0?oooooo6Ooo
ool2o`0002gooooo000Nooooo`03o`000?oooooooooo0?oooooo6?ooool2o`0002kooooo000Noooo
o`?o0000oooooolGooooo`;o0000;oooool001kooooo00?o0000ooooooooool0oooooolFooooo`;o
0000<?ooool001kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo02oooooo
000Nooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_ooool0
0ol0003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool001kooooo00?o0000oooo
ooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo
0_l0000eooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo0_l0000fooooo`007_ooool0
0ol0003oooooooooo`3oooooo`oooooo0_l0000gooooo`007_ooool3o`000?oooooo3_ooool2o`00
03Sooooo000Nooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`0gooooo`00
7_ooool00ol0003oooooooooo`3oooooo`gooooo0_l0000iooooo`007_ooool00ol0003ooooooooo
o`3oooooo`cooooo0_l0000jooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo0_l0000k
ooooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo0_l0000looooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3ooooo
o`[ooooo00?o0000ooooooooool0>oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0ooooool9
ooooo`03o`000?oooooooooo03cooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?oooooo2?ooool00ol0003oooooooooo`0m
ooooo`001?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3
o`000?oooooo1oooool00ol0003oooooooooo`0nooooo`001?ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3oooooo`Kooooo0_l00010
ooooo`001?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0?oooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooooooo
o`3oooooo`Gooooo00?o0000ooooooooool0@?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooo`Cooooo
00?o0000ooooooooool0@Oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`03o`000?oo
oooooooo04;ooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`13
ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool0A?ooool001ko
oooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`15ooooo`007_ooool3o`000?kooooo
00?o0000ooooooooool0A_ooool001kooooo00?o0000ooooooooool0oOooool00ol0003ooooooooo
o`17ooooo`007_ooool00ol0003oooooooooo`3looooo`03o`000?oooooooooo04Sooooo000Noooo
o`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool0BOooool001kooooo00?o0000oooooooo
ool0n_ooool00ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`3iooooo`03o`00
0?oooooooooo04_ooooo000Nooooo`03o`000?oooooooooo0?Sooooo00?o0000ooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`3fooooo`03o`000?oooooooooo04kooooo000Nooooo`?o0000mOooool00ol0003o
ooooooooo`1?ooooo`007_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo053ooooo
000Nooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool0DOooool001kooooo00?o0000
ooooooooool0l_ooool00ol0003oooooooooo`1Booooo`007_ooool00ol0003oooooooooo`3aoooo
o`03o`000?oooooooooo05?ooooo000Nooooo`03o`000?oooooooooo0?3ooooo00?o0000oooooooo
ool0E?ooool001kooooo00?o0000ooooooooool0koooool00ol0003oooooooooo`1Eooooo`007_oo
ool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo05Kooooo000Nooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool0Eoooool001kooooo0ol0003/ooooo`03o`000?oooooooooo
05Sooooo000Nooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool0FOooool001kooooo
00?o0000ooooooooool0j_ooool00ol0003oooooooooo`1Jooooo`007_ooool00ol0003ooooooooo
o`3Yooooo`03o`000?oooooooooo05_ooooo000Nooooo`03o`000?oooooooooo0>Oooooo0_l0001N
ooooo`007_ooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo05kooooo000Nooooo`03
o`000?oooooooooo0>Gooooo00?o0000ooooooooool0Goooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0i?ooool00ol0003oooooooooo`1Pooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0hoooool00ol0003o
ooooooooo`1Qooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o
0000h_ooool00ol0003oooooooooo`1Rooooo`001?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo
06?ooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo0>3ooooo00?o0000ooooooooool0I?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0goooool0
0ol0003oooooooooo`1Uooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001_ooool00ol0003oooooooooo`3Nooooo`03o`000?oooooooooo06Kooooo0004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooo
oooo0=gooooo00?o0000ooooooooool0Ioooool001kooooo00?o0000ooooooooool0foooool2o`00
06[ooooo000Nooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0J_ooool001kooooo
00?o0000ooooooooool0fOooool00ol0003oooooooooo`1[ooooo`007_ooool3o`000=Sooooo00?o
0000ooooooooool0K?ooool001kooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`1]
ooooo`007_ooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo06kooooo000Nooooo`03
o`000?oooooooooo0=Gooooo00?o0000ooooooooool0Koooool001kooooo00?o0000ooooooooool0
e?ooool00ol0003oooooooooo`1`ooooo`007_ooool00ol0003oooooooooo`3Cooooo`03o`000?oo
oooooooo077ooooo000Nooooo`03o`000?oooooooooo0=;ooooo00?o0000ooooooooool0L_ooool0
01kooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`1cooooo`007_ooool00ol0003o
ooooooooo`3?ooooo`;o0000M_ooool001kooooo0ol0003>ooooo`03o`000?oooooooooo07Kooooo
000Nooooo`03o`000?oooooooooo0<gooooo00?o0000ooooooooool0Moooool001kooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`1hooooo`007_ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo0<[ooooo00?o0000oooooooo
ool0N_ooool001kooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`1kooooo`007_oo
ool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooo
oooo0<Oooooo00?o0000ooooooooool0OOooool001kooooo00?o0000ooooooooool0a_ooool00ol0
003oooooooooo`1nooooo`007_ooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo07oo
oooo000Nooooo`?o0000`oooool2o`0008;ooooo000Nooooo`03o`000?oooooooooo0<;ooooo0_l0
0023ooooo`007_ooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo08?ooooo000Noooo
o`03o`000?oooooooooo0;oooooo0_l00026ooooo`007_ooool00ol0003oooooooooo`2nooooo`;o
0000Qoooool001kooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`27ooooo`001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01Oooool00ol0003oooooooooo`2kooooo`;o0000R_ooool000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000oooo
ooooool0^_ooool2o`0008_ooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`2;
ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@05ooooo`?o0000]oooool2o`0008kooooo0004ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0]_ooool2o`0008oooooo
0004ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`00
0?oooooooooo0;Gooooo00?o0000ooooooooool0Soooool000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0/oooool2o`0009;ooooo
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03
o`000?oooooooooo0;;ooooo0_l0002Cooooo`007_ooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo09?ooooo000Nooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0U?oo
ool001kooooo00?o0000ooooooooool0[_ooool2o`0009Oooooo000Nooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool0Uoooool001kooooo0ol0002/ooooo`03o`000?oooooooooo09So
oooo000Nooooo`03o`000?oooooooooo0:[ooooo0_l0002Kooooo`007_ooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo09_ooooo000Nooooo`03o`000?oooooooooo0:Oooooo0_l0002N
ooooo`007_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo09kooooo000Nooooo`03
o`000?oooooooooo0:Cooooo0_l0002Qooooo`007_ooool00ol0003oooooooooo`2Sooooo`03o`00
0?oooooooooo0:7ooooo000Nooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0X_oo
ool001kooooo00?o0000ooooooooool0X?ooool2o`000:Gooooo000Nooooo`?o0000Woooool00ol0
003oooooooooo`2Uooooo`007_ooool00ol0003oooooooooo`2Mooooo`;o0000Z?ooool001kooooo
00?o0000ooooooooool0Voooool2o`000:[ooooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0
002[ooooo`007_ooool00ol0003oooooooooo`2Hooooo`;o0000[Oooool001kooooo00?o0000oooo
ooooool0U_ooool3o`000:kooooo000Nooooo`03o`000?oooooooooo09Gooooo0_l0002`ooooo`00
7_ooool00ol0003oooooooooo`2Cooooo`?o0000/Oooool001kooooo00?o0000ooooooooool0TOoo
ool3o`000;?ooooo000Nooooo`?o0000T?ooool3o`000;Cooooo000Nooooo`03o`000?oooooooooo
08kooooo0ol0002fooooo`007_ooool00ol0003oooooooooo`2=ooooo`;o0000^?ooool001kooooo
00?o0000ooooooooool0Roooool2o`000;[ooooo000Nooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0^_ooool001kooooo00?o0000ooooooooool0R?ooool2o`000;gooooo000Noooo
o`03o`000?oooooooooo08Kooooo0_l0002oooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`24
ooooo`?o0000`?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0P_ooool3o`000<;ooooo0004
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo
0ol00021ooooo`;o0000a?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`1oooooo`;o0000a_ooool000Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0
003oooooooooo`1mooooo`;o0000b?ooool000Cooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`1kooooo`;o0000b_ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`1iooooo`?o0000boooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`1gooooo`?o0000
cOooool001kooooo00?o0000ooooooooool0MOooool3o`000<oooooo000Nooooo`03o`000?oooooo
oooo07?ooooo0ol0003Aooooo`007_ooool00ol0003oooooooooo`1aooooo`?o0000doooool001ko
oooo0ol0001_ooooo`?o0000eOooool001kooooo00?o0000ooooooooool0KOooool3o`000=Oooooo
000Nooooo`03o`000?oooooooooo06_ooooo0ol0003Iooooo`007_ooool00ol0003oooooooooo`1Y
ooooo`?o0000foooool001kooooo00?o0000ooooooooool0I_ooool3o`000=kooooo000Nooooo`03
o`000?oooooooooo06Cooooo0_l0003Qooooo`007_ooool00ol0003oooooooooo`1Qooooo`?o0000
hoooool001kooooo00?o0000ooooooooool0Goooool3o`000>Gooooo000Nooooo`03o`000?oooooo
oooo05cooooo1?l0003Wooooo`007_ooool3o`0005[ooooo0ol0003Zooooo`007_ooool00ol0003o
ooooooooo`1Hooooo`?o0000k?ooool001kooooo00?o0000ooooooooool0EOooool4o`000>kooooo
000Nooooo`03o`000?oooooooooo05?ooooo0ol0003aooooo`007_ooool00ol0003oooooooooo`1@
ooooo`Co0000loooool001kooooo00?o0000ooooooooool0COooool4o`000?Kooooo000Nooooo`03
o`000?oooooooooo04[ooooo1?l0003iooooo`007_ooool00ol0003oooooooooo`17ooooo`Co0000
o?ooool001kooooo00?o0000ooooooooool0A?ooool4o`000?oooooo000Nooooo`03o`000?oooooo
oooo03oooooo1_l0003oooooo`?ooooo000Nooooo`?o0000??ooool5o`000?oooooo1oooool001ko
oooo00?o0000ooooooooool0>?ooool6o`000?oooooo2_ooool001kooooo00?o0000ooooooooool0
<oooool6o`000?oooooo3oooool001kooooo00?o0000ooooooooool0;_ooool8o`000?oooooo4_oo
ool001kooooo00?o0000ooooooooool0:Oooool6o`000?oooooo6Oooool001kooooo00?o0000oooo
ooooool09?ooool8o`000?oooooo7?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo01cooooo0ol000000ooooooo0000o`000003o`000?oooooo8oooool001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`go0000oooooolWooooo`005ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo4_l00003ooooo`;o0000oooo
ool^ooooo`005oooool00ol0003oooooooooo`04ooooo`_o0000oooooom0ooooo`005oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom8ooooo`005Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00UOooool01OlQ8B7o0000o`000?m4
A4CogMgM01Sooooo00Go8B4Qo`000?l0003oA4A4omgMg@15ooooo`04oa0@4?l0003o0000o`0006So
oooo001Wooooo`03o`000?oooooooooo02kooooo00?oMgMgoc8b<_ooool06_ooool00omgMgOo<S8b
ooooo`15ooooo`03o`000?oooooooooo06Sooooo001Wooooo`03oa0@4?oMgMgooooo02oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo06Sooooo001U
ooooo`05olc<c?l@413o0000o`000?n7QhL02_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;o
oooo1Ol00003ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o0000o`000?oo
ool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00007ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj0_ooool03_o^k^koEEEEo`000?l0003oV9RHo`000?l@413oooooonk^k_mEEEGo
0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Ko410@oc8b
<_l0003o0000oa0@4?nYZJT7ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool00ol@413o
0000o`000002o`000003oa0@4?oooooooooo00Oooooo00GoIVIVo`000?l0003oA4A4olc<c003oooo
o`09oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o<S8b00;o000000?o410@ojVYZOooool0
0_ooool01_l0003oMgMgo`000?l0003oEEEEonk^kVGooooo001Uooooo`06ob4Q8On7QhOo<S8bojVY
ZOm4A4CoQhN72Oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000ooooooooool00ooo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ooooooooooooooooo`000002oooo
o`06oeEEEOmgMgOoooooonk^k_mEEEGo00001oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;o
oooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo0000
0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00Ko0000ojVYZOoooooooooookZj^_l0
0007ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`09ooooo`06
ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Ko
0000ojVYZOoooooooooookZj^_l00003ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEEIOooool0
06Gooooo00Ko0000oooooomVIVKoQhN7omgMgOl@4109ooooo`05oa0@4?n7QhOoooooonk^k_l00000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool00ol0
003oooooooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4003ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0Hooo
ool006Gooooo00Ko410@omgMgOmgMgOoMgMgooooool00009ooooo`03okZj^_l@413o000000;o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool6o`00
00;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`06o`000?ooooooooooooooooo^k^ko
00000_ooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h7ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo06?ooooo001Uooooo`06ojVY
ZOm4A4CoV9RHodA4A?nHV9So410@3?ooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo
00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?n7QhOoooooojVYZOl00000
0_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Oooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00001oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool02Ooo
ool01_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?nj^[[oooooonk^k_mgMgOo00000oooool01_l0003oEEEEonk^k_ooooooMgMgofIVIVGo
oooo001Vooooo`05oiRHV?l0003o0000oa0@4?o<c<`02_ooool01?lb<S;o0000o`000?nHV9P5oooo
o`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0
003oMgMg00;o000000[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@1_ooool0
1_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002oooo
o`0:onk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?ooooook^k^oeEEE@;o000000KoA4A4onk^k_oo
ooooooooojVYZOlQ8B42o`000003oc8b<_l0003ooooo00Kooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`03oa0@4?l0003o000000?o00002?ooool01_o^k^koIVIVo`000?l0003oA4A4o`00
00;ooooo00Co410@o`000?oooooooooo0_l00002ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000
0_ooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo06Cooooo001Wooooo`03okZj^_lb
<S;ooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo08gooooo001Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Wooooo`03oa0@4?nj^[[ooooo08gooooo001looooo`03oa0@4?l0003o0000
02kooooo0_l0000Yooooo`04okZj^_l@413o0000oa0@48cooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.104687, -0.0829537, \
0.00422592, 0.00685281}}]
}, Open  ]],

Cell[TextData[{
  "However,  along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\  = \ 3\ \[Pi]/2\)]],
  " (i.e. the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-y\)\)]],
  " axis), the solution has a singular slope near the origin, as shown in \
Cell ",
  ButtonBox["6.28",
    ButtonData:>"Cell 6.28",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\[Phi][r, \[Beta]\  + \ \[Alpha]/2], {r, 0.0001, 1}, 
        PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.28"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237142 0.952476 0.0147151 0.592055 [
[.21421 .00222 -9 -9 ]
[.21421 .00222 9 0 ]
[.4047 .00222 -9 -9 ]
[.4047 .00222 9 0 ]
[.5952 .00222 -9 -9 ]
[.5952 .00222 9 0 ]
[.7857 .00222 -9 -9 ]
[.7857 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01121 .13313 -18 -4.5 ]
[.01121 .13313 0 4.5 ]
[.01121 .25154 -18 -4.5 ]
[.01121 .25154 0 4.5 ]
[.01121 .36995 -18 -4.5 ]
[.01121 .36995 0 4.5 ]
[.01121 .48836 -18 -4.5 ]
[.01121 .48836 0 4.5 ]
[.01121 .60677 -6 -4.5 ]
[.01121 .60677 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21421 .01472 m
.21421 .02097 L
s
[(0.2)] .21421 .00222 0 1 Mshowa
.4047 .01472 m
.4047 .02097 L
s
[(0.4)] .4047 .00222 0 1 Mshowa
.5952 .01472 m
.5952 .02097 L
s
[(0.6)] .5952 .00222 0 1 Mshowa
.7857 .01472 m
.7857 .02097 L
s
[(0.8)] .7857 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07134 .01472 m
.07134 .01847 L
s
.11896 .01472 m
.11896 .01847 L
s
.16659 .01472 m
.16659 .01847 L
s
.26183 .01472 m
.26183 .01847 L
s
.30946 .01472 m
.30946 .01847 L
s
.35708 .01472 m
.35708 .01847 L
s
.45233 .01472 m
.45233 .01847 L
s
.49995 .01472 m
.49995 .01847 L
s
.54758 .01472 m
.54758 .01847 L
s
.64282 .01472 m
.64282 .01847 L
s
.69045 .01472 m
.69045 .01847 L
s
.73807 .01472 m
.73807 .01847 L
s
.83332 .01472 m
.83332 .01847 L
s
.88094 .01472 m
.88094 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02371 .13313 m
.02996 .13313 L
s
[(0.2)] .01121 .13313 1 0 Mshowa
.02371 .25154 m
.02996 .25154 L
s
[(0.4)] .01121 .25154 1 0 Mshowa
.02371 .36995 m
.02996 .36995 L
s
[(0.6)] .01121 .36995 1 0 Mshowa
.02371 .48836 m
.02996 .48836 L
s
[(0.8)] .01121 .48836 1 0 Mshowa
.02371 .60677 m
.02996 .60677 L
s
[(1)] .01121 .60677 1 0 Mshowa
.125 Mabswid
.02371 .04432 m
.02746 .04432 L
s
.02371 .07392 m
.02746 .07392 L
s
.02371 .10352 m
.02746 .10352 L
s
.02371 .16273 m
.02746 .16273 L
s
.02371 .19233 m
.02746 .19233 L
s
.02371 .22193 m
.02746 .22193 L
s
.02371 .28114 m
.02746 .28114 L
s
.02371 .31074 m
.02746 .31074 L
s
.02371 .34035 m
.02746 .34035 L
s
.02371 .39955 m
.02746 .39955 L
s
.02371 .42915 m
.02746 .42915 L
s
.02371 .45876 m
.02746 .45876 L
s
.02371 .51796 m
.02746 .51796 L
s
.02371 .54756 m
.02746 .54756 L
s
.02371 .57717 m
.02746 .57717 L
s
.25 Mabswid
.02371 0 m
.02371 .61803 L
s
.5 Mabswid
.02381 .60332 m
.02605 .59115 L
.02846 .58196 L
.03279 .56871 L
.04262 .54502 L
.06244 .5081 L
.10458 .44878 L
.14603 .4026 L
.18596 .36477 L
.22437 .3327 L
.26524 .30214 L
.30459 .27549 L
.34242 .252 L
.38271 .22892 L
.42148 .20834 L
.46271 .18798 L
.50241 .16968 L
.54061 .15315 L
.58125 .13659 L
.62038 .12156 L
.66196 .10647 L
.70203 .09272 L
.74058 .08014 L
.78158 .06742 L
.82107 .05576 L
.85904 .04504 L
.89947 .03413 L
.93838 .02408 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00DOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0=?ooool4o`000003oa0@4?oooooooooo00Kooooo001Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40=_ooool00ol0003oooooooooo`08ooooo`00DOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002_o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000=_ooool0
0ol0003oooooooooo`08ooooo`00DOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0[oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03Kooooo00?o
0000ooooooooool02?ooool0057ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002go
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00fooooo`03o`00
0?oooooooooo00Sooooo001Aooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000]ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0]ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Kooooo00?o0000ooooooooool02?oo
ool0057ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000;Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000fooooo`03o`000?oooooooooo00Sooooo001A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=?ooool00omEEEGoIVIVo`00000:ooooo`00oooo
oomYooooo`006oooool00ol0003oooooooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo
0?ooooooBoooool001_ooooo00?o0000ooooooooool0oooooom;ooooo`006oooool00ol0003ooooo
ooooo`3ooooood_ooooo000Kooooo`03o`000?oooooooooo0?ooooooBoooool001?oooooool0001D
o`0000;ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool4o`00
00;ooooo00?o0000ooooooooool02?ooool001_ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0cooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`006oooool00ol0003ooooo
ooooo`3ooooooc;ooooo1?l0000Eooooo`006oooool00ol0003oooooooooo`3oooooobgooooo1Ol0
000Iooooo`006oooool00ol0003oooooooooo`3oooooobSooooo1Ol0000Nooooo`006oooool00ol0
003oooooooooo`3oooooobCooooo1?l0000Sooooo`006oooool00ol0003oooooooooo`3oooooob7o
oooo0ol0000Wooooo`006oooool00ol0003oooooooooo`3ooooooakooooo0ol0000Zooooo`006ooo
ool00ol0003oooooooooo`3ooooooa_ooooo0ol0000]ooooo`006oooool3o`000?oooooo5oooool4
o`00033ooooo000Kooooo`03o`000?oooooooooo0?oooooo4_ooool5o`0003Cooooo000Kooooo`03
o`000?oooooooooo0?oooooo3_ooool4o`0003Wooooo000Kooooo`03o`000?oooooooooo0?oooooo
2_ooool4o`0003gooooo000Kooooo`03o`000?oooooooooo0?oooooo1oooool3o`00047ooooo000K
ooooo`03o`000?oooooooooo0?oooooo1?ooool3o`0004Cooooo000Kooooo`03o`000?oooooooooo
0?oooooo0Oooool3o`0004Oooooo000Kooooo`03o`000?oooooooooo0?gooooo0ol0001:ooooo`00
6oooool00ol0003oooooooooo`3jooooo`?o0000COooool001_ooooo00?o0000ooooooooool0mooo
ool3o`00053ooooo000Kooooo`?o0000m?ooool3o`0005?ooooo000Kooooo`03o`000?oooooooooo
0?7ooooo0ol0001Fooooo`006oooool00ol0003oooooooooo`3^ooooo`?o0000FOooool001_ooooo
00?o0000ooooooooool0joooool3o`0005cooooo000Kooooo`03o`000?oooooooooo0>Sooooo0ol0
001Oooooo`006oooool00ol0003oooooooooo`3Uooooo`?o0000H_ooool001_ooooo00?o0000oooo
ooooool0h_ooool3o`0006Gooooo000Kooooo`03o`000?oooooooooo0=oooooo0ol0001Xooooo`00
6oooool00ol0003oooooooooo`3Looooo`?o0000Joooool001_ooooo00?o0000ooooooooool0fOoo
ool3o`0006kooooo000Kooooo`?o0000e_ooool3o`00077ooooo000Kooooo`03o`000?oooooooooo
0=Cooooo0_l0001dooooo`006oooool00ol0003oooooooooo`3Aooooo`?o0000M_ooool001_ooooo
00?o0000ooooooooool0c_ooool3o`0007Wooooo000Kooooo`03o`000?oooooooooo0<_ooooo0ol0
001looooo`006oooool00ol0003oooooooooo`38ooooo`?o0000Ooooool001_ooooo00?o0000oooo
ooooool0a_ooool2o`0008;ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001_ooool00ol0003oooooooooo`33ooooo`?o0000Q?ooool00005ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0<3ooooo0ol00027ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool0__ooool2o`0008[ooooo00001Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000;_ooooo0ol0002<ooooo`0000Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^Oooool2
o`0008oooooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2fooooo`?o0000TOooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0/oooool3o`0009Cooooo0000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`00
0?oooooooooo0;3ooooo0ol0002Gooooo`006oooool00ol0003oooooooooo`2]ooooo`?o0000V_oo
ool001_ooooo00?o0000ooooooooool0Zoooool2o`0009gooooo000Kooooo`03o`000?oooooooooo
0:Wooooo0_l0002Oooooo`006oooool00ol0003oooooooooo`2Wooooo`;o0000XOooool001_ooooo
00?o0000ooooooooool0Y?ooool3o`000:?ooooo000Kooooo`?o0000X_ooool2o`000:Kooooo000K
ooooo`03o`000?oooooooooo0:3ooooo0_l0002Xooooo`006oooool00ol0003oooooooooo`2Noooo
o`;o0000Z_ooool001_ooooo00?o0000ooooooooool0W?ooool2o`000:cooooo000Kooooo`03o`00
0?oooooooooo09[ooooo0_l0002^ooooo`006oooool00ol0003oooooooooo`2Gooooo`?o0000/?oo
ool001_ooooo00?o0000ooooooooool0UOooool2o`000;?ooooo000Kooooo`03o`000?oooooooooo
09?ooooo0_l0002eooooo`006oooool00ol0003oooooooooo`2Aooooo`;o0000]oooool001_ooooo
00?o0000ooooooooool0Soooool2o`000;Wooooo000Kooooo`?o0000SOooool2o`000;_ooooo000K
ooooo`03o`000?oooooooooo08_ooooo0_l0002mooooo`006oooool00ol0003oooooooooo`29oooo
o`;o0000_oooool001_ooooo00?o0000ooooooooool0Qoooool2o`000<7ooooo000Kooooo`03o`00
0?oooooooooo08Gooooo0_l00033ooooo`006oooool00ol0003oooooooooo`23ooooo`;o0000aOoo
ool001_ooooo00?o0000ooooooooool0POooool2o`000<Oooooo000Kooooo`03o`000?oooooooooo
07oooooo0_l00039ooooo`006oooool00ol0003oooooooooo`1mooooo`;o0000boooool001_ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`3;ooooo`006oooool3o`0007[ooooo0_l0
003>ooooo`006oooool00ol0003oooooooooo`1hooooo`;o0000d?ooool001_ooooo00?o0000oooo
ooooool0M_ooool2o`000=;ooooo000Kooooo`03o`000?oooooooooo07Cooooo0_l0003Dooooo`00
6oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0=Cooooo000Kooooo`03o`000?oo
oooooooo077ooooo0_l0003Gooooo`006oooool00ol0003oooooooooo`1_ooooo`;o0000fOooool0
0005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo06gooooo0_l0003Kooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0foooool00005oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000
ooooooooool0J_ooool2o`000=kooooo00001Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool3o`0006Sooooo0_l0003Pooooo`0000Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`3Pooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0IOooool2o`000>?ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Sooooo`;o0000iOooool00005onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0iOooool001_ooooo00?o0000ooooooooool0H?ooool2o`000>Sooooo000K
ooooo`03o`000?oooooooooo05kooooo0_l0003Zooooo`006oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo0>[ooooo000Kooooo`03o`000?oooooooooo05_ooooo0_l0003]ooooo`00
6oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0>gooooo000Kooooo`?o0000F?oo
ool2o`000?3ooooo000Kooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0l?ooool0
01_ooooo00?o0000ooooooooool0EOooool2o`000??ooooo000Kooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0loooool001_ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`3dooooo`006oooool00ol0003oooooooooo`1Aooooo`;o0000moooool001_ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`3gooooo`006oooool00ol0003oooooooooo`1>oooo
o`;o0000n_ooool001_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3jooooo`00
6oooool00ol0003oooooooooo`1;ooooo`;o0000oOooool001_ooooo0ol0001:ooooo`03o`000?oo
oooooooo0?gooooo000Kooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0o_ooool0
01_ooooo00?o0000ooooooooool0Aoooool2o`000?oooooo0_ooool001_ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`3oooooo`;ooooo000Kooooo`03o`000?oooooooooo04Cooooo
0_l0003oooooo`Gooooo000Kooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0oooo
ool5ooooo`006oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0?oooooo1_ooool0
01_ooooo00?o0000ooooooooool0@?ooool2o`000?oooooo2Oooool001_ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`3oooooo`Wooooo000Kooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0ooooool:ooooo`006oooool3o`0003gooooo00?o0000ooooooooool0oooo
ool;ooooo`006oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0?oooooo3?ooool0
01_ooooo00?o0000ooooooooool0>_ooool2o`000?oooooo3oooool001_ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`3oooooo`oooooo000Kooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0ooooool@ooooo`006oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo0?oooooo4Oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3o
oooooa;ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0?oooooo4ooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooooolDooooo`0000Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo0?oooooo5Oooool00005o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000booooo`03o`000?oooooooooo
0?oooooo5_ooool00005o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3ooooooaOooooo00001Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo0?oooooo6?ooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooooolI
ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`3ooooooa[ooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0oooooolKooooo`006oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo0?oooooo7?ooool001_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3ooooooagooooo000Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
oooooolNooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0?oooooo7ooo
ool001_ooooo0ol0000Xooooo`03o`000?oooooooooo0?oooooo8?ooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`3oooooob7ooooo000Kooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0oooooolQooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo0?oooooo8_ooool001_ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`3oooooob?ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0oooooolT
ooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo9Oooool001_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooobKooooo000Kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0oooooolWooooo`006oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0?oooooo:?ooool001_ooooo0ol0000Oooooo`03o`000?oooooo
oooo0?oooooo:Oooool001_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3ooooo
ob[ooooo000Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0ooooool[ooooo`00
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo;?ooool001_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`3oooooobgooooo000Kooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0ooooool^ooooo`006oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo0?oooooo;oooool001_ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`3ooooooboooooo000Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
ooooool`ooooo`006oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo<Ooo
ool001_ooooo0ol0000Fooooo`03o`000?oooooooooo0?oooooo<_ooool001_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`3ooooooc;ooooo000Kooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0oooooolcooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0?oooooo=?ooool001_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`3oooooocGooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0oooooole
ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo=_ooool00005
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolgooooo`0000GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3oooooocSooooo00001Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0oooooolhooooo`0000Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801_ooool3o`0000oooooo00?o0000ooooooooool0ooooooliooooo`00
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo>_ooool00005oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3ooooooc_ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooo
oolkooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo??ooool001_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3oooooocgooooo000Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0oooooolnooooo`006oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0?oooooo?_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`3oooooocoooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
ooooooloooooo`006oooool3o`0000Sooooo00?o0000ooooooooool0oooooom0ooooo`006oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo@?ooool001_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`3ooooood7ooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom1ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@Oooool001_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooood;ooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom2
ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@oooool001_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood?ooooo000Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom4ooooo`006oooool3o`0000Cooooo00?o
0000ooooooooool0oooooom4ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooAOooool001_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
odGooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooom6ooooo`00
6oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooA_ooool001_ooooo00Go
0000ooooooooooooooooo`00003oooooodWooooo000Kooooo`05o`000?ooooooooooooooool00000
oooooom9ooooo`006oooool01?l0003oooooooooool0003ooooood[ooooo000Kooooo`04o`000?oo
ooooooooo`000?ooooooB_ooool001_ooooo00Co0000oooooooooooo0000oooooom:ooooo`006ooo
ool3o`000?ooooooBoooool001_ooooo00?o0000ooooool00000oooooom;ooooo`006oooool00ol0
003oooooo`00003ooooood_ooooo000Kooooo`03o`000?oooooo00000?ooooooBoooool001_ooooo
0_l0003oooooodcooooo000Kooooo`;o0000oooooom<ooooo`006oooool2o`000?ooooooC?ooool0
017ooooo1?l000000ol@413oooooooooo`03ooooo`;o0000oooooom<ooooo`004oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo0ol0
003ooooood_ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom;
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooBoooool001?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood_ooooo000Aooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The singularity in ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Phi]/\[PartialD]r\)]],
  " is expected near the point of a cusp, as surface charge accumulates at \
such points [see Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:43"},
    ButtonStyle->"Hyperlink"],
  ", Exercise (5)(b)].  This singular behavior will make it difficult to find \
a convergent numerical solution using the Galerkin method."
}], "Text"],

Cell[TextData[{
  "\tNevertheless, we will now attempt a Galerkin solution.  First, we must \
choose basis functions. These functions must be zero on the boundary. \
However, if we were to use the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y) = \(\(y\)\(-\)\) | x | \)]],
  "  to define the basis functions via Eq. ",
  ButtonBox["(6.1.8)",
    ButtonData:>"(6.1.8)",
    ButtonStyle->"Hyperlink"],
  ",  grave problems would develop in the Galerkin method. Because gradients \
of the ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(m\ n\)\)]],
  " are required in the solution, the result would exhibit a singularity \
along ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and strong Gibbs phenomena throughout the domain.  "
}], "Text"],

Cell[TextData[{
  "\tWhat we need instead is a different function ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y)\)]],
  " that equals zero on the domain boundary, but is not singular, except at \
",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0)\)\)]],
  ". Such functions do exist (after all, the solution of Poisson's equation \
is one such function). One simple example is"
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_2\)(x, y)\  = \ 
        y\  - \ \@\(\((1 - a)\)\ x\^2 + a\ y\^2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < a < 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "It is easy to see that this function equals zero only along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(\(|\)\(x\)\(|\)\)\)]],
  ", but the function is singular only at  ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\) = \((0, 0)\)\)]],
  ".  If we use this choice in the Galerkin method, we can find a convergent \
solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ", although the convergence is slow, as we will see. The code is given \
below. Note the use of symmetry in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " when defining the basis functions and the inner product: the solution is \
symmetric in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so we choose basis functions that have this symmetry, and we integrate \
only over the right half of the domain."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          define\ the\ curves\ that\ determine\ the\ \(\(boundary\)\(:\)\)\ *) \
\),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", " ", 
      RowBox[{
        RowBox[{\(z[1, x_, y_]\  = \ x^2\  + \ y^2\  - 1;\), 
          "\[IndentingNewLine]", \(z[2, x_, y_]\  = \ \ y - 
                Sqrt[3  x^2/4\  + y^2/4]\ ;\), " ", "\[IndentingNewLine]", 
          StyleBox[\( (*\ define\ the\ charge\ density\ \ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\[IndentingNewLine]", \(\[Rho][x_, y_]\  = \ 0;\), 
          "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\[IndentingNewLine]", \(u[x_, y_]\  = \ 1 - \((x^2\  + \ y^2)\);\),
           "\[IndentingNewLine]", 
          RowBox[{
            StyleBox["(*",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            RowBox[{
              StyleBox["define",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["the",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["inner",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["product",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["using",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["Boole",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox["notation",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
                StyleBox["(",
                  FontColor->RGBColor[1, 0, 0]], 
                RowBox[{
                  StyleBox["Mathematica",
                    FontSlant->"Italic",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox["4.1",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], 
                  StyleBox["only",
                    FontColor->RGBColor[1, 0, 0]]}], 
                StyleBox[")",
                  FontColor->RGBColor[1, 0, 0]]}]}], " ", 
            StyleBox["*)",
              FontColor->RGBColor[1, 0, 0]]}], 
          "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
            2  NIntegrate[
                f\ g\ Boole[
                    z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
                      z[2, x, y] \[LessEqual] \ 0], {x, 0, 
                  Infinity}, {y, \(-Infinity\), Infinity}, 
                MaxRecursion \[Rule] 10]\)}], " ", ";"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.29"],

Cell[TextData[{
  "Numerical integration is now the fastest approach to determining the inner \
products. Even so, the equations take some time to evaluate for the chosen \
case of ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 3\)\)]],
  ".  (Each equation requires 16 two-dimensional numerical integrals to be \
evaluated, and there are 16 equations for the 16 Fourier coefficients.) The \
result is plotted in Cell ",
  ButtonBox["6.31",
    ButtonData:>"Cell 6.31",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(galerkin[3, 3, 2];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.30"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-3.504776182717489`\)\ \
c[0, 0] + 1.6350924463673526`\ c[0, 1] - 1.0227526155716995`\ c[0, 2] + 
            0.6779166577308993`\ c[0, 3] - 0.8677105081043167`\ c[1, 0] + 
            0.2723216680602963`\ c[1, 1] - 0.14866289229494548`\ c[1, 2] + 
            0.08227982270270344`\ c[1, 3] - 0.3806724524876043`\ c[2, 0] + 
            0.09300676803096145`\ c[2, 1] - 0.04761933121550303`\ c[2, 2] + 
            0.022885110525260842`\ c[2, 3] - 0.20807846879270914`\ c[3, 0] + 
            0.04182645159569168`\ c[3, 1] - 0.020610270712650886`\ c[3, 2] + 
            0.008758208032821293`\ c[3, 3] == 2.598240282383346`\)\),
      SequenceForm[ "eq", {0, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -3.5047761827174888, 
              c[ 0, 0]], 
            Times[ 1.6350924463673526, 
              c[ 0, 1]], 
            Times[ -1.0227526155716995, 
              c[ 0, 2]], 
            Times[ 0.67791665773089926, 
              c[ 0, 3]], 
            Times[ -0.86771050810431671, 
              c[ 1, 0]], 
            Times[ 0.27232166806029628, 
              c[ 1, 1]], 
            Times[ -0.14866289229494548, 
              c[ 1, 2]], 
            Times[ 0.08227982270270344, 
              c[ 1, 3]], 
            Times[ -0.38067245248760428, 
              c[ 2, 0]], 
            Times[ 0.093006768030961445, 
              c[ 2, 1]], 
            Times[ -0.047619331215503033, 
              c[ 2, 2]], 
            Times[ 0.022885110525260842, 
              c[ 2, 3]], 
            Times[ -0.20807846879270914, 
              c[ 3, 0]], 
            Times[ 0.041826451595691677, 
              c[ 3, 1]], 
            Times[ -0.020610270712650886, 
              c[ 3, 2]], 
            Times[ 0.0087582080328212925, 
              c[ 3, 3]]], 2.5982402823833461]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(1.6350925239061564`\ c[
                0, 0] - 1.2763198687162909`\ c[0, 1] + 
            0.8805203912687791`\ c[0, 2] - 0.6514869846919767`\ c[0, 3] + 
            0.27232166952168974`\ c[1, 0] - 0.1942256758862964`\ c[1, 1] + 
            0.10803183020642494`\ c[1, 2] - 0.07179909577063671`\ c[1, 3] + 
            0.09300676723714274`\ c[2, 0] - 0.06395972617819998`\ c[2, 1] + 
            0.03020060806200805`\ c[2, 2] - 0.01880516404465241`\ c[2, 3] + 
            0.041826451605907915`\ c[3, 0] - 0.028204153960637898`\ c[3, 1] + 
            0.011589116698569213`\ c[3, 2] - 
            0.006902689595527565`\ c[3, 3] == \(-0.889269023371542`\)\)\),
      SequenceForm[ "eq", {0, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 1.6350925239061564, 
              c[ 0, 0]], 
            Times[ -1.2763198687162909, 
              c[ 0, 1]], 
            Times[ 0.88052039126877912, 
              c[ 0, 2]], 
            Times[ -0.65148698469197674, 
              c[ 0, 3]], 
            Times[ 0.27232166952168974, 
              c[ 1, 0]], 
            Times[ -0.19422567588629641, 
              c[ 1, 1]], 
            Times[ 0.10803183020642494, 
              c[ 1, 2]], 
            Times[ -0.071799095770636714, 
              c[ 1, 3]], 
            Times[ 0.09300676723714274, 
              c[ 2, 0]], 
            Times[ -0.063959726178199977, 
              c[ 2, 1]], 
            Times[ 0.030200608062008048, 
              c[ 2, 2]], 
            Times[ -0.018805164044652409, 
              c[ 2, 3]], 
            Times[ 0.041826451605907915, 
              c[ 3, 0]], 
            Times[ -0.028204153960637898, 
              c[ 3, 1]], 
            Times[ 0.011589116698569213, 
              c[ 3, 2]], 
            Times[ -0.0069026895955275648, 
              c[ 3, 3]]], -0.88926902337154201]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1.0227526177521447`\)\
\ c[0, 0] + 0.880520394658569`\ c[0, 1] - 0.7073510935828231`\ c[0, 2] + 
            0.5575671460249609`\ c[0, 3] - 0.14866289134783212`\ c[1, 0] + 
            0.10803183570004865`\ c[1, 1] - 0.07824009300468761`\ c[1, 2] + 
            0.0541742488679077`\ c[1, 3] - 0.04761933173745078`\ c[2, 0] + 
            0.030200608308507737`\ c[2, 1] - 0.020548648043905132`\ c[2, 2] + 
            0.012764807179542589`\ c[2, 3] - 0.020610270624568165`\ c[3, 0] + 
            0.011589116724943931`\ c[3, 1] - 0.007558766448059473`\ c[3, 2] + 
            0.004258958381705501`\ c[3, 3] == 0.5366706427269019`\)\),
      SequenceForm[ "eq", {0, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -1.0227526177521447, 
              c[ 0, 0]], 
            Times[ 0.88052039465856902, 
              c[ 0, 1]], 
            Times[ -0.70735109358282311, 
              c[ 0, 2]], 
            Times[ 0.55756714602496094, 
              c[ 0, 3]], 
            Times[ -0.14866289134783212, 
              c[ 1, 0]], 
            Times[ 0.10803183570004865, 
              c[ 1, 1]], 
            Times[ -0.078240093004687608, 
              c[ 1, 2]], 
            Times[ 0.054174248867907698, 
              c[ 1, 3]], 
            Times[ -0.047619331737450782, 
              c[ 2, 0]], 
            Times[ 0.030200608308507737, 
              c[ 2, 1]], 
            Times[ -0.020548648043905132, 
              c[ 2, 2]], 
            Times[ 0.012764807179542589, 
              c[ 2, 3]], 
            Times[ -0.020610270624568165, 
              c[ 3, 0]], 
            Times[ 0.011589116724943931, 
              c[ 3, 1]], 
            Times[ -0.007558766448059473, 
              c[ 3, 2]], 
            Times[ 0.0042589583817055007, 
              c[ 3, 3]]], 0.5366706427269019]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{0, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.6779166128172255`\ c[
                0, 0] - 0.651486987230687`\ c[0, 1] + 
            0.5575671438121805`\ c[0, 2] - 0.46885502305622573`\ c[0, 3] + 
            0.08227982281961926`\ c[1, 0] - 0.07179909580567413`\ c[1, 1] + 
            0.05417424806375189`\ c[1, 2] - 0.04159374943281591`\ c[1, 3] + 
            0.022885110636592723`\ c[2, 0] - 0.018805164066519962`\ c[2, 1] + 
            0.01276480722589721`\ c[2, 2] - 0.009186543336556083`\ c[2, 3] + 
            0.00875820812159103`\ c[3, 0] - 0.006902689457136344`\ c[3, 1] + 
            0.004258958350581763`\ c[3, 2] - 
            0.002919450712013513`\ c[3, 3] == \(-0.3217016765357592`\)\)\),
      SequenceForm[ "eq", {0, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.67791661281722548, 
              c[ 0, 0]], 
            Times[ -0.65148698723068699, 
              c[ 0, 1]], 
            Times[ 0.55756714381218053, 
              c[ 0, 2]], 
            Times[ -0.46885502305622573, 
              c[ 0, 3]], 
            Times[ 0.082279822819619264, 
              c[ 1, 0]], 
            Times[ -0.071799095805674132, 
              c[ 1, 1]], 
            Times[ 0.054174248063751887, 
              c[ 1, 2]], 
            Times[ -0.041593749432815907, 
              c[ 1, 3]], 
            Times[ 0.022885110636592723, 
              c[ 2, 0]], 
            Times[ -0.018805164066519962, 
              c[ 2, 1]], 
            Times[ 0.01276480722589721, 
              c[ 2, 2]], 
            Times[ -0.0091865433365560835, 
              c[ 2, 3]], 
            Times[ 0.0087582081215910306, 
              c[ 3, 0]], 
            Times[ -0.0069026894571363436, 
              c[ 3, 1]], 
            Times[ 0.0042589583505817626, 
              c[ 3, 2]], 
            Times[ -0.0029194507120135129, 
              c[ 3, 3]]], -0.32170167653575921]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.8677105420708995`\)\
\ c[0, 0] + 0.2723216699354064`\ c[0, 1] - 0.14866289300866917`\ c[0, 2] + 
            0.08227982499502368`\ c[0, 3] - 0.5629235798971659`\ c[1, 0] + 
            0.14451078213844148`\ c[1, 1] - 0.07338332070922951`\ c[1, 2] + 
            0.03598704658806903`\ c[1, 3] - 0.33880162515399337`\ c[2, 0] + 
            0.0710884375066017`\ c[2, 1] - 0.0345581426179401`\ c[2, 2] + 
            0.014991767118211886`\ c[2, 3] - 0.21979385973125623`\ c[3, 0] + 
            0.038984932397991605`\ c[3, 1] - 0.018444191921273504`\ c[3, 2] + 
            0.0071606048950421455`\ c[3, 3] == 0.5768609331927412`\)\),
      SequenceForm[ "eq", {1, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.86771054207089948, 
              c[ 0, 0]], 
            Times[ 0.27232166993540641, 
              c[ 0, 1]], 
            Times[ -0.14866289300866917, 
              c[ 0, 2]], 
            Times[ 0.082279824995023676, 
              c[ 0, 3]], 
            Times[ -0.5629235798971659, 
              c[ 1, 0]], 
            Times[ 0.14451078213844148, 
              c[ 1, 1]], 
            Times[ -0.07338332070922951, 
              c[ 1, 2]], 
            Times[ 0.035987046588069033, 
              c[ 1, 3]], 
            Times[ -0.33880162515399337, 
              c[ 2, 0]], 
            Times[ 0.071088437506601695, 
              c[ 2, 1]], 
            Times[ -0.034558142617940102, 
              c[ 2, 2]], 
            Times[ 0.014991767118211886, 
              c[ 2, 3]], 
            Times[ -0.21979385973125623, 
              c[ 3, 0]], 
            Times[ 0.038984932397991605, 
              c[ 3, 1]], 
            Times[ -0.018444191921273504, 
              c[ 3, 2]], 
            Times[ 0.0071606048950421455, 
              c[ 3, 3]]], 0.57686093319274123]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.2723216699474639`\ c[
                0, 0] - 0.19422567603462149`\ c[0, 1] + 
            0.10803183075723373`\ c[0, 2] - 0.07179909592857112`\ c[0, 3] + 
            0.14451078250586874`\ c[1, 0] - 0.08972371530836601`\ c[1, 1] + 
            0.043302543786007994`\ c[1, 2] - 0.02655350782588484`\ c[1, 3] + 
            0.07108844120781621`\ c[2, 0] - 0.04215202694811472`\ c[2, 1] + 
            0.017822675775702214`\ c[2, 2] - 0.010371493880708307`\ c[2, 3] + 
            0.038984932304503055`\ c[3, 0] - 0.022534292697344104`\ c[3, 1] + 
            0.008469415937094119`\ c[3, 2] - 
            0.004748007467892514`\ c[3, 3] == \(-0.12293283971699011`\)\)\),
      SequenceForm[ "eq", {1, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.27232166994746387, 
              c[ 0, 0]], 
            Times[ -0.19422567603462149, 
              c[ 0, 1]], 
            Times[ 0.10803183075723373, 
              c[ 0, 2]], 
            Times[ -0.071799095928571116, 
              c[ 0, 3]], 
            Times[ 0.14451078250586874, 
              c[ 1, 0]], 
            Times[ -0.089723715308366009, 
              c[ 1, 1]], 
            Times[ 0.043302543786007994, 
              c[ 1, 2]], 
            Times[ -0.02655350782588484, 
              c[ 1, 3]], 
            Times[ 0.071088441207816211, 
              c[ 2, 0]], 
            Times[ -0.042152026948114721, 
              c[ 2, 1]], 
            Times[ 0.017822675775702214, 
              c[ 2, 2]], 
            Times[ -0.010371493880708307, 
              c[ 2, 3]], 
            Times[ 0.038984932304503055, 
              c[ 3, 0]], 
            Times[ -0.022534292697344104, 
              c[ 3, 1]], 
            Times[ 0.0084694159370941186, 
              c[ 3, 2]], 
            Times[ -0.0047480074678925141, 
              c[ 3, 3]]], -0.12293283971699011]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          2}\[InvisibleSpace]" = \
"\[InvisibleSpace]\(\(-0.14866289382341366`\)\ c[0, 0] + 
            0.10803183053481527`\ c[0, 1] - 0.07824009045658684`\ c[0, 2] + 
            0.05417424885717752`\ c[0, 3] - 0.07338333390671005`\ c[1, 0] + 
            0.04330254457040629`\ c[1, 1] - 0.028296991620815146`\ c[1, 2] + 
            0.017509189194162594`\ c[1, 3] - 0.03455814260575313`\ c[2, 0] + 
            0.017822675838733697`\ c[2, 1] - 0.011027571101483065`\ c[2, 2] + 
            0.0062006241524093075`\ c[2, 3] - 
            0.018444191962290742`\ c[3, 0] + 0.00846941594424941`\ c[3, 1] - 
            0.005046043648873608`\ c[3, 2] + 0.0025997154355896215`\ c[3, 3] == 
          0.07530758617720691`\)\),
      SequenceForm[ "eq", {1, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.14866289382341366, 
              c[ 0, 0]], 
            Times[ 0.10803183053481527, 
              c[ 0, 1]], 
            Times[ -0.078240090456586836, 
              c[ 0, 2]], 
            Times[ 0.054174248857177518, 
              c[ 0, 3]], 
            Times[ -0.073383333906710049, 
              c[ 1, 0]], 
            Times[ 0.04330254457040629, 
              c[ 1, 1]], 
            Times[ -0.028296991620815146, 
              c[ 1, 2]], 
            Times[ 0.017509189194162594, 
              c[ 1, 3]], 
            Times[ -0.034558142605753128, 
              c[ 2, 0]], 
            Times[ 0.017822675838733697, 
              c[ 2, 1]], 
            Times[ -0.011027571101483065, 
              c[ 2, 2]], 
            Times[ 0.0062006241524093075, 
              c[ 2, 3]], 
            Times[ -0.018444191962290742, 
              c[ 3, 0]], 
            Times[ 0.0084694159442494105, 
              c[ 3, 1]], 
            Times[ -0.0050460436488736077, 
              c[ 3, 2]], 
            Times[ 0.0025997154355896215, 
              c[ 3, 3]]], 0.075307586177206912]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{1, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.0822798230326752`\ c[
                0, 0] - 0.07179909452960061`\ c[0, 1] + 
            0.05417424943726847`\ c[0, 2] - 0.041593749670490655`\ c[0, 3] + 
            0.035987046512237254`\ c[1, 0] - 0.0265535077025885`\ c[1, 1] + 
            0.017509189259431242`\ c[1, 2] - 0.01229485586215261`\ c[1, 3] + 
            0.014991767136997073`\ c[2, 0] - 0.0103714937827982`\ c[2, 1] + 
            0.006200624187471231`\ c[2, 2] - 0.004117199584262991`\ c[2, 3] + 
            0.0071606048363704565`\ c[3, 0] - 
            0.004748007479610691`\ c[3, 1] + 
            0.0025997145290612292`\ c[3, 2] - 
            0.0016544379323899937`\ c[3, 3] == \(-0.03552098395910542`\)\)\),
      SequenceForm[ "eq", {1, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.082279823032675198, 
              c[ 0, 0]], 
            Times[ -0.071799094529600607, 
              c[ 0, 1]], 
            Times[ 0.054174249437268472, 
              c[ 0, 2]], 
            Times[ -0.041593749670490655, 
              c[ 0, 3]], 
            Times[ 0.035987046512237254, 
              c[ 1, 0]], 
            Times[ -0.026553507702588498, 
              c[ 1, 1]], 
            Times[ 0.017509189259431242, 
              c[ 1, 2]], 
            Times[ -0.01229485586215261, 
              c[ 1, 3]], 
            Times[ 0.014991767136997073, 
              c[ 2, 0]], 
            Times[ -0.0103714937827982, 
              c[ 2, 1]], 
            Times[ 0.0062006241874712313, 
              c[ 2, 2]], 
            Times[ -0.0041171995842629906, 
              c[ 2, 3]], 
            Times[ 0.0071606048363704565, 
              c[ 3, 0]], 
            Times[ -0.0047480074796106908, 
              c[ 3, 1]], 
            Times[ 0.0025997145290612292, 
              c[ 3, 2]], 
            Times[ -0.0016544379323899937, 
              c[ 3, 3]]], -0.035520983959105419]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.3806724459673615`\)\
\ c[0, 0] + 0.09300676820959519`\ c[0, 1] - 0.04761933191332914`\ c[0, 2] + 
            0.022885110712993165`\ c[0, 3] - 0.3388016263882182`\ c[1, 0] + 
            0.0710884345915904`\ c[1, 1] - 0.03455814220946763`\ c[1, 2] + 
            0.014991767052786471`\ c[1, 3] - 0.25016939757143913`\ c[2, 0] + 
            0.044646749743634265`\ c[2, 1] - 0.02106849883254663`\ c[2, 2] + 
            0.008206511674500603`\ c[2, 3] - 0.18436858180788676`\ c[3, 0] + 
            0.028535427759659313`\ c[3, 1] - 0.013210808856271098`\ c[3, 2] + 
            0.00465538751885035`\ c[3, 3] == 0.24517070818467906`\)\),
      SequenceForm[ "eq", {2, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.38067244596736149, 
              c[ 0, 0]], 
            Times[ 0.093006768209595192, 
              c[ 0, 1]], 
            Times[ -0.047619331913329142, 
              c[ 0, 2]], 
            Times[ 0.022885110712993165, 
              c[ 0, 3]], 
            Times[ -0.3388016263882182, 
              c[ 1, 0]], 
            Times[ 0.071088434591590394, 
              c[ 1, 1]], 
            Times[ -0.034558142209467631, 
              c[ 1, 2]], 
            Times[ 0.014991767052786471, 
              c[ 1, 3]], 
            Times[ -0.25016939757143913, 
              c[ 2, 0]], 
            Times[ 0.044646749743634265, 
              c[ 2, 1]], 
            Times[ -0.02106849883254663, 
              c[ 2, 2]], 
            Times[ 0.0082065116745006026, 
              c[ 2, 3]], 
            Times[ -0.18436858180788676, 
              c[ 3, 0]], 
            Times[ 0.028535427759659313, 
              c[ 3, 1]], 
            Times[ -0.013210808856271098, 
              c[ 3, 2]], 
            Times[ 0.0046553875188503503, 
              c[ 3, 3]]], 0.24517070818467906]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.09300676858251222`\ c[
                0, 0] - 0.0639597264024068`\ c[0, 1] + 
            0.030200608600381658`\ c[0, 2] - 0.018805164200911606`\ c[0, 3] + 
            0.07108844124563478`\ c[1, 0] - 0.04215202685041512`\ c[1, 1] + 
            0.01782267577269184`\ c[1, 2] - 0.010371493866559226`\ c[1, 3] + 
            0.044646749759782216`\ c[2, 0] - 0.025158600434750822`\ c[2, 1] + 
            0.009515322740270685`\ c[2, 2] - 0.005305401140639838`\ c[2, 3] + 
            0.028535427773151597`\ c[3, 0] - 0.01563950630913856`\ c[3, 1] + 
            0.005336731470548332`\ c[3, 2] - 
            0.002885254562545731`\ c[3, 3] == \(-0.03823872062672139`\)\)\),
      SequenceForm[ "eq", {2, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.093006768582512223, 
              c[ 0, 0]], 
            Times[ -0.063959726402406797, 
              c[ 0, 1]], 
            Times[ 0.030200608600381658, 
              c[ 0, 2]], 
            Times[ -0.018805164200911606, 
              c[ 0, 3]], 
            Times[ 0.071088441245634779, 
              c[ 1, 0]], 
            Times[ -0.042152026850415122, 
              c[ 1, 1]], 
            Times[ 0.017822675772691841, 
              c[ 1, 2]], 
            Times[ -0.010371493866559226, 
              c[ 1, 3]], 
            Times[ 0.044646749759782216, 
              c[ 2, 0]], 
            Times[ -0.025158600434750822, 
              c[ 2, 1]], 
            Times[ 0.0095153227402706847, 
              c[ 2, 2]], 
            Times[ -0.0053054011406398378, 
              c[ 2, 3]], 
            Times[ 0.028535427773151597, 
              c[ 3, 0]], 
            Times[ -0.015639506309138559, 
              c[ 3, 1]], 
            Times[ 0.005336731470548332, 
              c[ 3, 2]], 
            Times[ -0.0028852545625457312, 
              c[ 3, 3]]], -0.038238720626721387]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.047619331882800736`\
\)\ c[0, 0] + 0.030200608022089265`\ c[0, 1] - 
            0.020548648514115368`\ c[0, 2] + 0.012764807296138811`\ c[0, 3] - 
            0.03455814275408066`\ c[1, 0] + 0.017822675905215586`\ c[1, 1] - 
            0.01102757068246567`\ c[1, 2] + 0.006200624149158334`\ c[1, 3] - 
            0.02106849947853066`\ c[2, 0] + 0.009515322805536375`\ c[2, 1] - 
            0.005603437354810236`\ c[2, 2] + 0.002887019227867494`\ c[2, 3] - 
            0.013210808739043267`\ c[3, 0] + 0.005336731444395667`\ c[3, 1] - 
            0.0030386032396916883`\ c[3, 2] + 
            0.0014442877493821647`\ c[3, 3] == 0.0243875802394917`\)\),
      SequenceForm[ "eq", {2, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.047619331882800736, 
              c[ 0, 0]], 
            Times[ 0.030200608022089265, 
              c[ 0, 1]], 
            Times[ -0.020548648514115368, 
              c[ 0, 2]], 
            Times[ 0.012764807296138811, 
              c[ 0, 3]], 
            Times[ -0.034558142754080659, 
              c[ 1, 0]], 
            Times[ 0.017822675905215586, 
              c[ 1, 1]], 
            Times[ -0.011027570682465669, 
              c[ 1, 2]], 
            Times[ 0.0062006241491583342, 
              c[ 1, 3]], 
            Times[ -0.02106849947853066, 
              c[ 2, 0]], 
            Times[ 0.0095153228055363751, 
              c[ 2, 1]], 
            Times[ -0.0056034373548102361, 
              c[ 2, 2]], 
            Times[ 0.0028870192278674942, 
              c[ 2, 3]], 
            Times[ -0.013210808739043267, 
              c[ 3, 0]], 
            Times[ 0.0053367314443956669, 
              c[ 3, 1]], 
            Times[ -0.0030386032396916883, 
              c[ 3, 2]], 
            Times[ 0.0014442877493821647, 
              c[ 3, 3]]], 0.0243875802394917]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{2, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.022885110580302508`\ c[
                0, 0] - 0.018805163961872734`\ c[0, 1] + 
            0.012764807483112877`\ c[0, 2] - 0.009186543489622327`\ c[0, 3] + 
            0.014991767161337587`\ c[1, 0] - 0.01037149382582035`\ c[1, 1] + 
            0.006200624176987195`\ c[1, 2] - 
            0.0041171994085293555`\ c[1, 3] + 0.00820651169220701`\ c[2, 0] - 
            0.00530540114512719`\ c[2, 1] + 0.002887019234026584`\ c[2, 2] - 
            0.0018235067209312376`\ c[2, 3] + 
            0.0046553875171790144`\ c[3, 0] - 
            0.0028852545574931075`\ c[3, 1] + 
            0.0014442877632039925`\ c[3, 2] - 
            0.0008787138625165395`\ c[3, 3] == \(-0.009321944375888791`\)\)\),
      
      SequenceForm[ "eq", {2, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.022885110580302508, 
              c[ 0, 0]], 
            Times[ -0.018805163961872734, 
              c[ 0, 1]], 
            Times[ 0.012764807483112877, 
              c[ 0, 2]], 
            Times[ -0.0091865434896223272, 
              c[ 0, 3]], 
            Times[ 0.014991767161337587, 
              c[ 1, 0]], 
            Times[ -0.01037149382582035, 
              c[ 1, 1]], 
            Times[ 0.0062006241769871949, 
              c[ 1, 2]], 
            Times[ -0.0041171994085293555, 
              c[ 1, 3]], 
            Times[ 0.0082065116922070101, 
              c[ 2, 0]], 
            Times[ -0.0053054011451271902, 
              c[ 2, 1]], 
            Times[ 0.0028870192340265839, 
              c[ 2, 2]], 
            Times[ -0.0018235067209312376, 
              c[ 2, 3]], 
            Times[ 0.0046553875171790144, 
              c[ 3, 0]], 
            Times[ -0.0028852545574931075, 
              c[ 3, 1]], 
            Times[ 0.0014442877632039925, 
              c[ 3, 2]], 
            Times[ -0.00087871386251653946, 
              c[ 3, 3]]], -0.009321944375888791]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          0}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.2080784695867788`\)\
\ c[0, 0] + 0.041826452142622705`\ c[0, 1] - 0.02061027040146507`\ c[0, 2] + 
            0.008758208035893066`\ c[0, 3] - 0.21979380402340754`\ c[1, 0] + 
            0.03898493238881015`\ c[1, 1] - 0.01844419189747768`\ c[1, 2] + 
            0.007160604924111817`\ c[1, 3] - 0.18436858213188756`\ c[2, 0] + 
            0.028535427718901468`\ c[2, 1] - 0.013210808696861066`\ c[2, 2] + 
            0.0046553875186983295`\ c[2, 3] - 0.14856074079149387`\ c[3, 0] + 
            0.020319604058881984`\ c[3, 1] - 0.009275936052455228`\ c[3, 2] + 
            0.00298341529175595`\ c[3, 3] == 0.131630143329326`\)\),
      SequenceForm[ "eq", {3, 0}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.20807846958677881, 
              c[ 0, 0]], 
            Times[ 0.041826452142622705, 
              c[ 0, 1]], 
            Times[ -0.02061027040146507, 
              c[ 0, 2]], 
            Times[ 0.0087582080358930663, 
              c[ 0, 3]], 
            Times[ -0.21979380402340754, 
              c[ 1, 0]], 
            Times[ 0.038984932388810151, 
              c[ 1, 1]], 
            Times[ -0.018444191897477681, 
              c[ 1, 2]], 
            Times[ 0.0071606049241118167, 
              c[ 1, 3]], 
            Times[ -0.18436858213188756, 
              c[ 2, 0]], 
            Times[ 0.028535427718901468, 
              c[ 2, 1]], 
            Times[ -0.013210808696861066, 
              c[ 2, 2]], 
            Times[ 0.0046553875186983295, 
              c[ 2, 3]], 
            Times[ -0.14856074079149387, 
              c[ 3, 0]], 
            Times[ 0.020319604058881984, 
              c[ 3, 1]], 
            Times[ -0.0092759360524552279, 
              c[ 3, 2]], 
            Times[ 0.0029834152917559498, 
              c[ 3, 3]]], 0.13163014332932599]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          1}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.04182645168182704`\ c[
                0, 0] - 0.02820415492792206`\ c[0, 1] + 
            0.011589116716604685`\ c[0, 2] - 0.006902689479110434`\ c[0, 3] + 
            0.03898493234031709`\ c[1, 0] - 0.02253429260451624`\ c[1, 1] + 
            0.008469415960970391`\ c[1, 2] - 0.004748007480681842`\ c[1, 3] + 
            0.028535427737025495`\ c[2, 0] - 0.01563950627511309`\ c[2, 1] + 
            0.005336731450951263`\ c[2, 2] - 
            0.0028852545796962136`\ c[2, 3] + 
            0.020319604078195486`\ c[3, 0] - 0.010822675764026448`\ c[3, 1] + 
            0.003369868832755333`\ c[3, 2] - 
            0.0017751841310206747`\ c[3, 3] == \(-0.016170535929320773`\)\)\),
      
      SequenceForm[ "eq", {3, 1}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.04182645168182704, 
              c[ 0, 0]], 
            Times[ -0.028204154927922061, 
              c[ 0, 1]], 
            Times[ 0.011589116716604685, 
              c[ 0, 2]], 
            Times[ -0.0069026894791104337, 
              c[ 0, 3]], 
            Times[ 0.038984932340317087, 
              c[ 1, 0]], 
            Times[ -0.02253429260451624, 
              c[ 1, 1]], 
            Times[ 0.008469415960970391, 
              c[ 1, 2]], 
            Times[ -0.0047480074806818418, 
              c[ 1, 3]], 
            Times[ 0.028535427737025495, 
              c[ 2, 0]], 
            Times[ -0.015639506275113089, 
              c[ 2, 1]], 
            Times[ 0.0053367314509512633, 
              c[ 2, 2]], 
            Times[ -0.0028852545796962136, 
              c[ 2, 3]], 
            Times[ 0.020319604078195486, 
              c[ 3, 0]], 
            Times[ -0.010822675764026448, 
              c[ 3, 1]], 
            Times[ 0.0033698688327553328, 
              c[ 3, 2]], 
            Times[ -0.0017751841310206747, 
              c[ 3, 3]]], -0.016170535929320773]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          2}\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-0.020610270669373022`\
\)\ c[0, 0] + 0.01158911681934974`\ c[0, 1] - 
            0.007558766410254932`\ c[0, 2] + 0.004258958388405497`\ c[0, 3] - 
            0.018444191882889812`\ c[1, 0] + 0.008469415958402414`\ c[1, 1] - 
            0.005046043688954668`\ c[1, 2] + 0.002599715430341638`\ c[1, 3] - 
            0.013210808700722231`\ c[2, 0] + 
            0.0053367314723437465`\ c[2, 1] - 
            0.0030386032160687757`\ c[2, 2] + 
            0.001444287748205167`\ c[2, 3] - 0.009275936049665331`\ c[3, 0] + 
            0.003369868821546629`\ c[3, 1] - 
            0.0018614590150906655`\ c[3, 2] + 
            0.0008208681426477635`\ c[3, 3] == 0.010733641011742517`\)\),
      SequenceForm[ "eq", {3, 2}, " = ", 
        Equal[ 
          Plus[ 
            Times[ -0.020610270669373022, 
              c[ 0, 0]], 
            Times[ 0.011589116819349741, 
              c[ 0, 1]], 
            Times[ -0.0075587664102549322, 
              c[ 0, 2]], 
            Times[ 0.0042589583884054972, 
              c[ 0, 3]], 
            Times[ -0.018444191882889812, 
              c[ 1, 0]], 
            Times[ 0.008469415958402414, 
              c[ 1, 1]], 
            Times[ -0.0050460436889546677, 
              c[ 1, 2]], 
            Times[ 0.002599715430341638, 
              c[ 1, 3]], 
            Times[ -0.013210808700722231, 
              c[ 2, 0]], 
            Times[ 0.0053367314723437465, 
              c[ 2, 1]], 
            Times[ -0.0030386032160687757, 
              c[ 2, 2]], 
            Times[ 0.0014442877482051669, 
              c[ 2, 3]], 
            Times[ -0.0092759360496653311, 
              c[ 3, 0]], 
            Times[ 0.0033698688215466292, 
              c[ 3, 1]], 
            Times[ -0.0018614590150906655, 
              c[ 3, 2]], 
            Times[ 0.00082086814264776349, 
              c[ 3, 3]]], 0.010733641011742517]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("eq"\[InvisibleSpace]{3, 
          3}\[InvisibleSpace]" = "\[InvisibleSpace]\(0.008758208053733783`\ c[
                0, 0] - 0.006902689499332309`\ c[0, 1] + 
            0.004258958339075735`\ c[0, 2] - 
            0.0029194507349737213`\ c[0, 3] + 
            0.0071606049283372275`\ c[1, 0] - 
            0.004748007462035559`\ c[1, 1] + 0.002599715390082774`\ c[1, 2] - 
            0.0016544378090879437`\ c[1, 3] + 
            0.004655387674539014`\ c[2, 0] - 0.002885254569564683`\ c[2, 1] + 
            0.0014442877470159754`\ c[2, 2] - 
            0.0008787138977880775`\ c[2, 3] + 
            0.002983415125407614`\ c[3, 0] - 0.001775184127632271`\ c[3, 1] + 
            0.0008208681744471414`\ c[3, 2] - 
            0.0004831062256722749`\ c[3, 
                3] == \(-0.0034129416600930133`\)\)\),
      SequenceForm[ "eq", {3, 3}, " = ", 
        Equal[ 
          Plus[ 
            Times[ 0.008758208053733783, 
              c[ 0, 0]], 
            Times[ -0.0069026894993323091, 
              c[ 0, 1]], 
            Times[ 0.0042589583390757347, 
              c[ 0, 2]], 
            Times[ -0.0029194507349737213, 
              c[ 0, 3]], 
            Times[ 0.0071606049283372275, 
              c[ 1, 0]], 
            Times[ -0.0047480074620355594, 
              c[ 1, 1]], 
            Times[ 0.0025997153900827741, 
              c[ 1, 2]], 
            Times[ -0.0016544378090879437, 
              c[ 1, 3]], 
            Times[ 0.0046553876745390136, 
              c[ 2, 0]], 
            Times[ -0.002885254569564683, 
              c[ 2, 1]], 
            Times[ 0.0014442877470159754, 
              c[ 2, 2]], 
            Times[ -0.00087871389778807754, 
              c[ 2, 3]], 
            Times[ 0.0029834151254076141, 
              c[ 3, 0]], 
            Times[ -0.001775184127632271, 
              c[ 3, 1]], 
            Times[ 0.0008208681744471414, 
              c[ 3, 2]], 
            Times[ -0.00048310622567227489, 
              c[ 3, 3]]], -0.0034129416600930133]],
      Editable->False]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\((\[Phi][x, y])\)\ Boole[
            z[1, x, y] \[LessEqual] \ \ \ 0\  && \ 
              z[2, x, y] \[LessEqual] \ \ \ 0\ ], {x, \(-1.3\), 
          1.3}, {y, \(-1.3\), 1.3}, PlotPoints \[Rule] 60, 
        PlotRange \[Rule] All, Mesh \[Rule] False, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel -> "\<\[Phi]\>"];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.31"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -5 0 ]
[.5 .82364 5 12 ]
[.09521 .21956 -12 -8.90049 ]
[.09521 .21956 0 .09951 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.5975 .02203 -5.10557 -9 ]
[.5975 .02203 .89443 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.74008 .05512 0 -6.20283 ]
[.74008 .05512 12 2.79717 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95518 .38451 0 -5.89111 ]
[.95518 .38451 6 3.10889 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01567 .318 -24 -2.78704 ]
[.01567 .318 0 6.21296 ]
[.00694 .37275 -18 -2.83348 ]
[.00694 .37275 0 6.16652 ]
[-0.00211 .42944 -24 -2.88175 ]
[-0.00211 .42944 0 6.11825 ]
[-0.01148 .48818 -6 -2.93196 ]
[-0.01148 .48818 0 6.06804 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10459 .22873 m
.10928 .23332 L
s
[(-1)] .09521 .21956 1 .97789 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60504 .03277 m
.60881 .03814 L
s
[(1)] .5975 .02203 .70186 1 Mshowa
.125 Mabswid
.15056 .21073 m
.15333 .21353 L
s
.19737 .19241 m
.20009 .19525 L
s
.24504 .17374 m
.24771 .17663 L
s
.29359 .15473 m
.29622 .15766 L
s
.39347 .11562 m
.39599 .11865 L
s
.44485 .0955 m
.4473 .09858 L
s
.49721 .075 m
.4996 .07812 L
s
.5506 .05409 m
.55293 .05726 L
s
.05944 .24641 m
.06229 .24912 L
s
.66056 .01103 m
.66275 .0143 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7278 .05976 m
.72167 .06208 L
s
[(-1)] .74008 .05512 -1 .37841 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94264 .38838 m
.93637 .39032 L
s
[(1)] .95518 .38451 -1 .30914 Mshowa
.125 Mabswid
.7527 .09784 m
.74901 .09921 L
s
.77673 .1346 m
.77303 .13594 L
s
.79994 .17011 m
.79623 .17143 L
s
.82238 .20443 m
.81866 .20572 L
s
.86507 .26972 m
.86133 .27097 L
s
.88539 .30081 m
.88165 .30203 L
s
.90507 .33092 m
.90132 .33212 L
s
.92415 .3601 m
.92039 .36128 L
s
.702 .02028 m
.69833 .02171 L
s
.96058 .41582 m
.95681 .41697 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02794 .31333 m
.03407 .311 L
s
[(0.25)] .01567 .318 1 -0.38066 Mshowa
.01924 .36819 m
.0254 .36591 L
s
[(0.5)] .00694 .37275 1 -0.37034 Mshowa
.01024 .425 m
.01642 .42278 L
s
[(0.75)] -0.00211 .42944 1 -0.35961 Mshowa
.00091 .48386 m
.00711 .4817 L
s
[(1)] -0.01148 .48818 1 -0.34845 Mshowa
.125 Mabswid
.03468 .27079 m
.03835 .26936 L
s
.03301 .28132 m
.03668 .2799 L
s
.03133 .29192 m
.03501 .2905 L
s
.02964 .30259 m
.03332 .30118 L
s
.02622 .32415 m
.0299 .32276 L
s
.0245 .33505 m
.02818 .33366 L
s
.02276 .34602 m
.02644 .34464 L
s
.02101 .35706 m
.0247 .35569 L
s
.01747 .37939 m
.02116 .37803 L
s
.01568 .39067 m
.01938 .38932 L
s
.01388 .40203 m
.01758 .40069 L
s
.01207 .41347 m
.01577 .41213 L
s
.0084 .4366 m
.01211 .43528 L
s
.00655 .44829 m
.01026 .44697 L
s
.00469 .46006 m
.0084 .45875 L
s
.00281 .47192 m
.00652 .47062 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39995 .5989 .40512 .60371 .4138 .60111 .40865 .59628 Mtetra
.40865 .59628 .4138 .60111 .42251 .5985 .41737 .59365 Mtetra
.41737 .59365 .42251 .5985 .43124 .59588 .42613 .59102 Mtetra
.42613 .59102 .43124 .59588 .44001 .59325 .43491 .58837 Mtetra
.43491 .58837 .44001 .59325 .4488 .59061 .44372 .58572 Mtetra
.44372 .58572 .4488 .59061 .45762 .58796 .45256 .58306 Mtetra
.45256 .58306 .45762 .58796 .46647 .58531 .46142 .58039 Mtetra
.46142 .58039 .46647 .58531 .47535 .58265 .47032 .57771 Mtetra
.47032 .57771 .47535 .58265 .48425 .57997 .47925 .57502 Mtetra
.47925 .57502 .48425 .57997 .49319 .57729 .4882 .57232 Mtetra
.4882 .57232 .49319 .57729 .50216 .5746 .49719 .56961 Mtetra
.49719 .56961 .50216 .5746 .51115 .5719 .5062 .5669 Mtetra
.5062 .5669 .51115 .5719 .52017 .5692 .51524 .56418 Mtetra
.51524 .56418 .52017 .5692 .52923 .56648 .52432 .56144 Mtetra
.52432 .56144 .52923 .56648 .53831 .56376 .53342 .5587 Mtetra
.53342 .5587 .53831 .56376 .54743 .56102 .54256 .55595 Mtetra
.54256 .55595 .54743 .56102 .55657 .55828 .55172 .55319 Mtetra
.55172 .55319 .55657 .55828 .56575 .55553 .56092 .55042 Mtetra
.56092 .55042 .56575 .55553 .57495 .55276 .57014 .54764 Mtetra
.57014 .54764 .57495 .55276 .58419 .54999 .5794 .54485 Mtetra
.5794 .54485 .58419 .54999 .59345 .54721 .58869 .54206 Mtetra
.58869 .54206 .59345 .54721 .60275 .54442 .598 .53925 Mtetra
.598 .53925 .60275 .54442 .61208 .54163 .60735 .53643 Mtetra
.60735 .53643 .61208 .54163 .62144 .53882 .61673 .53361 Mtetra
.61673 .53361 .62144 .53882 .63083 .536 .62615 .53077 Mtetra
.62615 .53077 .63083 .536 .64026 .53317 .63559 .52793 Mtetra
.63559 .52793 .64026 .53317 .64971 .53034 .64507 .52507 Mtetra
.64507 .52507 .64971 .53034 .6592 .52749 .65458 .52221 Mtetra
.65458 .52221 .6592 .52749 .66872 .52463 .66412 .51934 Mtetra
.66412 .51934 .66872 .52463 .67827 .52177 .67369 .51645 Mtetra
.67369 .51645 .67827 .52177 .68785 .51889 .6833 .51356 Mtetra
.6833 .51356 .68785 .51889 .69747 .51601 .69293 .51066 Mtetra
.69293 .51066 .69747 .51601 .70711 .51312 .70261 .50775 Mtetra
.70261 .50775 .70711 .51312 .7168 .51021 .71231 .50482 Mtetra
.71231 .50482 .7168 .51021 .72651 .5073 .72205 .50189 Mtetra
.72205 .50189 .72651 .5073 .73626 .50437 .73182 .49895 Mtetra
.73182 .49895 .73626 .50437 .74604 .50144 .74162 .49599 Mtetra
.74162 .49599 .74604 .50144 .75585 .49849 .75146 .49303 Mtetra
.75146 .49303 .75585 .49849 .7657 .49554 .76133 .49006 Mtetra
.76133 .49006 .7657 .49554 .77558 .49257 .77124 .48707 Mtetra
.77124 .48707 .77558 .49257 .7855 .4896 .78118 .48408 Mtetra
.78118 .48408 .7855 .4896 .79545 .48661 .79115 .48108 Mtetra
.79115 .48108 .79545 .48661 .80544 .48362 .80116 .47806 Mtetra
.80116 .47806 .80544 .48362 .81546 .48061 .81121 .47504 Mtetra
.81121 .47504 .81546 .48061 .82551 .4776 .82129 .472 Mtetra
.82129 .472 .82551 .4776 .8356 .47457 .8314 .46895 Mtetra
.8314 .46895 .8356 .47457 .84573 .47153 .84155 .4659 Mtetra
.84155 .4659 .84573 .47153 .85588 .46848 .85174 .46283 Mtetra
.85174 .46283 .85588 .46848 .86608 .46543 .86196 .45975 Mtetra
.86196 .45975 .86608 .46543 .87631 .46236 .87222 .45666 Mtetra
.87222 .45666 .87631 .46236 .88658 .45928 .88251 .45356 Mtetra
.88251 .45356 .88658 .45928 .89688 .45619 .89284 .45045 Mtetra
.89284 .45045 .89688 .45619 .90722 .45308 .90321 .44733 Mtetra
.90321 .44733 .90722 .45308 .9176 .44997 .91361 .4442 Mtetra
.91361 .4442 .9176 .44997 .92801 .44685 .92405 .44105 Mtetra
.92405 .44105 .92801 .44685 .93846 .44371 .93452 .4379 Mtetra
.93452 .4379 .93846 .44371 .94895 .44057 .94504 .43473 Mtetra
.94504 .43473 .94895 .44057 .95947 .43741 .95559 .43155 Mtetra
.95559 .43155 .95947 .43741 .97003 .43424 .96618 .42836 Mtetra
.39475 .59406 .39995 .5989 .40865 .59628 .40347 .59142 Mtetra
.40347 .59142 .40865 .59628 .41737 .59365 .41221 .58878 Mtetra
.41221 .58878 .41737 .59365 .42613 .59102 .42098 .58613 Mtetra
.42098 .58613 .42613 .59102 .43491 .58837 .42978 .58347 Mtetra
.42978 .58347 .43491 .58837 .44372 .58572 .43861 .5808 Mtetra
.43861 .5808 .44372 .58572 .45256 .58306 .44746 .57812 Mtetra
.44746 .57812 .45256 .58306 .46142 .58039 .45635 .57543 Mtetra
.45635 .57543 .46142 .58039 .47032 .57771 .46527 .57274 Mtetra
.46527 .57274 .47032 .57771 .47925 .57502 .47421 .57003 Mtetra
.47421 .57003 .47925 .57502 .4882 .57232 .48318 .56732 Mtetra
.48318 .56732 .4882 .57232 .49719 .56961 .49219 .5646 Mtetra
.49219 .5646 .49719 .56961 .5062 .5669 .50122 .56186 Mtetra
.50122 .56186 .5062 .5669 .51524 .56418 .51028 .55912 Mtetra
.51028 .55912 .51524 .56418 .52432 .56144 .51938 .55637 Mtetra
.51938 .55637 .52432 .56144 .53342 .5587 .5285 .55361 Mtetra
.5285 .55361 .53342 .5587 .54256 .55595 .53766 .55085 Mtetra
.53766 .55085 .54256 .55595 .55172 .55319 .54684 .54807 Mtetra
.54684 .54807 .55172 .55319 .56092 .55042 .55606 .54528 Mtetra
.55606 .54528 .56092 .55042 .57014 .54764 .5653 .54249 Mtetra
.5653 .54249 .57014 .54764 .5794 .54485 .57458 .53968 Mtetra
.57458 .53968 .5794 .54485 .58869 .54206 .58389 .53687 Mtetra
.58389 .53687 .58869 .54206 .598 .53925 .59323 .53404 Mtetra
.59323 .53404 .598 .53925 .60735 .53643 .6026 .53121 Mtetra
.6026 .53121 .60735 .53643 .61673 .53361 .612 .52837 Mtetra
.612 .52837 .61673 .53361 .62615 .53077 .62143 .52551 Mtetra
.62143 .52551 .62615 .53077 .63559 .52793 .6309 .52265 Mtetra
.6309 .52265 .63559 .52793 .64507 .52507 .6404 .51978 Mtetra
.6404 .51978 .64507 .52507 .65458 .52221 .64993 .5169 Mtetra
.64993 .5169 .65458 .52221 .66412 .51934 .65949 .51401 Mtetra
.65949 .51401 .66412 .51934 .67369 .51645 .66908 .51111 Mtetra
.66908 .51111 .67369 .51645 .6833 .51356 .67871 .50819 Mtetra
.67871 .50819 .6833 .51356 .69293 .51066 .68837 .50527 Mtetra
.68837 .50527 .69293 .51066 .70261 .50775 .69807 .50234 Mtetra
.69807 .50234 .70261 .50775 .71231 .50482 .70779 .4994 Mtetra
.70779 .4994 .71231 .50482 .72205 .50189 .71756 .49645 Mtetra
.71756 .49645 .72205 .50189 .73182 .49895 .72735 .49349 Mtetra
.72735 .49349 .73182 .49895 .74162 .49599 .73718 .49052 Mtetra
.73718 .49052 .74162 .49599 .75146 .49303 .74704 .48753 Mtetra
.74704 .48753 .75146 .49303 .76133 .49006 .75694 .48454 Mtetra
.75694 .48454 .76133 .49006 .77124 .48707 .76687 .48154 Mtetra
.76687 .48154 .77124 .48707 .78118 .48408 .77683 .47853 Mtetra
.77683 .47853 .78118 .48408 .79115 .48108 .78683 .4755 Mtetra
.78683 .4755 .79115 .48108 .80116 .47806 .79686 .47247 Mtetra
.79686 .47247 .80116 .47806 .81121 .47504 .80693 .46942 Mtetra
.80693 .46942 .81121 .47504 .82129 .472 .81704 .46637 Mtetra
.81704 .46637 .82129 .472 .8314 .46895 .82718 .4633 Mtetra
.82718 .4633 .8314 .46895 .84155 .4659 .83735 .46023 Mtetra
.83735 .46023 .84155 .4659 .85174 .46283 .84756 .45714 Mtetra
.84756 .45714 .85174 .46283 .86196 .45975 .85781 .45404 Mtetra
.85781 .45404 .86196 .45975 .87222 .45666 .8681 .45093 Mtetra
.8681 .45093 .87222 .45666 .88251 .45356 .87841 .44781 Mtetra
.87841 .44781 .88251 .45356 .89284 .45045 .88877 .44468 Mtetra
.88877 .44468 .89284 .45045 .90321 .44733 .89916 .44154 Mtetra
.89916 .44154 .90321 .44733 .91361 .4442 .90959 .43838 Mtetra
.90959 .43838 .91361 .4442 .92405 .44105 .92006 .43522 Mtetra
.92006 .43522 .92405 .44105 .93452 .4379 .93056 .43204 Mtetra
.93056 .43204 .93452 .4379 .94504 .43473 .94111 .42885 Mtetra
.94111 .42885 .94504 .43473 .95559 .43155 .95168 .42565 Mtetra
.95168 .42565 .95559 .43155 .96618 .42836 .9623 .42244 Mtetra
.38952 .58919 .39475 .59406 .40347 .59142 .39825 .58654 Mtetra
.39825 .58654 .40347 .59142 .41221 .58878 .40701 .58388 Mtetra
.40701 .58388 .41221 .58878 .42098 .58613 .4158 .58121 Mtetra
.4158 .58121 .42098 .58613 .42978 .58347 .42462 .57853 Mtetra
.42462 .57853 .42978 .58347 .43861 .5808 .43347 .57585 Mtetra
.43347 .57585 .43861 .5808 .44746 .57812 .44234 .57315 Mtetra
.44234 .57315 .44746 .57812 .45635 .57543 .45125 .57045 Mtetra
.45125 .57045 .45635 .57543 .46527 .57274 .46018 .56774 Mtetra
.46018 .56774 .46527 .57274 .47421 .57003 .46914 .56501 Mtetra
.46914 .56501 .47421 .57003 .48318 .56732 .47814 .56228 Mtetra
.47814 .56228 .48318 .56732 .49219 .5646 .48716 .55955 Mtetra
.48716 .55955 .49219 .5646 .50122 .56186 .49621 .5568 Mtetra
.49621 .5568 .50122 .56186 .51028 .55912 .50529 .55404 Mtetra
.50529 .55404 .51028 .55912 .51938 .55637 .51441 .55127 Mtetra
.51441 .55127 .51938 .55637 .5285 .55361 .52355 .5485 Mtetra
.52355 .5485 .5285 .55361 .53766 .55085 .53272 .54571 Mtetra
.53272 .54571 .53766 .55085 .54684 .54807 .54193 .54292 Mtetra
.54193 .54292 .54684 .54807 .55606 .54528 .55116 .54011 Mtetra
.55116 .54011 .55606 .54528 .5653 .54249 .56043 .5373 Mtetra
.56043 .5373 .5653 .54249 .57458 .53968 .56973 .53448 Mtetra
.56973 .53448 .57458 .53968 .58389 .53687 .57906 .53165 Mtetra
.57906 .53165 .58389 .53687 .59323 .53404 .58842 .52881 Mtetra
.58842 .52881 .59323 .53404 .6026 .53121 .59781 .52595 Mtetra
.59781 .52595 .6026 .53121 .612 .52837 .60723 .52309 Mtetra
.60723 .52309 .612 .52837 .62143 .52551 .61669 .52022 Mtetra
.61669 .52022 .62143 .52551 .6309 .52265 .62618 .51734 Mtetra
.62618 .51734 .6309 .52265 .6404 .51978 .6357 .51445 Mtetra
.6357 .51445 .6404 .51978 .64993 .5169 .64525 .51155 Mtetra
.64525 .51155 .64993 .5169 .65949 .51401 .65483 .50864 Mtetra
.65483 .50864 .65949 .51401 .66908 .51111 .66445 .50572 Mtetra
.66445 .50572 .66908 .51111 .67871 .50819 .6741 .50279 Mtetra
.6741 .50279 .67871 .50819 .68837 .50527 .68378 .49985 Mtetra
.68378 .49985 .68837 .50527 .69807 .50234 .6935 .4969 Mtetra
.6935 .4969 .69807 .50234 .70779 .4994 .70325 .49394 Mtetra
.70325 .49394 .70779 .4994 .71756 .49645 .71304 .49097 Mtetra
.71304 .49097 .71756 .49645 .72735 .49349 .72285 .48799 Mtetra
.72285 .48799 .72735 .49349 .73718 .49052 .7327 .485 Mtetra
.7327 .485 .73718 .49052 .74704 .48753 .74259 .482 Mtetra
.74259 .482 .74704 .48753 .75694 .48454 .75251 .47899 Mtetra
.75251 .47899 .75694 .48454 .76687 .48154 .76246 .47597 Mtetra
.76246 .47597 .76687 .48154 .77683 .47853 .77245 .47294 Mtetra
.77245 .47294 .77683 .47853 .78683 .4755 .78248 .46989 Mtetra
.78248 .46989 .78683 .4755 .79686 .47247 .79254 .46684 Mtetra
.79254 .46684 .79686 .47247 .80693 .46942 .80263 .46377 Mtetra
.80263 .46377 .80693 .46942 .81704 .46637 .81276 .4607 Mtetra
.81276 .4607 .81704 .46637 .82718 .4633 .82293 .45761 Mtetra
.82293 .45761 .82718 .4633 .83735 .46023 .83313 .45452 Mtetra
.83313 .45452 .83735 .46023 .84756 .45714 .84336 .45141 Mtetra
.84336 .45141 .84756 .45714 .85781 .45404 .85364 .44829 Mtetra
.85364 .44829 .85781 .45404 .8681 .45093 .86395 .44516 Mtetra
.86395 .44516 .8681 .45093 .87841 .44781 .87429 .44202 Mtetra
.87429 .44202 .87841 .44781 .88877 .44468 .88468 .43887 Mtetra
.88468 .43887 .88877 .44468 .89916 .44154 .89509 .4357 Mtetra
.89509 .4357 .89916 .44154 .90959 .43838 .90555 .43253 Mtetra
.90555 .43253 .90959 .43838 .92006 .43522 .91605 .42934 Mtetra
.91605 .42934 .92006 .43522 .93056 .43204 .92658 .42615 Mtetra
.92658 .42615 .93056 .43204 .94111 .42885 .93715 .42294 Mtetra
.93715 .42294 .94111 .42885 .95168 .42565 .94775 .41972 Mtetra
.94775 .41972 .95168 .42565 .9623 .42244 .9584 .41649 Mtetra
.38426 .58429 .38952 .58919 .39825 .58654 .39301 .58162 Mtetra
.39301 .58162 .39825 .58654 .40701 .58388 .40179 .57894 Mtetra
.40179 .57894 .40701 .58388 .4158 .58121 .41059 .57626 Mtetra
.41059 .57626 .4158 .58121 .42462 .57853 .41943 .57357 Mtetra
.41943 .57357 .42462 .57853 .43347 .57585 .42829 .57086 Mtetra
.42829 .57086 .43347 .57585 .44234 .57315 .43719 .56815 Mtetra
.43719 .56815 .44234 .57315 .45125 .57045 .44611 .56543 Mtetra
.44611 .56543 .45125 .57045 .46018 .56774 .45506 .5627 Mtetra
.45506 .5627 .46018 .56774 .46914 .56501 .46404 .55997 Mtetra
.46404 .55997 .46914 .56501 .47814 .56228 .47306 .55722 Mtetra
.47306 .55722 .47814 .56228 .48716 .55955 .4821 .55446 Mtetra
.4821 .55446 .48716 .55955 .49621 .5568 .49117 .5517 Mtetra
.49117 .5517 .49621 .5568 .50529 .55404 .50027 .54893 Mtetra
.50027 .54893 .50529 .55404 .51441 .55127 .50941 .54614 Mtetra
.50941 .54614 .51441 .55127 .52355 .5485 .51857 .54335 Mtetra
.51857 .54335 .52355 .5485 .53272 .54571 .52776 .54055 Mtetra
.52776 .54055 .53272 .54571 .54193 .54292 .53699 .53773 Mtetra
.53699 .53773 .54193 .54292 .55116 .54011 .54624 .53491 Mtetra
.54624 .53491 .55116 .54011 .56043 .5373 .55553 .53208 Mtetra
.55553 .53208 .56043 .5373 .56973 .53448 .56485 .52924 Mtetra
.56485 .52924 .56973 .53448 .57906 .53165 .5742 .52639 Mtetra
.5742 .52639 .57906 .53165 .58842 .52881 .58358 .52353 Mtetra
.58358 .52353 .58842 .52881 .59781 .52595 .59299 .52067 Mtetra
.59299 .52067 .59781 .52595 .60723 .52309 .60244 .51779 Mtetra
.60244 .51779 .60723 .52309 .61669 .52022 .61191 .5149 Mtetra
.61191 .5149 .61669 .52022 .62618 .51734 .62142 .512 Mtetra
.62142 .512 .62618 .51734 .6357 .51445 .63097 .50909 Mtetra
.63097 .50909 .6357 .51445 .64525 .51155 .64054 .50617 Mtetra
.64054 .50617 .64525 .51155 .65483 .50864 .65015 .50324 Mtetra
.65015 .50324 .65483 .50864 .66445 .50572 .65979 .50031 Mtetra
.65979 .50031 .66445 .50572 .6741 .50279 .66946 .49736 Mtetra
.66946 .49736 .6741 .50279 .68378 .49985 .67917 .4944 Mtetra
.67917 .4944 .68378 .49985 .6935 .4969 .68891 .49143 Mtetra
.68891 .49143 .6935 .4969 .70325 .49394 .69868 .48845 Mtetra
.69868 .48845 .70325 .49394 .71304 .49097 .70849 .48546 Mtetra
.70849 .48546 .71304 .49097 .72285 .48799 .71833 .48246 Mtetra
.71833 .48246 .72285 .48799 .7327 .485 .7282 .47945 Mtetra
.7282 .47945 .7327 .485 .74259 .482 .73811 .47643 Mtetra
.73811 .47643 .74259 .482 .75251 .47899 .74806 .4734 Mtetra
.74806 .4734 .75251 .47899 .76246 .47597 .75804 .47036 Mtetra
.75804 .47036 .76246 .47597 .77245 .47294 .76805 .46731 Mtetra
.76805 .46731 .77245 .47294 .78248 .46989 .7781 .46425 Mtetra
.7781 .46425 .78248 .46989 .79254 .46684 .78818 .46117 Mtetra
.78818 .46117 .79254 .46684 .80263 .46377 .7983 .45809 Mtetra
.7983 .45809 .80263 .46377 .81276 .4607 .80846 .45499 Mtetra
.80846 .45499 .81276 .4607 .82293 .45761 .81865 .45189 Mtetra
.81865 .45189 .82293 .45761 .83313 .45452 .82887 .44877 Mtetra
.82887 .44877 .83313 .45452 .84336 .45141 .83914 .44564 Mtetra
.83914 .44564 .84336 .45141 .85364 .44829 .84943 .4425 Mtetra
.84943 .4425 .85364 .44829 .86395 .44516 .85977 .43935 Mtetra
.85977 .43935 .86395 .44516 .87429 .44202 .87014 .43619 Mtetra
.87014 .43619 .87429 .44202 .88468 .43887 .88055 .43302 Mtetra
.88055 .43302 .88468 .43887 .89509 .4357 .891 .42984 Mtetra
.891 .42984 .89509 .4357 .90555 .43253 .90148 .42664 Mtetra
.90148 .42664 .90555 .43253 .91605 .42934 .912 .42343 Mtetra
.912 .42343 .91605 .42934 .92658 .42615 .92256 .42021 Mtetra
.92256 .42021 .92658 .42615 .93715 .42294 .93316 .41698 Mtetra
.93316 .41698 .93715 .42294 .94775 .41972 .9438 .41374 Mtetra
.9438 .41374 .94775 .41972 .9584 .41649 .95447 .41049 Mtetra
.37896 .57936 .38426 .58429 .39301 .58162 .38773 .57667 Mtetra
.38773 .57667 .39301 .58162 .40179 .57894 .39653 .57398 Mtetra
.39653 .57398 .40179 .57894 .41059 .57626 .40535 .57128 Mtetra
.40535 .57128 .41059 .57626 .41943 .57357 .4142 .56857 Mtetra
.4142 .56857 .41943 .57357 .42829 .57086 .42309 .56585 Mtetra
.42309 .56585 .42829 .57086 .43719 .56815 .432 .56313 Mtetra
.432 .56313 .43719 .56815 .44611 .56543 .44094 .56039 Mtetra
.44094 .56039 .44611 .56543 .45506 .5627 .44991 .55764 Mtetra
.44991 .55764 .45506 .5627 .46404 .55997 .45892 .55489 Mtetra
.45892 .55489 .46404 .55997 .47306 .55722 .46795 .55213 Mtetra
.46795 .55213 .47306 .55722 .4821 .55446 .47701 .54935 Mtetra
.47701 .54935 .4821 .55446 .49117 .5517 .4861 .54657 Mtetra
.4861 .54657 .49117 .5517 .50027 .54893 .49522 .54378 Mtetra
.49522 .54378 .50027 .54893 .50941 .54614 .50437 .54098 Mtetra
.50437 .54098 .50941 .54614 .51857 .54335 .51356 .53817 Mtetra
.51356 .53817 .51857 .54335 .52776 .54055 .52277 .53535 Mtetra
.52277 .53535 .52776 .54055 .53699 .53773 .53202 .53252 Mtetra
.53202 .53252 .53699 .53773 .54624 .53491 .54129 .52968 Mtetra
.54129 .52968 .54624 .53491 .55553 .53208 .5506 .52683 Mtetra
.5506 .52683 .55553 .53208 .56485 .52924 .55994 .52397 Mtetra
.55994 .52397 .56485 .52924 .5742 .52639 .56931 .52111 Mtetra
.56931 .52111 .5742 .52639 .58358 .52353 .57871 .51823 Mtetra
.57871 .51823 .58358 .52353 .59299 .52067 .58815 .51534 Mtetra
.58815 .51534 .59299 .52067 .60244 .51779 .59761 .51245 Mtetra
.59761 .51245 .60244 .51779 .61191 .5149 .60711 .50954 Mtetra
.60711 .50954 .61191 .5149 .62142 .512 .61664 .50662 Mtetra
.61664 .50662 .62142 .512 .63097 .50909 .6262 .5037 Mtetra
.6262 .5037 .63097 .50909 .64054 .50617 .6358 .50076 Mtetra
.6358 .50076 .64054 .50617 .65015 .50324 .64543 .49781 Mtetra
.64543 .49781 .65015 .50324 .65979 .50031 .65509 .49486 Mtetra
.65509 .49486 .65979 .50031 .66946 .49736 .66479 .49189 Mtetra
.66479 .49189 .66946 .49736 .67917 .4944 .67452 .48891 Mtetra
.67452 .48891 .67917 .4944 .68891 .49143 .68428 .48592 Mtetra
.68428 .48592 .68891 .49143 .69868 .48845 .69408 .48293 Mtetra
.69408 .48293 .69868 .48845 .70849 .48546 .70391 .47992 Mtetra
.70391 .47992 .70849 .48546 .71833 .48246 .71377 .4769 Mtetra
.71377 .4769 .71833 .48246 .7282 .47945 .72367 .47387 Mtetra
.72367 .47387 .7282 .47945 .73811 .47643 .73361 .47083 Mtetra
.73361 .47083 .73811 .47643 .74806 .4734 .74357 .46778 Mtetra
.74357 .46778 .74806 .4734 .75804 .47036 .75358 .46472 Mtetra
.75358 .46472 .75804 .47036 .76805 .46731 .76362 .46165 Mtetra
.76362 .46165 .76805 .46731 .7781 .46425 .77369 .45856 Mtetra
.77369 .45856 .7781 .46425 .78818 .46117 .7838 .45547 Mtetra
.7838 .45547 .78818 .46117 .7983 .45809 .79394 .45237 Mtetra
.79394 .45237 .7983 .45809 .80846 .45499 .80412 .44925 Mtetra
.80412 .44925 .80846 .45499 .81865 .45189 .81434 .44612 Mtetra
.81434 .44612 .81865 .45189 .82887 .44877 .82459 .44299 Mtetra
.82459 .44299 .82887 .44877 .83914 .44564 .83488 .43984 Mtetra
.83488 .43984 .83914 .44564 .84943 .4425 .84521 .43668 Mtetra
.84521 .43668 .84943 .4425 .85977 .43935 .85557 .43351 Mtetra
.85557 .43351 .85977 .43935 .87014 .43619 .86597 .43033 Mtetra
.86597 .43033 .87014 .43619 .88055 .43302 .8764 .42713 Mtetra
.8764 .42713 .88055 .43302 .891 .42984 .88688 .42393 Mtetra
.88688 .42393 .891 .42984 .90148 .42664 .89739 .42071 Mtetra
.89739 .42071 .90148 .42664 .912 .42343 .90794 .41748 Mtetra
.90794 .41748 .912 .42343 .92256 .42021 .91852 .41424 Mtetra
.91852 .41424 .92256 .42021 .93316 .41698 .92915 .41099 Mtetra
.92915 .41099 .93316 .41698 .9438 .41374 .93981 .40773 Mtetra
.93981 .40773 .9438 .41374 .95447 .41049 .95051 .40445 Mtetra
.37364 .5744 .37896 .57936 .38773 .57667 .38242 .5717 Mtetra
.38242 .5717 .38773 .57667 .39653 .57398 .39123 .56899 Mtetra
.39123 .56899 .39653 .57398 .40535 .57128 .40008 .56627 Mtetra
.40008 .56627 .40535 .57128 .4142 .56857 .40895 .56355 Mtetra
.40895 .56355 .4142 .56857 .42309 .56585 .41785 .56081 Mtetra
.41785 .56081 .42309 .56585 .432 .56313 .42678 .55807 Mtetra
.42678 .55807 .432 .56313 .44094 .56039 .43574 .55531 Mtetra
.43574 .55531 .44094 .56039 .44991 .55764 .44473 .55255 Mtetra
.44473 .55255 .44991 .55764 .45892 .55489 .45375 .54978 Mtetra
.45375 .54978 .45892 .55489 .46795 .55213 .4628 .547 Mtetra
.4628 .547 .46795 .55213 .47701 .54935 .47189 .54421 Mtetra
.47189 .54421 .47701 .54935 .4861 .54657 .481 .54141 Mtetra
.481 .54141 .4861 .54657 .49522 .54378 .49014 .5386 Mtetra
.49014 .5386 .49522 .54378 .50437 .54098 .49931 .53578 Mtetra
.49931 .53578 .50437 .54098 .51356 .53817 .50851 .53296 Mtetra
.50851 .53296 .51356 .53817 .52277 .53535 .51775 .53012 Mtetra
.51775 .53012 .52277 .53535 .53202 .53252 .52701 .52727 Mtetra
.52701 .52727 .53202 .53252 .54129 .52968 .53631 .52441 Mtetra
.53631 .52441 .54129 .52968 .5506 .52683 .54564 .52155 Mtetra
.54564 .52155 .5506 .52683 .55994 .52397 .555 .51867 Mtetra
.555 .51867 .55994 .52397 .56931 .52111 .56439 .51579 Mtetra
.56439 .51579 .56931 .52111 .57871 .51823 .57381 .51289 Mtetra
.57381 .51289 .57871 .51823 .58815 .51534 .58327 .50999 Mtetra
.58327 .50999 .58815 .51534 .59761 .51245 .59276 .50707 Mtetra
.59276 .50707 .59761 .51245 .60711 .50954 .60228 .50415 Mtetra
.60228 .50415 .60711 .50954 .61664 .50662 .61183 .50121 Mtetra
.61183 .50121 .61664 .50662 .6262 .5037 .62141 .49827 Mtetra
.62141 .49827 .6262 .5037 .6358 .50076 .63103 .49531 Mtetra
.63103 .49531 .6358 .50076 .64543 .49781 .64068 .49235 Mtetra
.64068 .49235 .64543 .49781 .65509 .49486 .65037 .48937 Mtetra
.65037 .48937 .65509 .49486 .66479 .49189 .66009 .48638 Mtetra
.66009 .48638 .66479 .49189 .67452 .48891 .66984 .48339 Mtetra
.66984 .48339 .67452 .48891 .68428 .48592 .67963 .48038 Mtetra
.67963 .48038 .68428 .48592 .69408 .48293 .68945 .47736 Mtetra
.68945 .47736 .69408 .48293 .70391 .47992 .6993 .47434 Mtetra
.6993 .47434 .70391 .47992 .71377 .4769 .70919 .4713 Mtetra
.70919 .4713 .71377 .4769 .72367 .47387 .71911 .46825 Mtetra
.71911 .46825 .72367 .47387 .73361 .47083 .72907 .46519 Mtetra
.72907 .46519 .73361 .47083 .74357 .46778 .73906 .46212 Mtetra
.73906 .46212 .74357 .46778 .75358 .46472 .74909 .45904 Mtetra
.74909 .45904 .75358 .46472 .76362 .46165 .75915 .45595 Mtetra
.75915 .45595 .76362 .46165 .77369 .45856 .76925 .45284 Mtetra
.76925 .45284 .77369 .45856 .7838 .45547 .77938 .44973 Mtetra
.77938 .44973 .7838 .45547 .79394 .45237 .78955 .44661 Mtetra
.78955 .44661 .79394 .45237 .80412 .44925 .79976 .44347 Mtetra
.79976 .44347 .80412 .44925 .81434 .44612 .81 .44032 Mtetra
.81 .44032 .81434 .44612 .82459 .44299 .82028 .43717 Mtetra
.82028 .43717 .82459 .44299 .83488 .43984 .8306 .434 Mtetra
.8306 .434 .83488 .43984 .84521 .43668 .84095 .43082 Mtetra
.84095 .43082 .84521 .43668 .85557 .43351 .85134 .42762 Mtetra
.85134 .42762 .85557 .43351 .86597 .43033 .86176 .42442 Mtetra
.86176 .42442 .86597 .43033 .8764 .42713 .87223 .42121 Mtetra
.87223 .42121 .8764 .42713 .88688 .42393 .88273 .41798 Mtetra
.88273 .41798 .88688 .42393 .89739 .42071 .89327 .41474 Mtetra
.89327 .41474 .89739 .42071 .90794 .41748 .90384 .41149 Mtetra
.90384 .41149 .90794 .41748 .91852 .41424 .91446 .40823 Mtetra
.91446 .40823 .91852 .41424 .92915 .41099 .92511 .40496 Mtetra
.92511 .40496 .92915 .41099 .93981 .40773 .9358 .40167 Mtetra
.9358 .40167 .93981 .40773 .95051 .40445 .94653 .39838 Mtetra
.36828 .56941 .37364 .5744 .38242 .5717 .37708 .56669 Mtetra
.37708 .56669 .38242 .5717 .39123 .56899 .38591 .56397 Mtetra
.38591 .56397 .39123 .56899 .40008 .56627 .39477 .56123 Mtetra
.39477 .56123 .40008 .56627 .40895 .56355 .40366 .55849 Mtetra
.40366 .55849 .40895 .56355 .41785 .56081 .41258 .55574 Mtetra
.41258 .55574 .41785 .56081 .42678 .55807 .42153 .55298 Mtetra
.42153 .55298 .42678 .55807 .43574 .55531 .43051 .55021 Mtetra
.43051 .55021 .43574 .55531 .44473 .55255 .43952 .54743 Mtetra
.43952 .54743 .44473 .55255 .45375 .54978 .44856 .54464 Mtetra
.44856 .54464 .45375 .54978 .4628 .547 .45763 .54184 Mtetra
.45763 .54184 .4628 .547 .47189 .54421 .46673 .53903 Mtetra
.46673 .53903 .47189 .54421 .481 .54141 .47586 .53622 Mtetra
.47586 .53622 .481 .54141 .49014 .5386 .48502 .53339 Mtetra
.48502 .53339 .49014 .5386 .49931 .53578 .49422 .53056 Mtetra
.49422 .53056 .49931 .53578 .50851 .53296 .50344 .52771 Mtetra
.50344 .52771 .50851 .53296 .51775 .53012 .51269 .52485 Mtetra
.51269 .52485 .51775 .53012 .52701 .52727 .52198 .52199 Mtetra
.52198 .52199 .52701 .52727 .53631 .52441 .5313 .51912 Mtetra
.5313 .51912 .53631 .52441 .54564 .52155 .54064 .51623 Mtetra
.54064 .51623 .54564 .52155 .555 .51867 .55003 .51334 Mtetra
.55003 .51334 .555 .51867 .56439 .51579 .55944 .51043 Mtetra
.55944 .51043 .56439 .51579 .57381 .51289 .56888 .50752 Mtetra
.56888 .50752 .57381 .51289 .58327 .50999 .57836 .5046 Mtetra
.57836 .5046 .58327 .50999 .59276 .50707 .58787 .50166 Mtetra
.58787 .50166 .59276 .50707 .60228 .50415 .59741 .49872 Mtetra
.59741 .49872 .60228 .50415 .61183 .50121 .60699 .49577 Mtetra
.60699 .49577 .61183 .50121 .62141 .49827 .61659 .4928 Mtetra
.61659 .4928 .62141 .49827 .63103 .49531 .62623 .48983 Mtetra
.62623 .48983 .63103 .49531 .64068 .49235 .63591 .48684 Mtetra
.63591 .48684 .64068 .49235 .65037 .48937 .64562 .48385 Mtetra
.64562 .48385 .65037 .48937 .66009 .48638 .65536 .48084 Mtetra
.65536 .48084 .66009 .48638 .66984 .48339 .66513 .47783 Mtetra
.66513 .47783 .66984 .48339 .67963 .48038 .67494 .4748 Mtetra
.67494 .4748 .67963 .48038 .68945 .47736 .68479 .47177 Mtetra
.68479 .47177 .68945 .47736 .6993 .47434 .69466 .46872 Mtetra
.69466 .46872 .6993 .47434 .70919 .4713 .70458 .46566 Mtetra
.70458 .46566 .70919 .4713 .71911 .46825 .71452 .46259 Mtetra
.71452 .46259 .71911 .46825 .72907 .46519 .7245 .45951 Mtetra
.7245 .45951 .72907 .46519 .73906 .46212 .73452 .45642 Mtetra
.73452 .45642 .73906 .46212 .74909 .45904 .74457 .45332 Mtetra
.74457 .45332 .74909 .45904 .75915 .45595 .75466 .45021 Mtetra
.75466 .45021 .75915 .45595 .76925 .45284 .76478 .44709 Mtetra
.76478 .44709 .76925 .45284 .77938 .44973 .77494 .44395 Mtetra
.77494 .44395 .77938 .44973 .78955 .44661 .78514 .44081 Mtetra
.78514 .44081 .78955 .44661 .79976 .44347 .79537 .43765 Mtetra
.79537 .43765 .79976 .44347 .81 .44032 .80564 .43448 Mtetra
.80564 .43448 .81 .44032 .82028 .43717 .81594 .43131 Mtetra
.81594 .43131 .82028 .43717 .8306 .434 .82628 .42812 Mtetra
.82628 .42812 .8306 .434 .84095 .43082 .83666 .42491 Mtetra
.83666 .42491 .84095 .43082 .85134 .42762 .84708 .4217 Mtetra
.84708 .4217 .85134 .42762 .86176 .42442 .85753 .41848 Mtetra
.85753 .41848 .86176 .42442 .87223 .42121 .86802 .41524 Mtetra
.86802 .41524 .87223 .42121 .88273 .41798 .87855 .41199 Mtetra
.87855 .41199 .88273 .41798 .89327 .41474 .88912 .40873 Mtetra
.88912 .40873 .89327 .41474 .90384 .41149 .89972 .40546 Mtetra
.89972 .40546 .90384 .41149 .91446 .40823 .91036 .40218 Mtetra
.91036 .40218 .91446 .40823 .92511 .40496 .92104 .39888 Mtetra
.92104 .39888 .92511 .40496 .9358 .40167 .93176 .39558 Mtetra
.93176 .39558 .9358 .40167 .94653 .39838 .94252 .39226 Mtetra
.36288 .56439 .36828 .56941 .37708 .56669 .37171 .56165 Mtetra
.37171 .56165 .37708 .56669 .38591 .56397 .38056 .55891 Mtetra
.38056 .55891 .38591 .56397 .39477 .56123 .38944 .55616 Mtetra
.38944 .55616 .39477 .56123 .40366 .55849 .39834 .5534 Mtetra
.39834 .5534 .40366 .55849 .41258 .55574 .40728 .55063 Mtetra
.40728 .55063 .41258 .55574 .42153 .55298 .41625 .54786 Mtetra
.41625 .54786 .42153 .55298 .43051 .55021 .42525 .54507 Mtetra
.42525 .54507 .43051 .55021 .43952 .54743 .43428 .54227 Mtetra
.43428 .54227 .43952 .54743 .44856 .54464 .44334 .53947 Mtetra
.44334 .53947 .44856 .54464 .45763 .54184 .45243 .53665 Mtetra
.45243 .53665 .45763 .54184 .46673 .53903 .46155 .53383 Mtetra
.46155 .53383 .46673 .53903 .47586 .53622 .4707 .53099 Mtetra
.4707 .53099 .47586 .53622 .48502 .53339 .47988 .52815 Mtetra
.47988 .52815 .48502 .53339 .49422 .53056 .48909 .52529 Mtetra
.48909 .52529 .49422 .53056 .50344 .52771 .49833 .52243 Mtetra
.49833 .52243 .50344 .52771 .51269 .52485 .50761 .51956 Mtetra
.50761 .51956 .51269 .52485 .52198 .52199 .51691 .51668 Mtetra
.51691 .51668 .52198 .52199 .5313 .51912 .52625 .51378 Mtetra
.52625 .51378 .5313 .51912 .54064 .51623 .53562 .51088 Mtetra
.53562 .51088 .54064 .51623 .55003 .51334 .54502 .50797 Mtetra
.54502 .50797 .55003 .51334 .55944 .51043 .55446 .50505 Mtetra
.55446 .50505 .55944 .51043 .56888 .50752 .56392 .50212 Mtetra
.56392 .50212 .56888 .50752 .57836 .5046 .57342 .49917 Mtetra
.57342 .49917 .57836 .5046 .58787 .50166 .58295 .49622 Mtetra
.58295 .49622 .58787 .50166 .59741 .49872 .59251 .49326 Mtetra
.59251 .49326 .59741 .49872 .60699 .49577 .60211 .49029 Mtetra
.60211 .49029 .60699 .49577 .61659 .4928 .61174 .4873 Mtetra
.61174 .4873 .61659 .4928 .62623 .48983 .62141 .48431 Mtetra
.62141 .48431 .62623 .48983 .63591 .48684 .6311 .48131 Mtetra
.6311 .48131 .63591 .48684 .64562 .48385 .64083 .47829 Mtetra
.64083 .47829 .64562 .48385 .65536 .48084 .6506 .47527 Mtetra
.6506 .47527 .65536 .48084 .66513 .47783 .66039 .47223 Mtetra
.66039 .47223 .66513 .47783 .67494 .4748 .67023 .46919 Mtetra
.67023 .46919 .67494 .4748 .68479 .47177 .68009 .46613 Mtetra
.68009 .46613 .68479 .47177 .69466 .46872 .69 .46307 Mtetra
.69 .46307 .69466 .46872 .70458 .46566 .69993 .45999 Mtetra
.69993 .45999 .70458 .46566 .71452 .46259 .7099 .4569 Mtetra
.7099 .4569 .71452 .46259 .7245 .45951 .71991 .4538 Mtetra
.71991 .4538 .7245 .45951 .73452 .45642 .72995 .45069 Mtetra
.72995 .45069 .73452 .45642 .74457 .45332 .74003 .44757 Mtetra
.74003 .44757 .74457 .45332 .75466 .45021 .75014 .44444 Mtetra
.75014 .44444 .75466 .45021 .76478 .44709 .76029 .44129 Mtetra
.76029 .44129 .76478 .44709 .77494 .44395 .77047 .43814 Mtetra
.77047 .43814 .77494 .44395 .78514 .44081 .78069 .43497 Mtetra
.78069 .43497 .78514 .44081 .79537 .43765 .79095 .4318 Mtetra
.79095 .4318 .79537 .43765 .80564 .43448 .80124 .42861 Mtetra
.80124 .42861 .80564 .43448 .81594 .43131 .81158 .42541 Mtetra
.81158 .42541 .81594 .43131 .82628 .42812 .82194 .4222 Mtetra
.82194 .4222 .82628 .42812 .83666 .42491 .83235 .41897 Mtetra
.83235 .41897 .83666 .42491 .84708 .4217 .84279 .41574 Mtetra
.84279 .41574 .84708 .4217 .85753 .41848 .85327 .41249 Mtetra
.85327 .41249 .85753 .41848 .86802 .41524 .86379 .40924 Mtetra
.86379 .40924 .86802 .41524 .87855 .41199 .87434 .40597 Mtetra
.87434 .40597 .87855 .41199 .88912 .40873 .88494 .40268 Mtetra
.88494 .40268 .88912 .40873 .89972 .40546 .89557 .39939 Mtetra
.89557 .39939 .89972 .40546 .91036 .40218 .90624 .39609 Mtetra
.90624 .39609 .91036 .40218 .92104 .39888 .91695 .39277 Mtetra
.91695 .39277 .92104 .39888 .93176 .39558 .9277 .38944 Mtetra
.9277 .38944 .93176 .39558 .94252 .39226 .93849 .3861 Mtetra
.35746 .55933 .36288 .56439 .37171 .56165 .3663 .55659 Mtetra
.3663 .55659 .37171 .56165 .38056 .55891 .37517 .55383 Mtetra
.37517 .55383 .38056 .55891 .38944 .55616 .38406 .55106 Mtetra
.38406 .55106 .38944 .55616 .39834 .5534 .39299 .54828 Mtetra
.39299 .54828 .39834 .5534 .40728 .55063 .40195 .5455 Mtetra
.40195 .5455 .40728 .55063 .41625 .54786 .41094 .5427 Mtetra
.41094 .5427 .41625 .54786 .42525 .54507 .41995 .5399 Mtetra
.41995 .5399 .42525 .54507 .43428 .54227 .429 .53708 Mtetra
.429 .53708 .43428 .54227 .44334 .53947 .43808 .53426 Mtetra
.43808 .53426 .44334 .53947 .45243 .53665 .44719 .53143 Mtetra
.44719 .53143 .45243 .53665 .46155 .53383 .45633 .52859 Mtetra
.45633 .52859 .46155 .53383 .4707 .53099 .4655 .52573 Mtetra
.4655 .52573 .4707 .53099 .47988 .52815 .4747 .52287 Mtetra
.4747 .52287 .47988 .52815 .48909 .52529 .48393 .52 Mtetra
.48393 .52 .48909 .52529 .49833 .52243 .49319 .51712 Mtetra
.49319 .51712 .49833 .52243 .50761 .51956 .50249 .51423 Mtetra
.50249 .51423 .50761 .51956 .51691 .51668 .51182 .51133 Mtetra
.51182 .51133 .51691 .51668 .52625 .51378 .52117 .50842 Mtetra
.52117 .50842 .52625 .51378 .53562 .51088 .53056 .5055 Mtetra
.53056 .5055 .53562 .51088 .54502 .50797 .53999 .50257 Mtetra
.53999 .50257 .54502 .50797 .55446 .50505 .54944 .49963 Mtetra
.54944 .49963 .55446 .50505 .56392 .50212 .55893 .49668 Mtetra
.55893 .49668 .56392 .50212 .57342 .49917 .56845 .49372 Mtetra
.56845 .49372 .57342 .49917 .58295 .49622 .578 .49075 Mtetra
.578 .49075 .58295 .49622 .59251 .49326 .58759 .48776 Mtetra
.58759 .48776 .59251 .49326 .60211 .49029 .59721 .48477 Mtetra
.59721 .48477 .60211 .49029 .61174 .4873 .60686 .48177 Mtetra
.60686 .48177 .61174 .4873 .62141 .48431 .61654 .47876 Mtetra
.61654 .47876 .62141 .48431 .6311 .48131 .62626 .47574 Mtetra
.62626 .47574 .6311 .48131 .64083 .47829 .63602 .4727 Mtetra
.63602 .4727 .64083 .47829 .6506 .47527 .64581 .46966 Mtetra
.64581 .46966 .6506 .47527 .66039 .47223 .65563 .4666 Mtetra
.65563 .4666 .66039 .47223 .67023 .46919 .66548 .46354 Mtetra
.66548 .46354 .67023 .46919 .68009 .46613 .67537 .46046 Mtetra
.67537 .46046 .68009 .46613 .69 .46307 .6853 .45738 Mtetra
.6853 .45738 .69 .46307 .69993 .45999 .69526 .45428 Mtetra
.69526 .45428 .69993 .45999 .7099 .4569 .70525 .45117 Mtetra
.70525 .45117 .7099 .4569 .71991 .4538 .71528 .44805 Mtetra
.71528 .44805 .71991 .4538 .72995 .45069 .72535 .44492 Mtetra
.72535 .44492 .72995 .45069 .74003 .44757 .73545 .44178 Mtetra
.73545 .44178 .74003 .44757 .75014 .44444 .74559 .43862 Mtetra
.74559 .43862 .75014 .44444 .76029 .44129 .75576 .43546 Mtetra
.75576 .43546 .76029 .44129 .77047 .43814 .76597 .43229 Mtetra
.76597 .43229 .77047 .43814 .78069 .43497 .77622 .4291 Mtetra
.77622 .4291 .78069 .43497 .79095 .4318 .7865 .4259 Mtetra
.7865 .4259 .79095 .4318 .80124 .42861 .79682 .42269 Mtetra
.79682 .42269 .80124 .42861 .81158 .42541 .80718 .41947 Mtetra
.80718 .41947 .81158 .42541 .82194 .4222 .81757 .41624 Mtetra
.81757 .41624 .82194 .4222 .83235 .41897 .82801 .41299 Mtetra
.82801 .41299 .83235 .41897 .84279 .41574 .83847 .40974 Mtetra
.83847 .40974 .84279 .41574 .85327 .41249 .84898 .40647 Mtetra
.84898 .40647 .85327 .41249 .86379 .40924 .85953 .40319 Mtetra
.85953 .40319 .86379 .40924 .87434 .40597 .87011 .3999 Mtetra
.87011 .3999 .87434 .40597 .88494 .40268 .88073 .3966 Mtetra
.88073 .3966 .88494 .40268 .89557 .39939 .89139 .39328 Mtetra
.89139 .39328 .89557 .39939 .90624 .39609 .90209 .38995 Mtetra
.90209 .38995 .90624 .39609 .91695 .39277 .91283 .38661 Mtetra
.91283 .38661 .91695 .39277 .9277 .38944 .92361 .38326 Mtetra
.92361 .38326 .9277 .38944 .93849 .3861 .93443 .3799 Mtetra
.352 .55425 .35746 .55933 .3663 .55659 .36086 .55149 Mtetra
.36086 .55149 .3663 .55659 .37517 .55383 .36975 .54871 Mtetra
.36975 .54871 .37517 .55383 .38406 .55106 .37866 .54593 Mtetra
.37866 .54593 .38406 .55106 .39299 .54828 .38761 .54313 Mtetra
.38761 .54313 .39299 .54828 .40195 .5455 .39658 .54033 Mtetra
.39658 .54033 .40195 .5455 .41094 .5427 .40559 .53752 Mtetra
.40559 .53752 .41094 .5427 .41995 .5399 .41463 .5347 Mtetra
.41463 .5347 .41995 .5399 .429 .53708 .42369 .53187 Mtetra
.42369 .53187 .429 .53708 .43808 .53426 .43279 .52902 Mtetra
.43279 .52902 .43808 .53426 .44719 .53143 .44192 .52617 Mtetra
.44192 .52617 .44719 .53143 .45633 .52859 .45108 .52331 Mtetra
.45108 .52331 .45633 .52859 .4655 .52573 .46027 .52044 Mtetra
.46027 .52044 .4655 .52573 .4747 .52287 .46949 .51756 Mtetra
.46949 .51756 .4747 .52287 .48393 .52 .47874 .51468 Mtetra
.47874 .51468 .48393 .52 .49319 .51712 .48802 .51178 Mtetra
.48802 .51178 .49319 .51712 .50249 .51423 .49734 .50887 Mtetra
.49734 .50887 .50249 .51423 .51182 .51133 .50669 .50595 Mtetra
.50669 .50595 .51182 .51133 .52117 .50842 .51606 .50302 Mtetra
.51606 .50302 .52117 .50842 .53056 .5055 .52548 .50008 Mtetra
.52548 .50008 .53056 .5055 .53999 .50257 .53492 .49713 Mtetra
.53492 .49713 .53999 .50257 .54944 .49963 .5444 .49417 Mtetra
.5444 .49417 .54944 .49963 .55893 .49668 .5539 .4912 Mtetra
.5539 .4912 .55893 .49668 .56845 .49372 .56345 .48822 Mtetra
.56345 .48822 .56845 .49372 .578 .49075 .57302 .48523 Mtetra
.57302 .48523 .578 .49075 .58759 .48776 .58263 .48223 Mtetra
.58263 .48223 .58759 .48776 .59721 .48477 .59227 .47922 Mtetra
.59227 .47922 .59721 .48477 .60686 .48177 .60195 .4762 Mtetra
.60195 .4762 .60686 .48177 .61654 .47876 .61165 .47317 Mtetra
.61165 .47317 .61654 .47876 .62626 .47574 .6214 .47013 Mtetra
.6214 .47013 .62626 .47574 .63602 .4727 .63117 .46707 Mtetra
.63117 .46707 .63602 .4727 .64581 .46966 .64098 .46401 Mtetra
.64098 .46401 .64581 .46966 .65563 .4666 .65083 .46094 Mtetra
.65083 .46094 .65563 .4666 .66548 .46354 .66071 .45785 Mtetra
.66071 .45785 .66548 .46354 .67537 .46046 .67062 .45476 Mtetra
.67062 .45476 .67537 .46046 .6853 .45738 .68057 .45165 Mtetra
.68057 .45165 .6853 .45738 .69526 .45428 .69055 .44853 Mtetra
.69055 .44853 .69526 .45428 .70525 .45117 .70057 .4454 Mtetra
.70057 .4454 .70525 .45117 .71528 .44805 .71063 .44226 Mtetra
.71063 .44226 .71528 .44805 .72535 .44492 .72072 .43911 Mtetra
.72072 .43911 .72535 .44492 .73545 .44178 .73085 .43595 Mtetra
.73085 .43595 .73545 .44178 .74559 .43862 .74101 .43277 Mtetra
.74101 .43277 .74559 .43862 .75576 .43546 .75121 .42959 Mtetra
.75121 .42959 .75576 .43546 .76597 .43229 .76144 .42639 Mtetra
.76144 .42639 .76597 .43229 .77622 .4291 .77172 .42319 Mtetra
.77172 .42319 .77622 .4291 .7865 .4259 .78203 .41997 Mtetra
.78203 .41997 .7865 .4259 .79682 .42269 .79237 .41674 Mtetra
.79237 .41674 .79682 .42269 .80718 .41947 .80275 .41349 Mtetra
.80275 .41349 .80718 .41947 .81757 .41624 .81318 .41024 Mtetra
.81318 .41024 .81757 .41624 .82801 .41299 .82363 .40697 Mtetra
.82363 .40697 .82801 .41299 .83847 .40974 .83413 .4037 Mtetra
.83413 .4037 .83847 .40974 .84898 .40647 .84466 .40041 Mtetra
.84466 .40041 .84898 .40647 .85953 .40319 .85524 .3971 Mtetra
.85524 .3971 .85953 .40319 .87011 .3999 .86585 .39379 Mtetra
.86585 .39379 .87011 .3999 .88073 .3966 .8765 .39047 Mtetra
.8765 .39047 .88073 .3966 .89139 .39328 .88719 .38713 Mtetra
.88719 .38713 .89139 .39328 .90209 .38995 .89791 .38378 Mtetra
.89791 .38378 .90209 .38995 .91283 .38661 .90868 .38041 Mtetra
.90868 .38041 .91283 .38661 .92361 .38326 .91949 .37704 Mtetra
.91949 .37704 .92361 .38326 .93443 .3799 .93033 .37365 Mtetra
.34651 .54914 .352 .55425 .36086 .55149 .35539 .54636 Mtetra
.35539 .54636 .36086 .55149 .36975 .54871 .36429 .54356 Mtetra
.36429 .54356 .36975 .54871 .37866 .54593 .37322 .54076 Mtetra
.37322 .54076 .37866 .54593 .38761 .54313 .38219 .53795 Mtetra
.38219 .53795 .38761 .54313 .39658 .54033 .39118 .53513 Mtetra
.39118 .53513 .39658 .54033 .40559 .53752 .40021 .5323 Mtetra
.40021 .5323 .40559 .53752 .41463 .5347 .40926 .52946 Mtetra
.40926 .52946 .41463 .5347 .42369 .53187 .41835 .52661 Mtetra
.41835 .52661 .42369 .53187 .43279 .52902 .42747 .52375 Mtetra
.42747 .52375 .43279 .52902 .44192 .52617 .43661 .52089 Mtetra
.43661 .52089 .44192 .52617 .45108 .52331 .44579 .51801 Mtetra
.44579 .51801 .45108 .52331 .46027 .52044 .455 .51512 Mtetra
.455 .51512 .46027 .52044 .46949 .51756 .46424 .51222 Mtetra
.46424 .51222 .46949 .51756 .47874 .51468 .47351 .50932 Mtetra
.47351 .50932 .47874 .51468 .48802 .51178 .48282 .5064 Mtetra
.48282 .5064 .48802 .51178 .49734 .50887 .49216 .50347 Mtetra
.49216 .50347 .49734 .50887 .50669 .50595 .50152 .50053 Mtetra
.50152 .50053 .50669 .50595 .51606 .50302 .51092 .49759 Mtetra
.51092 .49759 .51606 .50302 .52548 .50008 .52036 .49463 Mtetra
.52036 .49463 .52548 .50008 .53492 .49713 .52982 .49166 Mtetra
.52982 .49166 .53492 .49713 .5444 .49417 .53932 .48868 Mtetra
.53932 .48868 .5444 .49417 .5539 .4912 .54885 .48569 Mtetra
.54885 .48569 .5539 .4912 .56345 .48822 .55841 .4827 Mtetra
.55841 .4827 .56345 .48822 .57302 .48523 .56801 .47969 Mtetra
.56801 .47969 .57302 .48523 .58263 .48223 .57764 .47667 Mtetra
.57764 .47667 .58263 .48223 .59227 .47922 .5873 .47364 Mtetra
.5873 .47364 .59227 .47922 .60195 .4762 .597 .4706 Mtetra
.597 .4706 .60195 .4762 .61165 .47317 .60673 .46754 Mtetra
.60673 .46754 .61165 .47317 .6214 .47013 .6165 .46448 Mtetra
.6165 .46448 .6214 .47013 .63117 .46707 .62629 .46141 Mtetra
.62629 .46141 .63117 .46707 .64098 .46401 .63613 .45833 Mtetra
.63613 .45833 .64098 .46401 .65083 .46094 .646 .45523 Mtetra
.646 .45523 .65083 .46094 .66071 .45785 .6559 .45213 Mtetra
.6559 .45213 .66071 .45785 .67062 .45476 .66584 .44901 Mtetra
.66584 .44901 .67062 .45476 .68057 .45165 .67581 .44588 Mtetra
.67581 .44588 .68057 .45165 .69055 .44853 .68582 .44275 Mtetra
.68582 .44275 .69055 .44853 .70057 .4454 .69586 .4396 Mtetra
.69586 .4396 .70057 .4454 .71063 .44226 .70594 .43644 Mtetra
.70594 .43644 .71063 .44226 .72072 .43911 .71606 .43326 Mtetra
.71606 .43326 .72072 .43911 .73085 .43595 .72621 .43008 Mtetra
.72621 .43008 .73085 .43595 .74101 .43277 .7364 .42689 Mtetra
.7364 .42689 .74101 .43277 .75121 .42959 .74662 .42368 Mtetra
.74662 .42368 .75121 .42959 .76144 .42639 .75688 .42046 Mtetra
.75688 .42046 .76144 .42639 .77172 .42319 .76718 .41723 Mtetra
.76718 .41723 .77172 .42319 .78203 .41997 .77752 .41399 Mtetra
.77752 .41399 .78203 .41997 .79237 .41674 .78789 .41074 Mtetra
.78789 .41074 .79237 .41674 .80275 .41349 .7983 .40748 Mtetra
.7983 .40748 .80275 .41349 .81318 .41024 .80875 .4042 Mtetra
.80875 .4042 .81318 .41024 .82363 .40697 .81923 .40091 Mtetra
.81923 .40091 .82363 .40697 .83413 .4037 .82976 .39761 Mtetra
.82976 .39761 .83413 .4037 .84466 .40041 .84032 .3943 Mtetra
.84032 .3943 .84466 .40041 .85524 .3971 .85092 .39098 Mtetra
.85092 .39098 .85524 .3971 .86585 .39379 .86156 .38764 Mtetra
.86156 .38764 .86585 .39379 .8765 .39047 .87224 .38429 Mtetra
.87224 .38429 .8765 .39047 .88719 .38713 .88295 .38093 Mtetra
.88295 .38093 .88719 .38713 .89791 .38378 .89371 .37756 Mtetra
.89371 .37756 .89791 .38378 .90868 .38041 .9045 .37418 Mtetra
.9045 .37418 .90868 .38041 .91949 .37704 .91534 .37078 Mtetra
.91534 .37078 .91949 .37704 .93033 .37365 .92622 .36737 Mtetra
.34098 .54399 .34651 .54914 .35539 .54636 .34988 .54119 Mtetra
.34988 .54119 .35539 .54636 .36429 .54356 .3588 .53838 Mtetra
.3588 .53838 .36429 .54356 .37322 .54076 .36775 .53557 Mtetra
.36775 .53557 .37322 .54076 .38219 .53795 .37674 .53274 Mtetra
.37674 .53274 .38219 .53795 .39118 .53513 .38575 .5299 Mtetra
.38575 .5299 .39118 .53513 .40021 .5323 .39479 .52705 Mtetra
.39479 .52705 .40021 .5323 .40926 .52946 .40387 .52419 Mtetra
.40387 .52419 .40926 .52946 .41835 .52661 .41297 .52133 Mtetra
.41297 .52133 .41835 .52661 .42747 .52375 .42211 .51845 Mtetra
.42211 .51845 .42747 .52375 .43661 .52089 .43128 .51557 Mtetra
.43128 .51557 .43661 .52089 .44579 .51801 .44047 .51267 Mtetra
.44047 .51267 .44579 .51801 .455 .51512 .4497 .50976 Mtetra
.4497 .50976 .455 .51512 .46424 .51222 .45897 .50685 Mtetra
.45897 .50685 .46424 .51222 .47351 .50932 .46826 .50392 Mtetra
.46826 .50392 .47351 .50932 .48282 .5064 .47758 .50099 Mtetra
.47758 .50099 .48282 .5064 .49216 .50347 .48694 .49804 Mtetra
.48694 .49804 .49216 .50347 .50152 .50053 .49633 .49508 Mtetra
.49633 .49508 .50152 .50053 .51092 .49759 .50575 .49212 Mtetra
.50575 .49212 .51092 .49759 .52036 .49463 .5152 .48914 Mtetra
.5152 .48914 .52036 .49463 .52982 .49166 .52469 .48615 Mtetra
.52469 .48615 .52982 .49166 .53932 .48868 .53421 .48316 Mtetra
.53421 .48316 .53932 .48868 .54885 .48569 .54376 .48015 Mtetra
.54376 .48015 .54885 .48569 .55841 .4827 .55335 .47713 Mtetra
.55335 .47713 .55841 .4827 .56801 .47969 .56296 .4741 Mtetra
.56296 .4741 .56801 .47969 .57764 .47667 .57262 .47106 Mtetra
.57262 .47106 .57764 .47667 .5873 .47364 .5823 .46801 Mtetra
.5823 .46801 .5873 .47364 .597 .4706 .59202 .46495 Mtetra
.59202 .46495 .597 .4706 .60673 .46754 .60178 .46188 Mtetra
.60178 .46188 .60673 .46754 .6165 .46448 .61156 .4588 Mtetra
.61156 .4588 .6165 .46448 .62629 .46141 .62139 .45571 Mtetra
.62139 .45571 .62629 .46141 .63613 .45833 .63124 .45261 Mtetra
.63124 .45261 .63613 .45833 .646 .45523 .64113 .44949 Mtetra
.64113 .44949 .646 .45523 .6559 .45213 .65106 .44637 Mtetra
.65106 .44637 .6559 .45213 .66584 .44901 .66102 .44323 Mtetra
.66102 .44323 .66584 .44901 .67581 .44588 .67102 .44008 Mtetra
.67102 .44008 .67581 .44588 .68582 .44275 .68105 .43692 Mtetra
.68105 .43692 .68582 .44275 .69586 .4396 .69112 .43375 Mtetra
.69112 .43375 .69586 .4396 .70594 .43644 .70123 .43057 Mtetra
.70123 .43057 .70594 .43644 .71606 .43326 .71137 .42738 Mtetra
.71137 .42738 .71606 .43326 .72621 .43008 .72154 .42417 Mtetra
.72154 .42417 .72621 .43008 .7364 .42689 .73176 .42096 Mtetra
.73176 .42096 .7364 .42689 .74662 .42368 .74201 .41773 Mtetra
.74201 .41773 .74662 .42368 .75688 .42046 .75229 .41449 Mtetra
.75229 .41449 .75688 .42046 .76718 .41723 .76262 .41124 Mtetra
.76262 .41124 .76718 .41723 .77752 .41399 .77298 .40798 Mtetra
.77298 .40798 .77752 .41399 .78789 .41074 .78338 .40471 Mtetra
.78338 .40471 .78789 .41074 .7983 .40748 .79382 .40142 Mtetra
.79382 .40142 .7983 .40748 .80875 .4042 .80429 .39812 Mtetra
.80429 .39812 .80875 .4042 .81923 .40091 .8148 .39481 Mtetra
.8148 .39481 .81923 .40091 .82976 .39761 .82535 .39149 Mtetra
.82535 .39149 .82976 .39761 .84032 .3943 .83594 .38816 Mtetra
.83594 .38816 .84032 .3943 .85092 .39098 .84657 .38481 Mtetra
.84657 .38481 .85092 .39098 .86156 .38764 .85724 .38145 Mtetra
.85724 .38145 .86156 .38764 .87224 .38429 .86794 .37808 Mtetra
.86794 .37808 .87224 .38429 .88295 .38093 .87869 .3747 Mtetra
.87869 .3747 .88295 .38093 .89371 .37756 .88947 .3713 Mtetra
.88947 .3713 .89371 .37756 .9045 .37418 .9003 .36789 Mtetra
.9003 .36789 .9045 .37418 .91534 .37078 .91116 .36447 Mtetra
.91116 .36447 .91534 .37078 .92622 .36737 .92207 .36104 Mtetra
.33542 .53882 .34098 .54399 .34988 .54119 .34434 .536 Mtetra
.34434 .536 .34988 .54119 .3588 .53838 .35328 .53317 Mtetra
.35328 .53317 .3588 .53838 .36775 .53557 .36225 .53034 Mtetra
.36225 .53034 .36775 .53557 .37674 .53274 .37125 .52749 Mtetra
.37125 .52749 .37674 .53274 .38575 .5299 .38028 .52463 Mtetra
.38028 .52463 .38575 .5299 .39479 .52705 .38935 .52177 Mtetra
.38935 .52177 .39479 .52705 .40387 .52419 .39844 .51889 Mtetra
.39844 .51889 .40387 .52419 .41297 .52133 .40756 .51601 Mtetra
.40756 .51601 .41297 .52133 .42211 .51845 .41672 .51312 Mtetra
.41672 .51312 .42211 .51845 .43128 .51557 .42591 .51021 Mtetra
.42591 .51021 .43128 .51557 .44047 .51267 .43512 .5073 Mtetra
.43512 .5073 .44047 .51267 .4497 .50976 .44437 .50437 Mtetra
.44437 .50437 .4497 .50976 .45897 .50685 .45365 .50144 Mtetra
.45365 .50144 .45897 .50685 .46826 .50392 .46297 .49849 Mtetra
.46297 .49849 .46826 .50392 .47758 .50099 .47231 .49554 Mtetra
.47231 .49554 .47758 .50099 .48694 .49804 .48169 .49257 Mtetra
.48169 .49257 .48694 .49804 .49633 .49508 .4911 .4896 Mtetra
.4911 .4896 .49633 .49508 .50575 .49212 .50054 .48661 Mtetra
.50054 .48661 .50575 .49212 .5152 .48914 .51002 .48362 Mtetra
.51002 .48362 .5152 .48914 .52469 .48615 .51952 .48061 Mtetra
.51952 .48061 .52469 .48615 .53421 .48316 .52906 .4776 Mtetra
.52906 .4776 .53421 .48316 .54376 .48015 .53864 .47457 Mtetra
.53864 .47457 .54376 .48015 .55335 .47713 .54825 .47153 Mtetra
.54825 .47153 .55335 .47713 .56296 .4741 .55789 .46848 Mtetra
.55789 .46848 .56296 .4741 .57262 .47106 .56756 .46543 Mtetra
.56756 .46543 .57262 .47106 .5823 .46801 .57727 .46236 Mtetra
.57727 .46236 .5823 .46801 .59202 .46495 .58701 .45928 Mtetra
.58701 .45928 .59202 .46495 .60178 .46188 .59679 .45619 Mtetra
.59679 .45619 .60178 .46188 .61156 .4588 .6066 .45308 Mtetra
.6066 .45308 .61156 .4588 .62139 .45571 .61645 .44997 Mtetra
.61645 .44997 .62139 .45571 .63124 .45261 .62633 .44685 Mtetra
.62633 .44685 .63124 .45261 .64113 .44949 .63624 .44371 Mtetra
.63624 .44371 .64113 .44949 .65106 .44637 .64619 .44057 Mtetra
.64619 .44057 .65106 .44637 .66102 .44323 .65618 .43741 Mtetra
.65618 .43741 .66102 .44323 .67102 .44008 .6662 .43424 Mtetra
.6662 .43424 .67102 .44008 .68105 .43692 .67626 .43106 Mtetra
.67626 .43106 .68105 .43692 .69112 .43375 .68635 .42787 Mtetra
.68635 .42787 .69112 .43375 .70123 .43057 .69648 .42467 Mtetra
.69648 .42467 .70123 .43057 .71137 .42738 .70664 .42145 Mtetra
.70664 .42145 .71137 .42738 .72154 .42417 .71685 .41823 Mtetra
.71685 .41823 .72154 .42417 .73176 .42096 .72709 .41499 Mtetra
.72709 .41499 .73176 .42096 .74201 .41773 .73736 .41174 Mtetra
.73736 .41174 .74201 .41773 .75229 .41449 .74767 .40848 Mtetra
.74767 .40848 .75229 .41449 .76262 .41124 .75802 .40521 Mtetra
.75802 .40521 .76262 .41124 .77298 .40798 .76841 .40193 Mtetra
.76841 .40193 .77298 .40798 .78338 .40471 .77884 .39863 Mtetra
.77884 .39863 .78338 .40471 .79382 .40142 .7893 .39532 Mtetra
.7893 .39532 .79382 .40142 .80429 .39812 .7998 .392 Mtetra
.7998 .392 .80429 .39812 .8148 .39481 .81034 .38867 Mtetra
.81034 .38867 .8148 .39481 .82535 .39149 .82092 .38532 Mtetra
.82092 .38532 .82535 .39149 .83594 .38816 .83154 .38197 Mtetra
.83154 .38197 .83594 .38816 .84657 .38481 .84219 .3786 Mtetra
.84219 .3786 .84657 .38481 .85724 .38145 .85289 .37522 Mtetra
.85289 .37522 .85724 .38145 .86794 .37808 .86362 .37182 Mtetra
.86362 .37182 .86794 .37808 .87869 .3747 .8744 .36842 Mtetra
.8744 .36842 .87869 .3747 .88947 .3713 .88521 .365 Mtetra
.88521 .365 .88947 .3713 .9003 .36789 .89607 .36157 Mtetra
.89607 .36157 .9003 .36789 .91116 .36447 .90696 .35812 Mtetra
.90696 .35812 .91116 .36447 .92207 .36104 .91789 .35467 Mtetra
.32983 .53361 .33542 .53882 .34434 .536 .33876 .53077 Mtetra
.33876 .53077 .34434 .536 .35328 .53317 .34772 .52793 Mtetra
.34772 .52793 .35328 .53317 .36225 .53034 .35671 .52507 Mtetra
.35671 .52507 .36225 .53034 .37125 .52749 .36573 .52221 Mtetra
.36573 .52221 .37125 .52749 .38028 .52463 .37478 .51934 Mtetra
.37478 .51934 .38028 .52463 .38935 .52177 .38386 .51645 Mtetra
.38386 .51645 .38935 .52177 .39844 .51889 .39298 .51356 Mtetra
.39298 .51356 .39844 .51889 .40756 .51601 .40212 .51066 Mtetra
.40212 .51066 .40756 .51601 .41672 .51312 .4113 .50775 Mtetra
.4113 .50775 .41672 .51312 .42591 .51021 .4205 .50482 Mtetra
.4205 .50482 .42591 .51021 .43512 .5073 .42974 .50189 Mtetra
.42974 .50189 .43512 .5073 .44437 .50437 .43901 .49895 Mtetra
.626 .73 .922 r
.43901 .49895 .44437 .50437 .45365 .50144 .44829 .49686 Mtetra
.599 .076 0 r
.44829 .49686 .45365 .50144 .46297 .49849 .45738 .50629 Mtetra
.75 .892 .493 r
.45738 .50629 .46297 .49849 .47231 .49554 .46701 .49006 Mtetra
.664 .741 .908 r
.46701 .49006 .47231 .49554 .48169 .49257 .47641 .48707 Mtetra
.47641 .48707 .48169 .49257 .4911 .4896 .48584 .48408 Mtetra
.48584 .48408 .4911 .4896 .50054 .48661 .4953 .48108 Mtetra
.4953 .48108 .50054 .48661 .51002 .48362 .5048 .47806 Mtetra
.5048 .47806 .51002 .48362 .51952 .48061 .51433 .47504 Mtetra
.51433 .47504 .51952 .48061 .52906 .4776 .52389 .472 Mtetra
.52389 .472 .52906 .4776 .53864 .47457 .53348 .46895 Mtetra
.53348 .46895 .53864 .47457 .54825 .47153 .54311 .4659 Mtetra
.54311 .4659 .54825 .47153 .55789 .46848 .55278 .46283 Mtetra
.55278 .46283 .55789 .46848 .56756 .46543 .56247 .45975 Mtetra
.56247 .45975 .56756 .46543 .57727 .46236 .5722 .45666 Mtetra
.5722 .45666 .57727 .46236 .58701 .45928 .58197 .45356 Mtetra
.58197 .45356 .58701 .45928 .59679 .45619 .59177 .45045 Mtetra
.59177 .45045 .59679 .45619 .6066 .45308 .6016 .44733 Mtetra
.6016 .44733 .6066 .45308 .61645 .44997 .61147 .4442 Mtetra
.61147 .4442 .61645 .44997 .62633 .44685 .62138 .44105 Mtetra
.62138 .44105 .62633 .44685 .63624 .44371 .63132 .4379 Mtetra
.63132 .4379 .63624 .44371 .64619 .44057 .64129 .43473 Mtetra
.64129 .43473 .64619 .44057 .65618 .43741 .6513 .43155 Mtetra
.6513 .43155 .65618 .43741 .6662 .43424 .66135 .42836 Mtetra
.66135 .42836 .6662 .43424 .67626 .43106 .67143 .42516 Mtetra
.67143 .42516 .67626 .43106 .68635 .42787 .68155 .42195 Mtetra
.68155 .42195 .68635 .42787 .69648 .42467 .6917 .41873 Mtetra
.6917 .41873 .69648 .42467 .70664 .42145 .70189 .41549 Mtetra
.70189 .41549 .70664 .42145 .71685 .41823 .71212 .41224 Mtetra
.71212 .41224 .71685 .41823 .72709 .41499 .72238 .40898 Mtetra
.72238 .40898 .72709 .41499 .73736 .41174 .73268 .40571 Mtetra
.73268 .40571 .73736 .41174 .74767 .40848 .74302 .40243 Mtetra
.74302 .40243 .74767 .40848 .75802 .40521 .7534 .39914 Mtetra
0 .155 .681 r
.7534 .39914 .75802 .40521 .76841 .40193 .76482 .40943 Mtetra
0 0 0 r
.76482 .40943 .76841 .40193 .77884 .39863 .77433 .3934 Mtetra
.696 .787 .921 r
.77433 .3934 .77884 .39863 .7893 .39532 .78476 .38918 Mtetra
.664 .741 .908 r
.78476 .38918 .7893 .39532 .7998 .392 .79528 .38584 Mtetra
.79528 .38584 .7998 .392 .81034 .38867 .80585 .38249 Mtetra
.80585 .38249 .81034 .38867 .82092 .38532 .81646 .37912 Mtetra
.81646 .37912 .82092 .38532 .83154 .38197 .8271 .37574 Mtetra
.8271 .37574 .83154 .38197 .84219 .3786 .83779 .37235 Mtetra
.83779 .37235 .84219 .3786 .85289 .37522 .84851 .36894 Mtetra
.84851 .36894 .85289 .37522 .86362 .37182 .85927 .36553 Mtetra
.85927 .36553 .86362 .37182 .8744 .36842 .87008 .3621 Mtetra
.87008 .3621 .8744 .36842 .88521 .365 .88092 .35865 Mtetra
.88092 .35865 .88521 .365 .89607 .36157 .8918 .3552 Mtetra
.8918 .3552 .89607 .36157 .90696 .35812 .90273 .35173 Mtetra
.90273 .35173 .90696 .35812 .91789 .35467 .91369 .34825 Mtetra
.3242 .52837 .32983 .53361 .33876 .53077 .33315 .52551 Mtetra
.33315 .52551 .33876 .53077 .34772 .52793 .34213 .52265 Mtetra
.34213 .52265 .34772 .52793 .35671 .52507 .35114 .51978 Mtetra
.35114 .51978 .35671 .52507 .36573 .52221 .36018 .5169 Mtetra
.36018 .5169 .36573 .52221 .37478 .51934 .36925 .51401 Mtetra
.36925 .51401 .37478 .51934 .38386 .51645 .37835 .51111 Mtetra
.37835 .51111 .38386 .51645 .39298 .51356 .38748 .50819 Mtetra
.38748 .50819 .39298 .51356 .40212 .51066 .39664 .50527 Mtetra
.39664 .50527 .40212 .51066 .4113 .50775 .40584 .50234 Mtetra
.40584 .50234 .4113 .50775 .4205 .50482 .41506 .4994 Mtetra
.41506 .4994 .4205 .50482 .42974 .50189 .42432 .49645 Mtetra
.42432 .49645 .42974 .50189 .43901 .49895 .43361 .49349 Mtetra
0 .114 .617 r
.43361 .49349 .43901 .49895 .44829 .49686 .44267 .50129 Mtetra
.734 .31 .243 r
.44267 .50129 .44829 .49686 .45738 .50629 .45178 .5107 Mtetra
.751 .332 .255 r
.45178 .5107 .45738 .50629 .46701 .49006 .46097 .52125 Mtetra
0 0 .07 r
.46097 .52125 .46701 .49006 .47641 .48707 .47109 .48154 Mtetra
.664 .741 .908 r
.47109 .48154 .47641 .48707 .48584 .48408 .48054 .47853 Mtetra
.48054 .47853 .48584 .48408 .4953 .48108 .49003 .4755 Mtetra
.49003 .4755 .4953 .48108 .5048 .47806 .49954 .47247 Mtetra
.49954 .47247 .5048 .47806 .51433 .47504 .5091 .46942 Mtetra
.5091 .46942 .51433 .47504 .52389 .472 .51868 .46637 Mtetra
.51868 .46637 .52389 .472 .53348 .46895 .5283 .4633 Mtetra
.5283 .4633 .53348 .46895 .54311 .4659 .53795 .46023 Mtetra
.53795 .46023 .54311 .4659 .55278 .46283 .54763 .45714 Mtetra
.54763 .45714 .55278 .46283 .56247 .45975 .55735 .45404 Mtetra
.55735 .45404 .56247 .45975 .5722 .45666 .56711 .45093 Mtetra
.56711 .45093 .5722 .45666 .58197 .45356 .57689 .44781 Mtetra
.57689 .44781 .58197 .45356 .59177 .45045 .58672 .44468 Mtetra
.58672 .44468 .59177 .45045 .6016 .44733 .59657 .44154 Mtetra
.59657 .44154 .6016 .44733 .61147 .4442 .60647 .43838 Mtetra
.60647 .43838 .61147 .4442 .62138 .44105 .61639 .43522 Mtetra
.61639 .43522 .62138 .44105 .63132 .4379 .62636 .43204 Mtetra
.62636 .43204 .63132 .4379 .64129 .43473 .63636 .42885 Mtetra
.63636 .42885 .64129 .43473 .6513 .43155 .64639 .42565 Mtetra
.64639 .42565 .6513 .43155 .66135 .42836 .65646 .42244 Mtetra
.65646 .42244 .66135 .42836 .67143 .42516 .66657 .41922 Mtetra
.66657 .41922 .67143 .42516 .68155 .42195 .67671 .41599 Mtetra
.67671 .41599 .68155 .42195 .6917 .41873 .68689 .41274 Mtetra
.68689 .41274 .6917 .41873 .70189 .41549 .6971 .40949 Mtetra
.6971 .40949 .70189 .41549 .71212 .41224 .70736 .40622 Mtetra
.70736 .40622 .71212 .41224 .72238 .40898 .71765 .40294 Mtetra
.71765 .40294 .72238 .40898 .73268 .40571 .72798 .39965 Mtetra
.72798 .39965 .73268 .40571 .74302 .40243 .73834 .39634 Mtetra
.883 .479 .039 r
.73834 .39634 .74302 .40243 .7534 .39914 .75136 .43063 Mtetra
.333 .096 .398 r
.75136 .43063 .7534 .39914 .76482 .40943 .76092 .41346 Mtetra
.803 .926 .548 r
.76092 .41346 .76482 .40943 .77433 .3934 .77051 .39742 Mtetra
.737 .909 .535 r
.77051 .39742 .77433 .3934 .78476 .38918 .78018 .383 Mtetra
.664 .741 .908 r
.78018 .383 .78476 .38918 .79528 .38584 .79074 .37964 Mtetra
.79074 .37964 .79528 .38584 .80585 .38249 .80133 .37626 Mtetra
.80133 .37626 .80585 .38249 .81646 .37912 .81196 .37287 Mtetra
.81196 .37287 .81646 .37912 .8271 .37574 .82264 .36947 Mtetra
.82264 .36947 .8271 .37574 .83779 .37235 .83335 .36605 Mtetra
.83335 .36605 .83779 .37235 .84851 .36894 .8441 .36262 Mtetra
.8441 .36262 .84851 .36894 .85927 .36553 .85489 .35918 Mtetra
.85489 .35918 .85927 .36553 .87008 .3621 .86572 .35573 Mtetra
.86572 .35573 .87008 .3621 .88092 .35865 .8766 .35226 Mtetra
.8766 .35226 .88092 .35865 .8918 .3552 .88751 .34879 Mtetra
.88751 .34879 .8918 .3552 .90273 .35173 .89846 .34529 Mtetra
.89846 .34529 .90273 .35173 .91369 .34825 .90946 .34179 Mtetra
.31854 .52309 .3242 .52837 .33315 .52551 .3275 .52022 Mtetra
.3275 .52022 .33315 .52551 .34213 .52265 .3365 .51734 Mtetra
.3365 .51734 .34213 .52265 .35114 .51978 .34553 .51445 Mtetra
.34553 .51445 .35114 .51978 .36018 .5169 .35459 .51155 Mtetra
.35459 .51155 .36018 .5169 .36925 .51401 .36368 .50864 Mtetra
.36368 .50864 .36925 .51401 .37835 .51111 .3728 .50572 Mtetra
.3728 .50572 .37835 .51111 .38748 .50819 .38195 .50279 Mtetra
.38195 .50279 .38748 .50819 .39664 .50527 .39113 .49985 Mtetra
.39113 .49985 .39664 .50527 .40584 .50234 .40034 .4969 Mtetra
.40034 .4969 .40584 .50234 .41506 .4994 .40959 .49394 Mtetra
.40959 .49394 .41506 .4994 .42432 .49645 .41887 .49097 Mtetra
.019 .414 .859 r
.41887 .49097 .42432 .49645 .43361 .49349 .42796 .49559 Mtetra
.723 .252 .128 r
.42796 .49559 .43361 .49349 .44267 .50129 .43702 .5038 Mtetra
.743 .289 .171 r
.43702 .5038 .44267 .50129 .45178 .5107 .44616 .5131 Mtetra
.762 .314 .186 r
.44616 .5131 .45178 .5107 .46097 .52125 .45538 .5235 Mtetra
.779 .335 .196 r
.45538 .5235 .46097 .52125 .47109 .48154 .46468 .53498 Mtetra
0 0 .186 r
.46468 .53498 .47109 .48154 .48054 .47853 .47521 .47294 Mtetra
.664 .741 .908 r
.47521 .47294 .48054 .47853 .49003 .4755 .48472 .46989 Mtetra
.48472 .46989 .49003 .4755 .49954 .47247 .49426 .46684 Mtetra
.49426 .46684 .49954 .47247 .5091 .46942 .50383 .46377 Mtetra
.50383 .46377 .5091 .46942 .51868 .46637 .51344 .4607 Mtetra
.51344 .4607 .51868 .46637 .5283 .4633 .52308 .45761 Mtetra
.52308 .45761 .5283 .4633 .53795 .46023 .53275 .45452 Mtetra
.53275 .45452 .53795 .46023 .54763 .45714 .54246 .45141 Mtetra
.54246 .45141 .54763 .45714 .55735 .45404 .5522 .44829 Mtetra
.5522 .44829 .55735 .45404 .56711 .45093 .56197 .44516 Mtetra
.56197 .44516 .56711 .45093 .57689 .44781 .57179 .44202 Mtetra
.57179 .44202 .57689 .44781 .58672 .44468 .58163 .43887 Mtetra
.58163 .43887 .58672 .44468 .59657 .44154 .59151 .4357 Mtetra
.59151 .4357 .59657 .44154 .60647 .43838 .60143 .43253 Mtetra
.60143 .43253 .60647 .43838 .61639 .43522 .61138 .42934 Mtetra
.61138 .42934 .61639 .43522 .62636 .43204 .62137 .42615 Mtetra
.62137 .42615 .62636 .43204 .63636 .42885 .63139 .42294 Mtetra
.63139 .42294 .63636 .42885 .64639 .42565 .64145 .41972 Mtetra
.64145 .41972 .64639 .42565 .65646 .42244 .65154 .41649 Mtetra
.65154 .41649 .65646 .42244 .66657 .41922 .66167 .41324 Mtetra
.66167 .41324 .66657 .41922 .67671 .41599 .67184 .40999 Mtetra
.67184 .40999 .67671 .41599 .68689 .41274 .68205 .40672 Mtetra
.68205 .40672 .68689 .41274 .6971 .40949 .69229 .40344 Mtetra
.69229 .40344 .6971 .40949 .70736 .40622 .70257 .40015 Mtetra
.70257 .40015 .70736 .40622 .71765 .40294 .71288 .39685 Mtetra
.71288 .39685 .71765 .40294 .72798 .39965 .72324 .39354 Mtetra
.941 .579 .202 r
.72324 .39354 .72798 .39965 .73834 .39634 .73755 .45057 Mtetra
.431 .204 .467 r
.73755 .45057 .73834 .39634 .75136 .43063 .74717 .43247 Mtetra
.932 .964 .67 r
.74717 .43247 .75136 .43063 .76092 .41346 .75681 .41542 Mtetra
.91 .971 .672 r
.75681 .41542 .76092 .41346 .77051 .39742 .76648 .39947 Mtetra
.883 .976 .674 r
.76648 .39947 .77051 .39742 .78018 .383 .77619 .3846 Mtetra
.795 .987 .73 r
.77619 .3846 .78018 .383 .79074 .37964 .78616 .37339 Mtetra
.664 .741 .908 r
.78616 .37339 .79074 .37964 .80133 .37626 .79678 .36999 Mtetra
.79678 .36999 .80133 .37626 .81196 .37287 .80744 .36658 Mtetra
.80744 .36658 .81196 .37287 .82264 .36947 .81814 .36315 Mtetra
.81814 .36315 .82264 .36947 .83335 .36605 .82888 .35971 Mtetra
.82888 .35971 .83335 .36605 .8441 .36262 .83966 .35626 Mtetra
.83966 .35626 .8441 .36262 .85489 .35918 .85048 .3528 Mtetra
.85048 .3528 .85489 .35918 .86572 .35573 .86134 .34932 Mtetra
.86134 .34932 .86572 .35573 .8766 .35226 .87224 .34583 Mtetra
.87224 .34583 .8766 .35226 .88751 .34879 .88319 .34233 Mtetra
.88319 .34233 .88751 .34879 .89846 .34529 .89417 .33881 Mtetra
.89417 .33881 .89846 .34529 .90946 .34179 .9052 .33528 Mtetra
.31284 .51779 .31854 .52309 .3275 .52022 .32182 .5149 Mtetra
.32182 .5149 .3275 .52022 .3365 .51734 .33084 .512 Mtetra
.33084 .512 .3365 .51734 .34553 .51445 .33988 .50909 Mtetra
.33988 .50909 .34553 .51445 .35459 .51155 .34896 .50617 Mtetra
.34896 .50617 .35459 .51155 .36368 .50864 .35807 .50324 Mtetra
.35807 .50324 .36368 .50864 .3728 .50572 .36721 .50031 Mtetra
.36721 .50031 .3728 .50572 .38195 .50279 .37638 .49736 Mtetra
.37638 .49736 .38195 .50279 .39113 .49985 .38558 .4944 Mtetra
.38558 .4944 .39113 .49985 .40034 .4969 .39482 .49143 Mtetra
.39482 .49143 .40034 .4969 .40959 .49394 .40408 .48845 Mtetra
.409 .642 .952 r
.40408 .48845 .40959 .49394 .41887 .49097 .41324 .48959 Mtetra
.648 .09 0 r
.41324 .48959 .41887 .49097 .42796 .49559 .42227 .49665 Mtetra
.72 .225 .062 r
.42227 .49665 .42796 .49559 .43702 .5038 .43136 .50473 Mtetra
.744 .258 .085 r
.43136 .50473 .43702 .5038 .44616 .5131 .44052 .51385 Mtetra
.765 .286 .102 r
.44052 .51385 .44616 .5131 .45538 .5235 .44976 .52401 Mtetra
.783 .31 .114 r
.44976 .52401 .45538 .5235 .46468 .53498 .45909 .5352 Mtetra
.798 .33 .12 r
.45909 .5352 .46468 .53498 .47521 .47294 .46851 .5474 Mtetra
0 0 .232 r
.46851 .5474 .47521 .47294 .48472 .46989 .47938 .46425 Mtetra
.664 .741 .908 r
.47938 .46425 .48472 .46989 .49426 .46684 .48894 .46117 Mtetra
.48894 .46117 .49426 .46684 .50383 .46377 .49853 .45809 Mtetra
.49853 .45809 .50383 .46377 .51344 .4607 .50816 .45499 Mtetra
.50816 .45499 .51344 .4607 .52308 .45761 .51782 .45189 Mtetra
.51782 .45189 .52308 .45761 .53275 .45452 .52752 .44877 Mtetra
.52752 .44877 .53275 .45452 .54246 .45141 .53725 .44564 Mtetra
.53725 .44564 .54246 .45141 .5522 .44829 .54701 .4425 Mtetra
.54701 .4425 .5522 .44829 .56197 .44516 .55681 .43935 Mtetra
.55681 .43935 .56197 .44516 .57179 .44202 .56664 .43619 Mtetra
.56664 .43619 .57179 .44202 .58163 .43887 .57651 .43302 Mtetra
.57651 .43302 .58163 .43887 .59151 .4357 .58642 .42984 Mtetra
.58642 .42984 .59151 .4357 .60143 .43253 .59636 .42664 Mtetra
.59636 .42664 .60143 .43253 .61138 .42934 .60633 .42343 Mtetra
.60633 .42343 .61138 .42934 .62137 .42615 .61634 .42021 Mtetra
.61634 .42021 .62137 .42615 .63139 .42294 .62639 .41698 Mtetra
.62639 .41698 .63139 .42294 .64145 .41972 .63647 .41374 Mtetra
.63647 .41374 .64145 .41972 .65154 .41649 .64659 .41049 Mtetra
.64659 .41049 .65154 .41649 .66167 .41324 .65675 .40722 Mtetra
.65675 .40722 .66167 .41324 .67184 .40999 .66694 .40395 Mtetra
.66694 .40395 .67184 .40999 .68205 .40672 .67717 .40066 Mtetra
.67717 .40066 .68205 .40672 .69229 .40344 .68744 .39736 Mtetra
.68744 .39736 .69229 .40344 .70257 .40015 .69774 .39405 Mtetra
.69774 .39405 .70257 .40015 .71288 .39685 .70808 .39072 Mtetra
.957 .614 .267 r
.70808 .39072 .71288 .39685 .72324 .39354 .7234 .46919 Mtetra
.465 .242 .49 r
.7234 .46919 .72324 .39354 .73755 .45057 .7331 .45036 Mtetra
.961 .93 .714 r
.7331 .45036 .73755 .45057 .74717 .43247 .74281 .43251 Mtetra
.954 .945 .722 r
.74281 .43251 .74717 .43247 .75681 .41542 .75253 .41568 Mtetra
.944 .959 .73 r
.75253 .41568 .75681 .41542 .76648 .39947 .76228 .39988 Mtetra
.929 .972 .739 r
.76228 .39988 .76648 .39947 .77619 .3846 .77206 .38511 Mtetra
.911 .982 .75 r
.77206 .38511 .77619 .3846 .78616 .37339 .78189 .37135 Mtetra
.804 .95 .915 r
.78189 .37135 .78616 .37339 .79678 .36999 .7922 .36368 Mtetra
.664 .741 .908 r
.7922 .36368 .79678 .36999 .80744 .36658 .80289 .36024 Mtetra
.80289 .36024 .80744 .36658 .81814 .36315 .81361 .35679 Mtetra
.81361 .35679 .81814 .36315 .82888 .35971 .82438 .35333 Mtetra
.82438 .35333 .82888 .35971 .83966 .35626 .83519 .34986 Mtetra
.83519 .34986 .83966 .35626 .85048 .3528 .84604 .34637 Mtetra
.84604 .34637 .85048 .3528 .86134 .34932 .85693 .34287 Mtetra
.85693 .34287 .86134 .34932 .87224 .34583 .86786 .33935 Mtetra
.86786 .33935 .87224 .34583 .88319 .34233 .87884 .33583 Mtetra
.87884 .33583 .88319 .34233 .89417 .33881 .88985 .33229 Mtetra
.88985 .33229 .89417 .33881 .9052 .33528 .9009 .32873 Mtetra
.3071 .51245 .31284 .51779 .32182 .5149 .31611 .50954 Mtetra
.31611 .50954 .32182 .5149 .33084 .512 .32514 .50662 Mtetra
.32514 .50662 .33084 .512 .33988 .50909 .33421 .5037 Mtetra
.33421 .5037 .33988 .50909 .34896 .50617 .3433 .50076 Mtetra
.3433 .50076 .34896 .50617 .35807 .50324 .35243 .49781 Mtetra
.35243 .49781 .35807 .50324 .36721 .50031 .36159 .49486 Mtetra
.36159 .49486 .36721 .50031 .37638 .49736 .37078 .49189 Mtetra
.37078 .49189 .37638 .49736 .38558 .4944 .38 .48891 Mtetra
.38 .48891 .38558 .4944 .39482 .49143 .38925 .48592 Mtetra
.641 .735 .917 r
.38925 .48592 .39482 .49143 .40408 .48845 .39852 .48347 Mtetra
0 .242 .716 r
.39852 .48347 .40408 .48845 .41324 .48959 .40752 .48951 Mtetra
.673 .137 0 r
.40752 .48951 .41324 .48959 .42227 .49665 .41657 .49643 Mtetra
.705 .181 0 r
.41657 .49643 .42227 .49665 .43136 .50473 .42568 .50432 Mtetra
.732 .218 0 r
.42568 .50432 .43136 .50473 .44052 .51385 .43486 .51321 Mtetra
.755 .249 .006 r
.43486 .51321 .44052 .51385 .44976 .52401 .44412 .52307 Mtetra
.773 .274 .017 r
.44412 .52307 .44976 .52401 .45909 .5352 .45346 .5339 Mtetra
.789 .295 .023 r
.45346 .5339 .45909 .5352 .46851 .5474 .46291 .5457 Mtetra
.802 .314 .025 r
.46291 .5457 .46851 .5474 .47938 .46425 .47245 .55847 Mtetra
0 0 .257 r
.47245 .55847 .47938 .46425 .48894 .46117 .48358 .45547 Mtetra
.664 .741 .908 r
.48358 .45547 .48894 .46117 .49853 .45809 .4932 .45237 Mtetra
.4932 .45237 .49853 .45809 .50816 .45499 .50285 .44925 Mtetra
.50285 .44925 .50816 .45499 .51782 .45189 .51253 .44612 Mtetra
.51253 .44612 .51782 .45189 .52752 .44877 .52225 .44299 Mtetra
.52225 .44299 .52752 .44877 .53725 .44564 .532 .43984 Mtetra
.532 .43984 .53725 .44564 .54701 .4425 .54179 .43668 Mtetra
.54179 .43668 .54701 .4425 .55681 .43935 .55161 .43351 Mtetra
.55161 .43351 .55681 .43935 .56664 .43619 .56147 .43033 Mtetra
.56147 .43033 .56664 .43619 .57651 .43302 .57136 .42713 Mtetra
.57136 .42713 .57651 .43302 .58642 .42984 .58129 .42393 Mtetra
.58129 .42393 .58642 .42984 .59636 .42664 .59125 .42071 Mtetra
.59125 .42071 .59636 .42664 .60633 .42343 .60125 .41748 Mtetra
.60125 .41748 .60633 .42343 .61634 .42021 .61128 .41424 Mtetra
.61128 .41424 .61634 .42021 .62639 .41698 .62136 .41099 Mtetra
.62136 .41099 .62639 .41698 .63647 .41374 .63146 .40773 Mtetra
.63146 .40773 .63647 .41374 .64659 .41049 .64161 .40445 Mtetra
.64161 .40445 .64659 .41049 .65675 .40722 .65179 .40117 Mtetra
.65179 .40117 .65675 .40722 .66694 .40395 .66201 .39787 Mtetra
.66201 .39787 .66694 .40395 .67717 .40066 .67226 .39456 Mtetra
.67226 .39456 .67717 .40066 .68744 .39736 .68255 .39123 Mtetra
.68255 .39123 .68744 .39736 .69774 .39405 .69288 .3879 Mtetra
.963 .631 .303 r
.69288 .3879 .69774 .39405 .70808 .39072 .70892 .48645 Mtetra
.483 .261 .501 r
.70892 .48645 .70808 .39072 .7234 .46919 .71872 .46704 Mtetra
.953 .881 .725 r
.71872 .46704 .7234 .46919 .7331 .45036 .72851 .44858 Mtetra
.953 .898 .734 r
.72851 .44858 .7331 .45036 .74281 .43251 .7383 .43107 Mtetra
.95 .914 .744 r
.7383 .43107 .74281 .43251 .75253 .41568 .7481 .41451 Mtetra
.945 .93 .755 r
.7481 .41451 .75253 .41568 .76228 .39988 .75793 .39892 Mtetra
.937 .945 .768 r
.75793 .39892 .76228 .39988 .77206 .38511 .76779 .3843 Mtetra
.925 .959 .782 r
.76779 .3843 .77206 .38511 .78189 .37135 .77769 .37065 Mtetra
.912 .97 .795 r
.77769 .37065 .78189 .37135 .7922 .36368 .78763 .35788 Mtetra
.684 .769 .916 r
.78763 .35788 .7922 .36368 .80289 .36024 .7983 .35387 Mtetra
.664 .741 .908 r
.7983 .35387 .80289 .36024 .81361 .35679 .80906 .35039 Mtetra
.80906 .35039 .81361 .35679 .82438 .35333 .81985 .34691 Mtetra
.81985 .34691 .82438 .35333 .83519 .34986 .83069 .34341 Mtetra
.83069 .34341 .83519 .34986 .84604 .34637 .84157 .3399 Mtetra
.84157 .3399 .84604 .34637 .85693 .34287 .85249 .33637 Mtetra
.85249 .33637 .85693 .34287 .86786 .33935 .86345 .33283 Mtetra
.86345 .33283 .86786 .33935 .87884 .33583 .87445 .32928 Mtetra
.87445 .32928 .87884 .33583 .88985 .33229 .8855 .32572 Mtetra
.8855 .32572 .88985 .33229 .9009 .32873 .89658 .32214 Mtetra
.30133 .50707 .3071 .51245 .31611 .50954 .31035 .50415 Mtetra
.31035 .50415 .31611 .50954 .32514 .50662 .31941 .50121 Mtetra
.31941 .50121 .32514 .50662 .33421 .5037 .32849 .49827 Mtetra
.32849 .49827 .33421 .5037 .3433 .50076 .3376 .49531 Mtetra
.3376 .49531 .3433 .50076 .35243 .49781 .34675 .49235 Mtetra
.34675 .49235 .35243 .49781 .36159 .49486 .35593 .48937 Mtetra
.35593 .48937 .36159 .49486 .37078 .49189 .36514 .48638 Mtetra
.36514 .48638 .37078 .49189 .38 .48891 .37438 .48339 Mtetra
.37438 .48339 .38 .48891 .38925 .48592 .38365 .48038 Mtetra
.308 .592 .944 r
.38365 .48038 .38925 .48592 .39852 .48347 .39276 .48251 Mtetra
.596 .024 0 r
.39276 .48251 .39852 .48347 .40752 .48951 .40178 .48838 Mtetra
.638 .078 0 r
.40178 .48838 .40752 .48951 .41657 .49643 .41085 .49513 Mtetra
.675 .127 0 r
.41085 .49513 .41657 .49643 .42568 .50432 .41998 .50281 Mtetra
.705 .168 0 r
.41998 .50281 .42568 .50432 .43486 .51321 .42918 .51142 Mtetra
.729 .2 0 r
.42918 .51142 .43486 .51321 .44412 .52307 .43846 .52093 Mtetra
.747 .226 0 r
.43846 .52093 .44412 .52307 .45346 .5339 .44782 .53134 Mtetra
.762 .248 0 r
.44782 .53134 .45346 .5339 .46291 .5457 .45728 .54266 Mtetra
.773 .266 0 r
.45728 .54266 .46291 .5457 .47245 .55847 .46683 .55492 Mtetra
.781 .282 0 r
.46683 .55492 .47245 .55847 .48358 .45547 .4765 .56812 Mtetra
0 0 .272 r
.4765 .56812 .48358 .45547 .4932 .45237 .48783 .44661 Mtetra
.664 .741 .908 r
.48783 .44661 .4932 .45237 .50285 .44925 .4975 .44347 Mtetra
.4975 .44347 .50285 .44925 .51253 .44612 .50721 .44032 Mtetra
.50721 .44032 .51253 .44612 .52225 .44299 .51695 .43717 Mtetra
.51695 .43717 .52225 .44299 .532 .43984 .52672 .434 Mtetra
.52672 .434 .532 .43984 .54179 .43668 .53653 .43082 Mtetra
.53653 .43082 .54179 .43668 .55161 .43351 .54638 .42762 Mtetra
.54638 .42762 .55161 .43351 .56147 .43033 .55626 .42442 Mtetra
.55626 .42442 .56147 .43033 .57136 .42713 .56617 .42121 Mtetra
.56617 .42121 .57136 .42713 .58129 .42393 .57612 .41798 Mtetra
.57612 .41798 .58129 .42393 .59125 .42071 .58611 .41474 Mtetra
.58611 .41474 .59125 .42071 .60125 .41748 .59613 .41149 Mtetra
.59613 .41149 .60125 .41748 .61128 .41424 .60619 .40823 Mtetra
.60619 .40823 .61128 .41424 .62136 .41099 .61629 .40496 Mtetra
.61629 .40496 .62136 .41099 .63146 .40773 .62642 .40167 Mtetra
.62642 .40167 .63146 .40773 .64161 .40445 .63659 .39838 Mtetra
.63659 .39838 .64161 .40445 .65179 .40117 .6468 .39507 Mtetra
.6468 .39507 .65179 .40117 .66201 .39787 .65704 .39175 Mtetra
.65704 .39175 .66201 .39787 .67226 .39456 .66732 .38841 Mtetra
.66732 .38841 .67226 .39456 .68255 .39123 .67764 .38507 Mtetra
.966 .642 .326 r
.67764 .38507 .68255 .39123 .69288 .3879 .69413 .50226 Mtetra
.493 .272 .507 r
.69413 .50226 .69288 .3879 .70892 .48645 .70403 .48244 Mtetra
.933 .835 .724 r
.70403 .48244 .70892 .48645 .71872 .46704 .71392 .46352 Mtetra
.936 .852 .734 r
.71392 .46352 .71872 .46704 .72851 .44858 .72379 .44551 Mtetra
.938 .868 .744 r
.72379 .44551 .72851 .44858 .7383 .43107 .73367 .4284 Mtetra
.938 .885 .755 r
.73367 .4284 .7383 .43107 .7481 .41451 .74356 .41216 Mtetra
.935 .901 .767 r
.74356 .41216 .7481 .41451 .75793 .39892 .75346 .39681 Mtetra
.93 .916 .78 r
.75346 .39681 .75793 .39892 .76779 .3843 .76339 .38238 Mtetra
.923 .929 .795 r
.76339 .38238 .76779 .3843 .77769 .37065 .77336 .36887 Mtetra
.913 .941 .81 r
.77336 .36887 .77769 .37065 .78763 .35788 .78337 .35623 Mtetra
.832 .966 .891 r
.78337 .35623 .78763 .35788 .7983 .35387 .79368 .34744 Mtetra
.664 .741 .908 r
.79368 .34744 .7983 .35387 .80906 .35039 .80447 .34395 Mtetra
.80447 .34395 .80906 .35039 .81985 .34691 .81529 .34044 Mtetra
.81529 .34044 .81985 .34691 .83069 .34341 .82616 .33691 Mtetra
.82616 .33691 .83069 .34341 .84157 .3399 .83707 .33338 Mtetra
.83707 .33338 .84157 .3399 .85249 .33637 .84802 .32983 Mtetra
.84802 .32983 .85249 .33637 .86345 .33283 .85901 .32626 Mtetra
.85901 .32626 .86345 .33283 .87445 .32928 .87004 .32269 Mtetra
.87004 .32269 .87445 .32928 .8855 .32572 .88111 .3191 Mtetra
.88111 .3191 .8855 .32572 .89658 .32214 .89223 .31549 Mtetra
.29552 .50166 .30133 .50707 .31035 .50415 .30456 .49872 Mtetra
.30456 .49872 .31035 .50415 .31941 .50121 .31364 .49577 Mtetra
.31364 .49577 .31941 .50121 .32849 .49827 .32274 .4928 Mtetra
.32274 .4928 .32849 .49827 .3376 .49531 .33187 .48983 Mtetra
.33187 .48983 .3376 .49531 .34675 .49235 .34104 .48684 Mtetra
.34104 .48684 .34675 .49235 .35593 .48937 .35024 .48385 Mtetra
.35024 .48385 .35593 .48937 .36514 .48638 .35947 .48084 Mtetra
.35947 .48084 .36514 .48638 .37438 .48339 .36873 .47783 Mtetra
.626 .731 .922 r
.36873 .47783 .37438 .48339 .38365 .48038 .37798 .47565 Mtetra
0 .327 .777 r
.37798 .47565 .38365 .48038 .39276 .48251 .38697 .48068 Mtetra
.535 0 0 r
.38697 .48068 .39276 .48251 .40178 .48838 .39602 .48637 Mtetra
.586 .012 0 r
.39602 .48637 .40178 .48838 .41085 .49513 .40511 .49293 Mtetra
.629 .066 0 r
.40511 .49293 .41085 .49513 .41998 .50281 .41426 .50038 Mtetra
.661 .109 0 r
.41426 .50038 .41998 .50281 .42918 .51142 .42348 .50868 Mtetra
.685 .141 0 r
.42348 .50868 .42918 .51142 .43846 .52093 .43278 .5178 Mtetra
.701 .166 0 r
.43278 .5178 .43846 .52093 .44782 .53134 .44215 .52773 Mtetra
.712 .187 0 r
.44215 .52773 .44782 .53134 .45728 .54266 .45163 .53851 Mtetra
.72 .204 0 r
.45163 .53851 .45728 .54266 .46683 .55492 .46119 .55018 Mtetra
.724 .219 0 r
.46119 .55018 .46683 .55492 .4765 .56812 .47087 .56277 Mtetra
.724 .231 0 r
.47087 .56277 .4765 .56812 .48783 .44661 .48066 .57628 Mtetra
0 0 .282 r
.48066 .57628 .48783 .44661 .4975 .44347 .49212 .43765 Mtetra
.664 .741 .908 r
.49212 .43765 .4975 .44347 .50721 .44032 .50185 .43448 Mtetra
.50185 .43448 .50721 .44032 .51695 .43717 .51161 .43131 Mtetra
.51161 .43131 .51695 .43717 .52672 .434 .52141 .42812 Mtetra
.52141 .42812 .52672 .434 .53653 .43082 .53124 .42491 Mtetra
.53124 .42491 .53653 .43082 .54638 .42762 .54111 .4217 Mtetra
.54111 .4217 .54638 .42762 .55626 .42442 .55101 .41848 Mtetra
.55101 .41848 .55626 .42442 .56617 .42121 .56095 .41524 Mtetra
.56095 .41524 .56617 .42121 .57612 .41798 .57093 .41199 Mtetra
.57093 .41199 .57612 .41798 .58611 .41474 .58094 .40873 Mtetra
.58094 .40873 .58611 .41474 .59613 .41149 .59099 .40546 Mtetra
.59099 .40546 .59613 .41149 .60619 .40823 .60107 .40218 Mtetra
.60107 .40218 .60619 .40823 .61629 .40496 .61119 .39888 Mtetra
.61119 .39888 .61629 .40496 .62642 .40167 .62135 .39558 Mtetra
.62135 .39558 .62642 .40167 .63659 .39838 .63154 .39226 Mtetra
.63154 .39226 .63659 .39838 .6468 .39507 .64177 .38893 Mtetra
.64177 .38893 .6468 .39507 .65704 .39175 .65204 .38558 Mtetra
.65204 .38558 .65704 .39175 .66732 .38841 .66235 .38223 Mtetra
.967 .649 .343 r
.66235 .38223 .66732 .38841 .67764 .38507 .67905 .5166 Mtetra
.499 .279 .51 r
.67905 .5166 .67764 .38507 .69413 .50226 .68906 .49646 Mtetra
.912 .795 .719 r
.68906 .49646 .69413 .50226 .70403 .48244 .69904 .47722 Mtetra
.915 .81 .728 r
.69904 .47722 .70403 .48244 .71392 .46352 .70901 .45886 Mtetra
.919 .827 .739 r
.70901 .45886 .71392 .46352 .72379 .44551 .71897 .44137 Mtetra
.922 .844 .749 r
.71897 .44137 .72379 .44551 .73367 .4284 .72894 .4247 Mtetra
.923 .86 .76 r
.72894 .4247 .73367 .4284 .74356 .41216 .7389 .40882 Mtetra
.923 .875 .772 r
.7389 .40882 .74356 .41216 .75346 .39681 .74888 .39375 Mtetra
.92 .889 .785 r
.74888 .39375 .75346 .39681 .76339 .38238 .75888 .37951 Mtetra
.914 .901 .8 r
.75888 .37951 .76339 .38238 .77336 .36887 .76891 .36617 Mtetra
.905 .913 .815 r
.76891 .36617 .77336 .36887 .78337 .35623 .77899 .35368 Mtetra
.898 .923 .828 r
.77899 .35368 .78337 .35623 .79368 .34744 .7891 .34185 Mtetra
.695 .785 .92 r
.7891 .34185 .79368 .34744 .80447 .34395 .79985 .33746 Mtetra
.664 .741 .908 r
.79985 .33746 .80447 .34395 .81529 .34044 .8107 .33392 Mtetra
.8107 .33392 .81529 .34044 .82616 .33691 .8216 .33037 Mtetra
.8216 .33037 .82616 .33691 .83707 .33338 .83253 .32681 Mtetra
.83253 .32681 .83707 .33338 .84802 .32983 .84351 .32324 Mtetra
.84351 .32324 .84802 .32983 .85901 .32626 .85453 .31965 Mtetra
.85453 .31965 .85901 .32626 .87004 .32269 .8656 .31605 Mtetra
.8656 .31605 .87004 .32269 .88111 .3191 .8767 .31243 Mtetra
.8767 .31243 .88111 .3191 .89223 .31549 .88785 .3088 Mtetra
.28968 .49622 .29552 .50166 .30456 .49872 .29874 .49326 Mtetra
.29874 .49326 .30456 .49872 .31364 .49577 .30783 .49029 Mtetra
.30783 .49029 .31364 .49577 .32274 .4928 .31695 .4873 Mtetra
.31695 .4873 .32274 .4928 .33187 .48983 .3261 .48431 Mtetra
.3261 .48431 .33187 .48983 .34104 .48684 .33529 .48131 Mtetra
.33529 .48131 .34104 .48684 .35024 .48385 .34451 .47829 Mtetra
.34451 .47829 .35024 .48385 .35947 .48084 .35375 .47527 Mtetra
.35375 .47527 .35947 .48084 .36873 .47783 .36304 .47223 Mtetra
.409 .643 .953 r
.36304 .47223 .36873 .47783 .37798 .47565 .37216 .47329 Mtetra
.41 0 0 r
.37216 .47329 .37798 .47565 .38697 .48068 .38117 .4781 Mtetra
.46 0 0 r
.38117 .4781 .38697 .48068 .39602 .48637 .39024 .4836 Mtetra
.519 0 0 r
.39024 .4836 .39602 .48637 .40511 .49293 .39935 .48995 Mtetra
.567 .001 0 r
.39935 .48995 .40511 .49293 .41426 .50038 .40852 .49715 Mtetra
.601 .044 0 r
.40852 .49715 .41426 .50038 .42348 .50868 .41776 .50513 Mtetra
.622 .074 0 r
.41776 .50513 .42348 .50868 .43278 .5178 .42707 .51383 Mtetra
.635 .096 0 r
.42707 .51383 .43278 .5178 .44215 .52773 .43647 .52326 Mtetra
.641 .114 0 r
.43647 .52326 .44215 .52773 .45163 .53851 .44595 .53345 Mtetra
.642 .129 0 r
.44595 .53345 .45163 .53851 .46119 .55018 .45553 .54446 Mtetra
.64 .143 0 r
.45553 .54446 .46119 .55018 .47087 .56277 .46522 .55636 Mtetra
.635 .154 0 r
.46522 .55636 .47087 .56277 .48066 .57628 .47501 .56918 Mtetra
.625 .162 0 r
.47501 .56918 .48066 .57628 .49212 .43765 .48493 .58291 Mtetra
0 0 .289 r
.48493 .58291 .49212 .43765 .50185 .43448 .49645 .42861 Mtetra
.664 .741 .908 r
.49645 .42861 .50185 .43448 .51161 .43131 .50624 .42541 Mtetra
.50624 .42541 .51161 .43131 .52141 .42812 .51606 .4222 Mtetra
.51606 .4222 .52141 .42812 .53124 .42491 .52592 .41897 Mtetra
.52592 .41897 .53124 .42491 .54111 .4217 .53581 .41574 Mtetra
.53581 .41574 .54111 .4217 .55101 .41848 .54573 .41249 Mtetra
.54573 .41249 .55101 .41848 .56095 .41524 .5557 .40924 Mtetra
.5557 .40924 .56095 .41524 .57093 .41199 .56569 .40597 Mtetra
.56569 .40597 .57093 .41199 .58094 .40873 .57573 .40268 Mtetra
.57573 .40268 .58094 .40873 .59099 .40546 .5858 .39939 Mtetra
.5858 .39939 .59099 .40546 .60107 .40218 .59591 .39609 Mtetra
.59591 .39609 .60107 .40218 .61119 .39888 .60605 .39277 Mtetra
.60605 .39277 .61119 .39888 .62135 .39558 .61624 .38944 Mtetra
.61624 .38944 .62135 .39558 .63154 .39226 .62645 .3861 Mtetra
.62645 .3861 .63154 .39226 .64177 .38893 .63671 .38274 Mtetra
.63671 .38274 .64177 .38893 .65204 .38558 .64701 .37938 Mtetra
.968 .654 .357 r
.64701 .37938 .65204 .38558 .66235 .38223 .66369 .52938 Mtetra
.504 .283 .512 r
.66369 .52938 .66235 .38223 .67905 .5166 .67381 .50905 Mtetra
.89 .761 .713 r
.67381 .50905 .67905 .5166 .68906 .49646 .68389 .48957 Mtetra
.895 .775 .722 r
.68389 .48957 .68906 .49646 .69904 .47722 .69396 .47099 Mtetra
.899 .79 .732 r
.69396 .47099 .69904 .47722 .70901 .45886 .70402 .45327 Mtetra
.903 .807 .742 r
.70402 .45327 .70901 .45886 .71897 .44137 .71407 .43634 Mtetra
.907 .823 .753 r
.71407 .43634 .71897 .44137 .72894 .4247 .72411 .42014 Mtetra
.909 .839 .763 r
.72411 .42014 .72894 .4247 .7389 .40882 .73415 .40465 Mtetra
.91 .853 .774 r
.73415 .40465 .7389 .40882 .74888 .39375 .7442 .38986 Mtetra
.908 .866 .786 r
.7442 .38986 .74888 .39375 .75888 .37951 .75427 .37585 Mtetra
.903 .877 .801 r
.75427 .37585 .75888 .37951 .76891 .36617 .76437 .36267 Mtetra
.896 .888 .816 r
.76437 .36267 .76891 .36617 .77899 .35368 .77452 .35034 Mtetra
.888 .898 .83 r
.77452 .35034 .77899 .35368 .7891 .34185 .7847 .3387 Mtetra
.809 .912 .91 r
.7847 .3387 .7891 .34185 .79985 .33746 .79519 .33092 Mtetra
.664 .741 .908 r
.79519 .33092 .79985 .33746 .8107 .33392 .80608 .32736 Mtetra
.80608 .32736 .8107 .33392 .8216 .33037 .817 .32379 Mtetra
.817 .32379 .8216 .33037 .83253 .32681 .82797 .3202 Mtetra
.82797 .3202 .83253 .32681 .84351 .32324 .83898 .3166 Mtetra
.83898 .3166 .84351 .32324 .85453 .31965 .85003 .31299 Mtetra
.85003 .31299 .85453 .31965 .8656 .31605 .86112 .30936 Mtetra
.86112 .30936 .8656 .31605 .8767 .31243 .87226 .30572 Mtetra
.87226 .30572 .8767 .31243 .88785 .3088 .88343 .30207 Mtetra
.2838 .49075 .28968 .49622 .29874 .49326 .29287 .48776 Mtetra
.29287 .48776 .29874 .49326 .30783 .49029 .30198 .48477 Mtetra
.30198 .48477 .30783 .49029 .31695 .4873 .31112 .48177 Mtetra
.31112 .48177 .31695 .4873 .3261 .48431 .3203 .47876 Mtetra
.3203 .47876 .3261 .48431 .33529 .48131 .3295 .47574 Mtetra
.3295 .47574 .33529 .48131 .34451 .47829 .33874 .4727 Mtetra
.33874 .4727 .34451 .47829 .35375 .47527 .34801 .46966 Mtetra
.34801 .46966 .35375 .47527 .36304 .47223 .35731 .4666 Mtetra
.118 .481 .898 r
.35731 .4666 .36304 .47223 .37216 .47329 .36632 .47028 Mtetra
0 .258 .637 r
.36632 .47028 .37216 .47329 .38117 .4781 .37536 .47486 Mtetra
.374 0 0 r
.37536 .47486 .38117 .4781 .39024 .4836 .38444 .48017 Mtetra
.441 0 0 r
.38444 .48017 .39024 .4836 .39935 .48995 .39357 .48631 Mtetra
.494 0 0 r
.39357 .48631 .39935 .48995 .40852 .49715 .40276 .49325 Mtetra
.527 0 0 r
.40276 .49325 .40852 .49715 .41776 .50513 .41201 .50089 Mtetra
.544 .002 0 r
.41201 .50089 .41776 .50513 .42707 .51383 .42134 .50917 Mtetra
.55 .02 0 r
.42134 .50917 .42707 .51383 .43647 .52326 .43075 .51807 Mtetra
.549 .033 0 r
.43075 .51807 .43647 .52326 .44595 .53345 .44026 .52763 Mtetra
.542 .045 0 r
.44026 .52763 .44595 .53345 .45553 .54446 .44985 .53793 Mtetra
.534 .057 0 r
.44985 .53793 .45553 .54446 .46522 .55636 .45955 .54907 Mtetra
0 0 .469 r
.45955 .54907 .46522 .55636 .47501 .56918 .46934 .56112 Mtetra
0 0 .474 r
.46934 .56112 .47501 .56918 .48493 .58291 .47926 .57411 Mtetra
0 0 .48 r
.47926 .57411 .48493 .58291 .49645 .42861 .4893 .58794 Mtetra
0 0 .294 r
.4893 .58794 .49645 .42861 .50624 .42541 .50083 .41947 Mtetra
.664 .741 .908 r
.50083 .41947 .50624 .42541 .51606 .4222 .51067 .41624 Mtetra
.51067 .41624 .51606 .4222 .52592 .41897 .52055 .41299 Mtetra
.52055 .41299 .52592 .41897 .53581 .41574 .53047 .40974 Mtetra
.53047 .40974 .53581 .41574 .54573 .41249 .54042 .40647 Mtetra
.54042 .40647 .54573 .41249 .5557 .40924 .5504 .40319 Mtetra
.5504 .40319 .5557 .40924 .56569 .40597 .56043 .3999 Mtetra
.56043 .3999 .56569 .40597 .57573 .40268 .57049 .3966 Mtetra
.57049 .3966 .57573 .40268 .5858 .39939 .58058 .39328 Mtetra
.58058 .39328 .5858 .39939 .59591 .39609 .59071 .38995 Mtetra
.59071 .38995 .59591 .39609 .60605 .39277 .60088 .38661 Mtetra
.60088 .38661 .60605 .39277 .61624 .38944 .61109 .38326 Mtetra
.61109 .38326 .61624 .38944 .62645 .3861 .62134 .3799 Mtetra
.62134 .3799 .62645 .3861 .63671 .38274 .63162 .37652 Mtetra
.969 .658 .368 r
.63162 .37652 .63671 .38274 .64701 .37938 .64807 .54058 Mtetra
.506 .286 .514 r
.64807 .54058 .64701 .37938 .66369 .52938 .6583 .52015 Mtetra
.871 .732 .706 r
.6583 .52015 .66369 .52938 .67381 .50905 .66849 .50053 Mtetra
.875 .744 .715 r
.66849 .50053 .67381 .50905 .68389 .48957 .67866 .48179 Mtetra
.879 .758 .725 r
.67866 .48179 .68389 .48957 .69396 .47099 .68881 .46394 Mtetra
.884 .774 .735 r
.68881 .46394 .69396 .47099 .70402 .45327 .69895 .44689 Mtetra
.889 .79 .745 r
.69895 .44689 .70402 .45327 .71407 .43634 .70908 .43056 Mtetra
.893 .806 .755 r
.70908 .43056 .71407 .43634 .72411 .42014 .7192 .41486 Mtetra
.897 .821 .765 r
.7192 .41486 .72411 .42014 .73415 .40465 .72932 .39976 Mtetra
.898 .835 .775 r
.72932 .39976 .73415 .40465 .7442 .38986 .73944 .38528 Mtetra
.896 .847 .787 r
.73944 .38528 .7442 .38986 .75427 .37585 .74958 .37149 Mtetra
.892 .857 .8 r
.74958 .37149 .75427 .37585 .76437 .36267 .75975 .35849 Mtetra
.885 .866 .815 r
.75975 .35849 .76437 .36267 .77452 .35034 .76995 .34632 Mtetra
.878 .875 .829 r
.76995 .34632 .77452 .35034 .7847 .3387 .7802 .33488 Mtetra
.866 .886 .848 r
.7802 .33488 .7847 .3387 .79519 .33092 .79051 .32434 Mtetra
.664 .741 .908 r
.79051 .32434 .79519 .33092 .80608 .32736 .80142 .32076 Mtetra
.80142 .32076 .80608 .32736 .817 .32379 .81238 .31716 Mtetra
.81238 .31716 .817 .32379 .82797 .3202 .82337 .31355 Mtetra
.82337 .31355 .82797 .3202 .83898 .3166 .83441 .30992 Mtetra
.83441 .30992 .83898 .3166 .85003 .31299 .84549 .30628 Mtetra
.84549 .30628 .85003 .31299 .86112 .30936 .85661 .30263 Mtetra
.85661 .30263 .86112 .30936 .87226 .30572 .86778 .29896 Mtetra
.86778 .29896 .87226 .30572 .88343 .30207 .87899 .29528 Mtetra
.27788 .48523 .2838 .49075 .29287 .48776 .28697 .48223 Mtetra
.28697 .48223 .29287 .48776 .30198 .48477 .2961 .47922 Mtetra
.2961 .47922 .30198 .48477 .31112 .48177 .30526 .4762 Mtetra
.30526 .4762 .31112 .48177 .3203 .47876 .31445 .47317 Mtetra
.31445 .47317 .3203 .47876 .3295 .47574 .32368 .47013 Mtetra
.32368 .47013 .3295 .47574 .33874 .4727 .33293 .46707 Mtetra
.33293 .46707 .33874 .4727 .34801 .46966 .34222 .46401 Mtetra
.579 .715 .936 r
.34222 .46401 .34801 .46966 .35731 .4666 .35145 .46269 Mtetra
0 .384 .791 r
.35145 .46269 .35731 .4666 .36632 .47028 .36045 .4667 Mtetra
0 .327 .728 r
.36045 .4667 .36632 .47028 .37536 .47486 .36951 .47105 Mtetra
0 .26 .679 r
.36951 .47105 .37536 .47486 .38444 .48017 .37862 .47615 Mtetra
0 .187 .621 r
.37862 .47615 .38444 .48017 .39357 .48631 .38776 .48208 Mtetra
0 .13 .575 r
.38776 .48208 .39357 .48631 .40276 .49325 .39697 .48875 Mtetra
.443 0 0 r
.39697 .48875 .40276 .49325 .41201 .50089 .40624 .49605 Mtetra
.455 0 0 r
.40624 .49605 .41201 .50089 .42134 .50917 .41559 .50389 Mtetra
0 .059 .546 r
.41559 .50389 .42134 .50917 .43075 .51807 .42502 .51225 Mtetra
0 .052 .556 r
.42502 .51225 .43075 .51807 .44026 .52763 .43454 .52117 Mtetra
0 .043 .565 r
.43454 .52117 .44026 .52763 .44985 .53793 .44415 .53073 Mtetra
0 .033 .57 r
.44415 .53073 .44985 .53793 .45955 .54907 .45385 .54107 Mtetra
0 .02 .571 r
.45385 .54107 .45955 .54907 .46934 .56112 .46366 .55228 Mtetra
0 .007 .569 r
.46366 .55228 .46934 .56112 .47926 .57411 .47357 .56443 Mtetra
0 0 .567 r
.47357 .56443 .47926 .57411 .4893 .58794 .48361 .57749 Mtetra
0 0 .57 r
.48361 .57749 .4893 .58794 .50083 .41947 .49377 .59132 Mtetra
0 0 .298 r
.49377 .59132 .50083 .41947 .51067 .41624 .50525 .41024 Mtetra
.664 .741 .908 r
.50525 .41024 .51067 .41624 .52055 .41299 .51516 .40697 Mtetra
.51516 .40697 .52055 .41299 .53047 .40974 .52509 .4037 Mtetra
.52509 .4037 .53047 .40974 .54042 .40647 .53507 .40041 Mtetra
.53507 .40041 .54042 .40647 .5504 .40319 .54508 .3971 Mtetra
.54508 .3971 .5504 .40319 .56043 .3999 .55513 .39379 Mtetra
.55513 .39379 .56043 .3999 .57049 .3966 .56521 .39047 Mtetra
.56521 .39047 .57049 .3966 .58058 .39328 .57533 .38713 Mtetra
.57533 .38713 .58058 .39328 .59071 .38995 .58549 .38378 Mtetra
.58549 .38378 .59071 .38995 .60088 .38661 .59568 .38041 Mtetra
.59568 .38041 .60088 .38661 .61109 .38326 .60591 .37704 Mtetra
.60591 .37704 .61109 .38326 .62134 .3799 .61618 .37365 Mtetra
.969 .661 .377 r
.61618 .37365 .62134 .3799 .63162 .37652 .63221 .55015 Mtetra
.508 .288 .514 r
.63221 .55015 .63162 .37652 .64807 .54058 .64255 .52973 Mtetra
.853 .707 .7 r
.64255 .52973 .64807 .54058 .6583 .52015 .65285 .51003 Mtetra
.857 .717 .708 r
.65285 .51003 .6583 .52015 .66849 .50053 .66311 .4912 Mtetra
.861 .73 .717 r
.66311 .4912 .66849 .50053 .67866 .48179 .67336 .47327 Mtetra
.865 .744 .728 r
.67336 .47327 .67866 .48179 .68881 .46394 .68359 .45619 Mtetra
.87 .76 .738 r
.68359 .45619 .68881 .46394 .69895 .44689 .69381 .43985 Mtetra
.876 .776 .748 r
.69381 .43985 .69895 .44689 .70908 .43056 .70402 .42413 Mtetra
.881 .792 .758 r
.70402 .42413 .70908 .43056 .7192 .41486 .71422 .40895 Mtetra
.885 .806 .767 r
.71422 .40895 .7192 .41486 .72932 .39976 .72442 .39425 Mtetra
.886 .819 .776 r
.72442 .39425 .72932 .39976 .73944 .38528 .73461 .38008 Mtetra
.886 .83 .787 r
.73461 .38008 .73944 .38528 .74958 .37149 .74481 .36652 Mtetra
.882 .839 .799 r
.74481 .36652 .74958 .37149 .75975 .35849 .75504 .3537 Mtetra
.875 .848 .814 r
.75504 .3537 .75975 .35849 .76995 .34632 .7653 .3417 Mtetra
.868 .856 .828 r
.7653 .3417 .76995 .34632 .7802 .33488 .77561 .33045 Mtetra
.866 .865 .836 r
.77561 .33045 .7802 .33488 .79051 .32434 .78594 .31953 Mtetra
.73 .833 .929 r
.78594 .31953 .79051 .32434 .80142 .32076 .79673 .3141 Mtetra
.664 .741 .908 r
.79673 .3141 .80142 .32076 .81238 .31716 .80772 .31048 Mtetra
.80772 .31048 .81238 .31716 .82337 .31355 .81874 .30684 Mtetra
.81874 .30684 .82337 .31355 .83441 .30992 .82981 .30319 Mtetra
.82981 .30319 .83441 .30992 .84549 .30628 .84092 .29953 Mtetra
.84092 .29953 .84549 .30628 .85661 .30263 .85208 .29585 Mtetra
.85208 .29585 .85661 .30263 .86778 .29896 .86327 .29216 Mtetra
.86327 .29216 .86778 .29896 .87899 .29528 .87451 .28845 Mtetra
.27192 .47969 .27788 .48523 .28697 .48223 .28103 .47667 Mtetra
.28103 .47667 .28697 .48223 .2961 .47922 .29018 .47364 Mtetra
.29018 .47364 .2961 .47922 .30526 .4762 .29936 .4706 Mtetra
.29936 .4706 .30526 .4762 .31445 .47317 .30857 .46754 Mtetra
.30857 .46754 .31445 .47317 .32368 .47013 .31782 .46448 Mtetra
.31782 .46448 .32368 .47013 .33293 .46707 .32709 .46141 Mtetra
.32709 .46141 .33293 .46707 .34222 .46401 .3364 .45833 Mtetra
.447 .662 .953 r
.3364 .45833 .34222 .46401 .35145 .46269 .34554 .45889 Mtetra
0 .409 .806 r
.34554 .45889 .35145 .46269 .36045 .4667 .35457 .46261 Mtetra
0 .384 .798 r
.35457 .46261 .36045 .4667 .36951 .47105 .36365 .46673 Mtetra
0 .315 .749 r
.36365 .46673 .36951 .47105 .37862 .47615 .37277 .47162 Mtetra
0 .244 .694 r
.37277 .47162 .37862 .47615 .38776 .48208 .38194 .47732 Mtetra
0 .19 .653 r
.38194 .47732 .38776 .48208 .39697 .48875 .39116 .48372 Mtetra
0 .157 .632 r
.39116 .48372 .39697 .48875 .40624 .49605 .40045 .49068 Mtetra
0 .142 .629 r
.40045 .49068 .40624 .49605 .41559 .50389 .40981 .49809 Mtetra
0 .137 .637 r
.40981 .49809 .41559 .50389 .42502 .51225 .41926 .5059 Mtetra
0 .134 .648 r
.41926 .5059 .42502 .51225 .43454 .52117 .4288 .51416 Mtetra
0 .129 .656 r
.4288 .51416 .43454 .52117 .44415 .53073 .43843 .52297 Mtetra
0 .119 .658 r
.43843 .52297 .44415 .53073 .45385 .54107 .44814 .53247 Mtetra
0 .105 .653 r
.44814 .53247 .45385 .54107 .46366 .55228 .45796 .54279 Mtetra
0 .088 .645 r
.45796 .54279 .46366 .55228 .47357 .56443 .46787 .55404 Mtetra
0 .073 .635 r
.46787 .55404 .47357 .56443 .48361 .57749 .4779 .56625 Mtetra
0 .064 .629 r
.4779 .56625 .48361 .57749 .49377 .59132 .48805 .57932 Mtetra
0 .066 .63 r
.48805 .57932 .49377 .59132 .50525 .41024 .49833 .593 Mtetra
0 0 .301 r
.49833 .593 .50525 .41024 .51516 .40697 .50972 .40091 Mtetra
.664 .741 .908 r
.50972 .40091 .51516 .40697 .52509 .4037 .51968 .39761 Mtetra
.51968 .39761 .52509 .4037 .53507 .40041 .52968 .3943 Mtetra
.52968 .3943 .53507 .40041 .54508 .3971 .53972 .39098 Mtetra
.53972 .39098 .54508 .3971 .55513 .39379 .54979 .38764 Mtetra
.54979 .38764 .55513 .39379 .56521 .39047 .55989 .38429 Mtetra
.55989 .38429 .56521 .39047 .57533 .38713 .57004 .38093 Mtetra
.57004 .38093 .57533 .38713 .58549 .38378 .58022 .37756 Mtetra
.58022 .37756 .58549 .38378 .59568 .38041 .59044 .37418 Mtetra
.59044 .37418 .59568 .38041 .60591 .37704 .6007 .37078 Mtetra
.969 .663 .385 r
.6007 .37078 .60591 .37704 .61618 .37365 .61614 .55803 Mtetra
.51 .288 .514 r
.61614 .55803 .61618 .37365 .63221 .55015 .62659 .53777 Mtetra
.838 .686 .694 r
.62659 .53777 .63221 .55015 .64255 .52973 .63698 .51807 Mtetra
.84 .694 .701 r
.63698 .51807 .64255 .52973 .65285 .51003 .64735 .49918 Mtetra
.843 .705 .71 r
.64735 .49918 .65285 .51003 .66311 .4912 .65768 .48122 Mtetra
.847 .718 .72 r
.65768 .48122 .66311 .4912 .67336 .47327 .66801 .46414 Mtetra
.852 .733 .731 r
.66801 .46414 .67336 .47327 .68359 .45619 .67832 .44787 Mtetra
.858 .749 .742 r
.67832 .44787 .68359 .45619 .69381 .43985 .68862 .43225 Mtetra
.863 .765 .752 r
.68862 .43225 .69381 .43985 .70402 .42413 .6989 .41716 Mtetra
.869 .78 .76 r
.6989 .41716 .70402 .42413 .71422 .40895 .70918 .40249 Mtetra
.874 .794 .768 r
.70918 .40249 .71422 .40895 .72442 .39425 .71944 .3882 Mtetra
.876 .805 .777 r
.71944 .3882 .72442 .39425 .73461 .38008 .7297 .37433 Mtetra
.876 .816 .786 r
.7297 .37433 .73461 .38008 .74481 .36652 .73996 .361 Mtetra
.872 .824 .798 r
.73996 .361 .74481 .36652 .75504 .3537 .75025 .34836 Mtetra
.865 .832 .812 r
.75025 .34836 .75504 .3537 .7653 .3417 .76058 .33654 Mtetra
.858 .839 .826 r
.76058 .33654 .7653 .3417 .77561 .33045 .77095 .32549 Mtetra
.855 .847 .835 r
.77095 .32549 .77561 .33045 .78594 .31953 .78135 .31482 Mtetra
.79 .852 .897 r
.78135 .31482 .78594 .31953 .79673 .3141 .79201 .3074 Mtetra
.664 .741 .908 r
.79201 .3074 .79673 .3141 .80772 .31048 .80302 .30376 Mtetra
.80302 .30376 .80772 .31048 .81874 .30684 .81408 .30009 Mtetra
.81408 .30009 .81874 .30684 .82981 .30319 .82518 .29642 Mtetra
.82518 .29642 .82981 .30319 .84092 .29953 .83632 .29273 Mtetra
.83632 .29273 .84092 .29953 .85208 .29585 .8475 .28902 Mtetra
.8475 .28902 .85208 .29585 .86327 .29216 .85873 .2853 Mtetra
.85873 .2853 .86327 .29216 .87451 .28845 .87 .28157 Mtetra
.26592 .4741 .27192 .47969 .28103 .47667 .27506 .47106 Mtetra
.27506 .47106 .28103 .47667 .29018 .47364 .28422 .46801 Mtetra
.28422 .46801 .29018 .47364 .29936 .4706 .29342 .46495 Mtetra
.29342 .46495 .29936 .4706 .30857 .46754 .30265 .46188 Mtetra
.30265 .46188 .30857 .46754 .31782 .46448 .31192 .4588 Mtetra
.31192 .4588 .31782 .46448 .32709 .46141 .32121 .45571 Mtetra
.32121 .45571 .32709 .46141 .3364 .45833 .33054 .45261 Mtetra
.308 .593 .945 r
.33054 .45261 .3364 .45833 .34554 .45889 .33961 .45462 Mtetra
0 .461 .861 r
.33961 .45462 .34554 .45889 .35457 .46261 .34867 .45806 Mtetra
0 .431 .847 r
.34867 .45806 .35457 .46261 .36365 .46673 .35777 .46194 Mtetra
0 .362 .802 r
.35777 .46194 .36365 .46673 .37277 .47162 .36691 .4666 Mtetra
0 .294 .753 r
.36691 .4666 .37277 .47162 .38194 .47732 .37609 .47208 Mtetra
0 .244 .717 r
.37609 .47208 .38194 .47732 .39116 .48372 .38533 .47821 Mtetra
0 .217 .701 r
.38533 .47821 .39116 .48372 .40045 .49068 .39463 .48483 Mtetra
0 .207 .701 r
.39463 .48483 .40045 .49068 .40981 .49809 .40402 .4918 Mtetra
0 .208 .711 r
.40402 .4918 .40981 .49809 .41926 .5059 .41349 .49907 Mtetra
0 .21 .722 r
.41349 .49907 .41926 .5059 .4288 .51416 .42304 .50667 Mtetra
0 .208 .728 r
.42304 .50667 .4288 .51416 .43843 .52297 .43268 .51472 Mtetra
0 .199 .726 r
.43268 .51472 .43843 .52297 .44814 .53247 .44241 .52337 Mtetra
0 .183 .717 r
.44241 .52337 .44814 .53247 .45796 .54279 .45224 .53277 Mtetra
0 .163 .703 r
.45224 .53277 .45796 .54279 .46787 .55404 .46216 .54307 Mtetra
0 .143 .687 r
.46216 .54307 .46787 .55404 .4779 .56625 .47218 .55435 Mtetra
0 .127 .674 r
.47218 .55435 .4779 .56625 .48805 .57932 .48232 .56656 Mtetra
0 .12 .666 r
.48232 .56656 .48805 .57932 .49833 .593 .49258 .57954 Mtetra
0 .126 .667 r
.49258 .57954 .49833 .593 .50972 .40091 .50298 .59294 Mtetra
0 0 .303 r
.50298 .59294 .50972 .40091 .51968 .39761 .51424 .39149 Mtetra
.664 .741 .908 r
.51424 .39149 .51968 .39761 .52968 .3943 .52426 .38816 Mtetra
.52426 .38816 .52968 .3943 .53972 .39098 .53432 .38481 Mtetra
.53432 .38481 .53972 .39098 .54979 .38764 .54441 .38145 Mtetra
.54441 .38145 .54979 .38764 .55989 .38429 .55454 .37808 Mtetra
.55454 .37808 .55989 .38429 .57004 .38093 .56471 .3747 Mtetra
.56471 .3747 .57004 .38093 .58022 .37756 .57492 .3713 Mtetra
.57492 .3713 .58022 .37756 .59044 .37418 .58516 .36789 Mtetra
.968 .665 .392 r
.58516 .36789 .59044 .37418 .6007 .37078 .59987 .5642 Mtetra
.511 .289 .514 r
.59987 .5642 .6007 .37078 .61614 .55803 .61042 .54424 Mtetra
.824 .668 .69 r
.61042 .54424 .61614 .55803 .62659 .53777 .62092 .52462 Mtetra
.826 .675 .695 r
.62092 .52462 .62659 .53777 .63698 .51807 .63137 .50573 Mtetra
.828 .684 .704 r
.63137 .50573 .63698 .51807 .64735 .49918 .6418 .48774 Mtetra
.831 .695 .713 r
.6418 .48774 .64735 .49918 .65768 .48122 .65221 .47069 Mtetra
.835 .708 .724 r
.65221 .47069 .65768 .48122 .66801 .46414 .6626 .4545 Mtetra
.84 .723 .735 r
.6626 .4545 .66801 .46414 .67832 .44787 .67299 .43904 Mtetra
.846 .738 .745 r
.67299 .43904 .67832 .44787 .68862 .43225 .68337 .42416 Mtetra
.852 .754 .755 r
.68337 .42416 .68862 .43225 .6989 .41716 .69373 .40969 Mtetra
.858 .769 .763 r
.69373 .40969 .6989 .41716 .70918 .40249 .70407 .39552 Mtetra
.863 .782 .77 r
.70407 .39552 .70918 .40249 .71944 .3882 .7144 .38163 Mtetra
.866 .793 .777 r
.7144 .38163 .71944 .3882 .7297 .37433 .72473 .36807 Mtetra
.866 .803 .786 r
.72473 .36807 .7297 .37433 .73996 .361 .73505 .35497 Mtetra
.863 .81 .797 r
.73505 .35497 .73996 .361 .75025 .34836 .7454 .34253 Mtetra
.856 .817 .81 r
.7454 .34253 .75025 .34836 .76058 .33654 .75579 .33089 Mtetra
.848 .824 .824 r
.75579 .33089 .76058 .33654 .77095 .32549 .76622 .32005 Mtetra
.845 .832 .834 r
.76622 .32005 .77095 .32549 .78135 .31482 .77668 .30962 Mtetra
.821 .84 .862 r
.77668 .30962 .78135 .31482 .79201 .3074 .78725 .30066 Mtetra
.664 .741 .908 r
.78725 .30066 .79201 .3074 .80302 .30376 .7983 .29698 Mtetra
.7983 .29698 .80302 .30376 .81408 .30009 .80938 .2933 Mtetra
.80938 .2933 .81408 .30009 .82518 .29642 .82051 .28959 Mtetra
.82051 .28959 .82518 .29642 .83632 .29273 .83169 .28588 Mtetra
.83169 .28588 .83632 .29273 .8475 .28902 .8429 .28214 Mtetra
.8429 .28214 .8475 .28902 .85873 .2853 .85416 .2784 Mtetra
.85416 .2784 .85873 .2853 .87 .28157 .86546 .27464 Mtetra
.25989 .46848 .26592 .4741 .27506 .47106 .26904 .46543 Mtetra
.26904 .46543 .27506 .47106 .28422 .46801 .27823 .46236 Mtetra
.27823 .46236 .28422 .46801 .29342 .46495 .28744 .45928 Mtetra
.28744 .45928 .29342 .46495 .30265 .46188 .29669 .45619 Mtetra
.29669 .45619 .30265 .46188 .31192 .4588 .30598 .45308 Mtetra
.30598 .45308 .31192 .4588 .32121 .45571 .31529 .44997 Mtetra
.31529 .44997 .32121 .45571 .33054 .45261 .32464 .44685 Mtetra
.184 .523 .919 r
.32464 .44685 .33054 .45261 .33961 .45462 .33366 .44993 Mtetra
.075 .501 .898 r
.33366 .44993 .33961 .45462 .34867 .45806 .34274 .45309 Mtetra
.042 .468 .882 r
.34274 .45309 .34867 .45806 .35777 .46194 .35187 .45672 Mtetra
0 .402 .841 r
.35187 .45672 .35777 .46194 .36691 .4666 .36102 .46116 Mtetra
0 .337 .798 r
.36102 .46116 .36691 .4666 .37609 .47208 .37022 .46639 Mtetra
0 .292 .768 r
.37022 .46639 .37609 .47208 .38533 .47821 .37947 .47224 Mtetra
0 .27 .755 r
.37947 .47224 .38533 .47821 .39463 .48483 .3888 .47852 Mtetra
0 .266 .758 r
.3888 .47852 .39463 .48483 .40402 .4918 .3982 .48506 Mtetra
0 .271 .768 r
.3982 .48506 .40402 .4918 .41349 .49907 .40769 .4918 Mtetra
0 .277 .778 r
.40769 .4918 .41349 .49907 .42304 .50667 .41726 .49876 Mtetra
0 .278 .781 r
.41726 .49876 .42304 .50667 .43268 .51472 .42692 .50606 Mtetra
0 .269 .776 r
.42692 .50606 .43268 .51472 .44241 .52337 .43667 .51385 Mtetra
0 .252 .763 r
.43667 .51385 .44241 .52337 .45224 .53277 .4465 .52232 Mtetra
0 .23 .745 r
.4465 .52232 .45224 .53277 .46216 .54307 .45643 .53164 Mtetra
0 .206 .726 r
.45643 .53164 .46216 .54307 .47218 .55435 .46645 .54192 Mtetra
0 .184 .708 r
.46645 .54192 .47218 .55435 .48232 .56656 .47658 .55319 Mtetra
0 .169 .694 r
.47658 .55319 .48232 .56656 .49258 .57954 .48683 .56535 Mtetra
0 .165 .687 r
.48683 .56535 .49258 .57954 .50298 .59294 .4972 .57815 Mtetra
.009 .176 .69 r
.4972 .57815 .50298 .59294 .51424 .39149 .50772 .59109 Mtetra
0 0 .305 r
.50772 .59109 .51424 .39149 .52426 .38816 .5188 .38197 Mtetra
.664 .741 .908 r
.5188 .38197 .52426 .38816 .53432 .38481 .52888 .3786 Mtetra
.52888 .3786 .53432 .38481 .54441 .38145 .539 .37522 Mtetra
.539 .37522 .54441 .38145 .55454 .37808 .54916 .37182 Mtetra
.54916 .37182 .55454 .37808 .56471 .3747 .55935 .36842 Mtetra
.55935 .36842 .56471 .3747 .57492 .3713 .56958 .365 Mtetra
.968 .666 .398 r
.56958 .365 .57492 .3713 .58516 .36789 .58343 .56863 Mtetra
.512 .289 .513 r
.58343 .56863 .58516 .36789 .59987 .5642 .59408 .54912 Mtetra
.812 .653 .686 r
.59408 .54912 .59987 .5642 .61042 .54424 .60467 .5297 Mtetra
.813 .658 .69 r
.60467 .5297 .61042 .54424 .62092 .52462 .61522 .51086 Mtetra
.814 .665 .697 r
.61522 .51086 .62092 .52462 .63137 .50573 .62573 .49286 Mtetra
.816 .674 .706 r
.62573 .49286 .63137 .50573 .6418 .48774 .63622 .47582 Mtetra
.819 .686 .717 r
.63622 .47582 .6418 .48774 .65221 .47069 .64669 .45971 Mtetra
.823 .699 .728 r
.64669 .45971 .65221 .47069 .6626 .4545 .65716 .44443 Mtetra
.828 .714 .739 r
.65716 .44443 .6626 .4545 .67299 .43904 .66762 .42979 Mtetra
.834 .729 .749 r
.66762 .42979 .67299 .43904 .68337 .42416 .67806 .41562 Mtetra
.841 .745 .758 r
.67806 .41562 .68337 .42416 .69373 .40969 .6885 .40176 Mtetra
.847 .759 .765 r
.6885 .40176 .69373 .40969 .70407 .39552 .69891 .38809 Mtetra
.853 .771 .771 r
.69891 .38809 .70407 .39552 .7144 .38163 .70931 .37459 Mtetra
.857 .782 .777 r
.70931 .37459 .7144 .38163 .72473 .36807 .71969 .36134 Mtetra
.857 .791 .785 r
.71969 .36134 .72473 .36807 .73505 .35497 .73008 .34848 Mtetra
.854 .798 .795 r
.73008 .34848 .73505 .35497 .7454 .34253 .74048 .33624 Mtetra
.847 .804 .809 r
.74048 .33624 .7454 .34253 .75579 .33089 .75093 .3248 Mtetra
.839 .811 .823 r
.75093 .3248 .75579 .33089 .76622 .32005 .76142 .31416 Mtetra
.835 .818 .833 r
.76142 .31416 .76622 .32005 .77668 .30962 .77194 .30398 Mtetra
.837 .827 .838 r
.77194 .30398 .77668 .30962 .78725 .30066 .78246 .29386 Mtetra
.664 .741 .908 r
.78246 .29386 .78725 .30066 .7983 .29698 .79354 .29016 Mtetra
.79354 .29016 .7983 .29698 .80938 .2933 .80466 .28645 Mtetra
.80466 .28645 .80938 .2933 .82051 .28959 .81582 .28272 Mtetra
.81582 .28272 .82051 .28959 .83169 .28588 .82702 .27898 Mtetra
.82702 .27898 .83169 .28588 .8429 .28214 .83826 .27522 Mtetra
.83826 .27522 .8429 .28214 .85416 .2784 .84955 .27145 Mtetra
.84955 .27145 .85416 .2784 .86546 .27464 .86089 .26766 Mtetra
.25381 .46283 .25989 .46848 .26904 .46543 .26299 .45975 Mtetra
.26299 .45975 .26904 .46543 .27823 .46236 .27219 .45666 Mtetra
.27219 .45666 .27823 .46236 .28744 .45928 .28143 .45356 Mtetra
.28143 .45356 .28744 .45928 .29669 .45619 .2907 .45045 Mtetra
.2907 .45045 .29669 .45619 .30598 .45308 .3 .44733 Mtetra
.3 .44733 .30598 .45308 .31529 .44997 .30934 .4442 Mtetra
.647 .737 .915 r
.30934 .4442 .31529 .44997 .32464 .44685 .31868 .44145 Mtetra
.107 .493 .902 r
.31868 .44145 .32464 .44685 .33366 .44993 .32769 .44485 Mtetra
.146 .531 .92 r
.32769 .44485 .33366 .44993 .34274 .45309 .33679 .44774 Mtetra
.111 .498 .904 r
.33679 .44774 .34274 .45309 .35187 .45672 .34594 .45111 Mtetra
.031 .435 .869 r
.34594 .45111 .35187 .45672 .36102 .46116 .35512 .4553 Mtetra
0 .375 .832 r
.35512 .4553 .36102 .46116 .37022 .46639 .36433 .46028 Mtetra
0 .334 .807 r
.36433 .46028 .37022 .46639 .37947 .47224 .3736 .46585 Mtetra
0 .316 .797 r
.3736 .46585 .37947 .47224 .3888 .47852 .38294 .47178 Mtetra
0 .316 .801 r
.38294 .47178 .3888 .47852 .3982 .48506 .39236 .4779 Mtetra
0 .325 .81 r
.39236 .4779 .3982 .48506 .40769 .4918 .40186 .48413 Mtetra
0 .334 .817 r
.40186 .48413 .40769 .4918 .41726 .49876 .41146 .49047 Mtetra
.031 .336 .817 r
.41146 .49047 .41726 .49876 .42692 .50606 .42114 .49703 Mtetra
.054 .328 .809 r
.42114 .49703 .42692 .50606 .43667 .51385 .4309 .50397 Mtetra
.065 .312 .795 r
.4309 .50397 .43667 .51385 .4465 .52232 .44075 .51151 Mtetra
.066 .288 .776 r
.44075 .51151 .4465 .52232 .45643 .53164 .45069 .51983 Mtetra
.06 .262 .755 r
.45069 .51983 .45643 .53164 .46645 .54192 .46071 .52907 Mtetra
.052 .236 .734 r
.46071 .52907 .46645 .54192 .47658 .55319 .47083 .53933 Mtetra
.048 .216 .716 r
.47083 .53933 .47658 .55319 .48683 .56535 .48107 .55056 Mtetra
.05 .203 .703 r
.48107 .55056 .48683 .56535 .4972 .57815 .49142 .56259 Mtetra
.064 .202 .698 r
.49142 .56259 .4972 .57815 .50772 .59109 .50191 .57509 Mtetra
.096 .219 .703 r
.50191 .57509 .50772 .59109 .5188 .38197 .51254 .58741 Mtetra
0 0 .306 r
.51254 .58741 .5188 .38197 .52888 .3786 .52341 .37235 Mtetra
.664 .741 .908 r
.52341 .37235 .52888 .3786 .539 .37522 .53355 .36894 Mtetra
.53355 .36894 .539 .37522 .54916 .37182 .54373 .36553 Mtetra
.54373 .36553 .54916 .37182 .55935 .36842 .55395 .3621 Mtetra
.967 .667 .403 r
.55395 .3621 .55935 .36842 .56958 .365 .56684 .57128 Mtetra
.512 .289 .512 r
.56684 .57128 .56958 .365 .58343 .56863 .57758 .5524 Mtetra
.8 .64 .683 r
.57758 .5524 .58343 .56863 .59408 .54912 .58827 .53327 Mtetra
.801 .643 .686 r
.58827 .53327 .59408 .54912 .60467 .5297 .5989 .51455 Mtetra
.802 .648 .692 r
.5989 .51455 .60467 .5297 .61522 .51086 .60949 .49659 Mtetra
.803 .656 .7 r
.60949 .49659 .61522 .51086 .62573 .49286 .62006 .47957 Mtetra
.805 .666 .71 r
.62006 .47957 .62573 .49286 .63622 .47582 .6306 .46352 Mtetra
.808 .678 .721 r
.6306 .46352 .63622 .47582 .64669 .45971 .64114 .44838 Mtetra
.811 .691 .732 r
.64114 .44838 .64669 .45971 .65716 .44443 .65168 .43398 Mtetra
.817 .706 .743 r
.65168 .43398 .65716 .44443 .66762 .42979 .6622 .42016 Mtetra
.823 .721 .752 r
.6622 .42016 .66762 .42979 .67806 .41562 .67272 .40669 Mtetra
.83 .736 .76 r
.67272 .40669 .67806 .41562 .6885 .40176 .68321 .39341 Mtetra
.837 .749 .766 r
.68321 .39341 .6885 .40176 .69891 .38809 .69369 .38023 Mtetra
.843 .761 .772 r
.69369 .38023 .69891 .38809 .70931 .37459 .70415 .36711 Mtetra
.847 .771 .777 r
.70415 .36711 .70931 .37459 .71969 .36134 .7146 .35416 Mtetra
.848 .78 .784 r
.7146 .35416 .71969 .36134 .73008 .34848 .72504 .34155 Mtetra
.846 .787 .794 r
.72504 .34155 .73008 .34848 .74048 .33624 .7355 .32953 Mtetra
.839 .793 .807 r
.7355 .32953 .74048 .33624 .75093 .3248 .746 .31829 Mtetra
.83 .799 .822 r
.746 .31829 .75093 .3248 .76142 .31416 .75656 .30787 Mtetra
.826 .805 .832 r
.75656 .30787 .76142 .31416 .77194 .30398 .76714 .29792 Mtetra
.838 .816 .828 r
.76714 .29792 .77194 .30398 .78246 .29386 .77768 .28744 Mtetra
.679 .762 .914 r
.77768 .28744 .78246 .29386 .79354 .29016 .78875 .28329 Mtetra
.664 .741 .908 r
.78875 .28329 .79354 .29016 .80466 .28645 .79989 .27955 Mtetra
.79989 .27955 .80466 .28645 .81582 .28272 .81108 .2758 Mtetra
.81108 .2758 .81582 .28272 .82702 .27898 .82232 .27203 Mtetra
.82232 .27203 .82702 .27898 .83826 .27522 .83359 .26824 Mtetra
.83359 .26824 .83826 .27522 .84955 .27145 .84492 .26444 Mtetra
.84492 .26444 .84955 .27145 .86089 .26766 .85628 .26063 Mtetra
.2477 .45714 .25381 .46283 .26299 .45975 .25689 .45404 Mtetra
.25689 .45404 .26299 .45975 .27219 .45666 .26612 .45093 Mtetra
.26612 .45093 .27219 .45666 .28143 .45356 .27537 .44781 Mtetra
.27537 .44781 .28143 .45356 .2907 .45045 .28466 .44468 Mtetra
.28466 .44468 .2907 .45045 .3 .44733 .29398 .44154 Mtetra
.29398 .44154 .3 .44733 .30934 .4442 .30334 .43838 Mtetra
.617 .728 .925 r
.30334 .43838 .30934 .4442 .31868 .44145 .31266 .43626 Mtetra
.117 .509 .909 r
.31266 .43626 .31868 .44145 .32769 .44485 .32169 .4394 Mtetra
.207 .554 .933 r
.32169 .4394 .32769 .44485 .33679 .44774 .33082 .44203 Mtetra
.171 .521 .918 r
.33082 .44203 .33679 .44774 .34594 .45111 .33999 .44514 Mtetra
.095 .463 .889 r
.33999 .44514 .34594 .45111 .35512 .4553 .34919 .44907 Mtetra
.026 .407 .857 r
.34919 .44907 .35512 .4553 .36433 .46028 .35842 .45377 Mtetra
0 .37 .836 r
.35842 .45377 .36433 .46028 .3736 .46585 .36771 .45904 Mtetra
0 .356 .828 r
.36771 .45904 .3736 .46585 .38294 .47178 .37706 .46463 Mtetra
.005 .358 .831 r
.37706 .46463 .38294 .47178 .39236 .4779 .3865 .47034 Mtetra
.043 .37 .838 r
.3865 .47034 .39236 .4779 .40186 .48413 .39602 .47607 Mtetra
.085 .38 .842 r
.39602 .47607 .40186 .48413 .41146 .49047 .40564 .48181 Mtetra
.12 .383 .84 r
.40564 .48181 .41146 .49047 .42114 .49703 .41534 .48766 Mtetra
.143 .377 .831 r
.41534 .48766 .42114 .49703 .4309 .50397 .42512 .49379 Mtetra
.153 .361 .816 r
.42512 .49379 .4309 .50397 .44075 .51151 .43498 .50041 Mtetra
.152 .338 .796 r
.43498 .50041 .44075 .51151 .45069 .51983 .44493 .50773 Mtetra
.143 .311 .775 r
.44493 .50773 .45069 .51983 .46071 .52907 .45496 .51592 Mtetra
.131 .284 .753 r
.45496 .51592 .46071 .52907 .47083 .53933 .46508 .52509 Mtetra
.121 .259 .733 r
.46508 .52509 .47083 .53933 .48107 .55056 .4753 .53528 Mtetra
.117 .241 .717 r
.4753 .53528 .48107 .55056 .49142 .56259 .48564 .54639 Mtetra
.12 .232 .706 r
.48564 .54639 .49142 .56259 .50191 .57509 .4961 .55821 Mtetra
.135 .234 .703 r
.4961 .55821 .50191 .57509 .51254 .58741 .50669 .5703 Mtetra
.17 .256 .711 r
.50669 .5703 .51254 .58741 .52341 .37235 .51743 .58188 Mtetra
0 0 .306 r
.51743 .58188 .52341 .37235 .53355 .36894 .52807 .36262 Mtetra
.664 .741 .908 r
.52807 .36262 .53355 .36894 .54373 .36553 .53827 .35918 Mtetra
.967 .668 .408 r
.53827 .35918 .54373 .36553 .55395 .3621 .55013 .57214 Mtetra
.513 .288 .511 r
.55013 .57214 .55395 .3621 .56684 .57128 .56095 .554 Mtetra
.79 .628 .681 r
.56095 .554 .56684 .57128 .57758 .5524 .57172 .53527 Mtetra
.79 .629 .682 r
.57172 .53527 .57758 .5524 .58827 .53327 .58243 .51677 Mtetra
.79 .633 .687 r
.58243 .51677 .58827 .53327 .5989 .51455 .5931 .49892 Mtetra
.791 .64 .694 r
.5931 .49892 .5989 .51455 .60949 .49659 .60374 .48195 Mtetra
.792 .648 .703 r
.60374 .48195 .60949 .49659 .62006 .47957 .61436 .46596 Mtetra
.794 .659 .714 r
.61436 .46596 .62006 .47957 .6306 .46352 .62496 .45092 Mtetra
.797 .671 .725 r
.62496 .45092 .6306 .46352 .64114 .44838 .63556 .43674 Mtetra
.8 .684 .736 r
.63556 .43674 .64114 .44838 .65168 .43398 .64616 .42323 Mtetra
.805 .698 .747 r
.64616 .42323 .65168 .43398 .6622 .42016 .65675 .41018 Mtetra
.812 .713 .756 r
.65675 .41018 .6622 .42016 .67272 .40669 .66732 .39738 Mtetra
.82 .727 .763 r
.66732 .39738 .67272 .40669 .68321 .39341 .67788 .38467 Mtetra
.827 .74 .768 r
.67788 .38467 .68321 .39341 .69369 .38023 .68842 .37194 Mtetra
.834 .752 .772 r
.68842 .37194 .69369 .38023 .70415 .36711 .69894 .3592 Mtetra
.839 .761 .777 r
.69894 .3592 .70415 .36711 .7146 .35416 .70944 .34655 Mtetra
.84 .769 .784 r
.70944 .34655 .7146 .35416 .72504 .34155 .71995 .3342 Mtetra
.837 .776 .794 r
.71995 .3342 .72504 .34155 .7355 .32953 .73046 .32241 Mtetra
.83 .782 .806 r
.73046 .32241 .7355 .32953 .746 .31829 .74102 .31139 Mtetra
.821 .788 .82 r
.74102 .31139 .746 .31829 .75656 .30787 .75163 .3012 Mtetra
.817 .794 .831 r
.75163 .3012 .75656 .30787 .76714 .29792 .76227 .29148 Mtetra
.83 .804 .827 r
.76227 .29148 .76714 .29792 .77768 .28744 .77287 .28121 Mtetra
.702 .779 .911 r
.77287 .28121 .77768 .28744 .78875 .28329 .78392 .27638 Mtetra
.664 .741 .908 r
.78392 .27638 .78875 .28329 .79989 .27955 .7951 .27261 Mtetra
.7951 .27261 .79989 .27955 .81108 .2758 .80632 .26883 Mtetra
.80632 .26883 .81108 .2758 .82232 .27203 .81758 .26503 Mtetra
.81758 .26503 .82232 .27203 .83359 .26824 .82889 .26122 Mtetra
.82889 .26122 .83359 .26824 .84492 .26444 .84024 .25739 Mtetra
.84024 .25739 .84492 .26444 .85628 .26063 .85164 .25355 Mtetra
.24155 .45141 .2477 .45714 .25689 .45404 .25076 .44829 Mtetra
.25076 .44829 .25689 .45404 .26612 .45093 .26 .44516 Mtetra
.26 .44516 .26612 .45093 .27537 .44781 .26928 .44202 Mtetra
.26928 .44202 .27537 .44781 .28466 .44468 .27859 .43887 Mtetra
.27859 .43887 .28466 .44468 .29398 .44154 .28793 .4357 Mtetra
.28793 .4357 .29398 .44154 .30334 .43838 .2973 .43253 Mtetra
.602 .723 .93 r
.2973 .43253 .30334 .43838 .31266 .43626 .30662 .43069 Mtetra
.174 .53 .922 r
.30662 .43069 .31266 .43626 .32169 .4394 .31568 .43362 Mtetra
.258 .57 .939 r
.31568 .43362 .32169 .4394 .33082 .44203 .32483 .436 Mtetra
.224 .541 .926 r
.32483 .436 .33082 .44203 .33999 .44514 .33402 .43883 Mtetra
.153 .487 .902 r
.33402 .43883 .33999 .44514 .34919 .44907 .34324 .44248 Mtetra
.089 .436 .875 r
.34324 .44248 .34919 .44907 .35842 .45377 .35249 .44689 Mtetra
.054 .402 .857 r
.35249 .44689 .35842 .45377 .36771 .45904 .36179 .45184 Mtetra
.052 .389 .85 r
.36179 .45184 .36771 .45904 .37706 .46463 .37117 .45708 Mtetra
.077 .394 .852 r
.37117 .45708 .37706 .46463 .3865 .47034 .38062 .46239 Mtetra
.117 .405 .856 r
.38062 .46239 .3865 .47034 .39602 .47607 .39016 .46763 Mtetra
.16 .416 .857 r
.39016 .46763 .39602 .47607 .40564 .48181 .3998 .47281 Mtetra
.195 .421 .853 r
.3998 .47281 .40564 .48181 .41534 .48766 .40952 .47799 Mtetra
.218 .416 .843 r
.40952 .47799 .41534 .48766 .42512 .49379 .41932 .48334 Mtetra
.227 .402 .828 r
.41932 .48334 .42512 .49379 .43498 .50041 .4292 .48908 Mtetra
.226 .381 .81 r
.4292 .48908 .43498 .50041 .44493 .50773 .43916 .49541 Mtetra
.216 .354 .789 r
.43916 .49541 .44493 .50773 .45496 .51592 .4492 .50253 Mtetra
.203 .327 .768 r
.4492 .50253 .45496 .51592 .46508 .52509 .45932 .5106 Mtetra
.19 .3 .748 r
.45932 .5106 .46508 .52509 .4753 .53528 .46954 .51966 Mtetra
.181 .279 .73 r
.46954 .51966 .4753 .53528 .48564 .54639 .47986 .52968 Mtetra
.179 .265 .716 r
.47986 .52968 .48564 .54639 .4961 .55821 .49029 .54053 Mtetra
.185 .258 .706 r
.49029 .54053 .4961 .55821 .50669 .5703 .50085 .55195 Mtetra
.2 .262 .703 r
.50085 .55195 .50669 .5703 .51743 .58188 .51155 .56355 Mtetra
.23 .284 .712 r
.51155 .56355 .51743 .58188 .52807 .36262 .52239 .57445 Mtetra
.537 .307 .514 r
.52239 .57445 .52807 .36262 .53827 .35918 .53332 .57118 Mtetra
.512 .287 .51 r
.53332 .57118 .53827 .35918 .55013 .57214 .54421 .5537 Mtetra
.778 .616 .679 r
.54421 .5537 .55013 .57214 .56095 .554 .55506 .53546 Mtetra
.777 .614 .678 r
.55506 .53546 .56095 .554 .57172 .53527 .56584 .51734 Mtetra
.778 .618 .682 r
.56584 .51734 .57172 .53527 .58243 .51677 .57659 .49975 Mtetra
.779 .624 .688 r
.57659 .49975 .58243 .51677 .5931 .49892 .58729 .48293 Mtetra
.78 .632 .697 r
.58729 .48293 .5931 .49892 .60374 .48195 .59797 .46704 Mtetra
.782 .641 .707 r
.59797 .46704 .60374 .48195 .61436 .46596 .60864 .45212 Mtetra
.783 .652 .718 r
.60864 .45212 .61436 .46596 .62496 .45092 .6193 .4381 Mtetra
.786 .664 .729 r
.6193 .4381 .62496 .45092 .63556 .43674 .62995 .42486 Mtetra
.789 .677 .741 r
.62995 .42486 .63556 .43674 .64616 .42323 .6406 .41219 Mtetra
.795 .691 .75 r
.6406 .41219 .64616 .42323 .65675 .41018 .65125 .39988 Mtetra
.802 .705 .759 r
.65125 .39988 .65675 .41018 .66732 .39738 .66189 .38772 Mtetra
.81 .719 .765 r
.66189 .38772 .66732 .39738 .67788 .38467 .67251 .37553 Mtetra
.818 .731 .769 r
.67251 .37553 .67788 .38467 .68842 .37194 .6831 .36325 Mtetra
.825 .742 .773 r
.6831 .36325 .68842 .37194 .69894 .3592 .69368 .35087 Mtetra
.83 .752 .777 r
.69368 .35087 .69894 .3592 .70944 .34655 .70424 .33853 Mtetra
.831 .76 .784 r
.70424 .33853 .70944 .34655 .71995 .3342 .7148 .32646 Mtetra
.829 .766 .793 r
.7148 .32646 .71995 .3342 .73046 .32241 .72537 .31492 Mtetra
.822 .772 .806 r
.72537 .31492 .73046 .32241 .74102 .31139 .73599 .30415 Mtetra
.813 .777 .82 r
.73599 .30415 .74102 .31139 .75163 .3012 .74665 .29419 Mtetra
.809 .784 .83 r
.74665 .29419 .75163 .3012 .76227 .29148 .75735 .28468 Mtetra
.822 .794 .825 r
.75735 .28468 .76227 .29148 .77287 .28121 .768 .27459 Mtetra
.711 .77 .899 r
.768 .27459 .77287 .28121 .78392 .27638 .77906 .26941 Mtetra
.664 .741 .908 r
.77906 .26941 .78392 .27638 .7951 .27261 .79026 .26561 Mtetra
.79026 .26561 .7951 .27261 .80632 .26883 .80152 .2618 Mtetra
.80152 .2618 .80632 .26883 .81758 .26503 .81281 .25798 Mtetra
.81281 .25798 .81758 .26503 .82889 .26122 .82415 .25414 Mtetra
.82415 .25414 .82889 .26122 .84024 .25739 .83554 .25028 Mtetra
.83554 .25028 .84024 .25739 .85164 .25355 .84697 .24641 Mtetra
.23536 .44564 .24155 .45141 .25076 .44829 .24459 .4425 Mtetra
.24459 .4425 .25076 .44829 .26 .44516 .25385 .43935 Mtetra
.25385 .43935 .26 .44516 .26928 .44202 .26314 .43619 Mtetra
.26314 .43619 .26928 .44202 .27859 .43887 .27247 .43302 Mtetra
.27247 .43302 .27859 .43887 .28793 .4357 .28183 .42984 Mtetra
.28183 .42984 .28793 .4357 .2973 .43253 .29123 .42664 Mtetra
.603 .723 .93 r
.29123 .42664 .2973 .43253 .30662 .43069 .30057 .42477 Mtetra
.218 .542 .927 r
.30057 .42477 .30662 .43069 .31568 .43362 .30964 .42753 Mtetra
.3 .582 .94 r
.30964 .42753 .31568 .43362 .32483 .436 .31881 .42966 Mtetra
.271 .556 .93 r
.31881 .42966 .32483 .436 .33402 .43883 .32803 .43221 Mtetra
.206 .508 .91 r
.32803 .43221 .33402 .43883 .34324 .44248 .33727 .43555 Mtetra
.147 .461 .888 r
.33727 .43555 .34324 .44248 .35249 .44689 .34654 .43965 Mtetra
.115 .43 .871 r
.34654 .43965 .35249 .44689 .36179 .45184 .35586 .44427 Mtetra
.116 .418 .864 r
.35586 .44427 .36179 .45184 .37117 .45708 .36525 .44915 Mtetra
.142 .422 .864 r
.36525 .44915 .37117 .45708 .38062 .46239 .37472 .45406 Mtetra
.181 .434 .866 r
.37472 .45406 .38062 .46239 .39016 .46763 .38429 .45885 Mtetra
.223 .445 .865 r
.38429 .45885 .39016 .46763 .3998 .47281 .39394 .46348 Mtetra
.257 .45 .859 r
.39394 .46348 .3998 .47281 .40952 .47799 .40368 .46804 Mtetra
.28 .447 .849 r
.40368 .46804 .40952 .47799 .41932 .48334 .4135 .47266 Mtetra
.29 .435 .835 r
.4135 .47266 .41932 .48334 .4292 .48908 .4234 .47755 Mtetra
.289 .416 .818 r
.4234 .47755 .4292 .48908 .43916 .49541 .43337 .48293 Mtetra
.279 .392 .799 r
.43337 .48293 .43916 .49541 .4492 .50253 .44342 .48901 Mtetra
.266 .365 .779 r
.44342 .48901 .4492 .50253 .45932 .5106 .45355 .49594 Mtetra
.252 .339 .759 r
.45355 .49594 .45932 .5106 .46954 .51966 .46376 .50381 Mtetra
.243 .317 .74 r
.46376 .50381 .46954 .51966 .47986 .52968 .47407 .51261 Mtetra
.24 .3 .725 r
.47407 .51261 .47986 .52968 .49029 .54053 .48449 .52223 Mtetra
.247 .292 .713 r
.48449 .52223 .49029 .54053 .50085 .55195 .49503 .53246 Mtetra
.265 .293 .705 r
.49503 .53246 .50085 .55195 .51155 .56355 .50569 .54295 Mtetra
.306 .312 .702 r
.50569 .54295 .51155 .56355 .52239 .57445 .51648 .55289 Mtetra
.609 .5 .705 r
.51648 .55289 .52239 .57445 .53332 .57118 .52739 .54958 Mtetra
.747 .583 .672 r
.52739 .54958 .53332 .57118 .54421 .5537 .53829 .53299 Mtetra
.757 .592 .673 r
.53829 .53299 .54421 .5537 .55506 .53546 .54915 .51579 Mtetra
.762 .6 .677 r
.54915 .51579 .55506 .53546 .56584 .51734 .55996 .49879 Mtetra
.765 .608 .683 r
.55996 .49879 .56584 .51734 .57659 .49975 .57073 .48236 Mtetra
.768 .616 .691 r
.57073 .48236 .57659 .49975 .58729 .48293 .58147 .46672 Mtetra
.769 .625 .701 r
.58147 .46672 .58729 .48293 .59797 .46704 .59219 .45197 Mtetra
.771 .635 .711 r
.59219 .45197 .59797 .46704 .60864 .45212 .6029 .43813 Mtetra
.772 .646 .723 r
.6029 .43813 .60864 .45212 .6193 .4381 .61361 .42512 Mtetra
.775 .658 .734 r
.61361 .42512 .6193 .4381 .62995 .42486 .62432 .41278 Mtetra
.779 .671 .745 r
.62432 .41278 .62995 .42486 .6406 .41219 .63502 .40092 Mtetra
.784 .685 .754 r
.63502 .40092 .6406 .41219 .65125 .39988 .64572 .3893 Mtetra
.792 .698 .761 r
.64572 .3893 .65125 .39988 .66189 .38772 .65641 .37772 Mtetra
.8 .711 .766 r
.65641 .37772 .66189 .38772 .67251 .37553 .66709 .36603 Mtetra
.809 .723 .77 r
.66709 .36603 .67251 .37553 .6831 .36325 .67774 .35416 Mtetra
.816 .733 .773 r
.67774 .35416 .6831 .36325 .69368 .35087 .68837 .34214 Mtetra
.821 .742 .777 r
.68837 .34214 .69368 .35087 .70424 .33853 .69898 .33012 Mtetra
.823 .75 .783 r
.69898 .33012 .70424 .33853 .7148 .32646 .70959 .31834 Mtetra
.82 .757 .793 r
.70959 .31834 .7148 .32646 .72537 .31492 .72022 .30708 Mtetra
.814 .763 .805 r
.72022 .30708 .72537 .31492 .73599 .30415 .73089 .29657 Mtetra
.805 .768 .819 r
.73089 .29657 .73599 .30415 .74665 .29419 .74161 .28685 Mtetra
.801 .775 .829 r
.74161 .28685 .74665 .29419 .75735 .28468 .75237 .27755 Mtetra
.816 .784 .823 r
.75237 .27755 .75735 .28468 .768 .27459 .76307 .26758 Mtetra
.709 .758 .891 r
.76307 .26758 .768 .27459 .77906 .26941 .77416 .26239 Mtetra
.664 .741 .908 r
.77416 .26239 .77906 .26941 .79026 .26561 .7854 .25857 Mtetra
.7854 .25857 .79026 .26561 .80152 .2618 .79668 .25473 Mtetra
.79668 .25473 .80152 .2618 .81281 .25798 .80801 .25088 Mtetra
.80801 .25088 .81281 .25798 .82415 .25414 .81938 .24701 Mtetra
.81938 .24701 .82415 .25414 .83554 .25028 .8308 .24313 Mtetra
.8308 .24313 .83554 .25028 .84697 .24641 .84226 .23923 Mtetra
.22912 .43984 .23536 .44564 .24459 .4425 .23837 .43668 Mtetra
.23837 .43668 .24459 .4425 .25385 .43935 .24765 .43351 Mtetra
.24765 .43351 .25385 .43935 .26314 .43619 .25697 .43033 Mtetra
.25697 .43033 .26314 .43619 .27247 .43302 .26632 .42713 Mtetra
.26632 .42713 .27247 .43302 .28183 .42984 .2757 .42393 Mtetra
.2757 .42393 .28183 .42984 .29123 .42664 .28511 .42071 Mtetra
.619 .729 .925 r
.28511 .42071 .29123 .42664 .30057 .42477 .29449 .41849 Mtetra
.251 .548 .928 r
.29449 .41849 .30057 .42477 .30964 .42753 .30358 .42113 Mtetra
.335 .59 .938 r
.30358 .42113 .30964 .42753 .31881 .42966 .31278 .42304 Mtetra
.313 .57 .93 r
.31278 .42304 .31881 .42966 .32803 .43221 .32202 .4253 Mtetra
.254 .527 .915 r
.32202 .4253 .32803 .43221 .33727 .43555 .33128 .42832 Mtetra
.2 .483 .896 r
.33128 .42832 .33727 .43555 .34654 .43965 .34057 .43208 Mtetra
.171 .454 .881 r
.34057 .43208 .34654 .43965 .35586 .44427 .34991 .43635 Mtetra
.173 .443 .873 r
.34991 .43635 .35586 .44427 .36525 .44915 .35932 .44086 Mtetra
.198 .446 .871 r
.35932 .44086 .36525 .44915 .37472 .45406 .36881 .44537 Mtetra
.236 .457 .87 r
.36881 .44537 .37472 .45406 .38429 .45885 .37839 .44972 Mtetra
.276 .467 .867 r
.37839 .44972 .38429 .45885 .39394 .46348 .38806 .45385 Mtetra
.309 .473 .861 r
.38806 .45385 .39394 .46348 .40368 .46804 .39782 .45782 Mtetra
.331 .472 .85 r
.39782 .45782 .40368 .46804 .4135 .47266 .40766 .46176 Mtetra
.342 .462 .837 r
.40766 .46176 .4135 .47266 .4234 .47755 .41758 .46587 Mtetra
.342 .446 .822 r
.41758 .46587 .4234 .47755 .43337 .48293 .42757 .47036 Mtetra
.334 .424 .805 r
.42757 .47036 .43337 .48293 .44342 .48901 .43763 .47542 Mtetra
.321 .399 .786 r
.43763 .47542 .44342 .48901 .45355 .49594 .44777 .48124 Mtetra
.309 .374 .768 r
.44777 .48124 .45355 .49594 .46376 .50381 .45799 .48788 Mtetra
.3 .353 .75 r
.45799 .48788 .46376 .50381 .47407 .51261 .46829 .49536 Mtetra
.299 .337 .733 r
.46829 .49536 .47407 .51261 .48449 .52223 .4787 .50356 Mtetra
.311 .331 .72 r
.4787 .50356 .48449 .52223 .49503 .53246 .48921 .51219 Mtetra
.343 .338 .709 r
.48921 .51219 .49503 .53246 .50569 .54295 .49984 .52063 Mtetra
.426 .378 .701 r
.49984 .52063 .50569 .54295 .51648 .55289 .5106 .52683 Mtetra
.6 .472 .678 r
.5106 .52683 .51648 .55289 .52739 .54958 .52148 .52348 Mtetra
.697 .534 .663 r
.52148 .52348 .52739 .54958 .53829 .53299 .53238 .51054 Mtetra
.732 .57 .671 r
.53238 .51054 .53829 .53299 .54915 .51579 .54324 .49532 Mtetra
.746 .587 .678 r
.54324 .49532 .54915 .51579 .55996 .49879 .55407 .47986 Mtetra
.752 .599 .686 r
.55407 .47986 .55996 .49879 .57073 .48236 .56487 .4648 Mtetra
.756 .609 .695 r
.56487 .4648 .57073 .48236 .58147 .46672 .57564 .45042 Mtetra
.759 .62 .705 r
.57564 .45042 .58147 .46672 .59219 .45197 .5864 .43684 Mtetra
.76 .63 .716 r
.5864 .43684 .59219 .45197 .6029 .43813 .59715 .42408 Mtetra
.762 .641 .728 r
.59715 .42408 .6029 .43813 .61361 .42512 .6079 .41203 Mtetra
.765 .653 .739 r
.6079 .41203 .61361 .42512 .62432 .41278 .61865 .40055 Mtetra
.769 .666 .749 r
.61865 .40055 .62432 .41278 .63502 .40092 .62941 .38942 Mtetra
.775 .679 .757 r
.62941 .38942 .63502 .40092 .64572 .3893 .64016 .37844 Mtetra
.782 .691 .764 r
.64016 .37844 .64572 .3893 .65641 .37772 .6509 .3674 Mtetra
.791 .704 .768 r
.6509 .3674 .65641 .37772 .66709 .36603 .66162 .35618 Mtetra
.8 .715 .771 r
.66162 .35618 .66709 .36603 .67774 .35416 .67232 .34471 Mtetra
.808 .725 .774 r
.67232 .34471 .67774 .35416 .68837 .34214 .68301 .33304 Mtetra
.813 .734 .777 r
.68301 .33304 .68837 .34214 .69898 .33012 .69367 .32135 Mtetra
.814 .741 .783 r
.69367 .32135 .69898 .33012 .70959 .31834 .70434 .30987 Mtetra
.812 .748 .793 r
.70434 .30987 .70959 .31834 .72022 .30708 .71503 .29891 Mtetra
.805 .754 .805 r
.71503 .29891 .72022 .30708 .73089 .29657 .72575 .28868 Mtetra
.797 .76 .819 r
.72575 .28868 .73089 .29657 .74161 .28685 .73653 .27922 Mtetra
.794 .766 .828 r
.73653 .27922 .74161 .28685 .75237 .27755 .74733 .2701 Mtetra
.81 .776 .821 r
.74733 .2701 .75237 .27755 .76307 .26758 .75808 .2602 Mtetra
.697 .744 .888 r
.75808 .2602 .76307 .26758 .77416 .26239 .76923 .25532 Mtetra
.664 .741 .908 r
.76923 .25532 .77416 .26239 .7854 .25857 .7805 .25147 Mtetra
.7805 .25147 .7854 .25857 .79668 .25473 .79181 .24761 Mtetra
.79181 .24761 .79668 .25473 .80801 .25088 .80317 .24372 Mtetra
.80317 .24372 .80801 .25088 .81938 .24701 .81457 .23983 Mtetra
.81457 .23983 .81938 .24701 .8308 .24313 .82602 .23592 Mtetra
.82602 .23592 .8308 .24313 .84226 .23923 .83752 .23199 Mtetra
.22285 .434 .22912 .43984 .23837 .43668 .23212 .43082 Mtetra
.23212 .43082 .23837 .43668 .24765 .43351 .24142 .42762 Mtetra
.24142 .42762 .24765 .43351 .25697 .43033 .25075 .42442 Mtetra
.25075 .42442 .25697 .43033 .26632 .42713 .26012 .42121 Mtetra
.26012 .42121 .26632 .42713 .2757 .42393 .26952 .41798 Mtetra
.26952 .41798 .2757 .42393 .28511 .42071 .27896 .41474 Mtetra
.648 .737 .914 r
.27896 .41474 .28511 .42071 .29449 .41849 .2884 .41187 Mtetra
.274 .549 .925 r
.2884 .41187 .29449 .41849 .30358 .42113 .29749 .41446 Mtetra
.364 .595 .935 r
.29749 .41446 .30358 .42113 .31278 .42304 .30671 .41616 Mtetra
.349 .58 .929 r
.30671 .41616 .31278 .42304 .32202 .4253 .31598 .41814 Mtetra
.298 .543 .916 r
.31598 .41814 .32202 .4253 .33128 .42832 .32527 .42081 Mtetra
.249 .503 .9 r
.32527 .42081 .33128 .42832 .34057 .43208 .33458 .4242 Mtetra
.223 .475 .887 r
.33458 .4242 .34057 .43208 .34991 .43635 .34394 .4281 Mtetra
.223 .464 .878 r
.34394 .4281 .34991 .43635 .35932 .44086 .35337 .43223 Mtetra
.247 .466 .874 r
.35337 .43223 .35932 .44086 .36881 .44537 .36288 .43635 Mtetra
.282 .475 .871 r
.36288 .43635 .36881 .44537 .37839 .44972 .37248 .44027 Mtetra
.319 .485 .866 r
.37248 .44027 .37839 .44972 .38806 .45385 .38217 .44393 Mtetra
.351 .491 .859 r
.38217 .44393 .38806 .45385 .39782 .45782 .39195 .44736 Mtetra
.373 .491 .849 r
.39195 .44736 .39782 .45782 .40766 .46176 .40181 .45068 Mtetra
.384 .484 .838 r
.40181 .45068 .40766 .46176 .41758 .46587 .41174 .45407 Mtetra
.386 .47 .824 r
.41174 .45407 .41758 .46587 .42757 .47036 .42175 .45772 Mtetra
.38 .451 .809 r
.42175 .45772 .42757 .47036 .43763 .47542 .43183 .46184 Mtetra
.37 .429 .792 r
.43183 .46184 .43763 .47542 .44777 .48124 .44198 .46657 Mtetra
.359 .406 .775 r
.44198 .46657 .44777 .48124 .45799 .48788 .4522 .472 Mtetra
.352 .387 .757 r
.4522 .472 .45799 .48788 .46829 .49536 .46251 .47813 Mtetra
.354 .372 .741 r
.46251 .47813 .46829 .49536 .4787 .50356 .4729 .4848 Mtetra
.371 .368 .727 r
.4729 .4848 .4787 .50356 .48921 .51219 .4834 .49164 Mtetra
.411 .38 .714 r
.4834 .49164 .48921 .51219 .49984 .52063 .49402 .49779 Mtetra
.491 .417 .7 r
.49402 .49779 .49984 .52063 .5106 .52683 .50475 .5011 Mtetra
.6 .473 .679 r
.50475 .5011 .5106 .52683 .52148 .52348 .51559 .4977 Mtetra
.673 .52 .669 r
.51559 .4977 .52148 .52348 .53238 .51054 .52647 .48758 Mtetra
.712 .555 .674 r
.52647 .48758 .53238 .51054 .54324 .49532 .53734 .47458 Mtetra
.73 .576 .682 r
.53734 .47458 .54324 .49532 .55407 .47986 .54818 .46085 Mtetra
.739 .591 .691 r
.54818 .46085 .55407 .47986 .56487 .4648 .559 .44726 Mtetra
.745 .603 .7 r
.559 .44726 .56487 .4648 .57564 .45042 .5698 .43417 Mtetra
.748 .615 .711 r
.5698 .43417 .57564 .45042 .5864 .43684 .5806 .42175 Mtetra
.75 .626 .722 r
.5806 .42175 .5864 .43684 .59715 .42408 .59138 .41002 Mtetra
.752 .637 .733 r
.59138 .41002 .59715 .42408 .6079 .41203 .60218 .39888 Mtetra
.755 .649 .744 r
.60218 .39888 .6079 .41203 .61865 .40055 .61297 .38819 Mtetra
.759 .661 .753 r
.61297 .38819 .61865 .40055 .62941 .38942 .62377 .37774 Mtetra
.766 .673 .76 r
.62377 .37774 .62941 .38942 .64016 .37844 .63456 .36733 Mtetra
.774 .685 .766 r
.63456 .36733 .64016 .37844 .6509 .3674 .64535 .35679 Mtetra
.783 .697 .769 r
.64535 .35679 .6509 .3674 .66162 .35618 .65612 .34599 Mtetra
.791 .707 .771 r
.65612 .34599 .66162 .35618 .67232 .34471 .66687 .3349 Mtetra
.799 .717 .774 r
.66687 .3349 .67232 .34471 .68301 .33304 .6776 .32359 Mtetra
.804 .726 .778 r
.6776 .32359 .68301 .33304 .69367 .32135 .68832 .31223 Mtetra
.806 .733 .784 r
.68832 .31223 .69367 .32135 .70434 .30987 .69904 .30109 Mtetra
.804 .74 .793 r
.69904 .30109 .70434 .30987 .71503 .29891 .70978 .29045 Mtetra
.797 .746 .806 r
.70978 .29045 .71503 .29891 .72575 .28868 .72056 .28053 Mtetra
.79 .752 .819 r
.72056 .28053 .72575 .28868 .73653 .27922 .73139 .27131 Mtetra
.788 .759 .826 r
.73139 .27131 .73653 .27922 .74733 .2701 .74224 .26235 Mtetra
.807 .769 .818 r
.74224 .26235 .74733 .2701 .75808 .2602 .75303 .25246 Mtetra
.675 .726 .888 r
.75303 .25246 .75808 .2602 .76923 .25532 .76426 .2482 Mtetra
.664 .741 .908 r
.76426 .2482 .76923 .25532 .7805 .25147 .77556 .24432 Mtetra
.77556 .24432 .7805 .25147 .79181 .24761 .78691 .24043 Mtetra
.78691 .24043 .79181 .24761 .80317 .24372 .7983 .23652 Mtetra
.7983 .23652 .80317 .24372 .81457 .23983 .80973 .2326 Mtetra
.80973 .2326 .81457 .23983 .82602 .23592 .82121 .22866 Mtetra
.82121 .22866 .82602 .23592 .83752 .23199 .83274 .2247 Mtetra
.21653 .42812 .22285 .434 .23212 .43082 .22582 .42491 Mtetra
.22582 .42491 .23212 .43082 .24142 .42762 .23514 .4217 Mtetra
.23514 .4217 .24142 .42762 .25075 .42442 .2445 .41848 Mtetra
.2445 .41848 .25075 .42442 .26012 .42121 .25388 .41524 Mtetra
.25388 .41524 .26012 .42121 .26952 .41798 .2633 .41199 Mtetra
.2633 .41199 .26952 .41798 .27896 .41474 .27276 .40873 Mtetra
.27276 .40873 .27896 .41474 .2884 .41187 .28225 .40546 Mtetra
.314 .581 .937 r
.28225 .40546 .2884 .41187 .29749 .41446 .29139 .40751 Mtetra
.386 .598 .93 r
.29139 .40751 .29749 .41446 .30671 .41616 .30063 .40905 Mtetra
.38 .589 .926 r
.30063 .40905 .30671 .41616 .31598 .41814 .30992 .41074 Mtetra
.337 .557 .916 r
.30992 .41074 .31598 .41814 .32527 .42081 .31923 .41306 Mtetra
.294 .521 .903 r
.31923 .41306 .32527 .42081 .33458 .4242 .32857 .41606 Mtetra
.269 .495 .89 r
.32857 .41606 .33458 .4242 .34394 .4281 .33796 .41956 Mtetra
.269 .482 .881 r
.33796 .41956 .34394 .4281 .35337 .43223 .34741 .4233 Mtetra
.289 .482 .875 r
.34741 .4233 .35337 .43223 .36288 .43635 .35693 .42701 Mtetra
.321 .49 .87 r
.35693 .42701 .36288 .43635 .37248 .44027 .36655 .43052 Mtetra
.355 .498 .864 r
.36655 .43052 .37248 .44027 .38217 .44393 .37626 .43374 Mtetra
.385 .505 .856 r
.37626 .43374 .38217 .44393 .39195 .44736 .38605 .43669 Mtetra
.407 .506 .847 r
.38605 .43669 .39195 .44736 .40181 .45068 .39593 .43945 Mtetra
.419 .501 .836 r
.39593 .43945 .40181 .45068 .41174 .45407 .40589 .44218 Mtetra
.423 .49 .824 r
.40589 .44218 .41174 .45407 .42175 .45772 .41592 .44507 Mtetra
.419 .474 .811 r
.41592 .44507 .42175 .45772 .43183 .46184 .42601 .4483 Mtetra
.411 .455 .796 r
.42601 .4483 .43183 .46184 .44198 .46657 .43617 .45202 Mtetra
.403 .435 .78 r
.43617 .45202 .44198 .46657 .4522 .472 .4464 .45629 Mtetra
.398 .418 .764 r
.4464 .45629 .4522 .472 .46251 .47813 .45671 .46109 Mtetra
.402 .405 .748 r
.45671 .46109 .46251 .47813 .4729 .4848 .46711 .46625 Mtetra
.421 .402 .733 r
.46711 .46625 .4729 .4848 .4834 .49164 .4776 .47132 Mtetra
.461 .413 .718 r
.4776 .47132 .4834 .49164 .49402 .49779 .48821 .47541 Mtetra
.527 .442 .703 r
.48821 .47541 .49402 .49779 .50475 .5011 .49892 .47679 Mtetra
.603 .48 .686 r
.49892 .47679 .50475 .5011 .51559 .4977 .50973 .47335 Mtetra
.66 .517 .678 r
.50973 .47335 .51559 .4977 .52647 .48758 .52059 .46508 Mtetra
.696 .547 .681 r
.52059 .46508 .52647 .48758 .53734 .47458 .53145 .45407 Mtetra
.716 .569 .688 r
.53145 .45407 .53734 .47458 .54818 .46085 .5423 .44205 Mtetra
.727 .586 .697 r
.5423 .44205 .54818 .46085 .559 .44726 .55314 .42991 Mtetra
.734 .599 .706 r
.55314 .42991 .559 .44726 .5698 .43417 .56396 .41809 Mtetra
.738 .611 .717 r
.56396 .41809 .5698 .43417 .5806 .42175 .57478 .40679 Mtetra
.74 .623 .728 r
.57478 .40679 .5806 .42175 .59138 .41002 .58561 .39602 Mtetra
.743 .634 .739 r
.58561 .39602 .59138 .41002 .60218 .39888 .59643 .38571 Mtetra
.746 .645 .749 r
.59643 .38571 .60218 .39888 .61297 .38819 .60726 .37573 Mtetra
.751 .657 .757 r
.60726 .37573 .61297 .38819 .62377 .37774 .6181 .36589 Mtetra
.757 .668 .763 r
.6181 .36589 .62377 .37774 .63456 .36733 .62893 .356 Mtetra
.765 .679 .767 r
.62893 .356 .63456 .36733 .64535 .35679 .63976 .3459 Mtetra
.775 .69 .77 r
.63976 .3459 .64535 .35679 .65612 .34599 .65057 .33549 Mtetra
.783 .7 .772 r
.65057 .33549 .65612 .34599 .66687 .3349 .66137 .32477 Mtetra
.791 .709 .774 r
.66137 .32477 .66687 .3349 .6776 .32359 .67215 .31381 Mtetra
.796 .718 .778 r
.67215 .31381 .6776 .32359 .68832 .31223 .68292 .30281 Mtetra
.798 .726 .785 r
.68292 .30281 .68832 .31223 .69904 .30109 .6937 .29202 Mtetra
.795 .733 .794 r
.6937 .29202 .69904 .30109 .70978 .29045 .70449 .28173 Mtetra
.789 .739 .807 r
.70449 .28173 .70978 .29045 .72056 .28053 .71533 .27212 Mtetra
.782 .745 .819 r
.71533 .27212 .72056 .28053 .73139 .27131 .72621 .26314 Mtetra
.783 .752 .825 r
.72621 .26314 .73139 .27131 .74224 .26235 .7371 .25431 Mtetra
.795 .759 .821 r
.7371 .25431 .74224 .26235 .75303 .25246 .74797 .24492 Mtetra
.663 .729 .898 r
.74797 .24492 .75303 .25246 .76426 .2482 .75925 .24103 Mtetra
.664 .741 .908 r
.75925 .24103 .76426 .2482 .77556 .24432 .77059 .23712 Mtetra
.77059 .23712 .77556 .24432 .78691 .24043 .78196 .2332 Mtetra
.78196 .2332 .78691 .24043 .7983 .23652 .79339 .22926 Mtetra
.79339 .22926 .7983 .23652 .80973 .2326 .80486 .22531 Mtetra
.80486 .22531 .80973 .2326 .82121 .22866 .81637 .22134 Mtetra
.81637 .22134 .82121 .22866 .83274 .2247 .82793 .21736 Mtetra
.21018 .4222 .21653 .42812 .22582 .42491 .21948 .41897 Mtetra
.21948 .41897 .22582 .42491 .23514 .4217 .22882 .41574 Mtetra
.22882 .41574 .23514 .4217 .2445 .41848 .2382 .41249 Mtetra
.2382 .41249 .2445 .41848 .25388 .41524 .2476 .40924 Mtetra
.2476 .40924 .25388 .41524 .2633 .41199 .25705 .40597 Mtetra
.25705 .40597 .2633 .41199 .27276 .40873 .26652 .40268 Mtetra
.26652 .40268 .27276 .40873 .28225 .40546 .27603 .39939 Mtetra
.404 .641 .953 r
.27603 .39939 .28225 .40546 .29139 .40751 .28526 .4003 Mtetra
.402 .598 .925 r
.28526 .4003 .29139 .40751 .30063 .40905 .29452 .40172 Mtetra
.406 .596 .922 r
.29452 .40172 .30063 .40905 .30992 .41074 .30383 .40313 Mtetra
.372 .57 .915 r
.30383 .40313 .30992 .41074 .31923 .41306 .31318 .40509 Mtetra
.334 .538 .903 r
.31318 .40509 .31923 .41306 .32857 .41606 .32254 .40769 Mtetra
.311 .512 .891 r
.32254 .40769 .32857 .41606 .33796 .41956 .33195 .41077 Mtetra
.31 .499 .881 r
.33195 .41077 .33796 .41956 .34741 .4233 .34142 .41409 Mtetra
.327 .497 .874 r
.34142 .41409 .34741 .4233 .35693 .42701 .35097 .4174 Mtetra
.355 .502 .867 r
.35097 .4174 .35693 .42701 .36655 .43052 .36061 .42051 Mtetra
.386 .51 .861 r
.36061 .42051 .36655 .43052 .37626 .43374 .37033 .42332 Mtetra
.413 .515 .853 r
.37033 .42332 .37626 .43374 .38605 .43669 .38014 .42582 Mtetra
.434 .517 .844 r
.38014 .42582 .38605 .43669 .39593 .43945 .39004 .42808 Mtetra
.447 .514 .835 r
.39004 .42808 .39593 .43945 .40589 .44218 .40001 .43023 Mtetra
.452 .506 .824 r
.40001 .43023 .40589 .44218 .41592 .44507 .41006 .43244 Mtetra
.451 .494 .812 r
.41006 .43244 .41592 .44507 .42601 .4483 .42017 .43487 Mtetra
.446 .478 .799 r
.42017 .43487 .42601 .4483 .43617 .45202 .43035 .43766 Mtetra
.44 .461 .785 r
.43035 .43766 .43617 .45202 .4464 .45629 .44059 .44085 Mtetra
.438 .446 .77 r
.44059 .44085 .4464 .45629 .45671 .46109 .45091 .44442 Mtetra
.444 .435 .755 r
.45091 .44442 .45671 .46109 .46711 .46625 .46131 .44815 Mtetra
.462 .432 .739 r
.46131 .44815 .46711 .46625 .4776 .47132 .4718 .45162 Mtetra
.498 .441 .724 r
.4718 .45162 .4776 .47132 .48821 .47541 .48239 .45402 Mtetra
.549 .462 .709 r
.48239 .45402 .48821 .47541 .49892 .47679 .49309 .45409 Mtetra
.606 .49 .695 r
.49309 .45409 .49892 .47679 .50973 .47335 .50387 .45061 Mtetra
.652 .519 .688 r
.50387 .45061 .50973 .47335 .52059 .46508 .51471 .44358 Mtetra
.684 .545 .69 r
.51471 .44358 .52059 .46508 .53145 .45407 .52557 .43419 Mtetra
.704 .566 .696 r
.52557 .43419 .53145 .45407 .5423 .44205 .53642 .4237 Mtetra
.716 .583 .704 r
.53642 .4237 .5423 .44205 .55314 .42991 .54727 .41292 Mtetra
.724 .597 .714 r
.54727 .41292 .55314 .42991 .56396 .41809 .55812 .40229 Mtetra
.728 .609 .724 r
.55812 .40229 .56396 .41809 .57478 .40679 .56896 .39201 Mtetra
.731 .62 .735 r
.56896 .39201 .57478 .40679 .58561 .39602 .57981 .38212 Mtetra
.734 .631 .745 r
.57981 .38212 .58561 .39602 .59643 .38571 .59067 .37256 Mtetra
.738 .642 .753 r
.59067 .37256 .59643 .38571 .60726 .37573 .60154 .36321 Mtetra
.743 .653 .76 r
.60154 .36321 .60726 .37573 .6181 .36589 .61241 .3539 Mtetra
.75 .664 .766 r
.61241 .3539 .6181 .36589 .62893 .356 .62328 .34446 Mtetra
.758 .674 .769 r
.62328 .34446 .62893 .356 .63976 .3459 .63414 .33476 Mtetra
.767 .684 .771 r
.63414 .33476 .63976 .3459 .65057 .33549 .645 .32472 Mtetra
.776 .694 .773 r
.645 .32472 .65057 .33549 .66137 .32477 .65584 .31435 Mtetra
.783 .703 .775 r
.65584 .31435 .66137 .32477 .67215 .31381 .66666 .30375 Mtetra
.788 .711 .779 r
.66666 .30375 .67215 .31381 .68292 .30281 .67748 .29312 Mtetra
.79 .719 .786 r
.67748 .29312 .68292 .30281 .6937 .29202 .68831 .28271 Mtetra
.787 .726 .796 r
.68831 .28271 .6937 .29202 .70449 .28173 .69916 .27278 Mtetra
.781 .733 .808 r
.69916 .27278 .70449 .28173 .71533 .27212 .71005 .26349 Mtetra
.776 .739 .82 r
.71005 .26349 .71533 .27212 .72621 .26314 .72098 .25475 Mtetra
.779 .747 .824 r
.72098 .25475 .72621 .26314 .7371 .25431 .73191 .24598 Mtetra
.77 .747 .831 r
.73191 .24598 .7371 .25431 .74797 .24492 .74289 .23772 Mtetra
.664 .741 .908 r
.74289 .23772 .74797 .24492 .75925 .24103 .75421 .2338 Mtetra
.75421 .2338 .75925 .24103 .77059 .23712 .76558 .22987 Mtetra
.76558 .22987 .77059 .23712 .78196 .2332 .77699 .22592 Mtetra
.77699 .22592 .78196 .2332 .79339 .22926 .78844 .22195 Mtetra
.78844 .22195 .79339 .22926 .80486 .22531 .79994 .21797 Mtetra
.79994 .21797 .80486 .22531 .81637 .22134 .81149 .21397 Mtetra
.81149 .21397 .81637 .22134 .82793 .21736 .82308 .20996 Mtetra
.20378 .41624 .21018 .4222 .21948 .41897 .2131 .41299 Mtetra
.2131 .41299 .21948 .41897 .22882 .41574 .22246 .40974 Mtetra
.22246 .40974 .22882 .41574 .2382 .41249 .23186 .40647 Mtetra
.23186 .40647 .2382 .41249 .2476 .40924 .24128 .40319 Mtetra
.24128 .40319 .2476 .40924 .25705 .40597 .25075 .3999 Mtetra
.25075 .3999 .25705 .40597 .26652 .40268 .26024 .3966 Mtetra
.26024 .3966 .26652 .40268 .27603 .39939 .26977 .39328 Mtetra
.51 .689 .948 r
.26977 .39328 .27603 .39939 .28526 .4003 .27912 .39284 Mtetra
.413 .596 .92 r
.27912 .39284 .28526 .4003 .29452 .40172 .28838 .39418 Mtetra
.428 .602 .918 r
.28838 .39418 .29452 .40172 .30383 .40313 .29772 .39534 Mtetra
.403 .581 .912 r
.29772 .39534 .30383 .40313 .31318 .40509 .30709 .39694 Mtetra
.371 .553 .903 r
.30709 .39694 .31318 .40509 .32254 .40769 .31649 .39912 Mtetra
.349 .529 .891 r
.31649 .39912 .32254 .40769 .33195 .41077 .32593 .40177 Mtetra
.346 .515 .881 r
.32593 .40177 .33195 .41077 .34142 .41409 .33542 .40466 Mtetra
.36 .51 .872 r
.33542 .40466 .34142 .41409 .35097 .4174 .34499 .40756 Mtetra
.384 .513 .865 r
.34499 .40756 .35097 .4174 .36061 .42051 .35464 .41028 Mtetra
.411 .519 .857 r
.35464 .41028 .36061 .42051 .37033 .42332 .36438 .4127 Mtetra
.436 .524 .85 r
.36438 .4127 .37033 .42332 .38014 .42582 .37421 .41479 Mtetra
.456 .527 .841 r
.37421 .41479 .38014 .42582 .39004 .42808 .38413 .4166 Mtetra
.47 .525 .833 r
.38413 .4166 .39004 .42808 .40001 .43023 .39412 .41824 Mtetra
.476 .52 .823 r
.39412 .41824 .40001 .43023 .41006 .43244 .40418 .41986 Mtetra
.477 .51 .813 r
.40418 .41986 .41006 .43244 .42017 .43487 .41431 .42159 Mtetra
.475 .498 .802 r
.41431 .42159 .42017 .43487 .43035 .43766 .4245 .42354 Mtetra
.472 .484 .789 r
.4245 .42354 .43035 .43766 .44059 .44085 .43476 .42576 Mtetra
.471 .471 .775 r
.43476 .42576 .44059 .44085 .45091 .44442 .44509 .42821 Mtetra
.478 .461 .761 r
.44509 .42821 .45091 .44442 .46131 .44815 .4555 .43068 Mtetra
.495 .459 .746 r
.4555 .43068 .46131 .44815 .4718 .45162 .46599 .43278 Mtetra
.525 .465 .732 r
.46599 .43278 .4718 .45162 .48239 .45402 .47658 .43385 Mtetra
.566 .48 .717 r
.47658 .43385 .48239 .45402 .49309 .45409 .48726 .43299 Mtetra
.61 .501 .706 r
.48726 .43299 .49309 .45409 .50387 .45061 .49802 .42947 Mtetra
.647 .524 .7 r
.49802 .42947 .50387 .45061 .51471 .44358 .50884 .42329 Mtetra
.675 .546 .7 r
.50884 .42329 .51471 .44358 .52557 .43419 .51969 .41517 Mtetra
.694 .566 .705 r
.51969 .41517 .52557 .43419 .53642 .4237 .53054 .40599 Mtetra
.707 .582 .713 r
.53054 .40599 .53642 .4237 .54727 .41292 .5414 .39641 Mtetra
.715 .596 .722 r
.5414 .39641 .54727 .41292 .55812 .40229 .55226 .38684 Mtetra
.72 .608 .732 r
.55226 .38684 .55812 .40229 .56896 .39201 .56313 .37747 Mtetra
.723 .619 .741 r
.56313 .37747 .56896 .39201 .57981 .38212 .57401 .36836 Mtetra
.726 .63 .75 r
.57401 .36836 .57981 .38212 .59067 .37256 .58489 .35946 Mtetra
.731 .64 .758 r
.58489 .35946 .59067 .37256 .60154 .36321 .59579 .35065 Mtetra
.736 .65 .764 r
.59579 .35065 .60154 .36321 .61241 .3539 .60669 .3418 Mtetra
.743 .66 .768 r
.60669 .3418 .61241 .3539 .62328 .34446 .61759 .33275 Mtetra
.751 .669 .771 r
.61759 .33275 .62328 .34446 .63414 .33476 .62849 .32341 Mtetra
.76 .679 .772 r
.62849 .32341 .63414 .33476 .645 .32472 .63938 .31371 Mtetra
.769 .688 .774 r
.63938 .31371 .645 .32472 .65584 .31435 .65026 .30369 Mtetra
.776 .697 .776 r
.65026 .30369 .65584 .31435 .66666 .30375 .66114 .29346 Mtetra
.78 .705 .781 r
.66114 .29346 .66666 .30375 .67748 .29312 .672 .28321 Mtetra
.781 .713 .788 r
.672 .28321 .67748 .29312 .68831 .28271 .68288 .2732 Mtetra
.779 .721 .798 r
.68288 .2732 .68831 .28271 .69916 .27278 .69379 .26365 Mtetra
.774 .728 .81 r
.69379 .26365 .69916 .27278 .71005 .26349 .70473 .25467 Mtetra
.77 .734 .82 r
.70473 .25467 .71005 .26349 .72098 .25475 .7157 .24613 Mtetra
.776 .742 .822 r
.7157 .24613 .72098 .25475 .73191 .24598 .72667 .23739 Mtetra
.739 .731 .844 r
.72667 .23739 .73191 .24598 .74289 .23772 .73778 .23048 Mtetra
.664 .741 .908 r
.73778 .23048 .74289 .23772 .75421 .2338 .74913 .22653 Mtetra
.74913 .22653 .75421 .2338 .76558 .22987 .76053 .22256 Mtetra
.76053 .22256 .76558 .22987 .77699 .22592 .77197 .21858 Mtetra
.77197 .21858 .77699 .22592 .78844 .22195 .78346 .21459 Mtetra
.78346 .21459 .78844 .22195 .79994 .21797 .79499 .21058 Mtetra
.79499 .21058 .79994 .21797 .81149 .21397 .80657 .20655 Mtetra
.80657 .20655 .81149 .21397 .82308 .20996 .8182 .2025 Mtetra
.19733 .41024 .20378 .41624 .2131 .41299 .20668 .40697 Mtetra
.20668 .40697 .2131 .41299 .22246 .40974 .21606 .4037 Mtetra
.21606 .4037 .22246 .40974 .23186 .40647 .22547 .40041 Mtetra
.22547 .40041 .23186 .40647 .24128 .40319 .23492 .3971 Mtetra
.23492 .3971 .24128 .40319 .25075 .3999 .2444 .39379 Mtetra
.2444 .39379 .25075 .3999 .26024 .3966 .25392 .39047 Mtetra
.25392 .39047 .26024 .3966 .26977 .39328 .26347 .38713 Mtetra
.604 .723 .929 r
.26347 .38713 .26977 .39328 .27912 .39284 .27295 .38511 Mtetra
.418 .591 .914 r
.27295 .38511 .27912 .39284 .28838 .39418 .28222 .38645 Mtetra
.446 .605 .914 r
.28222 .38645 .28838 .39418 .29772 .39534 .29158 .3874 Mtetra
.43 .591 .91 r
.29158 .3874 .29772 .39534 .30709 .39694 .30098 .38865 Mtetra
.403 .567 .901 r
.30098 .38865 .30709 .39694 .31649 .39912 .31041 .39041 Mtetra
.384 .544 .891 r
.31041 .39041 .31649 .39912 .32593 .40177 .31988 .39261 Mtetra
.379 .529 .88 r
.31988 .39261 .32593 .40177 .33542 .40466 .3294 .39506 Mtetra
.389 .523 .871 r
.3294 .39506 .33542 .40466 .34499 .40756 .33899 .39754 Mtetra
.409 .524 .863 r
.33899 .39754 .34499 .40756 .35464 .41028 .34866 .39987 Mtetra
.433 .528 .855 r
.34866 .39987 .35464 .41028 .36438 .4127 .35842 .40191 Mtetra
.455 .532 .847 r
.35842 .40191 .36438 .4127 .37421 .41479 .36826 .40362 Mtetra
.474 .535 .839 r
.36826 .40362 .37421 .41479 .38413 .4166 .37819 .40504 Mtetra
.488 .535 .831 r
.37819 .40504 .38413 .4166 .39412 .41824 .3882 .40624 Mtetra
.496 .531 .823 r
.3882 .40624 .39412 .41824 .40418 .41986 .39828 .40735 Mtetra
.499 .524 .814 r
.39828 .40735 .40418 .41986 .41431 .42159 .40842 .40847 Mtetra
.498 .514 .804 r
.40842 .40847 .41431 .42159 .4245 .42354 .41863 .4097 Mtetra
.498 .503 .793 r
.41863 .4097 .4245 .42354 .43476 .42576 .4289 .41108 Mtetra
.499 .493 .781 r
.4289 .41108 .43476 .42576 .44509 .42821 .43925 .41255 Mtetra
.506 .485 .768 r
.43925 .41255 .44509 .42821 .4555 .43068 .44966 .41394 Mtetra
.521 .482 .754 r
.44966 .41394 .4555 .43068 .46599 .43278 .46016 .41491 Mtetra
.546 .487 .74 r
.46016 .41491 .46599 .43278 .47658 .43385 .47075 .41493 Mtetra
.579 .498 .727 r
.47075 .41493 .47658 .43385 .48726 .43299 .48142 .4134 Mtetra
.613 .514 .717 r
.48142 .4134 .48726 .43299 .49802 .42947 .49216 .40984 Mtetra
.644 .532 .712 r
.49216 .40984 .49802 .42947 .50884 .42329 .50297 .40426 Mtetra
.669 .551 .712 r
.50297 .40426 .50884 .42329 .51969 .41517 .5138 .39711 Mtetra
.687 .568 .716 r
.5138 .39711 .51969 .41517 .53054 .40599 .52466 .389 Mtetra
.699 .583 .723 r
.52466 .389 .53054 .40599 .5414 .39641 .53553 .38045 Mtetra
.707 .597 .731 r
.53553 .38045 .5414 .39641 .55226 .38684 .5464 .37179 Mtetra
.712 .609 .74 r
.5464 .37179 .55226 .38684 .56313 .37747 .55729 .36322 Mtetra
.716 .619 .748 r
.55729 .36322 .56313 .37747 .57401 .36836 .56819 .35477 Mtetra
.72 .629 .756 r
.56819 .35477 .57401 .36836 .58489 .35946 .5791 .34642 Mtetra
.724 .639 .762 r
.5791 .34642 .58489 .35946 .59579 .35065 .59002 .33808 Mtetra
.73 .648 .767 r
.59002 .33808 .59579 .35065 .60669 .3418 .60095 .32961 Mtetra
.737 .657 .77 r
.60095 .32961 .60669 .3418 .61759 .33275 .61188 .32091 Mtetra
.745 .666 .772 r
.61188 .32091 .61759 .33275 .62849 .32341 .62281 .31189 Mtetra
.754 .674 .774 r
.62281 .31189 .62849 .32341 .63938 .31371 .63374 .30252 Mtetra
.762 .683 .775 r
.63374 .30252 .63938 .31371 .65026 .30369 .64466 .29284 Mtetra
.768 .692 .778 r
.64466 .29284 .65026 .30369 .66114 .29346 .65558 .28298 Mtetra
.772 .7 .783 r
.65558 .28298 .66114 .29346 .672 .28321 .66649 .27314 Mtetra
.773 .708 .791 r
.66649 .27314 .672 .28321 .68288 .2732 .67742 .26353 Mtetra
.771 .716 .801 r
.67742 .26353 .68288 .2732 .69379 .26365 .68838 .25435 Mtetra
.767 .723 .812 r
.68838 .25435 .69379 .26365 .70473 .25467 .69937 .24568 Mtetra
.765 .73 .82 r
.69937 .24568 .70473 .25467 .7157 .24613 .71038 .2373 Mtetra
.775 .738 .819 r
.71038 .2373 .7157 .24613 .72667 .23739 .72139 .22851 Mtetra
.698 .709 .857 r
.72139 .22851 .72667 .23739 .73778 .23048 .73264 .22317 Mtetra
.664 .741 .908 r
.73264 .22317 .73778 .23048 .74913 .22653 .74402 .2192 Mtetra
.74402 .2192 .74913 .22653 .76053 .22256 .75545 .2152 Mtetra
.75545 .2152 .76053 .22256 .77197 .21858 .76692 .21119 Mtetra
.76692 .21119 .77197 .21858 .78346 .21459 .77844 .20717 Mtetra
.77844 .20717 .78346 .21459 .79499 .21058 .79001 .20313 Mtetra
.79001 .20313 .79499 .21058 .80657 .20655 .80162 .19907 Mtetra
.80162 .19907 .80657 .20655 .8182 .2025 .81328 .19499 Mtetra
.19085 .4042 .19733 .41024 .20668 .40697 .20021 .40091 Mtetra
.20021 .40091 .20668 .40697 .21606 .4037 .20961 .39761 Mtetra
.20961 .39761 .21606 .4037 .22547 .40041 .21905 .3943 Mtetra
.21905 .3943 .22547 .40041 .23492 .3971 .22851 .39098 Mtetra
.22851 .39098 .23492 .3971 .2444 .39379 .23802 .38764 Mtetra
.23802 .38764 .2444 .39379 .25392 .39047 .24755 .38429 Mtetra
.24755 .38429 .25392 .39047 .26347 .38713 .25713 .38093 Mtetra
.25713 .38093 .26347 .38713 .27295 .38511 .26673 .37756 Mtetra
.438 .608 .92 r
.26673 .37756 .27295 .38511 .28222 .38645 .27604 .37852 Mtetra
.458 .606 .91 r
.27604 .37852 .28222 .38645 .29158 .3874 .28541 .37932 Mtetra
.452 .599 .907 r
.28541 .37932 .29158 .3874 .30098 .38865 .29484 .38025 Mtetra
.432 .58 .9 r
.29484 .38025 .30098 .38865 .31041 .39041 .3043 .3816 Mtetra
.415 .559 .89 r
.3043 .3816 .31041 .39041 .31988 .39261 .3138 .38334 Mtetra
.409 .544 .88 r
.3138 .38334 .31988 .39261 .3294 .39506 .32335 .38534 Mtetra
.416 .536 .87 r
.32335 .38534 .3294 .39506 .33899 .39754 .33296 .3874 Mtetra
.431 .534 .861 r
.33296 .3874 .33899 .39754 .34866 .39987 .34266 .38932 Mtetra
.451 .536 .852 r
.34266 .38932 .34866 .39987 .35842 .40191 .35243 .391 Mtetra
.472 .539 .845 r
.35243 .391 .35842 .40191 .36826 .40362 .36229 .39237 Mtetra
.489 .542 .837 r
.36229 .39237 .36826 .40362 .37819 .40504 .37224 .39344 Mtetra
.502 .542 .83 r
.37224 .39344 .37819 .40504 .3882 .40624 .38226 .39426 Mtetra
.511 .54 .823 r
.38226 .39426 .3882 .40624 .39828 .40735 .39235 .39493 Mtetra
.516 .536 .815 r
.39235 .39493 .39828 .40735 .40842 .40847 .40251 .39553 Mtetra
.518 .529 .806 r
.40251 .39553 .40842 .40847 .41863 .4097 .41273 .39615 Mtetra
.519 .52 .797 r
.41273 .39615 .41863 .4097 .4289 .41108 .42302 .39682 Mtetra
.522 .512 .786 r
.42302 .39682 .4289 .41108 .43925 .41255 .43338 .39747 Mtetra
.529 .506 .774 r
.43338 .39747 .43925 .41255 .44966 .41394 .44381 .39796 Mtetra
.543 .503 .762 r
.44381 .39796 .44966 .41394 .46016 .41491 .45431 .39801 Mtetra
.563 .506 .75 r
.45431 .39801 .46016 .41491 .47075 .41493 .4649 .39724 Mtetra
.59 .515 .738 r
.4649 .39724 .47075 .41493 .48142 .4134 .47556 .3952 Mtetra
.617 .527 .729 r
.47556 .3952 .48142 .4134 .49216 .40984 .4863 .39161 Mtetra
.643 .542 .725 r
.4863 .39161 .49216 .40984 .50297 .40426 .49709 .38646 Mtetra
.664 .558 .724 r
.49709 .38646 .50297 .40426 .5138 .39711 .50792 .38005 Mtetra
.68 .573 .727 r
.50792 .38005 .5138 .39711 .52466 .389 .51877 .37279 Mtetra
.692 .587 .733 r
.51877 .37279 .52466 .389 .53553 .38045 .52965 .36507 Mtetra
.7 .599 .74 r
.52965 .36507 .53553 .38045 .5464 .37179 .54053 .35718 Mtetra
.706 .61 .748 r
.54053 .35718 .5464 .37179 .55729 .36322 .55144 .34926 Mtetra
.71 .62 .755 r
.55144 .34926 .55729 .36322 .56819 .35477 .56235 .34137 Mtetra
.714 .63 .761 r
.56235 .34137 .56819 .35477 .5791 .34642 .57328 .33348 Mtetra
.719 .638 .767 r
.57328 .33348 .5791 .34642 .59002 .33808 .58423 .32551 Mtetra
.725 .646 .77 r
.58423 .32551 .59002 .33808 .60095 .32961 .59518 .31738 Mtetra
.732 .655 .773 r
.59518 .31738 .60095 .32961 .61188 .32091 .60614 .30897 Mtetra
.74 .663 .774 r
.60614 .30897 .61188 .32091 .62281 .31189 .61711 .30025 Mtetra
.748 .671 .775 r
.61711 .30025 .62281 .31189 .63374 .30252 .62807 .29119 Mtetra
.756 .679 .777 r
.62807 .29119 .63374 .30252 .64466 .29284 .63903 .28186 Mtetra
.761 .688 .781 r
.63903 .28186 .64466 .29284 .65558 .28298 .64998 .27238 Mtetra
.765 .696 .786 r
.64998 .27238 .65558 .28298 .66649 .27314 .66095 .26294 Mtetra
.766 .704 .794 r
.66095 .26294 .66649 .27314 .67742 .26353 .67193 .25374 Mtetra
.764 .712 .804 r
.67193 .25374 .67742 .26353 .68838 .25435 .68293 .24493 Mtetra
.761 .72 .814 r
.68293 .24493 .68838 .25435 .69937 .24568 .69397 .23654 Mtetra
.761 .727 .82 r
.69397 .23654 .69937 .24568 .71038 .2373 .70503 .22827 Mtetra
.766 .731 .821 r
.70503 .22827 .71038 .2373 .72139 .22851 .71608 .21981 Mtetra
.66 .699 .875 r
.71608 .21981 .72139 .22851 .73264 .22317 .72745 .21582 Mtetra
.664 .741 .908 r
.72745 .21582 .73264 .22317 .74402 .2192 .73887 .21181 Mtetra
.73887 .21181 .74402 .2192 .75545 .2152 .75033 .20779 Mtetra
.75033 .20779 .75545 .2152 .76692 .21119 .76183 .20375 Mtetra
.76183 .20375 .76692 .21119 .77844 .20717 .77338 .19969 Mtetra
.77338 .19969 .77844 .20717 .79001 .20313 .78498 .19562 Mtetra
.78498 .19562 .79001 .20313 .80162 .19907 .79663 .19153 Mtetra
.79663 .19153 .80162 .19907 .81328 .19499 .80832 .18743 Mtetra
.18432 .39812 .19085 .4042 .20021 .40091 .1937 .39481 Mtetra
.1937 .39481 .20021 .40091 .20961 .39761 .20312 .39149 Mtetra
.20312 .39149 .20961 .39761 .21905 .3943 .21258 .38816 Mtetra
.21258 .38816 .21905 .3943 .22851 .39098 .22206 .38481 Mtetra
.22206 .38481 .22851 .39098 .23802 .38764 .23159 .38145 Mtetra
.23159 .38145 .23802 .38764 .24755 .38429 .24114 .37808 Mtetra
.24114 .37808 .24755 .38429 .25713 .38093 .25074 .3747 Mtetra
.25074 .3747 .25713 .38093 .26673 .37756 .26037 .3713 Mtetra
.537 .699 .944 r
.26037 .3713 .26673 .37756 .27604 .37852 .26983 .3704 Mtetra
.466 .605 .905 r
.26983 .3704 .27604 .37852 .28541 .37932 .27922 .37111 Mtetra
.47 .605 .903 r
.27922 .37111 .28541 .37932 .29484 .38025 .28867 .37176 Mtetra
.457 .591 .898 r
.28867 .37176 .29484 .38025 .3043 .3816 .29816 .37271 Mtetra
.442 .572 .889 r
.29816 .37271 .3043 .3816 .3138 .38334 .30769 .37402 Mtetra
.436 .557 .879 r
.30769 .37402 .3138 .38334 .32335 .38534 .31727 .37556 Mtetra
.44 .548 .869 r
.31727 .37556 .32335 .38534 .33296 .3874 .32691 .37718 Mtetra
.452 .544 .86 r
.32691 .37718 .33296 .3874 .34266 .38932 .33663 .37871 Mtetra
.468 .544 .851 r
.33663 .37871 .34266 .38932 .35243 .391 .34642 .38003 Mtetra
.486 .546 .843 r
.34642 .38003 .35243 .391 .36229 .39237 .3563 .38107 Mtetra
.501 .548 .836 r
.3563 .38107 .36229 .39237 .37224 .39344 .36625 .38182 Mtetra
.514 .549 .83 r
.36625 .38182 .37224 .39344 .38226 .39426 .37629 .38231 Mtetra
.523 .548 .823 r
.37629 .38231 .38226 .39426 .39235 .39493 .38639 .38261 Mtetra
.529 .546 .816 r
.38639 .38261 .39235 .39493 .40251 .39553 .39657 .38279 Mtetra
.533 .541 .809 r
.39657 .38279 .40251 .39553 .41273 .39615 .40681 .38291 Mtetra
.536 .535 .801 r
.40681 .38291 .41273 .39615 .42302 .39682 .41711 .38298 Mtetra
.54 .529 .792 r
.41711 .38298 .42302 .39682 .43338 .39747 .42748 .38296 Mtetra
.547 .524 .781 r
.42748 .38296 .43338 .39747 .44381 .39796 .43792 .38273 Mtetra
.56 .522 .77 r
.43792 .38273 .44381 .39796 .45431 .39801 .44843 .38206 Mtetra
.577 .524 .759 r
.44843 .38206 .45431 .39801 .4649 .39724 .45902 .38067 Mtetra
.599 .531 .749 r
.45902 .38067 .4649 .39724 .47556 .3952 .46968 .37826 Mtetra
.622 .54 .742 r
.46968 .37826 .47556 .3952 .4863 .39161 .48041 .37463 Mtetra
.643 .553 .737 r
.48041 .37463 .4863 .39161 .49709 .38646 .49119 .36979 Mtetra
.661 .566 .737 r
.49119 .36979 .49709 .38646 .50792 .38005 .50202 .36392 Mtetra
.676 .579 .739 r
.50202 .36392 .50792 .38005 .51877 .37279 .51287 .35732 Mtetra
.687 .592 .744 r
.51287 .35732 .51877 .37279 .52965 .36507 .52375 .35027 Mtetra
.695 .603 .75 r
.52375 .35027 .52965 .36507 .54053 .35718 .53465 .34299 Mtetra
.7 .613 .756 r
.53465 .34299 .54053 .35718 .55144 .34926 .54557 .3356 Mtetra
.705 .622 .762 r
.54557 .3356 .55144 .34926 .56235 .34137 .5565 .32816 Mtetra
.71 .631 .767 r
.5565 .32816 .56235 .34137 .57328 .33348 .56745 .32064 Mtetra
.715 .638 .771 r
.56745 .32064 .57328 .33348 .58423 .32551 .57842 .31299 Mtetra
.721 .646 .773 r
.57842 .31299 .58423 .32551 .59518 .31738 .5894 .30512 Mtetra
.728 .653 .775 r
.5894 .30512 .59518 .31738 .60614 .30897 .60038 .29699 Mtetra
.735 .661 .776 r
.60038 .29699 .60614 .30897 .61711 .30025 .61137 .28853 Mtetra
.743 .668 .778 r
.61137 .28853 .61711 .30025 .62807 .29119 .62237 .27978 Mtetra
.75 .676 .78 r
.62237 .27978 .62807 .29119 .63903 .28186 .63336 .27079 Mtetra
.755 .685 .784 r
.63336 .27079 .63903 .28186 .64998 .27238 .64436 .2617 Mtetra
.758 .693 .79 r
.64436 .2617 .64998 .27238 .66095 .26294 .65537 .25267 Mtetra
.758 .702 .798 r
.65537 .25267 .66095 .26294 .67193 .25374 .6664 .24387 Mtetra
.757 .709 .807 r
.6664 .24387 .67193 .25374 .68293 .24493 .67745 .23542 Mtetra
.755 .717 .816 r
.67745 .23542 .68293 .24493 .69397 .23654 .68853 .22725 Mtetra
.759 .724 .82 r
.68853 .22725 .69397 .23654 .70503 .22827 .69962 .21902 Mtetra
.725 .713 .839 r
.69962 .21902 .70503 .22827 .71608 .21981 .71083 .21243 Mtetra
.664 .741 .908 r
.71083 .21243 .71608 .21981 .72745 .21582 .72223 .20841 Mtetra
.72223 .20841 .72745 .21582 .73887 .21181 .73367 .20437 Mtetra
.73367 .20437 .73887 .21181 .75033 .20779 .74517 .20032 Mtetra
.74517 .20032 .75033 .20779 .76183 .20375 .7567 .19625 Mtetra
.7567 .19625 .76183 .20375 .77338 .19969 .76829 .19216 Mtetra
.76829 .19216 .77338 .19969 .78498 .19562 .77992 .18806 Mtetra
.77992 .18806 .78498 .19562 .79663 .19153 .7916 .18394 Mtetra
.7916 .18394 .79663 .19153 .80832 .18743 .80333 .17981 Mtetra
.17775 .392 .18432 .39812 .1937 .39481 .18715 .38867 Mtetra
.18715 .38867 .1937 .39481 .20312 .39149 .19659 .38532 Mtetra
.19659 .38532 .20312 .39149 .21258 .38816 .20606 .38197 Mtetra
.20606 .38197 .21258 .38816 .22206 .38481 .21557 .3786 Mtetra
.21557 .3786 .22206 .38481 .23159 .38145 .22511 .37522 Mtetra
.22511 .37522 .23159 .38145 .24114 .37808 .23469 .37182 Mtetra
.23469 .37182 .24114 .37808 .25074 .3747 .24431 .36842 Mtetra
.24431 .36842 .25074 .3747 .26037 .3713 .25396 .365 Mtetra
.643 .736 .916 r
.25396 .365 .26037 .3713 .26983 .3704 .2636 .36206 Mtetra
.468 .6 .901 r
.2636 .36206 .26983 .3704 .27922 .37111 .27299 .36276 Mtetra
.484 .609 .9 r
.27299 .36276 .27922 .37111 .28867 .37176 .28247 .3632 Mtetra
.477 .6 .896 r
.28247 .3632 .28867 .37176 .29816 .37271 .29199 .3638 Mtetra
.466 .585 .889 r
.29199 .3638 .29816 .37271 .30769 .37402 .30155 .36467 Mtetra
.46 .571 .879 r
.30155 .36467 .30769 .37402 .31727 .37556 .31116 .36576 Mtetra
.462 .56 .869 r
.31116 .36576 .31727 .37556 .32691 .37718 .32083 .36695 Mtetra
.471 .555 .86 r
.32083 .36695 .32691 .37718 .33663 .37871 .33057 .36808 Mtetra
.483 .553 .851 r
.33057 .36808 .33663 .37871 .34642 .38003 .34038 .36905 Mtetra
.498 .553 .843 r
.34038 .36905 .34642 .38003 .3563 .38107 .35028 .36978 Mtetra
.512 .555 .836 r
.35028 .36978 .3563 .38107 .36625 .38182 .36025 .37023 Mtetra
.524 .556 .83 r
.36025 .37023 .36625 .38182 .37629 .38231 .37029 .37043 Mtetra
.533 .556 .824 r
.37029 .37043 .37629 .38231 .38639 .38261 .38041 .37042 Mtetra
.54 .554 .818 r
.38041 .37042 .38639 .38261 .39657 .38279 .3906 .37025 Mtetra
.545 .551 .812 r
.3906 .37025 .39657 .38279 .40681 .38291 .40085 .36996 Mtetra
.549 .547 .805 r
.40085 .36996 .40681 .38291 .41711 .38298 .41117 .36955 Mtetra
.554 .543 .797 r
.41117 .36955 .41711 .38298 .42748 .38296 .42155 .369 Mtetra
.562 .54 .788 r
.42155 .369 .42748 .38296 .43792 .38273 .432 .36819 Mtetra
.573 .539 .779 r
.432 .36819 .43792 .38273 .44843 .38206 .44252 .36696 Mtetra
.589 .541 .769 r
.44252 .36696 .44843 .38206 .45902 .38067 .45311 .3651 Mtetra
.606 .546 .761 r
.45311 .3651 .45902 .38067 .46968 .37826 .46378 .36241 Mtetra
.625 .554 .754 r
.46378 .36241 .46968 .37826 .48041 .37463 .4745 .35875 Mtetra
.644 .564 .75 r
.4745 .35875 .48041 .37463 .49119 .36979 .48528 .35412 Mtetra
.66 .575 .749 r
.48528 .35412 .49119 .36979 .50202 .36392 .4961 .34865 Mtetra
.673 .586 .751 r
.4961 .34865 .50202 .36392 .51287 .35732 .50696 .34255 Mtetra
.683 .597 .754 r
.50696 .34255 .51287 .35732 .52375 .35027 .51784 .33601 Mtetra
.69 .608 .759 r
.51784 .33601 .52375 .35027 .53465 .34299 .52875 .32921 Mtetra
.696 .617 .763 r
.52875 .32921 .53465 .34299 .54557 .3356 .53968 .32224 Mtetra
.702 .625 .768 r
.53968 .32224 .54557 .3356 .5565 .32816 .55063 .31515 Mtetra
.706 .632 .772 r
.55063 .31515 .5565 .32816 .56745 .32064 .5616 .30792 Mtetra
.712 .639 .775 r
.5616 .30792 .56745 .32064 .57842 .31299 .57259 .30052 Mtetra
.718 .646 .776 r
.57259 .30052 .57842 .31299 .5894 .30512 .58359 .29289 Mtetra
.724 .653 .778 r
.58359 .29289 .5894 .30512 .60038 .29699 .5946 .28499 Mtetra
.731 .66 .779 r
.5946 .28499 .60038 .29699 .61137 .28853 .60562 .2768 Mtetra
.738 .667 .781 r
.60562 .2768 .61137 .28853 .62237 .27978 .61664 .26835 Mtetra
.744 .675 .783 r
.61664 .26835 .62237 .27978 .63336 .27079 .62767 .25971 Mtetra
.748 .683 .788 r
.62767 .25971 .63336 .27079 .64436 .2617 .63871 .25101 Mtetra
.751 .691 .794 r
.63871 .25101 .64436 .2617 .65537 .25267 .64977 .24238 Mtetra
.752 .7 .802 r
.64977 .24238 .65537 .25267 .6664 .24387 .66084 .23396 Mtetra
.751 .707 .811 r
.66084 .23396 .6664 .24387 .67745 .23542 .67194 .22582 Mtetra
.751 .715 .818 r
.67194 .22582 .67745 .23542 .68853 .22725 .68306 .21782 Mtetra
.758 .722 .818 r
.68306 .21782 .68853 .22725 .69962 .21902 .69418 .20954 Mtetra
.672 .687 .856 r
.69418 .20954 .69962 .21902 .71083 .21243 .70553 .20499 Mtetra
.664 .741 .908 r
.70553 .20499 .71083 .21243 .72223 .20841 .71697 .20094 Mtetra
.71697 .20094 .72223 .20841 .73367 .20437 .72844 .19688 Mtetra
.72844 .19688 .73367 .20437 .74517 .20032 .73997 .19279 Mtetra
.73997 .19279 .74517 .20032 .7567 .19625 .75154 .18869 Mtetra
.75154 .18869 .7567 .19625 .76829 .19216 .76316 .18458 Mtetra
.76316 .18458 .76829 .19216 .77992 .18806 .77482 .18044 Mtetra
.77482 .18044 .77992 .18806 .7916 .18394 .78654 .17629 Mtetra
.78654 .17629 .7916 .18394 .80333 .17981 .7983 .17213 Mtetra
.17113 .38584 .17775 .392 .18715 .38867 .18055 .38249 Mtetra
.18055 .38249 .18715 .38867 .19659 .38532 .19001 .37912 Mtetra
.19001 .37912 .19659 .38532 .20606 .38197 .19951 .37574 Mtetra
.19951 .37574 .20606 .38197 .21557 .3786 .20903 .37235 Mtetra
.20903 .37235 .21557 .3786 .22511 .37522 .2186 .36894 Mtetra
.2186 .36894 .22511 .37522 .23469 .37182 .2282 .36553 Mtetra
.2282 .36553 .23469 .37182 .24431 .36842 .23783 .3621 Mtetra
.23783 .3621 .24431 .36842 .25396 .365 .2475 .35865 Mtetra
.2475 .35865 .25396 .365 .2636 .36206 .25721 .3552 Mtetra
.544 .684 .93 r
.25721 .3552 .2636 .36206 .27299 .36276 .26674 .35425 Mtetra
.492 .609 .897 r
.26674 .35425 .27299 .36276 .28247 .3632 .27623 .35456 Mtetra
.494 .607 .894 r
.27623 .35456 .28247 .3632 .29199 .3638 .28578 .35486 Mtetra
.487 .596 .888 r
.28578 .35486 .29199 .3638 .30155 .36467 .29538 .35534 Mtetra
.482 .583 .879 r
.29538 .35534 .30155 .36467 .31116 .36576 .30502 .356 Mtetra
.482 .573 .87 r
.30502 .356 .31116 .36576 .32083 .36695 .31472 .35676 Mtetra
.488 .566 .861 r
.31472 .35676 .32083 .36695 .33057 .36808 .32448 .3575 Mtetra
.498 .562 .852 r
.32448 .3575 .33057 .36808 .34038 .36905 .33432 .35811 Mtetra
.509 .561 .844 r
.33432 .35811 .34038 .36905 .35028 .36978 .34423 .35852 Mtetra
.521 .561 .837 r
.34423 .35852 .35028 .36978 .36025 .37023 .35421 .3587 Mtetra
.532 .562 .831 r
.35421 .3587 .36025 .37023 .37029 .37043 .36427 .35864 Mtetra
.541 .562 .826 r
.36427 .35864 .37029 .37043 .38041 .37042 .3744 .35837 Mtetra
.548 .562 .82 r
.3744 .35837 .38041 .37042 .3906 .37025 .3846 .3579 Mtetra
.554 .56 .815 r
.3846 .3579 .3906 .37025 .40085 .36996 .39486 .35728 Mtetra
.56 .558 .809 r
.39486 .35728 .40085 .36996 .41117 .36955 .40519 .3565 Mtetra
.566 .556 .802 r
.40519 .3565 .41117 .36955 .42155 .369 .41559 .35552 Mtetra
.574 .554 .795 r
.41559 .35552 .42155 .369 .432 .36819 .42605 .35426 Mtetra
.584 .554 .787 r
.42605 .35426 .432 .36819 .44252 .36696 .43658 .3526 Mtetra
.598 .556 .779 r
.43658 .3526 .44252 .36696 .45311 .3651 .44718 .35039 Mtetra
.613 .56 .771 r
.44718 .35039 .45311 .3651 .46378 .36241 .45784 .34749 Mtetra
.629 .567 .765 r
.45784 .34749 .46378 .36241 .4745 .35875 .46857 .3438 Mtetra
.645 .575 .762 r
.46857 .3438 .4745 .35875 .48528 .35412 .47934 .33932 Mtetra
.659 .584 .76 r
.47934 .33932 .48528 .35412 .4961 .34865 .49017 .33413 Mtetra
.67 .594 .761 r
.49017 .33413 .4961 .34865 .50696 .34255 .50103 .32839 Mtetra
.68 .604 .764 r
.50103 .32839 .50696 .34255 .51784 .33601 .51192 .32224 Mtetra
.687 .613 .767 r
.51192 .32224 .51784 .33601 .52875 .32921 .52284 .3158 Mtetra
.694 .621 .771 r
.52284 .3158 .52875 .32921 .53968 .32224 .53378 .30915 Mtetra
.699 .628 .774 r
.53378 .30915 .53968 .32224 .55063 .31515 .54474 .30233 Mtetra
.704 .634 .776 r
.54474 .30233 .55063 .31515 .5616 .30792 .55573 .29534 Mtetra
.709 .641 .778 r
.55573 .29534 .5616 .30792 .57259 .30052 .56674 .28815 Mtetra
.715 .647 .78 r
.56674 .28815 .57259 .30052 .58359 .29289 .57776 .28072 Mtetra
.721 .653 .781 r
.57776 .28072 .58359 .29289 .5946 .28499 .58879 .27304 Mtetra
.727 .659 .782 r
.58879 .27304 .5946 .28499 .60562 .2768 .59984 .26511 Mtetra
.733 .666 .784 r
.59984 .26511 .60562 .2768 .61664 .26835 .6109 .25696 Mtetra
.739 .674 .788 r
.6109 .25696 .61664 .26835 .62767 .25971 .62196 .24867 Mtetra
.743 .682 .793 r
.62196 .24867 .62767 .25971 .63871 .25101 .63304 .24034 Mtetra
.745 .69 .799 r
.63304 .24034 .63871 .25101 .64977 .24238 .64413 .2321 Mtetra
.746 .699 .807 r
.64413 .2321 .64977 .24238 .66084 .23396 .65525 .22402 Mtetra
.746 .706 .814 r
.65525 .22402 .66084 .23396 .67194 .22582 .66639 .21613 Mtetra
.749 .713 .819 r
.66639 .21613 .67194 .22582 .68306 .21782 .67754 .20821 Mtetra
.723 .706 .834 r
.67754 .20821 .68306 .21782 .69418 .20954 .68878 .20157 Mtetra
.663 .725 .896 r
.68878 .20157 .69418 .20954 .70553 .20499 .7002 .1975 Mtetra
.664 .741 .908 r
.7002 .1975 .70553 .20499 .71697 .20094 .71167 .19342 Mtetra
.71167 .19342 .71697 .20094 .72844 .19688 .72318 .18932 Mtetra
.72318 .18932 .72844 .19688 .73997 .19279 .73473 .18521 Mtetra
.73473 .18521 .73997 .19279 .75154 .18869 .74634 .18108 Mtetra
.74634 .18108 .75154 .18869 .76316 .18458 .75799 .17693 Mtetra
.75799 .17693 .76316 .18458 .77482 .18044 .76969 .17277 Mtetra
.76969 .17277 .77482 .18044 .78654 .17629 .78143 .16859 Mtetra
.78143 .16859 .78654 .17629 .7983 .17213 .79323 .16439 Mtetra
.16447 .37964 .17113 .38584 .18055 .38249 .17391 .37626 Mtetra
.17391 .37626 .18055 .38249 .19001 .37912 .18339 .37287 Mtetra
.18339 .37287 .19001 .37912 .19951 .37574 .1929 .36947 Mtetra
.1929 .36947 .19951 .37574 .20903 .37235 .20245 .36605 Mtetra
.20245 .36605 .20903 .37235 .2186 .36894 .21204 .36262 Mtetra
.21204 .36262 .2186 .36894 .2282 .36553 .22166 .35918 Mtetra
.22166 .35918 .2282 .36553 .23783 .3621 .23131 .35573 Mtetra
.23131 .35573 .23783 .3621 .2475 .35865 .241 .35226 Mtetra
.241 .35226 .2475 .35865 .25721 .3552 .25073 .34879 Mtetra
.654 .739 .912 r
.25073 .34879 .25721 .3552 .26674 .35425 .26047 .34555 Mtetra
.494 .606 .893 r
.26047 .34555 .26674 .35425 .27623 .35456 .26997 .34581 Mtetra
.505 .611 .891 r
.26997 .34581 .27623 .35456 .28578 .35486 .27954 .34589 Mtetra
.504 .605 .887 r
.27954 .34589 .28578 .35486 .29538 .35534 .28916 .34604 Mtetra
.501 .595 .88 r
.28916 .34604 .29538 .35534 .30502 .356 .29884 .3463 Mtetra
.501 .585 .871 r
.29884 .3463 .30502 .356 .31472 .35676 .30857 .34665 Mtetra
.504 .577 .862 r
.30857 .34665 .31472 .35676 .32448 .3575 .31836 .347 Mtetra
.511 .572 .853 r
.31836 .347 .32448 .3575 .33432 .35811 .32821 .34726 Mtetra
.52 .57 .846 r
.32821 .34726 .33432 .35811 .34423 .35852 .33814 .34736 Mtetra
.53 .569 .839 r
.33814 .34736 .34423 .35852 .35421 .3587 .34814 .34727 Mtetra
.539 .569 .833 r
.34814 .34727 .35421 .3587 .36427 .35864 .35821 .34696 Mtetra
.548 .569 .828 r
.35821 .34696 .36427 .35864 .3744 .35837 .36836 .34645 Mtetra
.555 .569 .823 r
.36836 .34645 .3744 .35837 .3846 .3579 .37857 .34574 Mtetra
.561 .568 .818 r
.37857 .34574 .3846 .3579 .39486 .35728 .38884 .34485 Mtetra
.568 .567 .813 r
.38884 .34485 .39486 .35728 .40519 .3565 .39918 .34376 Mtetra
.575 .567 .807 r
.39918 .34376 .40519 .3565 .41559 .35552 .40959 .34246 Mtetra
.583 .566 .801 r
.40959 .34246 .41559 .35552 .42605 .35426 .42006 .34086 Mtetra
.593 .567 .794 r
.42006 .34086 .42605 .35426 .43658 .3526 .4306 .33888 Mtetra
.605 .569 .787 r
.4306 .33888 .43658 .3526 .44718 .35039 .44121 .3364 Mtetra
.618 .573 .781 r
.44121 .3364 .44718 .35039 .45784 .34749 .45187 .33333 Mtetra
.632 .578 .776 r
.45187 .33333 .45784 .34749 .46857 .3438 .4626 .32961 Mtetra
.646 .586 .772 r
.4626 .32961 .46857 .3438 .47934 .33932 .47338 .32523 Mtetra
.658 .594 .771 r
.47338 .32523 .47934 .33932 .49017 .33413 .48421 .32025 Mtetra
.669 .602 .771 r
.48421 .32025 .49017 .33413 .50103 .32839 .49507 .31476 Mtetra
.678 .61 .772 r
.49507 .31476 .50103 .32839 .51192 .32224 .50597 .30889 Mtetra
.685 .618 .775 r
.50597 .30889 .51192 .32224 .52284 .3158 .5169 .30272 Mtetra
.691 .625 .777 r
.5169 .30272 .52284 .3158 .53378 .30915 .52786 .29631 Mtetra
.697 .631 .779 r
.52786 .29631 .53378 .30915 .54474 .30233 .53884 .2897 Mtetra
.702 .637 .781 r
.53884 .2897 .54474 .30233 .55573 .29534 .54984 .28289 Mtetra
.707 .642 .782 r
.54984 .28289 .55573 .29534 .56674 .28815 .56086 .27588 Mtetra
.712 .648 .784 r
.56086 .27588 .56674 .28815 .57776 .28072 .57191 .26864 Mtetra
.718 .654 .785 r
.57191 .26864 .57776 .28072 .58879 .27304 .58296 .26118 Mtetra
.724 .66 .786 r
.58296 .26118 .58879 .27304 .59984 .26511 .59404 .2535 Mtetra
.729 .667 .789 r
.59404 .2535 .59984 .26511 .6109 .25696 .60512 .24565 Mtetra
.733 .674 .793 r
.60512 .24565 .6109 .25696 .62196 .24867 .61622 .2377 Mtetra
.737 .682 .798 r
.61622 .2377 .62196 .24867 .63304 .24034 .62734 .22973 Mtetra
.739 .69 .804 r
.62734 .22973 .63304 .24034 .64413 .2321 .63847 .22184 Mtetra
.74 .698 .811 r
.63847 .22184 .64413 .2321 .65525 .22402 .64963 .21406 Mtetra
.742 .705 .817 r
.64963 .21406 .65525 .22402 .66639 .21613 .6608 .20632 Mtetra
.748 .712 .818 r
.6608 .20632 .66639 .21613 .67754 .20821 .67199 .19839 Mtetra
.663 .677 .853 r
.67199 .19839 .67754 .20821 .68878 .20157 .68338 .19405 Mtetra
.664 .741 .908 r
.68338 .19405 .68878 .20157 .7002 .1975 .69483 .18996 Mtetra
.69483 .18996 .7002 .1975 .71167 .19342 .70632 .18584 Mtetra
.70632 .18584 .71167 .19342 .72318 .18932 .71787 .18172 Mtetra
.71787 .18172 .72318 .18932 .73473 .18521 .72946 .17757 Mtetra
.72946 .17757 .73473 .18521 .74634 .18108 .74109 .17341 Mtetra
.74109 .17341 .74634 .18108 .75799 .17693 .75278 .16923 Mtetra
.75278 .16923 .75799 .17693 .76969 .17277 .76451 .16504 Mtetra
.76451 .16504 .76969 .17277 .78143 .16859 .77629 .16082 Mtetra
.77629 .16082 .78143 .16859 .79323 .16439 .78812 .15659 Mtetra
.15776 .37339 .16447 .37964 .17391 .37626 .16722 .36999 Mtetra
.16722 .36999 .17391 .37626 .18339 .37287 .17672 .36658 Mtetra
.17672 .36658 .18339 .37287 .1929 .36947 .18626 .36315 Mtetra
.18626 .36315 .1929 .36947 .20245 .36605 .19583 .35971 Mtetra
.19583 .35971 .20245 .36605 .21204 .36262 .20543 .35626 Mtetra
.20543 .35626 .21204 .36262 .22166 .35918 .21507 .3528 Mtetra
.21507 .3528 .22166 .35918 .23131 .35573 .22475 .34932 Mtetra
.22475 .34932 .23131 .35573 .241 .35226 .23446 .34583 Mtetra
.23446 .34583 .241 .35226 .25073 .34879 .24421 .34233 Mtetra
.24421 .34233 .25073 .34879 .26047 .34555 .25399 .33881 Mtetra
.591 .71 .926 r
.25399 .33881 .26047 .34555 .26997 .34581 .26368 .33691 Mtetra
.511 .61 .888 r
.26368 .33691 .26997 .34581 .27954 .34589 .27326 .33688 Mtetra
.516 .61 .885 r
.27326 .33688 .27954 .34589 .28916 .34604 .28291 .33676 Mtetra
.516 .604 .88 r
.28291 .33676 .28916 .34604 .29884 .3463 .29262 .33668 Mtetra
.517 .596 .872 r
.29262 .33668 .29884 .3463 .30857 .34665 .30238 .33665 Mtetra
.519 .588 .864 r
.30238 .33665 .30857 .34665 .31836 .347 .31219 .33662 Mtetra
.524 .583 .856 r
.31219 .33662 .31836 .347 .32821 .34726 .32207 .33654 Mtetra
.531 .579 .848 r
.32207 .33654 .32821 .34726 .33814 .34736 .33202 .33633 Mtetra
.539 .577 .841 r
.33202 .33633 .33814 .34736 .34814 .34727 .34204 .33597 Mtetra
.547 .576 .835 r
.34204 .33597 .34814 .34727 .35821 .34696 .35212 .33542 Mtetra
.554 .576 .83 r
.35212 .33542 .35821 .34696 .36836 .34645 .36228 .33469 Mtetra
.561 .576 .826 r
.36228 .33469 .36836 .34645 .37857 .34574 .3725 .33376 Mtetra
.568 .575 .821 r
.3725 .33376 .37857 .34574 .38884 .34485 .38279 .33264 Mtetra
.574 .575 .816 r
.38279 .33264 .38884 .34485 .39918 .34376 .39314 .33131 Mtetra
.581 .575 .811 r
.39314 .33131 .39918 .34376 .40959 .34246 .40356 .32974 Mtetra
.59 .576 .806 r
.40356 .32974 .40959 .34246 .42006 .34086 .41404 .32788 Mtetra
.599 .577 .8 r
.41404 .32788 .42006 .34086 .4306 .33888 .42459 .32566 Mtetra
.61 .58 .795 r
.42459 .32566 .4306 .33888 .44121 .3364 .4352 .32298 Mtetra
.622 .584 .789 r
.4352 .32298 .44121 .3364 .45187 .33333 .44588 .31979 Mtetra
.635 .589 .785 r
.44588 .31979 .45187 .33333 .4626 .32961 .45661 .31603 Mtetra
.647 .595 .782 r
.45661 .31603 .4626 .32961 .47338 .32523 .46739 .31171 Mtetra
.658 .602 .78 r
.46739 .31171 .47338 .32523 .48421 .32025 .47822 .30686 Mtetra
.668 .609 .779 r
.47822 .30686 .48421 .32025 .49507 .31476 .4891 .30156 Mtetra
.677 .616 .78 r
.4891 .30156 .49507 .31476 .50597 .30889 .5 .29589 Mtetra
.684 .623 .781 r
.5 .29589 .50597 .30889 .5169 .30272 .51094 .28991 Mtetra
.69 .629 .783 r
.51094 .28991 .5169 .30272 .52786 .29631 .52191 .28369 Mtetra
.695 .634 .784 r
.52191 .28369 .52786 .29631 .53884 .2897 .53291 .27725 Mtetra
.7 .639 .785 r
.53291 .27725 .53884 .2897 .54984 .28289 .54393 .2706 Mtetra
.705 .645 .786 r
.54393 .2706 .54984 .28289 .56086 .27588 .55497 .26375 Mtetra
.71 .65 .788 r
.55497 .26375 .56086 .27588 .57191 .26864 .56603 .25669 Mtetra
.715 .655 .789 r
.56603 .25669 .57191 .26864 .58296 .26118 .57711 .24944 Mtetra
.72 .661 .791 r
.57711 .24944 .58296 .26118 .59404 .2535 .58821 .24202 Mtetra
.725 .668 .794 r
.58821 .24202 .59404 .2535 .60512 .24565 .59933 .23447 Mtetra
.729 .675 .798 r
.59933 .23447 .60512 .24565 .61622 .2377 .61046 .22684 Mtetra
.732 .683 .803 r
.61046 .22684 .61622 .2377 .62734 .22973 .62161 .2192 Mtetra
.734 .691 .809 r
.62161 .2192 .62734 .22973 .63847 .22184 .63278 .2116 Mtetra
.737 .698 .815 r
.63278 .2116 .63847 .22184 .64963 .21406 .64398 .20402 Mtetra
.74 .705 .817 r
.64398 .20402 .64963 .21406 .6608 .20632 .65518 .19635 Mtetra
.699 .69 .838 r
.65518 .19635 .6608 .20632 .67199 .19839 .6665 .19059 Mtetra
.663 .733 .902 r
.6665 .19059 .67199 .19839 .68338 .19405 .67793 .18648 Mtetra
.664 .741 .908 r
.67793 .18648 .68338 .19405 .69483 .18996 .68942 .18235 Mtetra
.68942 .18235 .69483 .18996 .70632 .18584 .70094 .17821 Mtetra
.70094 .17821 .70632 .18584 .71787 .18172 .71252 .17405 Mtetra
.71252 .17405 .71787 .18172 .72946 .17757 .72414 .16988 Mtetra
.72414 .16988 .72946 .17757 .74109 .17341 .73581 .16568 Mtetra
.73581 .16568 .74109 .17341 .75278 .16923 .74753 .16147 Mtetra
.74753 .16147 .75278 .16923 .76451 .16504 .75929 .15724 Mtetra
.75929 .15724 .76451 .16504 .77629 .16082 .77111 .153 Mtetra
.77111 .153 .77629 .16082 .78812 .15659 .78297 .14874 Mtetra
.15101 .3671 .15776 .37339 .16722 .36999 .16049 .36368 Mtetra
.16049 .36368 .16722 .36999 .17672 .36658 .17001 .36024 Mtetra
.17001 .36024 .17672 .36658 .18626 .36315 .17956 .35679 Mtetra
.17956 .35679 .18626 .36315 .19583 .35971 .18915 .35333 Mtetra
.18915 .35333 .19583 .35971 .20543 .35626 .19878 .34986 Mtetra
.19878 .34986 .20543 .35626 .21507 .3528 .20844 .34637 Mtetra
.20844 .34637 .21507 .3528 .22475 .34932 .21814 .34287 Mtetra
.21814 .34287 .22475 .34932 .23446 .34583 .22787 .33935 Mtetra
.22787 .33935 .23446 .34583 .24421 .34233 .23764 .33583 Mtetra
.23764 .33583 .24421 .34233 .25399 .33881 .24745 .33229 Mtetra
.24745 .33229 .25399 .33881 .26368 .33691 .25729 .32873 Mtetra
.553 .651 .9 r
.25729 .32873 .26368 .33691 .27326 .33688 .26696 .32775 Mtetra
.524 .612 .883 r
.26696 .32775 .27326 .33688 .28291 .33676 .27663 .32747 Mtetra
.528 .61 .879 r
.27663 .32747 .28291 .33676 .29262 .33668 .28635 .32713 Mtetra
.53 .605 .873 r
.28635 .32713 .29262 .33668 .30238 .33665 .29614 .32677 Mtetra
.533 .599 .866 r
.29614 .32677 .30238 .33665 .31219 .33662 .30599 .32639 Mtetra
.537 .593 .858 r
.30599 .32639 .31219 .33662 .32207 .33654 .31589 .32597 Mtetra
.542 .589 .851 r
.31589 .32597 .32207 .33654 .33202 .33633 .32586 .32546 Mtetra
.548 .586 .844 r
.32586 .32546 .33202 .33633 .34204 .33597 .3359 .32482 Mtetra
.554 .584 .838 r
.3359 .32482 .34204 .33597 .35212 .33542 .346 .32403 Mtetra
.56 .583 .833 r
.346 .32403 .35212 .33542 .36228 .33469 .35617 .32307 Mtetra
.567 .582 .828 r
.35617 .32307 .36228 .33469 .3725 .33376 .3664 .32194 Mtetra
.573 .582 .824 r
.3664 .32194 .3725 .33376 .38279 .33264 .3767 .32062 Mtetra
.58 .582 .82 r
.3767 .32062 .38279 .33264 .39314 .33131 .38707 .31908 Mtetra
.587 .583 .815 r
.38707 .31908 .39314 .33131 .40356 .32974 .39749 .3173 Mtetra
.595 .584 .811 r
.39749 .3173 .40356 .32974 .41404 .32788 .40799 .31524 Mtetra
.604 .586 .806 r
.40799 .31524 .41404 .32788 .42459 .32566 .41855 .31282 Mtetra
.615 .589 .801 r
.41855 .31282 .42459 .32566 .4352 .32298 .42917 .30999 Mtetra
.626 .592 .796 r
.42917 .30999 .4352 .32298 .44588 .31979 .43985 .30669 Mtetra
.637 .597 .792 r
.43985 .30669 .44588 .31979 .45661 .31603 .45059 .3029 Mtetra
.648 .602 .789 r
.45059 .3029 .45661 .31603 .46739 .31171 .46138 .29862 Mtetra
.658 .608 .787 r
.46138 .29862 .46739 .31171 .47822 .30686 .47221 .29386 Mtetra
.668 .615 .786 r
.47221 .29386 .47822 .30686 .4891 .30156 .48309 .28869 Mtetra
.676 .621 .786 r
.48309 .28869 .4891 .30156 .5 .29589 .49401 .28316 Mtetra
.682 .627 .787 r
.49401 .28316 .5 .29589 .51094 .28991 .50496 .27734 Mtetra
.688 .632 .788 r
.50496 .27734 .51094 .28991 .52191 .28369 .51594 .27126 Mtetra
.694 .637 .789 r
.51594 .27126 .52191 .28369 .53291 .27725 .52695 .26496 Mtetra
.698 .642 .79 r
.52695 .26496 .53291 .27725 .54393 .2706 .53799 .25846 Mtetra
.703 .647 .791 r
.53799 .25846 .54393 .2706 .55497 .26375 .54905 .25177 Mtetra
.708 .652 .792 r
.54905 .25177 .55497 .26375 .56603 .25669 .56013 .2449 Mtetra
.712 .658 .794 r
.56013 .2449 .56603 .25669 .57711 .24944 .57124 .23786 Mtetra
.717 .664 .796 r
.57124 .23786 .57711 .24944 .58821 .24202 .58236 .23069 Mtetra
.721 .67 .8 r
.58236 .23069 .58821 .24202 .59933 .23447 .59351 .22342 Mtetra
.724 .677 .804 r
.59351 .22342 .59933 .23447 .61046 .22684 .60467 .21609 Mtetra
.728 .685 .809 r
.60467 .21609 .61046 .22684 .62161 .2192 .61586 .20872 Mtetra
.731 .692 .813 r
.61586 .20872 .62161 .2192 .63278 .2116 .62706 .20134 Mtetra
.734 .698 .816 r
.62706 .20134 .63278 .2116 .64398 .20402 .63829 .19386 Mtetra
.72 .695 .826 r
.63829 .19386 .64398 .20402 .65518 .19635 .64956 .18711 Mtetra
.659 .692 .87 r
.64956 .18711 .65518 .19635 .6665 .19059 .66098 .18299 Mtetra
.664 .741 .908 r
.66098 .18299 .6665 .19059 .67793 .18648 .67245 .17885 Mtetra
.67245 .17885 .67793 .18648 .68942 .18235 .68396 .17469 Mtetra
.68396 .17469 .68942 .18235 .70094 .17821 .69552 .17052 Mtetra
.69552 .17052 .70094 .17821 .71252 .17405 .70713 .16633 Mtetra
.70713 .16633 .71252 .17405 .72414 .16988 .71878 .16212 Mtetra
.71878 .16212 .72414 .16988 .73581 .16568 .73049 .1579 Mtetra
.73049 .1579 .73581 .16568 .74753 .16147 .74224 .15365 Mtetra
.74224 .15365 .74753 .16147 .75929 .15724 .75404 .14939 Mtetra
.75404 .14939 .75929 .15724 .77111 .153 .76589 .14512 Mtetra
.76589 .14512 .77111 .153 .78297 .14874 .77778 .14082 Mtetra
.14421 .36077 .15101 .3671 .16049 .36368 .15371 .35733 Mtetra
.15371 .35733 .16049 .36368 .17001 .36024 .16325 .35387 Mtetra
.16325 .35387 .17001 .36024 .17956 .35679 .17282 .35039 Mtetra
.17282 .35039 .17956 .35679 .18915 .35333 .18243 .34691 Mtetra
.18243 .34691 .18915 .35333 .19878 .34986 .19208 .34341 Mtetra
.19208 .34341 .19878 .34986 .20844 .34637 .20176 .3399 Mtetra
.20176 .3399 .20844 .34637 .21814 .34287 .21148 .33637 Mtetra
.21148 .33637 .21814 .34287 .22787 .33935 .22124 .33283 Mtetra
.22124 .33283 .22787 .33935 .23764 .33583 .23103 .32928 Mtetra
.23103 .32928 .23764 .33583 .24745 .33229 .24086 .32572 Mtetra
.24086 .32572 .24745 .33229 .25729 .32873 .25072 .32214 Mtetra
.25072 .32214 .25729 .32873 .26696 .32775 .26062 .31854 Mtetra
.531 .615 .881 r
.26062 .31854 .26696 .32775 .27663 .32747 .27031 .31809 Mtetra
.535 .613 .877 r
.27031 .31809 .27663 .32747 .28635 .32713 .28006 .31758 Mtetra
.54 .612 .873 r
.28006 .31758 .28635 .32713 .29614 .32677 .28987 .31697 Mtetra
.544 .608 .867 r
.28987 .31697 .29614 .32677 .30599 .32639 .29974 .3163 Mtetra
.548 .603 .861 r
.29974 .3163 .30599 .32639 .31589 .32597 .30967 .31557 Mtetra
.552 .599 .854 r
.30967 .31557 .31589 .32597 .32586 .32546 .31966 .31475 Mtetra
.557 .595 .847 r
.31966 .31475 .32586 .32546 .3359 .32482 .32972 .31384 Mtetra
.562 .592 .841 r
.32972 .31384 .3359 .32482 .346 .32403 .33984 .3128 Mtetra
.567 .59 .836 r
.33984 .3128 .346 .32403 .35617 .32307 .35002 .31162 Mtetra
.573 .589 .831 r
.35002 .31162 .35617 .32307 .3664 .32194 .36027 .31028 Mtetra
.578 .589 .827 r
.36027 .31028 .3664 .32194 .3767 .32062 .37058 .30876 Mtetra
.585 .589 .823 r
.37058 .30876 .3767 .32062 .38707 .31908 .38096 .30704 Mtetra
.592 .59 .818 r
.38096 .30704 .38707 .31908 .39749 .3173 .3914 .30507 Mtetra
.6 .591 .814 r
.3914 .30507 .39749 .3173 .40799 .31524 .4019 .30283 Mtetra
.609 .593 .81 r
.4019 .30283 .40799 .31524 .41855 .31282 .41247 .30025 Mtetra
.618 .595 .805 r
.41247 .30025 .41855 .31282 .42917 .30999 .4231 .29729 Mtetra
.628 .599 .801 r
.4231 .29729 .42917 .30999 .43985 .30669 .43379 .29392 Mtetra
.639 .603 .798 r
.43379 .29392 .43985 .30669 .45059 .3029 .44453 .29009 Mtetra
.649 .608 .795 r
.44453 .29009 .45059 .3029 .46138 .29862 .45533 .28583 Mtetra
.658 .614 .793 r
.45533 .28583 .46138 .29862 .47221 .29386 .46618 .28114 Mtetra
.667 .619 .792 r
.46618 .28114 .47221 .29386 .48309 .28869 .47706 .27606 Mtetra
.674 .625 .791 r
.47706 .27606 .48309 .28869 .49401 .28316 .48799 .27064 Mtetra
.681 .63 .791 r
.48799 .27064 .49401 .28316 .50496 .27734 .49895 .26494 Mtetra
.687 .635 .792 r
.49895 .26494 .50496 .27734 .51594 .27126 .50995 .25899 Mtetra
.692 .64 .793 r
.50995 .25899 .51594 .27126 .52695 .26496 .52098 .25283 Mtetra
.697 .645 .794 r
.52098 .25283 .52695 .26496 .53799 .25846 .53203 .24647 Mtetra
.701 .649 .795 r
.53203 .24647 .53799 .25846 .54905 .25177 .54311 .23995 Mtetra
.705 .654 .797 r
.54311 .23995 .54905 .25177 .56013 .2449 .55421 .23327 Mtetra
.709 .66 .799 r
.55421 .23327 .56013 .2449 .57124 .23786 .56534 .22645 Mtetra
.713 .666 .802 r
.56534 .22645 .57124 .23786 .58236 .23069 .57649 .21953 Mtetra
.717 .673 .805 r
.57649 .21953 .58236 .23069 .59351 .22342 .58766 .21251 Mtetra
.721 .679 .809 r
.58766 .21251 .59351 .22342 .60467 .21609 .59886 .20542 Mtetra
.724 .686 .813 r
.59886 .20542 .60467 .21609 .61586 .20872 .61007 .19825 Mtetra
.728 .692 .815 r
.61007 .19825 .61586 .20872 .62706 .20134 .62131 .19097 Mtetra
.731 .696 .817 r
.62131 .19097 .62706 .20134 .63829 .19386 .63257 .18362 Mtetra
.654 .667 .85 r
.63257 .18362 .63829 .19386 .64956 .18711 .64397 .17949 Mtetra
.664 .741 .908 r
.64397 .17949 .64956 .18711 .66098 .18299 .65542 .17533 Mtetra
.65542 .17533 .66098 .18299 .67245 .17885 .66692 .17116 Mtetra
.66692 .17116 .67245 .17885 .68396 .17469 .67847 .16697 Mtetra
.67847 .16697 .68396 .17469 .69552 .17052 .69006 .16277 Mtetra
.69006 .16277 .69552 .17052 .70713 .16633 .7017 .15855 Mtetra
.7017 .15855 .70713 .16633 .71878 .16212 .71339 .15431 Mtetra
.71339 .15431 .71878 .16212 .73049 .1579 .72512 .15005 Mtetra
.72512 .15005 .73049 .1579 .74224 .15365 .73691 .14577 Mtetra
.73691 .14577 .74224 .15365 .75404 .14939 .74874 .14148 Mtetra
.74874 .14148 .75404 .14939 .76589 .14512 .76063 .13717 Mtetra
.76063 .13717 .76589 .14512 .77778 .14082 .77256 .13284 Mtetra
.13736 .3544 .14421 .36077 .15371 .35733 .14689 .35093 Mtetra
.14689 .35093 .15371 .35733 .16325 .35387 .15644 .34744 Mtetra
.15644 .34744 .16325 .35387 .17282 .35039 .16604 .34395 Mtetra
.16604 .34395 .17282 .35039 .18243 .34691 .17567 .34044 Mtetra
.17567 .34044 .18243 .34691 .19208 .34341 .18534 .33691 Mtetra
.18534 .33691 .19208 .34341 .20176 .3399 .19504 .33338 Mtetra
.19504 .33338 .20176 .3399 .21148 .33637 .20478 .32983 Mtetra
.20478 .32983 .21148 .33637 .22124 .33283 .21455 .32626 Mtetra
.21455 .32626 .22124 .33283 .23103 .32928 .22437 .32269 Mtetra
.22437 .32269 .23103 .32928 .24086 .32572 .23422 .3191 Mtetra
.23422 .3191 .24086 .32572 .25072 .32214 .24411 .31549 Mtetra
.24411 .31549 .25072 .32214 .26062 .31854 .25403 .31188 Mtetra
.654 .739 .912 r
.25403 .31188 .26062 .31854 .27031 .31809 .26397 .30849 Mtetra
.536 .608 .873 r
.26397 .30849 .27031 .31809 .28006 .31758 .27373 .30795 Mtetra
.546 .613 .871 r
.27373 .30795 .28006 .31758 .28987 .31697 .28355 .30719 Mtetra
.552 .613 .867 r
.28355 .30719 .28987 .31697 .29974 .3163 .29345 .3063 Mtetra
.557 .611 .862 r
.29345 .3063 .29974 .3163 .30967 .31557 .3034 .3053 Mtetra
.561 .607 .856 r
.3034 .3053 .30967 .31557 .31966 .31475 .31342 .30421 Mtetra
.565 .604 .85 r
.31342 .30421 .31966 .31475 .32972 .31384 .32349 .30303 Mtetra
.57 .601 .845 r
.32349 .30303 .32972 .31384 .33984 .3128 .33363 .30174 Mtetra
.574 .598 .839 r
.33363 .30174 .33984 .3128 .35002 .31162 .34383 .30032 Mtetra
.579 .596 .834 r
.34383 .30032 .35002 .31162 .36027 .31028 .3541 .29877 Mtetra
.584 .595 .83 r
.3541 .29877 .36027 .31028 .37058 .30876 .36442 .29705 Mtetra
.59 .595 .825 r
.36442 .29705 .37058 .30876 .38096 .30704 .37481 .29513 Mtetra
.596 .595 .821 r
.37481 .29513 .38096 .30704 .3914 .30507 .38527 .29299 Mtetra
.604 .596 .817 r
.38527 .29299 .3914 .30507 .4019 .30283 .39578 .29058 Mtetra
.612 .598 .813 r
.39578 .29058 .4019 .30283 .41247 .30025 .40636 .28787 Mtetra
.621 .601 .809 r
.40636 .28787 .41247 .30025 .4231 .29729 .417 .2848 Mtetra
.63 .604 .805 r
.417 .2848 .4231 .29729 .43379 .29392 .4277 .28135 Mtetra
.64 .608 .802 r
.4277 .28135 .43379 .29392 .44453 .29009 .43845 .27749 Mtetra
.649 .612 .799 r
.43845 .27749 .44453 .29009 .45533 .28583 .44926 .27324 Mtetra
.658 .617 .797 r
.44926 .27324 .45533 .28583 .46618 .28114 .46011 .26859 Mtetra
.666 .622 .796 r
.46011 .26859 .46618 .28114 .47706 .27606 .47101 .26359 Mtetra
.673 .627 .795 r
.47101 .26359 .47706 .27606 .48799 .27064 .48195 .25828 Mtetra
.679 .632 .795 r
.48195 .25828 .48799 .27064 .49895 .26494 .49292 .25269 Mtetra
.685 .637 .796 r
.49292 .25269 .49895 .26494 .50995 .25899 .50393 .24686 Mtetra
.69 .642 .797 r
.50393 .24686 .50995 .25899 .52098 .25283 .51497 .24084 Mtetra
.694 .647 .798 r
.51497 .24084 .52098 .25283 .53203 .24647 .52604 .23464 Mtetra
.698 .652 .8 r
.52604 .23464 .53203 .24647 .54311 .23995 .53714 .22829 Mtetra
.702 .657 .802 r
.53714 .22829 .54311 .23995 .55421 .23327 .54826 .2218 Mtetra
.706 .663 .804 r
.54826 .2218 .55421 .23327 .56534 .22645 .55942 .2152 Mtetra
.71 .669 .807 r
.55942 .2152 .56534 .22645 .57649 .21953 .57059 .20849 Mtetra
.714 .675 .81 r
.57059 .20849 .57649 .21953 .58766 .21251 .58179 .20168 Mtetra
.718 .681 .813 r
.58179 .20168 .58766 .21251 .59886 .20542 .59301 .19476 Mtetra
.723 .687 .815 r
.59301 .19476 .59886 .20542 .61007 .19825 .60426 .18768 Mtetra
.728 .691 .815 r
.60426 .18768 .61007 .19825 .62131 .19097 .61552 .18037 Mtetra
.66 .662 .841 r
.61552 .18037 .62131 .19097 .63257 .18362 .6269 .17597 Mtetra
.664 .741 .908 r
.6269 .17597 .63257 .18362 .64397 .17949 .63834 .1718 Mtetra
.63834 .1718 .64397 .17949 .65542 .17533 .64982 .16762 Mtetra
.64982 .16762 .65542 .17533 .66692 .17116 .66135 .16342 Mtetra
.66135 .16342 .66692 .17116 .67847 .16697 .67293 .1592 Mtetra
.67293 .1592 .67847 .16697 .69006 .16277 .68455 .15496 Mtetra
.68455 .15496 .69006 .16277 .7017 .15855 .69623 .15071 Mtetra
.69623 .15071 .7017 .15855 .71339 .15431 .70795 .14643 Mtetra
.70795 .14643 .71339 .15431 .72512 .15005 .71972 .14214 Mtetra
.71972 .14214 .72512 .15005 .73691 .14577 .73154 .13784 Mtetra
.73154 .13784 .73691 .14577 .74874 .14148 .74341 .13351 Mtetra
.74341 .13351 .74874 .14148 .76063 .13717 .75532 .12917 Mtetra
.75532 .12917 .76063 .13717 .77256 .13284 .76729 .1248 Mtetra
.13047 .34798 .13736 .3544 .14689 .35093 .14001 .34449 Mtetra
.14001 .34449 .14689 .35093 .15644 .34744 .14959 .34098 Mtetra
.14959 .34098 .15644 .34744 .16604 .34395 .15921 .33746 Mtetra
.15921 .33746 .16604 .34395 .17567 .34044 .16886 .33392 Mtetra
.16886 .33392 .17567 .34044 .18534 .33691 .17854 .33037 Mtetra
.17854 .33037 .18534 .33691 .19504 .33338 .18827 .32681 Mtetra
.18827 .32681 .19504 .33338 .20478 .32983 .19803 .32324 Mtetra
.19803 .32324 .20478 .32983 .21455 .32626 .20783 .31965 Mtetra
.20783 .31965 .21455 .32626 .22437 .32269 .21766 .31605 Mtetra
.21766 .31605 .22437 .32269 .23422 .3191 .22753 .31243 Mtetra
.22753 .31243 .23422 .3191 .24411 .31549 .23744 .3088 Mtetra
.23744 .3088 .24411 .31549 .25403 .31188 .24739 .30516 Mtetra
.24739 .30516 .25403 .31188 .26397 .30849 .25738 .3015 Mtetra
.654 .731 .906 r
.25738 .3015 .26397 .30849 .27373 .30795 .26738 .29808 Mtetra
.546 .608 .867 r
.26738 .29808 .27373 .30795 .28355 .30719 .27721 .29731 Mtetra
.556 .614 .866 r
.27721 .29731 .28355 .30719 .29345 .3063 .28712 .2963 Mtetra
.563 .615 .862 r
.28712 .2963 .29345 .3063 .3034 .3053 .29709 .29512 Mtetra
.569 .614 .858 r
.29709 .29512 .3034 .3053 .31342 .30421 .30713 .2938 Mtetra
.573 .611 .853 r
.30713 .2938 .31342 .30421 .32349 .30303 .31723 .29237 Mtetra
.577 .609 .847 r
.31723 .29237 .32349 .30303 .33363 .30174 .32739 .29083 Mtetra
.581 .606 .842 r
.32739 .29083 .33363 .30174 .34383 .30032 .33761 .28917 Mtetra
.586 .603 .837 r
.33761 .28917 .34383 .30032 .3541 .29877 .34789 .28738 Mtetra
.59 .602 .832 r
.34789 .28738 .3541 .29877 .36442 .29705 .35823 .28545 Mtetra
.595 .601 .827 r
.35823 .28545 .36442 .29705 .37481 .29513 .36864 .28334 Mtetra
.601 .601 .823 r
.36864 .28334 .37481 .29513 .38527 .29299 .3791 .28102 Mtetra
.608 .601 .819 r
.3791 .28102 .38527 .29299 .39578 .29058 .38963 .27845 Mtetra
.615 .603 .815 r
.38963 .27845 .39578 .29058 .40636 .28787 .40022 .2756 Mtetra
.624 .605 .811 r
.40022 .2756 .40636 .28787 .417 .2848 .41087 .27243 Mtetra
.632 .608 .807 r
.41087 .27243 .417 .2848 .4277 .28135 .42158 .2689 Mtetra
.641 .611 .804 r
.42158 .2689 .4277 .28135 .43845 .27749 .43234 .26502 Mtetra
.649 .615 .802 r
.43234 .26502 .43845 .27749 .44926 .27324 .44315 .26076 Mtetra
.657 .62 .8 r
.44315 .26076 .44926 .27324 .46011 .26859 .45402 .25616 Mtetra
.665 .624 .799 r
.45402 .25616 .46011 .26859 .47101 .26359 .46492 .25123 Mtetra
.671 .629 .799 r
.46492 .25123 .47101 .26359 .48195 .25828 .47587 .24602 Mtetra
.677 .634 .799 r
.47587 .24602 .48195 .25828 .49292 .25269 .48686 .24054 Mtetra
.683 .639 .8 r
.48686 .24054 .49292 .25269 .50393 .24686 .49788 .23485 Mtetra
.687 .644 .801 r
.49788 .23485 .50393 .24686 .51497 .24084 .50894 .22898 Mtetra
.692 .649 .802 r
.50894 .22898 .51497 .24084 .52604 .23464 .52003 .22295 Mtetra
.696 .654 .804 r
.52003 .22295 .52604 .23464 .53714 .22829 .53114 .21678 Mtetra
.7 .659 .807 r
.53114 .21678 .53714 .22829 .54826 .2218 .54229 .21049 Mtetra
.703 .665 .809 r
.54229 .21049 .54826 .2218 .55942 .2152 .55346 .20408 Mtetra
.707 .671 .812 r
.55346 .20408 .55942 .2152 .57059 .20849 .56466 .19754 Mtetra
.712 .676 .814 r
.56466 .19754 .57059 .20849 .58179 .20168 .57589 .19086 Mtetra
.717 .682 .815 r
.57589 .19086 .58179 .20168 .59301 .19476 .58714 .18399 Mtetra
.723 .686 .814 r
.58714 .18399 .59301 .19476 .60426 .18768 .5984 .17686 Mtetra
.658 .658 .838 r
.5984 .17686 .60426 .18768 .61552 .18037 .60977 .17245 Mtetra
.663 .734 .902 r
.60977 .17245 .61552 .18037 .6269 .17597 .62119 .16826 Mtetra
.664 .741 .908 r
.62119 .16826 .6269 .17597 .63834 .1718 .63266 .16406 Mtetra
.63266 .16406 .63834 .1718 .64982 .16762 .64418 .15985 Mtetra
.64418 .15985 .64982 .16762 .66135 .16342 .65574 .15561 Mtetra
.65574 .15561 .66135 .16342 .67293 .1592 .66735 .15136 Mtetra
.66735 .15136 .67293 .1592 .68455 .15496 .67901 .14709 Mtetra
.67901 .14709 .68455 .15496 .69623 .15071 .69071 .1428 Mtetra
.69071 .1428 .69623 .15071 .70795 .14643 .70247 .1385 Mtetra
.70247 .1385 .70795 .14643 .71972 .14214 .71427 .13418 Mtetra
.71427 .13418 .71972 .14214 .73154 .13784 .72613 .12984 Mtetra
.72613 .12984 .73154 .13784 .74341 .13351 .73803 .12548 Mtetra
.73803 .12548 .74341 .13351 .75532 .12917 .74998 .1211 Mtetra
.74998 .1211 .75532 .12917 .76729 .1248 .76198 .1167 Mtetra
.12353 .34152 .13047 .34798 .14001 .34449 .13309 .338 Mtetra
.13309 .338 .14001 .34449 .14959 .34098 .14269 .33447 Mtetra
.14269 .33447 .14959 .34098 .15921 .33746 .15233 .33092 Mtetra
.15233 .33092 .15921 .33746 .16886 .33392 .162 .32736 Mtetra
.162 .32736 .16886 .33392 .17854 .33037 .17171 .32379 Mtetra
.17171 .32379 .17854 .33037 .18827 .32681 .18145 .3202 Mtetra
.18145 .3202 .18827 .32681 .19803 .32324 .19123 .3166 Mtetra
.19123 .3166 .19803 .32324 .20783 .31965 .20105 .31299 Mtetra
.20105 .31299 .20783 .31965 .21766 .31605 .21091 .30936 Mtetra
.21091 .30936 .21766 .31605 .22753 .31243 .2208 .30572 Mtetra
.2208 .30572 .22753 .31243 .23744 .3088 .23073 .30207 Mtetra
.23073 .30207 .23744 .3088 .24739 .30516 .2407 .2984 Mtetra
.2407 .2984 .24739 .30516 .25738 .3015 .25071 .29472 Mtetra
.25071 .29472 .25738 .3015 .26738 .29808 .26076 .29102 Mtetra
.663 .734 .902 r
.26076 .29102 .26738 .29808 .27721 .29731 .27085 .28731 Mtetra
.56 .614 .863 r
.27085 .28731 .27721 .29731 .28712 .2963 .28077 .28617 Mtetra
.566 .614 .86 r
.28077 .28617 .28712 .2963 .29709 .29512 .29075 .28491 Mtetra
.574 .617 .857 r
.29075 .28491 .29709 .29512 .30713 .2938 .30081 .28344 Mtetra
.58 .617 .853 r
.30081 .28344 .30713 .2938 .31723 .29237 .31093 .2818 Mtetra
.584 .615 .849 r
.31093 .2818 .31723 .29237 .32739 .29083 .32111 .28004 Mtetra
.589 .613 .844 r
.32111 .28004 .32739 .29083 .33761 .28917 .33135 .27814 Mtetra
.592 .61 .839 r
.33135 .27814 .33761 .28917 .34789 .28738 .34165 .27613 Mtetra
.597 .608 .834 r
.34165 .27613 .34789 .28738 .35823 .28545 .35201 .27397 Mtetra
.601 .607 .829 r
.35201 .27397 .35823 .28545 .36864 .28334 .36243 .27165 Mtetra
.606 .606 .825 r
.36243 .27165 .36864 .28334 .3791 .28102 .37291 .26914 Mtetra
.612 .606 .82 r
.37291 .26914 .3791 .28102 .38963 .27845 .38345 .2664 Mtetra
.619 .607 .816 r
.38345 .2664 .38963 .27845 .40022 .2756 .39405 .26341 Mtetra
.626 .608 .813 r
.39405 .26341 .40022 .2756 .41087 .27243 .40471 .26013 Mtetra
.634 .61 .809 r
.40471 .26013 .41087 .27243 .42158 .2689 .41543 .25653 Mtetra
.641 .614 .806 r
.41543 .25653 .42158 .2689 .43234 .26502 .4262 .25261 Mtetra
.649 .617 .804 r
.4262 .25261 .43234 .26502 .44315 .26076 .43702 .24837 Mtetra
.656 .621 .803 r
.43702 .24837 .44315 .26076 .45402 .25616 .4479 .24381 Mtetra
.663 .626 .802 r
.4479 .24381 .45402 .25616 .46492 .25123 .45881 .23896 Mtetra
.669 .63 .802 r
.45881 .23896 .46492 .25123 .47587 .24602 .46977 .23384 Mtetra
.675 .635 .802 r
.46977 .23384 .47587 .24602 .48686 .24054 .48077 .2285 Mtetra
.68 .64 .803 r
.48077 .2285 .48686 .24054 .49788 .23485 .49181 .22296 Mtetra
.684 .645 .805 r
.49181 .22296 .49788 .23485 .50894 .22898 .50288 .21725 Mtetra
.689 .65 .807 r
.50288 .21725 .50894 .22898 .52003 .22295 .51398 .21139 Mtetra
.693 .656 .809 r
.51398 .21139 .52003 .22295 .53114 .21678 .52512 .20539 Mtetra
.697 .661 .811 r
.52512 .20539 .53114 .21678 .54229 .21049 .53629 .19927 Mtetra
.701 .667 .813 r
.53629 .19927 .54229 .21049 .55346 .20408 .54748 .193 Mtetra
.706 .672 .815 r
.54748 .193 .55346 .20408 .56466 .19754 .5587 .18655 Mtetra
.711 .677 .815 r
.5587 .18655 .56466 .19754 .57589 .19086 .56995 .17989 Mtetra
.714 .679 .814 r
.56995 .17989 .57589 .19086 .58714 .18399 .58123 .17309 Mtetra
.651 .653 .839 r
.58123 .17309 .58714 .18399 .5984 .17686 .59259 .16891 Mtetra
.663 .734 .902 r
.59259 .16891 .5984 .17686 .60977 .17245 .60399 .16471 Mtetra
.664 .741 .908 r
.60399 .16471 .60977 .17245 .62119 .16826 .61544 .1605 Mtetra
.61544 .1605 .62119 .16826 .63266 .16406 .62694 .15627 Mtetra
.62694 .15627 .63266 .16406 .64418 .15985 .63849 .15202 Mtetra
.63849 .15202 .64418 .15985 .65574 .15561 .65009 .14775 Mtetra
.65009 .14775 .65574 .15561 .66735 .15136 .66173 .14347 Mtetra
.66173 .14347 .66735 .15136 .67901 .14709 .67342 .13916 Mtetra
.67342 .13916 .67901 .14709 .69071 .1428 .68516 .13484 Mtetra
.68516 .13484 .69071 .1428 .70247 .1385 .69695 .1305 Mtetra
.69695 .1305 .70247 .1385 .71427 .13418 .70879 .12615 Mtetra
.70879 .12615 .71427 .13418 .72613 .12984 .72067 .12177 Mtetra
.72067 .12177 .72613 .12984 .73803 .12548 .73261 .11738 Mtetra
.73261 .11738 .73803 .12548 .74998 .1211 .7446 .11297 Mtetra
.7446 .11297 .74998 .1211 .76198 .1167 .75663 .10854 Mtetra
.11654 .33501 .12353 .34152 .13309 .338 .12612 .33147 Mtetra
.12612 .33147 .13309 .338 .14269 .33447 .13574 .32791 Mtetra
.13574 .32791 .14269 .33447 .15233 .33092 .1454 .32434 Mtetra
.1454 .32434 .15233 .33092 .162 .32736 .15509 .32076 Mtetra
.15509 .32076 .162 .32736 .17171 .32379 .16482 .31716 Mtetra
.16482 .31716 .17171 .32379 .18145 .3202 .17459 .31355 Mtetra
.17459 .31355 .18145 .3202 .19123 .3166 .18439 .30992 Mtetra
.18439 .30992 .19123 .3166 .20105 .31299 .19423 .30628 Mtetra
.19423 .30628 .20105 .31299 .21091 .30936 .20411 .30263 Mtetra
.20411 .30263 .21091 .30936 .2208 .30572 .21402 .29896 Mtetra
.21402 .29896 .2208 .30572 .23073 .30207 .22398 .29528 Mtetra
.22398 .29528 .23073 .30207 .2407 .2984 .23397 .29159 Mtetra
.23397 .29159 .2407 .2984 .25071 .29472 .244 .28788 Mtetra
.244 .28788 .25071 .29472 .26076 .29102 .25407 .28416 Mtetra
.25407 .28416 .26076 .29102 .27085 .28731 .26418 .28042 Mtetra
.26418 .28042 .27085 .28731 .28077 .28617 .27433 .27667 Mtetra
.599 .645 .868 r
.27433 .27667 .28077 .28617 .29075 .28491 .28439 .27451 Mtetra
.574 .614 .854 r
.28439 .27451 .29075 .28491 .30081 .28344 .29445 .27301 Mtetra
.583 .618 .852 r
.29445 .27301 .30081 .28344 .31093 .2818 .30459 .27126 Mtetra
.59 .619 .849 r
.30459 .27126 .31093 .2818 .32111 .28004 .31478 .26931 Mtetra
.595 .618 .845 r
.31478 .26931 .32111 .28004 .33135 .27814 .32504 .26722 Mtetra
.599 .617 .84 r
.32504 .26722 .33135 .27814 .34165 .27613 .33537 .26498 Mtetra
.603 .615 .836 r
.33537 .26498 .34165 .27613 .35201 .27397 .34574 .2626 Mtetra
.607 .613 .831 r
.34574 .2626 .35201 .27397 .36243 .27165 .35618 .26006 Mtetra
.612 .611 .826 r
.35618 .26006 .36243 .27165 .37291 .26914 .36668 .25735 Mtetra
.617 .611 .822 r
.36668 .25735 .37291 .26914 .38345 .2664 .37724 .25444 Mtetra
.622 .611 .818 r
.37724 .25444 .38345 .2664 .39405 .26341 .38785 .25129 Mtetra
.629 .612 .814 r
.38785 .25129 .39405 .26341 .40471 .26013 .39852 .2479 Mtetra
.635 .613 .811 r
.39852 .2479 .40471 .26013 .41543 .25653 .40925 .24423 Mtetra
.642 .616 .808 r
.40925 .24423 .41543 .25653 .4262 .25261 .42003 .24028 Mtetra
.649 .619 .806 r
.42003 .24028 .4262 .25261 .43702 .24837 .43086 .23604 Mtetra
.655 .623 .805 r
.43086 .23604 .43702 .24837 .4479 .24381 .44175 .23153 Mtetra
.661 .627 .805 r
.44175 .23153 .4479 .24381 .45881 .23896 .45267 .22676 Mtetra
.667 .631 .805 r
.45267 .22676 .45881 .23896 .46977 .23384 .46364 .22176 Mtetra
.672 .636 .806 r
.46364 .22176 .46977 .23384 .48077 .2285 .47466 .21655 Mtetra
.677 .641 .807 r
.47466 .21655 .48077 .2285 .49181 .22296 .4857 .21117 Mtetra
.681 .647 .809 r
.4857 .21117 .49181 .22296 .50288 .21725 .49679 .20562 Mtetra
.686 .652 .811 r
.49679 .20562 .50288 .21725 .51398 .21139 .50791 .19992 Mtetra
.69 .657 .813 r
.50791 .19992 .51398 .21139 .52512 .20539 .51906 .19407 Mtetra
.694 .663 .814 r
.51906 .19407 .52512 .20539 .53629 .19927 .53025 .18806 Mtetra
.7 .667 .815 r
.53025 .18806 .53629 .19927 .54748 .193 .54147 .18184 Mtetra
.705 .672 .814 r
.54147 .18184 .54748 .193 .5587 .18655 .55271 .17537 Mtetra
.691 .665 .82 r
.55271 .17537 .5587 .18655 .56995 .17989 .56399 .16955 Mtetra
.654 .668 .851 r
.56399 .16955 .56995 .17989 .58123 .17309 .57534 .16536 Mtetra
.664 .741 .908 r
.57534 .16536 .58123 .17309 .59259 .16891 .58673 .16115 Mtetra
.58673 .16115 .59259 .16891 .60399 .16471 .59817 .15692 Mtetra
.59817 .15692 .60399 .16471 .61544 .1605 .60965 .15267 Mtetra
.60965 .15267 .61544 .1605 .62694 .15627 .62118 .14841 Mtetra
.62118 .14841 .62694 .15627 .63849 .15202 .63276 .14413 Mtetra
.63276 .14413 .63849 .15202 .65009 .14775 .64439 .13983 Mtetra
.64439 .13983 .65009 .14775 .66173 .14347 .65606 .13551 Mtetra
.65606 .13551 .66173 .14347 .67342 .13916 .66779 .13117 Mtetra
.66779 .13117 .67342 .13916 .68516 .13484 .67956 .12682 Mtetra
.67956 .12682 .68516 .13484 .69695 .1305 .69138 .12245 Mtetra
.69138 .12245 .69695 .1305 .70879 .12615 .70325 .11806 Mtetra
.70325 .11806 .70879 .12615 .72067 .12177 .71518 .11365 Mtetra
.71518 .11365 .72067 .12177 .73261 .11738 .72715 .10922 Mtetra
.72715 .10922 .73261 .11738 .7446 .11297 .73917 .10478 Mtetra
.73917 .10478 .7446 .11297 .75663 .10854 .75124 .10031 Mtetra
.1095 .32846 .11654 .33501 .12612 .33147 .11911 .32489 Mtetra
.11911 .32489 .12612 .33147 .13574 .32791 .12875 .32131 Mtetra
.12875 .32131 .13574 .32791 .1454 .32434 .13842 .31771 Mtetra
.13842 .31771 .1454 .32434 .15509 .32076 .14813 .3141 Mtetra
.14813 .3141 .15509 .32076 .16482 .31716 .15789 .31048 Mtetra
.15789 .31048 .16482 .31716 .17459 .31355 .16767 .30684 Mtetra
.16767 .30684 .17459 .31355 .18439 .30992 .1775 .30319 Mtetra
.1775 .30319 .18439 .30992 .19423 .30628 .18736 .29953 Mtetra
.18736 .29953 .19423 .30628 .20411 .30263 .19726 .29585 Mtetra
.19726 .29585 .20411 .30263 .21402 .29896 .2072 .29216 Mtetra
.2072 .29216 .21402 .29896 .22398 .29528 .21717 .28845 Mtetra
.21717 .28845 .22398 .29528 .23397 .29159 .22719 .28473 Mtetra
.22719 .28473 .23397 .29159 .244 .28788 .23724 .28099 Mtetra
.23724 .28099 .244 .28788 .25407 .28416 .24733 .27724 Mtetra
.24733 .27724 .25407 .28416 .26418 .28042 .25747 .27348 Mtetra
.25747 .27348 .26418 .28042 .27433 .27667 .26764 .2697 Mtetra
.26764 .2697 .27433 .27667 .28439 .27451 .27785 .26591 Mtetra
.65 .691 .874 r
.27785 .26591 .28439 .27451 .29445 .27301 .28808 .26234 Mtetra
.581 .613 .849 r
.28808 .26234 .29445 .27301 .30459 .27126 .29822 .2606 Mtetra
.591 .619 .848 r
.29822 .2606 .30459 .27126 .31478 .26931 .30843 .25858 Mtetra
.599 .621 .845 r
.30843 .25858 .31478 .26931 .32504 .26722 .31871 .25634 Mtetra
.604 .621 .841 r
.31871 .25634 .32504 .26722 .33537 .26498 .32905 .25392 Mtetra
.609 .62 .837 r
.32905 .25392 .33537 .26498 .34574 .2626 .33944 .25134 Mtetra
.613 .619 .833 r
.33944 .25134 .34574 .2626 .35618 .26006 .3499 .24859 Mtetra
.617 .617 .828 r
.3499 .24859 .35618 .26006 .36668 .25735 .36042 .24568 Mtetra
.622 .616 .824 r
.36042 .24568 .36668 .25735 .37724 .25444 .37099 .24259 Mtetra
.626 .616 .82 r
.37099 .24259 .37724 .25444 .38785 .25129 .38162 .2393 Mtetra
.632 .616 .816 r
.38162 .2393 .38785 .25129 .39852 .2479 .3923 .23578 Mtetra
.637 .617 .813 r
.3923 .23578 .39852 .2479 .40925 .24423 .40304 .23204 Mtetra
.643 .619 .811 r
.40304 .23204 .40925 .24423 .42003 .24028 .41383 .22806 Mtetra
.648 .622 .809 r
.41383 .22806 .42003 .24028 .43086 .23604 .42468 .22383 Mtetra
.654 .625 .808 r
.42468 .22383 .43086 .23604 .44175 .23153 .43557 .21937 Mtetra
.659 .629 .808 r
.43557 .21937 .44175 .23153 .45267 .22676 .4465 .21469 Mtetra
.664 .633 .809 r
.4465 .21469 .45267 .22676 .46364 .22176 .45748 .2098 Mtetra
.669 .638 .81 r
.45748 .2098 .46364 .22176 .47466 .21655 .46851 .20473 Mtetra
.674 .643 .811 r
.46851 .20473 .47466 .21655 .4857 .21117 .47957 .19949 Mtetra
.679 .648 .813 r
.47957 .19949 .4857 .21117 .49679 .20562 .49067 .19408 Mtetra
.683 .654 .814 r
.49067 .19408 .49679 .20562 .50791 .19992 .50181 .1885 Mtetra
.688 .659 .816 r
.50181 .1885 .50791 .19992 .51906 .19407 .51298 .18273 Mtetra
.694 .663 .815 r
.51298 .18273 .51906 .19407 .53025 .18806 .52419 .17673 Mtetra
.7 .667 .814 r
.52419 .17673 .53025 .18806 .54147 .18184 .53542 .17044 Mtetra
.655 .646 .829 r
.53542 .17044 .54147 .18184 .55271 .17537 .5467 .16601 Mtetra
.658 .693 .871 r
.5467 .16601 .55271 .17537 .56399 .16955 .55803 .1618 Mtetra
.664 .741 .908 r
.55803 .1618 .56399 .16955 .57534 .16536 .56941 .15757 Mtetra
.56941 .15757 .57534 .16536 .58673 .16115 .58083 .15333 Mtetra
.58083 .15333 .58673 .16115 .59817 .15692 .59229 .14906 Mtetra
.59229 .14906 .59817 .15692 .60965 .15267 .60381 .14479 Mtetra
.60381 .14479 .60965 .15267 .62118 .14841 .61537 .14049 Mtetra
.61537 .14049 .62118 .14841 .63276 .14413 .62699 .13617 Mtetra
.62699 .13617 .63276 .14413 .64439 .13983 .63865 .13184 Mtetra
.63865 .13184 .64439 .13983 .65606 .13551 .65035 .12749 Mtetra
.65035 .12749 .65606 .13551 .66779 .13117 .66211 .12312 Mtetra
.66211 .12312 .66779 .13117 .67956 .12682 .67392 .11873 Mtetra
.67392 .11873 .67956 .12682 .69138 .12245 .68578 .11433 Mtetra
.68578 .11433 .69138 .12245 .70325 .11806 .69768 .10991 Mtetra
.69768 .10991 .70325 .11806 .71518 .11365 .70964 .10546 Mtetra
.70964 .10546 .71518 .11365 .72715 .10922 .72164 .101 Mtetra
.72164 .101 .72715 .10922 .73917 .10478 .7337 .09652 Mtetra
.7337 .09652 .73917 .10478 .75124 .10031 .74581 .09202 Mtetra
.10242 .32186 .1095 .32846 .11911 .32489 .11204 .31827 Mtetra
.11204 .31827 .11911 .32489 .12875 .32131 .1217 .31466 Mtetra
.1217 .31466 .12875 .32131 .13842 .31771 .1314 .31104 Mtetra
.1314 .31104 .13842 .31771 .14813 .3141 .14113 .3074 Mtetra
.14113 .3074 .14813 .3141 .15789 .31048 .1509 .30376 Mtetra
.1509 .30376 .15789 .31048 .16767 .30684 .16071 .30009 Mtetra
.16071 .30009 .16767 .30684 .1775 .30319 .17056 .29642 Mtetra
.17056 .29642 .1775 .30319 .18736 .29953 .18044 .29273 Mtetra
.18044 .29273 .18736 .29953 .19726 .29585 .19036 .28902 Mtetra
.19036 .28902 .19726 .29585 .2072 .29216 .20032 .2853 Mtetra
.20032 .2853 .2072 .29216 .21717 .28845 .21032 .28157 Mtetra
.21032 .28157 .21717 .28845 .22719 .28473 .22036 .27782 Mtetra
.22036 .27782 .22719 .28473 .23724 .28099 .23043 .27406 Mtetra
.23043 .27406 .23724 .28099 .24733 .27724 .24055 .27028 Mtetra
.24055 .27028 .24733 .27724 .25747 .27348 .2507 .26649 Mtetra
.2507 .26649 .25747 .27348 .26764 .2697 .2609 .26268 Mtetra
.2609 .26268 .26764 .2697 .27785 .26591 .27113 .25886 Mtetra
.27113 .25886 .27785 .26591 .28808 .26234 .28141 .25503 Mtetra
.663 .734 .902 r
.28141 .25503 .28808 .26234 .29822 .2606 .29172 .25117 Mtetra
.642 .67 .861 r
.29172 .25117 .29822 .2606 .30843 .25858 .30205 .24772 Mtetra
.598 .619 .844 r
.30205 .24772 .30843 .25858 .31871 .25634 .31233 .24546 Mtetra
.606 .623 .842 r
.31233 .24546 .31871 .25634 .32905 .25392 .32269 .24293 Mtetra
.613 .625 .839 r
.32269 .24293 .32905 .25392 .33944 .25134 .3331 .2402 Mtetra
.618 .625 .835 r
.3331 .2402 .33944 .25134 .3499 .24859 .34358 .23729 Mtetra
.622 .624 .831 r
.34358 .23729 .3499 .24859 .36042 .24568 .35411 .2342 Mtetra
.626 .623 .827 r
.35411 .2342 .36042 .24568 .37099 .24259 .3647 .23094 Mtetra
.631 .622 .824 r
.3647 .23094 .37099 .24259 .38162 .2393 .37534 .2275 Mtetra
.635 .622 .82 r
.37534 .2275 .38162 .2393 .3923 .23578 .38604 .22388 Mtetra
.639 .623 .818 r
.38604 .22388 .3923 .23578 .40304 .23204 .39679 .22006 Mtetra
.644 .624 .815 r
.39679 .22006 .40304 .23204 .41383 .22806 .4076 .21604 Mtetra
.649 .626 .814 r
.4076 .21604 .41383 .22806 .42468 .22383 .41845 .21182 Mtetra
.653 .629 .813 r
.41845 .21182 .42468 .22383 .43557 .21937 .42935 .20741 Mtetra
.658 .633 .813 r
.42935 .20741 .43557 .21937 .4465 .21469 .4403 .20281 Mtetra
.663 .637 .814 r
.4403 .20281 .4465 .21469 .45748 .2098 .45129 .19803 Mtetra
.667 .642 .815 r
.45129 .19803 .45748 .2098 .46851 .20473 .46233 .19307 Mtetra
.672 .646 .816 r
.46233 .19307 .46851 .20473 .47957 .19949 .4734 .18793 Mtetra
.677 .651 .817 r
.4734 .18793 .47957 .19949 .49067 .19408 .48452 .18261 Mtetra
.682 .656 .817 r
.48452 .18261 .49067 .19408 .50181 .1885 .49567 .17707 Mtetra
.689 .66 .816 r
.49567 .17707 .50181 .1885 .51298 .18273 .50686 .17126 Mtetra
.659 .646 .826 r
.50686 .17126 .51298 .18273 .52419 .17673 .51809 .16665 Mtetra
.655 .675 .857 r
.51809 .16665 .52419 .17673 .53542 .17044 .52935 .16244 Mtetra
.663 .734 .902 r
.52935 .16244 .53542 .17044 .5467 .16601 .54066 .15822 Mtetra
.664 .741 .908 r
.54066 .15822 .5467 .16601 .55803 .1618 .55202 .15398 Mtetra
.55202 .15398 .55803 .1618 .56941 .15757 .56343 .14972 Mtetra
.56343 .14972 .56941 .15757 .58083 .15333 .57488 .14544 Mtetra
.57488 .14544 .58083 .15333 .59229 .14906 .58638 .14115 Mtetra
.58638 .14115 .59229 .14906 .60381 .14479 .59793 .13684 Mtetra
.59793 .13684 .60381 .14479 .61537 .14049 .60952 .13251 Mtetra
.60952 .13251 .61537 .14049 .62699 .13617 .62117 .12816 Mtetra
.62117 .12816 .62699 .13617 .63865 .13184 .63286 .1238 Mtetra
.63286 .1238 .63865 .13184 .65035 .12749 .6446 .11941 Mtetra
.6446 .11941 .65035 .12749 .66211 .12312 .65639 .11501 Mtetra
.65639 .11501 .66211 .12312 .67392 .11873 .66823 .11059 Mtetra
.66823 .11059 .67392 .11873 .68578 .11433 .68012 .10615 Mtetra
.68012 .10615 .68578 .11433 .69768 .10991 .69206 .10169 Mtetra
.69206 .10169 .69768 .10991 .70964 .10546 .70406 .09721 Mtetra
.70406 .09721 .70964 .10546 .72164 .101 .7161 .09271 Mtetra
.7161 .09271 .72164 .101 .7337 .09652 .72819 .0882 Mtetra
.72819 .0882 .7337 .09652 .74581 .09202 .74034 .08366 Mtetra
.09528 .31522 .10242 .32186 .11204 .31827 .10492 .3116 Mtetra
.10492 .3116 .11204 .31827 .1217 .31466 .1146 .30796 Mtetra
.1146 .30796 .1217 .31466 .1314 .31104 .12432 .30432 Mtetra
.12432 .30432 .1314 .31104 .14113 .3074 .13408 .30066 Mtetra
.13408 .30066 .14113 .3074 .1509 .30376 .14387 .29698 Mtetra
.14387 .29698 .1509 .30376 .16071 .30009 .1537 .2933 Mtetra
.1537 .2933 .16071 .30009 .17056 .29642 .16357 .28959 Mtetra
.16357 .28959 .17056 .29642 .18044 .29273 .17347 .28588 Mtetra
.17347 .28588 .18044 .29273 .19036 .28902 .18341 .28214 Mtetra
.18341 .28214 .19036 .28902 .20032 .2853 .1934 .2784 Mtetra
.1934 .2784 .20032 .2853 .21032 .28157 .20342 .27464 Mtetra
.20342 .27464 .21032 .28157 .22036 .27782 .21348 .27086 Mtetra
.21348 .27086 .22036 .27782 .23043 .27406 .22358 .26707 Mtetra
.22358 .26707 .23043 .27406 .24055 .27028 .23372 .26327 Mtetra
.23372 .26327 .24055 .27028 .2507 .26649 .24389 .25945 Mtetra
.24389 .25945 .2507 .26649 .2609 .26268 .25411 .25562 Mtetra
.25411 .25562 .2609 .26268 .27113 .25886 .26437 .25177 Mtetra
.26437 .25177 .27113 .25886 .28141 .25503 .27467 .2479 Mtetra
.27467 .2479 .28141 .25503 .29172 .25117 .28501 .24402 Mtetra
.28501 .24402 .29172 .25117 .30205 .24772 .29539 .24013 Mtetra
.663 .728 .898 r
.29539 .24013 .30205 .24772 .31233 .24546 .30581 .23622 Mtetra
.656 .683 .863 r
.30581 .23622 .31233 .24546 .32269 .24293 .31627 .23229 Mtetra
.624 .638 .844 r
.31627 .23229 .32269 .24293 .3331 .2402 .32672 .22922 Mtetra
.62 .63 .839 r
.32672 .22922 .3331 .2402 .34358 .23729 .33721 .22621 Mtetra
.626 .631 .836 r
.33721 .22621 .34358 .23729 .35411 .2342 .34776 .223 Mtetra
.63 .631 .833 r
.34776 .223 .35411 .2342 .3647 .23094 .35836 .21961 Mtetra
.635 .631 .83 r
.35836 .21961 .3647 .23094 .37534 .2275 .36902 .21606 Mtetra
.638 .631 .827 r
.36902 .21606 .37534 .2275 .38604 .22388 .37974 .21233 Mtetra
.642 .632 .825 r
.37974 .21233 .38604 .22388 .39679 .22006 .3905 .20845 Mtetra
.646 .633 .823 r
.3905 .20845 .39679 .22006 .4076 .21604 .40132 .2044 Mtetra
.65 .635 .822 r
.40132 .2044 .4076 .21604 .41845 .21182 .41218 .20018 Mtetra
.654 .637 .821 r
.41218 .20018 .41845 .21182 .42935 .20741 .4231 .1958 Mtetra
.658 .64 .821 r
.4231 .1958 .42935 .20741 .4403 .20281 .43405 .19125 Mtetra
.663 .644 .821 r
.43405 .19125 .4403 .20281 .45129 .19803 .44506 .18654 Mtetra
.667 .648 .821 r
.44506 .18654 .45129 .19803 .46233 .19307 .45611 .18163 Mtetra
.672 .652 .821 r
.45611 .18163 .46233 .19307 .4734 .18793 .4672 .17653 Mtetra
.671 .652 .823 r
.4672 .17653 .4734 .18793 .48452 .18261 .47833 .17148 Mtetra
.65 .649 .836 r
.47833 .17148 .48452 .18261 .49567 .17707 .48949 .1673 Mtetra
.656 .683 .863 r
.48949 .1673 .49567 .17707 .50686 .17126 .50069 .16309 Mtetra
.663 .728 .898 r
.50069 .16309 .50686 .17126 .51809 .16665 .51194 .15887 Mtetra
.664 .741 .908 r
.51194 .15887 .51809 .16665 .52935 .16244 .52324 .15463 Mtetra
.52324 .15463 .52935 .16244 .54066 .15822 .53458 .15038 Mtetra
.53458 .15038 .54066 .15822 .55202 .15398 .54597 .1461 Mtetra
.54597 .1461 .55202 .15398 .56343 .14972 .5574 .14181 Mtetra
.5574 .14181 .56343 .14972 .57488 .14544 .56889 .1375 Mtetra
.56889 .1375 .57488 .14544 .58638 .14115 .58042 .13318 Mtetra
.58042 .13318 .58638 .14115 .59793 .13684 .592 .12883 Mtetra
.592 .12883 .59793 .13684 .60952 .13251 .60363 .12447 Mtetra
.60363 .12447 .60952 .13251 .62117 .12816 .6153 .12009 Mtetra
.6153 .12009 .62117 .12816 .63286 .1238 .62703 .11569 Mtetra
.62703 .11569 .63286 .1238 .6446 .11941 .6388 .11127 Mtetra
.6388 .11127 .6446 .11941 .65639 .11501 .65063 .10683 Mtetra
.65063 .10683 .65639 .11501 .66823 .11059 .6625 .10238 Mtetra
.6625 .10238 .66823 .11059 .68012 .10615 .67443 .0979 Mtetra
.67443 .0979 .68012 .10615 .69206 .10169 .6864 .09341 Mtetra
.6864 .09341 .69206 .10169 .70406 .09721 .69843 .08889 Mtetra
.69843 .08889 .70406 .09721 .7161 .09271 .71051 .08436 Mtetra
.71051 .08436 .7161 .09271 .72819 .0882 .72264 .07981 Mtetra
.72264 .07981 .72819 .0882 .74034 .08366 .73482 .07524 Mtetra
.08809 .30852 .09528 .31522 .10492 .3116 .09776 .30488 Mtetra
.09776 .30488 .10492 .3116 .1146 .30796 .10746 .30122 Mtetra
.10746 .30122 .1146 .30796 .12432 .30432 .1172 .29755 Mtetra
.1172 .29755 .12432 .30432 .13408 .30066 .12697 .29386 Mtetra
.12697 .29386 .13408 .30066 .14387 .29698 .13679 .29016 Mtetra
.13679 .29016 .14387 .29698 .1537 .2933 .14664 .28645 Mtetra
.14664 .28645 .1537 .2933 .16357 .28959 .15653 .28272 Mtetra
.15653 .28272 .16357 .28959 .17347 .28588 .16645 .27898 Mtetra
.16645 .27898 .17347 .28588 .18341 .28214 .17642 .27522 Mtetra
.17642 .27522 .18341 .28214 .1934 .2784 .18642 .27145 Mtetra
.18642 .27145 .1934 .2784 .20342 .27464 .19647 .26766 Mtetra
.19647 .26766 .20342 .27464 .21348 .27086 .20655 .26386 Mtetra
.20655 .26386 .21348 .27086 .22358 .26707 .21667 .26004 Mtetra
.21667 .26004 .22358 .26707 .23372 .26327 .22683 .25621 Mtetra
.22683 .25621 .23372 .26327 .24389 .25945 .23703 .25236 Mtetra
.23703 .25236 .24389 .25945 .25411 .25562 .24728 .2485 Mtetra
.24728 .2485 .25411 .25562 .26437 .25177 .25756 .24462 Mtetra
.25756 .24462 .26437 .25177 .27467 .2479 .26788 .24073 Mtetra
.26788 .24073 .27467 .2479 .28501 .24402 .27824 .23682 Mtetra
.27824 .23682 .28501 .24402 .29539 .24013 .28865 .2329 Mtetra
.28865 .2329 .29539 .24013 .30581 .23622 .29909 .22896 Mtetra
.29909 .22896 .30581 .23622 .31627 .23229 .30958 .225 Mtetra
.30958 .225 .31627 .23229 .32672 .22922 .32011 .22103 Mtetra
.661 .715 .888 r
.32011 .22103 .32672 .22922 .33721 .22621 .33068 .21705 Mtetra
.657 .689 .868 r
.33068 .21705 .33721 .22621 .34776 .223 .34129 .21305 Mtetra
.654 .669 .852 r
.34129 .21305 .34776 .223 .35836 .21961 .35195 .20903 Mtetra
.646 .653 .842 r
.35195 .20903 .35836 .21961 .36902 .21606 .36264 .20516 Mtetra
.642 .645 .838 r
.36264 .20516 .36902 .21606 .37974 .21233 .37337 .20137 Mtetra
.646 .646 .836 r
.37337 .20137 .37974 .21233 .3905 .20845 .38415 .19744 Mtetra
.649 .647 .835 r
.38415 .19744 .3905 .20845 .40132 .2044 .39498 .19335 Mtetra
.653 .649 .833 r
.39498 .19335 .40132 .2044 .41218 .20018 .40586 .18912 Mtetra
.657 .651 .833 r
.40586 .18912 .41218 .20018 .4231 .1958 .41679 .18474 Mtetra
.654 .65 .834 r
.41679 .18474 .4231 .1958 .43405 .19125 .42775 .18044 Mtetra
.651 .655 .841 r
.42775 .18044 .43405 .19125 .44506 .18654 .43876 .17629 Mtetra
.654 .669 .852 r
.43876 .17629 .44506 .18654 .45611 .18163 .44981 .17213 Mtetra
.657 .689 .868 r
.44981 .17213 .45611 .18163 .4672 .17653 .46091 .16794 Mtetra
.661 .715 .888 r
.46091 .16794 .4672 .17653 .47833 .17148 .47205 .16374 Mtetra
.664 .741 .908 r
.47205 .16374 .47833 .17148 .48949 .1673 .48323 .15952 Mtetra
.48323 .15952 .48949 .1673 .50069 .16309 .49447 .15529 Mtetra
.49447 .15529 .50069 .16309 .51194 .15887 .50575 .15103 Mtetra
.50575 .15103 .51194 .15887 .52324 .15463 .51707 .14676 Mtetra
.51707 .14676 .52324 .15463 .53458 .15038 .52845 .14247 Mtetra
.52845 .14247 .53458 .15038 .54597 .1461 .53987 .13817 Mtetra
.53987 .13817 .54597 .1461 .5574 .14181 .55133 .13384 Mtetra
.55133 .13384 .5574 .14181 .56889 .1375 .56285 .1295 Mtetra
.56285 .1295 .56889 .1375 .58042 .13318 .57441 .12514 Mtetra
.57441 .12514 .58042 .13318 .592 .12883 .58602 .12076 Mtetra
.58602 .12076 .592 .12883 .60363 .12447 .59769 .11636 Mtetra
.59769 .11636 .60363 .12447 .6153 .12009 .60939 .11195 Mtetra
.60939 .11195 .6153 .12009 .62703 .11569 .62115 .10752 Mtetra
.62115 .10752 .62703 .11569 .6388 .11127 .63296 .10306 Mtetra
.63296 .10306 .6388 .11127 .65063 .10683 .64482 .09859 Mtetra
.64482 .09859 .65063 .10683 .6625 .10238 .65673 .0941 Mtetra
.65673 .0941 .6625 .10238 .67443 .0979 .66869 .08959 Mtetra
.66869 .08959 .67443 .0979 .6864 .09341 .6807 .08506 Mtetra
.6807 .08506 .6864 .09341 .69843 .08889 .69276 .08051 Mtetra
.69276 .08051 .69843 .08889 .71051 .08436 .70487 .07595 Mtetra
.70487 .07595 .71051 .08436 .72264 .07981 .71704 .07136 Mtetra
.71704 .07136 .72264 .07981 .73482 .07524 .72926 .06675 Mtetra
.08086 .30179 .08809 .30852 .09776 .30488 .09054 .29812 Mtetra
.09054 .29812 .09776 .30488 .10746 .30122 .10026 .29443 Mtetra
.10026 .29443 .10746 .30122 .1172 .29755 .11002 .29073 Mtetra
.11002 .29073 .1172 .29755 .12697 .29386 .11982 .28702 Mtetra
.11982 .28702 .12697 .29386 .13679 .29016 .12965 .28329 Mtetra
.12965 .28329 .13679 .29016 .14664 .28645 .13952 .27955 Mtetra
.13952 .27955 .14664 .28645 .15653 .28272 .14943 .2758 Mtetra
.14943 .2758 .15653 .28272 .16645 .27898 .15938 .27203 Mtetra
.15938 .27203 .16645 .27898 .17642 .27522 .16937 .26824 Mtetra
.16937 .26824 .17642 .27522 .18642 .27145 .1794 .26444 Mtetra
.1794 .26444 .18642 .27145 .19647 .26766 .18946 .26063 Mtetra
.18946 .26063 .19647 .26766 .20655 .26386 .19957 .2568 Mtetra
.19957 .2568 .20655 .26386 .21667 .26004 .20971 .25295 Mtetra
.20971 .25295 .21667 .26004 .22683 .25621 .2199 .24909 Mtetra
.2199 .24909 .22683 .25621 .23703 .25236 .23012 .24522 Mtetra
.23012 .24522 .23703 .25236 .24728 .2485 .24039 .24133 Mtetra
.24039 .24133 .24728 .2485 .25756 .24462 .2507 .23742 Mtetra
.2507 .23742 .25756 .24462 .26788 .24073 .26104 .2335 Mtetra
.26104 .2335 .26788 .24073 .27824 .23682 .27143 .22957 Mtetra
.27143 .22957 .27824 .23682 .28865 .2329 .28186 .22561 Mtetra
.28186 .22561 .28865 .2329 .29909 .22896 .29233 .22165 Mtetra
.29233 .22165 .29909 .22896 .30958 .225 .30284 .21766 Mtetra
.30284 .21766 .30958 .225 .32011 .22103 .3134 .21366 Mtetra
.3134 .21366 .32011 .22103 .33068 .21705 .32399 .20965 Mtetra
.32399 .20965 .33068 .21705 .34129 .21305 .33463 .20562 Mtetra
.33463 .20562 .34129 .21305 .35195 .20903 .34531 .20157 Mtetra
.34531 .20157 .35195 .20903 .36264 .20516 .35604 .1975 Mtetra
.663 .736 .904 r
.35604 .1975 .36264 .20516 .37337 .20137 .36681 .19342 Mtetra
.662 .728 .898 r
.36681 .19342 .37337 .20137 .38415 .19744 .37762 .18932 Mtetra
.662 .724 .895 r
.37762 .18932 .38415 .19744 .39498 .19335 .38848 .18521 Mtetra
.38848 .18521 .39498 .19335 .40586 .18912 .39938 .18108 Mtetra
.662 .728 .898 r
.39938 .18108 .40586 .18912 .41679 .18474 .41032 .17693 Mtetra
.663 .736 .904 r
.41032 .17693 .41679 .18474 .42775 .18044 .42131 .17277 Mtetra
.664 .741 .908 r
.42131 .17277 .42775 .18044 .43876 .17629 .43234 .16859 Mtetra
.43234 .16859 .43876 .17629 .44981 .17213 .44342 .16439 Mtetra
.44342 .16439 .44981 .17213 .46091 .16794 .45455 .16017 Mtetra
.45455 .16017 .46091 .16794 .47205 .16374 .46572 .15594 Mtetra
.46572 .15594 .47205 .16374 .48323 .15952 .47693 .15169 Mtetra
.47693 .15169 .48323 .15952 .49447 .15529 .4882 .14742 Mtetra
.4882 .14742 .49447 .15529 .50575 .15103 .49951 .14313 Mtetra
.49951 .14313 .50575 .15103 .51707 .14676 .51086 .13883 Mtetra
.51086 .13883 .51707 .14676 .52845 .14247 .52227 .13451 Mtetra
.52227 .13451 .52845 .14247 .53987 .13817 .53372 .13017 Mtetra
.53372 .13017 .53987 .13817 .55133 .13384 .54522 .12581 Mtetra
.54522 .12581 .55133 .13384 .56285 .1295 .55676 .12144 Mtetra
.55676 .12144 .56285 .1295 .57441 .12514 .56836 .11704 Mtetra
.56836 .11704 .57441 .12514 .58602 .12076 .58 .11263 Mtetra
.58 .11263 .58602 .12076 .59769 .11636 .5917 .1082 Mtetra
.5917 .1082 .59769 .11636 .60939 .11195 .60344 .10375 Mtetra
.60344 .10375 .60939 .11195 .62115 .10752 .61523 .09928 Mtetra
.61523 .09928 .62115 .10752 .63296 .10306 .62707 .09479 Mtetra
.62707 .09479 .63296 .10306 .64482 .09859 .63897 .09029 Mtetra
.63897 .09029 .64482 .09859 .65673 .0941 .65091 .08576 Mtetra
.65091 .08576 .65673 .0941 .66869 .08959 .6629 .08121 Mtetra
.6629 .08121 .66869 .08959 .6807 .08506 .67495 .07665 Mtetra
.67495 .07665 .6807 .08506 .69276 .08051 .68705 .07207 Mtetra
.68705 .07207 .69276 .08051 .70487 .07595 .69919 .06746 Mtetra
.69919 .06746 .70487 .07595 .71704 .07136 .7114 .06284 Mtetra
.7114 .06284 .71704 .07136 .72926 .06675 .72365 .05819 Mtetra
.07357 .295 .08086 .30179 .09054 .29812 .08327 .2913 Mtetra
.08327 .2913 .09054 .29812 .10026 .29443 .09301 .28759 Mtetra
.09301 .28759 .10026 .29443 .11002 .29073 .10279 .28387 Mtetra
.10279 .28387 .11002 .29073 .11982 .28702 .11261 .28013 Mtetra
.11261 .28013 .11982 .28702 .12965 .28329 .12247 .27638 Mtetra
.12247 .27638 .12965 .28329 .13952 .27955 .13236 .27261 Mtetra
.13236 .27261 .13952 .27955 .14943 .2758 .14229 .26883 Mtetra
.14229 .26883 .14943 .2758 .15938 .27203 .15226 .26503 Mtetra
.15226 .26503 .15938 .27203 .16937 .26824 .16227 .26122 Mtetra
.16227 .26122 .16937 .26824 .1794 .26444 .17232 .25739 Mtetra
.17232 .25739 .1794 .26444 .18946 .26063 .18241 .25355 Mtetra
.18241 .25355 .18946 .26063 .19957 .2568 .19254 .24969 Mtetra
.19254 .24969 .19957 .2568 .20971 .25295 .20271 .24582 Mtetra
.20271 .24582 .20971 .25295 .2199 .24909 .21292 .24193 Mtetra
.21292 .24193 .2199 .24909 .23012 .24522 .22316 .23803 Mtetra
.22316 .23803 .23012 .24522 .24039 .24133 .23345 .23411 Mtetra
.23345 .23411 .24039 .24133 .2507 .23742 .24378 .23017 Mtetra
.24378 .23017 .2507 .23742 .26104 .2335 .25415 .22622 Mtetra
.25415 .22622 .26104 .2335 .27143 .22957 .26457 .22226 Mtetra
.26457 .22226 .27143 .22957 .28186 .22561 .27502 .21828 Mtetra
.27502 .21828 .28186 .22561 .29233 .22165 .28552 .21428 Mtetra
.28552 .21428 .29233 .22165 .30284 .21766 .29605 .21027 Mtetra
.29605 .21027 .30284 .21766 .3134 .21366 .30663 .20624 Mtetra
.30663 .20624 .3134 .21366 .32399 .20965 .31726 .20219 Mtetra
.31726 .20219 .32399 .20965 .33463 .20562 .32792 .19813 Mtetra
.32792 .19813 .33463 .20562 .34531 .20157 .33863 .19405 Mtetra
.33863 .19405 .34531 .20157 .35604 .1975 .34938 .18996 Mtetra
.34938 .18996 .35604 .1975 .36681 .19342 .36018 .18584 Mtetra
.36018 .18584 .36681 .19342 .37762 .18932 .37102 .18172 Mtetra
.37102 .18172 .37762 .18932 .38848 .18521 .3819 .17757 Mtetra
.3819 .17757 .38848 .18521 .39938 .18108 .39283 .17341 Mtetra
.39283 .17341 .39938 .18108 .41032 .17693 .4038 .16923 Mtetra
.4038 .16923 .41032 .17693 .42131 .17277 .41482 .16504 Mtetra
.41482 .16504 .42131 .17277 .43234 .16859 .42588 .16082 Mtetra
.42588 .16082 .43234 .16859 .44342 .16439 .43699 .15659 Mtetra
.43699 .15659 .44342 .16439 .45455 .16017 .44814 .15234 Mtetra
.44814 .15234 .45455 .16017 .46572 .15594 .45934 .14808 Mtetra
.45934 .14808 .46572 .15594 .47693 .15169 .47059 .1438 Mtetra
.47059 .1438 .47693 .15169 .4882 .14742 .48188 .13949 Mtetra
.48188 .13949 .4882 .14742 .49951 .14313 .49322 .13518 Mtetra
.49322 .13518 .49951 .14313 .51086 .13883 .50461 .13084 Mtetra
.50461 .13084 .51086 .13883 .52227 .13451 .51604 .12648 Mtetra
.51604 .12648 .52227 .13451 .53372 .13017 .52752 .12211 Mtetra
.52752 .12211 .53372 .13017 .54522 .12581 .53905 .11772 Mtetra
.53905 .11772 .54522 .12581 .55676 .12144 .55063 .11331 Mtetra
.55063 .11331 .55676 .12144 .56836 .11704 .56226 .10888 Mtetra
.56226 .10888 .56836 .11704 .58 .11263 .57394 .10443 Mtetra
.57394 .10443 .58 .11263 .5917 .1082 .58566 .09997 Mtetra
.58566 .09997 .5917 .1082 .60344 .10375 .59744 .09548 Mtetra
.59744 .09548 .60344 .10375 .61523 .09928 .60926 .09098 Mtetra
.60926 .09098 .61523 .09928 .62707 .09479 .62114 .08646 Mtetra
.62114 .08646 .62707 .09479 .63897 .09029 .63307 .08191 Mtetra
.63307 .08191 .63897 .09029 .65091 .08576 .64504 .07735 Mtetra
.64504 .07735 .65091 .08576 .6629 .08121 .65707 .07277 Mtetra
.65707 .07277 .6629 .08121 .67495 .07665 .66915 .06817 Mtetra
.66915 .06817 .67495 .07665 .68705 .07207 .68129 .06355 Mtetra
.68129 .06355 .68705 .07207 .69919 .06746 .69347 .05891 Mtetra
.69347 .05891 .69919 .06746 .7114 .06284 .70571 .05425 Mtetra
.70571 .05425 .7114 .06284 .72365 .05819 .718 .04957 Mtetra
.06623 .28816 .07357 .295 .08327 .2913 .07595 .28444 Mtetra
.07595 .28444 .08327 .2913 .09301 .28759 .08572 .28071 Mtetra
.08572 .28071 .09301 .28759 .10279 .28387 .09552 .27695 Mtetra
.09552 .27695 .10279 .28387 .11261 .28013 .10535 .27319 Mtetra
.10535 .27319 .11261 .28013 .12247 .27638 .11523 .26941 Mtetra
.11523 .26941 .12247 .27638 .13236 .27261 .12515 .26561 Mtetra
.12515 .26561 .13236 .27261 .14229 .26883 .1351 .2618 Mtetra
.1351 .2618 .14229 .26883 .15226 .26503 .14509 .25798 Mtetra
.14509 .25798 .15226 .26503 .16227 .26122 .15513 .25414 Mtetra
.15513 .25414 .16227 .26122 .17232 .25739 .1652 .25028 Mtetra
.1652 .25028 .17232 .25739 .18241 .25355 .17531 .24641 Mtetra
.17531 .24641 .18241 .25355 .19254 .24969 .18546 .24253 Mtetra
.18546 .24253 .19254 .24969 .20271 .24582 .19565 .23863 Mtetra
.19565 .23863 .20271 .24582 .21292 .24193 .20588 .23471 Mtetra
.20588 .23471 .21292 .24193 .22316 .23803 .21615 .23078 Mtetra
.21615 .23078 .22316 .23803 .23345 .23411 .22647 .22683 Mtetra
.22647 .22683 .23345 .23411 .24378 .23017 .23682 .22287 Mtetra
.23682 .22287 .24378 .23017 .25415 .22622 .24722 .21889 Mtetra
.24722 .21889 .25415 .22622 .26457 .22226 .25765 .2149 Mtetra
.25765 .2149 .26457 .22226 .27502 .21828 .26813 .21088 Mtetra
.26813 .21088 .27502 .21828 .28552 .21428 .27865 .20686 Mtetra
.27865 .20686 .28552 .21428 .29605 .21027 .28921 .20281 Mtetra
.28921 .20281 .29605 .21027 .30663 .20624 .29982 .19876 Mtetra
.29982 .19876 .30663 .20624 .31726 .20219 .31047 .19468 Mtetra
.31047 .19468 .31726 .20219 .32792 .19813 .32116 .19059 Mtetra
.32116 .19059 .32792 .19813 .33863 .19405 .33189 .18648 Mtetra
.33189 .18648 .33863 .19405 .34938 .18996 .34267 .18235 Mtetra
.34267 .18235 .34938 .18996 .36018 .18584 .35349 .17821 Mtetra
.35349 .17821 .36018 .18584 .37102 .18172 .36436 .17405 Mtetra
.36436 .17405 .37102 .18172 .3819 .17757 .37527 .16988 Mtetra
.37527 .16988 .3819 .17757 .39283 .17341 .38623 .16568 Mtetra
.38623 .16568 .39283 .17341 .4038 .16923 .39723 .16147 Mtetra
.39723 .16147 .4038 .16923 .41482 .16504 .40827 .15724 Mtetra
.40827 .15724 .41482 .16504 .42588 .16082 .41936 .153 Mtetra
.41936 .153 .42588 .16082 .43699 .15659 .4305 .14874 Mtetra
.4305 .14874 .43699 .15659 .44814 .15234 .44168 .14446 Mtetra
.44168 .14446 .44814 .15234 .45934 .14808 .45291 .14016 Mtetra
.45291 .14016 .45934 .14808 .47059 .1438 .46419 .13584 Mtetra
.46419 .13584 .47059 .1438 .48188 .13949 .47551 .13151 Mtetra
.47551 .13151 .48188 .13949 .49322 .13518 .48688 .12716 Mtetra
.48688 .12716 .49322 .13518 .50461 .13084 .4983 .12279 Mtetra
.4983 .12279 .50461 .13084 .51604 .12648 .50977 .1184 Mtetra
.50977 .1184 .51604 .12648 .52752 .12211 .52128 .11399 Mtetra
.52128 .11399 .52752 .12211 .53905 .11772 .53284 .10956 Mtetra
.53284 .10956 .53905 .11772 .55063 .11331 .54445 .10512 Mtetra
.54445 .10512 .55063 .11331 .56226 .10888 .55611 .10066 Mtetra
.55611 .10066 .56226 .10888 .57394 .10443 .56782 .09618 Mtetra
.56782 .09618 .57394 .10443 .58566 .09997 .57958 .09167 Mtetra
.57958 .09167 .58566 .09997 .59744 .09548 .59139 .08715 Mtetra
.59139 .08715 .59744 .09548 .60926 .09098 .60325 .08261 Mtetra
.60325 .08261 .60926 .09098 .62114 .08646 .61516 .07806 Mtetra
.61516 .07806 .62114 .08646 .63307 .08191 .62712 .07348 Mtetra
.62712 .07348 .63307 .08191 .64504 .07735 .63913 .06888 Mtetra
.63913 .06888 .64504 .07735 .65707 .07277 .6512 .06426 Mtetra
.6512 .06426 .65707 .07277 .66915 .06817 .66331 .05963 Mtetra
.66331 .05963 .66915 .06817 .68129 .06355 .67548 .05497 Mtetra
.67548 .05497 .68129 .06355 .69347 .05891 .6877 .05029 Mtetra
.6877 .05029 .69347 .05891 .70571 .05425 .69997 .04559 Mtetra
.69997 .04559 .70571 .05425 .718 .04957 .7123 .04087 Mtetra
.05883 .28128 .06623 .28816 .07595 .28444 .06858 .27753 Mtetra
.06858 .27753 .07595 .28444 .08572 .28071 .07836 .27377 Mtetra
.07836 .27377 .08572 .28071 .09552 .27695 .08818 .26999 Mtetra
.08818 .26999 .09552 .27695 .10535 .27319 .09804 .2662 Mtetra
.09804 .2662 .10535 .27319 .11523 .26941 .10794 .26239 Mtetra
.10794 .26239 .11523 .26941 .12515 .26561 .11788 .25857 Mtetra
.11788 .25857 .12515 .26561 .1351 .2618 .12786 .25473 Mtetra
.12786 .25473 .1351 .2618 .14509 .25798 .13787 .25088 Mtetra
.13787 .25088 .14509 .25798 .15513 .25414 .14792 .24701 Mtetra
.14792 .24701 .15513 .25414 .1652 .25028 .15802 .24313 Mtetra
.15802 .24313 .1652 .25028 .17531 .24641 .16815 .23923 Mtetra
.16815 .23923 .17531 .24641 .18546 .24253 .17833 .23531 Mtetra
.17833 .23531 .18546 .24253 .19565 .23863 .18854 .23139 Mtetra
.18854 .23139 .19565 .23863 .20588 .23471 .1988 .22744 Mtetra
.1988 .22744 .20588 .23471 .21615 .23078 .20909 .22348 Mtetra
.20909 .22348 .21615 .23078 .22647 .22683 .21943 .2195 Mtetra
.21943 .2195 .22647 .22683 .23682 .22287 .22981 .21551 Mtetra
.22981 .21551 .23682 .22287 .24722 .21889 .24023 .2115 Mtetra
.24023 .2115 .24722 .21889 .25765 .2149 .25069 .20748 Mtetra
.25069 .20748 .25765 .2149 .26813 .21088 .26119 .20344 Mtetra
.26119 .20344 .26813 .21088 .27865 .20686 .27174 .19938 Mtetra
.27174 .19938 .27865 .20686 .28921 .20281 .28232 .19531 Mtetra
.28232 .19531 .28921 .20281 .29982 .19876 .29296 .19122 Mtetra
.29296 .19122 .29982 .19876 .31047 .19468 .30363 .18711 Mtetra
.30363 .18711 .31047 .19468 .32116 .19059 .31435 .18299 Mtetra
.31435 .18299 .32116 .19059 .33189 .18648 .32511 .17885 Mtetra
.32511 .17885 .33189 .18648 .34267 .18235 .33591 .17469 Mtetra
.33591 .17469 .34267 .18235 .35349 .17821 .34676 .17052 Mtetra
.34676 .17052 .35349 .17821 .36436 .17405 .35766 .16633 Mtetra
.35766 .16633 .36436 .17405 .37527 .16988 .36859 .16212 Mtetra
.36859 .16212 .37527 .16988 .38623 .16568 .37958 .1579 Mtetra
.37958 .1579 .38623 .16568 .39723 .16147 .39061 .15365 Mtetra
.39061 .15365 .39723 .16147 .40827 .15724 .40168 .14939 Mtetra
.40168 .14939 .40827 .15724 .41936 .153 .4128 .14512 Mtetra
.4128 .14512 .41936 .153 .4305 .14874 .42397 .14082 Mtetra
.42397 .14082 .4305 .14874 .44168 .14446 .43518 .13651 Mtetra
.43518 .13651 .44168 .14446 .45291 .14016 .44644 .13218 Mtetra
.44644 .13218 .45291 .14016 .46419 .13584 .45774 .12783 Mtetra
.45774 .12783 .46419 .13584 .47551 .13151 .4691 .12346 Mtetra
.4691 .12346 .47551 .13151 .48688 .12716 .4805 .11907 Mtetra
.4805 .11907 .48688 .12716 .4983 .12279 .49194 .11467 Mtetra
.49194 .11467 .4983 .12279 .50977 .1184 .50344 .11025 Mtetra
.50344 .11025 .50977 .1184 .52128 .11399 .51499 .1058 Mtetra
.51499 .1058 .52128 .11399 .53284 .10956 .52658 .10134 Mtetra
.52658 .10134 .53284 .10956 .54445 .10512 .53822 .09687 Mtetra
.53822 .09687 .54445 .10512 .55611 .10066 .54992 .09237 Mtetra
.54992 .09237 .55611 .10066 .56782 .09618 .56166 .08785 Mtetra
.56166 .08785 .56782 .09618 .57958 .09167 .57345 .08331 Mtetra
.57345 .08331 .57958 .09167 .59139 .08715 .58529 .07876 Mtetra
.58529 .07876 .59139 .08715 .60325 .08261 .59719 .07418 Mtetra
.59719 .07418 .60325 .08261 .61516 .07806 .60913 .06959 Mtetra
.60913 .06959 .61516 .07806 .62712 .07348 .62113 .06497 Mtetra
.62113 .06497 .62712 .07348 .63913 .06888 .63317 .06034 Mtetra
.63317 .06034 .63913 .06888 .6512 .06426 .64527 .05569 Mtetra
.64527 .05569 .6512 .06426 .66331 .05963 .65742 .05101 Mtetra
.65742 .05101 .66331 .05963 .67548 .05497 .66963 .04632 Mtetra
.66963 .04632 .67548 .05497 .6877 .05029 .68188 .0416 Mtetra
.68188 .0416 .6877 .05029 .69997 .04559 .69419 .03687 Mtetra
.69419 .03687 .69997 .04559 .7123 .04087 .70656 .03211 Mtetra
.05139 .27435 .05883 .28128 .06858 .27753 .06115 .27057 Mtetra
.06115 .27057 .06858 .27753 .07836 .27377 .07096 .26678 Mtetra
.07096 .26678 .07836 .27377 .08818 .26999 .0808 .26298 Mtetra
.0808 .26298 .08818 .26999 .09804 .2662 .09068 .25916 Mtetra
.09068 .25916 .09804 .2662 .10794 .26239 .1006 .25532 Mtetra
.1006 .25532 .10794 .26239 .11788 .25857 .11056 .25147 Mtetra
.11056 .25147 .11788 .25857 .12786 .25473 .12056 .24761 Mtetra
.12056 .24761 .12786 .25473 .13787 .25088 .13059 .24372 Mtetra
.13059 .24372 .13787 .25088 .14792 .24701 .14067 .23983 Mtetra
.14067 .23983 .14792 .24701 .15802 .24313 .15079 .23592 Mtetra
.15079 .23592 .15802 .24313 .16815 .23923 .16094 .23199 Mtetra
.16094 .23199 .16815 .23923 .17833 .23531 .17114 .22805 Mtetra
.17114 .22805 .17833 .23531 .18854 .23139 .18138 .22409 Mtetra
.18138 .22409 .18854 .23139 .1988 .22744 .19166 .22012 Mtetra
.19166 .22012 .1988 .22744 .20909 .22348 .20198 .21613 Mtetra
.20198 .21613 .20909 .22348 .21943 .2195 .21234 .21212 Mtetra
.21234 .21212 .21943 .2195 .22981 .21551 .22274 .2081 Mtetra
.22274 .2081 .22981 .21551 .24023 .2115 .23318 .20406 Mtetra
.23318 .20406 .24023 .2115 .25069 .20748 .24367 .20001 Mtetra
.24367 .20001 .25069 .20748 .26119 .20344 .2542 .19594 Mtetra
.2542 .19594 .26119 .20344 .27174 .19938 .26477 .19185 Mtetra
.26477 .19185 .27174 .19938 .28232 .19531 .27538 .18774 Mtetra
.27538 .18774 .28232 .19531 .29296 .19122 .28604 .18362 Mtetra
.28604 .18362 .29296 .19122 .30363 .18711 .29674 .17949 Mtetra
.29674 .17949 .30363 .18711 .31435 .18299 .30748 .17533 Mtetra
.30748 .17533 .31435 .18299 .32511 .17885 .31827 .17116 Mtetra
.31827 .17116 .32511 .17885 .33591 .17469 .3291 .16697 Mtetra
.3291 .16697 .33591 .17469 .34676 .17052 .33998 .16277 Mtetra
.33998 .16277 .34676 .17052 .35766 .16633 .3509 .15855 Mtetra
.3509 .15855 .35766 .16633 .36859 .16212 .36187 .15431 Mtetra
.36187 .15431 .36859 .16212 .37958 .1579 .37288 .15005 Mtetra
.37288 .15005 .37958 .1579 .39061 .15365 .38393 .14577 Mtetra
.38393 .14577 .39061 .15365 .40168 .14939 .39504 .14148 Mtetra
.39504 .14148 .40168 .14939 .4128 .14512 .40619 .13717 Mtetra
.40619 .13717 .4128 .14512 .42397 .14082 .41738 .13284 Mtetra
.41738 .13284 .42397 .14082 .43518 .13651 .42862 .1285 Mtetra
.42862 .1285 .43518 .13651 .44644 .13218 .43991 .12413 Mtetra
.43991 .12413 .44644 .13218 .45774 .12783 .45125 .11975 Mtetra
.45125 .11975 .45774 .12783 .4691 .12346 .46263 .11535 Mtetra
.46263 .11535 .4691 .12346 .4805 .11907 .47406 .11093 Mtetra
.47406 .11093 .4805 .11907 .49194 .11467 .48554 .10649 Mtetra
.48554 .10649 .49194 .11467 .50344 .11025 .49707 .10203 Mtetra
.49707 .10203 .50344 .11025 .51499 .1058 .50865 .09756 Mtetra
.50865 .09756 .51499 .1058 .52658 .10134 .52027 .09306 Mtetra
.52027 .09306 .52658 .10134 .53822 .09687 .53195 .08855 Mtetra
.53195 .08855 .53822 .09687 .54992 .09237 .54367 .08401 Mtetra
.54367 .08401 .54992 .09237 .56166 .08785 .55545 .07946 Mtetra
.55545 .07946 .56166 .08785 .57345 .08331 .56727 .07489 Mtetra
.56727 .07489 .57345 .08331 .58529 .07876 .57915 .0703 Mtetra
.57915 .0703 .58529 .07876 .59719 .07418 .59108 .06569 Mtetra
.59108 .06569 .59719 .07418 .60913 .06959 .60305 .06105 Mtetra
.60305 .06105 .60913 .06959 .62113 .06497 .61508 .0564 Mtetra
.61508 .0564 .62113 .06497 .63317 .06034 .62717 .05173 Mtetra
.62717 .05173 .63317 .06034 .64527 .05569 .6393 .04704 Mtetra
.6393 .04704 .64527 .05569 .65742 .05101 .65149 .04233 Mtetra
.65149 .04233 .65742 .05101 .66963 .04632 .66373 .0376 Mtetra
.66373 .0376 .66963 .04632 .68188 .0416 .67602 .03284 Mtetra
.67602 .03284 .68188 .0416 .69419 .03687 .68837 .02807 Mtetra
.68837 .02807 .69419 .03687 .70656 .03211 .70077 .02327 Mtetra
.04389 .26737 .05139 .27435 .06115 .27057 .05368 .26356 Mtetra
.05368 .26356 .06115 .27057 .07096 .26678 .0635 .25975 Mtetra
.0635 .25975 .07096 .26678 .0808 .26298 .07336 .25591 Mtetra
.07336 .25591 .0808 .26298 .09068 .25916 .08327 .25206 Mtetra
.08327 .25206 .09068 .25916 .1006 .25532 .09321 .2482 Mtetra
.09321 .2482 .1006 .25532 .11056 .25147 .10319 .24432 Mtetra
.10319 .24432 .11056 .25147 .12056 .24761 .11321 .24043 Mtetra
.11321 .24043 .12056 .24761 .13059 .24372 .12327 .23652 Mtetra
.12327 .23652 .13059 .24372 .14067 .23983 .13337 .2326 Mtetra
.13337 .2326 .14067 .23983 .15079 .23592 .1435 .22866 Mtetra
.1435 .22866 .15079 .23592 .16094 .23199 .15368 .2247 Mtetra
.15368 .2247 .16094 .23199 .17114 .22805 .1639 .22073 Mtetra
.1639 .22073 .17114 .22805 .18138 .22409 .17416 .21674 Mtetra
.17416 .21674 .18138 .22409 .19166 .22012 .18447 .21274 Mtetra
.18447 .21274 .19166 .22012 .20198 .21613 .19481 .20872 Mtetra
.19481 .20872 .20198 .21613 .21234 .21212 .20519 .20468 Mtetra
.20519 .20468 .21234 .21212 .22274 .2081 .21562 .20063 Mtetra
.21562 .20063 .22274 .2081 .23318 .20406 .22609 .19656 Mtetra
.22609 .19656 .23318 .20406 .24367 .20001 .2366 .19248 Mtetra
.2366 .19248 .24367 .20001 .2542 .19594 .24715 .18838 Mtetra
.24715 .18838 .2542 .19594 .26477 .19185 .25775 .18426 Mtetra
.25775 .18426 .26477 .19185 .27538 .18774 .26839 .18012 Mtetra
.26839 .18012 .27538 .18774 .28604 .18362 .27907 .17597 Mtetra
.27907 .17597 .28604 .18362 .29674 .17949 .2898 .1718 Mtetra
.2898 .1718 .29674 .17949 .30748 .17533 .30057 .16762 Mtetra
.30057 .16762 .30748 .17533 .31827 .17116 .31138 .16342 Mtetra
.31138 .16342 .31827 .17116 .3291 .16697 .32224 .1592 Mtetra
.32224 .1592 .3291 .16697 .33998 .16277 .33314 .15496 Mtetra
.33314 .15496 .33998 .16277 .3509 .15855 .34409 .15071 Mtetra
.34409 .15071 .3509 .15855 .36187 .15431 .35509 .14643 Mtetra
.35509 .14643 .36187 .15431 .37288 .15005 .36613 .14214 Mtetra
.36613 .14214 .37288 .15005 .38393 .14577 .37721 .13784 Mtetra
.37721 .13784 .38393 .14577 .39504 .14148 .38834 .13351 Mtetra
.38834 .13351 .39504 .14148 .40619 .13717 .39952 .12917 Mtetra
.39952 .12917 .40619 .13717 .41738 .13284 .41074 .1248 Mtetra
.41074 .1248 .41738 .13284 .42862 .1285 .42202 .12042 Mtetra
.42202 .12042 .42862 .1285 .43991 .12413 .43333 .11603 Mtetra
.43333 .11603 .43991 .12413 .45125 .11975 .4447 .11161 Mtetra
.4447 .11161 .45125 .11975 .46263 .11535 .45611 .10717 Mtetra
.45611 .10717 .46263 .11535 .47406 .11093 .46758 .10272 Mtetra
.46758 .10272 .47406 .11093 .48554 .10649 .47909 .09825 Mtetra
.47909 .09825 .48554 .10649 .49707 .10203 .49065 .09375 Mtetra
.49065 .09375 .49707 .10203 .50865 .09756 .50225 .08924 Mtetra
.50225 .08924 .50865 .09756 .52027 .09306 .51391 .08471 Mtetra
.51391 .08471 .52027 .09306 .53195 .08855 .52562 .08016 Mtetra
.52562 .08016 .53195 .08855 .54367 .08401 .53738 .07559 Mtetra
.53738 .07559 .54367 .08401 .55545 .07946 .54919 .071 Mtetra
.54919 .071 .55545 .07946 .56727 .07489 .56104 .0664 Mtetra
.56104 .0664 .56727 .07489 .57915 .0703 .57295 .06177 Mtetra
.57295 .06177 .57915 .0703 .59108 .06569 .58492 .05712 Mtetra
.58492 .05712 .59108 .06569 .60305 .06105 .59693 .05245 Mtetra
.59693 .05245 .60305 .06105 .61508 .0564 .60899 .04776 Mtetra
.60899 .04776 .61508 .0564 .62717 .05173 .62111 .04305 Mtetra
.62111 .04305 .62717 .05173 .6393 .04704 .63328 .03833 Mtetra
.63328 .03833 .6393 .04704 .65149 .04233 .6455 .03358 Mtetra
.6455 .03358 .65149 .04233 .66373 .0376 .65778 .0288 Mtetra
.65778 .0288 .66373 .0376 .67602 .03284 .67011 .02401 Mtetra
.67011 .02401 .67602 .03284 .68837 .02807 .68249 .0192 Mtetra
.68249 .0192 .68837 .02807 .70077 .02327 .69493 .01437 Mtetra
.03634 .26033 .04389 .26737 .05368 .26356 .04614 .2565 Mtetra
.04614 .2565 .05368 .26356 .0635 .25975 .05599 .25266 Mtetra
.05599 .25266 .0635 .25975 .07336 .25591 .06587 .2488 Mtetra
.06587 .2488 .07336 .25591 .08327 .25206 .0758 .24492 Mtetra
.0758 .24492 .08327 .25206 .09321 .2482 .08576 .24103 Mtetra
.08576 .24103 .09321 .2482 .10319 .24432 .09576 .23712 Mtetra
.09576 .23712 .10319 .24432 .11321 .24043 .1058 .2332 Mtetra
.1058 .2332 .11321 .24043 .12327 .23652 .11588 .22926 Mtetra
.11588 .22926 .12327 .23652 .13337 .2326 .12601 .22531 Mtetra
.12601 .22531 .13337 .2326 .1435 .22866 .13617 .22134 Mtetra
.13617 .22134 .1435 .22866 .15368 .2247 .14637 .21736 Mtetra
.14637 .21736 .15368 .2247 .1639 .22073 .15661 .21335 Mtetra
.15661 .21335 .1639 .22073 .17416 .21674 .1669 .20934 Mtetra
.1669 .20934 .17416 .21674 .18447 .21274 .17722 .2053 Mtetra
.17722 .2053 .18447 .21274 .19481 .20872 .18759 .20126 Mtetra
.18759 .20126 .19481 .20872 .20519 .20468 .198 .19719 Mtetra
.198 .19719 .20519 .20468 .21562 .20063 .20845 .19311 Mtetra
.20845 .19311 .21562 .20063 .22609 .19656 .21894 .18901 Mtetra
.21894 .18901 .22609 .19656 .2366 .19248 .22948 .18489 Mtetra
.22948 .18489 .2366 .19248 .24715 .18838 .24006 .18076 Mtetra
.24006 .18076 .24715 .18838 .25775 .18426 .25068 .17661 Mtetra
.25068 .17661 .25775 .18426 .26839 .18012 .26134 .17245 Mtetra
.26134 .17245 .26839 .18012 .27907 .17597 .27205 .16826 Mtetra
.27205 .16826 .27907 .17597 .2898 .1718 .2828 .16406 Mtetra
.2828 .16406 .2898 .1718 .30057 .16762 .2936 .15985 Mtetra
.2936 .15985 .30057 .16762 .31138 .16342 .30444 .15561 Mtetra
.30444 .15561 .31138 .16342 .32224 .1592 .31533 .15136 Mtetra
.31533 .15136 .32224 .1592 .33314 .15496 .32626 .14709 Mtetra
.32626 .14709 .33314 .15496 .34409 .15071 .33723 .1428 Mtetra
.33723 .1428 .34409 .15071 .35509 .14643 .34826 .1385 Mtetra
.34826 .1385 .35509 .14643 .36613 .14214 .35932 .13418 Mtetra
.35932 .13418 .36613 .14214 .37721 .13784 .37044 .12984 Mtetra
.37044 .12984 .37721 .13784 .38834 .13351 .3816 .12548 Mtetra
.3816 .12548 .38834 .13351 .39952 .12917 .3928 .1211 Mtetra
.3928 .1211 .39952 .12917 .41074 .1248 .40406 .1167 Mtetra
.40406 .1167 .41074 .1248 .42202 .12042 .41536 .11229 Mtetra
.41536 .11229 .42202 .12042 .43333 .11603 .42671 .10786 Mtetra
.42671 .10786 .43333 .11603 .4447 .11161 .4381 .10341 Mtetra
.4381 .10341 .4447 .11161 .45611 .10717 .44955 .09894 Mtetra
.44955 .09894 .45611 .10717 .46758 .10272 .46104 .09445 Mtetra
.46104 .09445 .46758 .10272 .47909 .09825 .47258 .08994 Mtetra
.47258 .08994 .47909 .09825 .49065 .09375 .48417 .08541 Mtetra
.48417 .08541 .49065 .09375 .50225 .08924 .49581 .08086 Mtetra
.49581 .08086 .50225 .08924 .51391 .08471 .5075 .0763 Mtetra
.5075 .0763 .51391 .08471 .52562 .08016 .51924 .07171 Mtetra
.51924 .07171 .52562 .08016 .53738 .07559 .53103 .06711 Mtetra
.53103 .06711 .53738 .07559 .54919 .071 .54288 .06248 Mtetra
.54288 .06248 .54919 .071 .56104 .0664 .55477 .05784 Mtetra
.55477 .05784 .56104 .0664 .57295 .06177 .56671 .05317 Mtetra
.56671 .05317 .57295 .06177 .58492 .05712 .57871 .04849 Mtetra
.57871 .04849 .58492 .05712 .59693 .05245 .59075 .04378 Mtetra
.59075 .04378 .59693 .05245 .60899 .04776 .60285 .03905 Mtetra
.60285 .03905 .60899 .04776 .62111 .04305 .61501 .03431 Mtetra
.61501 .03431 .62111 .04305 .63328 .03833 .62721 .02954 Mtetra
.62721 .02954 .63328 .03833 .6455 .03358 .63947 .02475 Mtetra
.63947 .02475 .6455 .03358 .65778 .0288 .65178 .01994 Mtetra
.65178 .01994 .65778 .0288 .67011 .02401 .66415 .01511 Mtetra
.66415 .01511 .67011 .02401 .68249 .0192 .67657 .01026 Mtetra
.67657 .01026 .68249 .0192 .69493 .01437 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10459 .22873 m
.10928 .23332 L
s
[(-1)] .09521 .21956 1 .97789 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.60504 .03277 m
.60881 .03814 L
s
[(1)] .5975 .02203 .70186 1 Mshowa
.125 Mabswid
.15056 .21073 m
.15333 .21353 L
s
.19737 .19241 m
.20009 .19525 L
s
.24504 .17374 m
.24771 .17663 L
s
.29359 .15473 m
.29622 .15766 L
s
.39347 .11562 m
.39599 .11865 L
s
.44485 .0955 m
.4473 .09858 L
s
.49721 .075 m
.4996 .07812 L
s
.5506 .05409 m
.55293 .05726 L
s
.05944 .24641 m
.06229 .24912 L
s
.66056 .01103 m
.66275 .0143 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00g_ooool4o`000003oa0@4?oooooooooo08?ooooo
003Pooooo`03o`000?oooooooooo01cooooo0_l0001Wooooo`00h?ooool00ol0003oooooooooo`0I
ooooo`?o000000?oooooo`000?ooool0I_ooool00>3ooooo00?o0000ooooooooool05oooool2o`00
00Cooooo0_l0001Vooooo`00h?ooool00ol0003oooooooooo`0Dooooo`?o00001Oooool01?nY_NSo
0000ooooool0001Uooooo`00h?ooool00ol0003oooooooooo`0Booooo`?o00001Oooool3ojVmj003
o`000?oooooo000006Gooooo003Pooooo`03o`000?oooooooooo00oooooo0ol00003ooooo`03o`00
0?ooooooZKgX00GoZKgX00Co0000ojVmj?oooooo0000I?ooool00=kooooo00?oEEEEofIVI_l00000
3_ooool3o`0000Gooooo2OnY_NP01Ol0003oZKgXoooooooooooo000006?ooooo003]ooooo`;o0000
1_ooool;ojVmj003o`000?nY_NSoZKgX00?o0000H_ooool00>[ooooo0ol00005ooooo`koZKgX00Ko
0000ojVmj?nY_NSoZKgXooooool0001Rooooo`00j?ooool2o`0000Gooooo4_nY_NP00ol0003oZKgX
ojVmj002ooooo`03o`000?oooooooooo05oooooo003Uooooo`?o00001OoooolDojVmj006o`000?nY
_NSoZKgXojVmj?oooooo0000HOooool00>?ooooo0ol00005oooooaKoZKgX00?o0000ojVmj?nY_NP0
0_nY_NP00ooooooo0000ooooo`1Oooooo`00h?ooool3o`0000;ooooo00Co0000oooooooooooooooo
6?nY_NP00ol0003oZKgXojVmj002ojVmj0;ooooo00?o0000ooooooooool0GOooool00=kooooo0_l0
0006ooooo`03o`000?nY_NSoZKgX01SoZKgX00?o0000ojVmj?nY_NP00onY_NP00ooooooo0000oooo
o`0Aooooo`Co000000?o410@ooooooooool0A_ooool00=_ooooo0ol00005oooooakoZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0Booooo`03o`000?oooooooooo04Sooooo001foooo
o`;o00000_ooool2o`0005gooooo0_l00006ooooob3oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooo
oooo0000ooooo`07ooooo`Ko00001Oooool00ol0003oooooooooo`18ooooo`00M_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMgE[ooooo0ol00005ooooob?oZKgX00?o0000ojVmj?nY_NP01OnY_NP0
0ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo04Sooooo001gooooo`04omgMgOl0003o410@
olc<c5Sooooo0ol00005ooooobKoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ooooooo0000ooooo`0@
ooooo`03o`000?oooooooooo04Sooooo001gooooo`04onk^k_lQ8B7o410@onk^kUKooooo0ol00005
ooooobSoZKgX00?o0000ojVmj?nY_NP01onY_NP00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04Sooooo001gooooo`04ob4Q8OmgMgOoMgMgoc8b<U?ooooo0ol00003ooooo`03o`000?oooooo
ZKgX02[oZKgX00?o0000ojVmj?nY_NP02?nY_NP00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04Sooooo001fooooo`;o00000_ooool2o`00053ooooo0_l00005ooooobkoZKgX00?o0000ojVm
j?nY_NP02?nY_NP2o`0000gooooo00?oEEEEofIVI_l00000B_ooool00<Wooooo0ol00005oooooc3o
ZKgX00?o0000ojVmj?nY_NP02OnY_NP00ol0003oooooooooo`1Hooooo`00aoooool2o`0000Kooooo
<_nY_NP00ol0003oZKgXojVmj00:ojVmj003o`000?oooooooooo05Oooooo0034ooooo`?o00001Ooo
ooleojVmj003o`000?nY_NSoZKgX00[oZKgX00?oooooo`000?ooool0Eoooool00<;ooooo0_l00006
ooooocOoZKgX00?o0000ojVmj?nY_NP02onY_NP00ol0003oooooooooo`1Fooooo`00_oooool3o`00
00Gooooo>onY_NP00ol0003oZKgXojVmj00:ojVmj003ooooool0003ooooo05Kooooo002looooo`?o
00000oooool00ol0003oooooojVmj00mojVmj003o`000?nY_NSoZKgX00[oZKgX0_ooool00ol0003o
ooooooooo`1Dooooo`00^_ooool2o`0000Kooooo@?nY_NP00ol0003oZKgXojVmj00;ojVmj003oooo
ool0003ooooo05Gooooo002gooooo`?o00001Ooooom3ojVmj003o`000?nY_NSoZKgX00coZKgX00?o
ooooo`000?ooool0E?ooool00;Gooooo0_l00005ooooodKoZKgX00?o0000ojVmj?nY_NP03?nY_NP2
ooooo`03o`000?oooooooooo05;ooooo002booooo`?o00001Ooooom8ojVmj003o`000?nY_NSoZKgX
00goZKgX00?oooooo`000?ooool0Doooool00;3ooooo0_l00006oooood[oZKgX00?o0000ojVmj?nY
_NP03_nY_NP00ooooooo0000ooooo`1Booooo`00[Oooool4o`0000CoooooCOnY_NP00ol0003oZKgX
ojVmj00?ojVmj003ooooool0003ooooo057ooooo0026ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
8?ooool2o`0000Cooooo00?o0000oooooonY_NP0C_nY_NP00ol0003oZKgXojVmj00@ojVmj003o`00
0?oooooooooo053ooooo0026ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000Gooooo
D_nY_NP00ol0003oZKgXojVmj00@ojVmj003ooooool0003ooooo053ooooo0026ooooo`05oa0@4?oo
ooooooooooooool@41006oooool2o`0000GoooooEOnY_NP00ol0003oZKgXojVmj00AojVmj003oooo
ool0003ooooo04oooooo0026ooooo`05o`000?ooooooooooooooool000006?ooool3o`0000Gooooo
EonY_NP00ol0003oZKgXojVmj00BojVmj003o`000?oooooooooo04kooooo0026ooooo`05o`000?oo
ooooooooooooool000005Oooool3o`0000KoooooFOnY_NP00ol0003oZKgXojVmj00BojVmj003oooo
ool0003ooooo04kooooo0026ooooo`05oa0@4?ooooooooooooooool@41004oooool2o`0000Kooooo
G?nY_NP00ol0003oZKgXojVmj00CojVmj003o`000?oooooooooo04gooooo0026ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04?ooool3o`0000;ooooo00Co0000ooooooooooooooooG_nY_NP00ol0003o
ZKgXojVmj00CojVmj003ooooool0003ooooo04gooooo0026ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool2o`0000KoooooHOnY_NP00ol0003oZKgXojVmj00DojVmj003ooooool0003ooooo04co
oooo002Fooooo`?o00001OoooomUojVmj003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool0
Boooool009Cooooo0_l00006ooooofOoZKgX00?o0000ojVmj?nY_NP05?nY_NP00ooooooo0000oooo
o`1;ooooo`00TOooool3o`0000KoooooJOnY_NP00ol0003oZKgXojVmj00EojVmj003ooooool0003o
oooo04[ooooo002?ooooo`;o00001Ooooom]ojVmj003o`000?nY_NSoZKgX01KoZKgX00?o0000oooo
ooooool0BOooool008cooooo1?l00003ooooog3oZKgX00?o0000ojVmj?nY_NP05_nY_NP2o`0004[o
oooo002:ooooo`;o00001?ooool00ol0003oooooojVmj01`ojVmj003o`000?nY_NSoZKgX01OoZKgX
00?oooooo`000?ooool0B?ooool008Oooooo0ol00005ooooogCoZKgX00?o0000ojVmj?nY_NP06?nY
_NP00ol0003oooooooooo`17ooooo`00Q?ooool3o`0000GoooooMonY_NP00ol0003oZKgXojVmj00H
ojVmj003ooooool0003ooooo04Oooooo0022ooooo`;o00001_oooomiojVmj003o`000?nY_NSoZKgX
01WoZKgX00?oooooo`000?ooool0A_ooool007oooooo0ol00006ooooog_oZKgX00?o0000ojVmj?nY
_NP06OnY_NP00ooooooo0000ooooo`16ooooo`00OOooool3o`0000CoooooOonY_NP00ol0003oZKgX
ojVmj00JojVmj003ooooool0003ooooo04Gooooo001jooooo`?o00000_ooool00ol0003oooooojVm
j021ojVmj003o`000?nY_NSoZKgX01_oZKgX00?oooooo`000?ooool0A?ooool007Sooooo0_l00006
ooooodGoZKgX00?oZK[UojVmj?nY_NP01onY_NP00onY^nKoZKgXojVmj00aojVmj003o`000?nY_NSo
ZKgX01coZKgX00?o0000ooooooooool0@oooool007Gooooo0ol00005ooooodOoZKgX0onY^^D6ojVm
j0CoZK_V0onY_NP00onX/MkoZKgXojVmj00/ojVmj003o`000?nY_NSoZKgX01goZKgX00?o0000oooo
ooooool0@_ooool007?ooooo0_l00005ooooockoZKgX00?oZKOSojVmj?nY_NP01_nY_NP2ojN^g0Go
ZK[U0_nY_NP3ojN/f`GoZK_V00CoZKgXojRag_nX/MkoZ;7N3OnY_NP00onY^nKoZKgXojVmj00MojVm
j003o`000?nY_NSoZKgX01goZKgX00?oooooo`000?ooool0@_ooool0073ooooo0ol00006ooooocco
ZKgX00?oZ;3NojVghonY]n<00_nY]n<4ojVmj003ojJVe_nW[]coYjkL00?oYjkL0onY^^D00onXYM?o
YjcKojN/f`04ojN/f`;oZK_V0_nWYM@5ojRagP;oZKgX0onWZmT6ojVmj0?oZK_V7_nY_NP00ol0003o
ZKgXojVmj00NojVmj0;o0000@_ooool006kooooo0_l00006ooooocgoZKgX1?nX/=h4ojVgh`03ojVm
j?nVY]KoYZKF00;oYZKF1OnW[]`01?nY^^GoZ:GCojRUdonXYM<4ojN/f`03ok>Zd?nWYMCoYjGD00?o
YjGD0onX/Mh00on`Z]7oYj_IojN[f@04ojN[f@;oZKgX0onVYmH4ojVkiP;oZKgX0onY^nHHojVmj003
o`000?nY_NSoZKgX01koZKgX0_l00012ooooo`00Joooool3o`0000;ooooo00?o0000oooooonY_NP0
=?nY_NP2ojVli`OoZKgX0_nWZmX6ojR`gP;oZKOS00?oZjKBojJVe_nVY]H01?nVY]H2ojN^g0;o/:S@
1OnXYM<00onW[=_o/j[@ok>Zd002ok>Zd0GoYjGD00CoZ;7Nok2ZdOn`Z]7o/:[A1?nWZmT00onf[M3o
YZOFojJWeP04ojJWeP;oZK_V00?oZ:SFojVki_nY^nH01?nY^nHHojVmj003o`000?nY_NSoZKgX01ko
ZKgX00?oooooo`000?ooool0@?ooool006Sooooo0ol00004ooooocGoZKgX00?oZK[UojVlionY_>L0
0onY_>L3ojVmj003ojJWeonWZm[oYj_J00?oYj_J1?nX/=h00on/Y];oZjKBoj^VdP02oj^VdPCoYZKF
00?o[ZOAok2Xd?n`Z=000on`Z=03ojRUd`03ok6Yd?ncZ]3o/j[@00?o/j[@1?nWYM@00ond[=3o/:[A
ok2Zd@03ok2Zd@03ojN[fOnf[M3o]Zg@00;o]Zg@1?nVYmH00oni[m3oZ:SFojRXeP02ojRXePCoZK_V
00?oZ:WGojVmj?nY_NP05_nY_NP00ol0003oZKgXojVmj00OojVmj003o`000?oooooooooo03oooooo
001Vooooo`;o00001_ooooldojVmj0CoZK[U1OnY_>L01?nY_NSoYZOGojJWeonVYmL5ojN[fP03ojR`
g_n/Y];o[:KB00;o[:KB1?n[Y]800onVY]Ko[ZOAojjWd@02ojjWd@Go/:S@00CoZ:GCok6Yd?naZM3o
/JW@1OncZ]000onWYMCo]:c@okB/d002okB/d0Co/:[A1Onf[M03ojJWeP?o^Jo@1?nXZ=H00onY^nKo
Z:WGojRYe`02ojRYe`CoZKgX00?oYj[IojVmj?nY_NP04?nY_NP00ol0003oZKgXojVmj00OojVmj003
ooooool0003ooooo03oooooo001Sooooo`?o00001_ooooldojVmj0;oZKWU1OnY^^D2ojVli`;oYjKE
1?nVYmL4ojN[fP03ojZUd_n/Y];o[:KB00?o[:KB0on[Y]800on]Y]7o[ZOAojjWd@03ojjWd@Go/:S@
1?naZM05ok>Zd0Go]:c@0on`Z]47okJ]d003ojJWe_ni[m3o^Jo@00;o^Jo@0onXZ=H00onj/=3oZ:WG
ojRYe`04ojRYe`03ojVmj?nWZ]WoYj[I00;oYj[I0onY_NP00onX/MkoZKgXojVmj00;ojVmj003o`00
0?nY_NSoZKgX023oZKgX00?o0000ooooooooool0?_ooool0067ooooo0_l00005ooooocCoZKgX1onY
^ND2ojVji@;oZ:KE1OnWY]D4ojJWe`03ojN[f_nZYM;oZZGB00;oZZGB1On/Y]801?n[Y];o[JKAojfV
dOn]Y]45ojjWd@Go/:S@1?naZM05ok>Zd0Go]:c@00?o/:[AokJ]d?nf[M001Onf[M000ong[]3o^Jo@
okV_d004okV_d004ojRXe_nj/=3o^[3@okZ`d0CoZ:WG00?o^k;AojNZfOnWZ]T00onWZ]T00onY_NSo
Z;7NojRagP02ojRagPcoZKgX00?o0000ojVmj?nY_NP08OnY_NP00ol0003oooooooooo`0Sooooo`?o
000000?o410@ooooooooool05?ooool005kooooo0ol00004ooooocCoZKgX00?oZK[UojViiOnY^ND0
1_nY^ND00onWY]GoZ:KEojRVe@03ojRVe@GoYjKE0_nVYmL00onYY=;oZZGBojZUdP03ojZUdPCo[:KB
00?o[:G@ojfVdOn]Y]400_n]Y]44ojjWd@03ojjWd?n`Z=3o/:S@00?o/:S@1?naZM05ok>Zd0Go]:c@
1_nf[M04okN^d0Go^Jo@1Onj/=000onXZMOo^k;Aok^bd@02ok^bd@?oYj[I00?o^;7CojRag_nX/Mh0
1?nX/Mh2ojVmj0?oZK_V1_nY_NP00ol0003oZKgXojVmj00QojVmj003ooooool0003ooooo02Gooooo
00?o410@okZj^_ooool05Oooool003Oooooo1?l000000ol@413oooooooooo`0Nooooo`;o000000?o
ooooo`000?l000000oooooldojVmj0?oZK[U1_nY^ND3ojNVe@CoZ:KE1?nWY]D00onXXm;oZJCBojVT
dP02ojVTdPGoZZGB00?o[:KBojbUd?n/YM000_n/YM04ojfVd@03ojjWdOn^Ym3o[ZO@00;o[ZO@1On`
Z=04ok6Yd0Go/j[@1Ond[=04okJ]d0Ko]jk@1Oni[m03okZ`d003okZad?nk/]7o^k;A00Co^k;A00Co
Yj[IokRadonh/M?o^;7C1?nX/Mh2ok:`ePGoZK_V1OnY_NP00ol0003oZKgXojVmj00RojVmj003o`00
0?oooooooooo02Cooooo00?oV9RHoc8b<_ooool05Oooool003Wooooo00?o0000ooooooooool07Ooo
ool3o`0000Gooooo=?nY_NP3ojVli`CoZK[U0_nY^ND2ojJUe@GoYjKE1?nXY]D00onWY]GoZ:?BojRS
dP02ojRSdPCoZJCB0_nZYM82ojZTd0Go[:G@0on]Y]400on]YM3o[ZO@ojjWd003ojjWd0Go/:S@1?na
ZM05ok>Zd0Ko]:c@1?nf[M05okN^d0Go^Jo@00?o^[3@okZad?nj/M000_nj/M04ok^bd@03ok^bd?nh
/M?o^;7C00?o^;7C00?oZ;7Nok:`e_nb/=H00onb/=H2ojVkiP;oZJgJ1OnY_NP00ol0003oZKgXojVm
j00RojVmj003ooooool0003ooooo02Cooooo00?ogMgMo`000?nj^[X05Oooool002kooooo1_l00005
ooooo`03o`000?oooooooooo01_ooooo0_l00005ooooocGoZKgX1_nY_>L2ojVji@03ojFUe_nVYMGo
YZGE00?oYZGE1OnWY]D2ojRVe@03ojNSd_nXXm;oZ:?B00?oZ:?B0onYY=800onYXm3oZZC@ojZTd003
ojZTd0Go[:G@00Co[JKAojfUd?n]YM3o[JG@1On^Ym05ok2Xd0Co/JW@1OncZ]04okB/d003okB[conf
[M3o]Zg@00;o]Zg@1_ng[]04okV_d0Ko^[7@00?o^k;Aok^bd?nk/]000_nk/]03okRad`03okfddOnb
/=Ko/[3F00?o/[3F00?o_kKAojV]f_nY[MX00onY[MX3ojVmj003ojViiOl0003oZKgX02CoZKgX00?o
ooooo`000?ooool08oooool00omEEEGoMgMgodA4A00Eooooo`00>Oooool00ol0003oooooooooo`0H
ooooo`?o00001?ooooliojVmj0CoZKcW00?oY:GFojFUe_nUYMH00_nUYMH5ojJUe@;oYjKE0_nVX]84
ojNSdPGoZ:?B00CoZJCBojVSd?nYXm3oZJ?@1?nZY=04ojbUd003ojbTcon]YM3o[JG@00;o[JG@1?n^
Ym000on_Y/oo/:S@ok2Xd003ok2Xd0?o/JW@00?o/ZW?ok>Zd?ncZ]001?ncZ]000ond[=3o]:_?okB[
c`02okB[c`Co]Zg@1Ong[]05okV_d0Co^[7@00?o^k7@ok^bd?nk/]001?nk/]001?nh/M?o_KCAokfd
dOnm]=43ok:`eP?o_kKA1?nY[MX01OnY_NSoZKWUojViiOnY^NGo000002KoZKgX0_l0000Rooooo`05
omgMgOl@413oooooob4Q8OoMgMd05?ooool003Wooooo00?o0000ooooooooool05Oooool3o`0000Go
oooo??nY_NP00onY_>OoY:GFojBUeP02ojBUeP?oYJGF1?nVYMD00onUX];oYZ;BojJRdP03ojJRdPCo
Yj?B0_nXXm82ojRRd0CoZJ?@1OnZY=000on/YM3o[:C?ojbTc`02ojbTc`Co[JG@00?o[ZO@ojnVcon_
Y/l00_n_Y/l5ok2Xd004ok6Yd?nbZLoo/ZW?ok:Yc`Co/j[@00?o/j[?okB[condZll00ondZll3okJ]
d003okJ/cong[]3o]jk@00Co]jk@1?ni[m03okZad0?o^k7@1?nk/]000onl/]3o_KCAokfdd@03okfd
d@03ok:`e_no]]7o_kKA00;o_kKA0onY[MX2okVde@?oZKWU00?o0000ojViiOnY_NP09?nY_NP2o`00
02;ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Dooooo`00>Oooool00ol0003oooooooooo`0Coooo
o`;o00001_oooolmojVmj003ojFWeonTYMKoY:GF00?oY:GF1?nUYMH00onVYMGoYJ;BojFRdP02ojFR
dPCoYZ;B0onWXm800onWXM3oZ:;@ojRRd003ojRRd0CoZJ?@0_nZY=02oj^Sc`Go[:C?0on]YM000on^
YLoo[jK?ojnVc`03ojnVc`Co/:S@00?o/JO?ok:YconbZLl00onbZLl00oncZ]3o/j[?ok>Zc`02ok>Z
c`Go]:_?00Co]Zg@okJ/conf[<oo]Zc?1?ng[]000onh[Loo^Jo@okV_d003okV_d003okZad?nk/M3o
^k7@00;o^k7@0onk/]02okbbd0Go_KCA1_no]]400onY[M[o^KCEokVde@02okVde@;oZKWU00?o0000
ojb_fon/[m/09OnY_NP00ooooooo0000ooooo`0Oooooo`03onk^k_l0003ok^k^00;ooooo00?o0000
omgMgOooool04_ooool003Wooooo00?o0000ooooooooool04?ooool3o`000003ooooool0003o0000
00;ooooo??nY_NP2ojN[fPCoYJOG1OnTYMH2ojFUeP03ojBQdonUX];oYJ;B00?oYJ;B1OnVX]801?nW
Xm;oYj7@ojNQd?nWXM04ojRRd0?oZJ?@00?oZJ;?oj^Scon[Xll00on[Xll5ojbTc`04ojfUd?n^YLoo
[ZG?ojjUc`Go[jK?00?o/:S@ok6WconaYll00_naYll4ok:Yc`Go/j[?1?ndZll00oneZlko]Zc?okJ/
c`03okJ/c`03okN^d?nh[Loo^:g?00;o^:g?0oni[m000onj[loo^k7@ok^ad004ok^ad003ok^bd?nl
/]3o_;;@00;o_;;@1Onm]=45oknfd@Co^KCE00Co`[SAojb_fon/[m_o00000on/[m/TojVmj003oooo
ool0003ooooo01oooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Aooooo`00
=oooool00omEEEGoIVIVo`00000@ooooo`;o00001OoooollojVmj003ojR`g_nWZm[oYj_J00?oYj_J
1?nUYmL2ojBUeP;oXj7C1?nTXM<5ojFRdP;oYZ;B0_nVX=04ojNQd0GoZ:;@00CoZJ?@ojVRconYX/oo
ZJ;?1On[Xll2ojbTc`;o[JC>1?n^YLl4ojnVc`03ok2Vc_naYloo/JO?00?o/JO?0onbZLl2ok>XcPGo
/j[?00?o]:_?okF[c_neZlh00_neZlh3okJ/c`03okN/c_nh[Loo^:g?00Co^:g?00Co^Jo@okZ_conj
[loo^Zo?1?nk/M000onk/<oo_;;@okbbd003okbbd0Ko_KCA1Ono]]42okVde@?o`[SA00Go[:oKo`00
0?n/[m_o[:oKokVfeP0UojVmj003ooooool0003ooooo03Sooooo0017ooooo`?o00001OoooolmojVm
j0?oZ;3N1OnWZmX2ojFWe`03oj:Qe?nSXM?oXj7C00?oXj7C0onTXM<4ojFRdP03ojBOd?nVX=3oYZ3@
00?oYZ3@1?nWXM02ojRRd0;oZ:7>1?nYX/l4oj^Sc`03ojbRc_n]Y<ko[JC>00?o[JC>1?n^YLl00on_
Y/oo/:K>ok2VcP02ok2VcPGo/JO?00Co/ZW?ok>Xc_ncZ<ko/jS>1?ncZ/l00ondZLgo]J_>okF[cP03
okF[cP03okJ/cong[<ko]jc>00;o]jc>1?nh[Ll00oni[Lgo^Zo?okZ_c`03okZ_c`03ok^ad?nk/<oo
^k3?00;o^k3?0onl/]000onm//oo_KCAokfdd@03okfdd@03okjdd?no]]7o_kKA00?o_kKA00?o^KCE
ol:hdOo2^=400oo2^=400ol0003o^KKFokVfeP02okVfeP?oZKgX00?oZ;;OojVmj?nY_NP07onY_NP0
0ooooooo0000ooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool004Gooooo0_l00006
oooooccoZKgX0_nY]n<4ojR`gPCoYj_J00?oXJ7Eoj:Qe?nRXM@00_nRXM@4oj>Qd`CoY:7C00?oYJ;B
ojBOd?nTWm000_nTWm04ojJPd0?oYj7@00?oYio>ojRQc_nXXLh00onXXLh4ojVRc`03oj^Scon/X/ko
[:;>00;o[:;>1?n]Y<h3ojjUc`03ojnUc_n`Y/ko/:K>00?o/:K>1?naYll00onbYlgo/jS>ok>XcP03
ok>XcP03ok>ZcondZLgo]:W=00;o]:W=1?neZlh5okN/cP?o^:g?0oni[Ld4okZ_c`Ko^k3?00Co_;;@
okfbconm//oo_K;?0onm]=43okjdd0?o_kKA00?o`;OAol:hdOo2^=400oo2^=400oo2^M7o0000okVf
eP03okVfeP03ojVmj?nX/]ooZ;;O00;oZ;;O8OnY_NP00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0:oooool004;ooooo0ol00005ooooocgoZKgX1OnY]n<4ojR`gP03ojN[f_nQ
XMGoXJ7E00;oXJ7E0onRXM@5oj>Qd`;oY:7C00?oXioAojBOd?nTWm000onTWm05ojJPd004ojNQd?nW
WlkoYio>ojNOcPCoZ:7>0onYX/l00onZXLko[:;>ojbRcP03ojbRcPGo[JC>00Co[ZG?ojnUc_n_YLko
[jG>1On`Y/h00onaYloo/ZO=ok:Wc@02ok:Wc@?o/jS>00?o/jS=okBYcOndZLd00ondZLd3okF[cP;o
]Z[=1Ong[<h00onh[Loo^Jg=okV]c@02okV]c@?o^Zo?0_nk[/d4ok^`c`03okf`cOnm//oo_K;?00?o
_K;?00?o_KCAokjdd?nn]=000onn]=001?no]]7o`;OAol2gdOo0]m43ol:hd@?o`[WA00?o0000okVf
e_ni]]H00_o4^m85ojRbgb7oZKgX00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo
410@02_ooooo0010ooooo`;o00001Ooooom1ojVmj0GoZKOS0_nX/=h00onPXMKoXJ7Eoj6Qe@03oj6Q
e@CoXZ7D0_nSXM<2oj:Od@CoXioA1OnTWm02ojJPd0;oYIo?1?nWWlh5ojRQcP04ojVRconZXLkoZZ7>
ojZQcPGo[:;>0_n]Y<h2ojjSc@Co[jG>1?n`Y/h00onaY/go/ZO=ok:Wc@04ok:Wc@04ok>Xc_ncZ<go
/jS=ok>Xc@Go]:W=00Co]J_>okJZcOnfZ/go]Z[=1?ng[<h00onhZlco^Jg=okV]c@04okV]c@04okZ_
conk[/go^jk=ok^^c@?o^k3?0onm/<d4okfbc`Go_[C@00?o`;C?ol2gdOo0]m400oo0]m400oo2^=7o
`[WAol:id@02ol:id@03o`000?ni]]Koa;_B00?oa;_B0_nX/]l2ok:efb7oZKgX00?oooooo`000?oo
ool01Oooool01Ol0003ooooooooooooooooo000002_ooooo000mooooo`?o000000?oooooo`000?oo
ool00_oooom4ojVmj0;oZKOS0_nNXMH4oj2QePGoXJ7E0_nRXM@00onQWm;oXYoAoj:Od@03oj:Od@Co
XioA0onTWm000onTW/ooYIo?ojFOc`03ojFOc`CoYio>0_nXXLh2ojVPcPCoZZ7>1?n/X/h00on/X/go
[Z?=ojjSc@03ojjSc@Co[jG>00?o/:K>ok6VcOnaY/d00_naY/d4ok:Wc@03ok:Vc?ncZ<go/jS=00;o
/jS=1?ndZLd00oneZ<co]Z[=okJZc@03okJZc@03okN/c_nhZlco^:_<00;o^:_<1?ni[Ld00onj[<co
^jk=ok^^c@03ok^^c@03ok^`conm/<go_K3=00;o_K3=0onm//l2okjbcP?o_[C@0oo0]<l4ol2gd@Go
`[WA00?o0000olBkd_o4^m800_o4^m800oo6_=7o/[GKok:ef`03ok:efb7oZKgX00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000002_ooooo000kooooo`;o00001Oooool00ol0003o
ZKgXojVmj013ojVmj0;oWj?H1?nNXMH4oj2QeP;oXJ7E0_nPWm<4oj6OdPCoXYoA1OnSWm401?nTWm3o
Y9k?ojBNconTW/l4ojFOc`CoYio>1OnYX<h4ojZQcP03ojbRc_n/X/go[:;=00;o[:;=1On^Xld2ojnU
cP03ojnTcOnaY/go/JK=00Co/JK=00?o/ZO=ok:Vc?nbY/`00_nbY/`4ok>Xc@03okBYcOneZ<co]JS<
00;o]JS<0onfZ/d00ongZL_o^:_<okR[c004okR[c003okV]cOnj[<co^Zc<00;o^Zc<0onk[/d00onl
[/co_K3=okf`c@04okf`c@03okfbconn//ko_[;>00;o_[;>00?o_[C@ol2dcoo0]<l00_o0]<l3ol2g
d@;o`KO@0oo2^M400oo2^]7o0000ol:jd@02olBkdP?oa[cA0onb]M/2okfkf23oZKgX00?oooooo`00
0?ooool01?ooool01Ol@413ooooooooooooooooo410@02_ooooo000hooooo`?o00001Ooooom5ojVm
j003ojN^g?nOXmSoWj?H00?oWj?H1?nNXMH2oj2QeP03oinOe?nPWm?oX9oC00?oX9oC0onQWm85oj:O
d@;oXioA0_nSWM04ojBNc`GoYIo?1?nWWlh4ojVPcP?oZZ7>00?oZj7=ojbRcOn/X/d00on/X/d4ojjS
c@03ojjSc?n_Y<go[jC=00;o[jC=1?naY/d00onaYLco/ZK<ok:Vc003ok:Vc0?o/jS=00?o]:O<okFX
c?neZ<`01?neZ<`01?nfZ/go]jW;okNYbongZL/4okR[c003okV[bonj[<co^Zc<00Co^Zc<00Co^jk=
okb^c?nl[/co_:k<1?nm/<d00onn/<co_[;>okjbcP03okjbcPKo`;C?00?o`;OAol6gd?o1]m000_o1
]m001_o2^M7o`[[Aol:jdOl0003o`[[AolBkdPGoa[cA00?o/[GKokfkf?nm^mP00_nm^mPPojVmj0;o
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo000eooooo`?o00001?oooom5ojVmj0;o
ZK[U1?nW[]`5oinSf0;oWZ7F00?oWYoEoinOe?nOWm@00_nOWm@4oj2Od`CoXIoB0_nRWm42oj6Md0Go
Xig@1?nTW/l2ojFOc`;oYYk>1?nWWlh5ojVPcP04ojZQc_n[XLgoZj7=oj^Qc@Go[:;=00?o[Z?=ojjS
c?n^Xl`00_n^Xl`4ojnTc@03ok6VcOnaYLco/JG<00;o/JG<1OnbY/`01?ncZ<go]:O<okBWc?ndYl`4
okFXc003okJXbongZL_o]jW;00;o]jW;0onhZl`3okV[b`Co^Zc<00?o^jc;okb^c?nl[/`00onl[/`0
0onm/<go_[3<okj`c002okj`c0?o_[;>0_o0/ld4ol2dc`03ol6ec_o1]m3o`KO@00;o`KO@00Ko`[S@
ol:jdOo2^]7o`[[Ao`000?o2^]45olJld@03olJmd_nm^mSo_K_H00;o_K_H00?oaKoDojVmj?nY_NP0
7onY_NP00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:oooool003?ooooo
0_l00004ooooodKoZKgX1OnY^^D4ojN^g0;oWj?H0_nLWmH4oijOe@CoWioD1?nPWm<2oj6OdP03oj2M
dOnQWM3oXIg@00?oXIg@1?nSWM03ojBNc`03ojBMc_nVW/koYYk>00?oYYk>1?nWWlh2ojVPcP;oZJ3=
1?n[XLd4ojbRc@03ojfRc?n^Xlco[Z?<00?o[Z?<0on_Y<d00on`Y<co/JG<ok6Uc003ok6Uc0Co/ZK<
00?o/jK;okBWc?ndYl`00_ndYl`3okFXc0?o]ZS;1?ngZL/00onhZlco^J_;okV[b`02okV[b`?o^Zc<
0_nk[</4okb^c003okj^bonn/<co_[3<00Co_[3<00?o_[;>ol2ccOo0/ld00_o0/ld00oo0]<oo`KG>
ol6ecP02ol6ecP;o`KO@0oo2^=02ol:jd@03o`000?o3^]7o`k[A00?oa[cA0oo6_M82okfkf0?oaKoD
0onY_NP00onY^^GoZKgXojVmj00JojVmj003ooooool0003ooooo03;ooooo000`ooooo`?o00001Ooo
oom8ojVmj0GoZK[U0_nW[]`00onKWmOoW9oFoibOeP03oibOeP?oWYoE1OnOWm@2oj2Od`03oinMd_nP
WM7oX9gA00;oX9gA1?nQWM05oj>Md004ojBNconTWLkoY9g>ojBMcPCoYYk>0onWWlh00onWW/goZJ3=
ojVPc@03ojVPc@CoZj7=00?o[:;=ojfRc?n]X/`00_n]X/`5ojjSc004ojnTcOn`Y<co/:C<ok2Tc0Go
/JG<00Co/ZK<ok>VboncY/_o/jK;1OndYl`00oneZ<co]ZS;okJXb`02okJXb`?o]jW;00?o^:W:okV[
boniZl/01?niZl/00onj[<co^jc;ok^/b`02ok^/b`;o_:k<0onn[//4okj`c003ol2`boo0/lgo`;?=
00;o`;?=00?o`[?<ol6ec_o1]Lh00oo1]Lh00oo1]m3o`[S@ol:hd003ol:hd0;o00000oo3^]400oo6
_=7oa[gBolJmdP02olJmdP03okfkf?o5_mCoaKoD00?oaKoD00CoZKgXojVjiOnY^^GoZK[U7?nY_NP0
0ooooooo0000ooooo`0aooooo`00;_ooool2o`0000?ooooo00?o0000ooooooooool0BonY_NP2ojVj
i@;oVIkH1?nKWmL4oibOePCoWYoE0_nOWm@2oifMd`CoWigB1?nPWM44oj6Md0;oXig@0_nRW<l4ojBM
cPGoYYk>00CoYio>ojNNcOnWW/goYik=1?nYX<d3oj^Qc@03oj^Qc?n]X/co[J;<00?o[J;<1?n^Xl`0
0on_Xl_o/:C<ok2Tc002ok2Tc0Co/JG<00?o/ZG;ok>VboncY//00oncY//3okBWc003okFVb_nfZ<_o
]ZS;00Co]ZS;00Co]jW;okRYb_nhZL[o^:W:1?niZl/00onjZ/Wo^jc;ok^/b`03ok^/b`03okb^c?nn
[/_o_Zk;00;o_Zk;0onn/<`3ol2`b`;o`;?=0oo2/l`4ol6ecP?o`[S@0ol000000oo3^]7o0000ol>j
d@02ol>jd@Goa[gB1Oo5_m@00oo;`];oZK[UojVji@03ojVjiA_oZKgX00?oooooo`000?ooool0<Ooo
ool002_ooooo0ol00005ooooodgoZKgX00?oY:_LoiVNf?nIW]P00onIW]P3oi^Oe`GoW9oF0_nNWmD0
0onLW]GoWIgCoifMd`03oifMd`?oWigB1OnPWM42oj6Md003oj6Ld?nRW<ooXYc?00?oXYc?1?nTWLh2
ojJNcP;oYYg=1?nWW/d5ojVPc@04oj^QcOn[XLcoZj7<oj^Qc0Go[J;<00?o[Z?<ojnSbon_Xl/00_n_
Xl/4ok2Tc003ok6Uc?nbYL_o/ZG;00;o/ZG;1?ncY//00ondYlco]JK:okFVbP02okFVbPCo]ZS;00?o
]jO9okRYb_nhZLX00_nhZLX3okV[b`?o^Z[91?nk[</6okj^b`03okj`c?o0/<_o`;3;00;o`;3;00?o
`;?=ol:cc?o2/l`00_o2/l`3ol6ecP05ol>fcOl0003o0000o`000?o2^=000oo4^Ll00oo3^]7o0000
ol>jd@02olFkd@?oa[gB0_o7_m83olFoe0?obl;B0_nY^^D3ojbiha_oZKgX00?oooooo`000?ooool0
<?ooool002[ooooo0_l00004ooooodgoZKgX00?oZK_VojB[g?nTZm`00_nTZm`5oiVNf0?oVioG0_nL
WmH2oi^NePCoW9kE1?nMWM<4oinMdP;oX9gA0_nOW=44oj6Ld0CoXYc?1?nTWLh5ojJMc@CoYik=0_nY
X<d2ojZOc0CoZj7<1?n]X/`00on]XL_o[j?;ojnSb`03ojnSb`?o/:C<00?o/J?;ok:UbonbYL/00onb
YL/3ok>Vb`03ok>Ub_neY/[o]JK:00?o]JK:0onfZ</3okNWb@Co^:W:00?o^J_;okZZbOnjZ/T00_nj
Z/T3ok^/b`;o_Jc91?nn[//00ono[/Wo`;3;ol2`b`03ol2`b`Ko`[?<0ol00002ol>fc@03ol:hd?o4
^Looa;W?00?oa;W?00?o`k[Ao`000?o5^m400_o5^m400oo6_M;oakoBolNodP02olNodP03olFoe?o;
`];obl;B00;obl;B1_n/^N<KojVmj003o`000?oooooooooo02oooooo000Zooooo`?o000000?ooooo
ojVmj?nY_NP0C?nY_NP3ojVkiPCoY:_L1?nIW]P3oiZNe`GoVikF0onLW]D5oifMd`;oWigB00?oWIcB
oinLdOnOW=400onOW=43oj6Ld0GoXYc?1?nTWLh4ojJMc@?oYik=00?oZ9k<ojZOc?nZWl`00onZWl`4
oj^Qc003ojfRc?n]XL_o[J7;00;o[J7;1On_Xl/01?n`Y<co/J?;ok6SbonaXl/5ok:Ub`04ok>Vbonc
YL[o/jG:ok>UbPGo]JK:00?o]ZS;okNWbOngYlT00_ngYlT3okRYbP03okVXbOnjZ/Wo^Z[900Co^Z[9
00Co^jc;okf/bOnm[<Wo_Jc90onn[//3okn^b@?o`;3;0_o2/LX2ol:cc0?o00001Oo3]/d5olBic`06
olJjcoo5^m7oaK_Ao`000?o5^m7oa[gA1Oo7_m801?o8`=?obl;Bol_2d_o;`]82olk4d@Co[;WS00?o
/[kSojVmj?nY_NP06OnY_NP00ooooooo0000ooooo`0_ooooo`00:_ooool00ol0003oooooojVmj01@
ojVmj0?oZK_V0_nTZm`00onGW]WoVIkHoiVNf003oiVNf0?oVYkG1?nKW]H4oibNe@;oWIgC0_nLW=<4
oifLdPCoWicA1?nQW=04oj:Lc`CoY9g>1OnVWLd01?nWW/goZ9k<ojRNc?nXW/`4ojZOc0?oZj7<00?o
[:3;ojfQbon]XL/00on]XL/4ojnSb`03ojnRb_naXl_o/J?;00;o/J?;1?nbYL/00onbY<[o/jG:ok>U
bP02ok>UbPCo]JK:00?o]JK9okNWbOngYlT01?ngYlT01?nhZL[o^JS9okVXbOniZ<T4okZZb@03ok^Z
b?nm[<Wo_Jc900?o_Jc900?o_Zk;okn^bOno[/T00ono[/T00oo0/<_o`[7:ol:abP03o`000004ol:c
c?o4]<_oa;C;olBdb`?o`kK=0_o5]ld3olBic`?oa[[?00?oaK_Ao`000?o6_M400_o6_M43olNodP?o
b<3C00?obl;Bolk4dOo>a=400_o>a=400on/^N?o/[kSok:nh`02ok:nha_oZKgX00?oooooo`000?oo
ool0;_ooool001oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooZKgX04oo
ZKgX00CoY[3OoiBLfOnDW=WoU9cI1?nGW]T4oiVNf0CoVYkG1?nKW]H2oibNe@03oi^Le?nLW=?oW9cC
00?oW9cC0onMW=85oinLd@;oXIc@00?oX9_@oj:LconRW<l00onRW<l4ojBMcPCoYYg=1?nXW/`5ojZO
c004oj^Qc?n/X<_o[:3;ojbPb`Go[J7;00?o[j?;ojnRb_n_X/X00_n_X/X4ok6Sb`03ok:UbonbY<[o
/ZC:00;o/ZC:1?ncYLX00oneY/[o]JK9okFVb@02okFVb@Co]jO900?o]jO8okVXbOniZ<T00oniZ<T0
0onjZ/Wo^j[8ok^Zb002ok^Zb0?o_Jc900?o_Zc8okn^bOno[/T00ono[/T01?o1[lSo0000o`000?l0
0002ol:abP03ol:cc?o4]<_oa;C;00?oa;C;00?o`kK=olFgcOo5]ld00_o5]ld00oo4^Looa[[?olJj
c`02olJjc`03olFkdOo6_M7o000000?oa[gA00GoakoBolS0doo8`=?ob<3ColW2d`05olk4d@05olo6
d_nb_^?o/[kSok:nhone`^@07?nY_NP00ol0003oooooooooo`0]ooooo`007oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00Co0000ooooooooooooooooCOnY_NP4ojJ`g`?oU9cI1?nGW]T4oiVN
f0;oVYkG00?oVIgGoiZMe_nJWMH00_nJWMH4oi^Le0CoW9cC1?nMW=82oinLd@;oWY_@1?nPVm04oj:L
c`?oY9g>00?oY9c=ojJMcOnVWLd00onVWLd3ojRNc0CoZYo<00?oZYo;ojbPbon/X</00_n/X</4ojfQ
b`03ojjQb_n_X/[o[j;:00?o[j;:0onaXl/00onaXlWo/ZC:ok:TbP03ok:TbP?o/jG:00?o]:G9okFV
bOneY/T00oneY/T3okNWb@;o]jO81?niZ<T00onjZ<So^j[8ok^Zb004ok^Zb004okf/bOnn[<So_Zc8
okj/b0;o_jk90ol000000oo1[lSo`[7:ol:abP02ol:abPGoa;C;00?oaKG:olFgcOo5]ld00_o5]ld0
0oo7^<coa[[?olJjc`03olJjc`?oa[gA00?o0000olJmdOo8_]400oo8`=<3olW2d`?oc/CA0oo?a]80
1?nb_^?o]L;TokG2i?ne`^@LojVmj003o`000?oooooooooo02cooooo000Oooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`0000;oooooCOnY_NP3ojJ`g`CoU9cI1?nGW]T2oiVNf003oiRNf?nI
WMOoVIgG00;oVIgG1?nJWMH3oi^Le0GoW9cC0_nMW=800onLVm7oWY_@oijKd003oijKd0?oX9_@1OnR
W<l01?nTWLkoY9c=ojBLcOnTW<d4ojJMc@CoZ9k<00?oZYo<ojZObonZWl/00_nZWl/4ojbPb`03ojfQ
bon^XL[o[Z7:00;o[Z7:1On_X/X01?naXl_o/J?9ok6SbOnaXlT5ok:TbP04ok>Ub_ndYLWo]:G9okBU
b@Go]JK900?o]jO9okNWb?ngYlP00_ngYlP2okVXb@?o^ZS81?nkZ/P01?nlZ/Oo_Zc8okj/b?nn[<P3
o`0000Co`Jo80oo2/LX2ol>bb@?oa;C;0oo5]LX2olFgc@?oakS<0oo6^/l2olNkcP;oa[gA00Go0000
olRndOo8_]7ob;kAolS0d`05olW2d`05olk4dOo?a];oclKBolo6d_o@b=801One`^@KojVmj0;o0000
;Oooool001oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo
COnY_NP3ojJ`g`;oU9cI00?oUIkJoiNNfOnGW]T00_nGW]T4oiRNf0?oVIgG1OnJWMH3oi^Le0;oW9cC
0_nKVm<4oibKd@CoWY_@1?nPVm02oj:Lc`;oXI_>1?nTW<d5ojJMc@;oZ9k<00?oZ9g<ojZObonZWl/0
0onZWl/3ojbPb`03ojbOb_n^XL[o[Z7:00?o[Z7:1?n_X/X00on`XLWo/J?9ok6Sb@02ok6Sb@Co/ZC:
00?o/j?8okBUbOndYLT00_ndYLT4okFVb@03okJUb?ngYlSo]jO800?o]jO800?o^JS9okZXb?njZ<P0
0_njZ<P3ok^Zb0?o_:[70_l00002okj/b0Ko`Jo800?o`[7:ol>bbOo3//T00_o3//T00oo4]<_oaKG:
olFebP02olFebP03olFgcOo7^<coakS<00?oakS<00?oa[[?olNkc_o7^lh00_o7^lh00oo6_M7ob;kA
o`000002olRnd@GobL;C00CoblCColo6d_o?a];oclKB0oo@b=82okG2i0?o]/GV6onY_NP00ol0003o
ooooooooo`0[ooooo`007oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool01?oooom:ojVmj0;oVJGN0onBWMX4oiFNfPCoUikI0onHW]P4oiVMe`;oVYgF0_nHVmD3oiVKe0Go
Vi_C0onLVm45oijKd0;oX9_@00?oWi[?oj6Kc_nQVlh00onQVlh4ojBLc@;oYYg=0_nVW<`4ojRMc0Go
ZYo;00Co[:3;ojbOb_n/Wl[o[9o:1On^XLX00on_X/[o/:79ok2Qb@02ok2Qb@Co/J?900?o/ZC:ok>S
b?ncXlP00_ncXlP4okBUb@03okFVbOnfYLSo]ZG800;o]ZG80ongYlP00onhYlOo^ZS8okZXb004okZX
b003ok^Zb?nlZ/Oo000000;o00000onn[<P2okn]a`Co`Jo800?o`[37ol>bbOo3//T00_o3//T00oo5
/lSoaKG:olFebP03olFebPGoakS<00?obKW;olNkc_o7^lh00_o7^lh2olVmcP;ob;kA00?o0000ol[0
dOo:`=400oo9`]<3ol_4d`03olo6d_o@b=;od<SB00;od<SB1_nfaNHJojVmj003ooooool0003ooooo
02_ooooo000Oooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000KoooooAonY_NP5oiVU
gP?oTYgJ0onEW]X5oiNNf@?oV9kH0_nIWML00onGW=KoV9_EoiRKe@03oiRKe@?oVI_D1?nKVm<4oibK
d@;oWY_@0_nMV]04oinJc`CoXI_>0onTW<d00onSVlgoYYc<ojJLc003ojJLc0?oZ9g<1?nZWl/00onZ
W/[o[9o:ojbObP02ojbObPCo[Z7:00?o[Z39ok2QbOn`XLT00on`XLT3ok6Sb@03ok6Rb?ncXlSo/j?8
00?o/j?80ondYLT00ondY<So]ZG8okJUb004okJUb004okNWb?nhYlOo^:O7okRWa`Co^ZS80ol00004
okbZa`04okj/b?no[LOo_jg7okn]a`?o`Jo80oo2/<L2ol>bb@?oaK?80oo5]LX2olNfb@?oakS<0oo9
^L/2olNkcPCobKg>00?ob;kAol[0dOl000000_o:`=400oo9`]?oblCCol_4d`02ol_4d`God<SB00?o
d/_CokK5i_nfaNH00_nfaNH00oncanWoZKgXojVmj00IojVmj003ooooool0003ooooo02[ooooo000O
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`06ooooodOoZKgX1?nI
YMh4oi:MfP?oUIkJ0_nGW]T2oiFMf@?oUYcH1?nGW=H4oiRKe@CoVI_D1?nKVm<2oibKd@03oi^IdOnM
V]3oWI[@00?oWI[@0onOV/l5oj6KcP04ojBLcOnSVlgoXi_=oj>Kc@CoYYc<1?nXWL`00onZWl_oZYk:
ojZNbP02ojZNbPCo[9o:00?o[Z7:ojjPbOn^X<T00_n^X<T5ok2Qb@04ok6SbOnaX/So/J;8ok6Rb0Go
/j?800Co]:G9okBTb?ndY<So]:C81?nfYLP00ongYLOo^:O7okRWa`02okRWa`04okZXb?l0003o0000
o`0000;o^jS71?nlZ/L00onnZlOo_jg7okn]a`03okn]a`03ol6_b?o2/<Oo`[3700;o`[3700?o`k;9
olFcb?o5/lP00oo5/lP00oo5]L[oakK9olNfb@02olNfb@03olNhc?o9^L_obKW;00;obKW;00?oak_>
olVmc_o9_Lh00oo9_Lh2ol[0d@03o`000?o:`=7oc<;A00GoblCC00CocLKDom38d_o@b=;od<SB0ooB
bm<00onfaNKo/lOYok?7j@02ok?7jA_oZKgX00?o0000ooooooooool0:Oooool001oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00OoooooAonY_NP4oiVUgP;oTYgJ00Co
TYgKoiBMf_nDWM[oU9gJ1OnEWMT3oiJLf0?oUicF1OnHVmD2oiVKe003oiRIdonIVM;oVIWB00;oVIWB
1?nKVM44oifJd0CoWi[?0_nQVlh2oj6JcPCoXi_=1OnVW<`2ojRMc003ojRMbonZW/[oZYk:00?oZYk:
0on/WlX00on]W/Wo[Z39ojjPb@03ojjPb@Co/:7900?o/:78ok6Rb?naX/P00_naX/P4ok>Sb003ok>S
aondY<So]:C800;o]:C80onfYLP3okNUa`05okRWaol0003o0000o`000?njZ<P01?nkZ<L3okbZa`;o
_Z_71?no[LL00oo1[LKo`[37ol:`a`03ol:`a`KoaK?81Oo7]/T5olVib`GobKg>0_o<_/h2ol[0d@03
o`000?o<`]7oc<;A00?oblCC0oo=a]@01?o@b=;od/_Com;;dooBbm<2omC=d`?o/lOY00?o[L?YojVm
j?nY_NP06OnY_NP00ooooooo0000ooooo`0Yooooo`00:?ooool00ol0003oooooooooo`09ooooodGo
ZKgX00?oSigLoi2Mg?n@WM`00_n@WM`4oi:Mf`?oU9gJ1?nEWMT4oiJLf0?oUicF0_nHVmD2oiNJe0Co
V9WC1?nIVM83oi^Id@GoWI[@0_nOV/l00onNVLooXI[>oj6JcP03oj6JcP?oXi_=1?nVW<`00onVVl_o
Z9g;ojRMb`02ojRMb`GoZYk:00Co[9o:ojfNbOn]W/Wo[Ik91?n^X<T3ok2Qb@;o/:781OnaX/P00onc
XlSo/j?7ok>Sa`02ok>Sa`Co]:C800?o]ZG8okNUaongYLL00ol00002okRWa`03okVWaonkZ<Oo^jS7
00Co^jS700?o_:[7okj[aonnZlL00_nnZlL2okn]a`?o`Jg60oo2/<L2olBaa`CoaK?80_o7]<L4olNf
b@04olZhbOo9^L_obKW;olVib`;obk_;0oo9_Lh3olbncP04ol[0dOo<`]7oc<;Ao`0000;oc<;A00Go
blCColg6e?o=a]CocLKDolo8e003om;;d`Coe<gC00Co/lOYojg3jOn]`nWo[L?Y6onY_NP00ooooooo
0000ooooo`0Xooooo`00:?ooool3o`0000[ooooo@OnY_NP00onY^nKoSigLohnMg002ohnMg0CoT9gL
0onBWM/4oiBMfPCoUIgI0_nFW=P01?nDVmOoUY[FoiJJe_nFV]H5oiNJe0?oV9WC1?nIVM84oi^Id@;o
WI[@0_nLVM04oijIc`CoXI[>1?nSVld00onVW<coYY_;ojJKb`02ojJKb`?oZ9g;1?nZW/X00on[WLWo
[Ik9ojfNb@02ojfNb@Go[Z3900?o/:79ok2Qb?n`XLP00_n`XLP3ok6Rb003ok:QaoncXlOo/j?700?o
/j?70ondY<P01?neY<Oo0000o`000?l00003okNUa`04okRWaoniYlOo^JO7okVWa`Co^jS700?o_:W6
okj[aonnZlL00onnZlL00ono[LOo`Jg6ol6]aP03ol6]aP04ol:`aoo4/LOoa;77olBaa`?oaK?80oo7
]<L3olNfb@?ob[S900?obKW;ol^kboo;^l/00_o;^l/00oo9_Lkoc;k>olbncP02olbncPCoc<;A00?o
0000olk4dOo=a]@00_o=a]@3olo8e003om;;dooDcM?oe<gC00;oe<gC00?oe]3Cojg3jOn]`nT00on]
`nTKojVmj003o`000?oooooooooo02Oooooo000Xooooo`03o`000?oooooooooo00_ooooo?onY_NP3
ojVkiP?oSigL1On@WM`3oi:Mf`;oU9gJ00?oTYcJoi>Kf?nCVmP00_nCVmP4oiBKe`?oUY[F1?nGV]@4
oiRId`CoVIWB0_nKVM400onJV=7oW9W@oibId003oibId0?oWYW?1OnQV/h2oj>Kc@03oj>Jc?nVVl_o
YY_;00?oYY_;1?nXWL/00onZW/[oZig9oj^Mb@02oj^Mb@Co[Ik90_n^X<T2ojnOa`Go/:780_naX/P3
ok:Qa`Go/j?70ol000000oneY<Oo]jG7okNUa`02okNUa`03okNUa_niYlOo^JO700;o^JO70onkZ<L3
okbYaPCo_Z_71_o1[LH5olBaa`03olFcb?o7]<OoakC700?oakC700?oakK9olZhbOo:^<T00_o:^<T5
ol^kb`04olfmboo<_/koc;k>olbncP;oc/7>0oo<`]401?l0003oc/CAolk4dOo=a]@4olo8e004om7;
e?oDcM?oe<gComC=d`?oe]3C0_n]`nTNojVmj003o`000?oooooooooo02Kooooo000Xooooo`03o`00
0?oooooooooo00gooooo?_nY_NP3ojVkiP?oSigL1?n@WM`3oi6Mf`CoTYcJ1?nCVmP3oiBKe`CoUY[F
1?nGV]@2oiRId`03oiNHdonHV=;oV9SB00;oV9SB1?nJV=44oibId0CoWYW?0_nQV/h2oj2Ic@CoXi[<
1OnVVl/2ojRMb`03ojRKbOn[WLWoZig900?oZig90on]W/T00on]WLOo[io7ojnOa`03ojnOa`Co/:78
00?o/J;8ok:QaonbXLL00_nbXLL2ok>Sa`?o00001?neY<L3okNUa`?o]jG61?niYlL00onkZ<Oo_:W6
okbYaP02okbYaP?o_Z_70_noZlH4ol6]aP;o`jk61?o4/LL5olNda`03olVfaoo:^<Wob[S900;ob[S9
0_o<^LP3ol^kb`?ocKg;00?oc;k>olk1c_o>`Lh00_o>`Lh01_o<`]7oc/CAolk4dOl0003oc/CAom36
d@?oclSD0ooAbm@00ooDcM?oe]3ComK@d`02omK@d`03omKCe_nY_NSoZKgX01goZKgX00?oooooo`00
0?ooool09_ooool002Sooooo0_l0000?oooooccoZKgX00CoYk_Woh^KgOn;VmgoRi_M1?n>WMd4oi2M
g0?oTIgK0onBW=X5oi>Kf0?oU9_G0_nFV]H00onDV=GoUISDoiFHe002oiFHe0CoUiSC1?nHV=83oiZH
d@GoW9W@0_nNVLl00onNV<koX9W=oj2Ic@03oj2Ic@?oXi[<1?nVVl/00onUV/WoZ9_9ojRKb@02ojRK
b@GoZig900Co[Ik9ojfMaon]WLOo[Ig71?n_WlL3ok2Qb003ok2Oa_nbXLOo/Z7700?o/Z770_l00000
1?ncXlOo]:;6okBRa_ndX/H4okFTa`03okNUaongYLKo]jG600;o]jG61?niYlL6okbYaP04okj[aono
ZlKo_j_6okn[aP?o`Jg60oo3[/H3olBaa`;oa[;60oo7]<L3olVfa`;ob[S91?o<^LP00oo;^l_ocKg;
olfmb`02olfmb`Goc/7>00God<?>olk4dOo>a=7oc/CAo`000002om36d@03olo8e?oAbmCodL_D00;o
dL_D00CodlkDomK@dooFd=?oe]3C0ooFdmHOojVmj0;o00009_ooool002Sooooo00?o0000oooooooo
ool03_ooooljojVmj0CoYk_W0on;Vmd4ohjMg@?oT9gL1?nAWM/3oi:LfP;oTi_H0_nAVMP3oi:IePCo
U9SE1?nEV=@3oiNHd`GoV9SB0onJV=42oibId0;oViO?1?nNV<h4oj2Ic@CoXi[<00?oYY_;ojFJbOnU
V/T00_nUV/T3ojRKb@CoZig900?oZi_7ojfMaon]WLL00_n]WLL5ojnOa`05ok2Qb?n`WlKo/9o6ok2O
a_nbXLL00ol000000onbXLOo/j?7okBRaP03okBRaP?o]JC700?o]Z?6okNUa_ngYLH00ongYLH3okVW
a`;o^ZO61?nlZLH00onmZLKo_j_6okn[aP03okn[aP03ol6]a_o3[/Ko`jk600?o`jk600?oa;77olJb
a_o6//H00_o6//H00oo7]<OobKK7olVfa`02olVfa`03olZhbOo<^LSoc;W800?oc;W81?o=_L/2olno
b`?oc/7>0oo@`lh01_o>a=7od<KAom36dOl0003od<KAom;9d@?odL_D0ooCc]@01OoFd=?oe]?FomKC
e_oFdmKod]OL01ooZKgX00?oooooo`000?ooool09Oooool002Oooooo00?o0000ooooooooool04?oo
ooljojVmj0CoYk_W0on;Vmd4ohjMg@?oT9gL0_nAWM/01?n?Vm_oT9[Ioi2JfOn@V]T5oi6If0?oTYWF
0onDV=D4oiFHe0CoUiSC0_nHV=82oiNGd@?oVIO@1OnKUll3oijHcPGoX9W=0_nSV/`00onSV<[oYI[9
ojFJb@03ojFJb@CoZ9_900?oZig9oj^Kaon[VlL00_n[VlL3ojfMa`Co[io700?o[ik6ok2Oa_n`WlH0
0ol00003ok:Qa`03ok:Pa_ndX/Ko]:;600Co]:;600Co]JC7okJSa_nfXlKo]Z?61OngYLH01?niYlOo
^ZO6okZWa_njYlH3okbYaP?o_JW61?noZlH5ol>^aP03olB`a_o6//Koa[;600?oa[;61Oo9]/L5olbi
b0;oc[_80_o=_L/4olnob`03olk1c_o@`lkod<?>00;od<?>0oo@a]401Ol0003od/WAom;9dOoBbM7o
dL_D00?odlkD00CoeM7EomKCe_oFdmKoe]?F0ooBem`OojVmj003ooooool0003ooooo02Cooooo000W
ooooo`?o00004OooooljojVmj0;oYk_W00CoRI_Ooh^Lg_n;W=koRicN1?n=W=d3ohjLg0CoSi_K0on@
V]T4oi6If0?oTYWF1?nDV=D4oiFHe0;oUiSC00?oUIKBoiNGdOnGUm400onGUm43oiVGd0CoViO?1?nN
V<h2oj2Ic@;oX9O;1?nSV<X4ojFJb@?oZ9_900?oZ9[7oj^Kaon[VlL00on[VlL4ojfMa`03ojnOaon_
W/Ko[ik600?o00000on`WlH00onbXLOo/Z36ok:PaP02ok:PaPCo]:;600?o]:75okJSa_nfXlH00_nf
XlH4okNUaP03okRUaOnjYlKo^ZO600?o^ZO600?o_:W6okfYa_nmZLH00_nmZLH3okn[aP;o`Jc60oo3
[/H3olB`aPCoa[;600Cob;?6olVfaoo9]/OobKK70_o;]lL3olbib0?oc[_800?ocKg;olnoboo?_l/0
0oo?_l/4om33cP;od/G>0_o@a]401?oBbM7o0000om;9dOoBbM43om?>e0?oeM7E00?oe]?Fom;Gg?oB
em`00_oBem`00oo:f^GoZKgXojVmj00MojVmj003o`000?oooooooooo02?ooooo000Wooooo`03o`00
0?oooooooooo01;ooooo>?nY_NP00onW_NWoRI_OohVKg`02ohVKg`?oRicN1?n=W=d3ohjLg0?oSi_K
1?n@V]T4oi6If0?oTYWF0_nDV=D00onBU]CoTiKCoi>Fd`02oi>Fd`CoUIKB1?nGUm43oiVGd0GoViO?
0_nNV<h00onMU/goX9O;oj2Gb`03oj2Gb`?oXiS:1OnUV/T01?nXVlWoZ9[7ojRJaonXV/L4oj^Ka`?o
[Ig700Co[Ic5o`000?l0003o00000_n_W/H3ok2OaP03ok6NaOnbX<Ko/Z3600?o/Z360ondX/H2okBQ
a@Go]Z?600?o]jG6okRUaOnhYLD00_nhYLD4okZWaPKo_JW600?o_j_6ol6/a_o1[<H00_o1[<H00oo3
[/Koa;36olB`aP02olB`aP?oa[;60oo8/lH00oo9]/OobkO7ol^ga`02ol^ga`03olbib?o>^lSoc[_8
00;oc[_81Oo?_l/2om71b`;od<?>0ooBaLh01Oo@a]7od/WAom;9dOoBbM7o000000;oe<cB00?odlkD
omGAeOoEdMD00_oEdMD01?oHe=God]OLom;Gg?oBem`3ol[JiAkoZKgX00?oooooo`000?ooool08ooo
ool002Oooooo00?o0000ooooooooool04ooooolfojVmj0?oYkgY0on9Vml4oh^LgPCoSIcM0on>W=`3
ohnKf`;oT9[I00?oSYSHohnGeon?UmL00_n?UmL3oi6GePCoTYKD1?nCU]<3oiFFdPCoUiOA1?nIUm02
oi^Gc`;oVYK>1?nMU/d4oj2Gb`CoXiS:0_nUV/T2ojFHb0CoZ9[71On[VlL3o`000003ojfLaOn_W/Ko
[ik600?o[ik600Co/9o6ok6NaOnaW/Go/Ik51OnbX<H00ondX/Ko]:75okBQa@02okBQa@?o]Z?600?o
]j?5okRUaOnhYLD00onhYLD3okZWaP;o^jO51?nmZLH00onnZ/Go`Jc6ol6/aP03ol6/aPKoa;3600?o
a[;6olRca_o8/lH00_o8/lH5ol^ga`Goc[_800Cod;g8olnoboo?_l_ocko;0ooA`L/00oo@`lkod/G>
om;5cP02om;5cP05omC8c_oBbM7od/WAom;9dOl000000_oDc=801?oFcm;oeM7EomGAeOoEdMD3omSD
e@05om;Gg?o:f^Gob][Uol[JiOnjeNd07onY_NP00ooooooo0000ooooo`0Rooooo`001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool05OooooleojVmj0?oYkgY0on9Vml2oh^LgP03ohZLgon;
VmgoRi_M00;oRi_M0on<V]`3ohfIfPCoSYSH1?n?UmL3oi6GeP?oTYKD1?nCU]<4oiFFdPCoUiOA0_nI
Um000onHULooVYK>oiZFcP03oiZFcP?oWIK=1OnPUl/2oj>HbP03oj:Fb?nUV<SoYIS800?oYIS81?nX
V/L01?n[VlOo0000o`000?l00004ojfLa@Co[ik600?o[ic4ok6NaOnaW/D00_naW/D4ok:PaP03ok>O
a?ndXLGo]:7500?o]:750_nfXlH3okNSa@Go^:G500Co^ZO6ok^WaOnkYlGo^jO50onmZLH3okjZa@Co
`Jc600?o`Zg5olB`a_o4/<H00_o4/<H00oo6/LGob;?6olRcaP02olRcaP;ob[G61?o;]lL01?o=^LOo
c[_8oljkb?o>^lP3om2mb003olnobooA`L_odL7;00;odL7;00Coe<C;om;5c_oBaLkod/G>0ooDb<h0
1OoBbM7oe<cBomC<d_l0003oe<cB00;oe/oB00CoeM7EomSDeOoHe=Gof=CE0_oJf=D00oo:f^Go^]G]
ok[Ek@02ok[EkAooZKgX00?o0000ooooooooool08Oooool000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool2o`0001Oooooo=?nY_NP3ohNMh@?oR9cP1?n:W=l4oh^Kg@?oS9[L0on=VMX3ohjHf0Co
SiOG1?nAUmH3oi:Fe0CoTiKC0_nEU]800onDU=7oUYG@oiJEd002oiJEd0CoV9G?1?nJU/h4oifFc@;o
X9O;0_nOULT4oj:Fb0CoYIS80_nXV/L3o`0000CoZi[51?n]W<D00on_W/Ko[ic4ojnLa002ojnLa0Co
/Ik500?o/Z36ok>Oa?ncWl@00_ncWl@4okBQa@03okJSa_ngXlGo]j?500;o]j?51?nhYLD00oniYLGo
^jO5ok^Wa@03ok^Wa@03okfYa_nnZ/Go_Z[500;o_Z[50oo1[<H2ol:]a@?oa;360oo6/LD2olRcaP?o
b[G60oo;]lL3olfia`03oljkb?o@_LSod;g800;od;g81OoA`L/2omC4b`03om;5c_oDb<koe<S>00;o
e<S>00Goe/_>omC<d_oDc=;oe<cBo`000002omK?dP?of=CE0ooJf=D00ooMgMKo^]G]ok[Ek@02ok[E
kB3oZKgX00?o0000ooooooooool08?ooool000Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0001Wooooo=?nY_NP3ohNM
h@?oR9cP0on:W=l5oh^Kg@?oS9[L0on=VMX3ohjHf0CoSiOG0_nAUmH01?n?UMGoTICCoi6DdonAU=<4
oi:DdPCoU9CA1?nFUM03oiREc`GoVYK>0_nMU/d00onLU<_oWiG9oinEb@03oinEb@?oXYK80onUV<P3
o`0000?oZ9S51?n[V/D3ojfLa@03ojjJ`on_W<Co[ic400?o[ic40onaW/D00onbWL?o/io4ok>Oa003
ok>Oa0?o]:7500?o]J74okNSaOngXlD01?ngXlD01?nhYLGo^JG5okVUaOniYLD4ok^Wa@03okbXaOnn
Z/Go_Z[500Co_Z[500?o`Jc6ol:]aOo2[LD00_o2[LD00oo4/<Koa[75olJaa@02olJaa@03olRca_o:
]LKob[G600?ob[G600?obkO7olfiaoo=^LL00_o=^LL5om2mb004om:ob?oA`L_odL7;om71b`?oe<C;
1OoDb<h2omK;cP04omC<d_oFcm;oe/oBo`0000;ofM;B00?of=CEom[HeOoJf=D00_oJf=D2omgMeP;o
^]G]8OnY_NP00ol0003oooooooooo`0Pooooo`001?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Wo
oooo=?nY_NP3ohNMh@?oR9cP0on:W=l2oh^Kg@;oR9WM0on9Um/3ohZFf@?oS9KH1?n=UMH4ohnEe@?o
TICC1?nBU=83oiBDd@CoUYG@1?nHULl2oiZFcP;oVI?<1?nLU</4oinEb@?oXYK800GoYIS8o`000?l0
003oYIS8ojFFa@04ojRHa@GoZi[500Co[Ic5ojjJ`on^V/?o[Y[31On_W<@01?naW/Go/Yg3ok:M`onb
WL<5ok>Oa004okBQaOneXLCo]J74okFQa0Co]j?500?o^:?4okVUaOniYLD00oniYLD2ok^Wa@?o_:S5
1?nnZ/D00oo0ZlGo`Zg5ol:]a@02ol:]a@03olB_aOo6/LGoa[7500?oa[751Oo:]LH00oo<]lKocKW7
olfia`02olfia`;od;_60oo@_LP3om:ob003om71booDa<_oe<C;00;oe<C;00Coe/K;omC8c_oDb<ko
e<S>0ooFblh3omK?dP04o`000?oId];ofM;Bom_Fd`?of]SE0_oMgMH00ooMh]WoZKgXojVmj00RojVm
j003o`000?oooooooooo01oooooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0J
oooooc3oZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l5ohRIg@?oRIOK0on:U]T3ohbFf0CoSIGF0on?UMD3
oi6Dd`CoTYCB1?nDU=44oiJEd0;oV9G?00?oUi?>oiVCc?nITl`00onITl`3oibDb`CoWiG900GoXYK8
o`000?l0003o0000ojFHb004ojFFa@?oZ9S51?n[V/D00on[V<;o[Y[3ojjJ``02ojjJ``Co[ic400?o
/9_2ok:M`onbWL<00_nbWL<4ok>Oa003okBO`oneXLCo]J7400;o]J740ongXlD3okRSa0Co^JG500?o
^jO5okbXaOnlZ<D00_nlZ<D3okjZa@?o`:_50_o2[LD3olB_a@?oa[750_o8/lD3olZeaP?oc;O60_o=
^LL4om2kaP04om2mb?oB_lSod[o8om:ob0;oe<;80ooDa</3omK6b`04omC8c_oFblkoe/_>omK;cP;o
f<g?00Goe/oBomWBd_oId];o0000omWBdP02om_Fd`03om[HeOoMgMKogMgF00?ogN;I8onY_NP2o`00
023ooooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo0_l0000Loooooc3oZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l4ohRI
g@?oRIOK0on:U]T3ohbFf0GoSIGF0on?UMD3oi6Dd`CoTYCB0_nDU=400onBTm3oU9??oiBCc`02oiBC
c`CoUi?>1?nITl`3oibDb`;oWiG90ol00002oj:Fb003oj6Ca_nUU/GoYIK500?oYIK51?nXV<D00on[
V/GoZiS2oj^H`P02oj^H`P?o[Y[30on_W<@3ok2K`P?o/Yg30oncWl@3okBO``Co]J7400?o]j?5okRS
a?nhXl@00_nhXl@3okVUa@03okZUa?nlZ<Go_:S500Co_:S500?o_Z[5ol2[aOo0ZlD00_o0ZlD00oo2
[LGoa:o5olB_a@03olB_a@03olJaaOo8/lGob;?500;ob;?500?ob[G6olbga_o<]lH00_o<]lH00oo=
^LOod;_6om2kaP03om2kaP?od[o81?oD`/P01OoDa<_oe/K;omK6booFa/_of<W;00?oe/_>0ooHcLl0
1OoKdLoofM;BomWBd_oId];o000000;ofmKC00?og]_ComgMe_oMh]T00ooMh]T00oo?jNSoZKgXojVm
j00QojVmj003o`000?oooooooooo01kooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0MooooobooZKgX0on=Y^H3ohJLhP?oQicQ0on7V]l4ohRIg@?oRIOK0on:U]T3ohbFf0;oSIGF
0_n<TmD3ohfCe0?oSi?C1?nATm84oi:Cd0CoU9??0onGTlh4oiVCc0;oW9C;0ol000000onOULWoWY;7
oijBa`04oj6CaPCoYIK50onXV<D00onXUL;oZiS2oj^H`P03oj^H`PCo[Y[300?o[ic4ok2K`_n`Vl80
0_n`Vl84ok:M``03ok>Oa?ndWl?o]9o300;o]9o30oneXL@00onfXL;o^:?4okRSa004okRSa004okVU
aOnjYLCo^ZG4okZUa0Co_:S500?o_ZS4ol2[aOo0ZlD00oo0ZlD6olB_a@Gob;?51Oo<]lH5om2kaP;o
d[g600?od[o8omC2b?oD`/P00ooD`/P3omK6b`?of<W;00?oe/_>omS=cooHcLl00_oHcLl2om_Ac`04
omWBd_oKe]?ofmKCo`0000;og]_C00Coh=oDomgRfOoMh]WogN;I0oo?jNPRojVmj003ooooool0003o
oooo01kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo01kooooo;OnY_NP01?nG]NgoPYcSoh:L
hon2W><3ohBLhP?oQ9[Q1?n4V=l3ohBFg@?oQYGK0on7U=T3ohVCe`GoS9?E0on=Tm@3ohnCd`CoTI?B
0onBTm04oiBCc`CoUi?>0_nITl`3o`000003oibDbonJTLWoWY;700CoWY;70onQTlH5ojFFa@04ojRH
aOnXUL;oZ9G2ojRE`PCoZiS20on^V/<00on^V<7o/9_2ok2K`P03ok2K`P?o/Yg300?o/ic1okBO`ond
Wl<01?ndWl<01?neXLCo]Z72okJQ`_nfXL84okRSa003okVS`onjYLCo^ZG400;o^ZG40onlZ<D3okjX
a0?o`:_50_o2[<@4olB_a@;oa[351?o8/lD00oo:]<Goc;O6olbgaP02olbgaP04oljia_o@^lKod;_6
om2kaP?od[g61OoD`/P2omO4b003omK6booHbL_of<W;00;of<W;00Cof/c;omS=cooHcLoof<g?0ooK
dLl3om_Fd`03o`000?oNfm?og]_C00;oh=oD00GogN;IoloYj?o?jNSocnWXok78j`0SojVmj003oooo
ool0003ooooo01gooooo000Vooooo`;o00007oooool/ojVmj0?oUkG]0on2W><3ohBLhP?oQ9[Q1?n4
V=l3ohBFg@?oQYGK0on7U=T3ohVCe`CoS9?E0on=Tm@3ohnCd`CoTI?B1?nBTm04oiBCc`;oUi?>0ol0
0002oiNAb`CoVY791?nNT/L4oj6CaP;oYIK50_nUTl<4ojRE`PGoZiS200Co[Y[3ojjH`On^V<7o[YS1
1On`Vl801?nbWL?o/ic1ok>L`OncW<44okBO``03okFN`OnfXL;o]Z7200;o]Z720onhXl@3okVS``Co
^ZG400?o_:S5okjXa?nnZ<@00onnZ<@01?o0ZlGo`Zc4ol:/a?o2[<@3olB_a@?oa[350oo8/lD2olZd
a@?oc;O60oo>^LH00oo@^lKod[g6om:maP02om:maP04omC0a_oD`/Soe<;8omC2b0?oelC81OoHbL/2
om[<b`03omS=cooKdLoofm7?00;ofm7?00GogMC?om_FdooNfm?og]_Co`000002on3Oe0;ohnGD00?o
cnWXok78jonab>/00_nab>/SojVmj003o`000?oooooooooo01cooooo000Uooooo`;o00008Oooool/
ojVmj0?oUkG]0on2W><3ohBLhP?oQ9[Q1?n4V=l3ohBFg@?oQYGK0on7U=T3ohVCe`CoS9?E0on=Tm@3
ohnCd`CoTI?B0_nBTm001?nATM3oTi7>oi>Ac_nCTLh3o`0000;oUI3=1?nGTL/3oiZAb@GoWY;70_nQ
TlH00onQTL?oYI?3ojFC``03ojFC``?oZ9G21?n[V<800on/U/3o[YS1ojjH`@02ojjH`@Co/9_200?o
/IZook>L`OncW<400_ncW<43okBO``?o]Ik11?nfXL800onhXlCo^J?3okVS``02okVS``?o^ZG400?o
_:K3okjXa?nnZ<@01?nnZ<@5ol:/a003olB_aOo6/<Goa[3500?oa[3500?ob;?5olZdaOo:]<D00_o:
]<D00oo<]lKoc[W6oljiaP02oljiaPCod[g60ooD`<H00ooD`/SoelC8omO4b002omO4b004omW7b?oH
bL_of<W;omS9b`?of/c;00Cog<o<om_AcooKdLoofm7?0_oMe<l2omoId003omkKdooPgmCo000000?o
hnGD0_oUk=<2ok78jbCoZKgX00?oooooo`000?ooool07?ooool002Gooooo00?o0000ooooooooool0
8OoooolZojVmj004ojNmjOmnVnCoOY_TogjKi0?oPIcT0on1V^<3oh2Hh@CoP9GN0on1Tm`3oh:BfP?o
QI7H0on7TMH4ohVAe@?oS97C0on>TM84ohnAd@?oTI7@0ol00002oi>AcP?oUI3=1?nGTL/4oiZAb@;o
WY;70_nLSlD4oj6A``CoYI?31?nXUL800on[V<;o[9K0ojbF`002ojbF`0Co[YS100?o/9_2ok6J_ona
V[l00_naV[l4ok>L`@03okBO`oneW/7o]Ik100;o]Ik11?nfXL86okVS``04okZUa?nlY/?o_:K3okbV
``Co_ZS40_noZL@4ol:/a0Goa[3500?ob;;4olZdaOo:]<D00_o:]<D00oo<]lGoc[W6oljiaP03olji
aP03om2kaOoB_LKod[g600Coe<361?oGa<P3omW7b003omS9booJc<_of/c;00;of/c;0_oLcl`00ooK
dLoogMC?omgDc`03omoId005on;Md?oPgmCohnGDo`000?oSiM@00_oUk=<00ooDmnCoZKgXojVmj00U
ojVmj003ooooool0003ooooo01_ooooo000Uooooo`03o`000?oooooooooo02;ooooo:?nY_NP3ojNm
j@?oOY_T0on1W>@3oh6Jh`?oP9SQ1?n0UMh3oh6Cg0?oPY;J0on5TMP3ohNAePCoRI7E0on<TM<3ohjA
dP?oSi7A0ol000000onATM3oTi7>oi>AcP02oi>AcP?oUI3=1OnGTL/2oiZAb@03oiV>aonLSlGoW8o5
00;oW8o51?nQTL<4ojFC``?oZ9G200?oZ9>oojbF`?n/U/000on/U/04ojjH`@Go/IZo1?ncW<45okFN
`@?o]Z720_nhXL44okVS``03ok^S`_nlY/?o_:K300;o_:K30onnZ<@3oknYa0?o`Zc40_o3[L@3olJ`
a@?ob;;40_o:]<D3olbga@?oc[W60oo@^lD00ooB_LKoe<36omC0aP02omC0aP03omK2a_oGa<SoelC8
00CofLO800Cofl[8om[<booJc<_of/c;0ooLcl`00ooOd/cogMC?omoId003omoId004on;Md?oUhm3o
iN?@o`0000;oiNcC0ooDmn@WojVmj003o`000?oooooooooo01[ooooo000Uooooo`;o00009?oooolX
ojVmj0?oYkgY0omnVn@3oh6Li0?oPI[S0on0V>44oh2EgP;oPI?L0on2T]X3ohFAf0?oQi7F1?n9TMD3
ohbAd`?oSY7B00CoSi7Ao`000?l0003oSi7A1?nATM04oi>AcP?oUI3=0_nGTL/2oiF=b@CoVHk71?nL
SlD3oj6A``GoYI?300CoZ9G2ojRC_onXTkooZ9>o1?n/U/03ojjH`@;o[iNn1?naV[l3ok>L`@;o]9bo
1OneW/401?nfXL;o^:71okRQ`OnhXL43okVS``?o^j?21?nlY/<00onnZ<Co_jW4oknYa003oknYa003
ol:/a?o3[LCo`jg400;o`jg400?oa[35olRba?o8//@00_o8//@00oo:]<Goc;O5olbga@03olbga@03
oljia_o@^lGod;_500;od;_500Codkg5omC0a_oD`<Koe<360ooF`/H01?oGa<SofLO8omW7b?oIalP3
om_:b004om[<booLclcog<o<omc?c0;ogm;<00CohMK<omoId?oOfM3ogmW@0_oRgM02onGSd003onOY
d?l0003oe?OT00?oe?OT:?nY_NP00ol0003oooooooooo`0Iooooo`009Oooool00ol0003ooooooooo
o`0UooooobOoZKgX0on;[nh2ogfKi@?oOY_T0omlV><3og^Eh@CoNi;N0omlT=`3oh:BfP?oQI7H0on7
TMH4ohVAe@?oS97C0ol00004ohnAd@;oTI7@00?oShk?oi2>cOn@S/d00_n@S/d3oi:=b`CoUHg91?nI
S/L4oib?a@CoXI730_nUTl<2ojB@_`CoZ9>o1On/U/001?n^V<7o[iNnojnG__n_Ukh5ok6J_`04ok>L
`OndW;oo]9bookBL_`Co]Ik100?o]ijookRQ`OnhXL400onhXL400oniXl?o^j?2ok^S`P02ok^S`PCo
_:K31OnoZL@00oo1Zl?o`jg4ol>]a003ol>]a0Gob;;41_o<]lD4om2ka@?odkg500?oe<36omK2a_oF
`/H00_oF`/H3omW7b0Cofl[80ooLcl`3omoBc0;ohMK<00?ogmW@on;Md?oRgM000ooUhm000ooWjM3o
jO3?o`000002omCgi0;o[lCZ9onY_NP00ooooooo0000ooooo`0Iooooo`009Oooool00ol0003ooooo
ooooo`0VooooobOoZKgX0on;[nh2ogfKi@?oOY_T0omlV><3og^Eh@CoNi;N0_mlT=`3ogn?fP?oPXoH
0on5SmH4ohR?e0?o00000on<Sm44ohf?d0CoShk?1?n@S/d3oi:=b`CoUHg90onIS/L4oib?a@;oXI73
0_nOSL44ojB@_`CoZ9>o1?n/U/000on]U;go[iNnojnG_P02ojnG_PCo/IZo00?o/iVmokBL_ondW;l0
0_ndW;l3okFN`@?o]ijo1?nhXL45ok^S`P?o_:K30_nnYl83oknYa0?o`J_31?o3[L@00oo6[lCob;;4
olRba002olRba003olZda?o<]lGoc;O500;oc;O50_o?^LD2om2ka@Codkg51?oF`/H2omS5aP03omW7
b?oKb/Sofl[800;ofl[80_oMcLT01?oLclcogm;<omoBc?oOd/`3on7Fc003onCKc?oRgM3oiN?@00;o
iN?@0_oWjM000ooYl<oo0000ojo4jP04ojo4jROoZKgX0_l0000Iooooo`009?ooool01?l0003ooooo
o`000?l0000WooooobGoZKgX00CoY;cZogNIi_mgVNKoMiWV0omkVnH3ogjKi0?oO9SS0omkUN43og^B
gP?oO93L0omoSmX3oh:?f0?oQHoF0ol000001?n8SmCoRXoCohZ?don:Sm<3ohb?d@CoSHo@0on?S/l4
oi2>c@?oTXg;1?nESLT4oiV>a`;oW8o500?oVh_2oin=`OnOSL400onOSL44ojB@_`CoZ9>o00?o[9K0
ojfD_On]U;d00_n]U;d4ojnG_P03ok6J_oncVKgo/iVm00;o/iVm1?ndW;l00oneW/7o]ijookNN_`02
okNN_`?o^:710_niXKl5ok^S`P03okbV`onnYl;o_ZO200;o_ZO200?o_jW4ol6[`oo1Zl<00_o1Zl<3
ol>]a0;oaZo40oo8//@2olZda0?oc;O50oo?^LD00oo@^lGodkg5om>ma@02om>ma@;oeL350_oF`/H3
omS5aP04om_8a_oKb/Sofl[8om_:b0?ogLg900?oh=39omoBc?oOd/`00ooQe/`2onCKc003onOPcOoU
hm3oiN?@00;oinW@0ooYl<l00ol0003o[lCZojo4jP0YojVmj003ooooool0003ooooo01Sooooo000T
ooooo`;o0000:_oooolSojVmj0?oY;cZ0omgVNH3og^KiP;oNYWU0omgUN<3ogFBh@?oMXoN00CoNi;N
ogb@g?mlT=coO93L0omoSmX2oh:?f0?o00001?n8Sm@3ohZ?d`?oS8oA1?n=Sm03ohn>c`GoT8k=0onB
SL/3oiF=b@;oVHk70_nFR/@4oi^;`PCoWhg11?nTT;l3ojRC_`03ojV@_?n]U;go[IBm00?o[IBm1?n_
Ukh5ok>I_@?o]9bo00?o]Y^mokNN_ongW[l01?ngW[l01?nhXL7o^J6ookVQ_oniXKl4ok^S`P03okbT
`?nnYl;o_ZO200?o_ZO21_o1Zl<00oo3[LCoaZo4olJ_a002olJ_a003olRba?o:]<Cob[C400;ob[C4
00?oc;O5olniaOo?^LD00_o?^LD01?oA^lCodkg5om>maOoC_LD3omG0a@03omK2a_oHaLKof<G600;o
f<G60_oKb<H00ooKb/SogLg9omg=b@02omg=b@;oh=3900?ogm;<on7Fc?oQe/`00ooTfl`2onOPc@03
onGSd?oWjM3ojO3?00;ojO3?00?ojOS;olgcj_l00000:onY_NP00ooooooo0000ooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0Zooooob?oZKgX0onT_>X3ogNIiP?oNi_V0_mjVND3ogNEh`?oMI;Q
0omfSmh3ogR>g0;oNhgI0ol000001?moSMOoQHoFohF?e_n5SmH4ohR?e0?oRXoC0on<Sm44ohf?d0?o
Shk?0_n@S/d2ohf;c0?oSh[90onBRLL5oiJ:a0?oVh_21?nOSL44ojB@_`03ojRC_onYT;coZI2l00;o
ZI2l1?n]U;d3ojnG_P;o/IJk1OncVKd01?ndW;oo]Y^mokJK_OnfVkd4okNN_`03okVN_OniXKoo^J6o
00;o^J6o0onkXl83okbT`0Co_ZO200?o`:S1ol6[`oo1Zl<00_o1Zl<00oo4[<;oaZo4olJ_a003olJ_
a0Gob[C41Oo?^LD2om6ka003om>maOoE`<GoeL3500;oeL3500Coel;5omS5a_oHaLKof<G60ooKb<H0
1?oMblKogLg9omg=bOoMcLT3on3@b@03on;DbOoQe/coi=_<00;oi=_<0ooWh<d01OoYi/cok>g;onc]
booYl<oojOS;00?ocO?Z00?o0000ojVmj?nY_NP0:OnY_NP00ol0003oooooooooo`08ooooo`Co0000
00?o410@ooooooooool01oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0:ooooolSojVmj0;o
RK;a0omgV^L3ogRJi`?oM9OU0omgUN<2ogFBh@CoMXoN00CoN8kLo`000?l0003o00000_mkSMT2ogn=
e`?oPhkF1?n6S]@3ohR>dP?oRXgA1?n;SLl3ohb<cPGoSH_<0on?R/T3oi:9a`CoUX[40onKRl85oin=
`@;oY92o00?oY8flojV@_?nYT;`00onYT;`5ojfD_@04ojnG__naU[_o/IJkok6F^`Co/iVm00?o]9Rk
okJK_OnfVkd00_nfVkd3okNN_`?o^Ijm1?niXKl00onkXl;o_:C0okbT`002okbT`0?o_ZO20_o0Z<43
ol6[``;oa:c21?o6[l@2olR```?ob[C40_o<]/@3olnia@?odK_41OoE`<D2omO2a@03omS5a_oKb<Ko
flS600;oflS60_oMblH01?oMcLWoh=39on3@bOoPd<T2on;Db@03onGHbOoTflcoi=_<00?oin3=0_oY
i/`2onc]b`06onceb?oYnkoocO?Zolgcj_nY_NSo0000;?nY_NP00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool2o`0002gooooo8onY_NP2ohVbl@?oMi[W0omhV^L2ogBGi@?o
LI;S0om_S^401?mfSmko0000o`000?l00002ogR>g0?oNhgI0omoSML3oh>>ePCoQXkD0on8S]83ohZ=
d@CoRhg?0on<S<h4ohf;c0?oSh[90onBRLL4oiJ:a0CoVh_20onOSL400onOR[goY8flojB=_002ojB=
_0CoZI2l1?n]U;d00on^T[[o/IJkok6F^`02ok6F^`?o/iVm0ondV;/4okJK_@03okNN_oniW[go^Ijm
00;o^Ijm1?niXKl6okbT`003okjW`_o0Z<7o`:S100;o`:S100?o`J_3olB/`_o4[<800_o4[<82olJ_
a0Cob;3300?ob[C4olbfa?o<]/@00_o<]/@00oo?^LGodK_4om6ka002om6ka004om>ma?oE`<GoeL35
omG0a@?oel;51?oKb<H3omg;aP?oh=390ooRe<T2onGHb@03onCKc?oWh<goin3=00;ojNK<0oo/kL/0
0oo/mLSojO^ool_l^P03ojVmj003o`000?nY_NSoZKgX02WoZKgX00?oooooo`000?ooool02Oooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooob;oZKgX0om`Vn/3ogNJi`?oN9[W0_mdUnD3
og6Bh`03ofn>hOl0003o000000?oL8cN0omcRm`3og^=f@?oOhgG0_n3S]H4ohJ>e0?oR8kB0on:SM44
oh^=c`?oS8c>1?n=Rl`3ohn:b@?oTXW71OnFR/@3oi^;`P03oin=`OnOR[goWhZm00;oWhZm0onTSK`5
ojV@_004ojfD_On^T[[o[Y:jojjB^PGo/IJk00?o/iVmokBH^ondV;/00_ndV;/4okJK_@Go^Ijm0oni
XKl2ok^Q_PCo_:C000?o_ZFool2X`Oo0Z<400oo0Z<45olB/`P03olJ_a?o8/<?ob;3300?ob;331Oo<
]/@4om6ka0?odkg400?oeL35omO2aOoG`/D00_oG`/D00ooJaLGoflS6om_8aP04omg;aP03on3>a_oP
d<Woh]C900;oh]C90ooUf<T01?oXgLWoin3=onWVc?oYi/`3onc]b`03onceb?oYnkoojO^o00;obobj
0onY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0;_oooolRojVmj0?oL9_[0_meVnP3og>Ij0?oKYCV0ol00002ofn>h@CoL8cN
0_mcRm`3ogN;f@?oO8_G0on0S=H4ohJ>e0?oR8kB0on:SM44oh^=c`?oS8c>1?n=Rl`3ohn:b@?oTXW7
0_nFR/@2oi>6`P?oVHNo1OnOR[d3ojB=_0CoZI2l00?oZHjiojjB^_n^T[X00on^T[X3ok6F^`03ok:E
^OndV;_o]9Rk00?o]9Rk0onfVkd2okRK^`Go^Ijm00Co^J6ook^Q__nkXKko^j6n0onlY<02okjU_`Co
`:S10_o2ZL04olB/`PGob;3300?ob[;2olbfa?o<]/@00_o<]/@2olnh``;odK_41?oC_L@4omO2a@?o
f/G500CoflS6omg;a_oMblKogL_60_oPc/H00ooRdLKoh]C9on;Db@04onGHb@04onSMbOo[hlSojn?8
onWVc0;ok>g;00Cok?G8onWk_ooYnkoobobj1_nY_NP00ol0003oZKgXojVmj00XojVmj003ooooool0
003ooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0`ooooob;oZKgX
0om`Vn/2ogFKj0;oLiWX0ol00003ofZ?h`?oJ8_Q0om`S=h3og>;g0?oMh_I0omlRmL2oh2<ePCoPhcD
0on5S=83ohN;d0CoR8[?0on9R<d4ohZ7bP?oS8K70on?QLD5oi>6`P?oVHNo1?nOR[d4ojB=_003ojV@
_?nYS[WoZHji00;oZHji1?n^T[X2ok6F^`?o/YFi1OndV;/01?nfVkgo^9^kokRK^onhVk/4okVN_@03
ok^N_?nkXKko^j6n00?o^j6n00?o_:C0okjU_onnYKl00_nnYKl2ol2X`@?o`ZW00oo4[<82olJ]`@?o
b;330oo://82olbfa0CockS300CodK_4om>ma?oC_LCodkg40_oF_l@2omO2a@Cof/G50ooMblH3on3>
aP;oh]7600Coh]C9onGHbOoUf<WoiMS90_oXgLT2on_Sb006onkZaoo/kL_ok?G8onceb?oYnkoo_>R8
1onY_NP00ol0003oZKgXojVmj00YojVmj003ooooool0003ooooo00Oooooo00?o0000ooooooooool0
2Oooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
0ol0000boooooakoZKgX0onJ^Nd2of^Gj@04og:JjOl0003o0000o`0000;oLiWX0_m^U>H3ofZ?h`;o
J8_Q0omZRMh01?m`S=koLh_Log>;g?mcRm`2ogN;f@?oO8_G0on0S=H4oh><e0?oQHcB0on7Rm04ohR:
c`?oRHS=0on:QlX4ohb6a`?oShG51?nCQ/83oiV7_`GoWhZm0_nTSK`00onTR[WoZHjiojV>^@03ojV>
^@Co[Y:j00?o/IJkok:E^OnbUKT00_nbUKT4okBH^`03okNH^?nhVk_o^9^k00;o^9^k0oniW[d2ok^N
_0Co^j6n00?o_Z:mokjU_onnYKl00onnYKl00oo0Z<7o`ZW0ol:Y`003ol:Y`003olB/`_o6[L7oaZg1
00;oaZg100?ob;33olZb`_o://800_o://800oo<]/CockS3olnh``03olnh``?odkg41?oF_l@01?oG
`/Gof/G5om[5aOoJaLD2omc8a@04omg;a_oPc/Koh<k6on3>aP?oh]760_oUeLH00ooUf<Woj=g9onSM
b@03on_Sb005onkZaoo_lLCoko74ongh_OoRnJ`00_nlj8P7ojVmj003o`000?nY_NSoZKgX02WoZKgX
0_l00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03?ooooo7_nY_NP2oiZik@?o0000
0ombV^T2ofjGj0?oIi7V0omZSn<2ofR;h@?oJXWN0om^R=`3og>9fP?oO8_G0_n0S=H4oh><e0?oQHcB
0on7Rm04ohR:c`?oRHS=1?n:QlX3ohb6a`?oShG51?nCQ/83oiV7_`GoWhZm00CoY8flojB:^OnTR[Wo
Y8Zi1?nYS[T4ojjB^PGo/YFi0ondV;/2okNH^0Go^9^k00?o^Ijmok^N_?nkW[`00_nkW[`2ok^Q_P?o
_Z:m1?nnYKl6ol:Y`0GoaZg11Oo://85olnh``;odK[300?odkg4omJoa?oF_l@00ooF_l@3om[5a@?o
g<S500?ogl_4on3>a_oPc/H01?oRdLH2onGEaP;oj=g90oo[hlP2onkZa`;oko7400CokORmokcXR?nb
bN_o//W[2?nY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00?ooooo00?oEEEEofIV
I_l000002oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0doooooacoZKgX0ol000001?n2/?;oJIS[ofVHjomYV>/3og:Jj@;oKYOX0omWTNH2
of:;i0?oHHOQ0omZRMh3ofj8g0;oLhWJ0omhRMP3ogf:ePCoPhcD0on5S=83ohN;d0CoR8[?0_n9R<d4
ohZ7bP?oS8K70on?QLD5oi>6`P?oVHNo0_nOR[d2oif6^PCoY8Zi1OnYS[T2ojjB^P;o[i6g1OnbUKT0
0ondV;_o]iRhokNH^002okNH^0?o^9^k00?o^Y^iok^N_?nkW[`00onkW[`00onkXKko_Z:mokjR_@02
okjR_@?o_ZFo0_o1Y[h4ol:Y`0;oa:Zo1?o6[L400oo8[l7ob[;2olZb`P02olZb`P04olfd`_o?^<?o
ckS3olnh``?odK[31OoF_l@2omS2``03om[5aOoLb<Gog<S500;og<S50_oObl@01?oPc/Koh]76on;A
a_oRdLH3onGEaP04onSJa_oXgLWojn?8on_Sb0;ok^[70_o_lL@00oo]n;go0000ok;9j`03ok;9j`Oo
ZKgX00?o0000ojVmj?nY_NP0:OnY_NP00ol0003oooooooooo`0Aooooo`008oooool00ol0003ooooo
ooooo`0eoooooaSoZKgX0ol00003ojVmj0;oP[3b0omYV>/2offJj`?oIiCY0omWTNH2of:;i0;oHHOQ
0omSQMh3ofj8g0?oLhWJ0omhRMP2ogf:ePCoP8[D0on2R]83ohB9d0CoQ8O>0on4QL`3ohZ7bPCoS8K7
0on?QLD4oi>6`P;oVHNo00?oUh>loif6^_nMQ[X00onMQ[X3ojB:^@GoZHji00Co[Y:jojnA]on_TKOo
[i6g1OnbUKT5okNH^0;o^9^k0onjVkT4ok^N_0Ko_Z:m00Co_ZFool6V__o1Y[ko`JJn0oo2ZL03olBZ
_`?oaZg10_o8[l43olZb`P?ocKC200?ockS3om6j`ooA^/<00_oA^/<01?oD_<;oe[o4omJoa?oF_l@3
omS2``04om_4`ooLb<Gog<S5omc8a@?ogl_400?oh/k4on;Aa_oRdLH00ooUeLH2onSJaP;ok=o500Ko
jn?8onkZaoo_lLCoko74ongh_OoRnJ`2o`0000;o//W[2OnY_NP00ol0003oZKgXojVmj00YojVmj003
o`000?oooooooooo013ooooo000Sooooo`;o0000=ooooolDojVmj0?o00001onY_NP2ofNTl`?oJIS[
0_m]V^/3ofNDj@;oGXgW0omIQn@2of67h@;oHhGN0omXQ]`01?m^R=coLhWJog>9f_mcRMX2ogR9f0?o
OH[F1?n0R]@3oh::dP?oQ8W@1?n4Qlh2ohB5c0?oQH?91?n7PLH3oh^0``CoT86o1?nGPk`4oif6^PCo
Y8Zi0onYS[T00on[SKKo[i6gojnA]`02ojnA]`Co/YFi0_ndU;H4okNH^003okRK^onjVkWo^Y^i00;o
^Y^i1?nkW[`00onmWk[o_Z:mokjR_@03okjR_@Go`JJn00?o`ZW0olBZ_oo4Z[l00oo4Z[l00oo6[L7o
b:o1olR_`@02olR_`@03olZb`_o=]<;ocKC200;ocKC21?oA^/<3omBl`P03omJoa?oH`/?of<;300;o
f<;30_oKa<<00ooLb<Gogl_4omo;a002omo;a0;oh/k400?oh]76onGEa_oUeLH00ooXf/H2oncOa@06
onoVa?oak/7oko74oo7e^_oXn:co00003_nY_NP00ol0003oZKgXojVmj00XojVmj003ooooool0003o
oooo013ooooo000Rooooo`03o`000?oooooooooo03Sooooo4?nY_NP3o`0000_oZKgX0_mWY?<2ofJI
k0?oIiS/0omWU>T2oej=i`;oFHOT0omHPn42of>5gP?oJ8KL0om^QmX3ogB8f0?oOH[F0on0R]@3oh::
dP?oQ8W@1?n4Qlh3ohB5c0?oQH?91?n7PLH3oh^0``CoT86o0onGPk`4oif6^PCoY8Zi00?oZHjioj^=
]_n[SKH00_n[SKH4ojnA]`;o/YFi0ondU;H4okNH^0Go^Y^i0onkW[`2okfO^PCo_Z:m0_o0Xk/4ol6V
_PKoa:Zo1Oo8[l45olfd`P03olnf`OoA^/?odK[300Coe;c21?oH`/<3om_4``Cogl_40ooRc/@00ooU
d/?oiMG6onSJaP02onSJaP?ok=o500GoknK4oo7^`OoamK[olOFjonSh[00@ojVmj003o`000?nY_NSo
ZKgX02SoZKgX00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0>Oooool=ojVm
j0;o00003_nY_NP3oe2Dk`;oIYW/0omWV>`2oenAjP?oEHWW0_mIQn@2oeR3h@?oG8;O0omXQ]`3ofj7
fP;oM8SH0omiR=H3ogb8e004oh2:e?n2R];oPX[Boh::dP?oQ8W@0on4Qlh3ohB5c0?oQH?91?n7PLH3
oh^0``CoT86o0onGPk`5oif6^P;oY8Zi00?oY8Rfoj^=]_n[SKH00on[SKH4ojnA]`03ok:E^OndU;Ko
]9Bf00;o]9Bf1?ngV;P00oniV;Ko^Y^iokZK^@03okZK^@04ok^N_?nmWk[o_InjokfO^P?o_Z:m0oo0
Xk/4ol6V_P03ol>W_Oo4Z[ooa:Zo00;oa:Zo0_o7Zkh4olR_`@04ol^`_oo=]<;ocKC2olfd`P?ockK1
00?odK[3omBl`_oD_<800_oD_<800ooG_/;of<;3omS2``04om_4``03omk7`_oOblCogl_400Coh/k4
00CoiM;3onSF`ooXf/Koj=[60oo/glD01Oo_i/ColNk1oo7^`OoamK[oj?R/017oZKgX00?o0000ojVm
j?nY_NP0:OnY_NP00ol0003oooooooooo`0>ooooo`008_ooool00ol0003oooooooooo`0jooooo`Wo
ZKgX0ol0000AojVmj0?oD9C_0_mRVNh3ofNHk0;oGi7Z0_mERNL3odn3i0;oF8?Q0_mLP]l3of:3g@03
ofR6g?m^Qm[oKXOJ00?oM8SH0omiR=H3ogb8e0?oOXOB0omoQ]03ogn3c@04ohB7c_n4QLcoQ8G<ohB5
c0;oQH?91?n7PLH3oh^0``CoT86o1?nGPk`4oif6^P04ojB:^OnTR;KoY8RfojB8]PCoZhff1?n_TKL6
okBD]P;o]iRh0_niV;H5okZK^@Go_Inj00?o_Z:mol2S^oo0Xk/00_o0Xk/3ol6V_P;o`jNm0oo4Z[l3
olN[_P?ob:o10oo;/;l00oo=]<;ockK1olnf`@02olnf`@Coe;c20ooG_/801?oH`/?oflC3om_4`ooK
a<<3omk7`P04omo;a?oRc/Coh/k4on;>a0;oiM;30_oXe/<01?oXf/Kok=o5oncOaOo_i/@2oo7^`@;o
lOFj00?ocNf<ojVmj?nY_NP04?nY_NP00ol0003oZKgXojVmj00YojVmj003o`000?oooooooooo00go
oooo000Rooooo`;o0000??ooool5ojVmj0?o00005OnY_NP3oe2Dk`;oHYW^0_mQU^d3oeJ>jP;oEHWW
0_m?Pn@3odmoh@;oG8;O0omRPmd3ofV4f`;oM8SH0omiR=H4ogb8e0?oOXOB0omoQ]03ogn3c@?oOh3;
0omoO/L4ohN1aP?oRh331?n@PKl3oiN3_0;oWHJj0_nLPkL4ojB8]PGoZhff0_n_TKL2ok6@]0Go]9Bf
00Co]iRhokVH]_niV;Ko^IRf1?njVkT2okbL]`Co_Inj1_o0Xk/00oo1Y[ko`jNmol>W_@02ol>W_@03
olBZ_oo7Zkkoaj^n00?oaj^n00?ob:o1ol^`_oo;/;l00_o;/;l5olnf`@03om:h`?oD_<;oe;c200Co
ekk200?of/71om_4`ooKa<<01?oNal83on;>a0;oiM;30ooXe/<01Oo/g<;ok=o5onoVa?o_i/ColNk1
00;olOFj00?oj?R/ojVmj?nY_NP04_nY_NP00ol0003oZKgXojVmj00XojVmj003o`000?oooooooooo
00gooooo000Rooooo`03o`000?oooooooooo03cooooo00CoZKgXo`000?l0003o00005_nY_NP3ojFl
j@;oAXc/0omMV>l2of6Fk@?oEXkZ0_m;QNL2odn3i0;oCgoQ0omCOml3of:3g@;oJHCK0om_Q]T3ogV8
eP?oO8SD0omnQm83ogn6d0CoOh?=0omoP</2ogmna`CoPGc40on5Nl44oi21_`;oUh>l00?oU7njoib3
]onLPkL00onLPkL3ojB8]PGoZhff00Co[i6gok6@]?naT;Co/I2d1?ndU;H00ongUKCo^IRfokVH]P03
okVH]P;o^Y^i0onlW;L4okfO^P03oknP^?o0Xk_o`:>k00?o`:>k1Oo3Ykd6olN[_PCobk2o0_o>/[l3
olnf`@?od[S000?oe;c2omNn`_oG_/800_oG_/82om[1`@03om_4`ooNal;og/O200;og/O200CohL[2
on;>a?oUd/?oiM;31?oXe/<01Oo/g<;ol>;1oo3R`OocjKkolNk100;olOFj5_nY_NP00ol0003oZKgX
ojVmj00XojVmj0;o00003Oooool002;ooooo00?o0000ooooooooool0>_ooool3o`0001[oZKgX0onU
_>T2odJ<k0?oGIS_0_mIU>d3oeJ>jP04od^5iom4O^?oA7kSodAnh`;oCgoQ0_mCOml3oeZ0g@03of:3
gOmYQ=_oJHCK00;oKhKI0omdQ]L3ogR6e@04ogb8e?mnQm;oOXOBogj7dP;oOhK@1?moPld3ogn0b`?o
Ogk71?n1O<@2ohEk`@CoRgbm1?nDOkX4oib3]`CoY8Rf0on[SKH00on/Rk?o/I2dok6@]002ok6@]0?o
]9Bf0ongUK@4okVH]P03okZK^OnlW;Oo_9bg00;o_9bg0onmWkX2oknP^0Co`:>k0_o3Y;X4ol>W_@03
olJX^oo7Zkkoaj^n00;oaj^n0_o9[Kd2ol^`_`Coc[:o00?ockK1om:h`?oB^<000_oB^<04omNn`P?o
f/711?oNal82on7:`P;oi<k100CoiM;3onSF`ooXe/?oj=K30_o/g<82oo3R`@04oo?Y__odlKSom?6h
onkfZaKoZKgX00?o0000ojVmj?nY_NP0:?nY_NP00ooooooo0000ooooo`0<ooooo`008_ooool3o`00
03Oooooo0ol00004oooooa[oZKgX0onN^^`2od2<k@?oGIS_0_mIU>d2odb;jP;o?h3V0_m4O^<3odAk
h@;oDgoO0omJP=d3of:2g0;oKhKI0omdQ]L3ogR6e@?oNHGB0omjP]04ogn3c@;oOh3;0omoO/L4oh5l
a0?oQG_11?n;O;d3oiAo^PCoW8>g1?nTR;H00on[SKKo[8^cojb;/`02ojb;/`Co/I2d00?o]9BfokNE
]?ngUK@00_ngUK@4okVH]PKo_9bg00Co_InjoknP^?noX;So_j2h0oo0Xk/3ol>T^P?o`jNm0_o6Z;/3
olN[_P?obJfm00?obk2ooljb_oo>/[l00oo>/[l4om:h`0;oeKZo0_oG_/84om[1`@03omc3`?oNal;o
g/O200?ohL[20_oTc/400ooXd/3oj=K3onSF``02oncL`P;ol>;10_ocjKh2ooCa^1SoZKgX00?o0000
ojVmj?nY_NP0:?nY_NP00ol0003oooooooooo`0;ooooo`008Oooool2o`0003Kooooo0ol00008oooo
oa[oZKgX0onN^^`2od2<k@?oEIO`0_m@TNh2odb;jP;o?h3V0_m4O^<2odAkh@;oBG_O1?mJP=d2of:2
g0?oJH?J0_mdQ]L4ogR6e@?oNHGB0_mjP]04ogUoc@?oN7_90_moO/L4oh5la0?oQG_11?n;O;d3oiAo
^PGoW8>g0_nTR;H00onUQ[?o[8^cojb;/`03ojb;/`Co/I2d1OngUK@3okVH]P;o^iVd1OnlW;L5oknP
^003ol2S^oo3Y;[o`jBj00?o`jBj00?o`jNmolJX^oo6Z;/00_o6Z;/00oo7ZkkobJfmolV]_@02olV]
_@Koc[:o00?odKBnom:h`?oB^<001?oE^[l01?oG_/;of/71om[1`OoJ`L42omc3`004omk7`_oQb/;o
hL[2on7:`P?oi<k10_oXd/000ooXe/?ok=c2oo3R`@02oo3R`@04oo?Y__odlKSom?6honkfZaWoZKgX
00?o0000ojVmj?nY_NP09onY_NP00ooooooo0000ooooo`0;ooooo`0000Co<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0<_ooool3o`0000cooooo6_nY_NP3oiZikP;o=h[]0omEUo02oe2AkP;o
@HKZ0_loP>H2ocUih`;oA7_Q0_m9Nml3oeZ0g@?oHX;L0_mYPmX3ofn4f0?oN8KE0omiQM83ogZ2d0?o
NGo=0omhNlT3ogQhaPCoPGc40_n5Nl44oh]l_@CoU7nj1?nLPkL00onTR;KoYHJcojF6/`05ojb;/`Co
/I2d00?o]92bokNE]?ngUK@00ongUK@01?niV;Ko^iVdok^I]?nkVK@4okbL]`;o_iff1?noX;P6ol>T
^PGoaZRk1Oo9[Kd00oo<[kcoc[:ooljb_`02oljb_`;odKBn00?od[S0omFj_ooE^[l00ooE^[l3om[1
`@?og<?000?oh<Joon7:`_oQb/800ooTc/43onSB`005oncH_oo/g<;ol>;1oo3R`OocjKh00_odlKP0
0oo^mZ_oZKgXojVmj00IojVmj003o`000?nY_NSoZKgX02OoZKgX0_l0000;ooooo`0000CoV9RHoooo
oonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02oooooo0ol0000@oooooa[oZKgX0onJ^Nh2ocN:k@?oC9C`0_m5S^h2
od66jP;o<g_U00Go>GWSocUfh?liM^3o>GKPodUkg`03oe9mgP03oeZ0gOmRP]coHX;L00?oJH?J0_m_
Q=P3og:3e@04ogR6eOmiQM;oNHGBogV5dP;oNX;@1?miOld3ogQkb@;oN7S60omjM/801?n1O<CoQG_1
ohEk`On5Nl44oh]l_@?oU7nj0_nLPkL2oib0]0CoYHJc1On/Rk<2ok6@]0;o]92b1OngUK@4ok^I]0?o
_9bg0onoWKH4oknP^003ol:Q]oo3Y;[o`jBj00;o`jBj0_o5YKT4olJX^`04olVY^_o9[KgobJfmolV]
_@;oc:nl0oo>/[l3om6d_PGoeKZo0_oH_;h00ooJ`L7og<?0omc3`002omc3`0;oh<Jo00CohL[2onC>
`OoTc/7oi<k10ooXd/001_o/f;ool=jnoo3N__o`h/7olnVnooCa^0;ok_J[6onY_NP00ol0003oZKgX
ojVmj00XojVmj003o`000?oooooooooo00Wooooo0003ooooo`03oa0@4?oooooooooo00_ooooo00?o
ZJVYoeEEEOooool02?ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool2o`0001Cooooo6_nY
_NP3oiZikP;o;8O/0om<U?02odF>kP;o=8;X00?o<g_Uob]dhOl[M>400_liM^02ocmgg`?oDWgN0omJ
Omd2ofV3fP?oKhCH0ombPmD3og>1dP?oLgk?0omiOld3ogQkb@?oN7S60omjM/83ogie_P?oQWNk00Co
RgbmoiAo^_nDOk[oT7Zg1?nLP;@4ojF6/`Go[8^c00Co/I2dokB@/_ndT;;o]92b1?ngUK@2okZF/PCo
^iVd00?o_9bgoknM]_noWKH00_noWKH3oknP^0;o`Z6g0oo3Y;X3olFU^@?oaZRk0_o9ZKX2olV]_@Co
c:nl00?oc[:oom6d__oA];h00_oA];h01?oC][goeKZoomFj_ooE^[l3omRl_PCog<?00ooPa[l00ooS
b[koi<k1onC>`@03onSB`0;ok=Ro0_o`g[h00oociK_om^jfojVmj00NojVmj003o`000?nY_NSoZKgX
02OoZKgX00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool03?ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0:_ooool3o`0001Oo
oooo6_nY_NP3oiZikP;o;8O/0om2TO02ocV:k@03ocB2j?lUM^?o9GKS00;o:gCQ0_liM^02ocmgg`?o
DWgN0_mJOmd3of:1f`;oKhCH0ombPmD4og>1dP;oLgk?0ombN/`3ogQkb@?oN7S61?mjM/82ogie_PCo
QWNk0on@N[L5oib0]0?oYHJc1?n/Rk<00on_Rk3o]92bokB@/P03okB@/P;o]iFd0onjU[84ok^I]0Ko
_iff00?o_j2hol:Q]oo2XKL00_o2XKL00oo3Y;[oaJFiolFU^@03olFU^@03olJX^oo9ZK[obJVj00;o
bJVj00?obJfmolb__?o<[k`00_o<[k`4om6d_P?odkJm00?oeKZoomRl__oH_;h00_oH_;h00ooK_kgo
g<?0omc3`004on36_`;ohlZn00?oi<k1onSB`?oXd/000_o/f;l3oo3N_P03oo?U^oofk[KoZKgX01oo
ZKgX00?o0000ojVmj?nY_NP09OnY_NP00ooooooo0000ooooo`0:ooooo`000oooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo02Oooooo0ol0000Koooooa[oZKgX1?nM^^`01?lMP^So@Y7`od:Al?m2TO02ocV:
k@03obMli_lUM^?o9GKS00;o:gCQ0_l/LMl01?loMmooB7WNodQig_m8NMh3oeYog@;oHX7K0omXPMP3
og:3e@?oLh7B0omcO/l2og9jc0?oL7K800?oN7_9ogQha_mhN<H01?mjM/83ogie_PCoQWNk0on@N[L4
oib0]0CoYHJc0_n/Rk<3ojn;/0Co]92b00?o]iFdokZF/_njU[800_njU[84ok^I]003okjJ/onoWKKo
_iff00?o_iff1Oo2XKL6olFU^@GobJVj1Oo<[k`00oo?/;_odKBnom6d_P04om>f_@Cof;bn0ooK_kd0
1?oL`l3oh<Joon36_ooPa[l3on?:_P03onO>_OoXd/3ok=Ro00;ok=Ro0_o`g[h00oociK_om^jfojVm
j00PojVmj003o`000?nY_NSoZKgX02;oZKgX1Oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol@413oooooooooo`0<ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Uooooo`?o00007ooooolJojVmj0;oWK[/0_nU_>X2oa]niP;o=8g^0_l[QN/0
0olWO>Ko9GKSobEfh`02oae^gP03obaagolbL]ko<W;N00;oB7WN0omAO=d00omJOmgoHX7Kof:1f`02
ofR1f0?oJh3F1?mcPM82og=nc`?oLW[<0om`M/P3og1ba@?oNWK20omnMKh4ohIg^`?oT7Zg1?nLP;@4
ojF6/`03ojb;/on_Rk3o[h^`00;o[h^`1?ndT;86okZF/P;o^iVd0_nnV[<4oknM]P;o`Yjd1?o2XKL0
0oo5X[KoaJFiolFU^@03olFU^@CobJVj0_o<ZkT3olb__0?ock2k00?odKBnom>f_OoC][d00_oC][d0
0ooG^Kcof;bnomRl_P04om^o_@03omk2_?oPa[ooh<Jo00CohlZn00Coiljmon_C_Oo/f;ook=Ro0_o`
g[h2oo?U^`03ooK^]_nY_NSoZKgX023oZKgX00?o0000ojVmj?nY_NP07OnY_NP9ooooo`03o`000?oo
oooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`05ooooo`?o00008_ooool3o`0002?ooooo6_nY_NP4ojFljP;o6gkV
0_lUQn/2ob^5j`04oaQfholFKmoo5VoOoae^gP;o7F_M0_lbL]h2odQigP?oDGcM0omIOM/2ofR1f0;o
Jh3F1?m/OM82of]ic`?oLW[<1?m`M/P2og1ba@?oLFo100?oNWK2ogie__mnMKh01?n6Mk/3oi1j]`Go
W82d0_nUQ[<00onVQ;3o[h^`ojn;/003ojn;/0Co]92b1_njU[801?nkVKCo_YZcokjJ/onnV[<3oknM
]P?o`Yjd0oo2XKL2olFR]PCoaJFi0_o8Y[L2olVY^P?oc:^i0_o<[k`4oln`^`CodkJm0ooG^K`00ooH
_;kofknmom^o_@02om^o_@;og/:l00Coh<Joon?:__oSb[kohlZn0_oWc[d2on_C_@05oncH_oo`g[ko
l=jnoo?U^oofk[H09?nY_NP00ol0003oZKgXojVmj00IojVmj0cooooo00?o0000ooooooooool02?oo
ool00004oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co00001?ooool00ol0003ooooooooo
o`0Oooooo`?o00009ooooolJojVmj0;oYKcZ0_nY_NP2obn5j`;o9HO[0_lLOnL01?lHM^?o5VoOoaI_
gol=I]/2oae[g@;o<W;N0_llM=h3oe5lg@;oFGgK0omOOMT2of^0ePCoK7gB0_m[NLl2og9jc0CoL7K8
0om`L/D3og5_`@;oMVjm00?oOWFnohIg^on6Mk/00_n6Mk/3oi1j]`CoW82d00?oYHJcojJ4/?nVQ;00
1_n_Rk02okB@/P;o]i6`1OnjU[85okjJ/`03oknM]_o2W[Co`Yjd00;o`Yjd0_o2XKL3olFR]P?oaJFi
0oo8Y[L00oo9ZK[oc:^iolb[^@03olb[^@03olb__?o?/;_ock2k00;ock2k00Cod[:jom>f_OoC][go
dkJm0ooG^K`4om^o_@?og/:l0ooSb[h2onO>_@?ojm>m00GokmZkoo3N__ociK_olnFkooK^]P0UojVm
j003o`000?nY_NSoZKgX01CoZKgX4?ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003o
ooooooooo`0Looooo`?o0000:ooooolNojVmj0;o;hG[0_lCP>D2oaaoi`04o`M_g_l6J=_o1VSKo`eV
f`;o7F_M0_lTK=d01OllM=koAWOModIggOm6MmgoDGcM00;oFGgK0_mOOMT3of9keP?oK7gB0_m[NLl3
ofUdb`?oL7K80om`L/D4og5_`@;oMVjm1?n6Mk/3oi1j]`;oW82d0_nKOK44ojJ4/0Go[h^`00Co]92b
okNA/?ngTK3o]i6`1OnjU[800onmUk3o_YZcokjJ/`02okjJ/`Ko`Yjd00?o`Z6golFR]_o5X[H00_o5
X[H00oo5YKWob:JgolRV]`02olRV]`Koc:^i1?o?/;/2om:b^P;odkJm1?oG^K`00ooJ^k_ofknmom^o
_@04omk2_003on;6_?oSb[koiljm00;oiljm0oo[dkd00oo_f[_oln6ioo?Q^@0WojVmj003o`000?nY
_NSoZKgX017oZKgX4oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0I
ooooo`?o0000<OoooolLojVmj0;oCYOa0_lCP>D2o`Ygh@04o`M_g_l6J=_o1VSKo`1NeP;o3F?I00?o
96cMobi_gOl^Kmd00om6Mmd2odmig0?oGggI0_mRNmH2of9hdP04ofamd_m[NLooJgW?of]ic`;oJGC;
0omWKlL00om`M/SoL7;5og1ba@04og5_`@;oMVjm1?moL;T3ohaf]@CoVgfa1?nVQ;05ojn;/0Co]i6`
1?njU[82okfG/0Co_YZc00?o`I^aol:N]?o2W[@00oo2W[@5olFR]PGob:Jg00?objRfolb[^Oo<ZkT0
0oo<ZkT00oo>[KSock2koln`^`04om:b^P04om>f_OoG^KcoekVlomNi_0?of[^k00Cofknmomk2_?oN
`[cog/:l0_oRa[`00ooVb[_oiljmonO>_@03on_C_@;okmZk0_ochKTXojVmj003o`000?nY_NSoZKgX
00goZKgX5_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`0001Oooooo0ol0000eoooooaco
ZKgX0om>Uo401?l0M]co2WOQo`YghOl0I]L2o`1Oe004o`1Ne_l=HmWo4fCJoa=TfP;o;VoM0om6Mmd2
odmig0;oGggI0omRNmH3of9hdP;oJgW?0omYM</3ofM_a`;oIF_300CoL7;5og5_`OmaKl7oLFo10omf
K[d3ogm`^@?oS7Je1OnKOK43ojJ4/0Co[h^`00?o/Xb^okNA/?ngTK000ongTK02okZF/P?o_IN`0onn
V[<2ol6K/@Go`Yjd00?oa9ncolFR]_o5X[H00_o5X[H01?o8Y;Cob:JgolRV]oo8Y[L2ol^X]PCoc:^i
0oo>[KP00oo?/;_od[:jom:b^P02om:b^PCoekVl0ooJ^k/3omk2_0?oh/Jl0_oVb[/01OoWc[gojm>m
on_C_Oo[dkgokmZk00;oln6i:_nY_NP00ol0003oZKgXojVmj008ojVmj1[ooooo00?o0000oooooooo
ool02?ooool001oooooo00?o0000ooooooooool05Oooool2o`0003Wooooo7?nY_NP4og:Yl`03o`1X
c_l0K]So06KG00;o05oD00Go05G>o`1KdolCI=[o4fCJobi_g@03ocUag@03odIggOm?NMcoE7SI00;o
E7SI0_mRNmH3of9hdP?oHG??0_mYM</4ofM_a`;oIF_31?maKl42ogI^_@?oOg2i1?n<M[D4oi]m/@Co
YXB`0_n_Rk03ok:<[PCo]i6`00?o^YJbokfG/?nmUk000onmUk001?nnV[?o`I^aol6K/Oo1Vk44ol:N
]0;oa9nc0oo5X[H2olRT]0;ob:Jg0oo;Z;H3olb[^@CocZfh1OoB/[X00ooE]KWoekVlomNi_004omZk
^`03omfn^_oN`[cog/:l00;oh/Jl0ooVb[/00ooZck[ojm>mon_C_@02onoJ^`;oln6i:onY_NP00ol0
003oZKgXojVmj004ojVmj1kooooo00?o0000ooooooooool01oooool001oooooo00?o0000oooooooo
ool04_ooool3o`0003cooooo7?nY_NP2og:Yl`;oU;O_00?o06;:o`1Rc?l0G<d00_l0E/`00ol0ELko
05_Coa=TfP02oaeWf`?o>G7M0_m1Lm/2oeAhf@?oEgKF0omRN=82of5cc`;oGVg:1?mWKlL2ofE[``?o
IVNo00?oLFo1ogI^_OmfK[d01?moL;T3ohaf]@CoVgfa1?nVQ;000on_Rk3o/Xb^ok:<[P02ok:<[PCo
]i6`1_nmUk000onnV[?o`I^aol6K/@02ol6K/@;o`Yjd0oo4Wk<2olFR]PCob:Bd00?ob:Jgol^X]_o;
Z;H00_o;Z;H00oo<ZkWocZfholj]^003olj]^0Cod[:j0ooE]KT01?oG^Kcof[^komZk^ooJ^k/2omfn
^P04omk2_?oRa[coh/Jlon;6_0?oi/Zk0_oZckX01?o[dkgokmZkoo?Q^OochKT/ojVmj004o`000?nY
_NSoZKgXojVmj27ooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool03ooo
ool3o`00043ooooo6onY_NP5oiBgk`03o`1Rb_l0H/co05c=00;o05K<00?o04[4o`1@c?l1Fm@00_lM
Im/2ocUag@?o@G?K0_mDN=T2oeMfeP;oEg;B00CoHWSBof5ccomQLlooHG??0_mNKLX3ofM_a`?oIF_3
0omVIkl2of]V^`04ogI^_OmoL;WoOg2iogm`^@?oS7Je1?nKOK44ojJ4/0Go/Xb^1?ngTK000onjTjko
_IN`okfG/003okfG/0Go`I^a00?o`YjdolBO/oo4Wk<00oo4Wk<00oo5X[Kob:BdolRT]002olRT]0Go
bjRf1Oo>[KP2om6_]`;od[:j1?oE]KT3omZk^`?ogKjj00?ohL:ion;6_?oRa[`00ooVb[/3on[?^P04
onkE^Oo_f[_oln6ioo?Q^BcoZKgX00?oooooo`000?ooool08_ooool00ol0003oooooooooo`07oooo
o`007oooool2o`0000gooooo0ol00013oooooacoZKgX0_nD]nl3ojVmj009oaikiOl0Dk[o05>jo`1@
_ol0Bl3o04[4o`1@c?l1FmCo7FOK00;o:6[K00?o>G7Mod5cfom1Lm/00_m7L]T3oeMfeP?oEg;B0_mQ
Lll2oei]bP?oFfO600?oIfo7ofE[`omUJl<00omVIkl3of]V^`?oOg2i0on<M[D5oi]m/@;oYXB`00?o
Z8B]ok:<[_nbS:h01?nbS:h2okNA/0;o^Y>^1OnmUk000oo0VJoo`I^aol6K/@02ol6K/@Koa9nc1Oo8
Y;@00oo:YK?objRfol^X]P02ol^X]P04oljZ]Oo>[KSocZfholj]^0?odJng00?od[:jomFe^OoE]KT0
0ooE]KT00ooH]kSof[^komZk^`03omfn^P;ohL:i00Coh/JlonK:^ooVb[_oi/Zk0ooZckX00oo^eKWo
ZKgXojVmj00ZojVmj0Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`00
7oooool00ol0003oooooooooo`09ooooo`?o0000AooooolQojVmj0;oJ:Cc00Oo04:So`0n/Ol0?[7o
03jgo`15`Ol0D<go2ekF00;o:6[K0om1Lm/2odMbf@;oEgKF0omGL]83oeE/cP;oGVg:0omKIlH2oeYS
`@?oIVNo0om[I[/3ogIY]`CoS7Je1?nKOK401?nVQ;3oZ8B]ojR4[OnXQ:d5ok:<[P04okNA/?njTjko
^Y>^okZC[PCo_IN`0_o0VJl4ol6K/@03olBM/?o4Wk?oa9nc00?oa9nc1?o8Y;@2olZU/`?objRf0_o>
Z[D3olj]^0?odJng1OoE]KT2omRg^004omZk^ooM_[[ogKjjomfn^P?ohL:i00?oiLJhonK:^ooVb[/0
0ooZckX2onkE^BWoZKgX2?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo
000Oooooo`03o`000?oooooooooo00Kooooo0ol0001;ooooob7oZKgX0_mXY?<02?nP^nco03jao`0n
/Ol0?[Oo04G1o`1@cOl;G]Ko:6[K0olaJmX00om1Lm_oAg;IodY_e@02odY_e@;oEg;B0omEK<h2oe9V
b@CoFfO60_mJHl43ofIW_`;oJfJk0omfJKL3ohIa/`03ohaf]OnKOK7oVgfa00;oVWZ_1?nXQ:d5ok:<
[PGo^Y>^0_nmUk03ol2I[`?o`I^a0_o4WK04olBO/`;oaj6b0_o8Y;@3olZU/`;objRf1?o>Z[D00oo>
[KSodJngom6_]`02om6_]`04omBa]_oE]KWoeKFiomFe^@?of;Nh1?oM_[X3on72^@;oiLJh00?oi/Zk
on[?^_oZckX00_o^eKTVojVmj0gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07
ooooo`007oooool3o`0000?ooooo0ol0001?ooooob7oZKgX1?nP^n`2o`0`Y`04o`14`_l0Dloo05??
oaEQe`?o<F_J0_lgJ]L2odY_e@;oBF[A00CoEg;BoeE/c_mEK<koEFc>0_mBI/T3oe]WaP;oFV?10_mJ
Gkd01?mVIkooJfJkof]V^om[I[/2ogIY]`CoQW6c1?nJNZl4ojR4[@Co/Xb^00?o]Xj/okZC[_njTjh0
0onjTjh00onmUk3o`9V_ol2I[`03ol2I[`04ol6K/Oo4WK3oa9f`olBM/0?oa9nc0oo7XK82olRT]0Co
bZFc00?objRfoljZ]Oo>Z[D00_o>Z[D4om6_]`?oe;6f00?oeKFiomRg^?oH]kP00_oH]kP00ooL^[Oo
gKjjomfn^P03on72^@?oiLJh0ooZckX2onkE^B?oZKgX4Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Oooooo000Nooooo`;o00000_ooool3o`0005?ooooo8OnY_NP2oj2kk0;oZKgX
0_l0<:L01?l0A<;o05??o`1CcolEHML3oc5[fP;o=f[G0_m:KmD2odUZd@?oEFc>0_mBI/T2odmOa004
oe]Wa_mJHl7oFV?1oeYS`@;oFUnm0om[I[/3ogIY]`?oQW6c1?nJNZl5ojR4[@;o/Xb^0onfSZ`4okZC
[PKo`9V_00?o`I^aolBM/?o4WK000_o4WK000oo4Wk?oaj6bolNQ/P02olNQ/P03olRT]?o:YK?obZFc
00?obZFc1Oo>Z[D00oo@[;CodJngom6_]`04omBa]PCof;Nh0ooL^[L01?oM_[[ohL:ion72^OoQ`[T3
onG6^004onW;^?oZck[ok]FionkE^B7oZKgX5Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Kooooo000Dooooo`Co000000?o410@ooooooooool00oooool4o`0005Oooooo9OnY_NP0
1?m>Uo7o032Wo`14`_l0Dll2o`1Ed@;o7V;G00Co<F_JocMZeoljI]?o>VKC0_m9J]42odMTc004oeE/
c_mBI/WoDVK9oe9Vb@;oCeo400?oFfO6oeYS`OmJHl400_mJGkd2oeiN^P04of]V^omfJKOoMVVgogIY
]`CoQW6c0onJNZl5ojR4[@03ok:<[_nfSZco]Xj/00;o]Xj/1?njTjh00onnUZgo`9V_ol2I[`03ol2I
[`Goa9f`1Oo7XK86olZU/`04olfW/oo>Z[GocZZeoljZ]@?od:bd00?odJngomBa]_oD/KH00_oD/KH0
1?oG];Gof;NhomRg^?oH]kP3ombj]`03omnn]ooQ`[WohL:i00?oiLJh0_oYbkP2ojVmj003onkE^OnY
_NSoZKgX01_oZKgX6Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo000F
ooooo`03o`000?oooooooooo00Gooooo0_l0001KooooobCoZKgX0_nT_>X01?l0::7o04G4o`1EdOl0
EM42oaiRe`;o963D0_ljI]<2odUZd@?oAfC<0_mBI/T3odmOa0;oFV?10_mJGkd3oeiN^P03of]V^omf
JKOoMVVg00CoQW6c1?nJNZl4ojR4[@Go]Xj/0onjTjh2okjF[@Go`9V_1Oo4WK000oo7Wk3oaj6bolNQ
/P02olNQ/P03olZS/Oo:YK?obZFc00;obZFc0_o=Yk<2oljZ]@Cod:bd1?oD/KH2omNd]@;of;Nh1?oL
^[L2omnn]`03on72^OoUa[SoiLJh00?ojL^h7OnY_NPMooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1I
ooooobCoZKgX0_nT_>X01Oma003o04G4o`1EdOl7E]7o7V;G00?o963D00?o>VKCocUQcoliHLl00om7
I<`2odAMa`?oCeo40_m<F[l00omJHl7oFUnmoeYO_@03oeiN^P;oMVVg1?n6LK<4oiYj[`?oZ8B]00?o
[8F[okJ>[?nfSZ`01?nfSZ`01?njTjko_YJ]okjF[OnnUZd4ol2I[`;o`i^^0oo4WK02olNO/0?oaj6b
0_o:Xk43olZU/`CocJNc00?ocZZeom2/]?o@[;@00_o@[;@01?oC[kCoe;6fomBa]_oD/KH3omNd]@04
omRg^?oL^[Oog;Zgombj]`?ogkjg0ooUa[P2onW;^1_oZKgX8Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0FOoooolVojVmj005og400?l0=KKo04K7o`MFdOlNH]L00_lTH=@01?lWG=3o>VKCocUQcoliHLl3
odMTc0;oA5g70_m?Gl@3odaJ_`;oFUnm0omNG[X2ofUQ]P04ogIY]on6LK?oQW6cohIa/`CoVWZ_0_nX
Q:d3ojb5Z`Go]Xj/00?o^Y>^okjF[OnnUZd00_nnUZd2ol2I[`?o`i^^0_o4WK03olNO/0;oaj6b1?o:
Xk400oo:YK?ocJNcolfW/`03olfW/`Cod:bd0_oC[k@2omBa]PCoekBe1?oL^[L3omnn]`03on?2]_oU
a[SojL^h00;ojL^h6?nY_NPUooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_oo
ool001Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1IooooobKoZKgX00CoM000
o`0e]_l0A/Oo1eKA0olTH=@00olWG=3o>F7?ocUQc`02ocMJb@04odMTc?m4GLOoA5g7od1F`P;oCeo4
0_m<F[l00om<E[_oFUnmoeiN^P03oeiN^P;oJF6f1?n6LK<3oiYj[`03ojR4[On/QJ_o[8F[00;o[8F[
1OnfSZ`5okjF[@03ol2I[oo3Vjko`i^^00;o`i^^00?oa9f`olNO/?o7Wk000oo7Wk000oo7XK;obZ>a
olZS/@02olZS/@KocJNc0oo@[;@4om>_]003omBa]_oG];GoekBe00;oekBe00?ofkNeombj]ooL^[L0
0ooO_[L2on?2]P03ojVmj?oYbkSojL^h01GoZKgX:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00[ooooo0_l0001JooooobKoZKgX00Ko
M000o`0SXol0AlOo04O7o`eCcolTH=@2obMLd0;o>F7?0olgF/T2odAMa`03od1F`_m?GlCoC5Zo00;o
C5Zo00?oC5JkoeYO_OmNG[X00_mNG[X2ofUQ]P?oOFZc00CoQW6coiYj[onJNZooVGV]1On/QJ/5okJ>
[0Go_YJ]1Oo3Vjh6olNO/0GobZ>a00?ocJFaolfW/oo=Yk<00_o=Yk<2om2Z/P;od:bd1?oC[k@4omNd
]@?ofkNe00?og;Zgomnn]ooO_[L00ooS`[H2ojVmj003onW;^?nY_NSoZKgX013oZKgX;Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0F?oooolWojVmj003o`0SXol0AlOo04O700;o3E??00?o9ec@obIFbolV
E//00olgF/T01?lcDlCoA5g7od1F`_m0E/83odaJ_`;oC5Jk0omNG[X2ofUQ]PCoOFZc0onINJd5ojb5
Z`Co]Xj/00?o^i6[okjF[OnnUZd00onnUZd00oo3VJgo`i^^ol>K[P02ol>K[P03olNN[_o7Wk3oain`
00?oain`00CobZ:_olZS/Oo:Xk7obZ>a0_o=YK43olfW/`?od:Zb00?od:bdom>_]?oC[k@00ooC[k@0
1?oG/K?oekBeomNd]OoG];D3om^g]@?ogkjg0_oS`[HCojVmj37ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`05ooooo`005?ooool00omEEEGoIVIVo`00000?ooooo`03o`000?oooooo
oooo05Sooooo9onY_NP01?l08ZGo04O7o`14a_l0A<H2oa1?b`;o9UK;0olgF/T00olcDlCo@5K2od1F
`P02ociA_@03odaJ_om<E[_oC5Jk00;oCeBh0_mNG[X2ofUQ]P?oOFZc1?nINJd5ojb5Z`;o]Xj/0onk
TJ/3okjF[@;o`iV]0oo3Vjh2olNN[PCoain`0_o:XZl3olZS/@;ocJFa0oo=Yk<3om2Z/PGodjnd0_oG
/K<2omNd]@CofkNe00?og[^domnn]ooS`[H00_oS`[H@ojVmj3Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`1HooooobOoZKgX00Co02:U
o`0e^_l0A<Ko04C60_l@Cl/01?lVE/_o94o6obA?a_lgF/T2oc=Ca0;o@5K20_lnDKd00om<F[ooC5Jk
odaF^`03odmD^0;oJF6f1?mmJ[<3oiUi[@Go[8F[00?o]Xj/ok^AZonkTJ/00_nkTJ/2okjF[@?o`iV]
0oo3Vjh2olNN[P?oain`0oo:XZl2olZS/@CocJFa00?ocJNcom2Z/_o@Z[800_o@Z[801?oC[;7odjnd
om>_]?oC[k@4omNa/`04omNd]OoK]kGofkNeom^g]@;og[^d0ooS`[H>ojVmj3Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`05ooooo`00:?ooool2o`0005Wooooo9onY_NP01ol08ZGo
03Fjo`14a_l0A<Ko44o;oa19a_lVE//00_lTClH2oc=Ca003oc1<_om0E/;o?U6m00;o?U6m0_m<E[/3
odmD^003oeMF]OmYHKKoOFZc00?oOFZc0onINJd5ojb5Z`Go^i6[0_nnUZd4ol>I[@03ol>K[_o7WZko
aij^00;oaij^0_o7Wk04olZR[`03olZS/Oo=YK7ocJFa00;ocJFa1?o@Z[82om>//@?odjnd1?oG/K<3
om^g]@?og[^d00?oZKgXon?2]_oS`[H02_nY_NPmooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool002[ooooo00?o0000ooooooooool0F?oooolVojVmj006oh`50?l0<[Wo04C6
o`10`ol@Cl_o44W60olTClH2oc=Ca006oc1<_olnDKgo?U6mociA_OlmC;WoC5Jk0om?E;P2oeMF]@04
ofUQ]_mmJ[?oOFZcogeZ/`?oVGV]1?n/QJ/00onbR:Wo^i6[ok^AZ`03ok^AZ`03okjF[Oo3VJgo`iV]
00?o`iV]00?o`i^^olNN[_o7WZh00_o7WZh00oo7Wk3obZ:_olZR[`03olZR[`GocJFa00Cod:R`om2Z
/_o@Z[;od:Zb0ooC[;400ooC[kCoek6comNa/`03omNa/`03omZd/ooK]kGofkNe00;og[^d0onY_NP0
0ooS`[KoZKgXojVmj005ojVmj47ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05
ooooo`00:oooool00ol0003oooooooooo`1HooooobKoZKgX00Co00f>o`0b^Ol0A<Ko04330_l@BLH2
obA?aP04ob58`?lcDlCo<4booc1<_`?o?U6m00?o?DbiodaF^om?E;P00_m?E;P2oeMF]@?oOFZc1?nI
NJd2ojb5Z`?o/XRY1?nkTJ/6ol>I[@Goaij^1_o:XZl01?o=Y:oocJFaolfU/Oo=YK42om2X/0;od:Zb
1?oC[;45omNa/`;of[Bc00CofkNeomjk]?oN^kCog[^d2?nY_NQ4ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool002cooooo00?o0000ooooooooool0F?oooolVojVmj007o`0Q
Yol0<[Wo0433o`10`ol@BLKo3d?1obA?aP02ob58`0;o<4bo0_l^AkX00olnDKgo?Dbioce<^@03odmD
^0;oEeJe0_m]H;<2ogeZ/`?oVGV]00?o[8F[ok:8ZOnbR:T00_nbR:T4ok^AZ`03ol6G[?o3VJgo`iV]
00?o`iV]00?oaYf]olNN[_o7WZh00_o7WZh00oo:XJkobZ:_olZR[`02olZR[`;ocJB_0oo=YK42om2X
/0;od:Zb1?oC[;401?oF[k7oek6comNa/ooG/K<3omZd/`?og[^d1_nY_NQ8ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01?ooool002gooooo00?o0000ooooooooool0F?oooolVojVm
j007o`0NZ?l0;[Oo02jgo`0j__l@BLKo3d?1obA?aP02ob58`0;o<4bo0_l^AkX2oce<^@;o?dZf00?o
CeBhoeMF]OmGE[D01?m]H;<2oiUi[@03oiUh[OnbR:Wo/XRY00?o/XRY0onkTJ/2ol6G[0Co`iV]0_o6
WJd3olNN[P;obZ6^0oo:XZl3olfT[`;ocJFa1?o@Z;001?o@Z[;odjbaom>//OoC[;42omJ_/@?oek6c
0ooJ];<00onY_NSog[^domjk]003ojVmj4cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`04ooooo`00;_ooool2o`0005Wooooo9_nY_NP01?l07ZSo02jgo`0^]ol0>[h2o`m3`@;o8DS0
00?o7T:koc1<_ol^AkX00_l^AkX2oce<^@;o?dZf00?oCeBhoeMF]OmGE[D00om]H;<3oiUh[@Ko/XRY
00Co^i6[ol6G[?o1Ujco`IN/0oo3VJd3olJM[@?oaij^0_o:XJh3olZR[`CocJB_00?ocJFaom2X/?o@
Z;000_o@Z;04om>//@?oeZna00Coek6comZd/ooJ];?of[Bc0onY_NP00ooN^kCoooooooooo`1>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0033ooooo00?o0000oooooooo
ool0E_oooolWojVmj005o`0NZ?l0;[Oo02jgo`0j__l?@l400_l=?;/00olQB<3o7T:kobi7^P02obi7
^P;o?Dbi0oloB[H2oeMF]@?oKF2c1?nIN:d5ok:8Z@03ok^AZoo1Ujco`IN/00;o`IN/0_o3VJd4olJM
[@03olNN[_o:XJkobZ6^00;obZ6^00?obZ:_olfT[oo=Y:l00oo=Y:l5om2X/003om:[/?oC[;7odjba
00CoeZna1?oJ];=Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0037o
oooo00?o0000ooooooooool0E_oooolWojVmj005o`0JYol0;[Oo03Zno`0d^Ol?@l400_l=?;/2oai2
^`?o;TNj00Co?Dbiocm:]_loB[Ko?dZf0_mGE[D4ofeP/`?oVGR]1OnbR:T5ol6G[003ol>I[Oo6WJgo
aYf]00?oaYf]00?oaij^olZQ[_o:XJh00_o:XJh6olfT[`04olnW[oo@Z;3od:R`om2X/0;odZ^`0_oC
[;44omJ_/@03oooooooJ];?of[Bc05Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`00<_ooool00ol0003oooooooooo`1GooooobKoZKgX00Co01ZWo`0^]ol0>[ko03Bi0ol=
?;/01_lN@[_o7Cfgobi7^_l^Ak[o;D>goce<^@;o?dZf00?o@d^doeMF]Om]H;<00om]H;<3oiUh[@Go
/XRY1Oo1Uj`6olJM[@GobZ6^00?oc:>^olfT[oo=Y:l00_o=Y:l2olnW[`?od:R`0ooBZk001?oC[;7o
eZnaomJ_/OoF[k42ooooo`;of[BcEoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Cooooo000cooooo`;o0000F?oooolUojVmj003o`08TOl06ZOo02Vc00;o03Bi0_l=?;/2oai2^`04
oadm]ol^Ak[o;D>gobe3]`?o?dZf00?o@d^doeMF]Om]H;<00_m]H;<3oiUh[@Co/XRY0_noUJ`4ol6G
[003olNM[Oo6WJgoaYf]00?oaYf]00CobZ2^olZQ[_o:XJkobZ6^0_o<Xjh4olfT[`;ocjN_0_o@Z;04
om:[/0CoeZna0oooool00ooJ];?oooooooooo`1Fooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01?ooool003Gooooo00?o0000ooooooooool0E_oooolUojVmj0;o01ZW00?o02Vco`0d
^Ol0;kD00_l=?;/01_lN@[_o7Cfgoadm]ol^Ak[o;D>gobm2]0;o?dZf0_m3Bk@3ofeP/`?oVGR]0onb
R:T3oknE[0?o`IN/0_o7WJd4olJM[@;obZ2^0oo:XJh2olbS[P?ocJB_1?o?Yjl00oo@Z;3odZ^`om:[
/002om:[/003oooooooF[k7oeZna05gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`00=_ooool00ol0003oooooooooo`1FooooobGoZKgX00Oo01ZWo`0FYOl09:oo03Bio`0_
]Ol=?;_o33Ng00?o7Cfg0_l]@kL01?l_@[Co?dZfod=;]?m3Bk@2odi?/`03ofeP/onIN:goVGR]00;o
VGR]0_nbR:T3oknE[0?o`IN/0_o7WJd3olJM[@?obZ2^0_o:XJh4olbS[P03olfT[oo?YjoocjN_00?o
cjN_1?oBZk02ooooo`;oeZnaG_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo000gooooo`03o`000?oooooooooo05Kooooo9OnY_NP00ol06ZOo01JUo`0T[`02o`0_]@;o33Ng
0_lM?KL2obe3]`;o;d:d00?o?dZfod=;]?m3Bk@00_m>Ck<01Om]H;?oVGR]oiUh[OnIN:go/XRY00Go
_iF/00?o`IN/olNM[Oo7WJd00_o7WJd2olJM[@CobZ2^00?obZ6^olbS[_o<Xjh00_o<Xjh00oo=Y:oo
cjN_olnW[`03olnW[`CodZ^`0oooool00ooF[k7oooooooooo`1Mooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00oooool003Sooooo0_l0001Hooooob?oZKgX00Co00FBo`0FYOl05ZGo
02B_0_l0;kD01Ol<=kOo33>coadm]olM?KOo;D>g00?o;d:d0_m3Bk@3odi?/`;oVGR]00?oVgndoknE
[?noUJ`01?noUJ`00oo1Ujcoaif]olNM[@02olNM[@03olJM[Oo:X:kobZ2^00?obZ2^00?obZ6^olbS
[_o<Xjh00_o<Xjh5olnW[`;ooooo0_oBZk1Uooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool003[ooooo00?o0000ooooooooool0E_oooolSojVmj005o`01TOl05ZGo02B_o`0P
[?l0;kD00_l<=kL01?l<<k?o7Cfgoahk]?l]@kL2obm2]003oc=3/om3BkCoCTnc00;oCTnc0onKOk@6
oknE[0Goaif]1_o:X:h5olbS[P03ooooooo?YjoocjN_00;ocjN_0_ooool00ooBZk3oooooooooo`1T
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool003_ooooo00?o0000oooo
ooooool0E_oooolSojVmj006o`01TOl05ZGo02B_o`0P[?l0;kGo33Ng0_l<<k<2oahk]0?o;d:d00Co
<d>cod=;]?m>Ck?oCTnc1?nKOk@5oknE[003ojVmj?o7WJgoaif]00;oaif]00?oZKgXolZP[_o:X:h0
0oo:X:h01?ooooooc:>^olbS[_o<Xjh2ooooo`?ocjN_0oooool00ooBZk3oooooooooo`1Uooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool003cooooo00?o0000ooooooooool0
EOoooolTojVmj005o`01TOl04Z;o022/o`0P[?l0:k400ol<<k<01?lN>kCo8S^cobm2]?l_@[@2oc=3
/`?oCTnc0onKOk@4oknE[0;oZKgX0oo7WJd2ooooo`CobZ2^0_ooool3olbS[P;ooooo0_o?Yjm]oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool003gooooo0_l0001FooooobCo
ZKgX00Go006Ao`0BX_l08:co022/o`0[/@02o``c/`;o7S^d00Go8S^cobm2]?lc@k?o<d>cocY8]P02
odi?/`?oVgnd0onoUJ`3ooooo`?oaif]0_ooool3olZP[P?ooooo0_o<Xjh4ooooo`03olnW[ooooooo
oooo06_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00?oooool00ol0
003oooooooooo`1Eooooob?oZKgX00Co01:Ro`0P[?l08:co02^a0_l<<k<01Ol@<k;o7S^dob8k/olR
>k?o;d:d00;o<d>c00?o>TRfodi?/onKOk@00onKOk@2oknE[0Cooooo00?oaif]ooooooooool00_oo
ool2olZP[PCooooo00?oc:>^ooooooooool0LOooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00;ooooo0010ooooo`03o`000?oooooooooo05Gooooo8_nY_NP01Ol007Wo01:Ro`0P[?l0
7Z[o02^a00;o33>c00Co43>bob8k/olR>k?o8S^c0_lc@k<00oljB;Koooooodi?/`03oi]o]003oknE
[?oooooooooo00?ooooo00?oaif]ooooooooool00_ooool00oo:X:koooooooooo`1hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool0047ooooo00?o0000ooooooooool0EOoo
oolRojVmj006o`00NOl04:7o022/o`0NZ_l0:Zoo33>c0_l@<k82ob8k/`03ob]1]_lc@k?o>TRf00;o
oooo0_nKOkB8ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool004;ooooo
00?o0000ooooooooool0EOoooolRojVmj003o`00TOl08:co01jZ00;o02Z_0_l@<k82ob8k/`03ob]1
]_oooooo<d>c08cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@ooo
ool2o`0005Kooooo8OnY_NP01_l007Wo012Qo`0NZ_l07Z[o02Z_o`8]/0;o43>b0_lR>k>?ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool004Gooooo00?o0000ooooooooool0
E?oooolPojVmj0;ooooo00So012Qo`0NZ_l0:Zoo02Z_o`8]/?l@<k;o63Rcob8k/i3ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00A_ooool00ol0003oooooooooo`1Doooo
oaWoZKgX2Oooool01_l04:7o01jZo`0Z[ol2;K3ooooooaPh/i;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`1DoooooaGoZKgX3_ooool0
0ol08:[o0Rf`ooooo`2Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0
04Sooooo0_l0001Foooooa7oZKgXYoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
007ooooo001:ooooo`03o`000?oooooooooo05Cooooo3OnY_NR[ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00Oooool004_ooooo00?o0000ooooooooool0E?ooool9ojVmj:kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?ooool00ol0003ooooooooo
o`1Cooooo`KoZKgX/_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo001=
ooooo`;o0000E?ooool2ojVmj;Kooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0
04oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`7ooooo001@ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0]_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool005;ooooo0_l0001?ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo0Oooool005Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oo
oooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00F_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00Fooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2nooooo`03o`000?oo
oooo0000007ooooo001Mooooo`;o0000A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooo
0000007ooooo001Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0_oooool1o`00
007ooooo0Ol00000063ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`30ooooo`;o
0000001Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0`?ooool3o`000000H_oo
ool2o`0003kooooo00?o0000ooooooooool0_?ooool4o`0000?ooooo001Tooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^?ooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0]Oooool3o`0000_ooooo001Vooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0/Oooool4o`0000kooooo001Wooooo`;o0000>Oooool00ol0003ooooo
ooooo`2]ooooo`Co00004_ooool006Wooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`2Yooooo`Co00005_ooool006[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2U
ooooo`Co00006_ooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Roooo
o`?o00007_ooool006cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Nooooo`Co
00008Oooool006gooooo0_l0000cooooo`03o`000?oooooooooo09[ooooo1?l0000Uooooo`00Kooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Kooooo1?l0000Yooooo`00L?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09;ooooo1?l0000]ooooo`00LOooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo08oooooo0ol0000aooooo`00L_ooool2o`0002ko
oooo00?o0000ooooooooool0Roooool4o`0003Cooooo001dooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0Qoooool4o`0003Sooooo001eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0Poooool4o`0003cooooo001fooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0Ooooool4o`00043ooooo001gooooo`;o0000:Oooool00ol0003oooooooooo`1loooo
o`?o0000A?ooool007Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co
0000Aoooool007[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000
Boooool007_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000Cooo
ool007cooooo0_l0000Tooooo`03o`000?oooooooooo06cooooo1?l0001Cooooo`00O_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo0ol0001Gooooo`00Ooooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Jooooo`00P?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Nooooo`00POooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo05gooooo1?l0001Rooooo`00P_ooool2o`0001kooooo00?o0000
ooooooooool0FOooool4o`0006Kooooo0024ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0EOooool4o`0006[ooooo0025ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0D_ooool3o`0006kooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
C_ooool4o`00077ooooo0027ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000MOoo
ool008Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000NOooool0
08[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000OOooool008_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`?o0000POooool008cooooo
0_l0000Cooooo`03o`000?oooooooooo03cooooo1?l00024ooooo`00S_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03Sooooo1?l00028ooooo`00Soooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Cooooo1?l0002<ooooo`00T?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo033ooooo1?l0002@ooooo`00TOooool2o`0000kooooo00?o0000oooooooo
ool0;Oooool3o`0009Cooooo002Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
:Oooool4o`0009Oooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Ooo
ool4o`0009_ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4
o`0009oooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`00
0:?ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`?o0000Yoooool009Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo1?l0002fooooo`00W_ooool01?l0003oooooooooool00009oooo
o`?o0000^_ooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o0000
00?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0032ooooo`03o`000?oooooo
oooo0:?ooooo0032ooooo`03oa0@4?oMgMgooooo0:?ooooo0030ooooo`05olc<c?l@413o0000o`00
0?n7QhL0Xoooool00<3ooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhNRooooo`00`?ooool01_l0
003oooooofIVI_n7QhOogMgMoa0@4:;ooooo0030ooooo`06oa0@4?oMgMgoMgMgogMgMooooooo0000
X_ooool00<3ooooo00KoZJVYodA4A?nHV9SoA4A4oiRHV?l@412Rooooo`00`Oooool01OnHV9So0000
o`000?l@413oc<c<0:;ooooo0032ooooo`03okZj^_lb<S;ooooo0:?ooooo0033ooooo`03o`000?oo
oooooooo0:;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The solution is apparently well behaved throughout the domain of interest. \
 However, closer examination shows that it is not particularly accurate near \
the origin. In Fig. ",
  ButtonBox["6.2",
    ButtonData:>"Fig. 6.2",
    ButtonStyle->"Hyperlink"],
  ", we compare the Galerkin solution  to the exact solution found previously \
along the line ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  ", for the  cases ",
  Cell[BoxData[
      \(TraditionalForm\`P\_x = \(P\_y = 1\), 3, 5\)]],
  ". "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -35 0 ]
[.02381 .64303 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
93.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
105.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(\\220) show
117.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
[ .008 .02 ] 0 setdash
.02381 .60332 m
.06244 .54932 L
.10458 .49445 L
.14415 .44691 L
.18221 .40487 L
.22272 .36406 L
.26171 .32849 L
.30316 .29448 L
.34309 .26514 L
.3815 .23983 L
.42237 .21567 L
.46172 .19478 L
.49955 .17653 L
.53984 .15875 L
.57861 .14289 L
.61984 .12706 L
.65954 .11253 L
.69774 .09902 L
.73838 .08499 L
.77751 .07176 L
.81909 .05805 L
.85916 .04536 L
.89771 .0339 L
.93871 .02298 L
.97619 .01472 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 .60332 m
.06244 .55935 L
.10458 .51235 L
.14415 .46952 L
.18221 .42985 L
.22272 .38955 L
.26171 .35287 L
.30316 .31637 L
.34309 .28376 L
.3815 .25484 L
.42237 .22675 L
.46172 .20228 L
.49955 .18109 L
.53984 .16091 L
.57861 .14366 L
.61984 .12741 L
.65954 .11352 L
.69774 .10148 L
.73838 .08971 L
.77751 .07897 L
.81909 .06766 L
.85916 .05632 L
.89771 .04442 L
.93871 .03004 L
.97619 .01472 L
s
0 g
[ ] 0 setdash
.02476 .59454 m
.0294 .57581 L
.03373 .56318 L
.04355 .54015 L
.06336 .50388 L
.10545 .4453 L
.14441 .40207 L
.18581 .36292 L
.2257 .32986 L
.26408 .30133 L
.3049 .27381 L
.34421 .24959 L
.38201 .22809 L
.42226 .20684 L
.46099 .18781 L
.50217 .1689 L
.54184 .15184 L
.58 .13639 L
.6206 .12087 L
.65969 .10675 L
.70123 .09254 L
.74126 .07956 L
.77977 .06767 L
.82073 .05562 L
.86018 .04456 L
.89812 .03438 L
.9385 .024 L
.97619 .01472 L
s
0 0 1 r
[ .05 .05 .01 .05 ] 0 setdash
.02381 .60332 m
.06244 .54262 L
.10458 .48231 L
.14415 .43181 L
.18221 .38887 L
.22272 .34886 L
.26171 .3153 L
.30316 .28414 L
.34309 .25771 L
.3815 .23487 L
.42237 .21269 L
.46172 .1929 L
.49955 .17497 L
.53984 .15686 L
.57861 .1403 L
.61984 .12362 L
.65954 .10849 L
.69774 .09484 L
.73838 .08127 L
.77751 .06907 L
.81909 .05685 L
.85916 .04557 L
.89771 .035 L
.93871 .02407 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00F_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;Oooool4o`000003oa0@4?oooooooooo01So
oooo001Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool09?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40;oooool00ol0003oooooooooo`0Jooooo`00F_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000;oooool00ol0003oooooooooo`0Jooooo`00F_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00009_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0Uooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b02oooooo00?o0000ooooooooool06_ooool005[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`09Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00_ooooo`03o`000?oooooooooo01[ooooo001Jooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000Vooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02oooooo00?o0000
ooooooooool06_ooool005[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
9_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000_ooooo`03o`000?oooooo
oooo01[ooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;Oooool00omEEEGoIVIVo`00
000Looooo`00:oooool00ol0003oooooooooo`3ooooooc_ooooo000[ooooo`03o`000?oooooooooo
0?oooooo>oooool002_ooooo00?o0000ooooooooool0ooooool`ooooo`03oa0@4?l0003o000000?o
00001Oooool002_ooooo00?o0000ooooooooool0oooooolbooooo`03o`000?oooooooooo00Kooooo
000[ooooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`06ooooo`009?oooooo
o`0002Ko00000ol00?l7o`0000cooooo00?o0000ooooooooool01_ooool002_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`3o0?l00?oo003o00?o003o00?oo`00oooo
ool000004oooool00ol0003o<S8bomgMg@06ooooo`00:oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02cooooo0ol00?l00ol0003oo`00ool00004ooooo`03o`000?oooooooooo013o
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`00:oooool00ol0003oooooooooo`3oooooo`ko
oooo0_l0o`000ooooooo0000o`000002o`0000;oo`009?ooool002_ooooo00?o0000ooooooooool0
ooooool=ooooo`Co000000?oooooool00?oo00009oooool002_ooooo00?o0000ooooooooool0oooo
ool9ooooo`Co00001?ooool00ooo003oooooooooo`0Wooooo`00:oooool00ol0003oooooooooo`3o
ooooo`Cooooo0_l00?l3o`0003;ooooo000[ooooo`03o`000?oooooooooo0?oooooo0Oooool01?l0
003o003oo`00ool0000fooooo`00:oooool00ol0003oooooooooo`3looooo`Co0000>_ooool002_o
oooo0_l0003iooooo`Co000000?o0?l0ooooooooool0>oooool002_ooooo00?o0000ooooooooool0
m?ooool4o`0000Sooooo0ooo000gooooo`00:oooool00ol0003oooooooooo`3`ooooo`;o00000_l0
0?l00ol0o`3oooooooooo`05ooooo`Coo`00>_ooool002_ooooo00?o0000ooooooooool0kOooool2
o`0000?o003o1oooool3ool003kooooo000[ooooo`03o`000?oooooooooo0>[ooooo0_l00003o`00
o`Oooooo0ooo0011ooooo`00:oooool00ol0003oooooooooo`3Wooooo`Go003o00?o0?l0oooooooo
ool01Oooool2ool004Cooooo000[ooooo`03o`000?oooooooooo0>Cooooo0ol00?mCooooo`00:ooo
ool00ol0003oooooooooo`3Pooooo`Co00000_l0o`1Dooooo`00:oooool00ol0003oooooooooo`3L
ooooo`Co0000F_ooool002_ooooo0_l0003Iooooo`Co00000_l0o`05ooooo`?oo`00E?ooool002_o
oooo00?o0000ooooooooool0eOooool3o`0000?ooooo00Co0?l0oooooooooooooooo1?oo001Goooo
o`00:oooool00ol0003oooooooooo`3Booooo`;o00000ol00?l4ooooo`Coo`00Foooool002_ooooo
00?o0000ooooooooool0coooool3o`000004ooooool00?oo0?l0o`3o00;ooooo0ooo001Oooooo`00
:oooool00ol0003oooooooooo`3<ooooo`?o00001?ooool00ol0o`3oooooooooo`02ool006;ooooo
000[ooooo`03o`000?oooooooooo0<Wooooo0ol0001^ooooo`00:oooool00ol0003oooooooooo`36
ooooo`?o00000oooool2o`3o06cooooo000[ooooo`03o`000?oooooooooo0<Cooooo0_l00005oooo
o`03o`3o0?oooooooooo06cooooo000[ooooo`03o`000?oooooooooo0<;ooooo0ol00?l2ooooo`;o
o`00LOooool002_ooooo0_l00030ooooo`?o003o00?oooooo`3o0?oo00000_oo001cooooo`00:ooo
ool00ol0003oooooooooo`2looooo`?o003o0_ooool3ool007Kooooo000[ooooo`03o`000?oooooo
oooo0;Wooooo0ol00?l00ol0003o0?l0ool00002ool007Wooooo000[ooooo`03o`000?oooooooooo
0;Oooooo0_l00?l00ol0003oooooo`3o0002ool007cooooo000[ooooo`03o`000?oooooooooo0;Co
oooo0_l000001?l00?ooooooooooooooool2ool007kooooo000[ooooo`03o`000?oooooooooo0;7o
oooo0ol00002o`3o08Cooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00006ooooo`03o`000?oooooooooo0:kooooo0ol00002ooooo`03o`3o0?oooooooooo08Co
oooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo0:_ooooo0ol0002<ooooo`004?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000:Wooooo0_l00002oooo
o`;o0?l0Roooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool0Y_ooool3o`000004oooooooo003oo`00o`3o08gooooo000@oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo0:Cooooo0_l000001?oooooo003oo`00oooo002@ooooo`004?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Qooooo`?o000000Co
ooooo`00ool00?ooo`00T_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2Nooooo`?o00000_ooool00ol0o`3o
o`00ool0002Dooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo09_ooooo0ol00003ooooo`?oo`00U_ooool002_o
oooo00?o0000ooooooooool0VOooool2o`0000?ooooo0ooo002Iooooo`00:oooool00ol0003ooooo
ooooo`2Fooooo`?o00000oooool00ol0o`3oo`00o`3o002Kooooo`00:oooool00ol0003ooooooooo
o`2Dooooo`;o0000Y?ooool002_ooooo0_l0002Cooooo`;o00000_ooool2o`00oj;ooooo000[oooo
o`03o`000?oooooooooo08oooooo0ol000001Ooooooo003oo`00ool00?oo0?l00:?ooooo000[oooo
o`03o`000?oooooooooo08gooooo0_l00002ooooo`;o003o00?oooooo`3o0?ooool0Y?ooool002_o
oooo00?o0000ooooooooool0Roooool2o`000004ooooool00?oo003oo`00ojWooooo000[ooooo`03
o`000?oooooooooo08Wooooo0_l000001?oooooo003oo`00ool0o`2[ooooo`00:oooool00ol0003o
ooooooooo`26ooooo`?o00000_ooool01?l00?oo0?l0o`3o0?ooool2ool00:Wooooo000[ooooo`03
o`000?oooooooooo08Cooooo0_l00004ooooo`03o`00ooooooooo`0000;oo`00Zoooool002_ooooo
00?o0000ooooooooool0P_ooool2o`0000Kooooo0_oo002^ooooo`00:oooool00ol0003ooooooooo
o`20ooooo`;o00001?ooool2o`3o0003oooooooo003ooooo0:oooooo000[ooooo`;o0000Ooooool2
o`0000Cooooo0_l0o`000oooooooo`00ool0002aooooo`00:oooool00ol0003oooooooooo`1loooo
o`;o00001oooool2ool00;?ooooo000[ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool01_ooool00ooo003oooooooooo`2cooooo`00:oooool00ol0003oooooooooo`1iooooo`;o0000
0oooool2o`3o00?ooooo00?oo`00ooooooooool0]?ooool002_ooooo00?o0000ooooooooool0Mooo
ool2o`0000;ooooo0_l00?l00ol0o`3oooooooooo`2jooooo`00:oooool00ol0003oooooooooo`1e
ooooo`;o00000_ooool2o`00okoooooo000[ooooo`03o`000?oooooooooo07?ooooo0_l00035oooo
o`00:oooool00ol0003oooooooooo`1aooooo`;o00001?ooool2o`3o0<7ooooo000[ooooo`03o`00
0?oooooooooo06oooooo0_l00004ooooo`;o0?l0`oooool002_ooooo0_l0001^ooooo`;o0000booo
ool002_ooooo00?o0000ooooooooool0Joooool2o`000<gooooo000[ooooo`03o`000?oooooooooo
06Wooooo0_l00004ooooo`;o0?l01?ooool2ool00<?ooooo000[ooooo`03o`000?oooooooooo06Oo
oooo0_l00002ooooo`;o003o00?oooooo`3o0?ooool01?ooool00ooo003oooooooooo`33ooooo`00
:oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo003o00;o003o1oooool2ool00<Kooooo
000[ooooo`03o`000?oooooooooo06Cooooo0_l000000ooooooo003oooooo`07ooooo`;oo`00b?oo
ool002_ooooo00?o0000ooooooooool0H_ooool2o`000003ooooool00?oo003o00;ooooo00?o0?l0
ooooooooool00oooool00ooo003oooooooooo`38ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Q
ooooo`04o`000?ooooooooooo`00o`?ooooo00?o0?l0ooooooooool00_ooool2ool00<_ooooo000@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Oooooo`;o00000_ooool01Ol00?oooooooooooooooooo0?l000?ooooo
0_oo003=ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
GOooool2o`0000;ooooo0_l00?l7ooooo`03ool00?oooooooooo0<gooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo05_o
oooo0_l00003ooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool0c_ooool0013ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`02ooooo`04o`00oooooooo0?l0o`3o00Kooooo00?oo`00
ooooooooool0c_ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool0F?ooool2o`0000Kooooo00?o0?l0ooooooooool0eoooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0E_ooool2o`000>;ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0h_ooool0
02_ooooo00?o0000ooooooooool0Doooool2o`000>Gooooo000[ooooo`03o`000?oooooooooo057o
oooo0_l00007ooooo`;o0?l0g_ooool002_ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`06ooooo`03o`3o0?oooooooooo0=kooooo000[ooooo`;o0000Coooool2o`000>[ooooo000[
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`3U
ooooo`00:oooool00ol0003oooooooooo`1;ooooo`;o00001?ooool00ol00?ooooooooooo`08oooo
o`;oo`00g?ooool002_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00;o0?l01_ooool00ooo003oooooooooo`3Looooo`00:oooool00ol0003ooooo
ooooo`18ooooo`;o00002?ooool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0=gooooo
000[ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`3Nooooo`00:oooool00ol0003oooooooooo`15ooooo`;o00004?ooool2ool00>7ooooo000[oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3Qoooo
o`00:oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Oooooo00?o0?l0oooooooo
ool01Oooool00ooo003oooooooooo`3Rooooo`00:oooool2o`0004;ooooo0_l00009ooooo`03o`3o
0?oooooooooo00Gooooo00?oo`00ooooooooool0hoooool002_ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>Cooooo000[ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03oooool2ool00>Oooooo000[ooooo`03o`000?oooooooooo
03gooooo0_l00004ooooo`;o003omOooool002_ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o0?l0ooooooooool0l?ooool002_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo
00?o0?l0ooooooooool0lOooool002_ooooo00?o0000ooooooooool0>Oooool2o`0000Gooooo00?o
003oooooooooool00_ooool00ol0o`3oooooooooo`3booooo`00:oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00?ooooo0_l00?ojooooo`00:oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0n_ooool002_ooooo0_l0000gooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0noooool002_ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o0?l0ooooooooool0
m_ooool002_ooooo00?o0000ooooooooool0<oooool2o`0000Gooooo00?o003oooooooooool00ooo
ool00ol0o`3oooooooooo`3gooooo`00:oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooo
oooo0?7ooooo000[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`0:ooooo`03ool00?oooooooooo0?;ooooo000[ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`3cooooo`004?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0m?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o0?l01oooool0
0ooo003oooooooooo`3eooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Ooo
ool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0?Kooooo000@ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000/ooooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool0moooool0013ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooooooool0n?ooool0013ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo0?Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04Oooool00ooo003oooooooooo`3jooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Wooooo00?o0?l0ooooooooool01Oooool00ooo003oooooooooo`3kooooo`00:oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_ooool00ol0o`3o
ooooooooo`05ooooo`03ool00?oooooooooo0?cooooo000[ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`3oooooo`_ooooo000[ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`3oooooo`_ooooo000[
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`3o
ooooo`cooooo000[ooooo`;o00009?ooool00ol0003oooooooooo`3ooooooaGooooo000[ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`3oooooo`[o
oooo000[ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0o`3ooooo
ooooo`3oooooo`_ooooo000[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0oooo
oolGooooo`00:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0?oooooo6?ooool0
02_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3ooooooaWooooo000[ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3oooooo`So
oooo000[ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0o`3ooooo
ooooo`03ooooo`03ool00?oooooooooo0?oooooo2Oooool002_ooooo0_l0000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0?l0ooooooooool00oooool00ooo003oooooooooo`3oooooo`[ooooo000[
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`03
ooooo`03ool00?oooooooooo0?oooooo2oooool002_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?oo`00ooooooooool0ooooool;oooo
o`00:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ooo003oooooooooo`3oooooo`cooooo000[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo0?oooooo
3Oooool002_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`04o`00oooo
ooooooooo`3o00Kooooo00?oo`00ooooooooool0ooooool>ooooo`00:oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`3o0005ooooo`03ool0
0?oooooooooo0?oooooo3oooool002_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooooooo00;o0?l01Oooool00ooo003oooooooooo`3ooooooa3ooooo000[
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`07
ooooo`03ool00?oooooooooo0?oooooo4Oooool002_ooooo0_l0000Eooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool01_ooool00ooo003oooooooooo`3ooooooa;ooooo000[ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`3ooooooaco
oooo000[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`3ooooooagooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Ooo
ool01?l00?ooooooooooool0o`3ooooooagooooo000[ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01Oooool01?l00?ooooooooooool0o`3ooooooakooooo000[ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`3oooooob3ooooo000[
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolXooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo:Oooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3oooooob[ooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000>ooooo`03
o`000?oooooooooo00Oooooo00?o0?l0ooooooooool0oooooolPooooo`004?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0o`3oooooooooo`3oooooob7ooooo000@ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo00;ooooo00?oo`00
ooooooooool0oooooolMooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@
okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`3ooooooagooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo0?oooooo7_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?oo`00ooooooooool0oooooolOooooo`00:oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0oooooolPooooo`00:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Go0?l0oooooooooooooooo
ool0003oooooob?ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool01?l00?ooooooooooool0o`03ooooo`03ool00?oooooooooo0?oooooo8_ooool002_ooooo0_l0
0009ooooo`03o`000?oooooooooo00Cooooo00?o003oooooool0o`000oooool00ooo003ooooooooo
o`3oooooob?ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`03ooooo`03ool00?oooooooooo0?oooooo9?ooool002_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?oo`00oooo
ooooool0oooooolUooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?oo`00ooooooooool0oooooolVooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00Co0?l0ooooooooooooo`00oooooolYooooo`00:oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0?l0ooooooooool0ooooool[ooooo`00:ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0?l0ooooooooool0oooo
ool/ooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo=?ooool0
02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocGooooo000[ooooo`;o
00001?ooool00ol0003oooooooooo`3oooooocGooooo000[ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0oooooolfooooo`00:oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0?l0ooooooooool0ooooool`ooooo`00:oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0?l0ooooooooool0ooooool`ooooo`00:oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0?l0ooooooooool0oooooolaooooo`00:oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o003oooooooooool0oooooolcooooo`00:oooool01?l0003oooooooooool0
0004ooooo`03o`00ooooooooo`000?oooooo<oooool002_ooooo00Co0000oooooooooooo00000ooo
ool01?l00?oooooooooooooo003ooooooc?ooooo000[ooooo`03o`000?oooooo000000?ooooo00Co
003oooooooooooooo`00ooooooldooooo`00:oooool3o`0000?ooooo00?o003oo`3o0?oo0000oooo
ooleooooo`00:oooool00ol0003oooooo`000002ooooo`03o`00ool0o`3oo`000?oooooo=_ooool0
02_ooooo00?o0000ooooool000000_ooool00ol00?ooo`00ooooo`3oooooocKooooo000[ooooo`06
o`000?oooooo0000ooooool00?ooo`00oooooolhooooo`00:oooool2o`000004ooooool00?oooooo
ool00?oooooo>?ooool002_ooooo0_l000000ooooooo003oool0003oooooocWooooo000Qooooo`Co
000000?o410@ooooooooool00oooool2o`000003o`00oooo003ooooo0?oooooo>Oooool002?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00o`3ooooooc_ooooo000Sooooo`03o`000?oo
oooooooo00Gooooo00?o0000o`00ooooool0oooooolkooooo`008oooool00ol0003oooooooooo`05
ooooo`03o`00ool0003o00000?oooooo>oooool002?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooooc_ooooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolkooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
>oooool0027ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3ooooooc_ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0005
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`0`
ooooo`03ofIVI_mgMgOooooo0?oooooo6?ooool000Gooooo00?o410@omgMgOooool01_ooool00ooM
gMgo410@onk^kP0:ooooo`;o<S8b8oooool00olQ8B7ogMgMooooo`0;ooooo`03onk^k_l@413ogMgM
0?oooooo6?ooool000?ooooo00Goc<c<oa0@4?l0003o0000ohN7Q`06ooooo`04oeEEEOnHV9Sooooo
oa0@40Go00001?ooool00on7QhOo0000okZj^P03ooooo`06onk^k_lb<S;o0000o`000?mEEEGok^k^
2Oooool01OnHV9So410@o`000?lb<S;oc<c<00;ooooo00?oEEEEojVYZOooool00_ooool01_nj^[[o
A4A4ooooooooooooV9RHoeEEE@Gooooo1Ol00003ooooo`03ohN7QomVIVKooooo0?oooooo5oooool0
00?ooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhL5ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00oo<c<co0000oa0@4003ooooo`08oeEEEOmgMgOoooooonk^k_n7QhOo
8B4Qonk^k_ooool6o`000006ooooool@413o^[ZjoooooomgMgOo<S8b0oooool01_mEEEGoV9RHoooo
oooooooo410@okZj^P?ooooo00?o0000omgMgOooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00?ok^k^o`000?ooool0oooooolGooooo`000oooool01_l0003oooooofIVI_n7QhOogMgM
oa0@40Gooooo00?o<S8booooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?oQhN7ogMgMoooool02oooool00ol0003oooooooooo`02ooooo`04oa0@4?oMgMgo
ooooo`0000Cooooo0_mgMgL5ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooo
oolFooooo`000oooool01_l@413ogMgMogMgMomgMgOoooooo`0000Gooooo00?o<S8booooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o8B4Qooooool00000
1Ol00004ooooo`03ojVYZOl@413ooooo00?ooooo00CoQhN7ofIVI_oooooo00001?ooool00oo^k^ko
410@onk^kP05ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool0oooooolFooooo`00
0oooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40Gooooo00?o0000onk^k_ooool00_ooool00ol0
003o<S8bomgMg@0;ooooo`03ob4Q8Ol0003o000000Co00002_ooool00ol@413o0000okZj^P04oooo
o`04omgMgOl@413oooooo`0000Gooooo00?oEEEEoiRHV?ooool01Oooool00omgMgOoIVIVooooo`02
ooooo`03onk^k_l0003ooooo0?oooooo5oooool000Cooooo00GoV9RHo`000?l0003o410@olc<c005
ooooo`04oeEEEOmgMgOoooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q2Oooool00onHV9SoQhN7
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o^[Zjob4Q8Oooool00_ooool7o`0000?ooooo
00?ogMgMoa0@4?ooool01_ooool01_l0003oooooooooooooooooMgMgoeEEEOoooooo6?ooool000Go
oooo00?o^[Zjoc8b<_ooool01_ooool00ooMgMgo410@onk^kP0Aooooo`06oc8b<_n7QhOok^k^oooo
oon7QhOo<S8b2?ooool01Ol@413oV9RHoooooonj^[[o000000kooooo00WoEEEEoiRHV?oooooooooo
o`000?nj^[[ooooooiRHV?l@41000_ooool00oo^k^ko410@omgMg@3ooooooaSooooo0006ooooo`03
o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool04?ooool01_o^k^koMgMgo`000?l0003o<S8b
olc<c0Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0>ooooo`09okZj^_m4A4CooooooooooonHV9So
410@o`000?lQ8B7oc<c<00;ooooo00?oIVIVogMgMoooool0oooooolHooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{73.5625, 302.938}, {198.5, 57.1875}} -> {-0.552137, \
0.4152, 0.0043491, 0.007037}}],

Cell[TextData[{
  "Fig. 6.2 Potential along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  "for exact solution (solid) and Galerkin solutions with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(P\_x\), "=", 
            RowBox[{\(P\_y\), "=", 
              StyleBox[\(1\ \((dashed)\)\),
                FontColor->RGBColor[1, 0, 0]]}]}], ",", 
          StyleBox[\(3\ \((dotted)\)\),
            FontColor->RGBColor[0, 1, 0]], ",", 
          StyleBox[\(5\ \((dot - dashed)\)\),
            FontColor->RGBColor[0, 0, 1]]}], TraditionalForm]]],
  ". "
}], "Caption",
  CellTags->"Fig. 6.2"],

Cell[TextData[{
  "\tThe solid curve is the analytic  solution, and the dashed, dotted, and \
dot-dashed curves are Galerkin solutions in order of increasing accuracy. The \
 Galerkin solutions do not converge very rapidly near the origin,  because of \
the singularity in the radial electric field caused by the cusp point. This \
can be seen directly in the  plot (Fig. ",
  ButtonBox["6.3",
    ButtonData:>"Fig. 6.3",
    ButtonStyle->"Hyperlink"],
  ")  of the radial electric field along the same line, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3\ \[Pi]/2\)]],
  ":"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.187867 0.10856 [
[.21429 .17537 -9 -9 ]
[.21429 .17537 9 0 ]
[.40476 .17537 -9 -9 ]
[.40476 .17537 9 0 ]
[.59524 .17537 -9 -9 ]
[.59524 .17537 9 0 ]
[.78571 .17537 -9 -9 ]
[.78571 .17537 9 0 ]
[.97619 .17537 -3 -9 ]
[.97619 .17537 3 0 ]
[1.025 .18787 0 -6 ]
[1.025 .18787 10 6 ]
[.01131 .07931 -12 -4.5 ]
[.01131 .07931 0 4.5 ]
[.01131 .29643 -6 -4.5 ]
[.01131 .29643 0 4.5 ]
[.01131 .40499 -6 -4.5 ]
[.01131 .40499 0 4.5 ]
[.01131 .51355 -6 -4.5 ]
[.01131 .51355 0 4.5 ]
[.02381 .64303 -37.625 0 ]
[.02381 .64303 37.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .18787 m
.21429 .19412 L
s
[(0.2)] .21429 .17537 0 1 Mshowa
.40476 .18787 m
.40476 .19412 L
s
[(0.4)] .40476 .17537 0 1 Mshowa
.59524 .18787 m
.59524 .19412 L
s
[(0.6)] .59524 .17537 0 1 Mshowa
.78571 .18787 m
.78571 .19412 L
s
[(0.8)] .78571 .17537 0 1 Mshowa
.97619 .18787 m
.97619 .19412 L
s
[(1)] .97619 .17537 0 1 Mshowa
.125 Mabswid
.07143 .18787 m
.07143 .19162 L
s
.11905 .18787 m
.11905 .19162 L
s
.16667 .18787 m
.16667 .19162 L
s
.2619 .18787 m
.2619 .19162 L
s
.30952 .18787 m
.30952 .19162 L
s
.35714 .18787 m
.35714 .19162 L
s
.45238 .18787 m
.45238 .19162 L
s
.5 .18787 m
.5 .19162 L
s
.54762 .18787 m
.54762 .19162 L
s
.64286 .18787 m
.64286 .19162 L
s
.69048 .18787 m
.69048 .19162 L
s
.7381 .18787 m
.7381 .19162 L
s
.83333 .18787 m
.83333 .19162 L
s
.88095 .18787 m
.88095 .19162 L
s
.92857 .18787 m
.92857 .19162 L
s
.25 Mabswid
0 .18787 m
1 .18787 L
s
gsave
1.025 .18787 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07931 m
.03006 .07931 L
s
[(-1)] .01131 .07931 1 0 Mshowa
.02381 .29643 m
.03006 .29643 L
s
[(1)] .01131 .29643 1 0 Mshowa
.02381 .40499 m
.03006 .40499 L
s
[(2)] .01131 .40499 1 0 Mshowa
.02381 .51355 m
.03006 .51355 L
s
[(3)] .01131 .51355 1 0 Mshowa
.125 Mabswid
.02381 .10102 m
.02756 .10102 L
s
.02381 .12273 m
.02756 .12273 L
s
.02381 .14444 m
.02756 .14444 L
s
.02381 .16615 m
.02756 .16615 L
s
.02381 .20958 m
.02756 .20958 L
s
.02381 .23129 m
.02756 .23129 L
s
.02381 .253 m
.02756 .253 L
s
.02381 .27472 m
.02756 .27472 L
s
.02381 .31814 m
.02756 .31814 L
s
.02381 .33985 m
.02756 .33985 L
s
.02381 .36156 m
.02756 .36156 L
s
.02381 .38328 m
.02756 .38328 L
s
.02381 .4267 m
.02756 .4267 L
s
.02381 .44841 m
.02756 .44841 L
s
.02381 .47012 m
.02756 .47012 L
s
.02381 .49184 m
.02756 .49184 L
s
.02381 .53526 m
.02756 .53526 L
s
.02381 .55697 m
.02756 .55697 L
s
.02381 .57868 m
.02756 .57868 L
s
.02381 .6004 m
.02756 .6004 L
s
.02381 .05759 m
.02756 .05759 L
s
.02381 .03588 m
.02756 .03588 L
s
.02381 .01417 m
.02756 .01417 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -98.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(E) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.250 13.000 moveto
(H) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
86.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
98.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
104.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(\\220) show
122.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(L) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .389 m
.04262 .38787 L
.06244 .38619 L
.08255 .38401 L
.10458 .3811 L
.14509 .37447 L
.18408 .36672 L
.22553 .35723 L
.26546 .34713 L
.30387 .33673 L
.34474 .32518 L
.38409 .3138 L
.42192 .30283 L
.46221 .29136 L
.50098 .28072 L
.54221 .2701 L
.58192 .26077 L
.62011 .25285 L
.66075 .24578 L
.69988 .24052 L
.7213 .23837 L
.7311 .23757 L
.74147 .23686 L
.75104 .23632 L
.75611 .23608 L
.76154 .23587 L
.76654 .2357 L
.7711 .23559 L
.77329 .23554 L
.77568 .2355 L
.77794 .23547 L
.78002 .23544 L
.78113 .23543 L
.78235 .23542 L
.78357 .23542 L
.78486 .23541 L
.786 .23541 L
.78722 .23541 L
.78837 .23541 L
.78942 .23541 L
.79006 .23541 L
.79075 .23542 L
.79198 .23543 L
.7933 .23544 L
.79475 .23545 L
.79736 .23549 L
.79979 .23553 L
.80508 .23565 L
.80992 .2358 L
.8208 .23627 L
Mistroke
.83067 .23685 L
.83982 .23753 L
.86056 .2396 L
.88112 .24237 L
.89974 .24555 L
.93986 .25461 L
.97619 .26561 L
Mfstroke
0 1 0 r
[ .008 .02 ] 0 setdash
.02381 .44105 m
.06244 .4255 L
.10458 .40756 L
.14415 .39024 L
.18221 .37357 L
.22272 .35619 L
.26171 .34014 L
.30316 .32411 L
.34309 .30991 L
.3815 .29759 L
.42237 .28604 L
.46172 .27652 L
.49955 .26885 L
.53984 .26226 L
.57861 .25735 L
.59832 .25535 L
.61984 .25351 L
.65954 .25093 L
.67922 .24997 L
.70019 .24912 L
.74177 .24775 L
.78184 .24644 L
.82039 .24473 L
.84033 .24351 L
.86139 .24185 L
.89936 .2376 L
.91887 .23463 L
.93979 .23072 L
.97619 .22178 L
s
0 0 1 r
[ .05 .05 .01 .05 ] 0 setdash
.02381 .47413 m
.06244 .45272 L
.10458 .42542 L
.14415 .39866 L
.18221 .37373 L
.22272 .34948 L
.26171 .32917 L
.30316 .31128 L
.34309 .29761 L
.3815 .28745 L
.42237 .27931 L
.46172 .27341 L
.49955 .26891 L
.53984 .26479 L
.57861 .26101 L
.61984 .25688 L
.65954 .25269 L
.69774 .24859 L
.73838 .24443 L
.77751 .24097 L
.79749 .23952 L
.81909 .23823 L
.83996 .23725 L
.85916 .23656 L
.87958 .23597 L
.89865 .23544 L
.91697 .23481 L
.92725 .23432 L
.93662 .23376 L
.94646 .23301 L
.95557 .23211 L
.96557 .23086 L
.97619 .22916 L
s
0 g
[ ] 0 setdash
.02499 0 m
.02499 .61803 L
s
.03665 .61803 m
.03756 .60715 L
.04262 .5635 L
.04755 .53349 L
.05285 .50901 L
.06244 .47654 L
.07373 .44932 L
.08445 .42973 L
.10458 .4024 L
.12439 .38259 L
.14277 .36802 L
.1819 .34444 L
.22348 .32606 L
.26355 .3123 L
.3021 .3015 L
.34311 .29189 L
.38259 .28403 L
.42056 .27745 L
.46099 .27132 L
.4999 .2661 L
.54126 .26115 L
.5811 .25689 L
.61943 .25318 L
.66022 .2496 L
.69948 .24645 L
.73723 .24368 L
.77744 .24096 L
.81612 .23855 L
.85726 .23618 L
.89689 .23407 L
.935 .23218 L
.97556 .23031 L
.97619 .23028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`00
0?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool0
0ol0003oooooooooo`3oooooocOooooo000_ooooo`;o0000oooooolhooooo`00;oooool00ol0003o
ooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o
0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_oooo
o`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00
;oooool2o`000?oooooo>?ooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool0
0ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oo
oooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo
000_ooooo`;o0000oooooolhooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_oooo
o`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00
9Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolgooooo`009ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=oooool001cooooo1_l00005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolgooooo`009oooool00ol0
003oooooooooo`05ooooo`;o0000oooooolhooooo`009oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo=oooool002Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooocOooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolgooooo`009Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0?oooooo=oooool0
02oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool2o`000?oooooo>?ooool002oooooo
00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_
ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgoooo
o`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo
=oooool002oooooo0_l0003oooooocSooooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool0
02oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOo
oooo000_ooooo`03o`000?oooooooooo0?oooooo=oooool002oooooo00?o0000ooooooooool0oooo
oolgooooo`00;oooool2o`000?oooooo>?ooool002oooooo00?o0000ooooooooool0:oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;Oooool4
o`000003oa0@4?oooooooooo01Sooooo000_ooooo`03o`000?oooooooooo02_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Toooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@0_ooooo`03o`000?oooooooooo01[ooooo000_ooooo`03o`000?oooooooooo02_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^02Cooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00009?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Tooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000002oooooo00?o0000ooooooooool06_ooool002oooooo00?o0000ooooooooool0:oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h08oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00009Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Tooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b02oooooo00?o0000ooooooooool06_ooool002oooooo00?o
0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
8_ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00009Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Tooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<02oooooo00?o0000oooooooo
ool06_ooool002oooooo00?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool08Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000009Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool09_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400_ooooo`03o`00
0?oooooooooo01[ooooo000_ooooo`;o0000;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00V
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000002oooooo
00?o0000ooooooooool06_ooool002oooooo00?o0000ooooooooool0:oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Sooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@410Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY02gooooo00?oEEEEofIVI_l000007?ooool002oooooo00?o0000ooooooooool0
oooooolgooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooo
oooo0?oooooo;?ooool00ol@413o0000o`000003o`0000Gooooo000_ooooo`03o`000?oooooooooo
0?oooooo;_ooool00ol0003oooooooooo`06ooooo`009oooooooo`0002ko00002oooool00ol0003o
ooooooooo`06ooooo`00;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`00;oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04Oooool00ol0003o<S8bomgM
g@06ooooo`00;oooool00ol0003oooooooooo`3oooooobgooooo0_l000001?nYZJWo8B4Qo`000?lQ
8B44ooooo`00;oooool00ol0003oooooooooo`3oooooocOooooo000_ooooo`03o`000?oooooooooo
0?oooooo=oooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool2o`000?oooooo
>?ooool002oooooo00?o0000ooooooooool0oooooolgooooo`00;oooool00ol0003oooooooooo`3o
ooooocOooooo000_ooooo`03o`000?oooooooooo0?oooooo6Oooool2o`3o01cooooo000_ooooo`03
o`000?oooooooooo0?oooooo6?ooool00ol0o`3oooooooooo`0Looooo`00;oooool00ol0003ooooo
ooooo`3ooooooa;ooooo0_l0o`0Sooooo`00;oooool2o`000?oooooo4Oooool2o`3o00;ooooo1ol0
000Looooo`00;oooool00ol0003oooooooooo`3loooooaOo00000_l00?lQooooo`00;oooool00ol0
003oooooooooo`3:ooooo`[oo`003_ooool2ool001So00000_l00?l2ooooo`;o0?l01Oooool00ol0
o`3oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`34ooooo`Koo`003_ooool<o`0000?o
003o3Oooool2ool00004ooooool0o`3o0?l0o`3o00Gooooo00?o0?l0ooooooooool0=?ooool002oo
oooo00?o0000ooooooooool0cOooool;o`0000oooooo0_l0o`05ooooo`?o0?l01Oooool00ol0o`3o
ooooooooo`0mooooo`00;oooool00ol0003oooooooooo`31ooooo`co00000_l00?l00ol0o`3ooooo
ooooo`03ooooo`?o0?l01Oooool4o`3o00Gooooo00?o0?l0ooooooooool06oooool4ool002kooooo
000_ooooo`03o`000?oooooooooo0;?ooooo0_oo000<o`0000?ooooo1?l0o`10ooooo`Goo`00:Ooo
ool002oooooo0_l0002Zooooo`co00002?l00?m@ooooo`Coo`009Oooool002oooooo00?o0000oooo
ooooool0WOooool<o`0000;oo`000_ooool8o`00oecooooo0_oo000Sooooo`00;oooool00ol0003o
ooooooooo`2Dooooo`Wo000000?o0?l0ooooooooool0Loooool00ooo003oooooooooo`0Pooooo`00
;oooool00ol0003oooooooooo`2>ooooo`Ko000000?o0?l0ooooooooool01?ooool4o`00oiOooooo
000_ooooo`03o`000?oooooooooo08Gooooo2Ol0002Xooooo`00;oooool00ol0003oooooooooo`1l
ooooo`Wo000000?oooooo`00ool00?l01?l00?l:ooooo`?oo`00WOooool002oooooo0_l0001goooo
o`Ko000000?oooooo`00ool00?l01ol00?l;ooooo`Goo`00X?ooool002oooooo00?o0000oooooooo
ool0L?ooool6o`0001Oooooo1?oo002Uooooo`00;oooool00ol0003oooooooooo`1[ooooo`Go0000
2_ooool3o`3o00kooooo0_oo002Yooooo`00;oooool00ol0003oooooooooo`1Uooooo`Ko000000?o
ooooo`00ool00?l00_l00?lJooooo`03ool00?oooooooooo0:Wooooo000Uooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1Oooooo`Ko00003?ooool4o`3o0<7ooooo000Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F_ooool5o`000=Oooooo000Wooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool4o`00017ooooo0_l0o`39ooooo`00
9oooool00ol0003oooooooooo`05ooooo`;o0000Doooool4o`0000Gooooo0ol00?l;ooooo`;o0?l0
3_ooool3ool00;[ooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Cooo
ool3o`0000Kooooo0ol00?l8ooooo`;o0?l04Oooool3ool00;gooooo000Wooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0C?ooool3o`0000Kooooo0ol00?l9ooooo`;o0?l03oooool4
ool00<3ooooo000Wooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool3o`00
00Kooooo0ol00?lJooooo`?oo`00a?ooool002Gooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`16ooooo`?o00001oooool2o`00o`Wooooo0_l0o`0@ooooo`;oo`00aoooool002oooooo
00?o0000ooooooooool0@oooool3o`0000Wooooo00?o003oooooooooool01oooool2o`3o0=_ooooo
000_ooooo`;o0000@Oooool3o`000??ooooo000_ooooo`03o`000?oooooooooo03gooooo0ol0000C
ooooo`;o0?l0hOooool002oooooo00?o0000ooooooooool0>_ooool3o`0001Cooooo0_l0o`08oooo
o`Goo`00e_ooool002oooooo00?o0000ooooooooool0=oooool3o`0001kooooo0ooo003Kooooo`00
;oooool00ol0003oooooooooo`0dooooo`?o00005?ooool2o`3o00Sooooo0ooo003Nooooo`00;ooo
ool00ol0003oooooooooo`0booooo`;o00003?ooool2o`00o`Sooooo00?o0?l0ooooooooool01Ooo
ool3ool00>7ooooo000_ooooo`03o`000?oooooooooo033ooooo0_l0000=ooooo`03o`00oooooooo
oooo00kooooo0_oo003Tooooo`00;oooool2o`0002kooooo0ol0000Cooooo`;o0?l0lOooool002oo
oooo00?o0000ooooooooool0:oooool2o`0001Gooooo00?o0?l0ooooooooool0lOooool002oooooo
00?o0000ooooooooool0:Oooool2o`000?oooooo3?ooool002oooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0@ooooo`;o0?l00oooool3ool00??ooooo000_ooooo`03o`000?oooooo
oooo02Kooooo0_l0000Booooo`03o`3o0?oo003oo`0000?oo`00m_ooool002oooooo00?o0000oooo
ooooool09?ooool2o`00013ooooo1Ooo003kooooo`00;oooool2o`0002Cooooo00?o0000oooooooo
ool03Oooool00ooo003o0?l0o`3o003oooooo`7ooooo000_ooooo`03o`000?oooooooooo027ooooo
0_l0000>ooooo`;o003o00?o0?l0ooooooooool0ooooool1ooooo`00;oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00cooooo0_l00?ooooooo`Kooooo000_ooooo`03o`000?oooooo
oooo01oooooo00Co0000oooooooooooooooo0ooo0007ooooo`;o003oooooool8ooooo`00;oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oo003oo`0000;oo`002?ooool2o`00oooooooo2_ooool0
02oooooo00?o0000ooooooooool06Oooool4ool00003o`000?oooooooooo00Wooooo0_l00?oooooo
o`cooooo000_ooooo`03o`000?oooooooooo01Kooooo0ooo0003ooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooooooool0ooooool<ooooo`00;oooool2o`0001cooooo00?o0000ooooooooool0
1_ooool2o`3o00;o003oooooool?ooooo`00;oooool00ol0003oo`00ool00008ool001;ooooo00?o
0000ooooooooool01_ooool00ol0o`3oooooo`00o`3ooooooa7ooooo000_ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0oooooolKooooo`00;oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo0_l0o`3ooooooaSooooo000Tooooo`Go00001_ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooooooo`;o0?l0oooooolJooooo`009?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3ooooo
oakooooo000Uooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0000Fooooo`03o`000?oooooooooo0?oo
oooo7oooool002Kooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Dooooo`03o`3o
0?l0003o0?l00?oooooo8?ooool002Oooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0?oooooo8?ooool002Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo8Oooool002Cooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00gooooo0_l0o`03ooooo`03o`000?oooooo
oooo00?ooooo0_l00?oooooooagooooo000Tooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0<ooooo`03o`3o0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`3ooooooagooooo000_ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`3ooooooakooooo000_ooooo`;o00001_ooool2o`3o00Wo
oooo00?o0000ooooooooool0oooooolTooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`3o
0?oooooooooo00Sooooo00?o0000ooooooooool0oooooolUooooo`00;oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0?oooooo9Oooool002oooooo00?o0000o`3o0?l0o`003_ooool0
0ol0003oooooooooo`3oooooobKooooo000_ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0oooooolWooooo`00;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oo
oooo9oooool002oooooo0_l0000=ooooo`03o`000?oooooooooo0?oooooo:?ooool002oooooo00?o
0000ooooooooool02Oooool2o`00o`03o`000?oooooooooo0?oooooo:Oooool002oooooo00?o0000
ooooooooool01oooool2o`00o`;ooooo00?o0000ooooooooool0oooooolYooooo`00;oooool00ol0
003oooooooooo`05ooooo`;o003o0oooool00ol0003oooooooooo`3oooooob[ooooo000_ooooo`03
o`000?oooooooooo00?ooooo0_l00?l5ooooo`03o`000?oooooooooo0?oooooo:_ooool002oooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
:_ooool002oooooo00?o0000ooooooooool00_l00?l7ooooo`03o`000?oooooooooo0?oooooo:ooo
ool002oooooo00?o0000o`00ool00?l02Oooool00ol0003oooooooooo`3oooooob_ooooo000_oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool[ooooo`00;oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0?oooooo;?ooool002oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3oooooobcooooo000_ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0ooooool]ooooo`00;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo;Oooool002oooooo0_l00008ooooo`03o`000?oooooooooo0?oooooo;Oooool002oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooobkooooo000_ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool^ooooo`00;oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo;_ooool002Cooooo00GoV9RHoa0@4?l0003o<S8bolc<
c006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool_ooooo`009?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooooboooooo000Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooooboooooo000Wooooo`03ojVYZOl@413ooooo00Gooooo0_l00006oooo
o`03o`000?oooooooooo0?oooooo;oooool002Kooooo00?o410@o`000?nj^[X01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo;oooool002Oooooo00?o^[Zjob4Q8Oooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo;oooool002Cooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool`ooooo`009?ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc3ooooo000_ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool`ooooo`00;oooool2o`0000Gooooo00?o0000ooooooooool0ooooool`
ooooo`00;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo<?ooool002oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooc3ooooo000_ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooolaooooo`00;oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo<Oooool002oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooooc7ooooo000_ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooolaooooo`00;oooool2o`0000Cooooo00?o0000ooooooooool0oooooolaooooo`00
;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo<_ooool002oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc;ooooo000_ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolbooooo`00;oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo<_ooool002oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooc;ooooo000_ooooo`;o00000oooool00ol0003oooooooooo`3ooooooc;ooooo
000_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolbooooo`00;oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo<_ooool002oooooo00Go0000oooo
ooooooooooooo`00003oooooocGooooo000_ooooo`05o`000?ooooooooooooooool00000oooooole
ooooo`00;oooool01Ol0003ooooooooooooooooo00000?oooooo=Oooool002oooooo00Go0000oooo
ooooooooooooo`00003oooooocGooooo000_ooooo`;o00000_ooool00ol0003oooooooooo`3ooooo
oc?ooooo000_ooooo`05o`000?ooooooooooooooool00000ooooooleooooo`00;oooool01Ol0003o
oooooooooooooooo00000?oooooo=Oooool002oooooo00Go0000ooooooooooooooooo`00003ooooo
ocGooooo000_ooooo`04o`000?ooooooooooo`000?oooooo=_ooool002oooooo00Co0000oooooooo
oooo0000oooooolfooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`002_ooool3o`0000Sooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`0aoooo
o`03ofIVI_mgMgOooooo0?oooooo4Oooool000_ooooo00?o0000ooooooooool01_ooool00ooMgMgo
410@onk^kP0:ooooo`;o<S8b9?ooool00olQ8B7ogMgMooooo`0;ooooo`03onk^k_l@413ogMgM0?oo
oooo4Oooool000;ooooo1_l00003ooooo`03o`000?oooooooooo00Kooooo00GoEEEEoiRHV?oooooo
oooooa0@4005o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01_o^k^ko<S8bo`000?l0003oEEEE
onk^kPWooooo00SoV9RHoa0@4?l0003o<S8bolc<c?ooooooEEEEojVYZ@?ooooo00?o^[ZjodA4A?oo
ool00_ooool00onHV9SoEEEEooooo`03ooooo`Go00001?ooool00on7QhOoIVIVooooo`3ooooooa3o
oooo0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooo`000?l00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004oooo
o`07oeEEEOmgMgOoooooonk^k_n7QhOo8B4Qonk^kP06o`0000;ooooo00Go410@okZj^_ooooooMgMg
oc8b<P02ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj1?ooool00ol0003ogMgMooooo`02oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00oo^k^ko0000ooooo`3ooooooa3ooooo0003oooo
o`05o`000?ooooooooooooooool@41003?ooool00olb<S;oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00on7QhOoMgMgooooo`0;ooooo`08o`000?oooooo
ooooooooool@413ogMgMooooool00005ooooo`;oMgMg1?ooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0?oooooo3oooool000?ooooo00?o0000ooooool@41003_ooool00olb<S;ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00olQ8B7o0000
o`000004o`0000Gooooo00?oZJVYoa0@4?ooool00_ooool01?n7QhOoIVIVooooool00005ooooo`03
onk^k_l@413ok^k^00Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooo`oo
oooo0003ooooo`?o00003_ooool00ol0003ok^k^ooooo`03ooooo`03o`000?lb<S;ogMgM00_ooooo
00?o8B4Qo`000?l000001?l0000:ooooo`03oa0@4?l0003o^[Zj00?ooooo00CogMgMoa0@4?oooooo
00001_ooool00omEEEGoV9RHooooo`04ooooo`03ogMgMomVIVKooooo00?ooooo00?ok^k^o`000?oo
ool0ooooool@ooooo`000oooool01Ol0003ooooooa0@4?oooooo410@00cooooo00?oEEEEogMgMooo
ool00_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Wooooo00?oV9RHohN7Qoooool00oooool00ol0
003oooooooooo`09ooooo`04okZj^_lQ8B7oooooooooo`Oo00001?ooool00ooMgMgo410@ooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoeEEEOooool0ooooool@ooooo`000oooool01Ol0
003ooooooooooooooooo000000cooooo00?ogMgMoa0@4?o^k^h04_ooool01_lb<S;oQhN7onk^k_oo
ooooQhN7oc8b<PSooooo00Go410@oiRHV?oooooo^[Zjo`00000>ooooo`08oeEEEOnHV9Soooooo`00
0?nj^[[ooooooiRHV?l@4103ooooo`03onk^k_l@413ogMgM0?oooooo4Oooool000;ooooo1_l0000=
ooooo`03ogMgMomVIVKooooo017ooooo00Kok^k^ogMgMol0003o0000oc8b<_o<c<`8ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT03_ooool02?nj^[[oA4A4oooooonHV9So410@o`000?lQ8B7oc<c<0ooo
ool00omVIVKoMgMgooooo`3ooooooa7ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{73.5625, 302.938}, {198.5, 57.1875}} -> {-0.569741, \
0.813124, 0.00439685, 0.0385729}}],

Cell[TextData[{
  "Fig. 6.3 Radial electric field along ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 3  \[Pi]/2\)]],
  "for exact solution (solid) and Galerkin solutions with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(P\_x\), "=", 
            RowBox[{\(P\_y\), "=", 
              StyleBox[\(1\ \((dashed)\)\),
                FontColor->RGBColor[1, 0, 0]]}]}], ",", 
          StyleBox[\(3\ \((dotted)\)\),
            FontColor->RGBColor[0, 1, 0]], ",", 
          StyleBox[\(5\ \((dot - dashed)\)\),
            FontColor->RGBColor[0, 0, 1]]}], TraditionalForm]]],
  "."
}], "Caption",
  CellTags->"Fig. 6.3"],

Cell[TextData[{
  "As might be expected, our Galerkin solution fails to capture the singular \
behavior near the origin, although it is reasonably accurate for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterTilde] 0.5\)]],
  ". Many more terms are needed to roughly approximate the singularity, but \
calculation of the required inner products is computationally intensive.  In \
general, numerical solutions near singularities are problematic in any \
numerical method. However, the Galerkin method in particular is best suited \
to problems with smoothly varying solutions, unless the required inner \
products are easy to evaluate."
}], "Text"],

Cell[TextData[{
  "\tIn Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:24",
    ButtonStyle->"Hyperlink"],
  ", we will observe that grid methods can do a somewhat better job in \
resolving solutions near singularities, if the grid is chosen to be \
sufficiently fine.  "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.1.3 Time-Dependent Problems", "Subsubtitle",
  CellTags->{"i:11", "c:9"}],

Cell[CellGroupData[{

Cell["The Heat Equation", "Section",
  CellTags->"c:10"],

Cell[TextData[{
  "The Galerkin method can also be used in the solution of PDEs with time \
dependence. As a simple example, we will use it to solve the heat equation in \
one dimension on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ x \[LessEqual] \ b\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, 
            t)\) = \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) \(T(x, t)\) + 
          S(x, t)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.15)"],

Cell["subject to mixed boundary conditions ", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`T(0, t) = \(T\_1\)(
        t), \[IndentingNewLine]\(\[PartialD]T\/\[PartialD]x\) \((b, t)\) = 
      0, \)]]], "NumberedEquation",
  CellTags->"(6.1.16)"],

Cell["and the initial condition", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(T\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.17)"],

Cell["We write the solution in the usual manner as ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t) = \[Sum]\_\(n = 0\)\%M\(\( c\_n\)(t)\)\ \(\(v\_n\)(x)\) + 
          u(x, t)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  "is any smooth function that satisfies the boundary conditions. For this \
problem, the choice"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(u(x, t)\)\(\ \)\(=\)\(\ \)\(\(T\_1\)(
          t)\)\(\ \)\)\)]],
  " "
}], "NumberedEquation",
  CellTags->"(6.1.19)"],

Cell["works well.", "Text"],

Cell[TextData[{
  "\t The basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(x)\)]],
  " are any set of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " functions that form a complete set  as ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", and that satisfy homogeneous mixed boundary conditions of the same type \
as specified in the problem. In this case, this implies homogeneous Dirichlet \
conditions  on one end, and homogeneous ",
  "von Neumann ",
  " conditions on the other:"
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          0) = \(\(\[PartialD]v\_n\/\[PartialD]x\) \((b)\) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For example, we could choose these functions to be eigenmodes of the \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\/\[PartialD]x\^2\)]],
  ", and then we would have the usual eigenmode expansion, as discussed \
previously in Secs. ",
  ButtonBox["3.1.4",
    ButtonData:>{"Chapter3.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.2.2",
    ButtonData:>{"Chapter4.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  ".  Here, however, we will choose some other set. For instance, one simple \
choice is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_n\)(
          x)\  = \ \ x\^n\ \((1 - \(n\/\(n + 1\)\) x\/b)\), \ \ n = 1, 
      2,  ... , M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.20)"],

Cell[TextData[{
  "Some of these functions are in Cell ",
  ButtonBox["6.32",
    ButtonData:>"Cell 6.32",
    ButtonStyle->"Hyperlink"],
  ", assuming ",
  Cell[BoxData[
      \(TraditionalForm\`b = 2\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v[n_, x_]\  = \ \ \ x^n \((1 - n \((x/b)\)\/\(n + 1\))\);\)\), "\n", 
    \(b = 2; \ 
    Plot[Evaluate[Table[v[n, x], {n, 1, 4}]], {x, 0, b}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.32"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.183939 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10668 -18 -4.5 ]
[.01131 .10668 0 4.5 ]
[.01131 .19865 -6 -4.5 ]
[.01131 .19865 0 4.5 ]
[.01131 .29062 -18 -4.5 ]
[.01131 .29062 0 4.5 ]
[.01131 .38259 -6 -4.5 ]
[.01131 .38259 0 4.5 ]
[.01131 .47456 -18 -4.5 ]
[.01131 .47456 0 4.5 ]
[.01131 .56653 -6 -4.5 ]
[.01131 .56653 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10668 m
.03006 .10668 L
s
[(0.5)] .01131 .10668 1 0 Mshowa
.02381 .19865 m
.03006 .19865 L
s
[(1)] .01131 .19865 1 0 Mshowa
.02381 .29062 m
.03006 .29062 L
s
[(1.5)] .01131 .29062 1 0 Mshowa
.02381 .38259 m
.03006 .38259 L
s
[(2)] .01131 .38259 1 0 Mshowa
.02381 .47456 m
.03006 .47456 L
s
[(2.5)] .01131 .47456 1 0 Mshowa
.02381 .56653 m
.03006 .56653 L
s
[(3)] .01131 .56653 1 0 Mshowa
.125 Mabswid
.02381 .03311 m
.02756 .03311 L
s
.02381 .0515 m
.02756 .0515 L
s
.02381 .0699 m
.02756 .0699 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .12508 m
.02756 .12508 L
s
.02381 .14347 m
.02756 .14347 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .18026 m
.02756 .18026 L
s
.02381 .21705 m
.02756 .21705 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .25384 m
.02756 .25384 L
s
.02381 .27223 m
.02756 .27223 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .32741 m
.02756 .32741 L
s
.02381 .3458 m
.02756 .3458 L
s
.02381 .3642 m
.02756 .3642 L
s
.02381 .40099 m
.02756 .40099 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .43777 m
.02756 .43777 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .49296 m
.02756 .49296 L
s
.02381 .51135 m
.02756 .51135 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .54814 m
.02756 .54814 L
s
.02381 .58493 m
.02756 .58493 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .02934 L
.10458 .04459 L
.14415 .05826 L
.18221 .07081 L
.22272 .08352 L
.26171 .09513 L
.30316 .10679 L
.34309 .11737 L
.3815 .12693 L
.42237 .13645 L
.46172 .14498 L
.49955 .15258 L
.53984 .16004 L
.57861 .1666 L
.61984 .1729 L
.65954 .17832 L
.69774 .18293 L
.73838 .18719 L
.77751 .19065 L
.81909 .19365 L
.85916 .19588 L
.87754 .19668 L
.89771 .1974 L
.91765 .19796 L
.92854 .19819 L
.93871 .19837 L
.94354 .19844 L
.94878 .1985 L
.95341 .19855 L
.95832 .19859 L
.96273 .19862 L
.96524 .19863 L
.9676 .19864 L
.96976 .19865 L
.97173 .19865 L
.97277 .19865 L
.97391 .19865 L
.97509 .19865 L
.97619 .19865 L
s
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01473 L
.03053 .01475 L
.03279 .01478 L
.03527 .01482 L
.0379 .01487 L
.04262 .015 L
.05205 .01535 L
.06244 .01589 L
.07293 .0166 L
.0842 .01755 L
.10458 .01971 L
.1458 .02576 L
.18551 .03352 L
.22371 .04259 L
.26435 .05375 L
.30348 .06574 L
.34506 .07961 L
.38513 .09383 L
.42368 .10811 L
.46468 .12372 L
.50417 .13895 L
.54214 .15358 L
.58257 .16891 L
.62148 .18325 L
.66284 .19779 L
.70268 .2109 L
.74101 .22249 L
.78179 .23348 L
.82106 .24257 L
.85881 .24971 L
.87978 .25294 L
.89901 .2554 L
.91786 .25732 L
.92745 .25811 L
.9377 .2588 L
.94804 .25934 L
.95744 .25969 L
.96198 .2598 L
.96436 .25985 L
.96689 .2599 L
.9691 .25993 L
.97027 .25994 L
.97153 .25995 L
.97269 .25996 L
.97374 .25996 L
.9748 .25997 L
Mistroke
.97581 .25997 L
.97619 .25997 L
Mfstroke
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01472 L
.03884 .01472 L
.04016 .01472 L
.04262 .01473 L
.045 .01473 L
.04753 .01474 L
.0521 .01475 L
.05752 .01478 L
.06244 .01481 L
.06787 .01486 L
.07287 .01491 L
.08414 .01507 L
.09408 .01527 L
.10458 .01556 L
.11406 .01588 L
.12422 .0163 L
.14255 .0173 L
.16379 .01887 L
.18391 .02082 L
.22224 .02595 L
.26302 .03364 L
.30229 .04344 L
.34004 .05517 L
.38024 .0702 L
.41893 .0871 L
.46007 .10756 L
.4997 .1295 L
.5378 .1524 L
.57837 .17836 L
.61741 .20446 L
.65891 .23284 L
.69889 .26018 L
.73736 .28583 L
.77828 .31162 L
.81768 .33417 L
.85557 .35288 L
.87664 .36171 L
.89591 .36861 L
.91605 .37451 L
Mistroke
.93473 .37865 L
.94394 .38017 L
.95375 .38141 L
.95936 .38192 L
.96211 .38212 L
.96464 .38227 L
.9669 .38238 L
.96937 .38248 L
.97066 .38252 L
.97186 .38255 L
.97313 .38257 L
.97384 .38258 L
.97449 .38259 L
.97531 .38259 L
.97619 .38259 L
Mfstroke
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.04011 .01472 L
.04141 .01472 L
.04262 .01472 L
.04521 .01472 L
.04765 .01472 L
.04984 .01472 L
.05221 .01472 L
.05481 .01472 L
.05754 .01472 L
.06244 .01472 L
.06507 .01473 L
.06746 .01473 L
.07283 .01473 L
.07781 .01474 L
.08253 .01476 L
.08802 .01477 L
.09309 .01479 L
.09862 .01482 L
.10458 .01486 L
.11421 .01494 L
.12324 .01504 L
.13399 .01519 L
.14385 .01538 L
.16277 .01589 L
.17349 .01629 L
.18347 .01673 L
.20393 .01791 L
.22252 .01936 L
.2417 .0213 L
.2625 .024 L
.28198 .02716 L
.30342 .03144 L
.34282 .04184 L
.38316 .05636 L
.42198 .07456 L
.46326 .09888 L
Mistroke
.50302 .12743 L
.54127 .15971 L
.58196 .19912 L
.62115 .24163 L
.66278 .29096 L
.7029 .34152 L
.7415 .39163 L
.78256 .44468 L
.8221 .4933 L
.86012 .53532 L
.88131 .55569 L
.9006 .57178 L
.91927 .5847 L
.92911 .59031 L
.93956 .59526 L
.94861 .59866 L
.95342 .60011 L
.9586 .60138 L
.96334 .60228 L
.96541 .60258 L
.96768 .60286 L
.96983 .60306 L
.97183 .6032 L
.97293 .60325 L
.97394 .60329 L
.9751 .60331 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00H03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0A03oool400000003014A4@3oool0oooo
0480oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM04<0oooo1@0000080?ooo`00H03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo04D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`04
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`120?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0203o
ool00600oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<0
VIVI028R8P3^k^h02@3oool00600oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c
<c<0oooo04D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c
<c<0oooo04@0oooo00<0VIVI028R8P3^k^h0203oool00600oooo00D000000?ooo`3oool0oooo0000
000<0?ooo`050000000R8R80000003<c<`3<c<`0AP3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00/0oooo00D00000028R8P000000<c<c0<c<c0160?ooo`0307MgM`1VIVH0oooo00L0
oooo001P0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00H0oooo001P0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`150?ooo`050000002k^k/0oooo09VIV@0A4A40203oool00600oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0<0?ooo`@00000A@3oool205EEE@030000003oool0oooo04@0oooo0P1EEED00`00
0000oooo0?ooo`0;0?ooo`@00000A03oool01@2IVIT04A4A0000000R8R80c<c<00P0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`004P3ooooo000005L00000000J0?ooo`03
0000003oool00000008000002`3oool:000000L0oooo00<000000?ooo`3oool00`3oool>00000003
0?ooo`0000000000010000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`006P3oool00`000000oooo
0?ooo`020?ooo`<000004P3oool7000001@0oooo1P00000=0?ooo`L000000P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`070?ooo`006P3oool00`000000oooo0?ooo`050?ooo`8000005`3oool7000001<0oooo1`00
000=0?ooo`L00000n03oool001X0oooo00<000000?ooo`3oool01`3oool3000001/0oooo1P00000D
0?ooo`L000003@3oool500000?<0oooo000J0?ooo`030000003oool0oooo00X0oooo0`00000N0?oo
o`L00000503oool7000000/0oooo0`00003`0?ooo`006P3oool3000000d0oooo0`00000R0?ooo`D0
00005P3oool5000000T0oooo1000003/0?ooo`006P3oool00`000000oooo0?ooo`0@0?ooo`<00000
903oool5000001H0oooo0`00000:0?ooo`D00000i`3oool001X0oooo00<000000?ooo`3oool04`3o
ool3000002H0oooo1000000E0?ooo`<00000303oool500000>80oooo000J0?ooo`030000003oool0
oooo01H0oooo0`00000W0?ooo`@00000503oool3000000h0oooo0`00003O0?ooo`006P3oool00`00
0000oooo0?ooo`0I0?ooo`800000:@3oool3000001@0oooo1000000=0?ooo`<00000g03oool001X0
oooo00<000000?ooo`3oool06`3oool3000002T0oooo1000000D0?ooo`<000003@3oool300000=T0
oooo000J0?ooo`<000007P3oool3000002X0oooo0`00000D0?ooo`<000003@3oool300000=H0oooo
000J0?ooo`030000003oool0oooo0240oooo0P00000[0?ooo`@000004`3oool3000000d0oooo0`00
003C0?ooo`006P3oool00`000000oooo0?ooo`0S0?ooo`<00000;03oool3000001<0oooo0`00000=
0?ooo`800000d@3oool001X0oooo00<000000?ooo`3oool09P3oool3000002`0oooo0`00000C0?oo
o`<00000303oool200000<l0oooo000J0?ooo`030000003oool0oooo02T0oooo0`00000/0?ooo`<0
00004`3oool3000000/0oooo0P00003=0?ooo`006P3oool00`000000oooo0?ooo`0/0?ooo`<00000
;03oool400000180oooo0`00000:0?ooo`<00000bP3oool001X0oooo00<000000?ooo`3oool0;`3o
ool3000002d0oooo0`00000B0?ooo`<000002P3oool200000<P0oooo000J0?ooo`<00000<P3oool4
000002`0oooo0`00000B0?ooo`8000002P3oool200000<H0oooo000J0?ooo`030000003oool0oooo
03H0oooo0`00000/0?ooo`<000004@3oool2000000X0oooo0P0000340?ooo`006P3oool00`000000
oooo0?ooo`0i0?ooo`@00000:`3oool300000100oooo0P00000:0?ooo`030000003oool0oooo0<40
oooo000J0?ooo`030000003oool0oooo03d0oooo0`00000[0?ooo`800000403oool3000000P0oooo
0P0000310?ooo`006P3oool00`000000oooo0?ooo`100?ooo`@00000:@3oool300000100oooo0P00
00080?ooo`030000003oool0oooo0;h0oooo000J0?ooo`030000003oool0oooo04@0oooo0`00000Y
0?ooo`<000003`3oool2000000L0oooo0P00002n0?ooo`006P3oool3000004L0oooo0`00000Y0?oo
o`8000003`3oool2000000L0oooo0P00002l0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`<0
0000:03oool3000000h0oooo0`0000060?ooo`030000003oool0oooo0;T0oooo000J0?ooo`030000
003oool0oooo04d0oooo1000000W0?ooo`8000003`3oool2000000D0oooo0P00002i0?ooo`006P3o
ool00`000000oooo0?ooo`1A0?ooo`<000009P3oool3000000h0oooo0P0000050?ooo`030000003o
ool0oooo0;H0oooo0000100c<c<0000003<c<`3^k^h50?ooo`808R8R1@3oool01@14A4@000000000
000c<c<0gMgM00D0oooo00<000000?ooo`3oool0E03oool4000002D0oooo0`00000=0?ooo`<00000
0`3oool200000;H0oooo0000102IVIT0oooo09VIV@1gMgL50?ooo`808R8R203oool00`1gMgL0<c<c
0?ooo`040?ooo`030000003oool0oooo05P0oooo0`00000U0?ooo`8000003P3oool2000000<0oooo
00<000000?ooo`3oool0/`3oool000<0oooo00<04A4A0?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`<00000F`3oool4000002<0oooo0`00000=0?ooo`8000000P3oool200000;<0oooo0003
0?ooo`030000003oool0oooo00d0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`1O
0?ooo`<000008`3oool2000000d0oooo00D000000?ooo`3oool0oooo0000002b0?ooo`000`3oool0
0`000000oooo0?ooo`0:0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?oo
o`1R0?ooo`@000008@3oool3000000/0oooo0P0000020?ooo`800000/03oool000<0oooo00<04A4A
0?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06H0oooo0`00000Q
0?ooo`<000002P3oool200000080oooo00<000000?ooo`3oool0[@3oool0000409VIV@3oool0VIVI
07MgM``0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1Y0?ooo`@00000803oool3
000000T0oooo00@000000?ooo`3oool00000[P3oool0000403<c<`000000<c<c0>k^kP`0oooo1000
00060?ooo`030000003oool0oooo06d0oooo1@00000N0?ooo`<000001`3oool2000000030?ooo`00
000000000:`0oooo000J0?ooo`<00000LP3oool4000001d0oooo0P0000070?ooo`80000000<0oooo
0000003oool0ZP3oool001X0oooo00<000000?ooo`3oool0MP3oool4000001/0oooo0`0000060?oo
o`040000003oool0000000000:T0oooo000J0?ooo`030000003oool0oooo07X0oooo1@00000I0?oo
o`<00000103oool2000000030?ooo`000000oooo0:L0oooo000J0?ooo`030000003oool0oooo07l0
oooo1@00000G0?ooo`<000000`3oool00`000000oooo0000002W0?ooo`006P3oool00`000000oooo
0?ooo`240?ooo`@000005P3oool3000000040?ooo`000000000000000:H0oooo000J0?ooo`030000
003oool0oooo08P0oooo1@00000D0?ooo`80000000<0oooo000000000000Y@3oool001X0oooo00<0
00000?ooo`3oool0S@3oool400000180oooo1@00002S0?ooo`006P3oool300000940oooo1000000A
0?ooo`<00000XP3oool001X0oooo00<000000?ooo`3oool0U@3oool5000000l0oooo0P00002P0?oo
o`006P3oool00`000000oooo0?ooo`2J0?ooo`@00000303oool4000009d0oooo000J0?ooo`030000
003oool0oooo09h0oooo1P0000070?ooo`D00000V`3oool001X0oooo00<000000?ooo`3oool0Y03o
ool7000000050?ooo`000000oooo0000003oool00`00002H0?ooo`006P3oool00`000000oooo0?oo
o`2[0?ooo`H000000P3oool3000009D0oooo000J0?ooo`<00000[P3oool00`000000oooo00000004
000000030?ooo`000000000009<0oooo000J0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool00P0000000`3oool000000000000400000900oooo000J0?ooo`030000003oool0oooo0;00
oooo00@000000?ooo`3oool0oooo0P0000030?ooo`H00000S03oool001X0oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo2@0000250?ooo`00
6P3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0080oooo0P0000070?ooo`<00000
0`3oool7000007h0oooo000J0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`<000001`3oool7000007L0oooo000J0?ooo`<00000]03oool0
0`000000oooo0?ooo`030?ooo`8000002P3oool3000000/0oooo2P00001]0?ooo`006P3oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool20000
01<0oooo2@00001T0?ooo`006P3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo00@0
oooo0P00000<0?ooo`<000006@3oool7000005d0oooo000J0?ooo`030000003oool0oooo0;L0oooo
00<000000?ooo`3oool01@3oool2000000d0oooo0`00000M0?ooo`X00000D`3oool00100oooo1000
00000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`<00000903oool>000004D0oooo000B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`060?ooo`800000403oool3
000002l0oooo3P00000g0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<00000^P3oool00`00
0000oooo0?ooo`070?ooo`8000004@3oool2000003/0oooo;P0000090?ooo`004P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`<00000K`3oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo00P0oooo0P00000C0?ooo`<00000K03oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04`3oool2000006X0oooo000B0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`090?ooo`8000005@3oool3000006L0oooo000@0?oo
o`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05@3oool3000006@0oooo000J0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`<00000H@3oool001X0oooo
0`0000310?ooo`030000003oool0oooo00X0oooo0P00000J0?ooo`<00000GP3oool001X0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo0`00
001K0?ooo`006P3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo00/0oooo0P00000M
0?ooo`@00000E`3oool001X0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo01h0oooo1@00001B0?ooo`006P3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool5000004d0oooo000J0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool0303oool2000002L0oooo100000190?ooo`006P3o
ool300000<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`D00000A03o
ool001X0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0=0?ooo`800000;@3oool5
000003l0oooo000J0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0_0?ooo`@00000>`3oool001X0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0?0?ooo`800000<`3oool4000003L0oooo000J0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool0403oool2000003D0oooo1000000c0?ooo`006P3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool6000002d0oooo000J
0?ooo`<00000c03oool00`000000oooo0?ooo`0A0?ooo`800000?03oool7000002H0oooo000J0?oo
o`030000003oool0oooo0<d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`100?oo
o``000006P3oool001X0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0B0?ooo`80
0000C03ooolA000000T0oooo000J0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1S0?ooo`006P3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo01@0oooo0P00001S0?ooo`006P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0H03oool001X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`0E0?ooo`800000H03oool001X0oooo0`00003B0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0G@3oool001X0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo05`0oooo000J0?ooo`030000003oool0oooo0=<0oooo00<0
00000?ooo`3oool05`3oool2000005`0oooo000400000003014A4@3oool0oooo0080oooo0P0R8R85
0?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0F@3oool00080oooo00<000000?ooo`3oool0103oool2
028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo01P0oooo0P00001I0?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05H0oooo00020?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0103oool300000=L0
oooo00<000000?ooo`3oool06@3oool2000005H0oooo00020?ooo`030000003oool0oooo00/0oooo
00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1C0?ooo`000P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0K0?ooo`800000
D`3oool00080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`3oool0703oool200000540oooo000205EEE@030000003oool0
oooo00/0oooo100000060?ooo`030000003oool0oooo0=X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1>0?ooo`006P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
01h0oooo0P00001>0?ooo`006P3oool300000=/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1;0?ooo`006P3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo01l0oooo
0P00001;0?ooo`006P3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0B03oool001X0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0P
0?ooo`800000B03oool001X0oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`0R0?oo
o`800000AP3oool001X0oooo00<000000?ooo`3oool0g`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo04<0oooo000J0?ooo`<00000h03oool00`000000oooo0?ooo`0S0?ooo`800000
@`3oool001X0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0T0?ooo`800000@@3o
ool001X0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo03h0oooo000J0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool09P3oool20000
03h0oooo000J0?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool09`3oool2000003`0
oooo000J0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0:03oool2000003X0oooo
000J0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0:P3oool3000003L0oooo000J
0?ooo`<00000i@3oool00`000000oooo0?ooo`0/0?ooo`800000=@3oool001X0oooo00<000000?oo
o`3oool0iP3oool00`000000oooo0?ooo`0]0?ooo`800000<`3oool001X0oooo00<000000?ooo`3o
ool0i`3oool00`000000oooo0?ooo`0^0?ooo`800000<@3oool001X0oooo00<000000?ooo`3oool0
j03oool00`000000oooo0?ooo`0_0?ooo`<00000;P3oool001X0oooo00<000000?ooo`3oool0j@3o
ool00`000000oooo0?ooo`0a0?ooo`<00000:`3oool001X0oooo00<000000?ooo`3oool0j@3oool0
0`000000oooo0?ooo`0d0?ooo`<00000:03oool001X0oooo0`00003Z0?ooo`030000003oool0oooo
03H0oooo0`00000U0?ooo`006P3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo03P0
oooo0`00000R0?ooo`006P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo03X0oooo
0`00000O0?ooo`006P3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo03`0oooo1000
000K0?ooo`003`3oool5000000H0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`10
0?ooo`<00000603oool000l0oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0
oooo0>h0oooo00<000000?ooo`3oool0@P3oool600000180oooo000@0?ooo`0309VIV@0R8R80k^k^
00L0oooo0`00003_0?ooo`030000003oool0oooo04L0oooo2@0000090?ooo`004@3oool00`2IVIT0
8R8R0>k^kP060?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0F03oool00180oooo
00<0MgMg06IVIP3oool01@3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo05L0oooo
000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?oo
o`1F0?ooo`003`3oool01@000000^k^k0?ooo`2IVIT04A4A00H0oooo00<000000?ooo`3oool0lP3o
ool00`000000oooo0?ooo`1F0?ooo`003`3oool01@2IVIT04A4A0000000R8R80c<c<00H0oooo00<0
00000?ooo`3oool0l`3oool00`000000oooo0?ooo`1E0?ooo`006P3oool300000?@0oooo00<00000
0?ooo`3oool0E03oool001X0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`1C0?oo
o`006P3oool00`000000oooo0?ooo`3e0?ooo`030000003oool0oooo05<0oooo000J0?ooo`030000
003oool0oooo0?H0oooo00<000000?ooo`3oool0DP3oool001X0oooo00<000000?ooo`3oool0m`3o
ool00`000000oooo0?ooo`1A0?ooo`006P3oool00`000000oooo0?ooo`3g0?ooo`030000003oool0
oooo0540oooo000J0?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool0D03oool001X0
oooo0`00003i0?ooo`030000003oool0oooo04l0oooo000J0?ooo`030000003oool0oooo0?X0oooo
00<000000?ooo`3oool0CP3oool001X0oooo00<000000?ooo`3oool0nP3oool00`000000oooo0?oo
o`1>0?ooo`006P3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo04d0oooo000J0?oo
o`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0C03oool001X0oooo00<000000?ooo`3o
ool0o03oool00`000000oooo0?ooo`1<0?ooo`006P3oool300000?d0oooo00<000000?ooo`3oool0
B`3oool001X0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`1:0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooo`030000003oool0oooo04T0oooo000J0?ooo`030000003oool0oooo
0?l0oooo00<000000?ooo`3oool0B@3oool001X0oooo00<000000?ooo`3oool0o`3oool10?ooo`03
0000003oool0oooo04P0oooo000J0?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo
0?ooo`170?ooo`006P3oool300000?l0oooo0`3oool00`000000oooo0?ooo`160?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0A@3oool001X0oooo00<000000?oo
o`3oool0o`3oool50?ooo`030000003oool0oooo04@0oooo000J0?ooo`030000003oool0oooo0?l0
oooo1@3oool00`000000oooo0?ooo`140?ooo`00100000050?ooo`808R8R1@3oool01@14A4@00000
0000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo04<0
oooo0000100R8R80k^k^0?ooo`14A4@50?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`03
0000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`120?ooo`0000<0VIVI028R8P3^k^h0
4@3oool00`000000oooo0?ooo`030?ooo`<00000o`3oool80?ooo`030000003oool0oooo0440oooo
0000103oool0VIVI028R8P3^k^h?0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0
o`3oool90?ooo`030000003oool0oooo0400oooo00020?ooo`0307MgM`1VIVH0oooo00/0oooo00D0
0000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo
0?ooo`100?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3oool:0?ooo`030000003oool0oooo03l0oooo0000102k^k/0oooo09VIV@0A
4A4<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003o
ool0oooo03h0oooo0000100A4A400000028R8P3<c<`<0?ooo`@000001P3oool00`000000oooo0?oo
o`3o0?ooo``0oooo00<000000?ooo`3oool0?@3oool001X0oooo00<000000?ooo`3oool0o`3oool=
0?ooo`030000003oool0oooo03`0oooo000J0?ooo`<00000o`3oool>0?ooo`030000003oool0oooo
03/0oooo000J0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0k0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<000000?ooo`3oool0>P3oool001X0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo03T0oooo000J0?ooo`030000003oool0
oooo0?l0oooo4@3oool00`000000oooo0?ooo`0h0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
oa80oooo00<000000?ooo`3oool0=`3oool001X0oooo0`00003o0?oooa<0oooo00<000000?ooo`3o
ool0=P3oool001X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`030000003oool0oooo03D0oooo
000J0?ooo`030000003oool0oooo0?l0oooo5@3oool00`000000oooo0?ooo`0d0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool0<`3oool001X0oooo00<000000?oo
o`3oool0o`3ooolG0?ooo`030000003oool0oooo0380oooo000J0?ooo`030000003oool0oooo0?l0
oooo603oool00`000000oooo0?ooo`0a0?ooo`006P3oool300000?l0oooo6@3oool00`000000oooo
0?ooo`0`0?ooo`006P3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool0;`3o
ool001X0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo02h0oooo000J0?oo
o`030000003oool0oooo0?l0oooo703oool00`000000oooo0?ooo`0]0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0;03oool001X0oooo00<000000?ooo`3oool0
o`3ooolN0?ooo`030000003oool0oooo02/0oooo000J0?ooo`<00000o`3ooolO0?ooo`030000003o
ool0oooo02X0oooo000J0?ooo`030000003oool0oooo0?l0oooo803oool00`000000oooo0?ooo`0Y
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooob40oooo00<000000?ooo`3oool0:03oool001X0
oooo00<000000?ooo`3oool0o`3ooolR0?ooo`800000:03oool000l0oooo00D0VIVI014A4@000000
<c<c0<c<c0060?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0U0?ooo`00
3`3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00H0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`80
00009@3oool001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooobL0oooo
00<000000?ooo`3oool08P3oool00180oooo00<0ZZZZ014A4@3oool01@3oool300000?l0oooo:03o
ool00`000000oooo0?ooo`0Q0?ooo`004@3oool00`0A4A4000000;^k^`060?ooo`030000003oool0
oooo0?l0oooo:@3oool200000240oooo000B0?ooo`030;^k^`0R8R80oooo00D0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`030000003oool0oooo01h0oooo000?0?ooo`05014A4@2IVIT0oooo0;^k
^`0000001P3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<000000?ooo`3oool07@3oool000l0
oooo00D0ZZZZ014A4@0000004A4A0:ZZZP060?ooo`030000003oool0oooo0?l0oooo;@3oool00`00
0000oooo0?ooo`0L0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3o
ool06`3oool001X0oooo0`00003o0?ooobl0oooo0P00000K0?ooo`006P3oool00`000000oooo0?oo
o`3o0?oooc40oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0o`3ooolb
0?ooo`<000005`3oool001X0oooo00<000000?ooo`3oool0o`3ooole0?ooo`<00000503oool001X0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`030000003oool0oooo0140oooo000J0?ooo`030000
003oool0oooo0?l0oooo>@3oool300000100oooo000J0?ooo`<00000o`3oooll0?ooo`L000002@3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
 \tNext, we choose an inner product. We will make the  simple \
choice\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_0\%b\( f\^*\) g\ \[DifferentialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.21)"],

Cell[TextData[{
  "\tThe Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " in Eq. ",
  ButtonBox["(6.1.18)",
    ButtonData:>"(6.1.18)",
    ButtonStyle->"Hyperlink"],
  " must now be determined. To do so, we first substitute Eq. ",
  ButtonBox["(6.1.18)",
    ButtonData:>"(6.1.18)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.1.15)",
    ButtonData:>"(6.1.15)",
    ButtonStyle->"Hyperlink"],
  ", obtaining"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\[PartialD]\/\[PartialD]t\) \(\
\(c\_n\)(t)\)\ \(\(v\_n\)(
              x)\) = \(\(\[Chi] \(\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(
                  t)\)\ \(\[PartialD]\^2\/\[PartialD]x\^2\) \(\(v\_n\)(
                  x)\)\)\)\(\ \)\(+\)\(\(S\&_\)(x, t)\)\(\ \)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.22)"],

Cell[TextData[{
  "where the modified source function ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t)\)]],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(S\&_\)(x, t) = 
      S(x, t)\  + \ \[Chi]\ \(\[PartialD]\^2\/\[PartialD]x\^2\) \(u(x, 
            t)\) - \(\[PartialD]\/\[PartialD]t\) \(u(x, 
            t)\)\)]]], "NumberedEquation",
  CellTags->"(6.1.23)"],

Cell[TextData[{
  "Now, we take an inner product of Eq. ",
  ButtonBox["(6.1.22)",
    ButtonData:>"(6.1.22)",
    ButtonStyle->"Hyperlink"],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ", yielding"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\((v\_m, 
              v\_n)\) \(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
              t)\)\  = \[Sum]\_\(n = 1\)\%M\(\( c\_n\)(
                t)\)\ \((v\_m, \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) 
                  v\_n)\) + \((v\_m, S\&_)\)\)]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2,  ... , M\)]]
}], "NumberedEquation",
  CellTags->"(6.1.24)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  " provides a set of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " coupled ODE's for the time variation of the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  ". One can solve these ODEs either analytically or numerically (using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "). The initial conditions on the ODEs are determined by Eq. ",
  ButtonBox["(6.1.17)",
    ButtonData:>"(6.1.17)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(0)\)\ \(\(v\_n\)(
                x)\) + u(x, 0) = \(T\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.25)"],

Cell[TextData[{
  "Taking an inner product of this equation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ", we obtain a set of coupled equations for the ",
  "initial-value",
  "s of the Fourier coefficients:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(n = 1\)\%M\(\( c\_n\)(0)\)\ \((v\_m, 
              v\_n)\) = \ \((v\_m, T\_o - u(x, 0))\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2,  ... , M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.26)"],

Cell[TextData[{
  " These ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " equations",
  ",",
  " together with the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " ODEs given by Eq. ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  ", are sufficient to specify ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands solve this problem on the time interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ \[Tau]\)]],
  ". We will use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to numerically determine the solutions to Eqs. ",
  ButtonBox["(6.1.24)",
    ButtonData:>"(6.1.24)",
    ButtonStyle->"Hyperlink"],
  ", subject to the initial conditions of Eq. ",
  ButtonBox["(6.1.26)",
    ButtonData:>"(6.1.26)",
    ButtonStyle->"Hyperlink"],
  ".  The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " are referred to as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["c",
              FontSlant->"Plain"], "[", 
            StyleBox["n",
              FontSlant->"Plain"], "]"}], "[", 
          StyleBox["t",
            FontSlant->"Plain"], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This notation is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[", ",
    FontWeight->"Bold"],
  "and it works in ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", whereas the notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " will not. This is because ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " interprets that as an instruction to solve a PDE for the function of two \
variables ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["c",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["t",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". (Recall that the same issue arose when we performed molecular dynamics \
simulations in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:27"},
    ButtonStyle->"Hyperlink"],
  ".) "
}], "Text"],

Cell[TextData[{
  "\tSince this is a numerical solution to the problem, we must choose \
specific forms for the initial and boundary conditions explicitly, and we \
must also choose a numerical value for the thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " and the size of the interval, ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". Below, we make these choices keeping ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(8\)\(\ \)\)\)]],
  "terms in the series expansion of the solution, and solving over a time \
interval of ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \[Tau] = 15\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(T0[x_]\  = \ 1; \ T1[t_]\  = 1 + \ Sin[t]; \ 
    S[x_, t_]\  = \ 0;\n\), "\[IndentingNewLine]", 
    \(\[Chi] = 1/8; \ b = 2; \ M = 8\ ; \ \[Tau] = 15. ;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.33"],

Cell["\<\
The temperature on the left side of the slab oscillates in time, \
and on the right the temperature gradient is zero.  \
\>", "Text"],

Cell[TextData[{
  "\tTo construct the Galerkin solution to this problem, we first define the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  ", according to Eq. ",
  ButtonBox["(6.1.19)",
    ButtonData:>"(6.1.19)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(u[x_, t_]\  = \ T1[t];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.34"],

Cell[TextData[{
  "We then define the inner product, as in Eq. ",
  ButtonBox["(6.1.21)",
    ButtonData:>"(6.1.21)",
    ButtonStyle->"Hyperlink"],
  ". In this case, we will assume that the functions to be integrated are \
sufficiently straightforward that the integrals can be done analytically \
using ",
  StyleBox["Integrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(norm[f_, g_]\)\(\ \)\(:=\)\(\ \)\(Integrate[
        f\ g, {x, 0, b}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.35"],

Cell[TextData[{
  "It is also useful to define the spatial operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Chi]\ \
\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(L[f_]\  := \ \[Chi]\ D[f, {x, 2}]\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.36"],

Cell[TextData[{
  "Next, we define the projection of the operator onto the functions, ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\) = \((v\_m, \(L\&^\) v\_n)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(Lmat[m_, n_]\  := \ norm[v[m, x], \ L[v[n, x]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.37"],

Cell[TextData[{
  "We then define the inner product  of the functions with each other, ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_m, v\_n)\)\)]],
  " .  Here we use symmetry of the inner product with respect to the \
interchange of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in order to reduce the number of integrations needed. Also, we use the \
double-equal-sign notation to store previously determined values of the inner \
product without redoing the integration:"
}], "Text"],

Cell[BoxData[{
    \(\(nm[n_, m_]\  := \ \((nm[n, m]\  = \ norm[v[m, x], v[n, x]]\ )\) /; 
          n \[GreaterEqual] \ m\ \ ;\)\), "\n", 
    \(nm[n_, m_]\  := \ 
      nm[m, n]\  /; \ \(\(n\)\(<\)\(m\)\(\ \ \)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.38"],

Cell[TextData[{
  "Next, we define the projection of the source function ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t)\)]],
  "onto the ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(Svec[m_]\  := \ 
        norm[v[m, x], \ 
          S[x, t] - D[u[x, t], t]\  + \ L[u[x, t]]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.39"],

Cell["\<\
We are ready to specify the differential equations for the Fourier \
coefficients: \
\>", "Text"],

Cell[BoxData[
    \(\(eq[m_]\  := \(eq[m]\  = \ 
          Sum[nm[m, n]\ D[\(c[n]\)[t], t], {n, 1, M}]\  \[Equal] \ 
            Sum[Lmat[m, n]\ \(c[n]\)[t], {n, 1, M}]\  + \ 
              Svec[m]\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.40"],

Cell["It is useful to print out the equations as a check:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[Print["\<eq[\>", m, "\<]= \>", eq[m]], {m, 1, M}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.41"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(16\/15\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(52\/45\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(152\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(208\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(544\/189\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(1376\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3392\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"16384", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1485"]}], 
          "==", \(\(-\(\(4\ Cos[t]\)\/3\)\) - 1\/12\ \(c[0]\)[t] - 
            1\/12\ \(c[1]\)[t] - 1\/10\ \(c[2]\)[t] - 2\/15\ \(c[3]\)[t] - 
            4\/21\ \(c[4]\)[t] - 2\/7\ \(c[5]\)[t] - 4\/9\ \(c[6]\)[t] - 
            32\/45\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 0, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16, 15], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 52, 45], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 152, 105], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 208, 105], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 544, 189], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 1376, 315], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 3392, 495], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 16384, 1485], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -4, 3], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -1, 10], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -4, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -2, 7], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -4, 9], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -32, 45], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(52\/45\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(416\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(12\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2272\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(32\/9\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"18944", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3465"], "+",
             
            RowBox[{\(4288\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"54272", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3861"]}], 
          "==", \(\(-\(\(4\ Cos[t]\)\/3\)\) - 1\/12\ \(c[0]\)[t] - 
            2\/15\ \(c[1]\)[t] - 1\/5\ \(c[2]\)[t] - 32\/105\ \(c[3]\)[t] - 
            10\/21\ \(c[4]\)[t] - 16\/21\ \(c[5]\)[t] - 56\/45\ \(c[6]\)[t] - 
            1024\/495\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 1, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 52, 45], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 416, 315], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 12, 7], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 2272, 945], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 32, 9], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 18944, 3465], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 4288, 495], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 54272, 3861], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -4, 3], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 12], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -1, 5], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -32, 105], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -10, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -16, 21], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -56, 45], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -1024, 495], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(152\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(12\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(16\/7\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(736\/225\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2432\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2944\/385\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(5248\/429\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(16384\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          "==", \(\(-\(\(8\ Cos[t]\)\/5\)\) - 1\/10\ \(c[0]\)[t] - 
            1\/5\ \(c[1]\)[t] - 12\/35\ \(c[2]\)[t] - 4\/7\ \(c[3]\)[t] - 
            20\/21\ \(c[4]\)[t] - 8\/5\ \(c[5]\)[t] - 448\/165\ \(c[6]\)[t] - 
            256\/55\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 2, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 152, 105], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 12, 7], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 16, 7], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 736, 225], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 2432, 495], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 2944, 385], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 5248, 429], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 16384, 819], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -8, 5], 
              Cos[ t]], 
            Times[ 
              Rational[ -1, 10], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1, 5], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -12, 35], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -4, 7], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -20, 21], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -8, 5], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -448, 165], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -256, 55], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(208\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2272\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(736\/225\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"11776", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "2475"], "+",
             
            RowBox[{\(3584\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"171008", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "15015"], 
            "+", 
            RowBox[{\(3584\/195\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"1859584", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "61425"]}], 
          "==", \(\(-\(\(32\ Cos[t]\)\/15\)\) - 2\/15\ \(c[0]\)[t] - 
            32\/105\ \(c[1]\)[t] - 4\/7\ \(c[2]\)[t] - 64\/63\ \(c[3]\)[t] - 
            16\/9\ \(c[4]\)[t] - 512\/165\ \(c[5]\)[t] - 
            896\/165\ \(c[6]\)[t] - 4096\/429\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 3, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 208, 105], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 2272, 945], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 736, 225], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 11776, 2475], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 3584, 495], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 171008, 15015], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 3584, 195], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 1859584, 61425], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -32, 15], 
              Cos[ t]], 
            Times[ 
              Rational[ -2, 15], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -32, 105], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -4, 7], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -64, 63], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -16, 9], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -512, 165], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -896, 165], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -4096, 429], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(544\/189\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(32\/9\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(2432\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3584\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"14336", " ", 
                RowBox[{
                  SuperscriptBox[\(c[4]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1287"], "+",
             
            RowBox[{\(11264\/637\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(23552\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(45056\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], 
          "==", \(\(-\(\(64\ Cos[t]\)\/21\)\) - 4\/21\ \(c[0]\)[t] - 
            10\/21\ \(c[1]\)[t] - 20\/21\ \(c[2]\)[t] - 16\/9\ \(c[3]\)[t] - 
            320\/99\ \(c[4]\)[t] - 64\/11\ \(c[5]\)[t] - 
            4480\/429\ \(c[6]\)[t] - 5120\/273\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 4, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 544, 189], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 32, 9], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 2432, 495], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 3584, 495], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 14336, 1287], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 11264, 637], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 23552, 819], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 45056, 945], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -64, 21], 
              Cos[ t]], 
            Times[ 
              Rational[ -4, 21], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -10, 21], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -20, 21], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -16, 9], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -320, 99], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -64, 11], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -4480, 429], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -5120, 273], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1376\/315\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"18944", " ", 
                RowBox[{
                  SuperscriptBox[\(c[1]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3465"], "+",
             
            RowBox[{\(2944\/385\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"171008", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "15015"], 
            "+", 
            RowBox[{\(11264\/637\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"90112", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3185"], "+",
             
            RowBox[{\(4864\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"413696", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "5355"]}], 
          "==", \(\(-\(\(32\ Cos[t]\)\/7\)\) - 2\/7\ \(c[0]\)[t] - 
            16\/21\ \(c[1]\)[t] - 8\/5\ \(c[2]\)[t] - 512\/165\ \(c[3]\)[t] - 
            64\/11\ \(c[4]\)[t] - 1536\/143\ \(c[5]\)[t] - 
            256\/13\ \(c[6]\)[t] - 16384\/455\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 5, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 1376, 315], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 18944, 3465], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 2944, 385], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 171008, 15015], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 11264, 637], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 90112, 3185], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 4864, 105], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 413696, 5355], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -32, 7], 
              Cos[ t]], 
            Times[ 
              Rational[ -2, 7], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -16, 21], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -8, 5], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -512, 165], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -64, 11], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -1536, 143], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -256, 13], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -16384, 455], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            RowBox[{\(3392\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[0]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(4288\/495\), " ", 
              RowBox[{
                SuperscriptBox[\(c[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(5248\/429\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(3584\/195\), " ", 
              RowBox[{
                SuperscriptBox[\(c[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(23552\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(4864\/105\), " ", 
              RowBox[{
                SuperscriptBox[\(c[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{\(19456\/255\), " ", 
              RowBox[{
                SuperscriptBox[\(c[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"176128", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1377"]}], 
          "==", \(\(-\(\(64\ Cos[t]\)\/9\)\) - 4\/9\ \(c[0]\)[t] - 
            56\/45\ \(c[1]\)[t] - 448\/165\ \(c[2]\)[t] - 
            896\/165\ \(c[3]\)[t] - 4480\/429\ \(c[4]\)[t] - 
            256\/13\ \(c[5]\)[t] - 7168\/195\ \(c[6]\)[t] - 
            1024\/15\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 6, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 3392, 495], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 4288, 495], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 5248, 429], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 3584, 195], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 23552, 819], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 4864, 105], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 19456, 255], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 176128, 1377], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -64, 9], 
              Cos[ t]], 
            Times[ 
              Rational[ -4, 9], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -56, 45], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -448, 165], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -896, 165], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -4480, 429], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -256, 13], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -7168, 195], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -1024, 15], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "7", 
        "\[InvisibleSpace]", "\<\"]= \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            FractionBox[
              RowBox[{"16384", " ", 
                RowBox[{
                  SuperscriptBox[\(c[0]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1485"], "+",
             
            FractionBox[
              RowBox[{"54272", " ", 
                RowBox[{
                  SuperscriptBox[\(c[1]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "3861"], "+",
             
            RowBox[{\(16384\/819\), " ", 
              RowBox[{
                SuperscriptBox[\(c[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"1859584", " ", 
                RowBox[{
                  SuperscriptBox[\(c[3]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "61425"], 
            "+", 
            RowBox[{\(45056\/945\), " ", 
              RowBox[{
                SuperscriptBox[\(c[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
            FractionBox[
              RowBox[{"413696", " ", 
                RowBox[{
                  SuperscriptBox[\(c[5]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "5355"], "+",
             
            FractionBox[
              RowBox[{"176128", " ", 
                RowBox[{
                  SuperscriptBox[\(c[6]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "1377"], "+",
             
            FractionBox[
              RowBox[{"5636096", " ", 
                RowBox[{
                  SuperscriptBox[\(c[7]\), "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "26163"]}], 
          "==", \(\(-\(\(512\ Cos[t]\)\/45\)\) - 32\/45\ \(c[0]\)[t] - 
            1024\/495\ \(c[1]\)[t] - 256\/55\ \(c[2]\)[t] - 
            4096\/429\ \(c[3]\)[t] - 5120\/273\ \(c[4]\)[t] - 
            16384\/455\ \(c[5]\)[t] - 1024\/15\ \(c[6]\)[t] - 
            32768\/255\ \(c[7]\)[t]\)}]}],
      SequenceForm[ "eq[", 7, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16384, 1485], 
              Derivative[ 1][ 
                c[ 0]][ t]], 
            Times[ 
              Rational[ 54272, 3861], 
              Derivative[ 1][ 
                c[ 1]][ t]], 
            Times[ 
              Rational[ 16384, 819], 
              Derivative[ 1][ 
                c[ 2]][ t]], 
            Times[ 
              Rational[ 1859584, 61425], 
              Derivative[ 1][ 
                c[ 3]][ t]], 
            Times[ 
              Rational[ 45056, 945], 
              Derivative[ 1][ 
                c[ 4]][ t]], 
            Times[ 
              Rational[ 413696, 5355], 
              Derivative[ 1][ 
                c[ 5]][ t]], 
            Times[ 
              Rational[ 176128, 1377], 
              Derivative[ 1][ 
                c[ 6]][ t]], 
            Times[ 
              Rational[ 5636096, 26163], 
              Derivative[ 1][ 
                c[ 7]][ t]]], 
          Plus[ 
            Times[ 
              Rational[ -512, 45], 
              Cos[ t]], 
            Times[ 
              Rational[ -32, 45], 
              c[ 0][ t]], 
            Times[ 
              Rational[ -1024, 495], 
              c[ 1][ t]], 
            Times[ 
              Rational[ -256, 55], 
              c[ 2][ t]], 
            Times[ 
              Rational[ -4096, 429], 
              c[ 3][ t]], 
            Times[ 
              Rational[ -5120, 273], 
              c[ 4][ t]], 
            Times[ 
              Rational[ -16384, 455], 
              c[ 5][ t]], 
            Times[ 
              Rational[ -1024, 15], 
              c[ 6][ t]], 
            Times[ 
              Rational[ -32768, 255], 
              c[ 7][ t]]]]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "The initial conditions on the Fourier coefficients are specified according \
to Eq. ",
  ButtonBox["(6.1.26)",
    ButtonData:>"(6.1.26)",
    ButtonStyle->"Hyperlink"],
  ". We print these out as well:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ic[m_]\  := \ \(ic[m]\  = \ 
          Sum[nm[m, n]\ \(c[n]\)[0], {n, 1, M}]\  \[Equal] \ 
            norm[v[m, x], T0[x] - u[x, 0]]\);\)\n\), "\[IndentingNewLine]", 
    \(\(Do[Print["\<ic[\>", m, "\<]= \>", ic[m]], {m, 1, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.42"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]0\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(16\/15\ \(c[0]\)[0] + 52\/45\ \(c[1]\)[0] + 
            152\/105\ \(c[2]\)[0] + 208\/105\ \(c[3]\)[0] + 
            544\/189\ \(c[4]\)[0] + 1376\/315\ \(c[5]\)[0] + 
            3392\/495\ \(c[6]\)[0] + \(16384\ \(c[7]\)[0]\)\/1485 == 0\)\),
      SequenceForm[ "ic[", 0, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16, 15], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 52, 45], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 152, 105], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 208, 105], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 544, 189], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 1376, 315], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 3392, 495], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 16384, 1485], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]1\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(52\/45\ \(c[0]\)[0] + 416\/315\ \(c[1]\)[0] + 
            12\/7\ \(c[2]\)[0] + 2272\/945\ \(c[3]\)[0] + 
            32\/9\ \(c[4]\)[0] + \(18944\ \(c[5]\)[0]\)\/3465 + 
            4288\/495\ \(c[6]\)[0] + \(54272\ \(c[7]\)[0]\)\/3861 == 0\)\),
      SequenceForm[ "ic[", 1, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 52, 45], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 416, 315], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 12, 7], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 2272, 945], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 32, 9], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 18944, 3465], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 4288, 495], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 54272, 3861], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]2\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(152\/105\ \(c[0]\)[0] + 12\/7\ \(c[1]\)[0] + 
            16\/7\ \(c[2]\)[0] + 736\/225\ \(c[3]\)[0] + 
            2432\/495\ \(c[4]\)[0] + 2944\/385\ \(c[5]\)[0] + 
            5248\/429\ \(c[6]\)[0] + 16384\/819\ \(c[7]\)[0] == 0\)\),
      SequenceForm[ "ic[", 2, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 152, 105], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 12, 7], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 16, 7], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 736, 225], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 2432, 495], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 2944, 385], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 5248, 429], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 16384, 819], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]3\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(208\/105\ \(c[0]\)[0] + 2272\/945\ \(c[1]\)[0] + 
            736\/225\ \(c[2]\)[0] + \(11776\ \(c[3]\)[0]\)\/2475 + 
            3584\/495\ \(c[4]\)[0] + \(171008\ \(c[5]\)[0]\)\/15015 + 
            3584\/195\ \(c[6]\)[0] + \(1859584\ \(c[7]\)[0]\)\/61425 == 0\)\),
      
      SequenceForm[ "ic[", 3, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 208, 105], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 2272, 945], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 736, 225], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 11776, 2475], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 3584, 495], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 171008, 15015], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 3584, 195], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 1859584, 61425], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]4\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(544\/189\ \(c[0]\)[0] + 32\/9\ \(c[1]\)[0] + 
            2432\/495\ \(c[2]\)[0] + 
            3584\/495\ \(c[3]\)[0] + \(14336\ \(c[4]\)[0]\)\/1287 + 
            11264\/637\ \(c[5]\)[0] + 23552\/819\ \(c[6]\)[0] + 
            45056\/945\ \(c[7]\)[0] == 0\)\),
      SequenceForm[ "ic[", 4, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 544, 189], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 32, 9], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 2432, 495], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 3584, 495], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 14336, 1287], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 11264, 637], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 23552, 819], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 45056, 945], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]5\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(1376\/315\ \(c[0]\)[0] + \(18944\ \(c[1]\)[0]\)\/3465 + 
            2944\/385\ \(c[2]\)[0] + \(171008\ \(c[3]\)[0]\)\/15015 + 
            11264\/637\ \(c[4]\)[0] + \(90112\ \(c[5]\)[0]\)\/3185 + 
            4864\/105\ \(c[6]\)[0] + \(413696\ \(c[7]\)[0]\)\/5355 == 0\)\),
      SequenceForm[ "ic[", 5, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 1376, 315], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 18944, 3465], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 2944, 385], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 171008, 15015], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 11264, 637], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 90112, 3185], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 4864, 105], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 413696, 5355], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]6\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(3392\/495\ \(c[0]\)[0] + 4288\/495\ \(c[1]\)[0] + 
            5248\/429\ \(c[2]\)[0] + 3584\/195\ \(c[3]\)[0] + 
            23552\/819\ \(c[4]\)[0] + 4864\/105\ \(c[5]\)[0] + 
            19456\/255\ \(c[6]\)[0] + \(176128\ \(c[7]\)[0]\)\/1377 == 0\)\),
      SequenceForm[ "ic[", 6, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 3392, 495], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 4288, 495], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 5248, 429], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 3584, 195], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 23552, 819], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 4864, 105], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 19456, 255], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 176128, 1377], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]7\[InvisibleSpace]"]= "\
\[InvisibleSpace]\(\(16384\ \(c[0]\)[0]\)\/1485 + \(54272\ \
\(c[1]\)[0]\)\/3861 + 
            16384\/819\ \(c[2]\)[0] + \(1859584\ \(c[3]\)[0]\)\/61425 + 
            45056\/945\ \(c[4]\)[
                0] + \(413696\ \(c[5]\)[0]\)\/5355 + \(176128\ \
\(c[6]\)[0]\)\/1377 + \(5636096\ \(c[7]\)[0]\)\/26163 == 0\)\),
      SequenceForm[ "ic[", 7, "]= ", 
        Equal[ 
          Plus[ 
            Times[ 
              Rational[ 16384, 1485], 
              c[ 0][ 0]], 
            Times[ 
              Rational[ 54272, 3861], 
              c[ 1][ 0]], 
            Times[ 
              Rational[ 16384, 819], 
              c[ 2][ 0]], 
            Times[ 
              Rational[ 1859584, 61425], 
              c[ 3][ 0]], 
            Times[ 
              Rational[ 45056, 945], 
              c[ 4][ 0]], 
            Times[ 
              Rational[ 413696, 5355], 
              c[ 5][ 0]], 
            Times[ 
              Rational[ 176128, 1377], 
              c[ 6][ 0]], 
            Times[ 
              Rational[ 5636096, 26163], 
              c[ 7][ 0]]], 0]],
      Editable->False]], "Print"]
}, Closed]],

Cell[TextData[{
  "In order to use ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine the solution to the coupled ODEs, we must make a list of the \
equations and initial conditions:"
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Join[Table[eq[m], {m, 1, M}], Table[ic[m], {m, 1, M}]];\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.43"],

Cell["\<\
Also, we create a list of the variables for which we are solving:\
\
\>", "Text"],

Cell[BoxData[
    \(\(vars\  = \ Table[\(c[m]\)[t], {m, 1, M}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.44"],

Cell[TextData[{
  "Finally, we solve the equations over a time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Tau]\)\(\ \)\)\)]],
  " and define the solution:"
}], "Text"],

Cell[BoxData[{
    \(\(\(coefficients\  = \ \(NDSolve[eqns, vars, {t, 0, \[Tau]}, 
            MaxSteps \[Rule] 5000]\)[\([1]\)];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(T[x_, t_]\  = \ 
        u[x, t]\  + \ 
          Evaluate[Sum[\(c[n]\)[t]\ v[n, x], {n, 1, M}]];\)\), "\n", 
    \(\(T[x_, t_]\  = \ T[x, t] /. coefficients;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.45"],

Cell[TextData[{
  "Cell ",
  ButtonBox["6.46",
    ButtonData:>"Cell 6.46",
    ButtonStyle->"Hyperlink"],
  " displays our solution."
}], "Text"],

Cell[BoxData[
    \(\(Table[
        Plot[T[x, t], {x, 0, b}, PlotRange \[Rule] {{0, 2}, {0, 2}}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t], t=\>" <> ToString[t]], {t, 0, 
          15,  .5}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.46"],

Cell[TextData[{
  "This solution exhibits the same behavior as was observed in Example 1 of \
Sec. ",
  ButtonBox["4.2.2",
    ButtonData:>{"Chapter4.nb", "c:20"},
    ButtonStyle->"Hyperlink"],
  ", where we solved a similar problem using the exact eigenmodes for the \
system. The temperature oscillations only penetrate a short distance into the \
material before they are averaged out."
}], "Text"],

Cell["\<\
\tBelow, we collect the Galerkin method commands in one \
module:\
\>", "Text",
  CellTags->"i:13"],

Cell[BoxData[
    RowBox[{\(galerkint[M_, \[Tau]_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({u, v, norm, L, eq, ic, eqns, vars}\), ",", 
          "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ function\ u\ used\ to\ match\ inhomogeneous\ \
boundary\ conditions, \ if\ any\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(u[x_, t_]\  = \ T1[t]\), " ", ";", "\[IndentingNewLine]", 
            
            
            StyleBox[\( (*\ define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
              
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(v[n_, x_]\  = \ 
              x\^n\ \ \((1 - n\/\(n + 1\)\ \((x/b)\))\)\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(define\ the\ inner\ product\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[
                RowBox[{
                  StyleBox[" ",
                    FontColor->RGBColor[1, 0, 0]], " "}]], 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], 
            "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
              Integrate[f\ g, {x, 0, b}]\), " ", ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L\&^[f_]\  := \ \[Chi]\ D[f, {x, 2}]\), 
            " ", ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[m_, n_]\  := \ 
              norm[v[m, x], \ L\&^[v[n, x]]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ norm\ of\ the\ basis\ functions\ with\ each\ \
other . \ 
                    Use\ symmetry\ of\ the\ norm\ to\ reduce\ the\ number\ of\
\ integrals\ that\ need\ be\ done; \ 
                remember\ their\ \(\(values\)\(.\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(nm[n_, 
                m_]\  := \ \((nm[n, m]\  = \ norm[v[m, x], v[n, x]]\ )\) /; 
                n \[GreaterEqual] \ m\), "  ", ";", 
            "\[IndentingNewLine]", \(nm[n_, m_]\  := \ 
              nm[m, n]\  /; \ n < m\), "  ", ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ projection\ of\ S\&_\ onto\ the\ basis\ \
\(\(functions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(S\&_[m_]\  := \ 
              norm[v[m, x], \ 
                S[x, t] - 
                  D[u[x, t], t]\  + \ \ \(\(\ \)\(L\)\)\&^[u[x, t]]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                define\ the\ equations\ for\ the\ Fourier\ coefficients\ \(c[
                      n]\)[t]\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eq[m_]\  := \(eq[m]\  = \ 
                Sum[nm[m, n]\ D[\(c[n]\)[t], t], {n, 1, M}]\  \[Equal] \ 
                  Sum[L[m, n]\ \(c[n]\)[t], {n, 1, M}]\  + \ \ S\&_[m]\)\), 
            ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ equations\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq[\>", m, "\<]= \>", eq[m]], {m, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ initial\ conditions\ \ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(ic[m_]\  := \ \(ic[m]\  = \ 
                Sum[nm[m, n]\ \(c[n]\)[0], {n, 1, M}]\  \[Equal] \ 
                  norm[v[m, x], T0[x] - u[x, 0]]\)\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                Print\ out\ the\ initial\ conditions\ \((not\ necessary, \ 
                    but\ a\ useful\ check)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Do[
              Print["\<ic[\>", m, "\<]= \>", ic[m]], {m, 1, M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ create\ lists\ of\ equations, \ variables\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Join[Table[eq[m], {m, 1, M}], Table[ic[m], {m, 1, M}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Table[\(c[m]\)[t], {m, 1, M}]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ solve\ the\ equations\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(NDSolve[eqns, 
                  vars, {t, 0, \[Tau]}]\)[\([1]\)]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ the\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
              u[x, t]\  + \ Evaluate[Sum[\(c[n]\)[t]\ v[n, x], {n, 1, M}]]\), 
            ";", "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
              T[x, t] /. coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.47"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reflection of a Quantum Particle from a Barrier ", "Section",
  CellTags->{"i:14", "c:11"}],

Cell["\<\
\tThe evolution of a quantum particle  moving in an external \
potential is another case where the Galerkin method is useful. This is a case \
where all of the steps in the method can be performed analytically, except \
for the solution of the coupled ODEs. \
\>", "Text"],

Cell[TextData[{
  "\tWe consider a particle  that encounters a potential barrier ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " of finite height and width. The particle wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " satisfies the time-dependent ",
  "Schr\[ODoubleDot]dinger",
  " equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\[Psi](x, 
            t)\) = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \
\(\[PartialD]\^2\/\[PartialD]x\^2\) \(\[Psi](x, t)\)\  + \ \(V(x)\) \(\[Psi](
              x, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.27)"],

Cell["The initial condition on the wave function is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 0) = \(\[Psi]\_o\)(x)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.28)"],

Cell[TextData[{
  "For this problem",
  ",",
  " we take the barrier potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " to be"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(V(x)\), " ", "=", " ", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(V\_o, \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\), \)},
                  {\(0, \ \ \ \ \(\(|\)\(x\)\(|\)\(\(\[GreaterEqual]\)\(\ \
\)\(\(a\)\(.\)\)\)\)\)}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(6.1.29)"],

Cell[TextData[{
  "We will assume that the system has periodic boundary conditions, with \
period ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  ". (So this barrier, and the wave function itself,  are periodically \
replicated in cells of width ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  ".) Then to match these boundary conditions we will expand the ",
  "wave function",
  " in terms of a periodic exponential Fourier series,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          t)\  = \[Sum]\+k\(\( c\_k\)(
              t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ n\ \[Pi]/L, \ \ \ \ n = \(-M\),  ... , 
      M\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.30)"],

Cell[TextData[{
  "Substituting this series into Eq. ",
  ButtonBox["(6.1.27)",
    ButtonData:>"(6.1.27)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[Sum]\+k\(\[PartialD]\/\
\[PartialD]t\) \(\(c\_k\)(
                t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\) = \[Sum]\+k\(\
\(\( \[HBar]\^2\) k\^2\)\/\(2\ m\)\) \(\(c\_k\)(
                t)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\) + \
\[Sum]\+\(k\&_\)\(\(c\_k\&_\)(t)\) \(V(
                x)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\&_\ x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.31)"],

Cell[TextData[{
  "In the last term, we replaced the dummy variable ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`k\&_\)]],
  ". For the inner product, we choose the one for which the Fourier modes are \
orthogonal:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-L\)\%L\( f\^*\) g \[DifferentialD]x\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.32)"],

Cell[TextData[{
  "Then, taking an inner product of Eq. ",
  ButtonBox["(6.1.31)",
    ButtonData:>{"Chapter6.nb", "(6.1.31)"},
    ButtonStyle->"Hyperlink"],
  " with respect to  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  "  yields the following coupled equations for the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\(c\_k\)(t)\) = \(\(\(\[HBar]\^2\) k\^2\)\/\(2\ m\)\) \(\(c\_k\)(
              t)\) + \[Sum]\+\(k\&_\)\(V\_\(k\ k\&_\)\) \(\(c\_k\&_\)(
                t)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.33)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\)\)]],
  " is the projection of the potential onto the Fourier modes:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\) = \((\[ExponentialE]\^\(\[ImaginaryI]\
\ k\ x\), \ \(V(
                x)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \(k\&_\) x\))\)/\((\
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \[ExponentialE]\^\(\[ImaginaryI]\ k\
\ x\))\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.34)"],

Cell[TextData[{
  "For the barrier potential of Eq. ",
  ButtonBox["(6.1.29)",
    ButtonData:>"(6.1.29)",
    ButtonStyle->"Hyperlink"],
  ", this matrix can be evaluated analytically:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\) = \(V\_o\/\(\((k\&_ - k)\) 
                L\)\) \(sin(k\&_ - k)\) a\)]],
  "."
}], "NumberedEquation",
  CellTags->"(6.1.35)"],

Cell[TextData[{
  "We are then left with the task of solving the coupled ODEs given by Eq. ",
  ButtonBox["(6.1.33)",
    ButtonData:>"(6.1.33)",
    ButtonStyle->"Hyperlink"],
  ", subject to the initial condition, Eq . ",
  ButtonBox["(6.1.28)",
    ButtonData:>"(6.1.28)",
    ButtonStyle->"Hyperlink"],
  ". When Eq. ",
  ButtonBox["(6.1.30)",
    ButtonData:>"(6.1.30)",
    ButtonStyle->"Hyperlink"],
  " is used in Eq. ",
  ButtonBox["(6.1.28)",
    ButtonData:>"(6.1.28)",
    ButtonStyle->"Hyperlink"],
  " and an inner product is taken, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(
          0) = \(\((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \(\[Psi]\_o\)(
                x))\)/\((\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\), \
\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\))\) = \(1\/\(2  
                  L\)\) \(\[Integral]\_\(-L\)\%L\( \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ k\ x\)\) \(\(\[Psi]\_o\)(x)\) \[DifferentialD]x\)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(6.1.36)"],

Cell["\<\
which is simply the usual expression for the Fourier coefficient of \
the initial condition. 
\tLet's solve this problem for specific (dimensionless) choices of the \
parameters:\
\>", "Text"],

Cell[BoxData[
    \(\[HBar] = 1; \ mass = 1;\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.48"],

Cell[TextData[{
  "For the initial condition, we choose a ",
  "wave function",
  " centered at ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o = 5\)]],
  " and at position ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-5\)\)]],
  ", moving toward the potential barrier from the left:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(
          x)\  = \ \(\[ExponentialE]\^\(\(-2\) \((x + 5)\)\^2\)\) \
\[ExponentialE]\^\(\(\ \ \)\(5\ \[ImaginaryI]\ x\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "This corresponds to a classical particle with energy ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[HBar]\ k\_o)\)\^2/\((2\ m)\) = 12.5\)]],
  " in our dimensionless units. We take the potential barrier height equal to \
",
  Cell[BoxData[
      \(TraditionalForm\`V\_o = 15\)]],
  ",",
  " in order to reflect the classical particle.  "
}], "Text"],

Cell[TextData[{
  "\tThe Fourier coefficients of the initial condition can be evaluated for \
general ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(
          0) = \(\[ExponentialE]\^\(\(-50\) - 1\/8\ \((\((\(-5\) - 20\ \
\[ImaginaryI])\) + k)\)\^2\)\ \@\(\[Pi]\/2\)\)\/\(2\ L\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "\tThe following module integrates the equations of motion for this initial \
condition. The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(t)\)]],
  " are referred to as ",
  StyleBox["c[n][t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 2  \[Pi]\ n/\((2  L)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(-M\), , , \(\(.\)\(M\)\)\)]],
  ". The equations for the coefficients are integrated up to time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  ". The module can be easily modified to solve for propagation of a quantum \
wave function starting with any initial condition and moving in any \
one-dimensional potential, simply by changing the definition of the initial \
conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_k\)(0)\)]],
  " and the potential matrix ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(k\ k\&_\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{\(schroedinger[L_, a_, V0_, M_, \[Tau]_]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({k, v, ic, V, eq, eqns, vars}\), ",", "\[IndentingNewLine]",
           
          StyleBox[\( (*\ DEFINE\ THE\ WAVENUMBER\ *) \),
            FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
          RowBox[{\(k[n_]\  = \ Pi\ n/L\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ DEFINE\ THE\ BASIS\ FUNCTIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(v[n_, x_]\  = \ Exp[I\ k[n]\ x]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                DEFINE\ AND\ PRINT\ THE\ INITIAL\ CONDITIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(ic[
                m_]\  := \ \(ic[
                  m]\  = \ \(c[m]\)[
                    0]\  \[Equal] \ \(\[ExponentialE]\^\(\(-50\) - 1\/8\ \
\((\((\(-5\) - 20\ \[ImaginaryI])\) + k[m])\)\^2\)\ \@\(\[Pi]\/2\)\)\/\(2\ \
L\)\)\), ";", 
            "\[IndentingNewLine]", \(Do[
              Print["\<ic[\>", m, "\<]=\>", ic[m]], {m, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                DEFINE\ PROJECTION\ OF\ THE\ POTENTIAL\ ONTO\ THE\ MODEs\ *) \
\),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(V[n_, m_]\  := \ 
              V0\ Sin[\((k[n] - k[m])\) a]/\((\((k[n] - k[m])\) L)\)\  /; \ 
                n \[NotEqual] \ m\), ";", 
            "\[IndentingNewLine]", \(V[n_, n_]\  := \ V0\ a/L\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ DEFINE\ AND\ PRINT\ THE\ ODEs\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(eq[
                n_]\  := \ \(eq[
                  n]\  = \ \ I\ \ D[\(c[n]\)[t], 
                      t]\  \[Equal] \ \(\[HBar]\^2\) 
                      k[n]\^2/\((2  mass\ )\)\ \(c[n]\)[t] + \ 
                    Sum[V[n, m]\ \(c[m]\)[t], {m, \(-M\), M}]\)\), " ", ";", 
            "\[IndentingNewLine]", \(Do[
              Print["\<eq[\>", m, "\<]=\>", eq[m]], {m, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                CREATE\ LISTS\ OF\ THE\ EQUATIONS\ AND\ VARIABLES\ FOR\ USE\ \
IN\ NDSOLVE*) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(eqns\  = \ 
              Join[Table[eq[m], {m, \(-M\), M}], 
                Table[ic[m], {m, \(-M\), M}]]\), ";", 
            "\[IndentingNewLine]", \(vars\  = \ 
              Table[\(c[n]\)[t], {n, \(-M\), M}]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ SOLVE\ THE\ EQUATIONS\ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(coefficients\  = \ \(NDSolve[eqns, 
                  vars, {t, 0, \[Tau]}, MaxSteps \[Rule] 6000]\)[\([1]\)]\), 
            ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ THE\ SOLUTION\ \ *) \),
              FontColor->RGBColor[0, 0, 1]], 
            "\[IndentingNewLine]", \(\[Psi][x_, t_]\  = \ 
              Sum[\(c[n]\)[t]\ v[n, x], {n, \(-M\), M}]\), " ", ";", 
            "\[IndentingNewLine]", \(\[Psi][x_, t_\ ] = \ \[Psi][x, t] /. 
                coefficients\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.49"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.50",
    ButtonData:>"Cell 6.50",
    ButtonStyle->"Hyperlink"],
  " we run this module,  taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 15\)]],
  " and a barrier half width ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ". We integrate over a time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  " and take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 60\)]],
  " (a large number of modes must be kept in order to represent the sharply \
peaked initial condition)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(schroedinger[15. , 1. , 15. , 60, 2.4];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.50"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-60\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-60\)]\)[0] == 
          7.335331140938072`*^-19 + 
            9.794604115626626`*^-20\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -60, "]=", 
        Equal[ 
          c[ -60][ 0], 
          Complex[ 7.3353311409380722*^-19, 9.7946041156266262*^-20]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-59\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-59\)]\)[0] == 
          7.034481033127066`*^-19 + 
            1.7071591735034567`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -59, "]=", 
        Equal[ 
          c[ -59][ 0], 
          Complex[ 7.0344810331270663*^-19, 1.7071591735034567*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-58\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-58\)]\)[0] == \(-2.7805081148506073`*^-18\) + 
            3.609844913780214`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -58, "]=", 
        Equal[ 
          c[ -58][ 0], 
          Complex[ -2.7805081148506073*^-18, 3.6098449137802142*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-57\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-57\)]\)[0] == \(-1.1024151804199695`*^-17\) - 
            1.4720153808748337`*^-18\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -57, "]=", 
        Equal[ 
          c[ -57][ 0], 
          Complex[ -1.1024151804199695*^-17, -1.4720153808748337*^-18]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-56\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-56\)]\)[0] == \(-1.022986277449601`*^-17\) - 
            2.4826286398272097`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -56, "]=", 
        Equal[ 
          c[ -56][ 0], 
          Complex[ -1.022986277449601*^-17, -2.4826286398272097*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-55\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-55\)]\)[0] == 
          3.912678790478846`*^-17 - 
            5.079705955767508`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -55, "]=", 
        Equal[ 
          c[ -55][ 0], 
          Complex[ 3.9126787904788461*^-17, -5.0797059557675078*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-54\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-54\)]\)[0] == 
          1.501092649792993`*^-16 + 
            2.004355081332875`*^-17\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -54, "]=", 
        Equal[ 
          c[ -54][ 0], 
          Complex[ 1.501092649792993*^-16, 2.0043550813328751*^-17]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-53\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-53\)]\)[0] == 
          1.3478588227660792`*^-16 + 
            3.2710437956071307`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -53, "]=", 
        Equal[ 
          c[ -53][ 0], 
          Complex[ 1.3478588227660792*^-16, 3.2710437956071307*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-52\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-52\)]\)[0] == \(-4.988397789818807`*^-16\) + 
            6.476277588730456`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -52, "]=", 
        Equal[ 
          c[ -52][ 0], 
          Complex[ -4.9883977898188071*^-16, 6.4762775887304558*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-51\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-51\)]\)[0] == \(-1.8518536616583415`*^-15\) - 
            2.472713657709106`*^-16\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -51, "]=", 
        Equal[ 
          c[ -51][ 0], 
          Complex[ -1.8518536616583415*^-15, -2.472713657709106*^-16]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-50\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-50\)]\)[0] == \(-1.6089993038929722`*^-15\) - 
            3.9047911407623456`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -50, "]=", 
        Equal[ 
          c[ -50][ 0], 
          Complex[ -1.6089993038929722*^-15, -3.9047911407623456*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-49\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-49\)]\)[0] == 
          5.762153359157374`*^-15 - 
            7.480819741140575`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -49, "]=", 
        Equal[ 
          c[ -49][ 0], 
          Complex[ 5.7621533591573736*^-15, -7.4808197411405753*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-48\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-48\)]\)[0] == 
          2.0698681576699788`*^-14 + 
            2.763820581019623`*^-15\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -48, "]=", 
        Equal[ 
          c[ -48][ 0], 
          Complex[ 2.0698681576699788*^-14, 2.7638205810196231*^-15]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-47\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-47\)]\)[0] == 
          1.7402200149787806`*^-14 + 
            4.2232434041615534`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -47, "]=", 
        Equal[ 
          c[ -47][ 0], 
          Complex[ 1.7402200149787806*^-14, 4.2232434041615534*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-46\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-46\)]\)[0] == \(-6.030390003406935`*^-14\) + 
            7.829062812528366`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -46, "]=", 
        Equal[ 
          c[ -46][ 0], 
          Complex[ -6.0303900034069348*^-14, 7.8290628125283658*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-45\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-45\)]\)[0] == \(-2.096117168449568`*^-13\) - 
            2.798869941992378`*^-14\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -45, "]=", 
        Equal[ 
          c[ -45][ 0], 
          Complex[ -2.0961171684495679*^-13, -2.798869941992378*^-14]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-44\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-44\)]\)[0] == \(-1.7052549355217378`*^-13\) - 
            4.138388592745842`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -44, "]=", 
        Equal[ 
          c[ -44][ 0], 
          Complex[ -1.7052549355217378*^-13, -4.1383885927458422*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-43\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-43\)]\)[0] == 
          5.717982742117037`*^-13 - 
            7.423474439247849`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -43, "]=", 
        Equal[ 
          c[ -43][ 0], 
          Complex[ 5.717982742117037*^-13, -7.4234744392478492*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-42\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-42\)]\)[0] == 
          1.9232036715401016`*^-12 + 
            2.5679847623139305`*^-13\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -42, "]=", 
        Equal[ 
          c[ -42][ 0], 
          Complex[ 1.9232036715401016*^-12, 2.5679847623139305*^-13]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-41\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-41\)]\)[0] == 
          1.5139492728678873`*^-12 + 
            3.674119493995461`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -41, "]=", 
        Equal[ 
          c[ -41][ 0], 
          Complex[ 1.5139492728678873*^-12, 3.6741194939954606*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-40\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-40\)]\)[0] == \(-4.912212354134527`*^-12\) + 
            6.377368469911435`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -40, "]=", 
        Equal[ 
          c[ -40][ 0], 
          Complex[ -4.9122123541345273*^-12, 6.3773684699114347*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-39\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-39\)]\)[0] == \(-1.5987179694847674`*^-11\) - 
            2.1347106630606324`*^-12\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -39, "]=", 
        Equal[ 
          c[ -39][ 0], 
          Complex[ -1.5987179694847674*^-11, -2.1347106630606324*^-12]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-38\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-38\)]\)[0] == \(-1.2177837791385021`*^-11\) - 
            2.955371888998911`*^-11\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -38, "]=", 
        Equal[ 
          c[ -38][ 0], 
          Complex[ -1.2177837791385021*^-11, -2.9553718889989107*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-37\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-37\)]\)[0] == 
          3.823387170140352`*^-11 - 4.96378149584561`*^-11\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -37, "]=", 
        Equal[ 
          c[ -37][ 0], 
          Complex[ 3.8233871701403521*^-11, -4.9637814958456102*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-36\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-36\)]\)[0] == 
          1.2040798430646403`*^-10 + 
            1.6077645521147805`*^-11\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -36, "]=", 
        Equal[ 
          c[ -36][ 0], 
          Complex[ 1.2040798430646403*^-10, 1.6077645521147805*^-11]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-35\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-35\)]\)[0] == 
          8.87494967118347`*^-11 + 
            2.1538122960589162`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -35, "]=", 
        Equal[ 
          c[ -35][ 0], 
          Complex[ 8.8749496711834706*^-11, 2.1538122960589162*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-34\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-34\)]\)[0] == \(-2.6962259027406485`*^-10\) + 
            3.5004240086290474`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -34, "]=", 
        Equal[ 
          c[ -34][ 0], 
          Complex[ -2.6962259027406485*^-10, 3.5004240086290474*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-33\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-33\)]\)[0] == \(-8.216286385355219`*^-10\) - 
            1.0970912000964858`*^-10\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -33, "]=", 
        Equal[ 
          c[ -33][ 0], 
          Complex[ -8.2162863853552194*^-10, -1.0970912000964858*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-32\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-32\)]\)[0] == \(-5.860011462731532`*^-10\) - 
            1.4221336696092427`*^-9\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -32, "]=", 
        Equal[ 
          c[ -32][ 0], 
          Complex[ -5.8600114627315315*^-10, -1.4221336696092427*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-31\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-31\)]\)[0] == 
          1.722666179841179`*^-9 - 2.2364825026864333`*^-9\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -31, "]=", 
        Equal[ 
          c[ -31][ 0], 
          Complex[ 1.722666179841179*^-09, -2.2364825026864333*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-30\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-30\)]\)[0] == 
          5.079637300825355`*^-9 + 6.782657177517886`*^-10\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -30, "]=", 
        Equal[ 
          c[ -30][ 0], 
          Complex[ 5.079637300825355*^-09, 6.7826571775178858*^-10]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-29\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-29\)]\)[0] == 
          3.5056445950433573`*^-9 + 8.507654368940215`*^-9\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -29, "]=", 
        Equal[ 
          c[ -29][ 0], 
          Complex[ 3.5056445950433573*^-09, 8.5076543689402149*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-28\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-28\)]\)[0] == \(-9.972012887709568`*^-9\) + 
            1.294634596122509`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -28, "]=", 
        Equal[ 
          c[ -28][ 0], 
          Complex[ -9.9720128877095675*^-09, 1.294634596122509*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-27\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-27\)]\)[0] == \(-2.8452910085798516`*^-8\) - 
            3.799214853063425`*^-9\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -27, "]=", 
        Equal[ 
          c[ -27][ 0], 
          Complex[ -2.8452910085798516*^-08, -3.799214853063425*^-09]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-26\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-26\)]\)[0] == \(-1.900089932667854`*^-8\) - 
            4.6112228375623136`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -26, "]=", 
        Equal[ 
          c[ -26][ 0], 
          Complex[ -1.9000899326678539*^-08, -4.6112228375623136*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-25\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-25\)]\)[0] == 
          5.2299963693679614`*^-8 - 6.78993731117622`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -25, "]=", 
        Equal[ 
          c[ -25][ 0], 
          Complex[ 5.2299963693679614*^-08, -6.7899373111762194*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-24\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-24\)]\)[0] == 
          1.4439678772753906`*^-7 + 1.928078425070984`*^-8\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -24, "]=", 
        Equal[ 
          c[ -24][ 0], 
          Complex[ 1.4439678772753906*^-07, 1.9280784250709841*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-23\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-23\)]\)[0] == 
          9.330765644954433`*^-8 + 2.264431745793443`*^-7\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -23, "]=", 
        Equal[ 
          c[ -23][ 0], 
          Complex[ 9.3307656449544327*^-08, 2.2644317457934431*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-22\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-22\)]\)[0] == \(-2.485173971388517`*^-7\) + 
            3.226422024291764`*^-7\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -22, "]=", 
        Equal[ 
          c[ -22][ 0], 
          Complex[ -2.4851739713885171*^-07, 3.2264220242917638*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-21\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-21\)]\)[0] == \(-6.639344827402652`*^-7\) - 
            8.865278597801253`*^-8\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -21, "]=", 
        Equal[ 
          c[ -21][ 0], 
          Complex[ -6.6393448274026523*^-07, -8.8652785978012531*^-08]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-20\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-20\)]\)[0] == \(-4.1514256000433074`*^-7\) - 
            1.00748644610114`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -20, "]=", 
        Equal[ 
          c[ -20][ 0], 
          Complex[ -4.1514256000433074*^-07, -1.00748644610114*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-19\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-19\)]\)[0] == 
          1.0699144623146792`*^-6 - 1.389035787861438`*^-6\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -19, "]=", 
        Equal[ 
          c[ -19][ 0], 
          Complex[ 1.0699144623146792*^-06, -1.3890357878614381*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-18\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-18\)]\)[0] == 
          2.7658573092806585`*^-6 + 3.693149888425013`*^-7\ \[ImaginaryI]\)\),
      
      SequenceForm[ "ic[", -18, "]=", 
        Equal[ 
          c[ -18][ 0], 
          Complex[ 2.7658573092806585*^-06, 3.6931498884250133*^-07]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-17\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-17\)]\)[0] == 
          1.673455195657134`*^-6 + 4.061215568368823`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -17, "]=", 
        Equal[ 
          c[ -17][ 0], 
          Complex[ 1.673455195657134*^-06, 4.0612155683688226*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-16\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-16\)]\)[0] == \(-4.173286230466249`*^-6\) + 
            5.418044274834741`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -16, "]=", 
        Equal[ 
          c[ -16][ 0], 
          Complex[ -4.173286230466249*^-06, 5.4180442748347407*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-15\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-15\)]\)[0] == \(-0.000010439294984769792`\) - 
            1.3939215511542179`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -15, "]=", 
        Equal[ 
          c[ -15][ 0], 
          Complex[ -1.0439294984769792*^-05, -1.3939215511542179*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-14\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-14\)]\)[0] == \(-6.111780832071051`*^-6\) - 
            0.000014832341809974786`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -14, "]=", 
        Equal[ 
          c[ -14][ 0], 
          Complex[ -6.1117808320710512*^-06, -1.4832341809974786*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-13\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-13\)]\)[
            0] == \(\(0.000014748373906686519`\)\(\[InvisibleSpace]\)\) - 
            0.000019147342979951347`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -13, "]=", 
        Equal[ 
          c[ -13][ 0], 
          Complex[ 1.4748373906686519*^-05, -1.9147342979951347*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-12\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-12\)]\)[
            0] == \(\(0.00003569845503170215`\)\(\[InvisibleSpace]\)\) + 
            4.766686436603075`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -12, "]=", 
        Equal[ 
          c[ -12][ 0], 
          Complex[ 3.5698455031702147*^-05, 4.7666864366030747*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-11\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-11\)]\)[
            0] == \(\(0.000020223592586349957`\)\(\[InvisibleSpace]\)\) + 
            0.000049079514810540953`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -11, "]=", 
        Equal[ 
          c[ -11][ 0], 
          Complex[ 2.0223592586349957*^-05, 4.9079514810540953*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-10\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-10\)]\)[0] == \(-0.00004722228079096236`\) + 
            0.0000613071795115112`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -10, "]=", 
        Equal[ 
          c[ -10][ 0], 
          Complex[ -4.7222280790962357*^-05, 6.1307179511511193*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-9\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-9\)]\)[0] == \(-0.0001106023933848528`\) - 
            0.000014768340196662326`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -9, "]=", 
        Equal[ 
          c[ -9][ 0], 
          Complex[ -0.00011060239338485281, -1.4768340196662326*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-8\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-8\)]\)[0] == \(-0.00006062973860757475`\) - 
            0.00014713894879182711`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -8, "]=", 
        Equal[ 
          c[ -8][ 0], 
          Complex[ -6.0629738607574752*^-05, -0.00014713894879182711]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-7\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-7\)]\)[
            0] == \(\(0.00013698929534785198`\)\(\[InvisibleSpace]\)\) - 
            0.00017784882856936433`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -7, "]=", 
        Equal[ 
          c[ -7][ 0], 
          Complex[ 0.00013698929534785198, -0.00017784882856936433]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-6\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-6\)]\)[
            0] == \(\(0.00031046774100934176`\)\(\[InvisibleSpace]\)\) + 
            0.00004145564195307023`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -6, "]=", 
        Equal[ 
          c[ -6][ 0], 
          Complex[ 0.00031046774100934176, 4.1455641953070233*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-5\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-5\)]\)[
            0] == \(\(0.0001646834425047736`\)\(\[InvisibleSpace]\)\) + 
            0.000399661109713977`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -5, "]=", 
        Equal[ 
          c[ -5][ 0], 
          Complex[ 0.0001646834425047736, 0.00039966110971397699]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-4\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-4\)]\)[0] == \(-0.00036005028324573703`\) + 
            0.0004674417876135656`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -4, "]=", 
        Equal[ 
          c[ -4][ 0], 
          Complex[ -0.00036005028324573703, 0.00046744178761356559]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-3\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-3\)]\)[0] == \(-0.0007895966391387181`\) - 
            0.00010543200222047335`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -3, "]=", 
        Equal[ 
          c[ -3][ 0], 
          Complex[ -0.00078959663913871813, -0.00010543200222047335]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-2\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-2\)]\)[0] == \(-0.0004052761347469436`\) - 
            0.0009835421660490228`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -2, "]=", 
        Equal[ 
          c[ -2][ 0], 
          Complex[ -0.00040527613474694362, -0.00098354216604902285]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]\(-1\)\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[\(-1\)]\)[
            0] == \(\(0.0008573862902450275`\)\(\[InvisibleSpace]\)\) - 
            0.0011131172473317155`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", -1, "]=", 
        Equal[ 
          c[ -1][ 0], 
          Complex[ 0.00085738629024502747, -0.0011131172473317155]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]0\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[0]\)[
            0] == \(\(0.0018194115745414745`\)\(\[InvisibleSpace]\)\) + 
            0.00024293949044191843`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 0, "]=", 
        Equal[ 
          c[ 0][ 0], 
          Complex[ 0.0018194115745414745, 0.00024293949044191843]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]1\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[1]\)[
            0] == \(\(0.0009036265377110837`\)\(\[InvisibleSpace]\)\) + 
            0.0021929611097250535`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 1, "]=", 
        Equal[ 
          c[ 1][ 0], 
          Complex[ 0.00090362653771108371, 0.0021929611097250535]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]2\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[2]\)[0] == \(-0.0018498084771490925`\) + 
            0.002401547288080178`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 2, "]=", 
        Equal[ 
          c[ 2][ 0], 
          Complex[ -0.0018498084771490925, 0.0024015472880801782]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]3\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[3]\)[0] == \(-0.0037983367726630436`\) - 
            0.0005071782619114722`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 3, "]=", 
        Equal[ 
          c[ 3][ 0], 
          Complex[ -0.0037983367726630436, -0.00050717826191147217]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]4\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[4]\)[0] == \(-0.0018254240826702153`\) - 
            0.00443002042878384`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 4, "]=", 
        Equal[ 
          c[ 4][ 0], 
          Complex[ -0.0018254240826702153, -0.0044300204287838398]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]5\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[5]\)[
            0] == \(\(0.0036158786637345034`\)\(\[InvisibleSpace]\)\) - 
            0.004694379826987181`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 5, "]=", 
        Equal[ 
          c[ 5][ 0], 
          Complex[ 0.0036158786637345034, -0.0046943798269871813]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]6\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[6]\)[
            0] == \(\(0.00718443856709052`\)\(\[InvisibleSpace]\)\) + 
            0.0009593122683305472`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 6, "]=", 
        Equal[ 
          c[ 6][ 0], 
          Complex[ 0.00718443856709052, 0.00095931226833054716]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]7\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[7]\)[
            0] == \(\(0.0033409919374256408`\)\(\[InvisibleSpace]\)\) + 
            0.00810806796936044`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 7, "]=", 
        Equal[ 
          c[ 7][ 0], 
          Complex[ 0.0033409919374256408, 0.0081080679693604392]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]8\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[8]\)[0] == \(-0.00640380036581786`\) + 
            0.00831384956438234`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 8, "]=", 
        Equal[ 
          c[ 8][ 0], 
          Complex[ -0.0064038003658178598, 0.0083138495643823394]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]9\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[9]\)[0] == \(-0.01231201272726306`\) - 
            0.0016439788226748522`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 9, "]=", 
        Equal[ 
          c[ 9][ 0], 
          Complex[ -0.012312012727263059, -0.0016439788226748522]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]10\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[10]\)[0] == \(-0.005540180725635956`\) - 
            0.013445157224955658`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 10, "]=", 
        Equal[ 
          c[ 10][ 0], 
          Complex[ -0.0055401807256359563, -0.013445157224955658]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]11\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[11]\)[
            0] == \(\(0.010275396125376408`\)\(\[InvisibleSpace]\)\) - 
            0.013340218732740933`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 11, "]=", 
        Equal[ 
          c[ 11][ 0], 
          Complex[ 0.010275396125376408, -0.013340218732740933]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]12\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[12]\)[
            0] == \(\(0.019116224784602547`\)\(\[InvisibleSpace]\)\) + 
            0.0025525208113040022`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 12, "]=", 
        Equal[ 
          c[ 12][ 0], 
          Complex[ 0.019116224784602547, 0.0025525208113040022]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]13\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[13]\)[
            0] == \(\(0.00832356334834773`\)\(\[InvisibleSpace]\)\) + 
            0.020199994085493885`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 13, "]=", 
        Equal[ 
          c[ 13][ 0], 
          Complex[ 0.00832356334834773, 0.020199994085493885]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]14\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[14]\)[0] == \(-0.01493812931490832`\) + 
            0.01939369636823092`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 14, "]=", 
        Equal[ 
          c[ 14][ 0], 
          Complex[ -0.01493812931490832, 0.01939369636823092]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]15\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[15]\)[0] == \(-0.026891315886045992`\) - 
            0.0035907007903448543`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 15, "]=", 
        Equal[ 
          c[ 15][ 0], 
          Complex[ -0.026891315886045992, -0.0035907007903448543]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]16\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[16]\)[0] == \(-0.011330041458550844`\) - 
            0.027496249006930273`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 16, "]=", 
        Equal[ 
          c[ 16][ 0], 
          Complex[ -0.011330041458550844, -0.027496249006930273]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]17\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[17]\)[
            0] == \(\(0.019675723404882765`\)\(\[InvisibleSpace]\)\) - 
            0.025544363520723232`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 17, "]=", 
        Equal[ 
          c[ 17][ 0], 
          Complex[ 0.019675723404882765, -0.025544363520723232]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]18\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[18]\)[
            0] == \(\(0.034273529663558164`\)\(\[InvisibleSpace]\)\) + 
            0.004576421271920926`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 18, "]=", 
        Equal[ 
          c[ 18][ 0], 
          Complex[ 0.034273529663558164, 0.0045764212719209257]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]19\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[19]\)[
            0] == \(\(0.013973029037588841`\)\(\[InvisibleSpace]\)\) + 
            0.03391036892531824`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 19, "]=", 
        Equal[ 
          c[ 19][ 0], 
          Complex[ 0.013973029037588841, 0.033910368925318242]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]20\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[20]\)[0] == \(-0.023480214257171367`\) + 
            0.030483612530394166`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 20, "]=", 
        Equal[ 
          c[ 20][ 0], 
          Complex[ -0.023480214257171367, 0.030483612530394166]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]21\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[21]\)[0] == \(-0.03957696288435094`\) - 
            0.005284569654772027`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 21, "]=", 
        Equal[ 
          c[ 21][ 0], 
          Complex[ -0.03957696288435094, -0.0052845696547720268]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]22\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[22]\)[0] == \(-0.015613004210010856`\) - 
            0.037890333682822706`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 22, "]=", 
        Equal[ 
          c[ 22][ 0], 
          Complex[ -0.015613004210010856, -0.037890333682822706]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]23\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[23]\)[
            0] == \(\(0.025386934061987446`\)\(\[InvisibleSpace]\)\) - 
            0.03295904597820822`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 23, "]=", 
        Equal[ 
          c[ 23][ 0], 
          Complex[ 0.025386934061987446, -0.032959045978208222]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]24\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[24]\)[
            0] == \(\(0.04140596849358669`\)\(\[InvisibleSpace]\)\) + 
            0.0055287902021955064`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 24, "]=", 
        Equal[ 
          c[ 24][ 0], 
          Complex[ 0.041405968493586687, 0.0055287902021955064]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]25\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[25]\)[
            0] == \(\(0.01580590053952679`\)\(\[InvisibleSpace]\)\) + 
            0.03835846308272794`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 25, "]=", 
        Equal[ 
          c[ 25][ 0], 
          Complex[ 0.015805900539526789, 0.038358463082727938]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]26\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[26]\)[0] == \(-0.024868827344722216`\) + 
            0.03228640456848667`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 26, "]=", 
        Equal[ 
          c[ 26][ 0], 
          Complex[ -0.024868827344722216, 0.032286404568486672]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]27\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[27]\)[0] == \(-0.039248248783685276`\) - 
            0.005240677641972817`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 27, "]=", 
        Equal[ 
          c[ 27][ 0], 
          Complex[ -0.039248248783685276, -0.0052406776419728169]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]28\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[28]\)[0] == \(-0.014497358061258837`\) - 
            0.03518283394224964`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 28, "]=", 
        Equal[ 
          c[ 28][ 0], 
          Complex[ -0.014497358061258837, -0.035182833942249643]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]29\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[29]\)[
            0] == \(\(0.02207177254967996`\)\(\[InvisibleSpace]\)\) - 
            0.02865507762809014`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 29, "]=", 
        Equal[ 
          c[ 29][ 0], 
          Complex[ 0.022071772549679961, -0.02865507762809014]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]30\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[30]\)[
            0] == \(\(0.03370656318130526`\)\(\[InvisibleSpace]\)\) + 
            0.0045007162746440385`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 30, "]=", 
        Equal[ 
          c[ 30][ 0], 
          Complex[ 0.033706563181305257, 0.0045007162746440385]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]31\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[31]\)[
            0] == \(\(0.012047455720440194`\)\(\[InvisibleSpace]\)\) + 
            0.029237301875818317`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 31, "]=", 
        Equal[ 
          c[ 31][ 0], 
          Complex[ 0.012047455720440194, 0.029237301875818317]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]32\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[32]\)[0] == \(-0.017748267660308285`\) + 
            0.0230420092643457`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 32, "]=", 
        Equal[ 
          c[ 32][ 0], 
          Complex[ -0.017748267660308285, 0.0230420092643457]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]33\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[33]\)[0] == \(-0.026226812696659125`\) - 
            0.0035019720670116552`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 33, "]=", 
        Equal[ 
          c[ 33][ 0], 
          Complex[ -0.026226812696659125, -0.0035019720670116552]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]34\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[34]\)[0] == \(-0.009070655330537277`\) - 
            0.022013070167211105`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 34, "]=", 
        Equal[ 
          c[ 34][ 0], 
          Complex[ -0.0090706553305372768, -0.022013070167211105]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]35\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[35]\)[
            0] == \(\(0.012930388686575991`\)\(\[InvisibleSpace]\)\) - 
            0.01678711081048119`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 35, "]=", 
        Equal[ 
          c[ 35][ 0], 
          Complex[ 0.012930388686575991, -0.01678711081048119]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]36\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[36]\)[
            0] == \(\(0.018488999435306422`\)\(\[InvisibleSpace]\)\) + 
            0.0024687696640196453`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 36, "]=", 
        Equal[ 
          c[ 36][ 0], 
          Complex[ 0.018488999435306422, 0.0024687696640196453]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]37\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[37]\)[
            0] == \(\(0.006187551740693366`\)\(\[InvisibleSpace]\)\) + 
            0.015016226024218735`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 37, "]=", 
        Equal[ 
          c[ 37][ 0], 
          Complex[ 0.0061875517406933664, 0.015016226024218735]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]38\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[38]\)[0] == \(-0.00853501016960533`\) + 
            0.011080731210694106`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 38, "]=", 
        Equal[ 
          c[ 38][ 0], 
          Complex[ -0.0085350101696053306, 0.011080731210694106]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]39\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[39]\)[0] == \(-0.011809136875938927`\) - 
            0.0015768316170696305`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 39, "]=", 
        Equal[ 
          c[ 39][ 0], 
          Complex[ -0.011809136875938927, -0.0015768316170696305]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]40\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[40]\)[0] == \(-0.003824158419086434`\) - 
            0.009280637896853482`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 40, "]=", 
        Equal[ 
          c[ 40][ 0], 
          Complex[ -0.0038241584190864342, -0.0092806378968534817]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]41\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[41]\)[
            0] == \(\(0.005104266702750216`\)\(\[InvisibleSpace]\)\) - 
            0.006626706499107406`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 41, "]=", 
        Equal[ 
          c[ 41][ 0], 
          Complex[ 0.0051042667027502162, -0.006626706499107406]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]42\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[42]\)[
            0] == \(\(0.0068337605334866155`\)\(\[InvisibleSpace]\)\) + 
            0.0009124874904820301`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 42, "]=", 
        Equal[ 
          c[ 42][ 0], 
          Complex[ 0.0068337605334866155, 0.00091248749048203012]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]43\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[43]\)[
            0] == \(\(0.0021413603610994977`\)\(\[InvisibleSpace]\)\) + 
            0.005196748654253613`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 43, "]=", 
        Equal[ 
          c[ 43][ 0], 
          Complex[ 0.0021413603610994977, 0.0051967486542536133]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]44\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[44]\)[0] == \(-0.0027656647028044194`\) + 
            0.0035905741858181404`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 44, "]=", 
        Equal[ 
          c[ 44][ 0], 
          Complex[ -0.0027656647028044194, 0.0035905741858181404]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]45\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[45]\)[0] == \(-0.003582929055634179`\) - 
            0.0004784156434118898`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 45, "]=", 
        Equal[ 
          c[ 45][ 0], 
          Complex[ -0.003582929055634179, -0.00047841564341188979]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]46\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[46]\)[0] == \(-0.0010863768337557103`\) - 
            0.002636467663916894`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 46, "]=", 
        Equal[ 
          c[ 46][ 0], 
          Complex[ -0.0010863768337557103, -0.0026364676639168941]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]47\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[47]\)[
            0] == \(\(0.0013576960299129625`\)\(\[InvisibleSpace]\)\) - 
            0.0017626534092328836`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 47, "]=", 
        Equal[ 
          c[ 47][ 0], 
          Complex[ 0.0013576960299129625, -0.0017626534092328836]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]48\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[48]\)[
            0] == \(\(0.0017019763235314503`\)\(\[InvisibleSpace]\)\) + 
            0.00022725878331687432`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 48, "]=", 
        Equal[ 
          c[ 48][ 0], 
          Complex[ 0.0017019763235314503, 0.00022725878331687432]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]49\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[49]\)[
            0] == \(\(0.0004993534854337122`\)\(\[InvisibleSpace]\)\) + 
            0.0012118532688687965`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 49, "]=", 
        Equal[ 
          c[ 49][ 0], 
          Complex[ 0.00049935348543371223, 0.0012118532688687965]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]50\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[50]\)[0] == \(-0.000603868564028268`\) + 
            0.0007839832773034097`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 50, "]=", 
        Equal[ 
          c[ 50][ 0], 
          Complex[ -0.00060386856402826802, 0.00078398327730340965]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]51\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[51]\)[0] == \(-0.0007324966996513722`\) - 
            0.00009780765245957932`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 51, "]=", 
        Equal[ 
          c[ 51][ 0], 
          Complex[ -0.00073249669965137223, -9.7807652459579319*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]52\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[52]\)[0] == \(-0.0002079565135738711`\) - 
            0.0005046781250323431`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 52, "]=", 
        Equal[ 
          c[ 52][ 0], 
          Complex[ -0.00020795651357387109, -0.00050467812503234314]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]53\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[53]\)[
            0] == \(\(0.0002433431627626659`\)\(\[InvisibleSpace]\)\) - 
            0.0003159246591334756`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 53, "]=", 
        Equal[ 
          c[ 53][ 0], 
          Complex[ 0.0002433431627626659, -0.00031592465913347559]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]54\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[54]\)[
            0] == \(\(0.0002856239908441051`\)\(\[InvisibleSpace]\)\) + 
            0.00003813834525656477`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 54, "]=", 
        Equal[ 
          c[ 54][ 0], 
          Complex[ 0.0002856239908441051, 3.8138345256564772*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]55\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[55]\)[
            0] == \(\(0.00007846461041173066`\)\(\[InvisibleSpace]\)\) + 
            0.0001904214096661091`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 55, "]=", 
        Equal[ 
          c[ 55][ 0], 
          Complex[ 7.8464610411730655*^-05, 0.00019042140966610911]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]56\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[56]\)[0] == \(-0.00008884494595643638`\) + 
            0.0001153445568322568`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 56, "]=", 
        Equal[ 
          c[ 56][ 0], 
          Complex[ -8.8844945956436384*^-05, 0.0001153445568322568]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]57\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[57]\)[0] == \(-0.00010090682614907303`\) - 
            0.000013473725939631881`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 57, "]=", 
        Equal[ 
          c[ 57][ 0], 
          Complex[ -0.00010090682614907303, -1.3473725939631881*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]58\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[58]\)[0] == \(-0.00002682328539272314`\) - 
            0.00006509594312081132`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 58, "]=", 
        Equal[ 
          c[ 58][ 0], 
          Complex[ -2.682328539272314*^-05, -6.5095943120811319*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]59\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[59]\)[
            0] == \(\(0.000029388888379470103`\)\(\[InvisibleSpace]\)\) - 
            0.000038154655500435244`\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 59, "]=", 
        Equal[ 
          c[ 59][ 0], 
          Complex[ 2.9388888379470103*^-05, -3.8154655500435244*^-05]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ic["\[InvisibleSpace]60\[InvisibleSpace]"]="\
\[InvisibleSpace]\(\(c[60]\)[
            0] == \(\(0.00003229856761218889`\)\(\[InvisibleSpace]\)\) + 
            4.31271168519765`*^-6\ \[ImaginaryI]\)\),
      SequenceForm[ "ic[", 60, "]=", 
        Equal[ 
          c[ 60][ 0], 
          Complex[ 3.2298567612188888*^-05, 4.3127116851976502*^-06]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-60\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-60\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(79.95683520871486`\ \(c[\(-60\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-59\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-58\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-57\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-56\)]\)[t] + 
            0.826993343132688`\ \(c[\(-55\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-54\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-53\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-52\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-51\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-50\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-49\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-48\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-47\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-44\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-43\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-42\)]\)[t] - 
            0.18675027222298618`\ \(c[\(-41\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-40\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-39\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-38\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-37\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-36\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-35\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-34\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-33\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-32\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-29\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-28\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-27\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-26\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-25\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-24\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-23\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-22\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-21\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-20\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-19\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-18\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-17\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-16\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-15\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-14\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-13\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-12\)]\)[t] - 
            0.07241337086197425`\ \(c[\(-11\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-10\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-9\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-8\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-7\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-6\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-5\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-4\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-3\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-2\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.016273855731265604`\ \(c[1]\)[t] + 
            0.0313229744913472`\ \(c[2]\)[t] + 
            0.04454710875183992`\ \(c[3]\)[t] + 
            0.05544148706619893`\ \(c[4]\)[t] + 
            0.06361487254866832`\ \(c[5]\)[t] + 
            0.06880242987642335`\ \(c[6]\)[t] + 
            0.07087301895267824`\ \(c[7]\)[t] + 
            0.06983076867396239`\ \(c[8]\)[t] + 
            0.06581101988179627`\ \(c[9]\)[t] + 
            0.059070953080906326`\ \(c[10]\)[t] + 
            0.049975424961080865`\ \(c[11]\)[t] + 
            0.03897872015785999`\ \(c[12]\)[t] + 
            0.026603074225527826`\ \(c[13]\)[t] + 
            0.013414935129827233`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.013061910521147383`\ \(c[16]\)[t] - 
            0.025221096343682053`\ \(c[17]\)[t] - 
            0.03598035706879378`\ \(c[18]\)[t] - 
            0.04491462243337642`\ \(c[19]\)[t] - 
            0.05168708394579296`\ \(c[20]\)[t] - 
            0.056061239158567186`\ \(c[21]\)[t] - 
            0.0579084423149932`\ \(c[22]\)[t] - 
            0.05721075023890897`\ \(c[23]\)[t] - 
            0.054059052045761224`\ \(c[24]\)[t] - 
            0.04864666724309928`\ \(c[25]\)[t] - 
            0.04125878107252025`\ \(c[26]\)[t] - 
            0.03225825116512552`\ \(c[27]\)[t] - 
            0.022068459300722043`\ \(c[28]\)[t] - 
            0.011153991006822649`\ \(c[29]\)[t] - 
            3.8981718325193755`*^-17\ \(c[30]\)[t] + 
            0.010908848347331966`\ \(c[31]\)[t] + 
            0.021108961070255627`\ \(c[32]\)[t] + 
            0.030177073670601236`\ \(c[33]\)[t] + 
            0.03774739544932687`\ \(c[34]\)[t] + 
            0.04352596542803616`\ \(c[35]\)[t] + 
            0.04730167054004106`\ \(c[36]\)[t] + 
            0.04895352855494272`\ \(c[37]\)[t] + 
            0.04845400275336168`\ \(c[38]\)[t] + 
            0.045868286584282256`\ \(c[39]\)[t] + 
            0.04134966715663448`\ \(c[40]\)[t] + 
            0.035131239329076656`\ \(c[41]\)[t] + 
            0.027514390699665887`\ \(c[42]\)[t] + 
            0.018854606004500233`\ \(c[43]\)[t] + 
            0.009545242303915543`\ \(c[44]\)[t] + 
            3.8981718325193755`*^-17\ \(c[45]\)[t] - 
            0.009365143392520679`\ \(c[46]\)[t] - 
            0.018149760920219783`\ \(c[47]\)[t] - 
            0.02598581343857328`\ \(c[48]\)[t] - 
            0.032552799745291155`\ \(c[49]\)[t] - 
            0.037590606506031236`\ \(c[50]\)[t] - 
            0.040909552899494966`\ \(c[51]\)[t] - 
            0.04239725240919144`\ \(c[52]\)[t] - 
            0.042022055485216314`\ \(c[53]\)[t] - 
            0.039832985717929335`\ \(c[54]\)[t] - 
            0.03595623231011687`\ \(c[55]\)[t] - 
            0.030588406657213296`\ \(c[56]\)[t] - 
            0.023986904712529237`\ \(c[57]\)[t] - 
            0.01645783405477577`\ \(c[58]\)[t] - 
            0.008342060500900982`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -60, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -60]][ t]], 
          Plus[ 
            Times[ 79.956835208714864, 
              c[ -60][ t]], 
            Times[ 0.99270519960720671, 
              c[ -59][ t]], 
            Times[ 0.9710122092317629, 
              c[ -58][ t]], 
            Times[ 0.93548928378863916, 
              c[ -57][ t]], 
            Times[ 0.88706379305918348, 
              c[ -56][ t]], 
            Times[ 0.82699334313268802, 
              c[ -55][ t]], 
            Times[ 0.75682672864065692, 
              c[ -54][ t]], 
            Times[ 0.67835603854706272, 
              c[ -53][ t]], 
            Times[ 0.59356153372868015, 
              c[ -52][ t]], 
            Times[ 0.50455115242710469, 
              c[ -51][ t]], 
            Times[ 0.41349667156634362, 
              c[ -50][ t]], 
            Times[ 0.32256865202152113, 
              c[ -49][ t]], 
            Times[ 0.23387232094715985, 
              c[ -48][ t]], 
            Times[ 0.14938649372796314, 
              c[ -47][ t]], 
            Times[ 0.070907514257657456, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.062044074975450718, 
              c[ -44][ t]], 
            Times[ -0.11423673049785459, 
              c[ -43][ t]], 
            Times[ -0.15591488063143982, 
              c[ -42][ t]], 
            Times[ -0.18675027222298618, 
              c[ -41][ t]], 
            Times[ -0.20674833578317206, 
              c[ -40][ t]], 
            Times[ -0.21623620818304484, 
              c[ -39][ t]], 
            Times[ -0.21584055771952013, 
              c[ -38][ t]], 
            Times[ -0.20645618564475834, 
              c[ -37][ t]], 
            Times[ -0.18920668216016426, 
              c[ -36][ t]], 
            Times[ -0.1653986686265376, 
              c[ -35][ t]], 
            Times[ -0.13647135277833591, 
              c[ -34][ t]], 
            Times[ -0.10394325375429328, 
              c[ -33][ t]], 
            Times[ -0.069358014945125918, 
              c[ -32][ t]], 
            Times[ -0.034231213779558796, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.032022748374426029, 
              c[ -29][ t]], 
            Times[ 0.060688263076985223, 
              c[ -28][ t]], 
            Times[ 0.085044480344421705, 
              c[ -27][ t]], 
            Times[ 0.10436044624225692, 
              c[ -26][ t]], 
            Times[ 0.1181419061618126, 
              c[ -25][ t]], 
            Times[ 0.12613778810677614, 
              c[ -24][ t]], 
            Times[ 0.12833762891430925, 
              c[ -23][ t]], 
            Times[ 0.12496032289024847, 
              c[ -22][ t]], 
            Times[ 0.11643488132933186, 
              c[ -21][ t]], 
            Times[ 0.10337416789158595, 
              c[ -20][ t]], 
            Times[ 0.086542809078944752, 
              c[ -19][ t]], 
            Times[ 0.066820663127759972, 
              c[ -18][ t]], 
            Times[ 0.045163358568919114, 
              c[ -17][ t]], 
            Times[ 0.022561481809254675, 
              c[ -16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -15][ t]], 
            Times[ -0.021580547817548056, 
              c[ -14][ t]], 
            Times[ -0.041319668477947373, 
              c[ -13][ t]], 
            Times[ -0.058468080236789913, 
              c[ -12][ t]], 
            Times[ -0.072413370861974247, 
              c[ -11][ t]], 
            Times[ -0.082699334313268813, 
              c[ -10][ t]], 
            Times[ -0.089038438663606695, 
              c[ -9][ t]], 
            Times[ -0.091317159035181589, 
              c[ -8][ t]], 
            Times[ -0.089594193770366842, 
              c[ -7][ t]], 
            Times[ -0.084091858737850814, 
              c[ -6][ t]], 
            Times[ -0.075181213012062598, 
              c[ -5][ t]], 
            Times[ -0.063361699504227403, 
              c[ -4][ t]], 
            Times[ -0.049236278094138941, 
              c[ -3][ t]], 
            Times[ -0.033483179628681567, 
              c[ -2][ t]], 
            Times[ -0.016825511857749262, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.016273855731265604, 
              c[ 1][ t]], 
            Times[ 0.031322974491347202, 
              c[ 2][ t]], 
            Times[ 0.044547108751839919, 
              c[ 3][ t]], 
            Times[ 0.055441487066198933, 
              c[ 4][ t]], 
            Times[ 0.063614872548668322, 
              c[ 5][ t]], 
            Times[ 0.068802429876423349, 
              c[ 6][ t]], 
            Times[ 0.070873018952678238, 
              c[ 7][ t]], 
            Times[ 0.069830768673962387, 
              c[ 8][ t]], 
            Times[ 0.065811019881796273, 
              c[ 9][ t]], 
            Times[ 0.059070953080906326, 
              c[ 10][ t]], 
            Times[ 0.049975424961080865, 
              c[ 11][ t]], 
            Times[ 0.03897872015785999, 
              c[ 12][ t]], 
            Times[ 0.026603074225527826, 
              c[ 13][ t]], 
            Times[ 0.013414935129827233, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.013061910521147383, 
              c[ 16][ t]], 
            Times[ -0.025221096343682053, 
              c[ 17][ t]], 
            Times[ -0.035980357068793781, 
              c[ 18][ t]], 
            Times[ -0.044914622433376419, 
              c[ 19][ t]], 
            Times[ -0.05168708394579296, 
              c[ 20][ t]], 
            Times[ -0.056061239158567186, 
              c[ 21][ t]], 
            Times[ -0.057908442314993203, 
              c[ 22][ t]], 
            Times[ -0.057210750238908967, 
              c[ 23][ t]], 
            Times[ -0.054059052045761224, 
              c[ 24][ t]], 
            Times[ -0.048646667243099281, 
              c[ 25][ t]], 
            Times[ -0.041258781072520248, 
              c[ 26][ t]], 
            Times[ -0.032258251165125519, 
              c[ 27][ t]], 
            Times[ -0.022068459300722043, 
              c[ 28][ t]], 
            Times[ -0.011153991006822649, 
              c[ 29][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 30][ t]], 
            Times[ 0.010908848347331966, 
              c[ 31][ t]], 
            Times[ 0.021108961070255627, 
              c[ 32][ t]], 
            Times[ 0.030177073670601236, 
              c[ 33][ t]], 
            Times[ 0.03774739544932687, 
              c[ 34][ t]], 
            Times[ 0.043525965428036162, 
              c[ 35][ t]], 
            Times[ 0.047301670540041058, 
              c[ 36][ t]], 
            Times[ 0.04895352855494272, 
              c[ 37][ t]], 
            Times[ 0.048454002753361682, 
              c[ 38][ t]], 
            Times[ 0.045868286584282256, 
              c[ 39][ t]], 
            Times[ 0.041349667156634483, 
              c[ 40][ t]], 
            Times[ 0.035131239329076656, 
              c[ 41][ t]], 
            Times[ 0.027514390699665887, 
              c[ 42][ t]], 
            Times[ 0.018854606004500233, 
              c[ 43][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 46][ t]], 
            Times[ -0.018149760920219783, 
              c[ 47][ t]], 
            Times[ -0.025985813438573278, 
              c[ 48][ t]], 
            Times[ -0.032552799745291155, 
              c[ 49][ t]], 
            Times[ -0.037590606506031236, 
              c[ 50][ t]], 
            Times[ -0.040909552899494966, 
              c[ 51][ t]], 
            Times[ -0.042397252409191441, 
              c[ 52][ t]], 
            Times[ -0.042022055485216314, 
              c[ 53][ t]], 
            Times[ -0.039832985717929335, 
              c[ 54][ t]], 
            Times[ -0.035956232310116867, 
              c[ 55][ t]], 
            Times[ -0.030588406657213296, 
              c[ 56][ t]], 
            Times[ -0.023986904712529237, 
              c[ 57][ t]], 
            Times[ -0.016457834054775768, 
              c[ 58][ t]], 
            Times[ -0.0083420605009009823, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-59\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-59\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9927051996072067`\ \(c[\(-60\)]\)[t] + 
            77.34687315598232`\ \(c[\(-59\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-58\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-57\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-56\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-55\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-54\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-53\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-52\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-51\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-50\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-49\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-48\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-47\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-46\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-45\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-44\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-43\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-42\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-41\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-40\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-39\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-38\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-37\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-36\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-35\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-34\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-33\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-32\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-31\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-30\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-29\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-28\)]\)[t] + 
            0.060688263076985`\ \(c[\(-27\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-26\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-25\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-24\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-23\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-22\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-21\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-20\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-19\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-18\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-17\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-16\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-15\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-14\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-13\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-12\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-11\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-10\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-9\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-8\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-7\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-6\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-5\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-4\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-3\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-2\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-1\)]\)[t] - 
            0.0168255118577494`\ \(c[0]\)[t] - 
            1.8033970416801674`*^-16\ \(c[1]\)[t] + 
            0.016273855731265604`\ \(c[2]\)[t] + 
            0.03132297449134708`\ \(c[3]\)[t] + 
            0.044547108751839815`\ \(c[4]\)[t] + 
            0.05544148706619893`\ \(c[5]\)[t] + 
            0.06361487254866825`\ \(c[6]\)[t] + 
            0.06880242987642332`\ \(c[7]\)[t] + 
            0.07087301895267824`\ \(c[8]\)[t] + 
            0.06983076867396242`\ \(c[9]\)[t] + 
            0.06581101988179631`\ \(c[10]\)[t] + 
            0.0590709530809064`\ \(c[11]\)[t] + 
            0.049975424961080865`\ \(c[12]\)[t] + 
            0.03897872015786009`\ \(c[13]\)[t] + 
            0.026603074225527937`\ \(c[14]\)[t] + 
            0.013414935129827233`\ \(c[15]\)[t] + 
            1.5206810699945212`*^-16\ \(c[16]\)[t] - 
            0.013061910521147276`\ \(c[17]\)[t] - 
            0.025221096343682053`\ \(c[18]\)[t] - 
            0.03598035706879378`\ \(c[19]\)[t] - 
            0.04491462243337629`\ \(c[20]\)[t] - 
            0.05168708394579296`\ \(c[21]\)[t] - 
            0.05606123915856713`\ \(c[22]\)[t] - 
            0.0579084423149932`\ \(c[23]\)[t] - 
            0.05721075023890897`\ \(c[24]\)[t] - 
            0.054059052045761224`\ \(c[25]\)[t] - 
            0.0486466672430994`\ \(c[26]\)[t] - 
            0.04125878107252025`\ \(c[27]\)[t] - 
            0.03225825116512568`\ \(c[28]\)[t] - 
            0.022068459300722043`\ \(c[29]\)[t] - 
            0.011153991006822649`\ \(c[30]\)[t] - 
            3.8981718325193755`*^-17\ \(c[31]\)[t] + 
            0.010908848347331785`\ \(c[32]\)[t] + 
            0.021108961070255627`\ \(c[33]\)[t] + 
            0.030177073670601094`\ \(c[34]\)[t] + 
            0.03774739544932687`\ \(c[35]\)[t] + 
            0.04352596542803616`\ \(c[36]\)[t] + 
            0.04730167054004106`\ \(c[37]\)[t] + 
            0.0489535285549427`\ \(c[38]\)[t] + 
            0.04845400275336168`\ \(c[39]\)[t] + 
            0.04586828658428231`\ \(c[40]\)[t] + 
            0.04134966715663448`\ \(c[41]\)[t] + 
            0.035131239329076656`\ \(c[42]\)[t] + 
            0.027514390699665887`\ \(c[43]\)[t] + 
            0.01885460600450039`\ \(c[44]\)[t] + 
            0.009545242303915543`\ \(c[45]\)[t] + 
            2.005337021455629`*^-16\ \(c[46]\)[t] - 
            0.009365143392520679`\ \(c[47]\)[t] - 
            0.018149760920219783`\ \(c[48]\)[t] - 
            0.02598581343857328`\ \(c[49]\)[t] - 
            0.03255279974529105`\ \(c[50]\)[t] - 
            0.037590606506031236`\ \(c[51]\)[t] - 
            0.040909552899494925`\ \(c[52]\)[t] - 
            0.04239725240919144`\ \(c[53]\)[t] - 
            0.042022055485216314`\ \(c[54]\)[t] - 
            0.039832985717929335`\ \(c[55]\)[t] - 
            0.035956232310116944`\ \(c[56]\)[t] - 
            0.030588406657213296`\ \(c[57]\)[t] - 
            0.02398690471252936`\ \(c[58]\)[t] - 
            0.01645783405477577`\ \(c[59]\)[t] - 
            0.008342060500900982`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -59, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -59]][ t]], 
          Plus[ 
            Times[ 0.99270519960720671, 
              c[ -60][ t]], 
            Times[ 77.346873155982323, 
              c[ -59][ t]], 
            Times[ 0.99270519960720693, 
              c[ -58][ t]], 
            Times[ 0.9710122092317629, 
              c[ -57][ t]], 
            Times[ 0.93548928378863916, 
              c[ -56][ t]], 
            Times[ 0.88706379305918392, 
              c[ -55][ t]], 
            Times[ 0.82699334313268846, 
              c[ -54][ t]], 
            Times[ 0.75682672864065692, 
              c[ -53][ t]], 
            Times[ 0.67835603854706361, 
              c[ -52][ t]], 
            Times[ 0.59356153372868092, 
              c[ -51][ t]], 
            Times[ 0.50455115242710469, 
              c[ -50][ t]], 
            Times[ 0.41349667156634429, 
              c[ -49][ t]], 
            Times[ 0.32256865202152191, 
              c[ -48][ t]], 
            Times[ 0.23387232094715985, 
              c[ -47][ t]], 
            Times[ 0.14938649372796384, 
              c[ -46][ t]], 
            Times[ 0.070907514257658094, 
              c[ -45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -44][ t]], 
            Times[ -0.062044074975450239, 
              c[ -43][ t]], 
            Times[ -0.11423673049785416, 
              c[ -42][ t]], 
            Times[ -0.15591488063143982, 
              c[ -41][ t]], 
            Times[ -0.18675027222298593, 
              c[ -40][ t]], 
            Times[ -0.20674833578317189, 
              c[ -39][ t]], 
            Times[ -0.21623620818304481, 
              c[ -38][ t]], 
            Times[ -0.21584055771952015, 
              c[ -37][ t]], 
            Times[ -0.20645618564475848, 
              c[ -36][ t]], 
            Times[ -0.18920668216016434, 
              c[ -35][ t]], 
            Times[ -0.16539866862653771, 
              c[ -34][ t]], 
            Times[ -0.13647135277833616, 
              c[ -33][ t]], 
            Times[ -0.1039432537542934, 
              c[ -32][ t]], 
            Times[ -0.06935801494512607, 
              c[ -31][ t]], 
            Times[ -0.034231213779559094, 
              c[ -30][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -29][ t]], 
            Times[ 0.032022748374425904, 
              c[ -28][ t]], 
            Times[ 0.060688263076985001, 
              c[ -27][ t]], 
            Times[ 0.085044480344421608, 
              c[ -26][ t]], 
            Times[ 0.10436044624225685, 
              c[ -25][ t]], 
            Times[ 0.11814190616181253, 
              c[ -24][ t]], 
            Times[ 0.12613778810677612, 
              c[ -23][ t]], 
            Times[ 0.12833762891430928, 
              c[ -22][ t]], 
            Times[ 0.12496032289024853, 
              c[ -21][ t]], 
            Times[ 0.11643488132933186, 
              c[ -20][ t]], 
            Times[ 0.10337416789158609, 
              c[ -19][ t]], 
            Times[ 0.086542809078944891, 
              c[ -18][ t]], 
            Times[ 0.066820663127759972, 
              c[ -17][ t]], 
            Times[ 0.045163358568919301, 
              c[ -16][ t]], 
            Times[ 0.022561481809254869, 
              c[ -15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -14][ t]], 
            Times[ -0.021580547817547879, 
              c[ -13][ t]], 
            Times[ -0.04131966847794722, 
              c[ -12][ t]], 
            Times[ -0.058468080236789913, 
              c[ -11][ t]], 
            Times[ -0.072413370861974122, 
              c[ -10][ t]], 
            Times[ -0.082699334313268744, 
              c[ -9][ t]], 
            Times[ -0.089038438663606653, 
              c[ -8][ t]], 
            Times[ -0.091317159035181589, 
              c[ -7][ t]], 
            Times[ -0.089594193770366884, 
              c[ -6][ t]], 
            Times[ -0.084091858737850855, 
              c[ -5][ t]], 
            Times[ -0.075181213012062598, 
              c[ -4][ t]], 
            Times[ -0.063361699504227528, 
              c[ -3][ t]], 
            Times[ -0.049236278094139066, 
              c[ -2][ t]], 
            Times[ -0.033483179628681567, 
              c[ -1][ t]], 
            Times[ -0.016825511857749401, 
              c[ 0][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ 0.016273855731265604, 
              c[ 2][ t]], 
            Times[ 0.031322974491347078, 
              c[ 3][ t]], 
            Times[ 0.044547108751839815, 
              c[ 4][ t]], 
            Times[ 0.055441487066198933, 
              c[ 5][ t]], 
            Times[ 0.063614872548668253, 
              c[ 6][ t]], 
            Times[ 0.068802429876423321, 
              c[ 7][ t]], 
            Times[ 0.070873018952678238, 
              c[ 8][ t]], 
            Times[ 0.069830768673962415, 
              c[ 9][ t]], 
            Times[ 0.065811019881796315, 
              c[ 10][ t]], 
            Times[ 0.059070953080906402, 
              c[ 11][ t]], 
            Times[ 0.049975424961080865, 
              c[ 12][ t]], 
            Times[ 0.038978720157860088, 
              c[ 13][ t]], 
            Times[ 0.026603074225527937, 
              c[ 14][ t]], 
            Times[ 0.013414935129827233, 
              c[ 15][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 16][ t]], 
            Times[ -0.013061910521147276, 
              c[ 17][ t]], 
            Times[ -0.025221096343682053, 
              c[ 18][ t]], 
            Times[ -0.035980357068793781, 
              c[ 19][ t]], 
            Times[ -0.044914622433376288, 
              c[ 20][ t]], 
            Times[ -0.05168708394579296, 
              c[ 21][ t]], 
            Times[ -0.05606123915856713, 
              c[ 22][ t]], 
            Times[ -0.057908442314993203, 
              c[ 23][ t]], 
            Times[ -0.057210750238908967, 
              c[ 24][ t]], 
            Times[ -0.054059052045761224, 
              c[ 25][ t]], 
            Times[ -0.048646667243099399, 
              c[ 26][ t]], 
            Times[ -0.041258781072520248, 
              c[ 27][ t]], 
            Times[ -0.032258251165125679, 
              c[ 28][ t]], 
            Times[ -0.022068459300722043, 
              c[ 29][ t]], 
            Times[ -0.011153991006822649, 
              c[ 30][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 31][ t]], 
            Times[ 0.010908848347331785, 
              c[ 32][ t]], 
            Times[ 0.021108961070255627, 
              c[ 33][ t]], 
            Times[ 0.030177073670601094, 
              c[ 34][ t]], 
            Times[ 0.03774739544932687, 
              c[ 35][ t]], 
            Times[ 0.043525965428036162, 
              c[ 36][ t]], 
            Times[ 0.047301670540041058, 
              c[ 37][ t]], 
            Times[ 0.048953528554942699, 
              c[ 38][ t]], 
            Times[ 0.048454002753361682, 
              c[ 39][ t]], 
            Times[ 0.045868286584282311, 
              c[ 40][ t]], 
            Times[ 0.041349667156634483, 
              c[ 41][ t]], 
            Times[ 0.035131239329076656, 
              c[ 42][ t]], 
            Times[ 0.027514390699665887, 
              c[ 43][ t]], 
            Times[ 0.018854606004500389, 
              c[ 44][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 45][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 46][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 47][ t]], 
            Times[ -0.018149760920219783, 
              c[ 48][ t]], 
            Times[ -0.025985813438573278, 
              c[ 49][ t]], 
            Times[ -0.032552799745291051, 
              c[ 50][ t]], 
            Times[ -0.037590606506031236, 
              c[ 51][ t]], 
            Times[ -0.040909552899494925, 
              c[ 52][ t]], 
            Times[ -0.042397252409191441, 
              c[ 53][ t]], 
            Times[ -0.042022055485216314, 
              c[ 54][ t]], 
            Times[ -0.039832985717929335, 
              c[ 55][ t]], 
            Times[ -0.035956232310116944, 
              c[ 56][ t]], 
            Times[ -0.030588406657213296, 
              c[ 57][ t]], 
            Times[ -0.023986904712529358, 
              c[ 58][ t]], 
            Times[ -0.016457834054775768, 
              c[ 59][ t]], 
            Times[ -0.0083420605009009823, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-58\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-58\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9710122092317629`\ \(c[\(-60\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-59\)]\)[t] + 
            74.7807760116991`\ \(c[\(-58\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-57\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-56\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-55\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-54\)]\)[t] + 
            0.826993343132688`\ \(c[\(-53\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-52\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-51\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-50\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-49\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-48\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-47\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-46\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-45\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-42\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-41\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-40\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-39\)]\)[t] - 
            0.206748335783172`\ \(c[\(-38\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-37\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-36\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-35\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-34\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-33\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-32\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-31\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-30\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-29\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-27\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-26\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-25\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-24\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-23\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-22\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-21\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-20\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-19\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-18\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-17\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-16\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-15\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-14\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-13\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-12\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-11\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-10\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-9\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-8\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-7\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-6\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-5\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-4\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-3\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-2\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-1\)]\)[t] - 
            0.03348317962868157`\ \(c[0]\)[t] - 
            0.0168255118577494`\ \(c[1]\)[t] - 
            3.898171832519376`*^-17\ \(c[2]\)[t] + 
            0.016273855731265604`\ \(c[3]\)[t] + 
            0.03132297449134708`\ \(c[4]\)[t] + 
            0.04454710875183992`\ \(c[5]\)[t] + 
            0.05544148706619893`\ \(c[6]\)[t] + 
            0.06361487254866825`\ \(c[7]\)[t] + 
            0.06880242987642335`\ \(c[8]\)[t] + 
            0.07087301895267824`\ \(c[9]\)[t] + 
            0.06983076867396242`\ \(c[10]\)[t] + 
            0.06581101988179627`\ \(c[11]\)[t] + 
            0.059070953080906326`\ \(c[12]\)[t] + 
            0.049975424961080865`\ \(c[13]\)[t] + 
            0.03897872015785999`\ \(c[14]\)[t] + 
            0.026603074225527826`\ \(c[15]\)[t] + 
            0.013414935129827233`\ \(c[16]\)[t] + 
            3.898171832519376`*^-17\ \(c[17]\)[t] - 
            0.013061910521147383`\ \(c[18]\)[t] - 
            0.025221096343682053`\ \(c[19]\)[t] - 
            0.03598035706879378`\ \(c[20]\)[t] - 
            0.04491462243337642`\ \(c[21]\)[t] - 
            0.05168708394579296`\ \(c[22]\)[t] - 
            0.056061239158567186`\ \(c[23]\)[t] - 
            0.0579084423149932`\ \(c[24]\)[t] - 
            0.05721075023890897`\ \(c[25]\)[t] - 
            0.054059052045761224`\ \(c[26]\)[t] - 
            0.04864666724309928`\ \(c[27]\)[t] - 
            0.04125878107252025`\ \(c[28]\)[t] - 
            0.03225825116512552`\ \(c[29]\)[t] - 
            0.022068459300722043`\ \(c[30]\)[t] - 
            0.011153991006822649`\ \(c[31]\)[t] - 
            3.8981718325193755`*^-17\ \(c[32]\)[t] + 
            0.010908848347331966`\ \(c[33]\)[t] + 
            0.021108961070255627`\ \(c[34]\)[t] + 
            0.030177073670601236`\ \(c[35]\)[t] + 
            0.03774739544932687`\ \(c[36]\)[t] + 
            0.04352596542803616`\ \(c[37]\)[t] + 
            0.04730167054004106`\ \(c[38]\)[t] + 
            0.04895352855494272`\ \(c[39]\)[t] + 
            0.04845400275336168`\ \(c[40]\)[t] + 
            0.04586828658428231`\ \(c[41]\)[t] + 
            0.04134966715663448`\ \(c[42]\)[t] + 
            0.035131239329076656`\ \(c[43]\)[t] + 
            0.027514390699665887`\ \(c[44]\)[t] + 
            0.018854606004500233`\ \(c[45]\)[t] + 
            0.009545242303915543`\ \(c[46]\)[t] + 
            2.005337021455629`*^-16\ \(c[47]\)[t] - 
            0.009365143392520679`\ \(c[48]\)[t] - 
            0.018149760920219783`\ \(c[49]\)[t] - 
            0.02598581343857328`\ \(c[50]\)[t] - 
            0.032552799745291155`\ \(c[51]\)[t] - 
            0.037590606506031236`\ \(c[52]\)[t] - 
            0.040909552899494925`\ \(c[53]\)[t] - 
            0.04239725240919144`\ \(c[54]\)[t] - 
            0.042022055485216314`\ \(c[55]\)[t] - 
            0.039832985717929335`\ \(c[56]\)[t] - 
            0.03595623231011687`\ \(c[57]\)[t] - 
            0.030588406657213296`\ \(c[58]\)[t] - 
            0.02398690471252936`\ \(c[59]\)[t] - 
            0.01645783405477577`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -58, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -58]][ t]], 
          Plus[ 
            Times[ 0.9710122092317629, 
              c[ -60][ t]], 
            Times[ 0.99270519960720693, 
              c[ -59][ t]], 
            Times[ 74.780776011699103, 
              c[ -58][ t]], 
            Times[ 0.99270519960720693, 
              c[ -57][ t]], 
            Times[ 0.9710122092317629, 
              c[ -56][ t]], 
            Times[ 0.93548928378863916, 
              c[ -55][ t]], 
            Times[ 0.88706379305918392, 
              c[ -54][ t]], 
            Times[ 0.82699334313268802, 
              c[ -53][ t]], 
            Times[ 0.75682672864065692, 
              c[ -52][ t]], 
            Times[ 0.67835603854706361, 
              c[ -51][ t]], 
            Times[ 0.59356153372868015, 
              c[ -50][ t]], 
            Times[ 0.50455115242710469, 
              c[ -49][ t]], 
            Times[ 0.41349667156634429, 
              c[ -48][ t]], 
            Times[ 0.32256865202152113, 
              c[ -47][ t]], 
            Times[ 0.23387232094715985, 
              c[ -46][ t]], 
            Times[ 0.14938649372796384, 
              c[ -45][ t]], 
            Times[ 0.070907514257657456, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.062044074975450239, 
              c[ -42][ t]], 
            Times[ -0.11423673049785459, 
              c[ -41][ t]], 
            Times[ -0.15591488063143982, 
              c[ -40][ t]], 
            Times[ -0.18675027222298593, 
              c[ -39][ t]], 
            Times[ -0.206748335783172, 
              c[ -38][ t]], 
            Times[ -0.21623620818304484, 
              c[ -37][ t]], 
            Times[ -0.21584055771952015, 
              c[ -36][ t]], 
            Times[ -0.20645618564475843, 
              c[ -35][ t]], 
            Times[ -0.18920668216016426, 
              c[ -34][ t]], 
            Times[ -0.16539866862653771, 
              c[ -33][ t]], 
            Times[ -0.13647135277833605, 
              c[ -32][ t]], 
            Times[ -0.10394325375429328, 
              c[ -31][ t]], 
            Times[ -0.06935801494512607, 
              c[ -30][ t]], 
            Times[ -0.034231213779558949, 
              c[ -29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ 0.032022748374425904, 
              c[ -27][ t]], 
            Times[ 0.060688263076985105, 
              c[ -26][ t]], 
            Times[ 0.085044480344421705, 
              c[ -25][ t]], 
            Times[ 0.10436044624225685, 
              c[ -24][ t]], 
            Times[ 0.11814190616181255, 
              c[ -23][ t]], 
            Times[ 0.12613778810677614, 
              c[ -22][ t]], 
            Times[ 0.12833762891430928, 
              c[ -21][ t]], 
            Times[ 0.12496032289024853, 
              c[ -20][ t]], 
            Times[ 0.11643488132933186, 
              c[ -19][ t]], 
            Times[ 0.10337416789158609, 
              c[ -18][ t]], 
            Times[ 0.086542809078944891, 
              c[ -17][ t]], 
            Times[ 0.066820663127759972, 
              c[ -16][ t]], 
            Times[ 0.045163358568919301, 
              c[ -15][ t]], 
            Times[ 0.022561481809254869, 
              c[ -14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -13][ t]], 
            Times[ -0.021580547817547879, 
              c[ -12][ t]], 
            Times[ -0.04131966847794722, 
              c[ -11][ t]], 
            Times[ -0.058468080236789913, 
              c[ -10][ t]], 
            Times[ -0.072413370861974122, 
              c[ -9][ t]], 
            Times[ -0.082699334313268744, 
              c[ -8][ t]], 
            Times[ -0.089038438663606695, 
              c[ -7][ t]], 
            Times[ -0.091317159035181589, 
              c[ -6][ t]], 
            Times[ -0.089594193770366884, 
              c[ -5][ t]], 
            Times[ -0.084091858737850814, 
              c[ -4][ t]], 
            Times[ -0.075181213012062598, 
              c[ -3][ t]], 
            Times[ -0.063361699504227528, 
              c[ -2][ t]], 
            Times[ -0.049236278094138941, 
              c[ -1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 0][ t]], 
            Times[ -0.016825511857749401, 
              c[ 1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ 0.016273855731265604, 
              c[ 3][ t]], 
            Times[ 0.031322974491347078, 
              c[ 4][ t]], 
            Times[ 0.044547108751839919, 
              c[ 5][ t]], 
            Times[ 0.055441487066198933, 
              c[ 6][ t]], 
            Times[ 0.063614872548668253, 
              c[ 7][ t]], 
            Times[ 0.068802429876423349, 
              c[ 8][ t]], 
            Times[ 0.070873018952678238, 
              c[ 9][ t]], 
            Times[ 0.069830768673962415, 
              c[ 10][ t]], 
            Times[ 0.065811019881796273, 
              c[ 11][ t]], 
            Times[ 0.059070953080906326, 
              c[ 12][ t]], 
            Times[ 0.049975424961080865, 
              c[ 13][ t]], 
            Times[ 0.03897872015785999, 
              c[ 14][ t]], 
            Times[ 0.026603074225527826, 
              c[ 15][ t]], 
            Times[ 0.013414935129827233, 
              c[ 16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ -0.013061910521147383, 
              c[ 18][ t]], 
            Times[ -0.025221096343682053, 
              c[ 19][ t]], 
            Times[ -0.035980357068793781, 
              c[ 20][ t]], 
            Times[ -0.044914622433376419, 
              c[ 21][ t]], 
            Times[ -0.05168708394579296, 
              c[ 22][ t]], 
            Times[ -0.056061239158567186, 
              c[ 23][ t]], 
            Times[ -0.057908442314993203, 
              c[ 24][ t]], 
            Times[ -0.057210750238908967, 
              c[ 25][ t]], 
            Times[ -0.054059052045761224, 
              c[ 26][ t]], 
            Times[ -0.048646667243099281, 
              c[ 27][ t]], 
            Times[ -0.041258781072520248, 
              c[ 28][ t]], 
            Times[ -0.032258251165125519, 
              c[ 29][ t]], 
            Times[ -0.022068459300722043, 
              c[ 30][ t]], 
            Times[ -0.011153991006822649, 
              c[ 31][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 32][ t]], 
            Times[ 0.010908848347331966, 
              c[ 33][ t]], 
            Times[ 0.021108961070255627, 
              c[ 34][ t]], 
            Times[ 0.030177073670601236, 
              c[ 35][ t]], 
            Times[ 0.03774739544932687, 
              c[ 36][ t]], 
            Times[ 0.043525965428036162, 
              c[ 37][ t]], 
            Times[ 0.047301670540041058, 
              c[ 38][ t]], 
            Times[ 0.04895352855494272, 
              c[ 39][ t]], 
            Times[ 0.048454002753361682, 
              c[ 40][ t]], 
            Times[ 0.045868286584282311, 
              c[ 41][ t]], 
            Times[ 0.041349667156634483, 
              c[ 42][ t]], 
            Times[ 0.035131239329076656, 
              c[ 43][ t]], 
            Times[ 0.027514390699665887, 
              c[ 44][ t]], 
            Times[ 0.018854606004500233, 
              c[ 45][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 46][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 47][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 48][ t]], 
            Times[ -0.018149760920219783, 
              c[ 49][ t]], 
            Times[ -0.025985813438573278, 
              c[ 50][ t]], 
            Times[ -0.032552799745291155, 
              c[ 51][ t]], 
            Times[ -0.037590606506031236, 
              c[ 52][ t]], 
            Times[ -0.040909552899494925, 
              c[ 53][ t]], 
            Times[ -0.042397252409191441, 
              c[ 54][ t]], 
            Times[ -0.042022055485216314, 
              c[ 55][ t]], 
            Times[ -0.039832985717929335, 
              c[ 56][ t]], 
            Times[ -0.035956232310116867, 
              c[ 57][ t]], 
            Times[ -0.030588406657213296, 
              c[ 58][ t]], 
            Times[ -0.023986904712529358, 
              c[ 59][ t]], 
            Times[ -0.016457834054775768, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-57\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-57\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.9354892837886392`\ \(c[\(-60\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-59\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-58\)]\)[t] + 
            72.25854377586516`\ \(c[\(-57\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-56\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-55\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-54\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-53\)]\)[t] + 
            0.826993343132688`\ \(c[\(-52\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-51\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-50\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-49\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-48\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-47\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-46\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-45\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-44\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-41\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-40\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-39\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-38\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-37\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-36\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-35\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-34\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-33\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-32\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-31\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-30\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-29\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-26\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-25\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-24\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-23\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-22\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-21\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-20\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-19\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-18\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-17\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-16\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-15\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-14\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-13\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-12\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-11\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-10\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-9\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-8\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-7\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-6\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-5\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-4\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-3\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-2\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-1\)]\)[t] - 
            0.04923627809413894`\ \(c[0]\)[t] - 
            0.03348317962868157`\ \(c[1]\)[t] - 
            0.016825511857749262`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.016273855731265604`\ \(c[4]\)[t] + 
            0.0313229744913472`\ \(c[5]\)[t] + 
            0.04454710875183992`\ \(c[6]\)[t] + 
            0.05544148706619893`\ \(c[7]\)[t] + 
            0.06361487254866832`\ \(c[8]\)[t] + 
            0.06880242987642335`\ \(c[9]\)[t] + 
            0.07087301895267824`\ \(c[10]\)[t] + 
            0.06983076867396242`\ \(c[11]\)[t] + 
            0.06581101988179627`\ \(c[12]\)[t] + 
            0.059070953080906326`\ \(c[13]\)[t] + 
            0.049975424961080865`\ \(c[14]\)[t] + 
            0.03897872015785999`\ \(c[15]\)[t] + 
            0.026603074225527826`\ \(c[16]\)[t] + 
            0.013414935129827233`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.013061910521147383`\ \(c[19]\)[t] - 
            0.025221096343682053`\ \(c[20]\)[t] - 
            0.03598035706879378`\ \(c[21]\)[t] - 
            0.04491462243337642`\ \(c[22]\)[t] - 
            0.05168708394579296`\ \(c[23]\)[t] - 
            0.056061239158567186`\ \(c[24]\)[t] - 
            0.0579084423149932`\ \(c[25]\)[t] - 
            0.05721075023890897`\ \(c[26]\)[t] - 
            0.054059052045761224`\ \(c[27]\)[t] - 
            0.04864666724309928`\ \(c[28]\)[t] - 
            0.04125878107252025`\ \(c[29]\)[t] - 
            0.03225825116512552`\ \(c[30]\)[t] - 
            0.022068459300722043`\ \(c[31]\)[t] - 
            0.011153991006822649`\ \(c[32]\)[t] - 
            3.8981718325193755`*^-17\ \(c[33]\)[t] + 
            0.010908848347331966`\ \(c[34]\)[t] + 
            0.021108961070255627`\ \(c[35]\)[t] + 
            0.030177073670601236`\ \(c[36]\)[t] + 
            0.03774739544932687`\ \(c[37]\)[t] + 
            0.04352596542803616`\ \(c[38]\)[t] + 
            0.04730167054004106`\ \(c[39]\)[t] + 
            0.04895352855494272`\ \(c[40]\)[t] + 
            0.04845400275336168`\ \(c[41]\)[t] + 
            0.045868286584282256`\ \(c[42]\)[t] + 
            0.04134966715663448`\ \(c[43]\)[t] + 
            0.035131239329076656`\ \(c[44]\)[t] + 
            0.027514390699665887`\ \(c[45]\)[t] + 
            0.018854606004500233`\ \(c[46]\)[t] + 
            0.009545242303915543`\ \(c[47]\)[t] + 
            3.8981718325193755`*^-17\ \(c[48]\)[t] - 
            0.009365143392520679`\ \(c[49]\)[t] - 
            0.018149760920219783`\ \(c[50]\)[t] - 
            0.02598581343857328`\ \(c[51]\)[t] - 
            0.032552799745291155`\ \(c[52]\)[t] - 
            0.037590606506031236`\ \(c[53]\)[t] - 
            0.040909552899494966`\ \(c[54]\)[t] - 
            0.04239725240919144`\ \(c[55]\)[t] - 
            0.042022055485216314`\ \(c[56]\)[t] - 
            0.039832985717929335`\ \(c[57]\)[t] - 
            0.03595623231011687`\ \(c[58]\)[t] - 
            0.030588406657213296`\ \(c[59]\)[t] - 
            0.023986904712529237`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -57, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -57]][ t]], 
          Plus[ 
            Times[ 0.93548928378863916, 
              c[ -60][ t]], 
            Times[ 0.9710122092317629, 
              c[ -59][ t]], 
            Times[ 0.99270519960720693, 
              c[ -58][ t]], 
            Times[ 72.258543775865164, 
              c[ -57][ t]], 
            Times[ 0.99270519960720671, 
              c[ -56][ t]], 
            Times[ 0.9710122092317629, 
              c[ -55][ t]], 
            Times[ 0.93548928378863916, 
              c[ -54][ t]], 
            Times[ 0.88706379305918348, 
              c[ -53][ t]], 
            Times[ 0.82699334313268802, 
              c[ -52][ t]], 
            Times[ 0.75682672864065692, 
              c[ -51][ t]], 
            Times[ 0.67835603854706272, 
              c[ -50][ t]], 
            Times[ 0.59356153372868015, 
              c[ -49][ t]], 
            Times[ 0.50455115242710469, 
              c[ -48][ t]], 
            Times[ 0.41349667156634362, 
              c[ -47][ t]], 
            Times[ 0.32256865202152113, 
              c[ -46][ t]], 
            Times[ 0.23387232094715985, 
              c[ -45][ t]], 
            Times[ 0.14938649372796314, 
              c[ -44][ t]], 
            Times[ 0.070907514257657456, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.062044074975450718, 
              c[ -41][ t]], 
            Times[ -0.11423673049785459, 
              c[ -40][ t]], 
            Times[ -0.15591488063143982, 
              c[ -39][ t]], 
            Times[ -0.18675027222298607, 
              c[ -38][ t]], 
            Times[ -0.20674833578317206, 
              c[ -37][ t]], 
            Times[ -0.21623620818304484, 
              c[ -36][ t]], 
            Times[ -0.21584055771952013, 
              c[ -35][ t]], 
            Times[ -0.20645618564475834, 
              c[ -34][ t]], 
            Times[ -0.18920668216016426, 
              c[ -33][ t]], 
            Times[ -0.1653986686265376, 
              c[ -32][ t]], 
            Times[ -0.13647135277833591, 
              c[ -31][ t]], 
            Times[ -0.10394325375429328, 
              c[ -30][ t]], 
            Times[ -0.069358014945125918, 
              c[ -29][ t]], 
            Times[ -0.034231213779558796, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.032022748374426029, 
              c[ -26][ t]], 
            Times[ 0.060688263076985223, 
              c[ -25][ t]], 
            Times[ 0.085044480344421705, 
              c[ -24][ t]], 
            Times[ 0.10436044624225692, 
              c[ -23][ t]], 
            Times[ 0.1181419061618126, 
              c[ -22][ t]], 
            Times[ 0.12613778810677614, 
              c[ -21][ t]], 
            Times[ 0.12833762891430925, 
              c[ -20][ t]], 
            Times[ 0.12496032289024847, 
              c[ -19][ t]], 
            Times[ 0.11643488132933186, 
              c[ -18][ t]], 
            Times[ 0.10337416789158595, 
              c[ -17][ t]], 
            Times[ 0.086542809078944752, 
              c[ -16][ t]], 
            Times[ 0.066820663127759972, 
              c[ -15][ t]], 
            Times[ 0.045163358568919114, 
              c[ -14][ t]], 
            Times[ 0.022561481809254675, 
              c[ -13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -12][ t]], 
            Times[ -0.021580547817548056, 
              c[ -11][ t]], 
            Times[ -0.041319668477947373, 
              c[ -10][ t]], 
            Times[ -0.058468080236789913, 
              c[ -9][ t]], 
            Times[ -0.072413370861974122, 
              c[ -8][ t]], 
            Times[ -0.082699334313268813, 
              c[ -7][ t]], 
            Times[ -0.089038438663606695, 
              c[ -6][ t]], 
            Times[ -0.091317159035181589, 
              c[ -5][ t]], 
            Times[ -0.089594193770366842, 
              c[ -4][ t]], 
            Times[ -0.084091858737850814, 
              c[ -3][ t]], 
            Times[ -0.075181213012062598, 
              c[ -2][ t]], 
            Times[ -0.063361699504227403, 
              c[ -1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 0][ t]], 
            Times[ -0.033483179628681567, 
              c[ 1][ t]], 
            Times[ -0.016825511857749262, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.016273855731265604, 
              c[ 4][ t]], 
            Times[ 0.031322974491347202, 
              c[ 5][ t]], 
            Times[ 0.044547108751839919, 
              c[ 6][ t]], 
            Times[ 0.055441487066198933, 
              c[ 7][ t]], 
            Times[ 0.063614872548668322, 
              c[ 8][ t]], 
            Times[ 0.068802429876423349, 
              c[ 9][ t]], 
            Times[ 0.070873018952678238, 
              c[ 10][ t]], 
            Times[ 0.069830768673962415, 
              c[ 11][ t]], 
            Times[ 0.065811019881796273, 
              c[ 12][ t]], 
            Times[ 0.059070953080906326, 
              c[ 13][ t]], 
            Times[ 0.049975424961080865, 
              c[ 14][ t]], 
            Times[ 0.03897872015785999, 
              c[ 15][ t]], 
            Times[ 0.026603074225527826, 
              c[ 16][ t]], 
            Times[ 0.013414935129827233, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.013061910521147383, 
              c[ 19][ t]], 
            Times[ -0.025221096343682053, 
              c[ 20][ t]], 
            Times[ -0.035980357068793781, 
              c[ 21][ t]], 
            Times[ -0.044914622433376419, 
              c[ 22][ t]], 
            Times[ -0.05168708394579296, 
              c[ 23][ t]], 
            Times[ -0.056061239158567186, 
              c[ 24][ t]], 
            Times[ -0.057908442314993203, 
              c[ 25][ t]], 
            Times[ -0.057210750238908967, 
              c[ 26][ t]], 
            Times[ -0.054059052045761224, 
              c[ 27][ t]], 
            Times[ -0.048646667243099281, 
              c[ 28][ t]], 
            Times[ -0.041258781072520248, 
              c[ 29][ t]], 
            Times[ -0.032258251165125519, 
              c[ 30][ t]], 
            Times[ -0.022068459300722043, 
              c[ 31][ t]], 
            Times[ -0.011153991006822649, 
              c[ 32][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 33][ t]], 
            Times[ 0.010908848347331966, 
              c[ 34][ t]], 
            Times[ 0.021108961070255627, 
              c[ 35][ t]], 
            Times[ 0.030177073670601236, 
              c[ 36][ t]], 
            Times[ 0.03774739544932687, 
              c[ 37][ t]], 
            Times[ 0.043525965428036162, 
              c[ 38][ t]], 
            Times[ 0.047301670540041058, 
              c[ 39][ t]], 
            Times[ 0.04895352855494272, 
              c[ 40][ t]], 
            Times[ 0.048454002753361682, 
              c[ 41][ t]], 
            Times[ 0.045868286584282256, 
              c[ 42][ t]], 
            Times[ 0.041349667156634483, 
              c[ 43][ t]], 
            Times[ 0.035131239329076656, 
              c[ 44][ t]], 
            Times[ 0.027514390699665887, 
              c[ 45][ t]], 
            Times[ 0.018854606004500233, 
              c[ 46][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 49][ t]], 
            Times[ -0.018149760920219783, 
              c[ 50][ t]], 
            Times[ -0.025985813438573278, 
              c[ 51][ t]], 
            Times[ -0.032552799745291155, 
              c[ 52][ t]], 
            Times[ -0.037590606506031236, 
              c[ 53][ t]], 
            Times[ -0.040909552899494966, 
              c[ 54][ t]], 
            Times[ -0.042397252409191441, 
              c[ 55][ t]], 
            Times[ -0.042022055485216314, 
              c[ 56][ t]], 
            Times[ -0.039832985717929335, 
              c[ 57][ t]], 
            Times[ -0.035956232310116867, 
              c[ 58][ t]], 
            Times[ -0.030588406657213296, 
              c[ 59][ t]], 
            Times[ -0.023986904712529237, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-56\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-56\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.8870637930591835`\ \(c[\(-60\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-59\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-58\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-57\)]\)[t] + 
            69.78017644848049`\ \(c[\(-56\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-55\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-54\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-53\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-52\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-51\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-50\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-49\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-48\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-47\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-46\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-45\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-44\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-43\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-42\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-41\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-40\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-39\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-38\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-37\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-36\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-35\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-34\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-33\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-32\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-31\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-30\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-29\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-28\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-27\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-26\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-25\)]\)[t] + 
            0.060688263076985`\ \(c[\(-24\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-23\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-22\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-21\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-20\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-19\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-18\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-17\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-16\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-15\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-14\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-13\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-12\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-11\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-10\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-9\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-8\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-7\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-6\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-5\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-4\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-3\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-2\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-1\)]\)[t] - 
            0.06336169950422753`\ \(c[0]\)[t] - 
            0.049236278094139066`\ \(c[1]\)[t] - 
            0.03348317962868157`\ \(c[2]\)[t] - 
            0.0168255118577494`\ \(c[3]\)[t] - 
            1.8033970416801674`*^-16\ \(c[4]\)[t] + 
            0.016273855731265604`\ \(c[5]\)[t] + 
            0.03132297449134708`\ \(c[6]\)[t] + 
            0.044547108751839815`\ \(c[7]\)[t] + 
            0.05544148706619893`\ \(c[8]\)[t] + 
            0.06361487254866825`\ \(c[9]\)[t] + 
            0.06880242987642332`\ \(c[10]\)[t] + 
            0.07087301895267824`\ \(c[11]\)[t] + 
            0.06983076867396242`\ \(c[12]\)[t] + 
            0.06581101988179631`\ \(c[13]\)[t] + 
            0.0590709530809064`\ \(c[14]\)[t] + 
            0.049975424961080865`\ \(c[15]\)[t] + 
            0.03897872015786009`\ \(c[16]\)[t] + 
            0.026603074225527937`\ \(c[17]\)[t] + 
            0.013414935129827233`\ \(c[18]\)[t] + 
            1.5206810699945212`*^-16\ \(c[19]\)[t] - 
            0.013061910521147276`\ \(c[20]\)[t] - 
            0.025221096343682053`\ \(c[21]\)[t] - 
            0.03598035706879378`\ \(c[22]\)[t] - 
            0.04491462243337629`\ \(c[23]\)[t] - 
            0.05168708394579296`\ \(c[24]\)[t] - 
            0.05606123915856713`\ \(c[25]\)[t] - 
            0.0579084423149932`\ \(c[26]\)[t] - 
            0.05721075023890897`\ \(c[27]\)[t] - 
            0.054059052045761224`\ \(c[28]\)[t] - 
            0.0486466672430994`\ \(c[29]\)[t] - 
            0.04125878107252025`\ \(c[30]\)[t] - 
            0.03225825116512568`\ \(c[31]\)[t] - 
            0.022068459300722043`\ \(c[32]\)[t] - 
            0.011153991006822649`\ \(c[33]\)[t] - 
            3.8981718325193755`*^-17\ \(c[34]\)[t] + 
            0.010908848347331785`\ \(c[35]\)[t] + 
            0.021108961070255627`\ \(c[36]\)[t] + 
            0.030177073670601094`\ \(c[37]\)[t] + 
            0.03774739544932687`\ \(c[38]\)[t] + 
            0.04352596542803616`\ \(c[39]\)[t] + 
            0.04730167054004106`\ \(c[40]\)[t] + 
            0.0489535285549427`\ \(c[41]\)[t] + 
            0.04845400275336168`\ \(c[42]\)[t] + 
            0.04586828658428231`\ \(c[43]\)[t] + 
            0.04134966715663448`\ \(c[44]\)[t] + 
            0.035131239329076656`\ \(c[45]\)[t] + 
            0.027514390699665887`\ \(c[46]\)[t] + 
            0.01885460600450039`\ \(c[47]\)[t] + 
            0.009545242303915543`\ \(c[48]\)[t] + 
            2.005337021455629`*^-16\ \(c[49]\)[t] - 
            0.009365143392520679`\ \(c[50]\)[t] - 
            0.018149760920219783`\ \(c[51]\)[t] - 
            0.02598581343857328`\ \(c[52]\)[t] - 
            0.03255279974529105`\ \(c[53]\)[t] - 
            0.037590606506031236`\ \(c[54]\)[t] - 
            0.040909552899494925`\ \(c[55]\)[t] - 
            0.04239725240919144`\ \(c[56]\)[t] - 
            0.042022055485216314`\ \(c[57]\)[t] - 
            0.039832985717929335`\ \(c[58]\)[t] - 
            0.035956232310116944`\ \(c[59]\)[t] - 
            0.030588406657213296`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -56, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -56]][ t]], 
          Plus[ 
            Times[ 0.88706379305918348, 
              c[ -60][ t]], 
            Times[ 0.93548928378863916, 
              c[ -59][ t]], 
            Times[ 0.9710122092317629, 
              c[ -58][ t]], 
            Times[ 0.99270519960720671, 
              c[ -57][ t]], 
            Times[ 69.780176448480489, 
              c[ -56][ t]], 
            Times[ 0.99270519960720693, 
              c[ -55][ t]], 
            Times[ 0.9710122092317629, 
              c[ -54][ t]], 
            Times[ 0.93548928378863916, 
              c[ -53][ t]], 
            Times[ 0.88706379305918392, 
              c[ -52][ t]], 
            Times[ 0.82699334313268846, 
              c[ -51][ t]], 
            Times[ 0.75682672864065692, 
              c[ -50][ t]], 
            Times[ 0.67835603854706361, 
              c[ -49][ t]], 
            Times[ 0.59356153372868092, 
              c[ -48][ t]], 
            Times[ 0.50455115242710469, 
              c[ -47][ t]], 
            Times[ 0.41349667156634429, 
              c[ -46][ t]], 
            Times[ 0.32256865202152191, 
              c[ -45][ t]], 
            Times[ 0.23387232094715985, 
              c[ -44][ t]], 
            Times[ 0.14938649372796384, 
              c[ -43][ t]], 
            Times[ 0.070907514257658094, 
              c[ -42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -41][ t]], 
            Times[ -0.062044074975450239, 
              c[ -40][ t]], 
            Times[ -0.11423673049785416, 
              c[ -39][ t]], 
            Times[ -0.15591488063143966, 
              c[ -38][ t]], 
            Times[ -0.18675027222298593, 
              c[ -37][ t]], 
            Times[ -0.20674833578317189, 
              c[ -36][ t]], 
            Times[ -0.21623620818304481, 
              c[ -35][ t]], 
            Times[ -0.21584055771952015, 
              c[ -34][ t]], 
            Times[ -0.20645618564475848, 
              c[ -33][ t]], 
            Times[ -0.18920668216016434, 
              c[ -32][ t]], 
            Times[ -0.16539866862653771, 
              c[ -31][ t]], 
            Times[ -0.13647135277833616, 
              c[ -30][ t]], 
            Times[ -0.1039432537542934, 
              c[ -29][ t]], 
            Times[ -0.06935801494512607, 
              c[ -28][ t]], 
            Times[ -0.034231213779559094, 
              c[ -27][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -26][ t]], 
            Times[ 0.032022748374425904, 
              c[ -25][ t]], 
            Times[ 0.060688263076985001, 
              c[ -24][ t]], 
            Times[ 0.085044480344421608, 
              c[ -23][ t]], 
            Times[ 0.10436044624225685, 
              c[ -22][ t]], 
            Times[ 0.11814190616181253, 
              c[ -21][ t]], 
            Times[ 0.12613778810677612, 
              c[ -20][ t]], 
            Times[ 0.12833762891430928, 
              c[ -19][ t]], 
            Times[ 0.12496032289024853, 
              c[ -18][ t]], 
            Times[ 0.11643488132933186, 
              c[ -17][ t]], 
            Times[ 0.10337416789158609, 
              c[ -16][ t]], 
            Times[ 0.086542809078944891, 
              c[ -15][ t]], 
            Times[ 0.066820663127759972, 
              c[ -14][ t]], 
            Times[ 0.045163358568919301, 
              c[ -13][ t]], 
            Times[ 0.022561481809254869, 
              c[ -12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -11][ t]], 
            Times[ -0.021580547817547879, 
              c[ -10][ t]], 
            Times[ -0.04131966847794722, 
              c[ -9][ t]], 
            Times[ -0.058468080236789774, 
              c[ -8][ t]], 
            Times[ -0.072413370861974122, 
              c[ -7][ t]], 
            Times[ -0.082699334313268744, 
              c[ -6][ t]], 
            Times[ -0.089038438663606653, 
              c[ -5][ t]], 
            Times[ -0.091317159035181589, 
              c[ -4][ t]], 
            Times[ -0.089594193770366884, 
              c[ -3][ t]], 
            Times[ -0.084091858737850855, 
              c[ -2][ t]], 
            Times[ -0.075181213012062598, 
              c[ -1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 0][ t]], 
            Times[ -0.049236278094139066, 
              c[ 1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 2][ t]], 
            Times[ -0.016825511857749401, 
              c[ 3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ 0.016273855731265604, 
              c[ 5][ t]], 
            Times[ 0.031322974491347078, 
              c[ 6][ t]], 
            Times[ 0.044547108751839815, 
              c[ 7][ t]], 
            Times[ 0.055441487066198933, 
              c[ 8][ t]], 
            Times[ 0.063614872548668253, 
              c[ 9][ t]], 
            Times[ 0.068802429876423321, 
              c[ 10][ t]], 
            Times[ 0.070873018952678238, 
              c[ 11][ t]], 
            Times[ 0.069830768673962415, 
              c[ 12][ t]], 
            Times[ 0.065811019881796315, 
              c[ 13][ t]], 
            Times[ 0.059070953080906402, 
              c[ 14][ t]], 
            Times[ 0.049975424961080865, 
              c[ 15][ t]], 
            Times[ 0.038978720157860088, 
              c[ 16][ t]], 
            Times[ 0.026603074225527937, 
              c[ 17][ t]], 
            Times[ 0.013414935129827233, 
              c[ 18][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 19][ t]], 
            Times[ -0.013061910521147276, 
              c[ 20][ t]], 
            Times[ -0.025221096343682053, 
              c[ 21][ t]], 
            Times[ -0.035980357068793781, 
              c[ 22][ t]], 
            Times[ -0.044914622433376288, 
              c[ 23][ t]], 
            Times[ -0.05168708394579296, 
              c[ 24][ t]], 
            Times[ -0.05606123915856713, 
              c[ 25][ t]], 
            Times[ -0.057908442314993203, 
              c[ 26][ t]], 
            Times[ -0.057210750238908967, 
              c[ 27][ t]], 
            Times[ -0.054059052045761224, 
              c[ 28][ t]], 
            Times[ -0.048646667243099399, 
              c[ 29][ t]], 
            Times[ -0.041258781072520248, 
              c[ 30][ t]], 
            Times[ -0.032258251165125679, 
              c[ 31][ t]], 
            Times[ -0.022068459300722043, 
              c[ 32][ t]], 
            Times[ -0.011153991006822649, 
              c[ 33][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 34][ t]], 
            Times[ 0.010908848347331785, 
              c[ 35][ t]], 
            Times[ 0.021108961070255627, 
              c[ 36][ t]], 
            Times[ 0.030177073670601094, 
              c[ 37][ t]], 
            Times[ 0.03774739544932687, 
              c[ 38][ t]], 
            Times[ 0.043525965428036162, 
              c[ 39][ t]], 
            Times[ 0.047301670540041058, 
              c[ 40][ t]], 
            Times[ 0.048953528554942699, 
              c[ 41][ t]], 
            Times[ 0.048454002753361682, 
              c[ 42][ t]], 
            Times[ 0.045868286584282311, 
              c[ 43][ t]], 
            Times[ 0.041349667156634483, 
              c[ 44][ t]], 
            Times[ 0.035131239329076656, 
              c[ 45][ t]], 
            Times[ 0.027514390699665887, 
              c[ 46][ t]], 
            Times[ 0.018854606004500389, 
              c[ 47][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 48][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 49][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 50][ t]], 
            Times[ -0.018149760920219783, 
              c[ 51][ t]], 
            Times[ -0.025985813438573278, 
              c[ 52][ t]], 
            Times[ -0.032552799745291051, 
              c[ 53][ t]], 
            Times[ -0.037590606506031236, 
              c[ 54][ t]], 
            Times[ -0.040909552899494925, 
              c[ 55][ t]], 
            Times[ -0.042397252409191441, 
              c[ 56][ t]], 
            Times[ -0.042022055485216314, 
              c[ 57][ t]], 
            Times[ -0.039832985717929335, 
              c[ 58][ t]], 
            Times[ -0.035956232310116944, 
              c[ 59][ t]], 
            Times[ -0.030588406657213296, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-55\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-55\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.826993343132688`\ \(c[\(-60\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-59\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-58\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-57\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-56\)]\)[t] + 
            67.34567402954512`\ \(c[\(-55\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-54\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-53\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-52\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-51\)]\)[t] + 
            0.826993343132688`\ \(c[\(-50\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-49\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-48\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-47\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-46\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-45\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-44\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-43\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-42\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-39\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-38\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-37\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-36\)]\)[t] - 
            0.206748335783172`\ \(c[\(-35\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-34\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-33\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-32\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-31\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-30\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-29\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-28\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-27\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-26\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-24\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-23\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-22\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-21\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-20\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-19\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-18\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-17\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-16\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-15\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-14\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-13\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-12\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-11\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-10\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-9\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-8\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-7\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-6\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-5\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-4\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-3\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-2\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-1\)]\)[t] - 
            0.0751812130120626`\ \(c[0]\)[t] - 
            0.06336169950422753`\ \(c[1]\)[t] - 
            0.04923627809413894`\ \(c[2]\)[t] - 
            0.03348317962868157`\ \(c[3]\)[t] - 
            0.0168255118577494`\ \(c[4]\)[t] - 
            3.898171832519376`*^-17\ \(c[5]\)[t] + 
            0.016273855731265604`\ \(c[6]\)[t] + 
            0.03132297449134708`\ \(c[7]\)[t] + 
            0.04454710875183992`\ \(c[8]\)[t] + 
            0.05544148706619893`\ \(c[9]\)[t] + 
            0.06361487254866825`\ \(c[10]\)[t] + 
            0.06880242987642335`\ \(c[11]\)[t] + 
            0.07087301895267824`\ \(c[12]\)[t] + 
            0.06983076867396242`\ \(c[13]\)[t] + 
            0.06581101988179627`\ \(c[14]\)[t] + 
            0.059070953080906326`\ \(c[15]\)[t] + 
            0.049975424961080865`\ \(c[16]\)[t] + 
            0.03897872015785999`\ \(c[17]\)[t] + 
            0.026603074225527826`\ \(c[18]\)[t] + 
            0.013414935129827233`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] - 
            0.013061910521147383`\ \(c[21]\)[t] - 
            0.025221096343682053`\ \(c[22]\)[t] - 
            0.03598035706879378`\ \(c[23]\)[t] - 
            0.04491462243337642`\ \(c[24]\)[t] - 
            0.05168708394579296`\ \(c[25]\)[t] - 
            0.056061239158567186`\ \(c[26]\)[t] - 
            0.0579084423149932`\ \(c[27]\)[t] - 
            0.05721075023890897`\ \(c[28]\)[t] - 
            0.054059052045761224`\ \(c[29]\)[t] - 
            0.04864666724309928`\ \(c[30]\)[t] - 
            0.04125878107252025`\ \(c[31]\)[t] - 
            0.03225825116512552`\ \(c[32]\)[t] - 
            0.022068459300722043`\ \(c[33]\)[t] - 
            0.011153991006822649`\ \(c[34]\)[t] - 
            3.8981718325193755`*^-17\ \(c[35]\)[t] + 
            0.010908848347331966`\ \(c[36]\)[t] + 
            0.021108961070255627`\ \(c[37]\)[t] + 
            0.030177073670601236`\ \(c[38]\)[t] + 
            0.03774739544932687`\ \(c[39]\)[t] + 
            0.04352596542803616`\ \(c[40]\)[t] + 
            0.04730167054004106`\ \(c[41]\)[t] + 
            0.04895352855494272`\ \(c[42]\)[t] + 
            0.04845400275336168`\ \(c[43]\)[t] + 
            0.04586828658428231`\ \(c[44]\)[t] + 
            0.04134966715663448`\ \(c[45]\)[t] + 
            0.035131239329076656`\ \(c[46]\)[t] + 
            0.027514390699665887`\ \(c[47]\)[t] + 
            0.018854606004500233`\ \(c[48]\)[t] + 
            0.009545242303915543`\ \(c[49]\)[t] + 
            2.005337021455629`*^-16\ \(c[50]\)[t] - 
            0.009365143392520679`\ \(c[51]\)[t] - 
            0.018149760920219783`\ \(c[52]\)[t] - 
            0.02598581343857328`\ \(c[53]\)[t] - 
            0.032552799745291155`\ \(c[54]\)[t] - 
            0.037590606506031236`\ \(c[55]\)[t] - 
            0.040909552899494925`\ \(c[56]\)[t] - 
            0.04239725240919144`\ \(c[57]\)[t] - 
            0.042022055485216314`\ \(c[58]\)[t] - 
            0.039832985717929335`\ \(c[59]\)[t] - 
            0.03595623231011687`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -55, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -55]][ t]], 
          Plus[ 
            Times[ 0.82699334313268802, 
              c[ -60][ t]], 
            Times[ 0.88706379305918392, 
              c[ -59][ t]], 
            Times[ 0.93548928378863916, 
              c[ -58][ t]], 
            Times[ 0.9710122092317629, 
              c[ -57][ t]], 
            Times[ 0.99270519960720693, 
              c[ -56][ t]], 
            Times[ 67.345674029545123, 
              c[ -55][ t]], 
            Times[ 0.99270519960720693, 
              c[ -54][ t]], 
            Times[ 0.9710122092317629, 
              c[ -53][ t]], 
            Times[ 0.93548928378863916, 
              c[ -52][ t]], 
            Times[ 0.88706379305918392, 
              c[ -51][ t]], 
            Times[ 0.82699334313268802, 
              c[ -50][ t]], 
            Times[ 0.75682672864065692, 
              c[ -49][ t]], 
            Times[ 0.67835603854706361, 
              c[ -48][ t]], 
            Times[ 0.59356153372868015, 
              c[ -47][ t]], 
            Times[ 0.50455115242710469, 
              c[ -46][ t]], 
            Times[ 0.41349667156634429, 
              c[ -45][ t]], 
            Times[ 0.32256865202152113, 
              c[ -44][ t]], 
            Times[ 0.23387232094715985, 
              c[ -43][ t]], 
            Times[ 0.14938649372796384, 
              c[ -42][ t]], 
            Times[ 0.070907514257657456, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.062044074975450239, 
              c[ -39][ t]], 
            Times[ -0.11423673049785436, 
              c[ -38][ t]], 
            Times[ -0.15591488063143982, 
              c[ -37][ t]], 
            Times[ -0.18675027222298593, 
              c[ -36][ t]], 
            Times[ -0.206748335783172, 
              c[ -35][ t]], 
            Times[ -0.21623620818304484, 
              c[ -34][ t]], 
            Times[ -0.21584055771952015, 
              c[ -33][ t]], 
            Times[ -0.20645618564475843, 
              c[ -32][ t]], 
            Times[ -0.18920668216016426, 
              c[ -31][ t]], 
            Times[ -0.16539866862653771, 
              c[ -30][ t]], 
            Times[ -0.13647135277833605, 
              c[ -29][ t]], 
            Times[ -0.10394325375429328, 
              c[ -28][ t]], 
            Times[ -0.06935801494512607, 
              c[ -27][ t]], 
            Times[ -0.034231213779558949, 
              c[ -26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ 0.032022748374425904, 
              c[ -24][ t]], 
            Times[ 0.060688263076985105, 
              c[ -23][ t]], 
            Times[ 0.085044480344421705, 
              c[ -22][ t]], 
            Times[ 0.10436044624225685, 
              c[ -21][ t]], 
            Times[ 0.11814190616181255, 
              c[ -20][ t]], 
            Times[ 0.12613778810677614, 
              c[ -19][ t]], 
            Times[ 0.12833762891430928, 
              c[ -18][ t]], 
            Times[ 0.12496032289024853, 
              c[ -17][ t]], 
            Times[ 0.11643488132933186, 
              c[ -16][ t]], 
            Times[ 0.10337416789158609, 
              c[ -15][ t]], 
            Times[ 0.086542809078944891, 
              c[ -14][ t]], 
            Times[ 0.066820663127759972, 
              c[ -13][ t]], 
            Times[ 0.045163358568919301, 
              c[ -12][ t]], 
            Times[ 0.022561481809254869, 
              c[ -11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -10][ t]], 
            Times[ -0.021580547817547879, 
              c[ -9][ t]], 
            Times[ -0.04131966847794722, 
              c[ -8][ t]], 
            Times[ -0.058468080236789913, 
              c[ -7][ t]], 
            Times[ -0.072413370861974122, 
              c[ -6][ t]], 
            Times[ -0.082699334313268744, 
              c[ -5][ t]], 
            Times[ -0.089038438663606695, 
              c[ -4][ t]], 
            Times[ -0.091317159035181589, 
              c[ -3][ t]], 
            Times[ -0.089594193770366884, 
              c[ -2][ t]], 
            Times[ -0.084091858737850814, 
              c[ -1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 0][ t]], 
            Times[ -0.063361699504227528, 
              c[ 1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 2][ t]], 
            Times[ -0.033483179628681567, 
              c[ 3][ t]], 
            Times[ -0.016825511857749401, 
              c[ 4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ 0.016273855731265604, 
              c[ 6][ t]], 
            Times[ 0.031322974491347078, 
              c[ 7][ t]], 
            Times[ 0.044547108751839919, 
              c[ 8][ t]], 
            Times[ 0.055441487066198933, 
              c[ 9][ t]], 
            Times[ 0.063614872548668253, 
              c[ 10][ t]], 
            Times[ 0.068802429876423349, 
              c[ 11][ t]], 
            Times[ 0.070873018952678238, 
              c[ 12][ t]], 
            Times[ 0.069830768673962415, 
              c[ 13][ t]], 
            Times[ 0.065811019881796273, 
              c[ 14][ t]], 
            Times[ 0.059070953080906326, 
              c[ 15][ t]], 
            Times[ 0.049975424961080865, 
              c[ 16][ t]], 
            Times[ 0.03897872015785999, 
              c[ 17][ t]], 
            Times[ 0.026603074225527826, 
              c[ 18][ t]], 
            Times[ 0.013414935129827233, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ -0.013061910521147383, 
              c[ 21][ t]], 
            Times[ -0.025221096343682053, 
              c[ 22][ t]], 
            Times[ -0.035980357068793781, 
              c[ 23][ t]], 
            Times[ -0.044914622433376419, 
              c[ 24][ t]], 
            Times[ -0.05168708394579296, 
              c[ 25][ t]], 
            Times[ -0.056061239158567186, 
              c[ 26][ t]], 
            Times[ -0.057908442314993203, 
              c[ 27][ t]], 
            Times[ -0.057210750238908967, 
              c[ 28][ t]], 
            Times[ -0.054059052045761224, 
              c[ 29][ t]], 
            Times[ -0.048646667243099281, 
              c[ 30][ t]], 
            Times[ -0.041258781072520248, 
              c[ 31][ t]], 
            Times[ -0.032258251165125519, 
              c[ 32][ t]], 
            Times[ -0.022068459300722043, 
              c[ 33][ t]], 
            Times[ -0.011153991006822649, 
              c[ 34][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 35][ t]], 
            Times[ 0.010908848347331966, 
              c[ 36][ t]], 
            Times[ 0.021108961070255627, 
              c[ 37][ t]], 
            Times[ 0.030177073670601236, 
              c[ 38][ t]], 
            Times[ 0.03774739544932687, 
              c[ 39][ t]], 
            Times[ 0.043525965428036162, 
              c[ 40][ t]], 
            Times[ 0.047301670540041058, 
              c[ 41][ t]], 
            Times[ 0.04895352855494272, 
              c[ 42][ t]], 
            Times[ 0.048454002753361682, 
              c[ 43][ t]], 
            Times[ 0.045868286584282311, 
              c[ 44][ t]], 
            Times[ 0.041349667156634483, 
              c[ 45][ t]], 
            Times[ 0.035131239329076656, 
              c[ 46][ t]], 
            Times[ 0.027514390699665887, 
              c[ 47][ t]], 
            Times[ 0.018854606004500233, 
              c[ 48][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 49][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 50][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 51][ t]], 
            Times[ -0.018149760920219783, 
              c[ 52][ t]], 
            Times[ -0.025985813438573278, 
              c[ 53][ t]], 
            Times[ -0.032552799745291155, 
              c[ 54][ t]], 
            Times[ -0.037590606506031236, 
              c[ 55][ t]], 
            Times[ -0.040909552899494925, 
              c[ 56][ t]], 
            Times[ -0.042397252409191441, 
              c[ 57][ t]], 
            Times[ -0.042022055485216314, 
              c[ 58][ t]], 
            Times[ -0.039832985717929335, 
              c[ 59][ t]], 
            Times[ -0.035956232310116867, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-54\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-54\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.7568267286406569`\ \(c[\(-60\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-59\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-58\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-57\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-56\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-55\)]\)[t] + 
            64.95503651905904`\ \(c[\(-54\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-53\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-52\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-51\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-50\)]\)[t] + 
            0.826993343132688`\ \(c[\(-49\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-48\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-47\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-46\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-45\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-44\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-43\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-42\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-41\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-38\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-37\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-36\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-35\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-34\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-33\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-32\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-31\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-30\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-29\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-28\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-27\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-26\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-23\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-22\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-21\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-20\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-19\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-18\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-17\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-16\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-15\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-14\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-13\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-12\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-11\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-10\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-9\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-8\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-7\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-6\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-5\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-4\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-3\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-2\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-1\)]\)[t] - 
            0.08409185873785081`\ \(c[0]\)[t] - 
            0.0751812130120626`\ \(c[1]\)[t] - 
            0.0633616995042274`\ \(c[2]\)[t] - 
            0.04923627809413894`\ \(c[3]\)[t] - 
            0.03348317962868157`\ \(c[4]\)[t] - 
            0.016825511857749262`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.016273855731265604`\ \(c[7]\)[t] + 
            0.0313229744913472`\ \(c[8]\)[t] + 
            0.04454710875183992`\ \(c[9]\)[t] + 
            0.05544148706619893`\ \(c[10]\)[t] + 
            0.06361487254866825`\ \(c[11]\)[t] + 
            0.06880242987642335`\ \(c[12]\)[t] + 
            0.07087301895267824`\ \(c[13]\)[t] + 
            0.06983076867396242`\ \(c[14]\)[t] + 
            0.06581101988179627`\ \(c[15]\)[t] + 
            0.059070953080906326`\ \(c[16]\)[t] + 
            0.049975424961080865`\ \(c[17]\)[t] + 
            0.03897872015785999`\ \(c[18]\)[t] + 
            0.026603074225527826`\ \(c[19]\)[t] + 
            0.013414935129827233`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.013061910521147383`\ \(c[22]\)[t] - 
            0.025221096343682053`\ \(c[23]\)[t] - 
            0.03598035706879378`\ \(c[24]\)[t] - 
            0.04491462243337642`\ \(c[25]\)[t] - 
            0.05168708394579296`\ \(c[26]\)[t] - 
            0.056061239158567186`\ \(c[27]\)[t] - 
            0.0579084423149932`\ \(c[28]\)[t] - 
            0.05721075023890897`\ \(c[29]\)[t] - 
            0.054059052045761224`\ \(c[30]\)[t] - 
            0.04864666724309928`\ \(c[31]\)[t] - 
            0.04125878107252025`\ \(c[32]\)[t] - 
            0.03225825116512552`\ \(c[33]\)[t] - 
            0.022068459300722043`\ \(c[34]\)[t] - 
            0.011153991006822649`\ \(c[35]\)[t] - 
            3.8981718325193755`*^-17\ \(c[36]\)[t] + 
            0.010908848347331966`\ \(c[37]\)[t] + 
            0.021108961070255627`\ \(c[38]\)[t] + 
            0.030177073670601236`\ \(c[39]\)[t] + 
            0.03774739544932687`\ \(c[40]\)[t] + 
            0.04352596542803616`\ \(c[41]\)[t] + 
            0.04730167054004106`\ \(c[42]\)[t] + 
            0.04895352855494272`\ \(c[43]\)[t] + 
            0.04845400275336168`\ \(c[44]\)[t] + 
            0.045868286584282256`\ \(c[45]\)[t] + 
            0.04134966715663448`\ \(c[46]\)[t] + 
            0.035131239329076656`\ \(c[47]\)[t] + 
            0.027514390699665887`\ \(c[48]\)[t] + 
            0.018854606004500233`\ \(c[49]\)[t] + 
            0.009545242303915543`\ \(c[50]\)[t] + 
            3.8981718325193755`*^-17\ \(c[51]\)[t] - 
            0.009365143392520679`\ \(c[52]\)[t] - 
            0.018149760920219783`\ \(c[53]\)[t] - 
            0.02598581343857328`\ \(c[54]\)[t] - 
            0.032552799745291155`\ \(c[55]\)[t] - 
            0.037590606506031236`\ \(c[56]\)[t] - 
            0.040909552899494966`\ \(c[57]\)[t] - 
            0.04239725240919144`\ \(c[58]\)[t] - 
            0.042022055485216314`\ \(c[59]\)[t] - 
            0.039832985717929335`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -54, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -54]][ t]], 
          Plus[ 
            Times[ 0.75682672864065692, 
              c[ -60][ t]], 
            Times[ 0.82699334313268846, 
              c[ -59][ t]], 
            Times[ 0.88706379305918392, 
              c[ -58][ t]], 
            Times[ 0.93548928378863916, 
              c[ -57][ t]], 
            Times[ 0.9710122092317629, 
              c[ -56][ t]], 
            Times[ 0.99270519960720693, 
              c[ -55][ t]], 
            Times[ 64.955036519059036, 
              c[ -54][ t]], 
            Times[ 0.99270519960720671, 
              c[ -53][ t]], 
            Times[ 0.9710122092317629, 
              c[ -52][ t]], 
            Times[ 0.93548928378863916, 
              c[ -51][ t]], 
            Times[ 0.88706379305918348, 
              c[ -50][ t]], 
            Times[ 0.82699334313268802, 
              c[ -49][ t]], 
            Times[ 0.75682672864065692, 
              c[ -48][ t]], 
            Times[ 0.67835603854706272, 
              c[ -47][ t]], 
            Times[ 0.59356153372868015, 
              c[ -46][ t]], 
            Times[ 0.50455115242710469, 
              c[ -45][ t]], 
            Times[ 0.41349667156634362, 
              c[ -44][ t]], 
            Times[ 0.32256865202152113, 
              c[ -43][ t]], 
            Times[ 0.23387232094715985, 
              c[ -42][ t]], 
            Times[ 0.14938649372796314, 
              c[ -41][ t]], 
            Times[ 0.070907514257657456, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.062044074975450475, 
              c[ -38][ t]], 
            Times[ -0.11423673049785459, 
              c[ -37][ t]], 
            Times[ -0.15591488063143982, 
              c[ -36][ t]], 
            Times[ -0.18675027222298607, 
              c[ -35][ t]], 
            Times[ -0.20674833578317206, 
              c[ -34][ t]], 
            Times[ -0.21623620818304484, 
              c[ -33][ t]], 
            Times[ -0.21584055771952013, 
              c[ -32][ t]], 
            Times[ -0.20645618564475834, 
              c[ -31][ t]], 
            Times[ -0.18920668216016426, 
              c[ -30][ t]], 
            Times[ -0.1653986686265376, 
              c[ -29][ t]], 
            Times[ -0.13647135277833591, 
              c[ -28][ t]], 
            Times[ -0.10394325375429328, 
              c[ -27][ t]], 
            Times[ -0.069358014945125918, 
              c[ -26][ t]], 
            Times[ -0.034231213779558796, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.032022748374426029, 
              c[ -23][ t]], 
            Times[ 0.060688263076985223, 
              c[ -22][ t]], 
            Times[ 0.085044480344421705, 
              c[ -21][ t]], 
            Times[ 0.10436044624225692, 
              c[ -20][ t]], 
            Times[ 0.1181419061618126, 
              c[ -19][ t]], 
            Times[ 0.12613778810677614, 
              c[ -18][ t]], 
            Times[ 0.12833762891430925, 
              c[ -17][ t]], 
            Times[ 0.12496032289024847, 
              c[ -16][ t]], 
            Times[ 0.11643488132933186, 
              c[ -15][ t]], 
            Times[ 0.10337416789158595, 
              c[ -14][ t]], 
            Times[ 0.086542809078944752, 
              c[ -13][ t]], 
            Times[ 0.066820663127759972, 
              c[ -12][ t]], 
            Times[ 0.045163358568919114, 
              c[ -11][ t]], 
            Times[ 0.022561481809254675, 
              c[ -10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -9][ t]], 
            Times[ -0.021580547817547879, 
              c[ -8][ t]], 
            Times[ -0.041319668477947373, 
              c[ -7][ t]], 
            Times[ -0.058468080236789913, 
              c[ -6][ t]], 
            Times[ -0.072413370861974122, 
              c[ -5][ t]], 
            Times[ -0.082699334313268813, 
              c[ -4][ t]], 
            Times[ -0.089038438663606695, 
              c[ -3][ t]], 
            Times[ -0.091317159035181589, 
              c[ -2][ t]], 
            Times[ -0.089594193770366842, 
              c[ -1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 0][ t]], 
            Times[ -0.075181213012062598, 
              c[ 1][ t]], 
            Times[ -0.063361699504227403, 
              c[ 2][ t]], 
            Times[ -0.049236278094138941, 
              c[ 3][ t]], 
            Times[ -0.033483179628681567, 
              c[ 4][ t]], 
            Times[ -0.016825511857749262, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.016273855731265604, 
              c[ 7][ t]], 
            Times[ 0.031322974491347202, 
              c[ 8][ t]], 
            Times[ 0.044547108751839919, 
              c[ 9][ t]], 
            Times[ 0.055441487066198933, 
              c[ 10][ t]], 
            Times[ 0.063614872548668253, 
              c[ 11][ t]], 
            Times[ 0.068802429876423349, 
              c[ 12][ t]], 
            Times[ 0.070873018952678238, 
              c[ 13][ t]], 
            Times[ 0.069830768673962415, 
              c[ 14][ t]], 
            Times[ 0.065811019881796273, 
              c[ 15][ t]], 
            Times[ 0.059070953080906326, 
              c[ 16][ t]], 
            Times[ 0.049975424961080865, 
              c[ 17][ t]], 
            Times[ 0.03897872015785999, 
              c[ 18][ t]], 
            Times[ 0.026603074225527826, 
              c[ 19][ t]], 
            Times[ 0.013414935129827233, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.013061910521147383, 
              c[ 22][ t]], 
            Times[ -0.025221096343682053, 
              c[ 23][ t]], 
            Times[ -0.035980357068793781, 
              c[ 24][ t]], 
            Times[ -0.044914622433376419, 
              c[ 25][ t]], 
            Times[ -0.05168708394579296, 
              c[ 26][ t]], 
            Times[ -0.056061239158567186, 
              c[ 27][ t]], 
            Times[ -0.057908442314993203, 
              c[ 28][ t]], 
            Times[ -0.057210750238908967, 
              c[ 29][ t]], 
            Times[ -0.054059052045761224, 
              c[ 30][ t]], 
            Times[ -0.048646667243099281, 
              c[ 31][ t]], 
            Times[ -0.041258781072520248, 
              c[ 32][ t]], 
            Times[ -0.032258251165125519, 
              c[ 33][ t]], 
            Times[ -0.022068459300722043, 
              c[ 34][ t]], 
            Times[ -0.011153991006822649, 
              c[ 35][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 36][ t]], 
            Times[ 0.010908848347331966, 
              c[ 37][ t]], 
            Times[ 0.021108961070255627, 
              c[ 38][ t]], 
            Times[ 0.030177073670601236, 
              c[ 39][ t]], 
            Times[ 0.03774739544932687, 
              c[ 40][ t]], 
            Times[ 0.043525965428036162, 
              c[ 41][ t]], 
            Times[ 0.047301670540041058, 
              c[ 42][ t]], 
            Times[ 0.04895352855494272, 
              c[ 43][ t]], 
            Times[ 0.048454002753361682, 
              c[ 44][ t]], 
            Times[ 0.045868286584282256, 
              c[ 45][ t]], 
            Times[ 0.041349667156634483, 
              c[ 46][ t]], 
            Times[ 0.035131239329076656, 
              c[ 47][ t]], 
            Times[ 0.027514390699665887, 
              c[ 48][ t]], 
            Times[ 0.018854606004500233, 
              c[ 49][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 52][ t]], 
            Times[ -0.018149760920219783, 
              c[ 53][ t]], 
            Times[ -0.025985813438573278, 
              c[ 54][ t]], 
            Times[ -0.032552799745291155, 
              c[ 55][ t]], 
            Times[ -0.037590606506031236, 
              c[ 56][ t]], 
            Times[ -0.040909552899494966, 
              c[ 57][ t]], 
            Times[ -0.042397252409191441, 
              c[ 58][ t]], 
            Times[ -0.042022055485216314, 
              c[ 59][ t]], 
            Times[ -0.039832985717929335, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-53\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-53\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.6783560385470627`\ \(c[\(-60\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-59\)]\)[t] + 
            0.826993343132688`\ \(c[\(-58\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-57\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-56\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-55\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-54\)]\)[t] + 
            62.60826391702222`\ \(c[\(-53\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-52\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-51\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-50\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-49\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-48\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-47\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-46\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-45\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-44\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-43\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-42\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-41\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-40\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-39\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-38\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-37\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-36\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-35\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-34\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-33\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-32\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-31\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-30\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-29\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-28\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-27\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-26\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-25\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-24\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-23\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-22\)]\)[t] + 
            0.060688263076985`\ \(c[\(-21\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-20\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-19\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-18\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-17\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-16\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-15\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-14\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-13\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-12\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-11\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-10\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-9\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-8\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-7\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-6\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-5\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-4\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-3\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-2\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-1\)]\)[t] - 
            0.08959419377036688`\ \(c[0]\)[t] - 
            0.08409185873785086`\ \(c[1]\)[t] - 
            0.0751812130120626`\ \(c[2]\)[t] - 
            0.06336169950422753`\ \(c[3]\)[t] - 
            0.049236278094139066`\ \(c[4]\)[t] - 
            0.03348317962868157`\ \(c[5]\)[t] - 
            0.0168255118577494`\ \(c[6]\)[t] - 
            1.8033970416801674`*^-16\ \(c[7]\)[t] + 
            0.016273855731265604`\ \(c[8]\)[t] + 
            0.03132297449134708`\ \(c[9]\)[t] + 
            0.044547108751839815`\ \(c[10]\)[t] + 
            0.055441487066198857`\ \(c[11]\)[t] + 
            0.06361487254866825`\ \(c[12]\)[t] + 
            0.06880242987642332`\ \(c[13]\)[t] + 
            0.07087301895267824`\ \(c[14]\)[t] + 
            0.06983076867396242`\ \(c[15]\)[t] + 
            0.06581101988179631`\ \(c[16]\)[t] + 
            0.0590709530809064`\ \(c[17]\)[t] + 
            0.049975424961080865`\ \(c[18]\)[t] + 
            0.03897872015786009`\ \(c[19]\)[t] + 
            0.026603074225527937`\ \(c[20]\)[t] + 
            0.013414935129827233`\ \(c[21]\)[t] + 
            1.5206810699945212`*^-16\ \(c[22]\)[t] - 
            0.013061910521147276`\ \(c[23]\)[t] - 
            0.025221096343682053`\ \(c[24]\)[t] - 
            0.03598035706879378`\ \(c[25]\)[t] - 
            0.04491462243337629`\ \(c[26]\)[t] - 
            0.05168708394579296`\ \(c[27]\)[t] - 
            0.05606123915856713`\ \(c[28]\)[t] - 
            0.0579084423149932`\ \(c[29]\)[t] - 
            0.05721075023890897`\ \(c[30]\)[t] - 
            0.054059052045761224`\ \(c[31]\)[t] - 
            0.0486466672430994`\ \(c[32]\)[t] - 
            0.04125878107252025`\ \(c[33]\)[t] - 
            0.03225825116512568`\ \(c[34]\)[t] - 
            0.022068459300722043`\ \(c[35]\)[t] - 
            0.011153991006822649`\ \(c[36]\)[t] - 
            3.8981718325193755`*^-17\ \(c[37]\)[t] + 
            0.010908848347331785`\ \(c[38]\)[t] + 
            0.021108961070255627`\ \(c[39]\)[t] + 
            0.030177073670601094`\ \(c[40]\)[t] + 
            0.03774739544932687`\ \(c[41]\)[t] + 
            0.04352596542803616`\ \(c[42]\)[t] + 
            0.04730167054004106`\ \(c[43]\)[t] + 
            0.0489535285549427`\ \(c[44]\)[t] + 
            0.04845400275336168`\ \(c[45]\)[t] + 
            0.04586828658428231`\ \(c[46]\)[t] + 
            0.04134966715663448`\ \(c[47]\)[t] + 
            0.035131239329076656`\ \(c[48]\)[t] + 
            0.027514390699665887`\ \(c[49]\)[t] + 
            0.01885460600450039`\ \(c[50]\)[t] + 
            0.009545242303915543`\ \(c[51]\)[t] + 
            2.005337021455629`*^-16\ \(c[52]\)[t] - 
            0.009365143392520679`\ \(c[53]\)[t] - 
            0.018149760920219783`\ \(c[54]\)[t] - 
            0.02598581343857328`\ \(c[55]\)[t] - 
            0.03255279974529105`\ \(c[56]\)[t] - 
            0.037590606506031236`\ \(c[57]\)[t] - 
            0.040909552899494925`\ \(c[58]\)[t] - 
            0.04239725240919144`\ \(c[59]\)[t] - 
            0.042022055485216314`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -53, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -53]][ t]], 
          Plus[ 
            Times[ 0.67835603854706272, 
              c[ -60][ t]], 
            Times[ 0.75682672864065692, 
              c[ -59][ t]], 
            Times[ 0.82699334313268802, 
              c[ -58][ t]], 
            Times[ 0.88706379305918348, 
              c[ -57][ t]], 
            Times[ 0.93548928378863916, 
              c[ -56][ t]], 
            Times[ 0.9710122092317629, 
              c[ -55][ t]], 
            Times[ 0.99270519960720671, 
              c[ -54][ t]], 
            Times[ 62.608263917022221, 
              c[ -53][ t]], 
            Times[ 0.99270519960720693, 
              c[ -52][ t]], 
            Times[ 0.9710122092317629, 
              c[ -51][ t]], 
            Times[ 0.93548928378863916, 
              c[ -50][ t]], 
            Times[ 0.88706379305918392, 
              c[ -49][ t]], 
            Times[ 0.82699334313268846, 
              c[ -48][ t]], 
            Times[ 0.75682672864065692, 
              c[ -47][ t]], 
            Times[ 0.67835603854706361, 
              c[ -46][ t]], 
            Times[ 0.59356153372868092, 
              c[ -45][ t]], 
            Times[ 0.50455115242710469, 
              c[ -44][ t]], 
            Times[ 0.41349667156634429, 
              c[ -43][ t]], 
            Times[ 0.32256865202152191, 
              c[ -42][ t]], 
            Times[ 0.23387232094715985, 
              c[ -41][ t]], 
            Times[ 0.14938649372796384, 
              c[ -40][ t]], 
            Times[ 0.070907514257658094, 
              c[ -39][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -38][ t]], 
            Times[ -0.062044074975450239, 
              c[ -37][ t]], 
            Times[ -0.11423673049785416, 
              c[ -36][ t]], 
            Times[ -0.15591488063143966, 
              c[ -35][ t]], 
            Times[ -0.18675027222298593, 
              c[ -34][ t]], 
            Times[ -0.20674833578317189, 
              c[ -33][ t]], 
            Times[ -0.21623620818304481, 
              c[ -32][ t]], 
            Times[ -0.21584055771952015, 
              c[ -31][ t]], 
            Times[ -0.20645618564475848, 
              c[ -30][ t]], 
            Times[ -0.18920668216016434, 
              c[ -29][ t]], 
            Times[ -0.16539866862653771, 
              c[ -28][ t]], 
            Times[ -0.13647135277833616, 
              c[ -27][ t]], 
            Times[ -0.1039432537542934, 
              c[ -26][ t]], 
            Times[ -0.06935801494512607, 
              c[ -25][ t]], 
            Times[ -0.034231213779559094, 
              c[ -24][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -23][ t]], 
            Times[ 0.032022748374425904, 
              c[ -22][ t]], 
            Times[ 0.060688263076985001, 
              c[ -21][ t]], 
            Times[ 0.085044480344421608, 
              c[ -20][ t]], 
            Times[ 0.10436044624225685, 
              c[ -19][ t]], 
            Times[ 0.11814190616181253, 
              c[ -18][ t]], 
            Times[ 0.12613778810677612, 
              c[ -17][ t]], 
            Times[ 0.12833762891430928, 
              c[ -16][ t]], 
            Times[ 0.12496032289024853, 
              c[ -15][ t]], 
            Times[ 0.11643488132933186, 
              c[ -14][ t]], 
            Times[ 0.10337416789158609, 
              c[ -13][ t]], 
            Times[ 0.086542809078944891, 
              c[ -12][ t]], 
            Times[ 0.066820663127759972, 
              c[ -11][ t]], 
            Times[ 0.045163358568919301, 
              c[ -10][ t]], 
            Times[ 0.022561481809254869, 
              c[ -9][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -8][ t]], 
            Times[ -0.021580547817547879, 
              c[ -7][ t]], 
            Times[ -0.04131966847794722, 
              c[ -6][ t]], 
            Times[ -0.058468080236789774, 
              c[ -5][ t]], 
            Times[ -0.072413370861974122, 
              c[ -4][ t]], 
            Times[ -0.082699334313268744, 
              c[ -3][ t]], 
            Times[ -0.089038438663606653, 
              c[ -2][ t]], 
            Times[ -0.091317159035181589, 
              c[ -1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 0][ t]], 
            Times[ -0.084091858737850855, 
              c[ 1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 2][ t]], 
            Times[ -0.063361699504227528, 
              c[ 3][ t]], 
            Times[ -0.049236278094139066, 
              c[ 4][ t]], 
            Times[ -0.033483179628681567, 
              c[ 5][ t]], 
            Times[ -0.016825511857749401, 
              c[ 6][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 7][ t]], 
            Times[ 0.016273855731265604, 
              c[ 8][ t]], 
            Times[ 0.031322974491347078, 
              c[ 9][ t]], 
            Times[ 0.044547108751839815, 
              c[ 10][ t]], 
            Times[ 0.055441487066198857, 
              c[ 11][ t]], 
            Times[ 0.063614872548668253, 
              c[ 12][ t]], 
            Times[ 0.068802429876423321, 
              c[ 13][ t]], 
            Times[ 0.070873018952678238, 
              c[ 14][ t]], 
            Times[ 0.069830768673962415, 
              c[ 15][ t]], 
            Times[ 0.065811019881796315, 
              c[ 16][ t]], 
            Times[ 0.059070953080906402, 
              c[ 17][ t]], 
            Times[ 0.049975424961080865, 
              c[ 18][ t]], 
            Times[ 0.038978720157860088, 
              c[ 19][ t]], 
            Times[ 0.026603074225527937, 
              c[ 20][ t]], 
            Times[ 0.013414935129827233, 
              c[ 21][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 22][ t]], 
            Times[ -0.013061910521147276, 
              c[ 23][ t]], 
            Times[ -0.025221096343682053, 
              c[ 24][ t]], 
            Times[ -0.035980357068793781, 
              c[ 25][ t]], 
            Times[ -0.044914622433376288, 
              c[ 26][ t]], 
            Times[ -0.05168708394579296, 
              c[ 27][ t]], 
            Times[ -0.05606123915856713, 
              c[ 28][ t]], 
            Times[ -0.057908442314993203, 
              c[ 29][ t]], 
            Times[ -0.057210750238908967, 
              c[ 30][ t]], 
            Times[ -0.054059052045761224, 
              c[ 31][ t]], 
            Times[ -0.048646667243099399, 
              c[ 32][ t]], 
            Times[ -0.041258781072520248, 
              c[ 33][ t]], 
            Times[ -0.032258251165125679, 
              c[ 34][ t]], 
            Times[ -0.022068459300722043, 
              c[ 35][ t]], 
            Times[ -0.011153991006822649, 
              c[ 36][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 37][ t]], 
            Times[ 0.010908848347331785, 
              c[ 38][ t]], 
            Times[ 0.021108961070255627, 
              c[ 39][ t]], 
            Times[ 0.030177073670601094, 
              c[ 40][ t]], 
            Times[ 0.03774739544932687, 
              c[ 41][ t]], 
            Times[ 0.043525965428036162, 
              c[ 42][ t]], 
            Times[ 0.047301670540041058, 
              c[ 43][ t]], 
            Times[ 0.048953528554942699, 
              c[ 44][ t]], 
            Times[ 0.048454002753361682, 
              c[ 45][ t]], 
            Times[ 0.045868286584282311, 
              c[ 46][ t]], 
            Times[ 0.041349667156634483, 
              c[ 47][ t]], 
            Times[ 0.035131239329076656, 
              c[ 48][ t]], 
            Times[ 0.027514390699665887, 
              c[ 49][ t]], 
            Times[ 0.018854606004500389, 
              c[ 50][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 51][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 52][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 53][ t]], 
            Times[ -0.018149760920219783, 
              c[ 54][ t]], 
            Times[ -0.025985813438573278, 
              c[ 55][ t]], 
            Times[ -0.032552799745291051, 
              c[ 56][ t]], 
            Times[ -0.037590606506031236, 
              c[ 57][ t]], 
            Times[ -0.040909552899494925, 
              c[ 58][ t]], 
            Times[ -0.042397252409191441, 
              c[ 59][ t]], 
            Times[ -0.042022055485216314, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-52\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-52\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.5935615337286801`\ \(c[\(-60\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-59\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-58\)]\)[t] + 
            0.826993343132688`\ \(c[\(-57\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-56\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-55\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-54\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-53\)]\)[t] + 
            60.305356223434714`\ \(c[\(-52\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-51\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-50\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-49\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-48\)]\)[t] + 
            0.826993343132688`\ \(c[\(-47\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-46\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-45\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-44\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-43\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-42\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-41\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-40\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-39\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-36\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-35\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-34\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-33\)]\)[t] - 
            0.206748335783172`\ \(c[\(-32\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-31\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-30\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-29\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-28\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-27\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-26\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-25\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-24\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-23\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-21\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-20\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-19\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-18\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-17\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-16\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-15\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-14\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-13\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-12\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-11\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-10\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-9\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-8\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-7\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-6\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-5\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-4\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-3\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-2\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-1\)]\)[t] - 
            0.09131715903518159`\ \(c[0]\)[t] - 
            0.08959419377036688`\ \(c[1]\)[t] - 
            0.08409185873785081`\ \(c[2]\)[t] - 
            0.0751812130120626`\ \(c[3]\)[t] - 
            0.06336169950422753`\ \(c[4]\)[t] - 
            0.04923627809413894`\ \(c[5]\)[t] - 
            0.03348317962868157`\ \(c[6]\)[t] - 
            0.0168255118577494`\ \(c[7]\)[t] - 
            3.898171832519376`*^-17\ \(c[8]\)[t] + 
            0.016273855731265604`\ \(c[9]\)[t] + 
            0.03132297449134708`\ \(c[10]\)[t] + 
            0.04454710875183992`\ \(c[11]\)[t] + 
            0.05544148706619893`\ \(c[12]\)[t] + 
            0.06361487254866825`\ \(c[13]\)[t] + 
            0.06880242987642335`\ \(c[14]\)[t] + 
            0.07087301895267824`\ \(c[15]\)[t] + 
            0.06983076867396242`\ \(c[16]\)[t] + 
            0.06581101988179627`\ \(c[17]\)[t] + 
            0.059070953080906326`\ \(c[18]\)[t] + 
            0.049975424961080865`\ \(c[19]\)[t] + 
            0.03897872015785999`\ \(c[20]\)[t] + 
            0.026603074225527826`\ \(c[21]\)[t] + 
            0.013414935129827233`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] - 
            0.013061910521147383`\ \(c[24]\)[t] - 
            0.025221096343682053`\ \(c[25]\)[t] - 
            0.03598035706879378`\ \(c[26]\)[t] - 
            0.04491462243337642`\ \(c[27]\)[t] - 
            0.05168708394579296`\ \(c[28]\)[t] - 
            0.056061239158567186`\ \(c[29]\)[t] - 
            0.0579084423149932`\ \(c[30]\)[t] - 
            0.05721075023890897`\ \(c[31]\)[t] - 
            0.054059052045761224`\ \(c[32]\)[t] - 
            0.04864666724309928`\ \(c[33]\)[t] - 
            0.04125878107252025`\ \(c[34]\)[t] - 
            0.03225825116512552`\ \(c[35]\)[t] - 
            0.022068459300722043`\ \(c[36]\)[t] - 
            0.011153991006822649`\ \(c[37]\)[t] - 
            3.8981718325193755`*^-17\ \(c[38]\)[t] + 
            0.010908848347331966`\ \(c[39]\)[t] + 
            0.021108961070255627`\ \(c[40]\)[t] + 
            0.030177073670601094`\ \(c[41]\)[t] + 
            0.03774739544932687`\ \(c[42]\)[t] + 
            0.04352596542803616`\ \(c[43]\)[t] + 
            0.04730167054004106`\ \(c[44]\)[t] + 
            0.04895352855494272`\ \(c[45]\)[t] + 
            0.04845400275336168`\ \(c[46]\)[t] + 
            0.04586828658428231`\ \(c[47]\)[t] + 
            0.04134966715663448`\ \(c[48]\)[t] + 
            0.035131239329076656`\ \(c[49]\)[t] + 
            0.027514390699665887`\ \(c[50]\)[t] + 
            0.018854606004500233`\ \(c[51]\)[t] + 
            0.009545242303915543`\ \(c[52]\)[t] + 
            2.005337021455629`*^-16\ \(c[53]\)[t] - 
            0.009365143392520679`\ \(c[54]\)[t] - 
            0.018149760920219783`\ \(c[55]\)[t] - 
            0.02598581343857328`\ \(c[56]\)[t] - 
            0.032552799745291155`\ \(c[57]\)[t] - 
            0.037590606506031236`\ \(c[58]\)[t] - 
            0.040909552899494925`\ \(c[59]\)[t] - 
            0.04239725240919144`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -52, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -52]][ t]], 
          Plus[ 
            Times[ 0.59356153372868015, 
              c[ -60][ t]], 
            Times[ 0.67835603854706361, 
              c[ -59][ t]], 
            Times[ 0.75682672864065692, 
              c[ -58][ t]], 
            Times[ 0.82699334313268802, 
              c[ -57][ t]], 
            Times[ 0.88706379305918392, 
              c[ -56][ t]], 
            Times[ 0.93548928378863916, 
              c[ -55][ t]], 
            Times[ 0.9710122092317629, 
              c[ -54][ t]], 
            Times[ 0.99270519960720693, 
              c[ -53][ t]], 
            Times[ 60.305356223434714, 
              c[ -52][ t]], 
            Times[ 0.99270519960720693, 
              c[ -51][ t]], 
            Times[ 0.9710122092317629, 
              c[ -50][ t]], 
            Times[ 0.93548928378863916, 
              c[ -49][ t]], 
            Times[ 0.88706379305918392, 
              c[ -48][ t]], 
            Times[ 0.82699334313268802, 
              c[ -47][ t]], 
            Times[ 0.75682672864065692, 
              c[ -46][ t]], 
            Times[ 0.67835603854706361, 
              c[ -45][ t]], 
            Times[ 0.59356153372868015, 
              c[ -44][ t]], 
            Times[ 0.50455115242710469, 
              c[ -43][ t]], 
            Times[ 0.41349667156634429, 
              c[ -42][ t]], 
            Times[ 0.32256865202152113, 
              c[ -41][ t]], 
            Times[ 0.23387232094715985, 
              c[ -40][ t]], 
            Times[ 0.14938649372796384, 
              c[ -39][ t]], 
            Times[ 0.070907514257657775, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.062044074975450239, 
              c[ -36][ t]], 
            Times[ -0.11423673049785436, 
              c[ -35][ t]], 
            Times[ -0.15591488063143982, 
              c[ -34][ t]], 
            Times[ -0.18675027222298593, 
              c[ -33][ t]], 
            Times[ -0.206748335783172, 
              c[ -32][ t]], 
            Times[ -0.21623620818304484, 
              c[ -31][ t]], 
            Times[ -0.21584055771952015, 
              c[ -30][ t]], 
            Times[ -0.20645618564475843, 
              c[ -29][ t]], 
            Times[ -0.18920668216016426, 
              c[ -28][ t]], 
            Times[ -0.16539866862653771, 
              c[ -27][ t]], 
            Times[ -0.13647135277833605, 
              c[ -26][ t]], 
            Times[ -0.10394325375429328, 
              c[ -25][ t]], 
            Times[ -0.06935801494512607, 
              c[ -24][ t]], 
            Times[ -0.034231213779558949, 
              c[ -23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ 0.032022748374425904, 
              c[ -21][ t]], 
            Times[ 0.060688263076985105, 
              c[ -20][ t]], 
            Times[ 0.085044480344421705, 
              c[ -19][ t]], 
            Times[ 0.10436044624225685, 
              c[ -18][ t]], 
            Times[ 0.11814190616181255, 
              c[ -17][ t]], 
            Times[ 0.12613778810677614, 
              c[ -16][ t]], 
            Times[ 0.12833762891430928, 
              c[ -15][ t]], 
            Times[ 0.12496032289024853, 
              c[ -14][ t]], 
            Times[ 0.11643488132933186, 
              c[ -13][ t]], 
            Times[ 0.10337416789158609, 
              c[ -12][ t]], 
            Times[ 0.086542809078944891, 
              c[ -11][ t]], 
            Times[ 0.066820663127759972, 
              c[ -10][ t]], 
            Times[ 0.045163358568919301, 
              c[ -9][ t]], 
            Times[ 0.022561481809254869, 
              c[ -8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -7][ t]], 
            Times[ -0.021580547817547879, 
              c[ -6][ t]], 
            Times[ -0.04131966847794722, 
              c[ -5][ t]], 
            Times[ -0.058468080236789913, 
              c[ -4][ t]], 
            Times[ -0.072413370861974122, 
              c[ -3][ t]], 
            Times[ -0.082699334313268744, 
              c[ -2][ t]], 
            Times[ -0.089038438663606695, 
              c[ -1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 0][ t]], 
            Times[ -0.089594193770366884, 
              c[ 1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 2][ t]], 
            Times[ -0.075181213012062598, 
              c[ 3][ t]], 
            Times[ -0.063361699504227528, 
              c[ 4][ t]], 
            Times[ -0.049236278094138941, 
              c[ 5][ t]], 
            Times[ -0.033483179628681567, 
              c[ 6][ t]], 
            Times[ -0.016825511857749401, 
              c[ 7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ 0.016273855731265604, 
              c[ 9][ t]], 
            Times[ 0.031322974491347078, 
              c[ 10][ t]], 
            Times[ 0.044547108751839919, 
              c[ 11][ t]], 
            Times[ 0.055441487066198933, 
              c[ 12][ t]], 
            Times[ 0.063614872548668253, 
              c[ 13][ t]], 
            Times[ 0.068802429876423349, 
              c[ 14][ t]], 
            Times[ 0.070873018952678238, 
              c[ 15][ t]], 
            Times[ 0.069830768673962415, 
              c[ 16][ t]], 
            Times[ 0.065811019881796273, 
              c[ 17][ t]], 
            Times[ 0.059070953080906326, 
              c[ 18][ t]], 
            Times[ 0.049975424961080865, 
              c[ 19][ t]], 
            Times[ 0.03897872015785999, 
              c[ 20][ t]], 
            Times[ 0.026603074225527826, 
              c[ 21][ t]], 
            Times[ 0.013414935129827233, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ -0.013061910521147383, 
              c[ 24][ t]], 
            Times[ -0.025221096343682053, 
              c[ 25][ t]], 
            Times[ -0.035980357068793781, 
              c[ 26][ t]], 
            Times[ -0.044914622433376419, 
              c[ 27][ t]], 
            Times[ -0.05168708394579296, 
              c[ 28][ t]], 
            Times[ -0.056061239158567186, 
              c[ 29][ t]], 
            Times[ -0.057908442314993203, 
              c[ 30][ t]], 
            Times[ -0.057210750238908967, 
              c[ 31][ t]], 
            Times[ -0.054059052045761224, 
              c[ 32][ t]], 
            Times[ -0.048646667243099281, 
              c[ 33][ t]], 
            Times[ -0.041258781072520248, 
              c[ 34][ t]], 
            Times[ -0.032258251165125519, 
              c[ 35][ t]], 
            Times[ -0.022068459300722043, 
              c[ 36][ t]], 
            Times[ -0.011153991006822649, 
              c[ 37][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 38][ t]], 
            Times[ 0.010908848347331966, 
              c[ 39][ t]], 
            Times[ 0.021108961070255627, 
              c[ 40][ t]], 
            Times[ 0.030177073670601094, 
              c[ 41][ t]], 
            Times[ 0.03774739544932687, 
              c[ 42][ t]], 
            Times[ 0.043525965428036162, 
              c[ 43][ t]], 
            Times[ 0.047301670540041058, 
              c[ 44][ t]], 
            Times[ 0.04895352855494272, 
              c[ 45][ t]], 
            Times[ 0.048454002753361682, 
              c[ 46][ t]], 
            Times[ 0.045868286584282311, 
              c[ 47][ t]], 
            Times[ 0.041349667156634483, 
              c[ 48][ t]], 
            Times[ 0.035131239329076656, 
              c[ 49][ t]], 
            Times[ 0.027514390699665887, 
              c[ 50][ t]], 
            Times[ 0.018854606004500233, 
              c[ 51][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 52][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 53][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 54][ t]], 
            Times[ -0.018149760920219783, 
              c[ 55][ t]], 
            Times[ -0.025985813438573278, 
              c[ 56][ t]], 
            Times[ -0.032552799745291155, 
              c[ 57][ t]], 
            Times[ -0.037590606506031236, 
              c[ 58][ t]], 
            Times[ -0.040909552899494925, 
              c[ 59][ t]], 
            Times[ -0.042397252409191441, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-51\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-51\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.5045511524271047`\ \(c[\(-60\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-59\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-58\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-57\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-56\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-55\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-54\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-53\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-52\)]\)[t] + 
            58.04631343829649`\ \(c[\(-51\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-50\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-49\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-48\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-47\)]\)[t] + 
            0.826993343132688`\ \(c[\(-46\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-45\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-44\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-43\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-42\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-41\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-40\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-39\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-38\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-35\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-34\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-33\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-32\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-31\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-30\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-29\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-28\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-27\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-26\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-25\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-24\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-23\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-20\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-19\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-18\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-17\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-16\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-15\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-14\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-13\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-12\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-11\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-10\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-9\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-8\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-7\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-6\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-5\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-4\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-3\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-2\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-1\)]\)[t] - 
            0.0890384386636067`\ \(c[0]\)[t] - 
            0.09131715903518159`\ \(c[1]\)[t] - 
            0.08959419377036684`\ \(c[2]\)[t] - 
            0.08409185873785081`\ \(c[3]\)[t] - 
            0.0751812130120626`\ \(c[4]\)[t] - 
            0.0633616995042274`\ \(c[5]\)[t] - 
            0.04923627809413894`\ \(c[6]\)[t] - 
            0.03348317962868157`\ \(c[7]\)[t] - 
            0.016825511857749262`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.016273855731265604`\ \(c[10]\)[t] + 
            0.03132297449134708`\ \(c[11]\)[t] + 
            0.04454710875183992`\ \(c[12]\)[t] + 
            0.05544148706619893`\ \(c[13]\)[t] + 
            0.06361487254866825`\ \(c[14]\)[t] + 
            0.06880242987642335`\ \(c[15]\)[t] + 
            0.07087301895267824`\ \(c[16]\)[t] + 
            0.06983076867396242`\ \(c[17]\)[t] + 
            0.06581101988179627`\ \(c[18]\)[t] + 
            0.059070953080906326`\ \(c[19]\)[t] + 
            0.049975424961080865`\ \(c[20]\)[t] + 
            0.03897872015785999`\ \(c[21]\)[t] + 
            0.026603074225527826`\ \(c[22]\)[t] + 
            0.013414935129827233`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.013061910521147383`\ \(c[25]\)[t] - 
            0.025221096343682053`\ \(c[26]\)[t] - 
            0.03598035706879378`\ \(c[27]\)[t] - 
            0.04491462243337642`\ \(c[28]\)[t] - 
            0.05168708394579296`\ \(c[29]\)[t] - 
            0.056061239158567186`\ \(c[30]\)[t] - 
            0.0579084423149932`\ \(c[31]\)[t] - 
            0.05721075023890897`\ \(c[32]\)[t] - 
            0.054059052045761224`\ \(c[33]\)[t] - 
            0.04864666724309928`\ \(c[34]\)[t] - 
            0.04125878107252025`\ \(c[35]\)[t] - 
            0.03225825116512552`\ \(c[36]\)[t] - 
            0.022068459300722043`\ \(c[37]\)[t] - 
            0.011153991006822649`\ \(c[38]\)[t] - 
            3.8981718325193755`*^-17\ \(c[39]\)[t] + 
            0.010908848347331966`\ \(c[40]\)[t] + 
            0.021108961070255627`\ \(c[41]\)[t] + 
            0.030177073670601236`\ \(c[42]\)[t] + 
            0.03774739544932687`\ \(c[43]\)[t] + 
            0.04352596542803616`\ \(c[44]\)[t] + 
            0.04730167054004106`\ \(c[45]\)[t] + 
            0.04895352855494272`\ \(c[46]\)[t] + 
            0.04845400275336168`\ \(c[47]\)[t] + 
            0.045868286584282256`\ \(c[48]\)[t] + 
            0.04134966715663448`\ \(c[49]\)[t] + 
            0.035131239329076656`\ \(c[50]\)[t] + 
            0.027514390699665887`\ \(c[51]\)[t] + 
            0.018854606004500233`\ \(c[52]\)[t] + 
            0.009545242303915543`\ \(c[53]\)[t] + 
            3.8981718325193755`*^-17\ \(c[54]\)[t] - 
            0.009365143392520679`\ \(c[55]\)[t] - 
            0.018149760920219783`\ \(c[56]\)[t] - 
            0.02598581343857328`\ \(c[57]\)[t] - 
            0.032552799745291155`\ \(c[58]\)[t] - 
            0.037590606506031236`\ \(c[59]\)[t] - 
            0.040909552899494966`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -51, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -51]][ t]], 
          Plus[ 
            Times[ 0.50455115242710469, 
              c[ -60][ t]], 
            Times[ 0.59356153372868092, 
              c[ -59][ t]], 
            Times[ 0.67835603854706361, 
              c[ -58][ t]], 
            Times[ 0.75682672864065692, 
              c[ -57][ t]], 
            Times[ 0.82699334313268846, 
              c[ -56][ t]], 
            Times[ 0.88706379305918392, 
              c[ -55][ t]], 
            Times[ 0.93548928378863916, 
              c[ -54][ t]], 
            Times[ 0.9710122092317629, 
              c[ -53][ t]], 
            Times[ 0.99270519960720693, 
              c[ -52][ t]], 
            Times[ 58.046313438296487, 
              c[ -51][ t]], 
            Times[ 0.99270519960720671, 
              c[ -50][ t]], 
            Times[ 0.9710122092317629, 
              c[ -49][ t]], 
            Times[ 0.93548928378863916, 
              c[ -48][ t]], 
            Times[ 0.88706379305918348, 
              c[ -47][ t]], 
            Times[ 0.82699334313268802, 
              c[ -46][ t]], 
            Times[ 0.75682672864065692, 
              c[ -45][ t]], 
            Times[ 0.67835603854706272, 
              c[ -44][ t]], 
            Times[ 0.59356153372868015, 
              c[ -43][ t]], 
            Times[ 0.50455115242710469, 
              c[ -42][ t]], 
            Times[ 0.41349667156634362, 
              c[ -41][ t]], 
            Times[ 0.32256865202152113, 
              c[ -40][ t]], 
            Times[ 0.23387232094715985, 
              c[ -39][ t]], 
            Times[ 0.14938649372796345, 
              c[ -38][ t]], 
            Times[ 0.070907514257657456, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.062044074975450475, 
              c[ -35][ t]], 
            Times[ -0.11423673049785459, 
              c[ -34][ t]], 
            Times[ -0.15591488063143982, 
              c[ -33][ t]], 
            Times[ -0.18675027222298607, 
              c[ -32][ t]], 
            Times[ -0.20674833578317206, 
              c[ -31][ t]], 
            Times[ -0.21623620818304484, 
              c[ -30][ t]], 
            Times[ -0.21584055771952013, 
              c[ -29][ t]], 
            Times[ -0.20645618564475834, 
              c[ -28][ t]], 
            Times[ -0.18920668216016426, 
              c[ -27][ t]], 
            Times[ -0.1653986686265376, 
              c[ -26][ t]], 
            Times[ -0.13647135277833591, 
              c[ -25][ t]], 
            Times[ -0.10394325375429328, 
              c[ -24][ t]], 
            Times[ -0.069358014945125918, 
              c[ -23][ t]], 
            Times[ -0.034231213779558796, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.032022748374426029, 
              c[ -20][ t]], 
            Times[ 0.060688263076985223, 
              c[ -19][ t]], 
            Times[ 0.085044480344421705, 
              c[ -18][ t]], 
            Times[ 0.10436044624225692, 
              c[ -17][ t]], 
            Times[ 0.1181419061618126, 
              c[ -16][ t]], 
            Times[ 0.12613778810677614, 
              c[ -15][ t]], 
            Times[ 0.12833762891430925, 
              c[ -14][ t]], 
            Times[ 0.12496032289024847, 
              c[ -13][ t]], 
            Times[ 0.11643488132933186, 
              c[ -12][ t]], 
            Times[ 0.10337416789158595, 
              c[ -11][ t]], 
            Times[ 0.086542809078944752, 
              c[ -10][ t]], 
            Times[ 0.066820663127759972, 
              c[ -9][ t]], 
            Times[ 0.045163358568919301, 
              c[ -8][ t]], 
            Times[ 0.022561481809254675, 
              c[ -7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -6][ t]], 
            Times[ -0.021580547817547879, 
              c[ -5][ t]], 
            Times[ -0.041319668477947373, 
              c[ -4][ t]], 
            Times[ -0.058468080236789913, 
              c[ -3][ t]], 
            Times[ -0.072413370861974122, 
              c[ -2][ t]], 
            Times[ -0.082699334313268813, 
              c[ -1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 0][ t]], 
            Times[ -0.091317159035181589, 
              c[ 1][ t]], 
            Times[ -0.089594193770366842, 
              c[ 2][ t]], 
            Times[ -0.084091858737850814, 
              c[ 3][ t]], 
            Times[ -0.075181213012062598, 
              c[ 4][ t]], 
            Times[ -0.063361699504227403, 
              c[ 5][ t]], 
            Times[ -0.049236278094138941, 
              c[ 6][ t]], 
            Times[ -0.033483179628681567, 
              c[ 7][ t]], 
            Times[ -0.016825511857749262, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.016273855731265604, 
              c[ 10][ t]], 
            Times[ 0.031322974491347078, 
              c[ 11][ t]], 
            Times[ 0.044547108751839919, 
              c[ 12][ t]], 
            Times[ 0.055441487066198933, 
              c[ 13][ t]], 
            Times[ 0.063614872548668253, 
              c[ 14][ t]], 
            Times[ 0.068802429876423349, 
              c[ 15][ t]], 
            Times[ 0.070873018952678238, 
              c[ 16][ t]], 
            Times[ 0.069830768673962415, 
              c[ 17][ t]], 
            Times[ 0.065811019881796273, 
              c[ 18][ t]], 
            Times[ 0.059070953080906326, 
              c[ 19][ t]], 
            Times[ 0.049975424961080865, 
              c[ 20][ t]], 
            Times[ 0.03897872015785999, 
              c[ 21][ t]], 
            Times[ 0.026603074225527826, 
              c[ 22][ t]], 
            Times[ 0.013414935129827233, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.013061910521147383, 
              c[ 25][ t]], 
            Times[ -0.025221096343682053, 
              c[ 26][ t]], 
            Times[ -0.035980357068793781, 
              c[ 27][ t]], 
            Times[ -0.044914622433376419, 
              c[ 28][ t]], 
            Times[ -0.05168708394579296, 
              c[ 29][ t]], 
            Times[ -0.056061239158567186, 
              c[ 30][ t]], 
            Times[ -0.057908442314993203, 
              c[ 31][ t]], 
            Times[ -0.057210750238908967, 
              c[ 32][ t]], 
            Times[ -0.054059052045761224, 
              c[ 33][ t]], 
            Times[ -0.048646667243099281, 
              c[ 34][ t]], 
            Times[ -0.041258781072520248, 
              c[ 35][ t]], 
            Times[ -0.032258251165125519, 
              c[ 36][ t]], 
            Times[ -0.022068459300722043, 
              c[ 37][ t]], 
            Times[ -0.011153991006822649, 
              c[ 38][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 39][ t]], 
            Times[ 0.010908848347331966, 
              c[ 40][ t]], 
            Times[ 0.021108961070255627, 
              c[ 41][ t]], 
            Times[ 0.030177073670601236, 
              c[ 42][ t]], 
            Times[ 0.03774739544932687, 
              c[ 43][ t]], 
            Times[ 0.043525965428036162, 
              c[ 44][ t]], 
            Times[ 0.047301670540041058, 
              c[ 45][ t]], 
            Times[ 0.04895352855494272, 
              c[ 46][ t]], 
            Times[ 0.048454002753361682, 
              c[ 47][ t]], 
            Times[ 0.045868286584282256, 
              c[ 48][ t]], 
            Times[ 0.041349667156634483, 
              c[ 49][ t]], 
            Times[ 0.035131239329076656, 
              c[ 50][ t]], 
            Times[ 0.027514390699665887, 
              c[ 51][ t]], 
            Times[ 0.018854606004500233, 
              c[ 52][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 55][ t]], 
            Times[ -0.018149760920219783, 
              c[ 56][ t]], 
            Times[ -0.025985813438573278, 
              c[ 57][ t]], 
            Times[ -0.032552799745291155, 
              c[ 58][ t]], 
            Times[ -0.037590606506031236, 
              c[ 59][ t]], 
            Times[ -0.040909552899494966, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-50\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-50\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.4134966715663436`\ \(c[\(-60\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-59\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-58\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-57\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-56\)]\)[t] + 
            0.826993343132688`\ \(c[\(-55\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-54\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-53\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-52\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-51\)]\)[t] + 
            55.83113556160753`\ \(c[\(-50\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-49\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-48\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-47\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-46\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-45\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-44\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-43\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-42\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-41\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-40\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-39\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-38\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-37\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-36\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-35\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-34\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-33\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-32\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-31\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-30\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-29\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-28\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-27\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-26\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-25\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-24\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-23\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-22\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-21\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-20\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-19\)]\)[t] + 
            0.060688263076985`\ \(c[\(-18\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-17\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-16\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-15\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-14\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-13\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-12\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-11\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-10\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-9\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-8\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-7\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-6\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-5\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-4\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-3\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-2\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-1\)]\)[t] - 
            0.08269933431326874`\ \(c[0]\)[t] - 
            0.08903843866360665`\ \(c[1]\)[t] - 
            0.09131715903518159`\ \(c[2]\)[t] - 
            0.08959419377036688`\ \(c[3]\)[t] - 
            0.08409185873785086`\ \(c[4]\)[t] - 
            0.0751812130120626`\ \(c[5]\)[t] - 
            0.06336169950422753`\ \(c[6]\)[t] - 
            0.049236278094139066`\ \(c[7]\)[t] - 
            0.03348317962868157`\ \(c[8]\)[t] - 
            0.0168255118577494`\ \(c[9]\)[t] - 
            1.8033970416801674`*^-16\ \(c[10]\)[t] + 
            0.01627385573126547`\ \(c[11]\)[t] + 
            0.03132297449134708`\ \(c[12]\)[t] + 
            0.044547108751839815`\ \(c[13]\)[t] + 
            0.055441487066198857`\ \(c[14]\)[t] + 
            0.06361487254866825`\ \(c[15]\)[t] + 
            0.06880242987642332`\ \(c[16]\)[t] + 
            0.07087301895267824`\ \(c[17]\)[t] + 
            0.06983076867396242`\ \(c[18]\)[t] + 
            0.06581101988179631`\ \(c[19]\)[t] + 
            0.0590709530809064`\ \(c[20]\)[t] + 
            0.049975424961080865`\ \(c[21]\)[t] + 
            0.03897872015786009`\ \(c[22]\)[t] + 
            0.026603074225527937`\ \(c[23]\)[t] + 
            0.013414935129827233`\ \(c[24]\)[t] + 
            1.5206810699945212`*^-16\ \(c[25]\)[t] - 
            0.013061910521147276`\ \(c[26]\)[t] - 
            0.025221096343682053`\ \(c[27]\)[t] - 
            0.03598035706879378`\ \(c[28]\)[t] - 
            0.04491462243337629`\ \(c[29]\)[t] - 
            0.05168708394579296`\ \(c[30]\)[t] - 
            0.05606123915856713`\ \(c[31]\)[t] - 
            0.0579084423149932`\ \(c[32]\)[t] - 
            0.05721075023890897`\ \(c[33]\)[t] - 
            0.054059052045761224`\ \(c[34]\)[t] - 
            0.0486466672430994`\ \(c[35]\)[t] - 
            0.04125878107252025`\ \(c[36]\)[t] - 
            0.03225825116512568`\ \(c[37]\)[t] - 
            0.022068459300722043`\ \(c[38]\)[t] - 
            0.011153991006822649`\ \(c[39]\)[t] - 
            3.8981718325193755`*^-17\ \(c[40]\)[t] + 
            0.010908848347331785`\ \(c[41]\)[t] + 
            0.021108961070255627`\ \(c[42]\)[t] + 
            0.030177073670601094`\ \(c[43]\)[t] + 
            0.03774739544932687`\ \(c[44]\)[t] + 
            0.04352596542803616`\ \(c[45]\)[t] + 
            0.04730167054004106`\ \(c[46]\)[t] + 
            0.0489535285549427`\ \(c[47]\)[t] + 
            0.04845400275336168`\ \(c[48]\)[t] + 
            0.04586828658428231`\ \(c[49]\)[t] + 
            0.04134966715663448`\ \(c[50]\)[t] + 
            0.035131239329076656`\ \(c[51]\)[t] + 
            0.027514390699665887`\ \(c[52]\)[t] + 
            0.01885460600450039`\ \(c[53]\)[t] + 
            0.009545242303915543`\ \(c[54]\)[t] + 
            2.005337021455629`*^-16\ \(c[55]\)[t] - 
            0.009365143392520679`\ \(c[56]\)[t] - 
            0.018149760920219783`\ \(c[57]\)[t] - 
            0.02598581343857328`\ \(c[58]\)[t] - 
            0.03255279974529105`\ \(c[59]\)[t] - 
            0.037590606506031236`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -50, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -50]][ t]], 
          Plus[ 
            Times[ 0.41349667156634362, 
              c[ -60][ t]], 
            Times[ 0.50455115242710469, 
              c[ -59][ t]], 
            Times[ 0.59356153372868015, 
              c[ -58][ t]], 
            Times[ 0.67835603854706272, 
              c[ -57][ t]], 
            Times[ 0.75682672864065692, 
              c[ -56][ t]], 
            Times[ 0.82699334313268802, 
              c[ -55][ t]], 
            Times[ 0.88706379305918348, 
              c[ -54][ t]], 
            Times[ 0.93548928378863916, 
              c[ -53][ t]], 
            Times[ 0.9710122092317629, 
              c[ -52][ t]], 
            Times[ 0.99270519960720671, 
              c[ -51][ t]], 
            Times[ 55.831135561607532, 
              c[ -50][ t]], 
            Times[ 0.99270519960720693, 
              c[ -49][ t]], 
            Times[ 0.9710122092317629, 
              c[ -48][ t]], 
            Times[ 0.93548928378863916, 
              c[ -47][ t]], 
            Times[ 0.88706379305918392, 
              c[ -46][ t]], 
            Times[ 0.82699334313268846, 
              c[ -45][ t]], 
            Times[ 0.75682672864065692, 
              c[ -44][ t]], 
            Times[ 0.67835603854706361, 
              c[ -43][ t]], 
            Times[ 0.59356153372868092, 
              c[ -42][ t]], 
            Times[ 0.50455115242710469, 
              c[ -41][ t]], 
            Times[ 0.41349667156634429, 
              c[ -40][ t]], 
            Times[ 0.32256865202152191, 
              c[ -39][ t]], 
            Times[ 0.23387232094716018, 
              c[ -38][ t]], 
            Times[ 0.14938649372796384, 
              c[ -37][ t]], 
            Times[ 0.070907514257658094, 
              c[ -36][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -35][ t]], 
            Times[ -0.062044074975450239, 
              c[ -34][ t]], 
            Times[ -0.11423673049785416, 
              c[ -33][ t]], 
            Times[ -0.15591488063143966, 
              c[ -32][ t]], 
            Times[ -0.18675027222298593, 
              c[ -31][ t]], 
            Times[ -0.20674833578317189, 
              c[ -30][ t]], 
            Times[ -0.21623620818304481, 
              c[ -29][ t]], 
            Times[ -0.21584055771952015, 
              c[ -28][ t]], 
            Times[ -0.20645618564475848, 
              c[ -27][ t]], 
            Times[ -0.18920668216016434, 
              c[ -26][ t]], 
            Times[ -0.16539866862653771, 
              c[ -25][ t]], 
            Times[ -0.13647135277833616, 
              c[ -24][ t]], 
            Times[ -0.1039432537542934, 
              c[ -23][ t]], 
            Times[ -0.06935801494512607, 
              c[ -22][ t]], 
            Times[ -0.034231213779559094, 
              c[ -21][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -20][ t]], 
            Times[ 0.032022748374425904, 
              c[ -19][ t]], 
            Times[ 0.060688263076985001, 
              c[ -18][ t]], 
            Times[ 0.085044480344421608, 
              c[ -17][ t]], 
            Times[ 0.10436044624225685, 
              c[ -16][ t]], 
            Times[ 0.11814190616181253, 
              c[ -15][ t]], 
            Times[ 0.12613778810677612, 
              c[ -14][ t]], 
            Times[ 0.12833762891430928, 
              c[ -13][ t]], 
            Times[ 0.12496032289024853, 
              c[ -12][ t]], 
            Times[ 0.11643488132933186, 
              c[ -11][ t]], 
            Times[ 0.10337416789158609, 
              c[ -10][ t]], 
            Times[ 0.086542809078944891, 
              c[ -9][ t]], 
            Times[ 0.066820663127760152, 
              c[ -8][ t]], 
            Times[ 0.045163358568919301, 
              c[ -7][ t]], 
            Times[ 0.022561481809254869, 
              c[ -6][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -5][ t]], 
            Times[ -0.021580547817547879, 
              c[ -4][ t]], 
            Times[ -0.04131966847794722, 
              c[ -3][ t]], 
            Times[ -0.058468080236789774, 
              c[ -2][ t]], 
            Times[ -0.072413370861974122, 
              c[ -1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 0][ t]], 
            Times[ -0.089038438663606653, 
              c[ 1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 2][ t]], 
            Times[ -0.089594193770366884, 
              c[ 3][ t]], 
            Times[ -0.084091858737850855, 
              c[ 4][ t]], 
            Times[ -0.075181213012062598, 
              c[ 5][ t]], 
            Times[ -0.063361699504227528, 
              c[ 6][ t]], 
            Times[ -0.049236278094139066, 
              c[ 7][ t]], 
            Times[ -0.033483179628681567, 
              c[ 8][ t]], 
            Times[ -0.016825511857749401, 
              c[ 9][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 10][ t]], 
            Times[ 0.016273855731265469, 
              c[ 11][ t]], 
            Times[ 0.031322974491347078, 
              c[ 12][ t]], 
            Times[ 0.044547108751839815, 
              c[ 13][ t]], 
            Times[ 0.055441487066198857, 
              c[ 14][ t]], 
            Times[ 0.063614872548668253, 
              c[ 15][ t]], 
            Times[ 0.068802429876423321, 
              c[ 16][ t]], 
            Times[ 0.070873018952678238, 
              c[ 17][ t]], 
            Times[ 0.069830768673962415, 
              c[ 18][ t]], 
            Times[ 0.065811019881796315, 
              c[ 19][ t]], 
            Times[ 0.059070953080906402, 
              c[ 20][ t]], 
            Times[ 0.049975424961080865, 
              c[ 21][ t]], 
            Times[ 0.038978720157860088, 
              c[ 22][ t]], 
            Times[ 0.026603074225527937, 
              c[ 23][ t]], 
            Times[ 0.013414935129827233, 
              c[ 24][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 25][ t]], 
            Times[ -0.013061910521147276, 
              c[ 26][ t]], 
            Times[ -0.025221096343682053, 
              c[ 27][ t]], 
            Times[ -0.035980357068793781, 
              c[ 28][ t]], 
            Times[ -0.044914622433376288, 
              c[ 29][ t]], 
            Times[ -0.05168708394579296, 
              c[ 30][ t]], 
            Times[ -0.05606123915856713, 
              c[ 31][ t]], 
            Times[ -0.057908442314993203, 
              c[ 32][ t]], 
            Times[ -0.057210750238908967, 
              c[ 33][ t]], 
            Times[ -0.054059052045761224, 
              c[ 34][ t]], 
            Times[ -0.048646667243099399, 
              c[ 35][ t]], 
            Times[ -0.041258781072520248, 
              c[ 36][ t]], 
            Times[ -0.032258251165125679, 
              c[ 37][ t]], 
            Times[ -0.022068459300722043, 
              c[ 38][ t]], 
            Times[ -0.011153991006822649, 
              c[ 39][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 40][ t]], 
            Times[ 0.010908848347331785, 
              c[ 41][ t]], 
            Times[ 0.021108961070255627, 
              c[ 42][ t]], 
            Times[ 0.030177073670601094, 
              c[ 43][ t]], 
            Times[ 0.03774739544932687, 
              c[ 44][ t]], 
            Times[ 0.043525965428036162, 
              c[ 45][ t]], 
            Times[ 0.047301670540041058, 
              c[ 46][ t]], 
            Times[ 0.048953528554942699, 
              c[ 47][ t]], 
            Times[ 0.048454002753361682, 
              c[ 48][ t]], 
            Times[ 0.045868286584282311, 
              c[ 49][ t]], 
            Times[ 0.041349667156634483, 
              c[ 50][ t]], 
            Times[ 0.035131239329076656, 
              c[ 51][ t]], 
            Times[ 0.027514390699665887, 
              c[ 52][ t]], 
            Times[ 0.018854606004500389, 
              c[ 53][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 54][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 55][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 56][ t]], 
            Times[ -0.018149760920219783, 
              c[ 57][ t]], 
            Times[ -0.025985813438573278, 
              c[ 58][ t]], 
            Times[ -0.032552799745291051, 
              c[ 59][ t]], 
            Times[ -0.037590606506031236, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-49\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-49\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.32256865202152113`\ \(c[\(-60\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-59\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-58\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-57\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-56\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-55\)]\)[t] + 
            0.826993343132688`\ \(c[\(-54\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-53\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-52\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-51\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-50\)]\)[t] + 
            53.65982259336788`\ \(c[\(-49\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-48\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-47\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-46\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-45\)]\)[t] + 
            0.826993343132688`\ \(c[\(-44\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-43\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-42\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-41\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-40\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-39\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-38\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-37\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-36\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-35\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-34\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-33\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-32\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-31\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-30\)]\)[t] - 
            0.206748335783172`\ \(c[\(-29\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-28\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-27\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-26\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-25\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-24\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-23\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-22\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-21\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-20\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-18\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-17\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-16\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-15\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-14\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-13\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-12\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-11\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-10\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-9\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-8\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-7\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-6\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-5\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-4\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-3\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-2\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-1\)]\)[t] - 
            0.07241337086197412`\ \(c[0]\)[t] - 
            0.08269933431326874`\ \(c[1]\)[t] - 
            0.0890384386636067`\ \(c[2]\)[t] - 
            0.09131715903518159`\ \(c[3]\)[t] - 
            0.08959419377036688`\ \(c[4]\)[t] - 
            0.08409185873785081`\ \(c[5]\)[t] - 
            0.0751812130120626`\ \(c[6]\)[t] - 
            0.06336169950422753`\ \(c[7]\)[t] - 
            0.04923627809413894`\ \(c[8]\)[t] - 
            0.03348317962868157`\ \(c[9]\)[t] - 
            0.0168255118577494`\ \(c[10]\)[t] - 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.016273855731265604`\ \(c[12]\)[t] + 
            0.03132297449134708`\ \(c[13]\)[t] + 
            0.04454710875183992`\ \(c[14]\)[t] + 
            0.05544148706619893`\ \(c[15]\)[t] + 
            0.06361487254866825`\ \(c[16]\)[t] + 
            0.06880242987642335`\ \(c[17]\)[t] + 
            0.07087301895267824`\ \(c[18]\)[t] + 
            0.06983076867396242`\ \(c[19]\)[t] + 
            0.06581101988179627`\ \(c[20]\)[t] + 
            0.059070953080906326`\ \(c[21]\)[t] + 
            0.049975424961080865`\ \(c[22]\)[t] + 
            0.03897872015785999`\ \(c[23]\)[t] + 
            0.026603074225527826`\ \(c[24]\)[t] + 
            0.013414935129827233`\ \(c[25]\)[t] + 
            3.898171832519376`*^-17\ \(c[26]\)[t] - 
            0.013061910521147383`\ \(c[27]\)[t] - 
            0.025221096343682053`\ \(c[28]\)[t] - 
            0.03598035706879378`\ \(c[29]\)[t] - 
            0.04491462243337642`\ \(c[30]\)[t] - 
            0.05168708394579296`\ \(c[31]\)[t] - 
            0.056061239158567186`\ \(c[32]\)[t] - 
            0.0579084423149932`\ \(c[33]\)[t] - 
            0.05721075023890897`\ \(c[34]\)[t] - 
            0.054059052045761224`\ \(c[35]\)[t] - 
            0.04864666724309928`\ \(c[36]\)[t] - 
            0.04125878107252025`\ \(c[37]\)[t] - 
            0.03225825116512552`\ \(c[38]\)[t] - 
            0.022068459300722043`\ \(c[39]\)[t] - 
            0.011153991006822649`\ \(c[40]\)[t] - 
            3.8981718325193755`*^-17\ \(c[41]\)[t] + 
            0.010908848347331966`\ \(c[42]\)[t] + 
            0.021108961070255627`\ \(c[43]\)[t] + 
            0.030177073670601094`\ \(c[44]\)[t] + 
            0.03774739544932687`\ \(c[45]\)[t] + 
            0.04352596542803616`\ \(c[46]\)[t] + 
            0.04730167054004106`\ \(c[47]\)[t] + 
            0.04895352855494272`\ \(c[48]\)[t] + 
            0.04845400275336168`\ \(c[49]\)[t] + 
            0.04586828658428231`\ \(c[50]\)[t] + 
            0.04134966715663448`\ \(c[51]\)[t] + 
            0.035131239329076656`\ \(c[52]\)[t] + 
            0.027514390699665887`\ \(c[53]\)[t] + 
            0.018854606004500233`\ \(c[54]\)[t] + 
            0.009545242303915543`\ \(c[55]\)[t] + 
            2.005337021455629`*^-16\ \(c[56]\)[t] - 
            0.009365143392520679`\ \(c[57]\)[t] - 
            0.018149760920219783`\ \(c[58]\)[t] - 
            0.02598581343857328`\ \(c[59]\)[t] - 
            0.032552799745291155`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -49, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -49]][ t]], 
          Plus[ 
            Times[ 0.32256865202152113, 
              c[ -60][ t]], 
            Times[ 0.41349667156634429, 
              c[ -59][ t]], 
            Times[ 0.50455115242710469, 
              c[ -58][ t]], 
            Times[ 0.59356153372868015, 
              c[ -57][ t]], 
            Times[ 0.67835603854706361, 
              c[ -56][ t]], 
            Times[ 0.75682672864065692, 
              c[ -55][ t]], 
            Times[ 0.82699334313268802, 
              c[ -54][ t]], 
            Times[ 0.88706379305918392, 
              c[ -53][ t]], 
            Times[ 0.93548928378863916, 
              c[ -52][ t]], 
            Times[ 0.9710122092317629, 
              c[ -51][ t]], 
            Times[ 0.99270519960720693, 
              c[ -50][ t]], 
            Times[ 53.659822593367878, 
              c[ -49][ t]], 
            Times[ 0.99270519960720693, 
              c[ -48][ t]], 
            Times[ 0.9710122092317629, 
              c[ -47][ t]], 
            Times[ 0.93548928378863916, 
              c[ -46][ t]], 
            Times[ 0.88706379305918392, 
              c[ -45][ t]], 
            Times[ 0.82699334313268802, 
              c[ -44][ t]], 
            Times[ 0.75682672864065692, 
              c[ -43][ t]], 
            Times[ 0.67835603854706361, 
              c[ -42][ t]], 
            Times[ 0.59356153372868015, 
              c[ -41][ t]], 
            Times[ 0.50455115242710469, 
              c[ -40][ t]], 
            Times[ 0.41349667156634429, 
              c[ -39][ t]], 
            Times[ 0.32256865202152157, 
              c[ -38][ t]], 
            Times[ 0.23387232094715985, 
              c[ -37][ t]], 
            Times[ 0.14938649372796384, 
              c[ -36][ t]], 
            Times[ 0.070907514257657775, 
              c[ -35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -34][ t]], 
            Times[ -0.062044074975450239, 
              c[ -33][ t]], 
            Times[ -0.11423673049785436, 
              c[ -32][ t]], 
            Times[ -0.15591488063143982, 
              c[ -31][ t]], 
            Times[ -0.18675027222298593, 
              c[ -30][ t]], 
            Times[ -0.206748335783172, 
              c[ -29][ t]], 
            Times[ -0.21623620818304484, 
              c[ -28][ t]], 
            Times[ -0.21584055771952015, 
              c[ -27][ t]], 
            Times[ -0.20645618564475843, 
              c[ -26][ t]], 
            Times[ -0.18920668216016426, 
              c[ -25][ t]], 
            Times[ -0.16539866862653771, 
              c[ -24][ t]], 
            Times[ -0.13647135277833605, 
              c[ -23][ t]], 
            Times[ -0.10394325375429328, 
              c[ -22][ t]], 
            Times[ -0.06935801494512607, 
              c[ -21][ t]], 
            Times[ -0.034231213779558949, 
              c[ -20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ 0.032022748374425904, 
              c[ -18][ t]], 
            Times[ 0.060688263076985105, 
              c[ -17][ t]], 
            Times[ 0.085044480344421705, 
              c[ -16][ t]], 
            Times[ 0.10436044624225685, 
              c[ -15][ t]], 
            Times[ 0.11814190616181255, 
              c[ -14][ t]], 
            Times[ 0.12613778810677614, 
              c[ -13][ t]], 
            Times[ 0.12833762891430928, 
              c[ -12][ t]], 
            Times[ 0.12496032289024853, 
              c[ -11][ t]], 
            Times[ 0.11643488132933186, 
              c[ -10][ t]], 
            Times[ 0.10337416789158609, 
              c[ -9][ t]], 
            Times[ 0.086542809078944891, 
              c[ -8][ t]], 
            Times[ 0.066820663127759972, 
              c[ -7][ t]], 
            Times[ 0.045163358568919301, 
              c[ -6][ t]], 
            Times[ 0.022561481809254869, 
              c[ -5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -4][ t]], 
            Times[ -0.021580547817547879, 
              c[ -3][ t]], 
            Times[ -0.04131966847794722, 
              c[ -2][ t]], 
            Times[ -0.058468080236789913, 
              c[ -1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 0][ t]], 
            Times[ -0.082699334313268744, 
              c[ 1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 2][ t]], 
            Times[ -0.091317159035181589, 
              c[ 3][ t]], 
            Times[ -0.089594193770366884, 
              c[ 4][ t]], 
            Times[ -0.084091858737850814, 
              c[ 5][ t]], 
            Times[ -0.075181213012062598, 
              c[ 6][ t]], 
            Times[ -0.063361699504227528, 
              c[ 7][ t]], 
            Times[ -0.049236278094138941, 
              c[ 8][ t]], 
            Times[ -0.033483179628681567, 
              c[ 9][ t]], 
            Times[ -0.016825511857749401, 
              c[ 10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.016273855731265604, 
              c[ 12][ t]], 
            Times[ 0.031322974491347078, 
              c[ 13][ t]], 
            Times[ 0.044547108751839919, 
              c[ 14][ t]], 
            Times[ 0.055441487066198933, 
              c[ 15][ t]], 
            Times[ 0.063614872548668253, 
              c[ 16][ t]], 
            Times[ 0.068802429876423349, 
              c[ 17][ t]], 
            Times[ 0.070873018952678238, 
              c[ 18][ t]], 
            Times[ 0.069830768673962415, 
              c[ 19][ t]], 
            Times[ 0.065811019881796273, 
              c[ 20][ t]], 
            Times[ 0.059070953080906326, 
              c[ 21][ t]], 
            Times[ 0.049975424961080865, 
              c[ 22][ t]], 
            Times[ 0.03897872015785999, 
              c[ 23][ t]], 
            Times[ 0.026603074225527826, 
              c[ 24][ t]], 
            Times[ 0.013414935129827233, 
              c[ 25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ -0.013061910521147383, 
              c[ 27][ t]], 
            Times[ -0.025221096343682053, 
              c[ 28][ t]], 
            Times[ -0.035980357068793781, 
              c[ 29][ t]], 
            Times[ -0.044914622433376419, 
              c[ 30][ t]], 
            Times[ -0.05168708394579296, 
              c[ 31][ t]], 
            Times[ -0.056061239158567186, 
              c[ 32][ t]], 
            Times[ -0.057908442314993203, 
              c[ 33][ t]], 
            Times[ -0.057210750238908967, 
              c[ 34][ t]], 
            Times[ -0.054059052045761224, 
              c[ 35][ t]], 
            Times[ -0.048646667243099281, 
              c[ 36][ t]], 
            Times[ -0.041258781072520248, 
              c[ 37][ t]], 
            Times[ -0.032258251165125519, 
              c[ 38][ t]], 
            Times[ -0.022068459300722043, 
              c[ 39][ t]], 
            Times[ -0.011153991006822649, 
              c[ 40][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 41][ t]], 
            Times[ 0.010908848347331966, 
              c[ 42][ t]], 
            Times[ 0.021108961070255627, 
              c[ 43][ t]], 
            Times[ 0.030177073670601094, 
              c[ 44][ t]], 
            Times[ 0.03774739544932687, 
              c[ 45][ t]], 
            Times[ 0.043525965428036162, 
              c[ 46][ t]], 
            Times[ 0.047301670540041058, 
              c[ 47][ t]], 
            Times[ 0.04895352855494272, 
              c[ 48][ t]], 
            Times[ 0.048454002753361682, 
              c[ 49][ t]], 
            Times[ 0.045868286584282311, 
              c[ 50][ t]], 
            Times[ 0.041349667156634483, 
              c[ 51][ t]], 
            Times[ 0.035131239329076656, 
              c[ 52][ t]], 
            Times[ 0.027514390699665887, 
              c[ 53][ t]], 
            Times[ 0.018854606004500233, 
              c[ 54][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 55][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 56][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 57][ t]], 
            Times[ -0.018149760920219783, 
              c[ 58][ t]], 
            Times[ -0.025985813438573278, 
              c[ 59][ t]], 
            Times[ -0.032552799745291155, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-48\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-48\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.23387232094715985`\ \(c[\(-60\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-59\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-58\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-57\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-56\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-55\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-54\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-53\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-52\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-51\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-50\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-49\)]\)[t] + 
            51.53237453357751`\ \(c[\(-48\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-47\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-46\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-45\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-44\)]\)[t] + 
            0.826993343132688`\ \(c[\(-43\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-42\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-41\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-40\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-39\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-38\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-37\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-36\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-35\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-32\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-31\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-30\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-29\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-28\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-27\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-26\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-25\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-24\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-23\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-22\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-21\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-20\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-17\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-16\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-15\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-14\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-13\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-12\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-11\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-10\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-9\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-8\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-7\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-6\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-5\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-4\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-3\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-2\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-1\)]\)[t] - 
            0.05846808023678991`\ \(c[0]\)[t] - 
            0.07241337086197412`\ \(c[1]\)[t] - 
            0.08269933431326881`\ \(c[2]\)[t] - 
            0.0890384386636067`\ \(c[3]\)[t] - 
            0.09131715903518159`\ \(c[4]\)[t] - 
            0.08959419377036684`\ \(c[5]\)[t] - 
            0.08409185873785081`\ \(c[6]\)[t] - 
            0.0751812130120626`\ \(c[7]\)[t] - 
            0.0633616995042274`\ \(c[8]\)[t] - 
            0.04923627809413894`\ \(c[9]\)[t] - 
            0.03348317962868157`\ \(c[10]\)[t] - 
            0.0168255118577494`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.016273855731265604`\ \(c[13]\)[t] + 
            0.03132297449134708`\ \(c[14]\)[t] + 
            0.04454710875183992`\ \(c[15]\)[t] + 
            0.05544148706619893`\ \(c[16]\)[t] + 
            0.06361487254866825`\ \(c[17]\)[t] + 
            0.06880242987642335`\ \(c[18]\)[t] + 
            0.07087301895267824`\ \(c[19]\)[t] + 
            0.06983076867396242`\ \(c[20]\)[t] + 
            0.06581101988179627`\ \(c[21]\)[t] + 
            0.059070953080906326`\ \(c[22]\)[t] + 
            0.049975424961080865`\ \(c[23]\)[t] + 
            0.03897872015785999`\ \(c[24]\)[t] + 
            0.026603074225527826`\ \(c[25]\)[t] + 
            0.013414935129827233`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.013061910521147383`\ \(c[28]\)[t] - 
            0.025221096343682053`\ \(c[29]\)[t] - 
            0.03598035706879378`\ \(c[30]\)[t] - 
            0.04491462243337642`\ \(c[31]\)[t] - 
            0.05168708394579296`\ \(c[32]\)[t] - 
            0.056061239158567186`\ \(c[33]\)[t] - 
            0.0579084423149932`\ \(c[34]\)[t] - 
            0.05721075023890897`\ \(c[35]\)[t] - 
            0.054059052045761224`\ \(c[36]\)[t] - 
            0.04864666724309928`\ \(c[37]\)[t] - 
            0.04125878107252025`\ \(c[38]\)[t] - 
            0.03225825116512552`\ \(c[39]\)[t] - 
            0.022068459300722043`\ \(c[40]\)[t] - 
            0.011153991006822649`\ \(c[41]\)[t] - 
            3.8981718325193755`*^-17\ \(c[42]\)[t] + 
            0.010908848347331966`\ \(c[43]\)[t] + 
            0.021108961070255627`\ \(c[44]\)[t] + 
            0.030177073670601236`\ \(c[45]\)[t] + 
            0.03774739544932687`\ \(c[46]\)[t] + 
            0.04352596542803616`\ \(c[47]\)[t] + 
            0.04730167054004106`\ \(c[48]\)[t] + 
            0.04895352855494272`\ \(c[49]\)[t] + 
            0.04845400275336168`\ \(c[50]\)[t] + 
            0.045868286584282256`\ \(c[51]\)[t] + 
            0.04134966715663448`\ \(c[52]\)[t] + 
            0.035131239329076656`\ \(c[53]\)[t] + 
            0.027514390699665887`\ \(c[54]\)[t] + 
            0.018854606004500233`\ \(c[55]\)[t] + 
            0.009545242303915543`\ \(c[56]\)[t] + 
            3.8981718325193755`*^-17\ \(c[57]\)[t] - 
            0.009365143392520679`\ \(c[58]\)[t] - 
            0.018149760920219783`\ \(c[59]\)[t] - 
            0.02598581343857328`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -48, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -48]][ t]], 
          Plus[ 
            Times[ 0.23387232094715985, 
              c[ -60][ t]], 
            Times[ 0.32256865202152191, 
              c[ -59][ t]], 
            Times[ 0.41349667156634429, 
              c[ -58][ t]], 
            Times[ 0.50455115242710469, 
              c[ -57][ t]], 
            Times[ 0.59356153372868092, 
              c[ -56][ t]], 
            Times[ 0.67835603854706361, 
              c[ -55][ t]], 
            Times[ 0.75682672864065692, 
              c[ -54][ t]], 
            Times[ 0.82699334313268846, 
              c[ -53][ t]], 
            Times[ 0.88706379305918392, 
              c[ -52][ t]], 
            Times[ 0.93548928378863916, 
              c[ -51][ t]], 
            Times[ 0.9710122092317629, 
              c[ -50][ t]], 
            Times[ 0.99270519960720693, 
              c[ -49][ t]], 
            Times[ 51.53237453357751, 
              c[ -48][ t]], 
            Times[ 0.99270519960720671, 
              c[ -47][ t]], 
            Times[ 0.9710122092317629, 
              c[ -46][ t]], 
            Times[ 0.93548928378863916, 
              c[ -45][ t]], 
            Times[ 0.88706379305918348, 
              c[ -44][ t]], 
            Times[ 0.82699334313268802, 
              c[ -43][ t]], 
            Times[ 0.75682672864065692, 
              c[ -42][ t]], 
            Times[ 0.67835603854706272, 
              c[ -41][ t]], 
            Times[ 0.59356153372868015, 
              c[ -40][ t]], 
            Times[ 0.50455115242710469, 
              c[ -39][ t]], 
            Times[ 0.41349667156634395, 
              c[ -38][ t]], 
            Times[ 0.32256865202152113, 
              c[ -37][ t]], 
            Times[ 0.23387232094715985, 
              c[ -36][ t]], 
            Times[ 0.14938649372796345, 
              c[ -35][ t]], 
            Times[ 0.070907514257657456, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.062044074975450475, 
              c[ -32][ t]], 
            Times[ -0.11423673049785459, 
              c[ -31][ t]], 
            Times[ -0.15591488063143982, 
              c[ -30][ t]], 
            Times[ -0.18675027222298607, 
              c[ -29][ t]], 
            Times[ -0.20674833578317206, 
              c[ -28][ t]], 
            Times[ -0.21623620818304484, 
              c[ -27][ t]], 
            Times[ -0.21584055771952013, 
              c[ -26][ t]], 
            Times[ -0.20645618564475834, 
              c[ -25][ t]], 
            Times[ -0.18920668216016426, 
              c[ -24][ t]], 
            Times[ -0.1653986686265376, 
              c[ -23][ t]], 
            Times[ -0.13647135277833591, 
              c[ -22][ t]], 
            Times[ -0.10394325375429328, 
              c[ -21][ t]], 
            Times[ -0.069358014945125918, 
              c[ -20][ t]], 
            Times[ -0.034231213779558796, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.032022748374426029, 
              c[ -17][ t]], 
            Times[ 0.060688263076985223, 
              c[ -16][ t]], 
            Times[ 0.085044480344421705, 
              c[ -15][ t]], 
            Times[ 0.10436044624225692, 
              c[ -14][ t]], 
            Times[ 0.1181419061618126, 
              c[ -13][ t]], 
            Times[ 0.12613778810677614, 
              c[ -12][ t]], 
            Times[ 0.12833762891430925, 
              c[ -11][ t]], 
            Times[ 0.12496032289024847, 
              c[ -10][ t]], 
            Times[ 0.11643488132933186, 
              c[ -9][ t]], 
            Times[ 0.10337416789158609, 
              c[ -8][ t]], 
            Times[ 0.086542809078944752, 
              c[ -7][ t]], 
            Times[ 0.066820663127759972, 
              c[ -6][ t]], 
            Times[ 0.045163358568919301, 
              c[ -5][ t]], 
            Times[ 0.022561481809254675, 
              c[ -4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -3][ t]], 
            Times[ -0.021580547817547879, 
              c[ -2][ t]], 
            Times[ -0.041319668477947373, 
              c[ -1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 0][ t]], 
            Times[ -0.072413370861974122, 
              c[ 1][ t]], 
            Times[ -0.082699334313268813, 
              c[ 2][ t]], 
            Times[ -0.089038438663606695, 
              c[ 3][ t]], 
            Times[ -0.091317159035181589, 
              c[ 4][ t]], 
            Times[ -0.089594193770366842, 
              c[ 5][ t]], 
            Times[ -0.084091858737850814, 
              c[ 6][ t]], 
            Times[ -0.075181213012062598, 
              c[ 7][ t]], 
            Times[ -0.063361699504227403, 
              c[ 8][ t]], 
            Times[ -0.049236278094138941, 
              c[ 9][ t]], 
            Times[ -0.033483179628681567, 
              c[ 10][ t]], 
            Times[ -0.016825511857749401, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.016273855731265604, 
              c[ 13][ t]], 
            Times[ 0.031322974491347078, 
              c[ 14][ t]], 
            Times[ 0.044547108751839919, 
              c[ 15][ t]], 
            Times[ 0.055441487066198933, 
              c[ 16][ t]], 
            Times[ 0.063614872548668253, 
              c[ 17][ t]], 
            Times[ 0.068802429876423349, 
              c[ 18][ t]], 
            Times[ 0.070873018952678238, 
              c[ 19][ t]], 
            Times[ 0.069830768673962415, 
              c[ 20][ t]], 
            Times[ 0.065811019881796273, 
              c[ 21][ t]], 
            Times[ 0.059070953080906326, 
              c[ 22][ t]], 
            Times[ 0.049975424961080865, 
              c[ 23][ t]], 
            Times[ 0.03897872015785999, 
              c[ 24][ t]], 
            Times[ 0.026603074225527826, 
              c[ 25][ t]], 
            Times[ 0.013414935129827233, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.013061910521147383, 
              c[ 28][ t]], 
            Times[ -0.025221096343682053, 
              c[ 29][ t]], 
            Times[ -0.035980357068793781, 
              c[ 30][ t]], 
            Times[ -0.044914622433376419, 
              c[ 31][ t]], 
            Times[ -0.05168708394579296, 
              c[ 32][ t]], 
            Times[ -0.056061239158567186, 
              c[ 33][ t]], 
            Times[ -0.057908442314993203, 
              c[ 34][ t]], 
            Times[ -0.057210750238908967, 
              c[ 35][ t]], 
            Times[ -0.054059052045761224, 
              c[ 36][ t]], 
            Times[ -0.048646667243099281, 
              c[ 37][ t]], 
            Times[ -0.041258781072520248, 
              c[ 38][ t]], 
            Times[ -0.032258251165125519, 
              c[ 39][ t]], 
            Times[ -0.022068459300722043, 
              c[ 40][ t]], 
            Times[ -0.011153991006822649, 
              c[ 41][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 42][ t]], 
            Times[ 0.010908848347331966, 
              c[ 43][ t]], 
            Times[ 0.021108961070255627, 
              c[ 44][ t]], 
            Times[ 0.030177073670601236, 
              c[ 45][ t]], 
            Times[ 0.03774739544932687, 
              c[ 46][ t]], 
            Times[ 0.043525965428036162, 
              c[ 47][ t]], 
            Times[ 0.047301670540041058, 
              c[ 48][ t]], 
            Times[ 0.04895352855494272, 
              c[ 49][ t]], 
            Times[ 0.048454002753361682, 
              c[ 50][ t]], 
            Times[ 0.045868286584282256, 
              c[ 51][ t]], 
            Times[ 0.041349667156634483, 
              c[ 52][ t]], 
            Times[ 0.035131239329076656, 
              c[ 53][ t]], 
            Times[ 0.027514390699665887, 
              c[ 54][ t]], 
            Times[ 0.018854606004500233, 
              c[ 55][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 58][ t]], 
            Times[ -0.018149760920219783, 
              c[ 59][ t]], 
            Times[ -0.025985813438573278, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-47\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-47\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.14938649372796314`\ \(c[\(-60\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-59\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-58\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-57\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-56\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-55\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-54\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-53\)]\)[t] + 
            0.826993343132688`\ \(c[\(-52\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-51\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-50\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-49\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-48\)]\)[t] + 
            49.448791382236415`\ \(c[\(-47\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-46\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-45\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-44\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-43\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-42\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-41\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-40\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-39\)]\)[t] + 
            0.504551152427105`\ \(c[\(-38\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-37\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-36\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-35\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-34\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-33\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-32\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-31\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-30\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-29\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-28\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-27\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-26\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-25\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-24\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-23\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-22\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-21\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-20\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-19\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-18\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-17\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-16\)]\)[t] + 
            0.060688263076985`\ \(c[\(-15\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-14\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-13\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-12\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-11\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-10\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-9\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-8\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-7\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-6\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-5\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-4\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-3\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-2\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-1\)]\)[t] - 
            0.04131966847794722`\ \(c[0]\)[t] - 
            0.058468080236789774`\ \(c[1]\)[t] - 
            0.07241337086197412`\ \(c[2]\)[t] - 
            0.08269933431326874`\ \(c[3]\)[t] - 
            0.08903843866360665`\ \(c[4]\)[t] - 
            0.09131715903518159`\ \(c[5]\)[t] - 
            0.08959419377036688`\ \(c[6]\)[t] - 
            0.08409185873785086`\ \(c[7]\)[t] - 
            0.0751812130120626`\ \(c[8]\)[t] - 
            0.06336169950422753`\ \(c[9]\)[t] - 
            0.049236278094139066`\ \(c[10]\)[t] - 
            0.033483179628681706`\ \(c[11]\)[t] - 
            0.0168255118577494`\ \(c[12]\)[t] - 
            1.8033970416801674`*^-16\ \(c[13]\)[t] + 
            0.01627385573126547`\ \(c[14]\)[t] + 
            0.03132297449134708`\ \(c[15]\)[t] + 
            0.044547108751839815`\ \(c[16]\)[t] + 
            0.055441487066198857`\ \(c[17]\)[t] + 
            0.06361487254866825`\ \(c[18]\)[t] + 
            0.06880242987642332`\ \(c[19]\)[t] + 
            0.07087301895267824`\ \(c[20]\)[t] + 
            0.06983076867396242`\ \(c[21]\)[t] + 
            0.06581101988179631`\ \(c[22]\)[t] + 
            0.0590709530809064`\ \(c[23]\)[t] + 
            0.049975424961080865`\ \(c[24]\)[t] + 
            0.03897872015786009`\ \(c[25]\)[t] + 
            0.026603074225527937`\ \(c[26]\)[t] + 
            0.013414935129827233`\ \(c[27]\)[t] + 
            1.5206810699945212`*^-16\ \(c[28]\)[t] - 
            0.013061910521147276`\ \(c[29]\)[t] - 
            0.025221096343682053`\ \(c[30]\)[t] - 
            0.03598035706879378`\ \(c[31]\)[t] - 
            0.04491462243337629`\ \(c[32]\)[t] - 
            0.05168708394579296`\ \(c[33]\)[t] - 
            0.05606123915856713`\ \(c[34]\)[t] - 
            0.0579084423149932`\ \(c[35]\)[t] - 
            0.05721075023890897`\ \(c[36]\)[t] - 
            0.054059052045761224`\ \(c[37]\)[t] - 
            0.0486466672430994`\ \(c[38]\)[t] - 
            0.04125878107252025`\ \(c[39]\)[t] - 
            0.03225825116512568`\ \(c[40]\)[t] - 
            0.022068459300722043`\ \(c[41]\)[t] - 
            0.011153991006822649`\ \(c[42]\)[t] - 
            3.8981718325193755`*^-17\ \(c[43]\)[t] + 
            0.010908848347331785`\ \(c[44]\)[t] + 
            0.021108961070255627`\ \(c[45]\)[t] + 
            0.030177073670601094`\ \(c[46]\)[t] + 
            0.03774739544932687`\ \(c[47]\)[t] + 
            0.04352596542803616`\ \(c[48]\)[t] + 
            0.04730167054004106`\ \(c[49]\)[t] + 
            0.0489535285549427`\ \(c[50]\)[t] + 
            0.04845400275336168`\ \(c[51]\)[t] + 
            0.04586828658428231`\ \(c[52]\)[t] + 
            0.04134966715663448`\ \(c[53]\)[t] + 
            0.035131239329076656`\ \(c[54]\)[t] + 
            0.027514390699665887`\ \(c[55]\)[t] + 
            0.01885460600450039`\ \(c[56]\)[t] + 
            0.009545242303915543`\ \(c[57]\)[t] + 
            2.005337021455629`*^-16\ \(c[58]\)[t] - 
            0.009365143392520679`\ \(c[59]\)[t] - 
            0.018149760920219783`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -47, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -47]][ t]], 
          Plus[ 
            Times[ 0.14938649372796314, 
              c[ -60][ t]], 
            Times[ 0.23387232094715985, 
              c[ -59][ t]], 
            Times[ 0.32256865202152113, 
              c[ -58][ t]], 
            Times[ 0.41349667156634362, 
              c[ -57][ t]], 
            Times[ 0.50455115242710469, 
              c[ -56][ t]], 
            Times[ 0.59356153372868015, 
              c[ -55][ t]], 
            Times[ 0.67835603854706272, 
              c[ -54][ t]], 
            Times[ 0.75682672864065692, 
              c[ -53][ t]], 
            Times[ 0.82699334313268802, 
              c[ -52][ t]], 
            Times[ 0.88706379305918348, 
              c[ -51][ t]], 
            Times[ 0.93548928378863916, 
              c[ -50][ t]], 
            Times[ 0.9710122092317629, 
              c[ -49][ t]], 
            Times[ 0.99270519960720671, 
              c[ -48][ t]], 
            Times[ 49.448791382236415, 
              c[ -47][ t]], 
            Times[ 0.99270519960720693, 
              c[ -46][ t]], 
            Times[ 0.9710122092317629, 
              c[ -45][ t]], 
            Times[ 0.93548928378863916, 
              c[ -44][ t]], 
            Times[ 0.88706379305918392, 
              c[ -43][ t]], 
            Times[ 0.82699334313268846, 
              c[ -42][ t]], 
            Times[ 0.75682672864065692, 
              c[ -41][ t]], 
            Times[ 0.67835603854706361, 
              c[ -40][ t]], 
            Times[ 0.59356153372868092, 
              c[ -39][ t]], 
            Times[ 0.50455115242710502, 
              c[ -38][ t]], 
            Times[ 0.41349667156634429, 
              c[ -37][ t]], 
            Times[ 0.32256865202152191, 
              c[ -36][ t]], 
            Times[ 0.23387232094716018, 
              c[ -35][ t]], 
            Times[ 0.14938649372796384, 
              c[ -34][ t]], 
            Times[ 0.070907514257658094, 
              c[ -33][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -32][ t]], 
            Times[ -0.062044074975450239, 
              c[ -31][ t]], 
            Times[ -0.11423673049785416, 
              c[ -30][ t]], 
            Times[ -0.15591488063143966, 
              c[ -29][ t]], 
            Times[ -0.18675027222298593, 
              c[ -28][ t]], 
            Times[ -0.20674833578317189, 
              c[ -27][ t]], 
            Times[ -0.21623620818304481, 
              c[ -26][ t]], 
            Times[ -0.21584055771952015, 
              c[ -25][ t]], 
            Times[ -0.20645618564475848, 
              c[ -24][ t]], 
            Times[ -0.18920668216016434, 
              c[ -23][ t]], 
            Times[ -0.16539866862653771, 
              c[ -22][ t]], 
            Times[ -0.13647135277833616, 
              c[ -21][ t]], 
            Times[ -0.1039432537542934, 
              c[ -20][ t]], 
            Times[ -0.06935801494512607, 
              c[ -19][ t]], 
            Times[ -0.034231213779559094, 
              c[ -18][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -17][ t]], 
            Times[ 0.032022748374425904, 
              c[ -16][ t]], 
            Times[ 0.060688263076985001, 
              c[ -15][ t]], 
            Times[ 0.085044480344421608, 
              c[ -14][ t]], 
            Times[ 0.10436044624225685, 
              c[ -13][ t]], 
            Times[ 0.11814190616181253, 
              c[ -12][ t]], 
            Times[ 0.12613778810677612, 
              c[ -11][ t]], 
            Times[ 0.12833762891430928, 
              c[ -10][ t]], 
            Times[ 0.12496032289024853, 
              c[ -9][ t]], 
            Times[ 0.11643488132933195, 
              c[ -8][ t]], 
            Times[ 0.10337416789158609, 
              c[ -7][ t]], 
            Times[ 0.086542809078944891, 
              c[ -6][ t]], 
            Times[ 0.066820663127760152, 
              c[ -5][ t]], 
            Times[ 0.045163358568919301, 
              c[ -4][ t]], 
            Times[ 0.022561481809254869, 
              c[ -3][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -2][ t]], 
            Times[ -0.021580547817547879, 
              c[ -1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 0][ t]], 
            Times[ -0.058468080236789774, 
              c[ 1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 2][ t]], 
            Times[ -0.082699334313268744, 
              c[ 3][ t]], 
            Times[ -0.089038438663606653, 
              c[ 4][ t]], 
            Times[ -0.091317159035181589, 
              c[ 5][ t]], 
            Times[ -0.089594193770366884, 
              c[ 6][ t]], 
            Times[ -0.084091858737850855, 
              c[ 7][ t]], 
            Times[ -0.075181213012062598, 
              c[ 8][ t]], 
            Times[ -0.063361699504227528, 
              c[ 9][ t]], 
            Times[ -0.049236278094139066, 
              c[ 10][ t]], 
            Times[ -0.033483179628681706, 
              c[ 11][ t]], 
            Times[ -0.016825511857749401, 
              c[ 12][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 13][ t]], 
            Times[ 0.016273855731265469, 
              c[ 14][ t]], 
            Times[ 0.031322974491347078, 
              c[ 15][ t]], 
            Times[ 0.044547108751839815, 
              c[ 16][ t]], 
            Times[ 0.055441487066198857, 
              c[ 17][ t]], 
            Times[ 0.063614872548668253, 
              c[ 18][ t]], 
            Times[ 0.068802429876423321, 
              c[ 19][ t]], 
            Times[ 0.070873018952678238, 
              c[ 20][ t]], 
            Times[ 0.069830768673962415, 
              c[ 21][ t]], 
            Times[ 0.065811019881796315, 
              c[ 22][ t]], 
            Times[ 0.059070953080906402, 
              c[ 23][ t]], 
            Times[ 0.049975424961080865, 
              c[ 24][ t]], 
            Times[ 0.038978720157860088, 
              c[ 25][ t]], 
            Times[ 0.026603074225527937, 
              c[ 26][ t]], 
            Times[ 0.013414935129827233, 
              c[ 27][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 28][ t]], 
            Times[ -0.013061910521147276, 
              c[ 29][ t]], 
            Times[ -0.025221096343682053, 
              c[ 30][ t]], 
            Times[ -0.035980357068793781, 
              c[ 31][ t]], 
            Times[ -0.044914622433376288, 
              c[ 32][ t]], 
            Times[ -0.05168708394579296, 
              c[ 33][ t]], 
            Times[ -0.05606123915856713, 
              c[ 34][ t]], 
            Times[ -0.057908442314993203, 
              c[ 35][ t]], 
            Times[ -0.057210750238908967, 
              c[ 36][ t]], 
            Times[ -0.054059052045761224, 
              c[ 37][ t]], 
            Times[ -0.048646667243099399, 
              c[ 38][ t]], 
            Times[ -0.041258781072520248, 
              c[ 39][ t]], 
            Times[ -0.032258251165125679, 
              c[ 40][ t]], 
            Times[ -0.022068459300722043, 
              c[ 41][ t]], 
            Times[ -0.011153991006822649, 
              c[ 42][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 43][ t]], 
            Times[ 0.010908848347331785, 
              c[ 44][ t]], 
            Times[ 0.021108961070255627, 
              c[ 45][ t]], 
            Times[ 0.030177073670601094, 
              c[ 46][ t]], 
            Times[ 0.03774739544932687, 
              c[ 47][ t]], 
            Times[ 0.043525965428036162, 
              c[ 48][ t]], 
            Times[ 0.047301670540041058, 
              c[ 49][ t]], 
            Times[ 0.048953528554942699, 
              c[ 50][ t]], 
            Times[ 0.048454002753361682, 
              c[ 51][ t]], 
            Times[ 0.045868286584282311, 
              c[ 52][ t]], 
            Times[ 0.041349667156634483, 
              c[ 53][ t]], 
            Times[ 0.035131239329076656, 
              c[ 54][ t]], 
            Times[ 0.027514390699665887, 
              c[ 55][ t]], 
            Times[ 0.018854606004500389, 
              c[ 56][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 57][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 58][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 59][ t]], 
            Times[ -0.018149760920219783, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-46\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-46\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.07090751425765746`\ \(c[\(-60\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-59\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-58\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-57\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-56\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-55\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-54\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-53\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-52\)]\)[t] + 
            0.826993343132688`\ \(c[\(-51\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-50\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-49\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-48\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-47\)]\)[t] + 
            47.40907313934462`\ \(c[\(-46\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-45\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-44\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-43\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-42\)]\)[t] + 
            0.826993343132688`\ \(c[\(-41\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-40\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-39\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-38\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-37\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-36\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-35\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-34\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-33\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-32\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-31\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-30\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-29\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-28\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-27\)]\)[t] - 
            0.206748335783172`\ \(c[\(-26\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-25\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-24\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-23\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-22\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-21\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-20\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-19\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-18\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-17\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-15\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-14\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-13\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-12\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-11\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-10\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-9\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-8\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-7\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-6\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-5\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-4\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-3\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-2\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-1\)]\)[t] - 
            0.02158054781754788`\ \(c[0]\)[t] - 
            0.04131966847794722`\ \(c[1]\)[t] - 
            0.05846808023678991`\ \(c[2]\)[t] - 
            0.07241337086197412`\ \(c[3]\)[t] - 
            0.08269933431326874`\ \(c[4]\)[t] - 
            0.0890384386636067`\ \(c[5]\)[t] - 
            0.09131715903518159`\ \(c[6]\)[t] - 
            0.08959419377036688`\ \(c[7]\)[t] - 
            0.08409185873785081`\ \(c[8]\)[t] - 
            0.0751812130120626`\ \(c[9]\)[t] - 
            0.06336169950422753`\ \(c[10]\)[t] - 
            0.04923627809413894`\ \(c[11]\)[t] - 
            0.03348317962868157`\ \(c[12]\)[t] - 
            0.0168255118577494`\ \(c[13]\)[t] - 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.016273855731265604`\ \(c[15]\)[t] + 
            0.03132297449134708`\ \(c[16]\)[t] + 
            0.04454710875183992`\ \(c[17]\)[t] + 
            0.05544148706619893`\ \(c[18]\)[t] + 
            0.06361487254866825`\ \(c[19]\)[t] + 
            0.06880242987642335`\ \(c[20]\)[t] + 
            0.07087301895267824`\ \(c[21]\)[t] + 
            0.06983076867396242`\ \(c[22]\)[t] + 
            0.06581101988179627`\ \(c[23]\)[t] + 
            0.059070953080906326`\ \(c[24]\)[t] + 
            0.049975424961080865`\ \(c[25]\)[t] + 
            0.03897872015785999`\ \(c[26]\)[t] + 
            0.026603074225527826`\ \(c[27]\)[t] + 
            0.013414935129827233`\ \(c[28]\)[t] + 
            3.898171832519376`*^-17\ \(c[29]\)[t] - 
            0.013061910521147383`\ \(c[30]\)[t] - 
            0.025221096343682053`\ \(c[31]\)[t] - 
            0.03598035706879378`\ \(c[32]\)[t] - 
            0.04491462243337642`\ \(c[33]\)[t] - 
            0.05168708394579296`\ \(c[34]\)[t] - 
            0.056061239158567186`\ \(c[35]\)[t] - 
            0.0579084423149932`\ \(c[36]\)[t] - 
            0.05721075023890897`\ \(c[37]\)[t] - 
            0.054059052045761224`\ \(c[38]\)[t] - 
            0.04864666724309928`\ \(c[39]\)[t] - 
            0.04125878107252025`\ \(c[40]\)[t] - 
            0.03225825116512568`\ \(c[41]\)[t] - 
            0.022068459300722043`\ \(c[42]\)[t] - 
            0.011153991006822649`\ \(c[43]\)[t] - 
            3.8981718325193755`*^-17\ \(c[44]\)[t] + 
            0.010908848347331966`\ \(c[45]\)[t] + 
            0.021108961070255627`\ \(c[46]\)[t] + 
            0.030177073670601094`\ \(c[47]\)[t] + 
            0.03774739544932687`\ \(c[48]\)[t] + 
            0.04352596542803616`\ \(c[49]\)[t] + 
            0.04730167054004106`\ \(c[50]\)[t] + 
            0.04895352855494272`\ \(c[51]\)[t] + 
            0.04845400275336168`\ \(c[52]\)[t] + 
            0.04586828658428231`\ \(c[53]\)[t] + 
            0.04134966715663448`\ \(c[54]\)[t] + 
            0.035131239329076656`\ \(c[55]\)[t] + 
            0.027514390699665887`\ \(c[56]\)[t] + 
            0.018854606004500233`\ \(c[57]\)[t] + 
            0.009545242303915543`\ \(c[58]\)[t] + 
            2.005337021455629`*^-16\ \(c[59]\)[t] - 
            0.009365143392520679`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -46, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -46]][ t]], 
          Plus[ 
            Times[ 0.070907514257657456, 
              c[ -60][ t]], 
            Times[ 0.14938649372796384, 
              c[ -59][ t]], 
            Times[ 0.23387232094715985, 
              c[ -58][ t]], 
            Times[ 0.32256865202152113, 
              c[ -57][ t]], 
            Times[ 0.41349667156634429, 
              c[ -56][ t]], 
            Times[ 0.50455115242710469, 
              c[ -55][ t]], 
            Times[ 0.59356153372868015, 
              c[ -54][ t]], 
            Times[ 0.67835603854706361, 
              c[ -53][ t]], 
            Times[ 0.75682672864065692, 
              c[ -52][ t]], 
            Times[ 0.82699334313268802, 
              c[ -51][ t]], 
            Times[ 0.88706379305918392, 
              c[ -50][ t]], 
            Times[ 0.93548928378863916, 
              c[ -49][ t]], 
            Times[ 0.9710122092317629, 
              c[ -48][ t]], 
            Times[ 0.99270519960720693, 
              c[ -47][ t]], 
            Times[ 47.409073139344621, 
              c[ -46][ t]], 
            Times[ 0.99270519960720693, 
              c[ -45][ t]], 
            Times[ 0.9710122092317629, 
              c[ -44][ t]], 
            Times[ 0.93548928378863916, 
              c[ -43][ t]], 
            Times[ 0.88706379305918392, 
              c[ -42][ t]], 
            Times[ 0.82699334313268802, 
              c[ -41][ t]], 
            Times[ 0.75682672864065692, 
              c[ -40][ t]], 
            Times[ 0.67835603854706361, 
              c[ -39][ t]], 
            Times[ 0.59356153372868059, 
              c[ -38][ t]], 
            Times[ 0.50455115242710469, 
              c[ -37][ t]], 
            Times[ 0.41349667156634429, 
              c[ -36][ t]], 
            Times[ 0.32256865202152157, 
              c[ -35][ t]], 
            Times[ 0.23387232094715985, 
              c[ -34][ t]], 
            Times[ 0.14938649372796384, 
              c[ -33][ t]], 
            Times[ 0.070907514257657775, 
              c[ -32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -31][ t]], 
            Times[ -0.062044074975450239, 
              c[ -30][ t]], 
            Times[ -0.11423673049785436, 
              c[ -29][ t]], 
            Times[ -0.15591488063143982, 
              c[ -28][ t]], 
            Times[ -0.18675027222298593, 
              c[ -27][ t]], 
            Times[ -0.206748335783172, 
              c[ -26][ t]], 
            Times[ -0.21623620818304484, 
              c[ -25][ t]], 
            Times[ -0.21584055771952015, 
              c[ -24][ t]], 
            Times[ -0.20645618564475843, 
              c[ -23][ t]], 
            Times[ -0.18920668216016426, 
              c[ -22][ t]], 
            Times[ -0.16539866862653771, 
              c[ -21][ t]], 
            Times[ -0.13647135277833605, 
              c[ -20][ t]], 
            Times[ -0.10394325375429328, 
              c[ -19][ t]], 
            Times[ -0.06935801494512607, 
              c[ -18][ t]], 
            Times[ -0.034231213779558949, 
              c[ -17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ 0.032022748374425904, 
              c[ -15][ t]], 
            Times[ 0.060688263076985105, 
              c[ -14][ t]], 
            Times[ 0.085044480344421705, 
              c[ -13][ t]], 
            Times[ 0.10436044624225685, 
              c[ -12][ t]], 
            Times[ 0.11814190616181255, 
              c[ -11][ t]], 
            Times[ 0.12613778810677614, 
              c[ -10][ t]], 
            Times[ 0.12833762891430928, 
              c[ -9][ t]], 
            Times[ 0.12496032289024853, 
              c[ -8][ t]], 
            Times[ 0.11643488132933186, 
              c[ -7][ t]], 
            Times[ 0.10337416789158609, 
              c[ -6][ t]], 
            Times[ 0.086542809078944891, 
              c[ -5][ t]], 
            Times[ 0.066820663127759972, 
              c[ -4][ t]], 
            Times[ 0.045163358568919301, 
              c[ -3][ t]], 
            Times[ 0.022561481809254869, 
              c[ -2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 0][ t]], 
            Times[ -0.04131966847794722, 
              c[ 1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 2][ t]], 
            Times[ -0.072413370861974122, 
              c[ 3][ t]], 
            Times[ -0.082699334313268744, 
              c[ 4][ t]], 
            Times[ -0.089038438663606695, 
              c[ 5][ t]], 
            Times[ -0.091317159035181589, 
              c[ 6][ t]], 
            Times[ -0.089594193770366884, 
              c[ 7][ t]], 
            Times[ -0.084091858737850814, 
              c[ 8][ t]], 
            Times[ -0.075181213012062598, 
              c[ 9][ t]], 
            Times[ -0.063361699504227528, 
              c[ 10][ t]], 
            Times[ -0.049236278094138941, 
              c[ 11][ t]], 
            Times[ -0.033483179628681567, 
              c[ 12][ t]], 
            Times[ -0.016825511857749401, 
              c[ 13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.016273855731265604, 
              c[ 15][ t]], 
            Times[ 0.031322974491347078, 
              c[ 16][ t]], 
            Times[ 0.044547108751839919, 
              c[ 17][ t]], 
            Times[ 0.055441487066198933, 
              c[ 18][ t]], 
            Times[ 0.063614872548668253, 
              c[ 19][ t]], 
            Times[ 0.068802429876423349, 
              c[ 20][ t]], 
            Times[ 0.070873018952678238, 
              c[ 21][ t]], 
            Times[ 0.069830768673962415, 
              c[ 22][ t]], 
            Times[ 0.065811019881796273, 
              c[ 23][ t]], 
            Times[ 0.059070953080906326, 
              c[ 24][ t]], 
            Times[ 0.049975424961080865, 
              c[ 25][ t]], 
            Times[ 0.03897872015785999, 
              c[ 26][ t]], 
            Times[ 0.026603074225527826, 
              c[ 27][ t]], 
            Times[ 0.013414935129827233, 
              c[ 28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ -0.013061910521147383, 
              c[ 30][ t]], 
            Times[ -0.025221096343682053, 
              c[ 31][ t]], 
            Times[ -0.035980357068793781, 
              c[ 32][ t]], 
            Times[ -0.044914622433376419, 
              c[ 33][ t]], 
            Times[ -0.05168708394579296, 
              c[ 34][ t]], 
            Times[ -0.056061239158567186, 
              c[ 35][ t]], 
            Times[ -0.057908442314993203, 
              c[ 36][ t]], 
            Times[ -0.057210750238908967, 
              c[ 37][ t]], 
            Times[ -0.054059052045761224, 
              c[ 38][ t]], 
            Times[ -0.048646667243099281, 
              c[ 39][ t]], 
            Times[ -0.041258781072520248, 
              c[ 40][ t]], 
            Times[ -0.032258251165125679, 
              c[ 41][ t]], 
            Times[ -0.022068459300722043, 
              c[ 42][ t]], 
            Times[ -0.011153991006822649, 
              c[ 43][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 44][ t]], 
            Times[ 0.010908848347331966, 
              c[ 45][ t]], 
            Times[ 0.021108961070255627, 
              c[ 46][ t]], 
            Times[ 0.030177073670601094, 
              c[ 47][ t]], 
            Times[ 0.03774739544932687, 
              c[ 48][ t]], 
            Times[ 0.043525965428036162, 
              c[ 49][ t]], 
            Times[ 0.047301670540041058, 
              c[ 50][ t]], 
            Times[ 0.04895352855494272, 
              c[ 51][ t]], 
            Times[ 0.048454002753361682, 
              c[ 52][ t]], 
            Times[ 0.045868286584282311, 
              c[ 53][ t]], 
            Times[ 0.041349667156634483, 
              c[ 54][ t]], 
            Times[ 0.035131239329076656, 
              c[ 55][ t]], 
            Times[ 0.027514390699665887, 
              c[ 56][ t]], 
            Times[ 0.018854606004500233, 
              c[ 57][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 58][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ 59][ t]], 
            Times[ -0.0093651433925206785, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-45\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-45\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.898171832519376`*^-17\ \(c[\(-60\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-59\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-58\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-57\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-56\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-55\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-54\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-53\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-52\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-51\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-50\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-49\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-48\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-47\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-46\)]\)[t] + 
            45.41321980490211`\ \(c[\(-45\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-44\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-43\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-42\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-41\)]\)[t] + 
            0.826993343132688`\ \(c[\(-40\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-39\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-38\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-37\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-36\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-35\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-34\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-33\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-32\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-29\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-28\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-27\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-26\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-25\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-24\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-23\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-22\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-21\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-20\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-19\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-18\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-17\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-14\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-13\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-12\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-11\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-10\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-9\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-8\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-7\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-6\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-5\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-4\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-3\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-2\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-1\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[0]\)[t] - 
            0.02158054781754788`\ \(c[1]\)[t] - 
            0.04131966847794737`\ \(c[2]\)[t] - 
            0.05846808023678991`\ \(c[3]\)[t] - 
            0.07241337086197412`\ \(c[4]\)[t] - 
            0.08269933431326881`\ \(c[5]\)[t] - 
            0.0890384386636067`\ \(c[6]\)[t] - 
            0.09131715903518159`\ \(c[7]\)[t] - 
            0.08959419377036684`\ \(c[8]\)[t] - 
            0.08409185873785081`\ \(c[9]\)[t] - 
            0.0751812130120626`\ \(c[10]\)[t] - 
            0.06336169950422753`\ \(c[11]\)[t] - 
            0.04923627809413894`\ \(c[12]\)[t] - 
            0.03348317962868157`\ \(c[13]\)[t] - 
            0.0168255118577494`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.016273855731265604`\ \(c[16]\)[t] + 
            0.03132297449134708`\ \(c[17]\)[t] + 
            0.04454710875183992`\ \(c[18]\)[t] + 
            0.05544148706619893`\ \(c[19]\)[t] + 
            0.06361487254866825`\ \(c[20]\)[t] + 
            0.06880242987642335`\ \(c[21]\)[t] + 
            0.07087301895267824`\ \(c[22]\)[t] + 
            0.06983076867396242`\ \(c[23]\)[t] + 
            0.06581101988179627`\ \(c[24]\)[t] + 
            0.059070953080906326`\ \(c[25]\)[t] + 
            0.049975424961080865`\ \(c[26]\)[t] + 
            0.03897872015785999`\ \(c[27]\)[t] + 
            0.026603074225527826`\ \(c[28]\)[t] + 
            0.013414935129827233`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.013061910521147383`\ \(c[31]\)[t] - 
            0.025221096343682053`\ \(c[32]\)[t] - 
            0.03598035706879378`\ \(c[33]\)[t] - 
            0.04491462243337642`\ \(c[34]\)[t] - 
            0.05168708394579296`\ \(c[35]\)[t] - 
            0.056061239158567186`\ \(c[36]\)[t] - 
            0.0579084423149932`\ \(c[37]\)[t] - 
            0.05721075023890897`\ \(c[38]\)[t] - 
            0.054059052045761224`\ \(c[39]\)[t] - 
            0.04864666724309928`\ \(c[40]\)[t] - 
            0.04125878107252025`\ \(c[41]\)[t] - 
            0.03225825116512552`\ \(c[42]\)[t] - 
            0.022068459300722043`\ \(c[43]\)[t] - 
            0.011153991006822649`\ \(c[44]\)[t] - 
            3.8981718325193755`*^-17\ \(c[45]\)[t] + 
            0.010908848347331966`\ \(c[46]\)[t] + 
            0.021108961070255627`\ \(c[47]\)[t] + 
            0.030177073670601236`\ \(c[48]\)[t] + 
            0.03774739544932687`\ \(c[49]\)[t] + 
            0.04352596542803616`\ \(c[50]\)[t] + 
            0.04730167054004106`\ \(c[51]\)[t] + 
            0.04895352855494272`\ \(c[52]\)[t] + 
            0.04845400275336168`\ \(c[53]\)[t] + 
            0.045868286584282256`\ \(c[54]\)[t] + 
            0.04134966715663448`\ \(c[55]\)[t] + 
            0.035131239329076656`\ \(c[56]\)[t] + 
            0.027514390699665887`\ \(c[57]\)[t] + 
            0.018854606004500233`\ \(c[58]\)[t] + 
            0.009545242303915543`\ \(c[59]\)[t] + 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -45, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -45]][ t]], 
          Plus[ 
            Times[ 3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ 0.070907514257658094, 
              c[ -59][ t]], 
            Times[ 0.14938649372796384, 
              c[ -58][ t]], 
            Times[ 0.23387232094715985, 
              c[ -57][ t]], 
            Times[ 0.32256865202152191, 
              c[ -56][ t]], 
            Times[ 0.41349667156634429, 
              c[ -55][ t]], 
            Times[ 0.50455115242710469, 
              c[ -54][ t]], 
            Times[ 0.59356153372868092, 
              c[ -53][ t]], 
            Times[ 0.67835603854706361, 
              c[ -52][ t]], 
            Times[ 0.75682672864065692, 
              c[ -51][ t]], 
            Times[ 0.82699334313268846, 
              c[ -50][ t]], 
            Times[ 0.88706379305918392, 
              c[ -49][ t]], 
            Times[ 0.93548928378863916, 
              c[ -48][ t]], 
            Times[ 0.9710122092317629, 
              c[ -47][ t]], 
            Times[ 0.99270519960720693, 
              c[ -46][ t]], 
            Times[ 45.413219804902113, 
              c[ -45][ t]], 
            Times[ 0.99270519960720671, 
              c[ -44][ t]], 
            Times[ 0.9710122092317629, 
              c[ -43][ t]], 
            Times[ 0.93548928378863916, 
              c[ -42][ t]], 
            Times[ 0.88706379305918348, 
              c[ -41][ t]], 
            Times[ 0.82699334313268802, 
              c[ -40][ t]], 
            Times[ 0.75682672864065692, 
              c[ -39][ t]], 
            Times[ 0.67835603854706317, 
              c[ -38][ t]], 
            Times[ 0.59356153372868015, 
              c[ -37][ t]], 
            Times[ 0.50455115242710469, 
              c[ -36][ t]], 
            Times[ 0.41349667156634395, 
              c[ -35][ t]], 
            Times[ 0.32256865202152113, 
              c[ -34][ t]], 
            Times[ 0.23387232094715985, 
              c[ -33][ t]], 
            Times[ 0.14938649372796345, 
              c[ -32][ t]], 
            Times[ 0.070907514257657456, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.062044074975450475, 
              c[ -29][ t]], 
            Times[ -0.11423673049785459, 
              c[ -28][ t]], 
            Times[ -0.15591488063143982, 
              c[ -27][ t]], 
            Times[ -0.18675027222298607, 
              c[ -26][ t]], 
            Times[ -0.20674833578317206, 
              c[ -25][ t]], 
            Times[ -0.21623620818304484, 
              c[ -24][ t]], 
            Times[ -0.21584055771952013, 
              c[ -23][ t]], 
            Times[ -0.20645618564475834, 
              c[ -22][ t]], 
            Times[ -0.18920668216016426, 
              c[ -21][ t]], 
            Times[ -0.1653986686265376, 
              c[ -20][ t]], 
            Times[ -0.13647135277833591, 
              c[ -19][ t]], 
            Times[ -0.10394325375429328, 
              c[ -18][ t]], 
            Times[ -0.069358014945125918, 
              c[ -17][ t]], 
            Times[ -0.034231213779558796, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.032022748374426029, 
              c[ -14][ t]], 
            Times[ 0.060688263076985223, 
              c[ -13][ t]], 
            Times[ 0.085044480344421705, 
              c[ -12][ t]], 
            Times[ 0.10436044624225692, 
              c[ -11][ t]], 
            Times[ 0.1181419061618126, 
              c[ -10][ t]], 
            Times[ 0.12613778810677614, 
              c[ -9][ t]], 
            Times[ 0.12833762891430925, 
              c[ -8][ t]], 
            Times[ 0.12496032289024847, 
              c[ -7][ t]], 
            Times[ 0.11643488132933186, 
              c[ -6][ t]], 
            Times[ 0.10337416789158609, 
              c[ -5][ t]], 
            Times[ 0.086542809078944752, 
              c[ -4][ t]], 
            Times[ 0.066820663127759972, 
              c[ -3][ t]], 
            Times[ 0.045163358568919301, 
              c[ -2][ t]], 
            Times[ 0.022561481809254675, 
              c[ -1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 0][ t]], 
            Times[ -0.021580547817547879, 
              c[ 1][ t]], 
            Times[ -0.041319668477947373, 
              c[ 2][ t]], 
            Times[ -0.058468080236789913, 
              c[ 3][ t]], 
            Times[ -0.072413370861974122, 
              c[ 4][ t]], 
            Times[ -0.082699334313268813, 
              c[ 5][ t]], 
            Times[ -0.089038438663606695, 
              c[ 6][ t]], 
            Times[ -0.091317159035181589, 
              c[ 7][ t]], 
            Times[ -0.089594193770366842, 
              c[ 8][ t]], 
            Times[ -0.084091858737850814, 
              c[ 9][ t]], 
            Times[ -0.075181213012062598, 
              c[ 10][ t]], 
            Times[ -0.063361699504227528, 
              c[ 11][ t]], 
            Times[ -0.049236278094138941, 
              c[ 12][ t]], 
            Times[ -0.033483179628681567, 
              c[ 13][ t]], 
            Times[ -0.016825511857749401, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.016273855731265604, 
              c[ 16][ t]], 
            Times[ 0.031322974491347078, 
              c[ 17][ t]], 
            Times[ 0.044547108751839919, 
              c[ 18][ t]], 
            Times[ 0.055441487066198933, 
              c[ 19][ t]], 
            Times[ 0.063614872548668253, 
              c[ 20][ t]], 
            Times[ 0.068802429876423349, 
              c[ 21][ t]], 
            Times[ 0.070873018952678238, 
              c[ 22][ t]], 
            Times[ 0.069830768673962415, 
              c[ 23][ t]], 
            Times[ 0.065811019881796273, 
              c[ 24][ t]], 
            Times[ 0.059070953080906326, 
              c[ 25][ t]], 
            Times[ 0.049975424961080865, 
              c[ 26][ t]], 
            Times[ 0.03897872015785999, 
              c[ 27][ t]], 
            Times[ 0.026603074225527826, 
              c[ 28][ t]], 
            Times[ 0.013414935129827233, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.013061910521147383, 
              c[ 31][ t]], 
            Times[ -0.025221096343682053, 
              c[ 32][ t]], 
            Times[ -0.035980357068793781, 
              c[ 33][ t]], 
            Times[ -0.044914622433376419, 
              c[ 34][ t]], 
            Times[ -0.05168708394579296, 
              c[ 35][ t]], 
            Times[ -0.056061239158567186, 
              c[ 36][ t]], 
            Times[ -0.057908442314993203, 
              c[ 37][ t]], 
            Times[ -0.057210750238908967, 
              c[ 38][ t]], 
            Times[ -0.054059052045761224, 
              c[ 39][ t]], 
            Times[ -0.048646667243099281, 
              c[ 40][ t]], 
            Times[ -0.041258781072520248, 
              c[ 41][ t]], 
            Times[ -0.032258251165125519, 
              c[ 42][ t]], 
            Times[ -0.022068459300722043, 
              c[ 43][ t]], 
            Times[ -0.011153991006822649, 
              c[ 44][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ 0.010908848347331966, 
              c[ 46][ t]], 
            Times[ 0.021108961070255627, 
              c[ 47][ t]], 
            Times[ 0.030177073670601236, 
              c[ 48][ t]], 
            Times[ 0.03774739544932687, 
              c[ 49][ t]], 
            Times[ 0.043525965428036162, 
              c[ 50][ t]], 
            Times[ 0.047301670540041058, 
              c[ 51][ t]], 
            Times[ 0.04895352855494272, 
              c[ 52][ t]], 
            Times[ 0.048454002753361682, 
              c[ 53][ t]], 
            Times[ 0.045868286584282256, 
              c[ 54][ t]], 
            Times[ 0.041349667156634483, 
              c[ 55][ t]], 
            Times[ 0.035131239329076656, 
              c[ 56][ t]], 
            Times[ 0.027514390699665887, 
              c[ 57][ t]], 
            Times[ 0.018854606004500233, 
              c[ 58][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-44\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-44\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.06204407497545072`\)\ \(c[\(-60\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-59\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-58\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-57\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-56\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-55\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-54\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-53\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-52\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-51\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-50\)]\)[t] + 
            0.826993343132688`\ \(c[\(-49\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-48\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-47\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-46\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-45\)]\)[t] + 
            43.46123137890887`\ \(c[\(-44\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-43\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-42\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-41\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-40\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-39\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-38\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-37\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-36\)]\)[t] + 
            0.504551152427105`\ \(c[\(-35\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-34\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-33\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-32\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-31\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-30\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-29\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-28\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-27\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-26\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-25\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-24\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-23\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-22\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-21\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-20\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-19\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-18\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-17\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-16\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-15\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-14\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-13\)]\)[t] + 
            0.060688263076985`\ \(c[\(-12\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-11\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-10\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-9\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-8\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-7\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-6\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-5\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-4\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-3\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-2\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-1\)]\)[t] + 
            0.02256148180925487`\ \(c[0]\)[t] + 
            2.274590327822911`*^-16\ \(c[1]\)[t] - 
            0.02158054781754788`\ \(c[2]\)[t] - 
            0.04131966847794722`\ \(c[3]\)[t] - 
            0.058468080236789774`\ \(c[4]\)[t] - 
            0.07241337086197412`\ \(c[5]\)[t] - 
            0.08269933431326874`\ \(c[6]\)[t] - 
            0.08903843866360665`\ \(c[7]\)[t] - 
            0.09131715903518159`\ \(c[8]\)[t] - 
            0.08959419377036688`\ \(c[9]\)[t] - 
            0.08409185873785086`\ \(c[10]\)[t] - 
            0.0751812130120627`\ \(c[11]\)[t] - 
            0.06336169950422753`\ \(c[12]\)[t] - 
            0.049236278094139066`\ \(c[13]\)[t] - 
            0.033483179628681706`\ \(c[14]\)[t] - 
            0.0168255118577494`\ \(c[15]\)[t] - 
            1.8033970416801674`*^-16\ \(c[16]\)[t] + 
            0.01627385573126547`\ \(c[17]\)[t] + 
            0.03132297449134708`\ \(c[18]\)[t] + 
            0.044547108751839815`\ \(c[19]\)[t] + 
            0.055441487066198857`\ \(c[20]\)[t] + 
            0.06361487254866825`\ \(c[21]\)[t] + 
            0.06880242987642332`\ \(c[22]\)[t] + 
            0.07087301895267824`\ \(c[23]\)[t] + 
            0.06983076867396242`\ \(c[24]\)[t] + 
            0.06581101988179631`\ \(c[25]\)[t] + 
            0.0590709530809064`\ \(c[26]\)[t] + 
            0.049975424961080865`\ \(c[27]\)[t] + 
            0.03897872015786009`\ \(c[28]\)[t] + 
            0.026603074225527937`\ \(c[29]\)[t] + 
            0.013414935129827233`\ \(c[30]\)[t] + 
            1.5206810699945212`*^-16\ \(c[31]\)[t] - 
            0.013061910521147276`\ \(c[32]\)[t] - 
            0.025221096343682053`\ \(c[33]\)[t] - 
            0.03598035706879378`\ \(c[34]\)[t] - 
            0.04491462243337629`\ \(c[35]\)[t] - 
            0.05168708394579296`\ \(c[36]\)[t] - 
            0.05606123915856713`\ \(c[37]\)[t] - 
            0.0579084423149932`\ \(c[38]\)[t] - 
            0.05721075023890897`\ \(c[39]\)[t] - 
            0.054059052045761224`\ \(c[40]\)[t] - 
            0.0486466672430994`\ \(c[41]\)[t] - 
            0.04125878107252025`\ \(c[42]\)[t] - 
            0.03225825116512568`\ \(c[43]\)[t] - 
            0.022068459300722043`\ \(c[44]\)[t] - 
            0.011153991006822649`\ \(c[45]\)[t] - 
            3.8981718325193755`*^-17\ \(c[46]\)[t] + 
            0.010908848347331785`\ \(c[47]\)[t] + 
            0.021108961070255627`\ \(c[48]\)[t] + 
            0.030177073670601094`\ \(c[49]\)[t] + 
            0.03774739544932687`\ \(c[50]\)[t] + 
            0.04352596542803616`\ \(c[51]\)[t] + 
            0.04730167054004106`\ \(c[52]\)[t] + 
            0.0489535285549427`\ \(c[53]\)[t] + 
            0.04845400275336168`\ \(c[54]\)[t] + 
            0.04586828658428231`\ \(c[55]\)[t] + 
            0.04134966715663448`\ \(c[56]\)[t] + 
            0.035131239329076656`\ \(c[57]\)[t] + 
            0.027514390699665887`\ \(c[58]\)[t] + 
            0.01885460600450039`\ \(c[59]\)[t] + 
            0.009545242303915543`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -44, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -44]][ t]], 
          Plus[ 
            Times[ -0.062044074975450718, 
              c[ -60][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -59][ t]], 
            Times[ 0.070907514257657456, 
              c[ -58][ t]], 
            Times[ 0.14938649372796314, 
              c[ -57][ t]], 
            Times[ 0.23387232094715985, 
              c[ -56][ t]], 
            Times[ 0.32256865202152113, 
              c[ -55][ t]], 
            Times[ 0.41349667156634362, 
              c[ -54][ t]], 
            Times[ 0.50455115242710469, 
              c[ -53][ t]], 
            Times[ 0.59356153372868015, 
              c[ -52][ t]], 
            Times[ 0.67835603854706272, 
              c[ -51][ t]], 
            Times[ 0.75682672864065692, 
              c[ -50][ t]], 
            Times[ 0.82699334313268802, 
              c[ -49][ t]], 
            Times[ 0.88706379305918348, 
              c[ -48][ t]], 
            Times[ 0.93548928378863916, 
              c[ -47][ t]], 
            Times[ 0.9710122092317629, 
              c[ -46][ t]], 
            Times[ 0.99270519960720671, 
              c[ -45][ t]], 
            Times[ 43.46123137890887, 
              c[ -44][ t]], 
            Times[ 0.99270519960720693, 
              c[ -43][ t]], 
            Times[ 0.9710122092317629, 
              c[ -42][ t]], 
            Times[ 0.93548928378863916, 
              c[ -41][ t]], 
            Times[ 0.88706379305918392, 
              c[ -40][ t]], 
            Times[ 0.82699334313268846, 
              c[ -39][ t]], 
            Times[ 0.75682672864065736, 
              c[ -38][ t]], 
            Times[ 0.67835603854706361, 
              c[ -37][ t]], 
            Times[ 0.59356153372868092, 
              c[ -36][ t]], 
            Times[ 0.50455115242710502, 
              c[ -35][ t]], 
            Times[ 0.41349667156634429, 
              c[ -34][ t]], 
            Times[ 0.32256865202152191, 
              c[ -33][ t]], 
            Times[ 0.23387232094716018, 
              c[ -32][ t]], 
            Times[ 0.14938649372796384, 
              c[ -31][ t]], 
            Times[ 0.070907514257658094, 
              c[ -30][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -29][ t]], 
            Times[ -0.062044074975450239, 
              c[ -28][ t]], 
            Times[ -0.11423673049785416, 
              c[ -27][ t]], 
            Times[ -0.15591488063143966, 
              c[ -26][ t]], 
            Times[ -0.18675027222298593, 
              c[ -25][ t]], 
            Times[ -0.20674833578317189, 
              c[ -24][ t]], 
            Times[ -0.21623620818304481, 
              c[ -23][ t]], 
            Times[ -0.21584055771952015, 
              c[ -22][ t]], 
            Times[ -0.20645618564475848, 
              c[ -21][ t]], 
            Times[ -0.18920668216016434, 
              c[ -20][ t]], 
            Times[ -0.16539866862653771, 
              c[ -19][ t]], 
            Times[ -0.13647135277833616, 
              c[ -18][ t]], 
            Times[ -0.1039432537542934, 
              c[ -17][ t]], 
            Times[ -0.06935801494512607, 
              c[ -16][ t]], 
            Times[ -0.034231213779559094, 
              c[ -15][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -14][ t]], 
            Times[ 0.032022748374425904, 
              c[ -13][ t]], 
            Times[ 0.060688263076985001, 
              c[ -12][ t]], 
            Times[ 0.085044480344421608, 
              c[ -11][ t]], 
            Times[ 0.10436044624225685, 
              c[ -10][ t]], 
            Times[ 0.11814190616181253, 
              c[ -9][ t]], 
            Times[ 0.12613778810677612, 
              c[ -8][ t]], 
            Times[ 0.12833762891430928, 
              c[ -7][ t]], 
            Times[ 0.12496032289024853, 
              c[ -6][ t]], 
            Times[ 0.11643488132933195, 
              c[ -5][ t]], 
            Times[ 0.10337416789158609, 
              c[ -4][ t]], 
            Times[ 0.086542809078944891, 
              c[ -3][ t]], 
            Times[ 0.066820663127760152, 
              c[ -2][ t]], 
            Times[ 0.045163358568919301, 
              c[ -1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 0][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 2][ t]], 
            Times[ -0.04131966847794722, 
              c[ 3][ t]], 
            Times[ -0.058468080236789774, 
              c[ 4][ t]], 
            Times[ -0.072413370861974122, 
              c[ 5][ t]], 
            Times[ -0.082699334313268744, 
              c[ 6][ t]], 
            Times[ -0.089038438663606653, 
              c[ 7][ t]], 
            Times[ -0.091317159035181589, 
              c[ 8][ t]], 
            Times[ -0.089594193770366884, 
              c[ 9][ t]], 
            Times[ -0.084091858737850855, 
              c[ 10][ t]], 
            Times[ -0.075181213012062695, 
              c[ 11][ t]], 
            Times[ -0.063361699504227528, 
              c[ 12][ t]], 
            Times[ -0.049236278094139066, 
              c[ 13][ t]], 
            Times[ -0.033483179628681706, 
              c[ 14][ t]], 
            Times[ -0.016825511857749401, 
              c[ 15][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 16][ t]], 
            Times[ 0.016273855731265469, 
              c[ 17][ t]], 
            Times[ 0.031322974491347078, 
              c[ 18][ t]], 
            Times[ 0.044547108751839815, 
              c[ 19][ t]], 
            Times[ 0.055441487066198857, 
              c[ 20][ t]], 
            Times[ 0.063614872548668253, 
              c[ 21][ t]], 
            Times[ 0.068802429876423321, 
              c[ 22][ t]], 
            Times[ 0.070873018952678238, 
              c[ 23][ t]], 
            Times[ 0.069830768673962415, 
              c[ 24][ t]], 
            Times[ 0.065811019881796315, 
              c[ 25][ t]], 
            Times[ 0.059070953080906402, 
              c[ 26][ t]], 
            Times[ 0.049975424961080865, 
              c[ 27][ t]], 
            Times[ 0.038978720157860088, 
              c[ 28][ t]], 
            Times[ 0.026603074225527937, 
              c[ 29][ t]], 
            Times[ 0.013414935129827233, 
              c[ 30][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 31][ t]], 
            Times[ -0.013061910521147276, 
              c[ 32][ t]], 
            Times[ -0.025221096343682053, 
              c[ 33][ t]], 
            Times[ -0.035980357068793781, 
              c[ 34][ t]], 
            Times[ -0.044914622433376288, 
              c[ 35][ t]], 
            Times[ -0.05168708394579296, 
              c[ 36][ t]], 
            Times[ -0.05606123915856713, 
              c[ 37][ t]], 
            Times[ -0.057908442314993203, 
              c[ 38][ t]], 
            Times[ -0.057210750238908967, 
              c[ 39][ t]], 
            Times[ -0.054059052045761224, 
              c[ 40][ t]], 
            Times[ -0.048646667243099399, 
              c[ 41][ t]], 
            Times[ -0.041258781072520248, 
              c[ 42][ t]], 
            Times[ -0.032258251165125679, 
              c[ 43][ t]], 
            Times[ -0.022068459300722043, 
              c[ 44][ t]], 
            Times[ -0.011153991006822649, 
              c[ 45][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 46][ t]], 
            Times[ 0.010908848347331785, 
              c[ 47][ t]], 
            Times[ 0.021108961070255627, 
              c[ 48][ t]], 
            Times[ 0.030177073670601094, 
              c[ 49][ t]], 
            Times[ 0.03774739544932687, 
              c[ 50][ t]], 
            Times[ 0.043525965428036162, 
              c[ 51][ t]], 
            Times[ 0.047301670540041058, 
              c[ 52][ t]], 
            Times[ 0.048953528554942699, 
              c[ 53][ t]], 
            Times[ 0.048454002753361682, 
              c[ 54][ t]], 
            Times[ 0.045868286584282311, 
              c[ 55][ t]], 
            Times[ 0.041349667156634483, 
              c[ 56][ t]], 
            Times[ 0.035131239329076656, 
              c[ 57][ t]], 
            Times[ 0.027514390699665887, 
              c[ 58][ t]], 
            Times[ 0.018854606004500389, 
              c[ 59][ t]], 
            Times[ 0.0095452423039155427, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-43\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-43\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.11423673049785459`\)\ \(c[\(-60\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-59\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-57\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-56\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-55\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-54\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-53\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-52\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-51\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-50\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-49\)]\)[t] + 
            0.826993343132688`\ \(c[\(-48\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-47\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-46\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-45\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-44\)]\)[t] + 
            41.553107861364936`\ \(c[\(-43\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-42\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-41\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-40\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-39\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-38\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-37\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-36\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-35\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-34\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-33\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-32\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-31\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-30\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-29\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-27\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-26\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-25\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-24\)]\)[t] - 
            0.206748335783172`\ \(c[\(-23\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-22\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-21\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-20\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-19\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-18\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-17\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-16\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-15\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-14\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-12\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-11\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-10\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-9\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-8\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-7\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-6\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-5\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-4\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-3\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-2\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-1\)]\)[t] + 
            0.0451633585689193`\ \(c[0]\)[t] + 
            0.02256148180925487`\ \(c[1]\)[t] + 
            3.8981718325193755`*^-17\ \(c[2]\)[t] - 
            0.02158054781754788`\ \(c[3]\)[t] - 
            0.04131966847794722`\ \(c[4]\)[t] - 
            0.05846808023678991`\ \(c[5]\)[t] - 
            0.07241337086197412`\ \(c[6]\)[t] - 
            0.08269933431326874`\ \(c[7]\)[t] - 
            0.0890384386636067`\ \(c[8]\)[t] - 
            0.09131715903518159`\ \(c[9]\)[t] - 
            0.08959419377036688`\ \(c[10]\)[t] - 
            0.08409185873785081`\ \(c[11]\)[t] - 
            0.0751812130120626`\ \(c[12]\)[t] - 
            0.06336169950422753`\ \(c[13]\)[t] - 
            0.04923627809413894`\ \(c[14]\)[t] - 
            0.03348317962868157`\ \(c[15]\)[t] - 
            0.0168255118577494`\ \(c[16]\)[t] - 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.016273855731265604`\ \(c[18]\)[t] + 
            0.03132297449134708`\ \(c[19]\)[t] + 
            0.04454710875183992`\ \(c[20]\)[t] + 
            0.05544148706619893`\ \(c[21]\)[t] + 
            0.06361487254866825`\ \(c[22]\)[t] + 
            0.06880242987642335`\ \(c[23]\)[t] + 
            0.07087301895267824`\ \(c[24]\)[t] + 
            0.06983076867396242`\ \(c[25]\)[t] + 
            0.06581101988179627`\ \(c[26]\)[t] + 
            0.059070953080906326`\ \(c[27]\)[t] + 
            0.049975424961080865`\ \(c[28]\)[t] + 
            0.03897872015785999`\ \(c[29]\)[t] + 
            0.026603074225527826`\ \(c[30]\)[t] + 
            0.013414935129827233`\ \(c[31]\)[t] + 
            3.898171832519376`*^-17\ \(c[32]\)[t] - 
            0.013061910521147383`\ \(c[33]\)[t] - 
            0.025221096343682053`\ \(c[34]\)[t] - 
            0.03598035706879378`\ \(c[35]\)[t] - 
            0.04491462243337642`\ \(c[36]\)[t] - 
            0.05168708394579296`\ \(c[37]\)[t] - 
            0.056061239158567186`\ \(c[38]\)[t] - 
            0.0579084423149932`\ \(c[39]\)[t] - 
            0.05721075023890897`\ \(c[40]\)[t] - 
            0.054059052045761224`\ \(c[41]\)[t] - 
            0.04864666724309928`\ \(c[42]\)[t] - 
            0.04125878107252025`\ \(c[43]\)[t] - 
            0.03225825116512568`\ \(c[44]\)[t] - 
            0.022068459300722043`\ \(c[45]\)[t] - 
            0.011153991006822649`\ \(c[46]\)[t] - 
            3.8981718325193755`*^-17\ \(c[47]\)[t] + 
            0.010908848347331966`\ \(c[48]\)[t] + 
            0.021108961070255627`\ \(c[49]\)[t] + 
            0.030177073670601094`\ \(c[50]\)[t] + 
            0.03774739544932687`\ \(c[51]\)[t] + 
            0.04352596542803616`\ \(c[52]\)[t] + 
            0.04730167054004106`\ \(c[53]\)[t] + 
            0.04895352855494272`\ \(c[54]\)[t] + 
            0.04845400275336168`\ \(c[55]\)[t] + 
            0.04586828658428231`\ \(c[56]\)[t] + 
            0.04134966715663448`\ \(c[57]\)[t] + 
            0.035131239329076656`\ \(c[58]\)[t] + 
            0.027514390699665887`\ \(c[59]\)[t] + 
            0.018854606004500233`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -43, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -43]][ t]], 
          Plus[ 
            Times[ -0.11423673049785459, 
              c[ -60][ t]], 
            Times[ -0.062044074975450239, 
              c[ -59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ 0.070907514257657456, 
              c[ -57][ t]], 
            Times[ 0.14938649372796384, 
              c[ -56][ t]], 
            Times[ 0.23387232094715985, 
              c[ -55][ t]], 
            Times[ 0.32256865202152113, 
              c[ -54][ t]], 
            Times[ 0.41349667156634429, 
              c[ -53][ t]], 
            Times[ 0.50455115242710469, 
              c[ -52][ t]], 
            Times[ 0.59356153372868015, 
              c[ -51][ t]], 
            Times[ 0.67835603854706361, 
              c[ -50][ t]], 
            Times[ 0.75682672864065692, 
              c[ -49][ t]], 
            Times[ 0.82699334313268802, 
              c[ -48][ t]], 
            Times[ 0.88706379305918392, 
              c[ -47][ t]], 
            Times[ 0.93548928378863916, 
              c[ -46][ t]], 
            Times[ 0.9710122092317629, 
              c[ -45][ t]], 
            Times[ 0.99270519960720693, 
              c[ -44][ t]], 
            Times[ 41.553107861364936, 
              c[ -43][ t]], 
            Times[ 0.99270519960720693, 
              c[ -42][ t]], 
            Times[ 0.9710122092317629, 
              c[ -41][ t]], 
            Times[ 0.93548928378863916, 
              c[ -40][ t]], 
            Times[ 0.88706379305918392, 
              c[ -39][ t]], 
            Times[ 0.82699334313268813, 
              c[ -38][ t]], 
            Times[ 0.75682672864065692, 
              c[ -37][ t]], 
            Times[ 0.67835603854706361, 
              c[ -36][ t]], 
            Times[ 0.59356153372868059, 
              c[ -35][ t]], 
            Times[ 0.50455115242710469, 
              c[ -34][ t]], 
            Times[ 0.41349667156634429, 
              c[ -33][ t]], 
            Times[ 0.32256865202152157, 
              c[ -32][ t]], 
            Times[ 0.23387232094715985, 
              c[ -31][ t]], 
            Times[ 0.14938649372796384, 
              c[ -30][ t]], 
            Times[ 0.070907514257657775, 
              c[ -29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ -0.062044074975450239, 
              c[ -27][ t]], 
            Times[ -0.11423673049785436, 
              c[ -26][ t]], 
            Times[ -0.15591488063143982, 
              c[ -25][ t]], 
            Times[ -0.18675027222298593, 
              c[ -24][ t]], 
            Times[ -0.206748335783172, 
              c[ -23][ t]], 
            Times[ -0.21623620818304484, 
              c[ -22][ t]], 
            Times[ -0.21584055771952015, 
              c[ -21][ t]], 
            Times[ -0.20645618564475843, 
              c[ -20][ t]], 
            Times[ -0.18920668216016426, 
              c[ -19][ t]], 
            Times[ -0.16539866862653771, 
              c[ -18][ t]], 
            Times[ -0.13647135277833605, 
              c[ -17][ t]], 
            Times[ -0.10394325375429328, 
              c[ -16][ t]], 
            Times[ -0.06935801494512607, 
              c[ -15][ t]], 
            Times[ -0.034231213779558949, 
              c[ -14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ 0.032022748374425904, 
              c[ -12][ t]], 
            Times[ 0.060688263076985105, 
              c[ -11][ t]], 
            Times[ 0.085044480344421705, 
              c[ -10][ t]], 
            Times[ 0.10436044624225685, 
              c[ -9][ t]], 
            Times[ 0.11814190616181255, 
              c[ -8][ t]], 
            Times[ 0.12613778810677614, 
              c[ -7][ t]], 
            Times[ 0.12833762891430928, 
              c[ -6][ t]], 
            Times[ 0.12496032289024853, 
              c[ -5][ t]], 
            Times[ 0.11643488132933186, 
              c[ -4][ t]], 
            Times[ 0.10337416789158609, 
              c[ -3][ t]], 
            Times[ 0.086542809078944891, 
              c[ -2][ t]], 
            Times[ 0.066820663127759972, 
              c[ -1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 0][ t]], 
            Times[ 0.022561481809254869, 
              c[ 1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 2][ t]], 
            Times[ -0.021580547817547879, 
              c[ 3][ t]], 
            Times[ -0.04131966847794722, 
              c[ 4][ t]], 
            Times[ -0.058468080236789913, 
              c[ 5][ t]], 
            Times[ -0.072413370861974122, 
              c[ 6][ t]], 
            Times[ -0.082699334313268744, 
              c[ 7][ t]], 
            Times[ -0.089038438663606695, 
              c[ 8][ t]], 
            Times[ -0.091317159035181589, 
              c[ 9][ t]], 
            Times[ -0.089594193770366884, 
              c[ 10][ t]], 
            Times[ -0.084091858737850814, 
              c[ 11][ t]], 
            Times[ -0.075181213012062598, 
              c[ 12][ t]], 
            Times[ -0.063361699504227528, 
              c[ 13][ t]], 
            Times[ -0.049236278094138941, 
              c[ 14][ t]], 
            Times[ -0.033483179628681567, 
              c[ 15][ t]], 
            Times[ -0.016825511857749401, 
              c[ 16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.016273855731265604, 
              c[ 18][ t]], 
            Times[ 0.031322974491347078, 
              c[ 19][ t]], 
            Times[ 0.044547108751839919, 
              c[ 20][ t]], 
            Times[ 0.055441487066198933, 
              c[ 21][ t]], 
            Times[ 0.063614872548668253, 
              c[ 22][ t]], 
            Times[ 0.068802429876423349, 
              c[ 23][ t]], 
            Times[ 0.070873018952678238, 
              c[ 24][ t]], 
            Times[ 0.069830768673962415, 
              c[ 25][ t]], 
            Times[ 0.065811019881796273, 
              c[ 26][ t]], 
            Times[ 0.059070953080906326, 
              c[ 27][ t]], 
            Times[ 0.049975424961080865, 
              c[ 28][ t]], 
            Times[ 0.03897872015785999, 
              c[ 29][ t]], 
            Times[ 0.026603074225527826, 
              c[ 30][ t]], 
            Times[ 0.013414935129827233, 
              c[ 31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ -0.013061910521147383, 
              c[ 33][ t]], 
            Times[ -0.025221096343682053, 
              c[ 34][ t]], 
            Times[ -0.035980357068793781, 
              c[ 35][ t]], 
            Times[ -0.044914622433376419, 
              c[ 36][ t]], 
            Times[ -0.05168708394579296, 
              c[ 37][ t]], 
            Times[ -0.056061239158567186, 
              c[ 38][ t]], 
            Times[ -0.057908442314993203, 
              c[ 39][ t]], 
            Times[ -0.057210750238908967, 
              c[ 40][ t]], 
            Times[ -0.054059052045761224, 
              c[ 41][ t]], 
            Times[ -0.048646667243099281, 
              c[ 42][ t]], 
            Times[ -0.041258781072520248, 
              c[ 43][ t]], 
            Times[ -0.032258251165125679, 
              c[ 44][ t]], 
            Times[ -0.022068459300722043, 
              c[ 45][ t]], 
            Times[ -0.011153991006822649, 
              c[ 46][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 47][ t]], 
            Times[ 0.010908848347331966, 
              c[ 48][ t]], 
            Times[ 0.021108961070255627, 
              c[ 49][ t]], 
            Times[ 0.030177073670601094, 
              c[ 50][ t]], 
            Times[ 0.03774739544932687, 
              c[ 51][ t]], 
            Times[ 0.043525965428036162, 
              c[ 52][ t]], 
            Times[ 0.047301670540041058, 
              c[ 53][ t]], 
            Times[ 0.04895352855494272, 
              c[ 54][ t]], 
            Times[ 0.048454002753361682, 
              c[ 55][ t]], 
            Times[ 0.045868286584282311, 
              c[ 56][ t]], 
            Times[ 0.041349667156634483, 
              c[ 57][ t]], 
            Times[ 0.035131239329076656, 
              c[ 58][ t]], 
            Times[ 0.027514390699665887, 
              c[ 59][ t]], 
            Times[ 0.018854606004500233, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-42\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-42\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.15591488063143982`\)\ \(c[\(-60\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-59\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-58\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-56\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-55\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-54\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-53\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-52\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-51\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-50\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-49\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-48\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-47\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-46\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-45\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-44\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-43\)]\)[t] + 
            39.68884925227028`\ \(c[\(-42\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-41\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-40\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-39\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-38\)]\)[t] + 
            0.826993343132688`\ \(c[\(-37\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-36\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-35\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-34\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-33\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-32\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-31\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-30\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-29\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-26\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-25\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-24\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-23\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-22\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-21\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-20\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-19\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-18\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-17\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-16\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-15\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-14\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-11\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-10\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-9\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-8\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-7\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-6\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-5\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-4\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-3\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-2\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-1\)]\)[t] + 
            0.06682066312775997`\ \(c[0]\)[t] + 
            0.0451633585689193`\ \(c[1]\)[t] + 
            0.022561481809254675`\ \(c[2]\)[t] + 
            3.8981718325193755`*^-17\ \(c[3]\)[t] - 
            0.02158054781754788`\ \(c[4]\)[t] - 
            0.04131966847794737`\ \(c[5]\)[t] - 
            0.05846808023678991`\ \(c[6]\)[t] - 
            0.07241337086197412`\ \(c[7]\)[t] - 
            0.08269933431326881`\ \(c[8]\)[t] - 
            0.0890384386636067`\ \(c[9]\)[t] - 
            0.09131715903518159`\ \(c[10]\)[t] - 
            0.08959419377036688`\ \(c[11]\)[t] - 
            0.08409185873785081`\ \(c[12]\)[t] - 
            0.0751812130120626`\ \(c[13]\)[t] - 
            0.06336169950422753`\ \(c[14]\)[t] - 
            0.04923627809413894`\ \(c[15]\)[t] - 
            0.03348317962868157`\ \(c[16]\)[t] - 
            0.0168255118577494`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.016273855731265604`\ \(c[19]\)[t] + 
            0.03132297449134708`\ \(c[20]\)[t] + 
            0.04454710875183992`\ \(c[21]\)[t] + 
            0.05544148706619893`\ \(c[22]\)[t] + 
            0.06361487254866825`\ \(c[23]\)[t] + 
            0.06880242987642335`\ \(c[24]\)[t] + 
            0.07087301895267824`\ \(c[25]\)[t] + 
            0.06983076867396242`\ \(c[26]\)[t] + 
            0.06581101988179627`\ \(c[27]\)[t] + 
            0.059070953080906326`\ \(c[28]\)[t] + 
            0.049975424961080865`\ \(c[29]\)[t] + 
            0.03897872015785999`\ \(c[30]\)[t] + 
            0.026603074225527826`\ \(c[31]\)[t] + 
            0.013414935129827233`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] - 
            0.013061910521147383`\ \(c[34]\)[t] - 
            0.025221096343682053`\ \(c[35]\)[t] - 
            0.03598035706879378`\ \(c[36]\)[t] - 
            0.04491462243337642`\ \(c[37]\)[t] - 
            0.05168708394579296`\ \(c[38]\)[t] - 
            0.056061239158567186`\ \(c[39]\)[t] - 
            0.0579084423149932`\ \(c[40]\)[t] - 
            0.05721075023890897`\ \(c[41]\)[t] - 
            0.054059052045761224`\ \(c[42]\)[t] - 
            0.04864666724309928`\ \(c[43]\)[t] - 
            0.04125878107252025`\ \(c[44]\)[t] - 
            0.03225825116512552`\ \(c[45]\)[t] - 
            0.022068459300722043`\ \(c[46]\)[t] - 
            0.011153991006822649`\ \(c[47]\)[t] - 
            3.8981718325193755`*^-17\ \(c[48]\)[t] + 
            0.010908848347331966`\ \(c[49]\)[t] + 
            0.021108961070255627`\ \(c[50]\)[t] + 
            0.030177073670601236`\ \(c[51]\)[t] + 
            0.03774739544932687`\ \(c[52]\)[t] + 
            0.04352596542803616`\ \(c[53]\)[t] + 
            0.04730167054004106`\ \(c[54]\)[t] + 
            0.04895352855494272`\ \(c[55]\)[t] + 
            0.04845400275336168`\ \(c[56]\)[t] + 
            0.045868286584282256`\ \(c[57]\)[t] + 
            0.04134966715663448`\ \(c[58]\)[t] + 
            0.035131239329076656`\ \(c[59]\)[t] + 
            0.027514390699665887`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -42, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -42]][ t]], 
          Plus[ 
            Times[ -0.15591488063143982, 
              c[ -60][ t]], 
            Times[ -0.11423673049785416, 
              c[ -59][ t]], 
            Times[ -0.062044074975450239, 
              c[ -58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ 0.070907514257658094, 
              c[ -56][ t]], 
            Times[ 0.14938649372796384, 
              c[ -55][ t]], 
            Times[ 0.23387232094715985, 
              c[ -54][ t]], 
            Times[ 0.32256865202152191, 
              c[ -53][ t]], 
            Times[ 0.41349667156634429, 
              c[ -52][ t]], 
            Times[ 0.50455115242710469, 
              c[ -51][ t]], 
            Times[ 0.59356153372868092, 
              c[ -50][ t]], 
            Times[ 0.67835603854706361, 
              c[ -49][ t]], 
            Times[ 0.75682672864065692, 
              c[ -48][ t]], 
            Times[ 0.82699334313268846, 
              c[ -47][ t]], 
            Times[ 0.88706379305918392, 
              c[ -46][ t]], 
            Times[ 0.93548928378863916, 
              c[ -45][ t]], 
            Times[ 0.9710122092317629, 
              c[ -44][ t]], 
            Times[ 0.99270519960720693, 
              c[ -43][ t]], 
            Times[ 39.68884925227028, 
              c[ -42][ t]], 
            Times[ 0.99270519960720671, 
              c[ -41][ t]], 
            Times[ 0.9710122092317629, 
              c[ -40][ t]], 
            Times[ 0.93548928378863916, 
              c[ -39][ t]], 
            Times[ 0.88706379305918381, 
              c[ -38][ t]], 
            Times[ 0.82699334313268802, 
              c[ -37][ t]], 
            Times[ 0.75682672864065692, 
              c[ -36][ t]], 
            Times[ 0.67835603854706317, 
              c[ -35][ t]], 
            Times[ 0.59356153372868015, 
              c[ -34][ t]], 
            Times[ 0.50455115242710469, 
              c[ -33][ t]], 
            Times[ 0.41349667156634395, 
              c[ -32][ t]], 
            Times[ 0.32256865202152113, 
              c[ -31][ t]], 
            Times[ 0.23387232094715985, 
              c[ -30][ t]], 
            Times[ 0.14938649372796345, 
              c[ -29][ t]], 
            Times[ 0.070907514257657456, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.062044074975450475, 
              c[ -26][ t]], 
            Times[ -0.11423673049785459, 
              c[ -25][ t]], 
            Times[ -0.15591488063143982, 
              c[ -24][ t]], 
            Times[ -0.18675027222298607, 
              c[ -23][ t]], 
            Times[ -0.20674833578317206, 
              c[ -22][ t]], 
            Times[ -0.21623620818304484, 
              c[ -21][ t]], 
            Times[ -0.21584055771952013, 
              c[ -20][ t]], 
            Times[ -0.20645618564475834, 
              c[ -19][ t]], 
            Times[ -0.18920668216016426, 
              c[ -18][ t]], 
            Times[ -0.1653986686265376, 
              c[ -17][ t]], 
            Times[ -0.13647135277833591, 
              c[ -16][ t]], 
            Times[ -0.10394325375429328, 
              c[ -15][ t]], 
            Times[ -0.069358014945125918, 
              c[ -14][ t]], 
            Times[ -0.034231213779558796, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ 0.032022748374426029, 
              c[ -11][ t]], 
            Times[ 0.060688263076985223, 
              c[ -10][ t]], 
            Times[ 0.085044480344421705, 
              c[ -9][ t]], 
            Times[ 0.10436044624225692, 
              c[ -8][ t]], 
            Times[ 0.1181419061618126, 
              c[ -7][ t]], 
            Times[ 0.12613778810677614, 
              c[ -6][ t]], 
            Times[ 0.12833762891430925, 
              c[ -5][ t]], 
            Times[ 0.12496032289024853, 
              c[ -4][ t]], 
            Times[ 0.11643488132933186, 
              c[ -3][ t]], 
            Times[ 0.10337416789158609, 
              c[ -2][ t]], 
            Times[ 0.086542809078944752, 
              c[ -1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 0][ t]], 
            Times[ 0.045163358568919301, 
              c[ 1][ t]], 
            Times[ 0.022561481809254675, 
              c[ 2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 3][ t]], 
            Times[ -0.021580547817547879, 
              c[ 4][ t]], 
            Times[ -0.041319668477947373, 
              c[ 5][ t]], 
            Times[ -0.058468080236789913, 
              c[ 6][ t]], 
            Times[ -0.072413370861974122, 
              c[ 7][ t]], 
            Times[ -0.082699334313268813, 
              c[ 8][ t]], 
            Times[ -0.089038438663606695, 
              c[ 9][ t]], 
            Times[ -0.091317159035181589, 
              c[ 10][ t]], 
            Times[ -0.089594193770366884, 
              c[ 11][ t]], 
            Times[ -0.084091858737850814, 
              c[ 12][ t]], 
            Times[ -0.075181213012062598, 
              c[ 13][ t]], 
            Times[ -0.063361699504227528, 
              c[ 14][ t]], 
            Times[ -0.049236278094138941, 
              c[ 15][ t]], 
            Times[ -0.033483179628681567, 
              c[ 16][ t]], 
            Times[ -0.016825511857749401, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.016273855731265604, 
              c[ 19][ t]], 
            Times[ 0.031322974491347078, 
              c[ 20][ t]], 
            Times[ 0.044547108751839919, 
              c[ 21][ t]], 
            Times[ 0.055441487066198933, 
              c[ 22][ t]], 
            Times[ 0.063614872548668253, 
              c[ 23][ t]], 
            Times[ 0.068802429876423349, 
              c[ 24][ t]], 
            Times[ 0.070873018952678238, 
              c[ 25][ t]], 
            Times[ 0.069830768673962415, 
              c[ 26][ t]], 
            Times[ 0.065811019881796273, 
              c[ 27][ t]], 
            Times[ 0.059070953080906326, 
              c[ 28][ t]], 
            Times[ 0.049975424961080865, 
              c[ 29][ t]], 
            Times[ 0.03897872015785999, 
              c[ 30][ t]], 
            Times[ 0.026603074225527826, 
              c[ 31][ t]], 
            Times[ 0.013414935129827233, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ -0.013061910521147383, 
              c[ 34][ t]], 
            Times[ -0.025221096343682053, 
              c[ 35][ t]], 
            Times[ -0.035980357068793781, 
              c[ 36][ t]], 
            Times[ -0.044914622433376419, 
              c[ 37][ t]], 
            Times[ -0.05168708394579296, 
              c[ 38][ t]], 
            Times[ -0.056061239158567186, 
              c[ 39][ t]], 
            Times[ -0.057908442314993203, 
              c[ 40][ t]], 
            Times[ -0.057210750238908967, 
              c[ 41][ t]], 
            Times[ -0.054059052045761224, 
              c[ 42][ t]], 
            Times[ -0.048646667243099281, 
              c[ 43][ t]], 
            Times[ -0.041258781072520248, 
              c[ 44][ t]], 
            Times[ -0.032258251165125519, 
              c[ 45][ t]], 
            Times[ -0.022068459300722043, 
              c[ 46][ t]], 
            Times[ -0.011153991006822649, 
              c[ 47][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ 0.010908848347331966, 
              c[ 49][ t]], 
            Times[ 0.021108961070255627, 
              c[ 50][ t]], 
            Times[ 0.030177073670601236, 
              c[ 51][ t]], 
            Times[ 0.03774739544932687, 
              c[ 52][ t]], 
            Times[ 0.043525965428036162, 
              c[ 53][ t]], 
            Times[ 0.047301670540041058, 
              c[ 54][ t]], 
            Times[ 0.04895352855494272, 
              c[ 55][ t]], 
            Times[ 0.048454002753361682, 
              c[ 56][ t]], 
            Times[ 0.045868286584282256, 
              c[ 57][ t]], 
            Times[ 0.041349667156634483, 
              c[ 58][ t]], 
            Times[ 0.035131239329076656, 
              c[ 59][ t]], 
            Times[ 0.027514390699665887, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-41\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-41\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.18675027222298618`\)\ \(c[\(-60\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-59\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-58\)]\)[t] - 
            0.06204407497545072`\ \(c[\(-57\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-56\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-55\)]\)[t] + 
            0.14938649372796314`\ \(c[\(-54\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-53\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-52\)]\)[t] + 
            0.4134966715663436`\ \(c[\(-51\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-50\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-49\)]\)[t] + 
            0.6783560385470627`\ \(c[\(-48\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-47\)]\)[t] + 
            0.826993343132688`\ \(c[\(-46\)]\)[t] + 
            0.8870637930591835`\ \(c[\(-45\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-44\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-43\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-42\)]\)[t] + 
            37.868455551624905`\ \(c[\(-41\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-40\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-39\)]\)[t] + 
            0.9354892837886393`\ \(c[\(-38\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-37\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-36\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-35\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-34\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-33\)]\)[t] + 
            0.504551152427105`\ \(c[\(-32\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-31\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-30\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-29\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-28\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-27\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-26\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-25\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-24\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-23\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-22\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-21\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-20\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-19\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-18\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-17\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-16\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-15\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-14\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-13\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-12\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-11\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-10\)]\)[t] + 
            0.060688263076985`\ \(c[\(-9\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-8\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-7\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-6\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-5\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-4\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-3\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-2\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-1\)]\)[t] + 
            0.08654280907894489`\ \(c[0]\)[t] + 
            0.06682066312776015`\ \(c[1]\)[t] + 
            0.0451633585689193`\ \(c[2]\)[t] + 
            0.02256148180925487`\ \(c[3]\)[t] + 
            2.274590327822911`*^-16\ \(c[4]\)[t] - 
            0.02158054781754788`\ \(c[5]\)[t] - 
            0.04131966847794722`\ \(c[6]\)[t] - 
            0.058468080236789774`\ \(c[7]\)[t] - 
            0.07241337086197412`\ \(c[8]\)[t] - 
            0.08269933431326874`\ \(c[9]\)[t] - 
            0.08903843866360665`\ \(c[10]\)[t] - 
            0.0913171590351816`\ \(c[11]\)[t] - 
            0.08959419377036688`\ \(c[12]\)[t] - 
            0.08409185873785086`\ \(c[13]\)[t] - 
            0.0751812130120627`\ \(c[14]\)[t] - 
            0.06336169950422753`\ \(c[15]\)[t] - 
            0.049236278094139066`\ \(c[16]\)[t] - 
            0.033483179628681706`\ \(c[17]\)[t] - 
            0.0168255118577494`\ \(c[18]\)[t] - 
            1.8033970416801674`*^-16\ \(c[19]\)[t] + 
            0.01627385573126547`\ \(c[20]\)[t] + 
            0.03132297449134708`\ \(c[21]\)[t] + 
            0.044547108751839815`\ \(c[22]\)[t] + 
            0.055441487066198857`\ \(c[23]\)[t] + 
            0.06361487254866825`\ \(c[24]\)[t] + 
            0.06880242987642332`\ \(c[25]\)[t] + 
            0.07087301895267824`\ \(c[26]\)[t] + 
            0.06983076867396242`\ \(c[27]\)[t] + 
            0.06581101988179631`\ \(c[28]\)[t] + 
            0.0590709530809064`\ \(c[29]\)[t] + 
            0.049975424961080865`\ \(c[30]\)[t] + 
            0.03897872015786009`\ \(c[31]\)[t] + 
            0.026603074225527937`\ \(c[32]\)[t] + 
            0.013414935129827233`\ \(c[33]\)[t] + 
            1.5206810699945212`*^-16\ \(c[34]\)[t] - 
            0.013061910521147276`\ \(c[35]\)[t] - 
            0.025221096343682053`\ \(c[36]\)[t] - 
            0.03598035706879378`\ \(c[37]\)[t] - 
            0.04491462243337629`\ \(c[38]\)[t] - 
            0.05168708394579296`\ \(c[39]\)[t] - 
            0.05606123915856713`\ \(c[40]\)[t] - 
            0.0579084423149932`\ \(c[41]\)[t] - 
            0.05721075023890897`\ \(c[42]\)[t] - 
            0.054059052045761224`\ \(c[43]\)[t] - 
            0.0486466672430994`\ \(c[44]\)[t] - 
            0.04125878107252025`\ \(c[45]\)[t] - 
            0.03225825116512568`\ \(c[46]\)[t] - 
            0.022068459300722043`\ \(c[47]\)[t] - 
            0.011153991006822649`\ \(c[48]\)[t] - 
            3.8981718325193755`*^-17\ \(c[49]\)[t] + 
            0.010908848347331785`\ \(c[50]\)[t] + 
            0.021108961070255627`\ \(c[51]\)[t] + 
            0.030177073670601094`\ \(c[52]\)[t] + 
            0.03774739544932687`\ \(c[53]\)[t] + 
            0.04352596542803616`\ \(c[54]\)[t] + 
            0.04730167054004106`\ \(c[55]\)[t] + 
            0.0489535285549427`\ \(c[56]\)[t] + 
            0.04845400275336168`\ \(c[57]\)[t] + 
            0.04586828658428231`\ \(c[58]\)[t] + 
            0.04134966715663448`\ \(c[59]\)[t] + 
            0.035131239329076656`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -41, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -41]][ t]], 
          Plus[ 
            Times[ -0.18675027222298618, 
              c[ -60][ t]], 
            Times[ -0.15591488063143982, 
              c[ -59][ t]], 
            Times[ -0.11423673049785459, 
              c[ -58][ t]], 
            Times[ -0.062044074975450718, 
              c[ -57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -56][ t]], 
            Times[ 0.070907514257657456, 
              c[ -55][ t]], 
            Times[ 0.14938649372796314, 
              c[ -54][ t]], 
            Times[ 0.23387232094715985, 
              c[ -53][ t]], 
            Times[ 0.32256865202152113, 
              c[ -52][ t]], 
            Times[ 0.41349667156634362, 
              c[ -51][ t]], 
            Times[ 0.50455115242710469, 
              c[ -50][ t]], 
            Times[ 0.59356153372868015, 
              c[ -49][ t]], 
            Times[ 0.67835603854706272, 
              c[ -48][ t]], 
            Times[ 0.75682672864065692, 
              c[ -47][ t]], 
            Times[ 0.82699334313268802, 
              c[ -46][ t]], 
            Times[ 0.88706379305918348, 
              c[ -45][ t]], 
            Times[ 0.93548928378863916, 
              c[ -44][ t]], 
            Times[ 0.9710122092317629, 
              c[ -43][ t]], 
            Times[ 0.99270519960720671, 
              c[ -42][ t]], 
            Times[ 37.868455551624905, 
              c[ -41][ t]], 
            Times[ 0.99270519960720693, 
              c[ -40][ t]], 
            Times[ 0.9710122092317629, 
              c[ -39][ t]], 
            Times[ 0.93548928378863927, 
              c[ -38][ t]], 
            Times[ 0.88706379305918392, 
              c[ -37][ t]], 
            Times[ 0.82699334313268846, 
              c[ -36][ t]], 
            Times[ 0.75682672864065736, 
              c[ -35][ t]], 
            Times[ 0.67835603854706361, 
              c[ -34][ t]], 
            Times[ 0.59356153372868092, 
              c[ -33][ t]], 
            Times[ 0.50455115242710502, 
              c[ -32][ t]], 
            Times[ 0.41349667156634429, 
              c[ -31][ t]], 
            Times[ 0.32256865202152191, 
              c[ -30][ t]], 
            Times[ 0.23387232094716018, 
              c[ -29][ t]], 
            Times[ 0.14938649372796384, 
              c[ -28][ t]], 
            Times[ 0.070907514257658094, 
              c[ -27][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -26][ t]], 
            Times[ -0.062044074975450239, 
              c[ -25][ t]], 
            Times[ -0.11423673049785416, 
              c[ -24][ t]], 
            Times[ -0.15591488063143966, 
              c[ -23][ t]], 
            Times[ -0.18675027222298593, 
              c[ -22][ t]], 
            Times[ -0.20674833578317189, 
              c[ -21][ t]], 
            Times[ -0.21623620818304481, 
              c[ -20][ t]], 
            Times[ -0.21584055771952015, 
              c[ -19][ t]], 
            Times[ -0.20645618564475848, 
              c[ -18][ t]], 
            Times[ -0.18920668216016434, 
              c[ -17][ t]], 
            Times[ -0.16539866862653771, 
              c[ -16][ t]], 
            Times[ -0.13647135277833616, 
              c[ -15][ t]], 
            Times[ -0.1039432537542934, 
              c[ -14][ t]], 
            Times[ -0.06935801494512607, 
              c[ -13][ t]], 
            Times[ -0.034231213779559094, 
              c[ -12][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -11][ t]], 
            Times[ 0.032022748374425904, 
              c[ -10][ t]], 
            Times[ 0.060688263076985001, 
              c[ -9][ t]], 
            Times[ 0.085044480344421608, 
              c[ -8][ t]], 
            Times[ 0.10436044624225685, 
              c[ -7][ t]], 
            Times[ 0.11814190616181253, 
              c[ -6][ t]], 
            Times[ 0.12613778810677612, 
              c[ -5][ t]], 
            Times[ 0.12833762891430925, 
              c[ -4][ t]], 
            Times[ 0.12496032289024853, 
              c[ -3][ t]], 
            Times[ 0.11643488132933195, 
              c[ -2][ t]], 
            Times[ 0.10337416789158609, 
              c[ -1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 0][ t]], 
            Times[ 0.066820663127760152, 
              c[ 1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 2][ t]], 
            Times[ 0.022561481809254869, 
              c[ 3][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 4][ t]], 
            Times[ -0.021580547817547879, 
              c[ 5][ t]], 
            Times[ -0.04131966847794722, 
              c[ 6][ t]], 
            Times[ -0.058468080236789774, 
              c[ 7][ t]], 
            Times[ -0.072413370861974122, 
              c[ 8][ t]], 
            Times[ -0.082699334313268744, 
              c[ 9][ t]], 
            Times[ -0.089038438663606653, 
              c[ 10][ t]], 
            Times[ -0.091317159035181603, 
              c[ 11][ t]], 
            Times[ -0.089594193770366884, 
              c[ 12][ t]], 
            Times[ -0.084091858737850855, 
              c[ 13][ t]], 
            Times[ -0.075181213012062695, 
              c[ 14][ t]], 
            Times[ -0.063361699504227528, 
              c[ 15][ t]], 
            Times[ -0.049236278094139066, 
              c[ 16][ t]], 
            Times[ -0.033483179628681706, 
              c[ 17][ t]], 
            Times[ -0.016825511857749401, 
              c[ 18][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 19][ t]], 
            Times[ 0.016273855731265469, 
              c[ 20][ t]], 
            Times[ 0.031322974491347078, 
              c[ 21][ t]], 
            Times[ 0.044547108751839815, 
              c[ 22][ t]], 
            Times[ 0.055441487066198857, 
              c[ 23][ t]], 
            Times[ 0.063614872548668253, 
              c[ 24][ t]], 
            Times[ 0.068802429876423321, 
              c[ 25][ t]], 
            Times[ 0.070873018952678238, 
              c[ 26][ t]], 
            Times[ 0.069830768673962415, 
              c[ 27][ t]], 
            Times[ 0.065811019881796315, 
              c[ 28][ t]], 
            Times[ 0.059070953080906402, 
              c[ 29][ t]], 
            Times[ 0.049975424961080865, 
              c[ 30][ t]], 
            Times[ 0.038978720157860088, 
              c[ 31][ t]], 
            Times[ 0.026603074225527937, 
              c[ 32][ t]], 
            Times[ 0.013414935129827233, 
              c[ 33][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 34][ t]], 
            Times[ -0.013061910521147276, 
              c[ 35][ t]], 
            Times[ -0.025221096343682053, 
              c[ 36][ t]], 
            Times[ -0.035980357068793781, 
              c[ 37][ t]], 
            Times[ -0.044914622433376288, 
              c[ 38][ t]], 
            Times[ -0.05168708394579296, 
              c[ 39][ t]], 
            Times[ -0.05606123915856713, 
              c[ 40][ t]], 
            Times[ -0.057908442314993203, 
              c[ 41][ t]], 
            Times[ -0.057210750238908967, 
              c[ 42][ t]], 
            Times[ -0.054059052045761224, 
              c[ 43][ t]], 
            Times[ -0.048646667243099399, 
              c[ 44][ t]], 
            Times[ -0.041258781072520248, 
              c[ 45][ t]], 
            Times[ -0.032258251165125679, 
              c[ 46][ t]], 
            Times[ -0.022068459300722043, 
              c[ 47][ t]], 
            Times[ -0.011153991006822649, 
              c[ 48][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 49][ t]], 
            Times[ 0.010908848347331785, 
              c[ 50][ t]], 
            Times[ 0.021108961070255627, 
              c[ 51][ t]], 
            Times[ 0.030177073670601094, 
              c[ 52][ t]], 
            Times[ 0.03774739544932687, 
              c[ 53][ t]], 
            Times[ 0.043525965428036162, 
              c[ 54][ t]], 
            Times[ 0.047301670540041058, 
              c[ 55][ t]], 
            Times[ 0.048953528554942699, 
              c[ 56][ t]], 
            Times[ 0.048454002753361682, 
              c[ 57][ t]], 
            Times[ 0.045868286584282311, 
              c[ 58][ t]], 
            Times[ 0.041349667156634483, 
              c[ 59][ t]], 
            Times[ 0.035131239329076656, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-40\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-40\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.20674833578317206`\)\ \(c[\(-60\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-59\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-58\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-57\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-56\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-54\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-53\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-52\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-51\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-50\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-49\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-48\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-47\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-46\)]\)[t] + 
            0.826993343132688`\ \(c[\(-45\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-44\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-43\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-42\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-41\)]\)[t] + 
            36.09192675942882`\ \(c[\(-40\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-39\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-38\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-37\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-36\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-35\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-34\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-33\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-32\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-31\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-30\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-29\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-28\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-27\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-26\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-24\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-23\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-22\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-21\)]\)[t] - 
            0.206748335783172`\ \(c[\(-20\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-19\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-18\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-17\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-16\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-15\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-14\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-13\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-12\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-11\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-9\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-8\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-7\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-6\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-5\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-4\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-3\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-2\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-1\)]\)[t] + 
            0.10337416789158609`\ \(c[0]\)[t] + 
            0.08654280907894489`\ \(c[1]\)[t] + 
            0.06682066312775997`\ \(c[2]\)[t] + 
            0.0451633585689193`\ \(c[3]\)[t] + 
            0.02256148180925487`\ \(c[4]\)[t] + 
            3.8981718325193755`*^-17\ \(c[5]\)[t] - 
            0.02158054781754788`\ \(c[6]\)[t] - 
            0.04131966847794722`\ \(c[7]\)[t] - 
            0.05846808023678991`\ \(c[8]\)[t] - 
            0.07241337086197412`\ \(c[9]\)[t] - 
            0.08269933431326874`\ \(c[10]\)[t] - 
            0.0890384386636067`\ \(c[11]\)[t] - 
            0.09131715903518159`\ \(c[12]\)[t] - 
            0.08959419377036688`\ \(c[13]\)[t] - 
            0.08409185873785081`\ \(c[14]\)[t] - 
            0.0751812130120626`\ \(c[15]\)[t] - 
            0.06336169950422753`\ \(c[16]\)[t] - 
            0.04923627809413894`\ \(c[17]\)[t] - 
            0.03348317962868157`\ \(c[18]\)[t] - 
            0.0168255118577494`\ \(c[19]\)[t] - 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.016273855731265604`\ \(c[21]\)[t] + 
            0.03132297449134708`\ \(c[22]\)[t] + 
            0.04454710875183992`\ \(c[23]\)[t] + 
            0.05544148706619893`\ \(c[24]\)[t] + 
            0.06361487254866825`\ \(c[25]\)[t] + 
            0.06880242987642335`\ \(c[26]\)[t] + 
            0.07087301895267824`\ \(c[27]\)[t] + 
            0.06983076867396242`\ \(c[28]\)[t] + 
            0.06581101988179627`\ \(c[29]\)[t] + 
            0.059070953080906326`\ \(c[30]\)[t] + 
            0.049975424961080865`\ \(c[31]\)[t] + 
            0.03897872015785999`\ \(c[32]\)[t] + 
            0.026603074225527826`\ \(c[33]\)[t] + 
            0.013414935129827233`\ \(c[34]\)[t] + 
            3.898171832519376`*^-17\ \(c[35]\)[t] - 
            0.013061910521147383`\ \(c[36]\)[t] - 
            0.025221096343682053`\ \(c[37]\)[t] - 
            0.03598035706879378`\ \(c[38]\)[t] - 
            0.04491462243337642`\ \(c[39]\)[t] - 
            0.05168708394579296`\ \(c[40]\)[t] - 
            0.05606123915856713`\ \(c[41]\)[t] - 
            0.0579084423149932`\ \(c[42]\)[t] - 
            0.05721075023890897`\ \(c[43]\)[t] - 
            0.054059052045761224`\ \(c[44]\)[t] - 
            0.04864666724309928`\ \(c[45]\)[t] - 
            0.04125878107252025`\ \(c[46]\)[t] - 
            0.03225825116512568`\ \(c[47]\)[t] - 
            0.022068459300722043`\ \(c[48]\)[t] - 
            0.011153991006822649`\ \(c[49]\)[t] - 
            3.8981718325193755`*^-17\ \(c[50]\)[t] + 
            0.010908848347331966`\ \(c[51]\)[t] + 
            0.021108961070255627`\ \(c[52]\)[t] + 
            0.030177073670601094`\ \(c[53]\)[t] + 
            0.03774739544932687`\ \(c[54]\)[t] + 
            0.04352596542803616`\ \(c[55]\)[t] + 
            0.04730167054004106`\ \(c[56]\)[t] + 
            0.04895352855494272`\ \(c[57]\)[t] + 
            0.04845400275336168`\ \(c[58]\)[t] + 
            0.04586828658428231`\ \(c[59]\)[t] + 
            0.04134966715663448`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -40, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -40]][ t]], 
          Plus[ 
            Times[ -0.20674833578317206, 
              c[ -60][ t]], 
            Times[ -0.18675027222298593, 
              c[ -59][ t]], 
            Times[ -0.15591488063143982, 
              c[ -58][ t]], 
            Times[ -0.11423673049785459, 
              c[ -57][ t]], 
            Times[ -0.062044074975450239, 
              c[ -56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ 0.070907514257657456, 
              c[ -54][ t]], 
            Times[ 0.14938649372796384, 
              c[ -53][ t]], 
            Times[ 0.23387232094715985, 
              c[ -52][ t]], 
            Times[ 0.32256865202152113, 
              c[ -51][ t]], 
            Times[ 0.41349667156634429, 
              c[ -50][ t]], 
            Times[ 0.50455115242710469, 
              c[ -49][ t]], 
            Times[ 0.59356153372868015, 
              c[ -48][ t]], 
            Times[ 0.67835603854706361, 
              c[ -47][ t]], 
            Times[ 0.75682672864065692, 
              c[ -46][ t]], 
            Times[ 0.82699334313268802, 
              c[ -45][ t]], 
            Times[ 0.88706379305918392, 
              c[ -44][ t]], 
            Times[ 0.93548928378863916, 
              c[ -43][ t]], 
            Times[ 0.9710122092317629, 
              c[ -42][ t]], 
            Times[ 0.99270519960720693, 
              c[ -41][ t]], 
            Times[ 36.091926759428823, 
              c[ -40][ t]], 
            Times[ 0.99270519960720693, 
              c[ -39][ t]], 
            Times[ 0.9710122092317629, 
              c[ -38][ t]], 
            Times[ 0.93548928378863916, 
              c[ -37][ t]], 
            Times[ 0.88706379305918392, 
              c[ -36][ t]], 
            Times[ 0.82699334313268813, 
              c[ -35][ t]], 
            Times[ 0.75682672864065692, 
              c[ -34][ t]], 
            Times[ 0.67835603854706361, 
              c[ -33][ t]], 
            Times[ 0.59356153372868059, 
              c[ -32][ t]], 
            Times[ 0.50455115242710469, 
              c[ -31][ t]], 
            Times[ 0.41349667156634429, 
              c[ -30][ t]], 
            Times[ 0.32256865202152157, 
              c[ -29][ t]], 
            Times[ 0.23387232094715985, 
              c[ -28][ t]], 
            Times[ 0.14938649372796384, 
              c[ -27][ t]], 
            Times[ 0.070907514257657775, 
              c[ -26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ -0.062044074975450239, 
              c[ -24][ t]], 
            Times[ -0.11423673049785436, 
              c[ -23][ t]], 
            Times[ -0.15591488063143982, 
              c[ -22][ t]], 
            Times[ -0.18675027222298593, 
              c[ -21][ t]], 
            Times[ -0.206748335783172, 
              c[ -20][ t]], 
            Times[ -0.21623620818304484, 
              c[ -19][ t]], 
            Times[ -0.21584055771952015, 
              c[ -18][ t]], 
            Times[ -0.20645618564475843, 
              c[ -17][ t]], 
            Times[ -0.18920668216016426, 
              c[ -16][ t]], 
            Times[ -0.16539866862653771, 
              c[ -15][ t]], 
            Times[ -0.13647135277833605, 
              c[ -14][ t]], 
            Times[ -0.10394325375429328, 
              c[ -13][ t]], 
            Times[ -0.06935801494512607, 
              c[ -12][ t]], 
            Times[ -0.034231213779558949, 
              c[ -11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ 0.032022748374425904, 
              c[ -9][ t]], 
            Times[ 0.060688263076985105, 
              c[ -8][ t]], 
            Times[ 0.085044480344421705, 
              c[ -7][ t]], 
            Times[ 0.10436044624225685, 
              c[ -6][ t]], 
            Times[ 0.11814190616181255, 
              c[ -5][ t]], 
            Times[ 0.12613778810677612, 
              c[ -4][ t]], 
            Times[ 0.12833762891430928, 
              c[ -3][ t]], 
            Times[ 0.12496032289024853, 
              c[ -2][ t]], 
            Times[ 0.11643488132933186, 
              c[ -1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 0][ t]], 
            Times[ 0.086542809078944891, 
              c[ 1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 2][ t]], 
            Times[ 0.045163358568919301, 
              c[ 3][ t]], 
            Times[ 0.022561481809254869, 
              c[ 4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 5][ t]], 
            Times[ -0.021580547817547879, 
              c[ 6][ t]], 
            Times[ -0.04131966847794722, 
              c[ 7][ t]], 
            Times[ -0.058468080236789913, 
              c[ 8][ t]], 
            Times[ -0.072413370861974122, 
              c[ 9][ t]], 
            Times[ -0.082699334313268744, 
              c[ 10][ t]], 
            Times[ -0.089038438663606695, 
              c[ 11][ t]], 
            Times[ -0.091317159035181589, 
              c[ 12][ t]], 
            Times[ -0.089594193770366884, 
              c[ 13][ t]], 
            Times[ -0.084091858737850814, 
              c[ 14][ t]], 
            Times[ -0.075181213012062598, 
              c[ 15][ t]], 
            Times[ -0.063361699504227528, 
              c[ 16][ t]], 
            Times[ -0.049236278094138941, 
              c[ 17][ t]], 
            Times[ -0.033483179628681567, 
              c[ 18][ t]], 
            Times[ -0.016825511857749401, 
              c[ 19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.016273855731265604, 
              c[ 21][ t]], 
            Times[ 0.031322974491347078, 
              c[ 22][ t]], 
            Times[ 0.044547108751839919, 
              c[ 23][ t]], 
            Times[ 0.055441487066198933, 
              c[ 24][ t]], 
            Times[ 0.063614872548668253, 
              c[ 25][ t]], 
            Times[ 0.068802429876423349, 
              c[ 26][ t]], 
            Times[ 0.070873018952678238, 
              c[ 27][ t]], 
            Times[ 0.069830768673962415, 
              c[ 28][ t]], 
            Times[ 0.065811019881796273, 
              c[ 29][ t]], 
            Times[ 0.059070953080906326, 
              c[ 30][ t]], 
            Times[ 0.049975424961080865, 
              c[ 31][ t]], 
            Times[ 0.03897872015785999, 
              c[ 32][ t]], 
            Times[ 0.026603074225527826, 
              c[ 33][ t]], 
            Times[ 0.013414935129827233, 
              c[ 34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ -0.013061910521147383, 
              c[ 36][ t]], 
            Times[ -0.025221096343682053, 
              c[ 37][ t]], 
            Times[ -0.035980357068793781, 
              c[ 38][ t]], 
            Times[ -0.044914622433376419, 
              c[ 39][ t]], 
            Times[ -0.05168708394579296, 
              c[ 40][ t]], 
            Times[ -0.05606123915856713, 
              c[ 41][ t]], 
            Times[ -0.057908442314993203, 
              c[ 42][ t]], 
            Times[ -0.057210750238908967, 
              c[ 43][ t]], 
            Times[ -0.054059052045761224, 
              c[ 44][ t]], 
            Times[ -0.048646667243099281, 
              c[ 45][ t]], 
            Times[ -0.041258781072520248, 
              c[ 46][ t]], 
            Times[ -0.032258251165125679, 
              c[ 47][ t]], 
            Times[ -0.022068459300722043, 
              c[ 48][ t]], 
            Times[ -0.011153991006822649, 
              c[ 49][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 50][ t]], 
            Times[ 0.010908848347331966, 
              c[ 51][ t]], 
            Times[ 0.021108961070255627, 
              c[ 52][ t]], 
            Times[ 0.030177073670601094, 
              c[ 53][ t]], 
            Times[ 0.03774739544932687, 
              c[ 54][ t]], 
            Times[ 0.043525965428036162, 
              c[ 55][ t]], 
            Times[ 0.047301670540041058, 
              c[ 56][ t]], 
            Times[ 0.04895352855494272, 
              c[ 57][ t]], 
            Times[ 0.048454002753361682, 
              c[ 58][ t]], 
            Times[ 0.045868286584282311, 
              c[ 59][ t]], 
            Times[ 0.041349667156634483, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-39\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-39\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.21623620818304484`\)\ \(c[\(-60\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-59\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-58\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-57\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-56\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-55\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-53\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-52\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-51\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-50\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-49\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-48\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-47\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-46\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-45\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-44\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-43\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-42\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-41\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-40\)]\)[t] + 
            34.35926287568203`\ \(c[\(-39\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-38\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-37\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-36\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-35\)]\)[t] + 
            0.826993343132688`\ \(c[\(-34\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-33\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-32\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-31\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-30\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-29\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-28\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-27\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-26\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-23\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-22\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-21\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-20\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-19\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-18\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-17\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-16\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-15\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-14\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-13\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-12\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-11\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-8\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-7\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-6\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-5\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-4\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-3\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-2\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-1\)]\)[t] + 
            0.11643488132933186`\ \(c[0]\)[t] + 
            0.10337416789158609`\ \(c[1]\)[t] + 
            0.08654280907894475`\ \(c[2]\)[t] + 
            0.06682066312775997`\ \(c[3]\)[t] + 
            0.0451633585689193`\ \(c[4]\)[t] + 
            0.022561481809254675`\ \(c[5]\)[t] + 
            3.8981718325193755`*^-17\ \(c[6]\)[t] - 
            0.02158054781754788`\ \(c[7]\)[t] - 
            0.04131966847794737`\ \(c[8]\)[t] - 
            0.05846808023678991`\ \(c[9]\)[t] - 
            0.07241337086197412`\ \(c[10]\)[t] - 
            0.08269933431326874`\ \(c[11]\)[t] - 
            0.0890384386636067`\ \(c[12]\)[t] - 
            0.09131715903518159`\ \(c[13]\)[t] - 
            0.08959419377036688`\ \(c[14]\)[t] - 
            0.08409185873785081`\ \(c[15]\)[t] - 
            0.0751812130120626`\ \(c[16]\)[t] - 
            0.06336169950422753`\ \(c[17]\)[t] - 
            0.04923627809413894`\ \(c[18]\)[t] - 
            0.03348317962868157`\ \(c[19]\)[t] - 
            0.0168255118577494`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.016273855731265604`\ \(c[22]\)[t] + 
            0.03132297449134708`\ \(c[23]\)[t] + 
            0.04454710875183992`\ \(c[24]\)[t] + 
            0.05544148706619893`\ \(c[25]\)[t] + 
            0.06361487254866825`\ \(c[26]\)[t] + 
            0.06880242987642335`\ \(c[27]\)[t] + 
            0.07087301895267824`\ \(c[28]\)[t] + 
            0.06983076867396242`\ \(c[29]\)[t] + 
            0.06581101988179627`\ \(c[30]\)[t] + 
            0.059070953080906326`\ \(c[31]\)[t] + 
            0.049975424961080865`\ \(c[32]\)[t] + 
            0.03897872015785999`\ \(c[33]\)[t] + 
            0.026603074225527826`\ \(c[34]\)[t] + 
            0.013414935129827233`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] - 
            0.013061910521147383`\ \(c[37]\)[t] - 
            0.025221096343682053`\ \(c[38]\)[t] - 
            0.03598035706879378`\ \(c[39]\)[t] - 
            0.04491462243337642`\ \(c[40]\)[t] - 
            0.05168708394579296`\ \(c[41]\)[t] - 
            0.056061239158567186`\ \(c[42]\)[t] - 
            0.0579084423149932`\ \(c[43]\)[t] - 
            0.05721075023890897`\ \(c[44]\)[t] - 
            0.054059052045761224`\ \(c[45]\)[t] - 
            0.04864666724309928`\ \(c[46]\)[t] - 
            0.04125878107252025`\ \(c[47]\)[t] - 
            0.03225825116512552`\ \(c[48]\)[t] - 
            0.022068459300722043`\ \(c[49]\)[t] - 
            0.011153991006822649`\ \(c[50]\)[t] - 
            3.8981718325193755`*^-17\ \(c[51]\)[t] + 
            0.010908848347331966`\ \(c[52]\)[t] + 
            0.021108961070255627`\ \(c[53]\)[t] + 
            0.030177073670601236`\ \(c[54]\)[t] + 
            0.03774739544932687`\ \(c[55]\)[t] + 
            0.04352596542803616`\ \(c[56]\)[t] + 
            0.04730167054004106`\ \(c[57]\)[t] + 
            0.04895352855494272`\ \(c[58]\)[t] + 
            0.04845400275336168`\ \(c[59]\)[t] + 
            0.045868286584282256`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -39, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -39]][ t]], 
          Plus[ 
            Times[ -0.21623620818304484, 
              c[ -60][ t]], 
            Times[ -0.20674833578317189, 
              c[ -59][ t]], 
            Times[ -0.18675027222298593, 
              c[ -58][ t]], 
            Times[ -0.15591488063143982, 
              c[ -57][ t]], 
            Times[ -0.11423673049785416, 
              c[ -56][ t]], 
            Times[ -0.062044074975450239, 
              c[ -55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ 0.070907514257658094, 
              c[ -53][ t]], 
            Times[ 0.14938649372796384, 
              c[ -52][ t]], 
            Times[ 0.23387232094715985, 
              c[ -51][ t]], 
            Times[ 0.32256865202152191, 
              c[ -50][ t]], 
            Times[ 0.41349667156634429, 
              c[ -49][ t]], 
            Times[ 0.50455115242710469, 
              c[ -48][ t]], 
            Times[ 0.59356153372868092, 
              c[ -47][ t]], 
            Times[ 0.67835603854706361, 
              c[ -46][ t]], 
            Times[ 0.75682672864065692, 
              c[ -45][ t]], 
            Times[ 0.82699334313268846, 
              c[ -44][ t]], 
            Times[ 0.88706379305918392, 
              c[ -43][ t]], 
            Times[ 0.93548928378863916, 
              c[ -42][ t]], 
            Times[ 0.9710122092317629, 
              c[ -41][ t]], 
            Times[ 0.99270519960720693, 
              c[ -40][ t]], 
            Times[ 34.359262875682028, 
              c[ -39][ t]], 
            Times[ 0.99270519960720671, 
              c[ -38][ t]], 
            Times[ 0.9710122092317629, 
              c[ -37][ t]], 
            Times[ 0.93548928378863916, 
              c[ -36][ t]], 
            Times[ 0.88706379305918381, 
              c[ -35][ t]], 
            Times[ 0.82699334313268802, 
              c[ -34][ t]], 
            Times[ 0.75682672864065692, 
              c[ -33][ t]], 
            Times[ 0.67835603854706317, 
              c[ -32][ t]], 
            Times[ 0.59356153372868015, 
              c[ -31][ t]], 
            Times[ 0.50455115242710469, 
              c[ -30][ t]], 
            Times[ 0.41349667156634395, 
              c[ -29][ t]], 
            Times[ 0.32256865202152113, 
              c[ -28][ t]], 
            Times[ 0.23387232094715985, 
              c[ -27][ t]], 
            Times[ 0.14938649372796345, 
              c[ -26][ t]], 
            Times[ 0.070907514257657456, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.062044074975450475, 
              c[ -23][ t]], 
            Times[ -0.11423673049785459, 
              c[ -22][ t]], 
            Times[ -0.15591488063143982, 
              c[ -21][ t]], 
            Times[ -0.18675027222298607, 
              c[ -20][ t]], 
            Times[ -0.20674833578317206, 
              c[ -19][ t]], 
            Times[ -0.21623620818304484, 
              c[ -18][ t]], 
            Times[ -0.21584055771952013, 
              c[ -17][ t]], 
            Times[ -0.20645618564475834, 
              c[ -16][ t]], 
            Times[ -0.18920668216016426, 
              c[ -15][ t]], 
            Times[ -0.1653986686265376, 
              c[ -14][ t]], 
            Times[ -0.13647135277833591, 
              c[ -13][ t]], 
            Times[ -0.10394325375429328, 
              c[ -12][ t]], 
            Times[ -0.069358014945125918, 
              c[ -11][ t]], 
            Times[ -0.034231213779558796, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ 0.032022748374426029, 
              c[ -8][ t]], 
            Times[ 0.060688263076985223, 
              c[ -7][ t]], 
            Times[ 0.085044480344421705, 
              c[ -6][ t]], 
            Times[ 0.10436044624225692, 
              c[ -5][ t]], 
            Times[ 0.11814190616181255, 
              c[ -4][ t]], 
            Times[ 0.12613778810677614, 
              c[ -3][ t]], 
            Times[ 0.12833762891430925, 
              c[ -2][ t]], 
            Times[ 0.12496032289024853, 
              c[ -1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 0][ t]], 
            Times[ 0.10337416789158609, 
              c[ 1][ t]], 
            Times[ 0.086542809078944752, 
              c[ 2][ t]], 
            Times[ 0.066820663127759972, 
              c[ 3][ t]], 
            Times[ 0.045163358568919301, 
              c[ 4][ t]], 
            Times[ 0.022561481809254675, 
              c[ 5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 6][ t]], 
            Times[ -0.021580547817547879, 
              c[ 7][ t]], 
            Times[ -0.041319668477947373, 
              c[ 8][ t]], 
            Times[ -0.058468080236789913, 
              c[ 9][ t]], 
            Times[ -0.072413370861974122, 
              c[ 10][ t]], 
            Times[ -0.082699334313268744, 
              c[ 11][ t]], 
            Times[ -0.089038438663606695, 
              c[ 12][ t]], 
            Times[ -0.091317159035181589, 
              c[ 13][ t]], 
            Times[ -0.089594193770366884, 
              c[ 14][ t]], 
            Times[ -0.084091858737850814, 
              c[ 15][ t]], 
            Times[ -0.075181213012062598, 
              c[ 16][ t]], 
            Times[ -0.063361699504227528, 
              c[ 17][ t]], 
            Times[ -0.049236278094138941, 
              c[ 18][ t]], 
            Times[ -0.033483179628681567, 
              c[ 19][ t]], 
            Times[ -0.016825511857749401, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.016273855731265604, 
              c[ 22][ t]], 
            Times[ 0.031322974491347078, 
              c[ 23][ t]], 
            Times[ 0.044547108751839919, 
              c[ 24][ t]], 
            Times[ 0.055441487066198933, 
              c[ 25][ t]], 
            Times[ 0.063614872548668253, 
              c[ 26][ t]], 
            Times[ 0.068802429876423349, 
              c[ 27][ t]], 
            Times[ 0.070873018952678238, 
              c[ 28][ t]], 
            Times[ 0.069830768673962415, 
              c[ 29][ t]], 
            Times[ 0.065811019881796273, 
              c[ 30][ t]], 
            Times[ 0.059070953080906326, 
              c[ 31][ t]], 
            Times[ 0.049975424961080865, 
              c[ 32][ t]], 
            Times[ 0.03897872015785999, 
              c[ 33][ t]], 
            Times[ 0.026603074225527826, 
              c[ 34][ t]], 
            Times[ 0.013414935129827233, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ -0.013061910521147383, 
              c[ 37][ t]], 
            Times[ -0.025221096343682053, 
              c[ 38][ t]], 
            Times[ -0.035980357068793781, 
              c[ 39][ t]], 
            Times[ -0.044914622433376419, 
              c[ 40][ t]], 
            Times[ -0.05168708394579296, 
              c[ 41][ t]], 
            Times[ -0.056061239158567186, 
              c[ 42][ t]], 
            Times[ -0.057908442314993203, 
              c[ 43][ t]], 
            Times[ -0.057210750238908967, 
              c[ 44][ t]], 
            Times[ -0.054059052045761224, 
              c[ 45][ t]], 
            Times[ -0.048646667243099281, 
              c[ 46][ t]], 
            Times[ -0.041258781072520248, 
              c[ 47][ t]], 
            Times[ -0.032258251165125519, 
              c[ 48][ t]], 
            Times[ -0.022068459300722043, 
              c[ 49][ t]], 
            Times[ -0.011153991006822649, 
              c[ 50][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ 0.010908848347331966, 
              c[ 52][ t]], 
            Times[ 0.021108961070255627, 
              c[ 53][ t]], 
            Times[ 0.030177073670601236, 
              c[ 54][ t]], 
            Times[ 0.03774739544932687, 
              c[ 55][ t]], 
            Times[ 0.043525965428036162, 
              c[ 56][ t]], 
            Times[ 0.047301670540041058, 
              c[ 57][ t]], 
            Times[ 0.04895352855494272, 
              c[ 58][ t]], 
            Times[ 0.048454002753361682, 
              c[ 59][ t]], 
            Times[ 0.045868286584282256, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-38\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-38\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.21584055771952013`\)\ \(c[\(-60\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-59\)]\)[t] - 
            0.206748335783172`\ \(c[\(-58\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-57\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-56\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-55\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-54\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-53\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-52\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-51\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-50\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-49\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-48\)]\)[t] + 
            0.504551152427105`\ \(c[\(-47\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-46\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-45\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-44\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-43\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-42\)]\)[t] + 
            0.9354892837886393`\ \(c[\(-41\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-40\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-39\)]\)[t] + 
            32.67046390038452`\ \(c[\(-38\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-37\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-36\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-35\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-34\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-33\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-32\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-31\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-30\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-29\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-28\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-27\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-26\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-25\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-22\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-21\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-20\)]\)[t] - 
            0.186750272222986`\ \(c[\(-19\)]\)[t] - 
            0.206748335783172`\ \(c[\(-18\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-17\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-16\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-15\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-14\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-13\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-12\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-11\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-10\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-9\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-7\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-6\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-5\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-4\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-3\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-2\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-1\)]\)[t] + 
            0.12496032289024853`\ \(c[0]\)[t] + 
            0.11643488132933186`\ \(c[1]\)[t] + 
            0.10337416789158609`\ \(c[2]\)[t] + 
            0.08654280907894489`\ \(c[3]\)[t] + 
            0.06682066312775997`\ \(c[4]\)[t] + 
            0.0451633585689193`\ \(c[5]\)[t] + 
            0.02256148180925487`\ \(c[6]\)[t] + 
            3.8981718325193755`*^-17\ \(c[7]\)[t] - 
            0.02158054781754788`\ \(c[8]\)[t] - 
            0.04131966847794722`\ \(c[9]\)[t] - 
            0.05846808023678991`\ \(c[10]\)[t] - 
            0.07241337086197412`\ \(c[11]\)[t] - 
            0.08269933431326874`\ \(c[12]\)[t] - 
            0.0890384386636067`\ \(c[13]\)[t] - 
            0.09131715903518159`\ \(c[14]\)[t] - 
            0.08959419377036688`\ \(c[15]\)[t] - 
            0.08409185873785081`\ \(c[16]\)[t] - 
            0.0751812130120626`\ \(c[17]\)[t] - 
            0.06336169950422753`\ \(c[18]\)[t] - 
            0.04923627809413894`\ \(c[19]\)[t] - 
            0.03348317962868157`\ \(c[20]\)[t] - 
            0.0168255118577494`\ \(c[21]\)[t] - 
            3.898171832519376`*^-17\ \(c[22]\)[t] + 
            0.016273855731265604`\ \(c[23]\)[t] + 
            0.03132297449134708`\ \(c[24]\)[t] + 
            0.04454710875183992`\ \(c[25]\)[t] + 
            0.05544148706619893`\ \(c[26]\)[t] + 
            0.06361487254866825`\ \(c[27]\)[t] + 
            0.06880242987642335`\ \(c[28]\)[t] + 
            0.07087301895267824`\ \(c[29]\)[t] + 
            0.06983076867396242`\ \(c[30]\)[t] + 
            0.06581101988179627`\ \(c[31]\)[t] + 
            0.059070953080906326`\ \(c[32]\)[t] + 
            0.049975424961080865`\ \(c[33]\)[t] + 
            0.03897872015785999`\ \(c[34]\)[t] + 
            0.026603074225527826`\ \(c[35]\)[t] + 
            0.013414935129827233`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] - 
            0.013061910521147383`\ \(c[38]\)[t] - 
            0.025221096343682053`\ \(c[39]\)[t] - 
            0.03598035706879378`\ \(c[40]\)[t] - 
            0.04491462243337629`\ \(c[41]\)[t] - 
            0.05168708394579296`\ \(c[42]\)[t] - 
            0.056061239158567186`\ \(c[43]\)[t] - 
            0.0579084423149932`\ \(c[44]\)[t] - 
            0.05721075023890897`\ \(c[45]\)[t] - 
            0.054059052045761224`\ \(c[46]\)[t] - 
            0.0486466672430994`\ \(c[47]\)[t] - 
            0.04125878107252025`\ \(c[48]\)[t] - 
            0.03225825116512552`\ \(c[49]\)[t] - 
            0.022068459300722043`\ \(c[50]\)[t] - 
            0.011153991006822649`\ \(c[51]\)[t] - 
            3.8981718325193755`*^-17\ \(c[52]\)[t] + 
            0.010908848347331785`\ \(c[53]\)[t] + 
            0.021108961070255627`\ \(c[54]\)[t] + 
            0.030177073670601236`\ \(c[55]\)[t] + 
            0.03774739544932687`\ \(c[56]\)[t] + 
            0.04352596542803616`\ \(c[57]\)[t] + 
            0.04730167054004106`\ \(c[58]\)[t] + 
            0.0489535285549427`\ \(c[59]\)[t] + 
            0.04845400275336168`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -38, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -38]][ t]], 
          Plus[ 
            Times[ -0.21584055771952013, 
              c[ -60][ t]], 
            Times[ -0.21623620818304481, 
              c[ -59][ t]], 
            Times[ -0.206748335783172, 
              c[ -58][ t]], 
            Times[ -0.18675027222298607, 
              c[ -57][ t]], 
            Times[ -0.15591488063143966, 
              c[ -56][ t]], 
            Times[ -0.11423673049785436, 
              c[ -55][ t]], 
            Times[ -0.062044074975450475, 
              c[ -54][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -53][ t]], 
            Times[ 0.070907514257657775, 
              c[ -52][ t]], 
            Times[ 0.14938649372796345, 
              c[ -51][ t]], 
            Times[ 0.23387232094716018, 
              c[ -50][ t]], 
            Times[ 0.32256865202152157, 
              c[ -49][ t]], 
            Times[ 0.41349667156634395, 
              c[ -48][ t]], 
            Times[ 0.50455115242710502, 
              c[ -47][ t]], 
            Times[ 0.59356153372868059, 
              c[ -46][ t]], 
            Times[ 0.67835603854706317, 
              c[ -45][ t]], 
            Times[ 0.75682672864065736, 
              c[ -44][ t]], 
            Times[ 0.82699334313268813, 
              c[ -43][ t]], 
            Times[ 0.88706379305918381, 
              c[ -42][ t]], 
            Times[ 0.93548928378863927, 
              c[ -41][ t]], 
            Times[ 0.9710122092317629, 
              c[ -40][ t]], 
            Times[ 0.99270519960720671, 
              c[ -39][ t]], 
            Times[ 32.670463900384519, 
              c[ -38][ t]], 
            Times[ 0.99270519960720671, 
              c[ -37][ t]], 
            Times[ 0.9710122092317629, 
              c[ -36][ t]], 
            Times[ 0.93548928378863916, 
              c[ -35][ t]], 
            Times[ 0.88706379305918381, 
              c[ -34][ t]], 
            Times[ 0.82699334313268813, 
              c[ -33][ t]], 
            Times[ 0.75682672864065692, 
              c[ -32][ t]], 
            Times[ 0.67835603854706317, 
              c[ -31][ t]], 
            Times[ 0.59356153372868059, 
              c[ -30][ t]], 
            Times[ 0.50455115242710469, 
              c[ -29][ t]], 
            Times[ 0.41349667156634395, 
              c[ -28][ t]], 
            Times[ 0.32256865202152157, 
              c[ -27][ t]], 
            Times[ 0.23387232094715985, 
              c[ -26][ t]], 
            Times[ 0.14938649372796345, 
              c[ -25][ t]], 
            Times[ 0.070907514257657775, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.062044074975450475, 
              c[ -22][ t]], 
            Times[ -0.11423673049785436, 
              c[ -21][ t]], 
            Times[ -0.15591488063143982, 
              c[ -20][ t]], 
            Times[ -0.18675027222298601, 
              c[ -19][ t]], 
            Times[ -0.206748335783172, 
              c[ -18][ t]], 
            Times[ -0.21623620818304484, 
              c[ -17][ t]], 
            Times[ -0.21584055771952015, 
              c[ -16][ t]], 
            Times[ -0.20645618564475843, 
              c[ -15][ t]], 
            Times[ -0.18920668216016426, 
              c[ -14][ t]], 
            Times[ -0.16539866862653771, 
              c[ -13][ t]], 
            Times[ -0.13647135277833605, 
              c[ -12][ t]], 
            Times[ -0.10394325375429328, 
              c[ -11][ t]], 
            Times[ -0.06935801494512607, 
              c[ -10][ t]], 
            Times[ -0.034231213779558949, 
              c[ -9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ 0.032022748374425904, 
              c[ -7][ t]], 
            Times[ 0.060688263076985105, 
              c[ -6][ t]], 
            Times[ 0.085044480344421705, 
              c[ -5][ t]], 
            Times[ 0.10436044624225685, 
              c[ -4][ t]], 
            Times[ 0.11814190616181255, 
              c[ -3][ t]], 
            Times[ 0.12613778810677614, 
              c[ -2][ t]], 
            Times[ 0.12833762891430928, 
              c[ -1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 0][ t]], 
            Times[ 0.11643488132933186, 
              c[ 1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 2][ t]], 
            Times[ 0.086542809078944891, 
              c[ 3][ t]], 
            Times[ 0.066820663127759972, 
              c[ 4][ t]], 
            Times[ 0.045163358568919301, 
              c[ 5][ t]], 
            Times[ 0.022561481809254869, 
              c[ 6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 7][ t]], 
            Times[ -0.021580547817547879, 
              c[ 8][ t]], 
            Times[ -0.04131966847794722, 
              c[ 9][ t]], 
            Times[ -0.058468080236789913, 
              c[ 10][ t]], 
            Times[ -0.072413370861974122, 
              c[ 11][ t]], 
            Times[ -0.082699334313268744, 
              c[ 12][ t]], 
            Times[ -0.089038438663606695, 
              c[ 13][ t]], 
            Times[ -0.091317159035181589, 
              c[ 14][ t]], 
            Times[ -0.089594193770366884, 
              c[ 15][ t]], 
            Times[ -0.084091858737850814, 
              c[ 16][ t]], 
            Times[ -0.075181213012062598, 
              c[ 17][ t]], 
            Times[ -0.063361699504227528, 
              c[ 18][ t]], 
            Times[ -0.049236278094138941, 
              c[ 19][ t]], 
            Times[ -0.033483179628681567, 
              c[ 20][ t]], 
            Times[ -0.016825511857749401, 
              c[ 21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ 0.016273855731265604, 
              c[ 23][ t]], 
            Times[ 0.031322974491347078, 
              c[ 24][ t]], 
            Times[ 0.044547108751839919, 
              c[ 25][ t]], 
            Times[ 0.055441487066198933, 
              c[ 26][ t]], 
            Times[ 0.063614872548668253, 
              c[ 27][ t]], 
            Times[ 0.068802429876423349, 
              c[ 28][ t]], 
            Times[ 0.070873018952678238, 
              c[ 29][ t]], 
            Times[ 0.069830768673962415, 
              c[ 30][ t]], 
            Times[ 0.065811019881796273, 
              c[ 31][ t]], 
            Times[ 0.059070953080906326, 
              c[ 32][ t]], 
            Times[ 0.049975424961080865, 
              c[ 33][ t]], 
            Times[ 0.03897872015785999, 
              c[ 34][ t]], 
            Times[ 0.026603074225527826, 
              c[ 35][ t]], 
            Times[ 0.013414935129827233, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ -0.013061910521147383, 
              c[ 38][ t]], 
            Times[ -0.025221096343682053, 
              c[ 39][ t]], 
            Times[ -0.035980357068793781, 
              c[ 40][ t]], 
            Times[ -0.044914622433376288, 
              c[ 41][ t]], 
            Times[ -0.05168708394579296, 
              c[ 42][ t]], 
            Times[ -0.056061239158567186, 
              c[ 43][ t]], 
            Times[ -0.057908442314993203, 
              c[ 44][ t]], 
            Times[ -0.057210750238908967, 
              c[ 45][ t]], 
            Times[ -0.054059052045761224, 
              c[ 46][ t]], 
            Times[ -0.048646667243099399, 
              c[ 47][ t]], 
            Times[ -0.041258781072520248, 
              c[ 48][ t]], 
            Times[ -0.032258251165125519, 
              c[ 49][ t]], 
            Times[ -0.022068459300722043, 
              c[ 50][ t]], 
            Times[ -0.011153991006822649, 
              c[ 51][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 52][ t]], 
            Times[ 0.010908848347331785, 
              c[ 53][ t]], 
            Times[ 0.021108961070255627, 
              c[ 54][ t]], 
            Times[ 0.030177073670601236, 
              c[ 55][ t]], 
            Times[ 0.03774739544932687, 
              c[ 56][ t]], 
            Times[ 0.043525965428036162, 
              c[ 57][ t]], 
            Times[ 0.047301670540041058, 
              c[ 58][ t]], 
            Times[ 0.048953528554942699, 
              c[ 59][ t]], 
            Times[ 0.048454002753361682, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-37\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-37\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.20645618564475834`\)\ \(c[\(-60\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-59\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-58\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-57\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-56\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-55\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-54\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-53\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-51\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-50\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-49\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-48\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-47\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-46\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-45\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-44\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-43\)]\)[t] + 
            0.826993343132688`\ \(c[\(-42\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-41\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-40\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-39\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-38\)]\)[t] + 
            31.025529833536286`\ \(c[\(-37\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-36\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-35\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-34\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-33\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-32\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-31\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-30\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-29\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-28\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-27\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-26\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-25\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-24\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-23\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-21\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-20\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-19\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-18\)]\)[t] - 
            0.206748335783172`\ \(c[\(-17\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-16\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-15\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-14\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-13\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-12\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-11\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-10\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-9\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-8\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-6\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-5\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-4\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-3\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-2\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-1\)]\)[t] + 
            0.12833762891430928`\ \(c[0]\)[t] + 
            0.12496032289024853`\ \(c[1]\)[t] + 
            0.11643488132933186`\ \(c[2]\)[t] + 
            0.10337416789158609`\ \(c[3]\)[t] + 
            0.08654280907894489`\ \(c[4]\)[t] + 
            0.06682066312775997`\ \(c[5]\)[t] + 
            0.0451633585689193`\ \(c[6]\)[t] + 
            0.02256148180925487`\ \(c[7]\)[t] + 
            3.8981718325193755`*^-17\ \(c[8]\)[t] - 
            0.02158054781754788`\ \(c[9]\)[t] - 
            0.04131966847794722`\ \(c[10]\)[t] - 
            0.05846808023678991`\ \(c[11]\)[t] - 
            0.07241337086197412`\ \(c[12]\)[t] - 
            0.08269933431326874`\ \(c[13]\)[t] - 
            0.0890384386636067`\ \(c[14]\)[t] - 
            0.09131715903518159`\ \(c[15]\)[t] - 
            0.08959419377036688`\ \(c[16]\)[t] - 
            0.08409185873785081`\ \(c[17]\)[t] - 
            0.0751812130120626`\ \(c[18]\)[t] - 
            0.06336169950422753`\ \(c[19]\)[t] - 
            0.04923627809413894`\ \(c[20]\)[t] - 
            0.03348317962868157`\ \(c[21]\)[t] - 
            0.0168255118577494`\ \(c[22]\)[t] - 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.016273855731265604`\ \(c[24]\)[t] + 
            0.03132297449134708`\ \(c[25]\)[t] + 
            0.04454710875183992`\ \(c[26]\)[t] + 
            0.05544148706619893`\ \(c[27]\)[t] + 
            0.06361487254866825`\ \(c[28]\)[t] + 
            0.06880242987642335`\ \(c[29]\)[t] + 
            0.07087301895267824`\ \(c[30]\)[t] + 
            0.06983076867396242`\ \(c[31]\)[t] + 
            0.06581101988179627`\ \(c[32]\)[t] + 
            0.059070953080906326`\ \(c[33]\)[t] + 
            0.049975424961080865`\ \(c[34]\)[t] + 
            0.03897872015785999`\ \(c[35]\)[t] + 
            0.026603074225527826`\ \(c[36]\)[t] + 
            0.013414935129827233`\ \(c[37]\)[t] + 
            3.898171832519376`*^-17\ \(c[38]\)[t] - 
            0.013061910521147383`\ \(c[39]\)[t] - 
            0.025221096343682053`\ \(c[40]\)[t] - 
            0.03598035706879378`\ \(c[41]\)[t] - 
            0.04491462243337642`\ \(c[42]\)[t] - 
            0.05168708394579296`\ \(c[43]\)[t] - 
            0.05606123915856713`\ \(c[44]\)[t] - 
            0.0579084423149932`\ \(c[45]\)[t] - 
            0.05721075023890897`\ \(c[46]\)[t] - 
            0.054059052045761224`\ \(c[47]\)[t] - 
            0.04864666724309928`\ \(c[48]\)[t] - 
            0.04125878107252025`\ \(c[49]\)[t] - 
            0.03225825116512568`\ \(c[50]\)[t] - 
            0.022068459300722043`\ \(c[51]\)[t] - 
            0.011153991006822649`\ \(c[52]\)[t] - 
            3.8981718325193755`*^-17\ \(c[53]\)[t] + 
            0.010908848347331966`\ \(c[54]\)[t] + 
            0.021108961070255627`\ \(c[55]\)[t] + 
            0.030177073670601094`\ \(c[56]\)[t] + 
            0.03774739544932687`\ \(c[57]\)[t] + 
            0.04352596542803616`\ \(c[58]\)[t] + 
            0.04730167054004106`\ \(c[59]\)[t] + 
            0.04895352855494272`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -37, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -37]][ t]], 
          Plus[ 
            Times[ -0.20645618564475834, 
              c[ -60][ t]], 
            Times[ -0.21584055771952015, 
              c[ -59][ t]], 
            Times[ -0.21623620818304484, 
              c[ -58][ t]], 
            Times[ -0.20674833578317206, 
              c[ -57][ t]], 
            Times[ -0.18675027222298593, 
              c[ -56][ t]], 
            Times[ -0.15591488063143982, 
              c[ -55][ t]], 
            Times[ -0.11423673049785459, 
              c[ -54][ t]], 
            Times[ -0.062044074975450239, 
              c[ -53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ 0.070907514257657456, 
              c[ -51][ t]], 
            Times[ 0.14938649372796384, 
              c[ -50][ t]], 
            Times[ 0.23387232094715985, 
              c[ -49][ t]], 
            Times[ 0.32256865202152113, 
              c[ -48][ t]], 
            Times[ 0.41349667156634429, 
              c[ -47][ t]], 
            Times[ 0.50455115242710469, 
              c[ -46][ t]], 
            Times[ 0.59356153372868015, 
              c[ -45][ t]], 
            Times[ 0.67835603854706361, 
              c[ -44][ t]], 
            Times[ 0.75682672864065692, 
              c[ -43][ t]], 
            Times[ 0.82699334313268802, 
              c[ -42][ t]], 
            Times[ 0.88706379305918392, 
              c[ -41][ t]], 
            Times[ 0.93548928378863916, 
              c[ -40][ t]], 
            Times[ 0.9710122092317629, 
              c[ -39][ t]], 
            Times[ 0.99270519960720671, 
              c[ -38][ t]], 
            Times[ 31.025529833536286, 
              c[ -37][ t]], 
            Times[ 0.99270519960720693, 
              c[ -36][ t]], 
            Times[ 0.9710122092317629, 
              c[ -35][ t]], 
            Times[ 0.93548928378863916, 
              c[ -34][ t]], 
            Times[ 0.88706379305918392, 
              c[ -33][ t]], 
            Times[ 0.82699334313268813, 
              c[ -32][ t]], 
            Times[ 0.75682672864065692, 
              c[ -31][ t]], 
            Times[ 0.67835603854706361, 
              c[ -30][ t]], 
            Times[ 0.59356153372868059, 
              c[ -29][ t]], 
            Times[ 0.50455115242710469, 
              c[ -28][ t]], 
            Times[ 0.41349667156634429, 
              c[ -27][ t]], 
            Times[ 0.32256865202152157, 
              c[ -26][ t]], 
            Times[ 0.23387232094715985, 
              c[ -25][ t]], 
            Times[ 0.14938649372796384, 
              c[ -24][ t]], 
            Times[ 0.070907514257657775, 
              c[ -23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ -0.062044074975450239, 
              c[ -21][ t]], 
            Times[ -0.11423673049785436, 
              c[ -20][ t]], 
            Times[ -0.15591488063143974, 
              c[ -19][ t]], 
            Times[ -0.18675027222298593, 
              c[ -18][ t]], 
            Times[ -0.206748335783172, 
              c[ -17][ t]], 
            Times[ -0.21623620818304484, 
              c[ -16][ t]], 
            Times[ -0.21584055771952015, 
              c[ -15][ t]], 
            Times[ -0.20645618564475843, 
              c[ -14][ t]], 
            Times[ -0.18920668216016426, 
              c[ -13][ t]], 
            Times[ -0.16539866862653771, 
              c[ -12][ t]], 
            Times[ -0.13647135277833605, 
              c[ -11][ t]], 
            Times[ -0.10394325375429328, 
              c[ -10][ t]], 
            Times[ -0.06935801494512607, 
              c[ -9][ t]], 
            Times[ -0.034231213779558949, 
              c[ -8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ 0.032022748374425904, 
              c[ -6][ t]], 
            Times[ 0.060688263076985105, 
              c[ -5][ t]], 
            Times[ 0.085044480344421608, 
              c[ -4][ t]], 
            Times[ 0.10436044624225685, 
              c[ -3][ t]], 
            Times[ 0.11814190616181255, 
              c[ -2][ t]], 
            Times[ 0.12613778810677612, 
              c[ -1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 0][ t]], 
            Times[ 0.12496032289024853, 
              c[ 1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 2][ t]], 
            Times[ 0.10337416789158609, 
              c[ 3][ t]], 
            Times[ 0.086542809078944891, 
              c[ 4][ t]], 
            Times[ 0.066820663127759972, 
              c[ 5][ t]], 
            Times[ 0.045163358568919301, 
              c[ 6][ t]], 
            Times[ 0.022561481809254869, 
              c[ 7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 8][ t]], 
            Times[ -0.021580547817547879, 
              c[ 9][ t]], 
            Times[ -0.04131966847794722, 
              c[ 10][ t]], 
            Times[ -0.058468080236789913, 
              c[ 11][ t]], 
            Times[ -0.072413370861974122, 
              c[ 12][ t]], 
            Times[ -0.082699334313268744, 
              c[ 13][ t]], 
            Times[ -0.089038438663606695, 
              c[ 14][ t]], 
            Times[ -0.091317159035181589, 
              c[ 15][ t]], 
            Times[ -0.089594193770366884, 
              c[ 16][ t]], 
            Times[ -0.084091858737850814, 
              c[ 17][ t]], 
            Times[ -0.075181213012062598, 
              c[ 18][ t]], 
            Times[ -0.063361699504227528, 
              c[ 19][ t]], 
            Times[ -0.049236278094138941, 
              c[ 20][ t]], 
            Times[ -0.033483179628681567, 
              c[ 21][ t]], 
            Times[ -0.016825511857749401, 
              c[ 22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.016273855731265604, 
              c[ 24][ t]], 
            Times[ 0.031322974491347078, 
              c[ 25][ t]], 
            Times[ 0.044547108751839919, 
              c[ 26][ t]], 
            Times[ 0.055441487066198933, 
              c[ 27][ t]], 
            Times[ 0.063614872548668253, 
              c[ 28][ t]], 
            Times[ 0.068802429876423349, 
              c[ 29][ t]], 
            Times[ 0.070873018952678238, 
              c[ 30][ t]], 
            Times[ 0.069830768673962415, 
              c[ 31][ t]], 
            Times[ 0.065811019881796273, 
              c[ 32][ t]], 
            Times[ 0.059070953080906326, 
              c[ 33][ t]], 
            Times[ 0.049975424961080865, 
              c[ 34][ t]], 
            Times[ 0.03897872015785999, 
              c[ 35][ t]], 
            Times[ 0.026603074225527826, 
              c[ 36][ t]], 
            Times[ 0.013414935129827233, 
              c[ 37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ -0.013061910521147383, 
              c[ 39][ t]], 
            Times[ -0.025221096343682053, 
              c[ 40][ t]], 
            Times[ -0.035980357068793781, 
              c[ 41][ t]], 
            Times[ -0.044914622433376419, 
              c[ 42][ t]], 
            Times[ -0.05168708394579296, 
              c[ 43][ t]], 
            Times[ -0.05606123915856713, 
              c[ 44][ t]], 
            Times[ -0.057908442314993203, 
              c[ 45][ t]], 
            Times[ -0.057210750238908967, 
              c[ 46][ t]], 
            Times[ -0.054059052045761224, 
              c[ 47][ t]], 
            Times[ -0.048646667243099281, 
              c[ 48][ t]], 
            Times[ -0.041258781072520248, 
              c[ 49][ t]], 
            Times[ -0.032258251165125679, 
              c[ 50][ t]], 
            Times[ -0.022068459300722043, 
              c[ 51][ t]], 
            Times[ -0.011153991006822649, 
              c[ 52][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 53][ t]], 
            Times[ 0.010908848347331966, 
              c[ 54][ t]], 
            Times[ 0.021108961070255627, 
              c[ 55][ t]], 
            Times[ 0.030177073670601094, 
              c[ 56][ t]], 
            Times[ 0.03774739544932687, 
              c[ 57][ t]], 
            Times[ 0.043525965428036162, 
              c[ 58][ t]], 
            Times[ 0.047301670540041058, 
              c[ 59][ t]], 
            Times[ 0.04895352855494272, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-36\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-36\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.18920668216016426`\)\ \(c[\(-60\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-59\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-58\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-57\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-56\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-55\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-54\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-53\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-52\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-50\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-49\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-48\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-47\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-46\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-45\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-44\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-43\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-42\)]\)[t] + 
            0.8269933431326885`\ \(c[\(-41\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-40\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-39\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-38\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-37\)]\)[t] + 
            29.42446067513735`\ \(c[\(-36\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-35\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-34\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-33\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-32\)]\)[t] + 
            0.826993343132688`\ \(c[\(-31\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-30\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-29\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-28\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-27\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-26\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-25\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-24\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-23\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-20\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-19\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-18\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-17\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-16\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-15\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-14\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-13\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-12\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-11\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-10\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-9\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-8\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-5\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-4\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-3\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-2\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-1\)]\)[t] + 
            0.12613778810677614`\ \(c[0]\)[t] + 
            0.12833762891430925`\ \(c[1]\)[t] + 
            0.12496032289024853`\ \(c[2]\)[t] + 
            0.11643488132933186`\ \(c[3]\)[t] + 
            0.10337416789158609`\ \(c[4]\)[t] + 
            0.08654280907894475`\ \(c[5]\)[t] + 
            0.06682066312775997`\ \(c[6]\)[t] + 
            0.0451633585689193`\ \(c[7]\)[t] + 
            0.022561481809254675`\ \(c[8]\)[t] + 
            3.8981718325193755`*^-17\ \(c[9]\)[t] - 
            0.02158054781754788`\ \(c[10]\)[t] - 
            0.04131966847794722`\ \(c[11]\)[t] - 
            0.05846808023678991`\ \(c[12]\)[t] - 
            0.07241337086197412`\ \(c[13]\)[t] - 
            0.08269933431326874`\ \(c[14]\)[t] - 
            0.0890384386636067`\ \(c[15]\)[t] - 
            0.09131715903518159`\ \(c[16]\)[t] - 
            0.08959419377036688`\ \(c[17]\)[t] - 
            0.08409185873785081`\ \(c[18]\)[t] - 
            0.0751812130120626`\ \(c[19]\)[t] - 
            0.06336169950422753`\ \(c[20]\)[t] - 
            0.04923627809413894`\ \(c[21]\)[t] - 
            0.03348317962868157`\ \(c[22]\)[t] - 
            0.0168255118577494`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.016273855731265604`\ \(c[25]\)[t] + 
            0.03132297449134708`\ \(c[26]\)[t] + 
            0.04454710875183992`\ \(c[27]\)[t] + 
            0.05544148706619893`\ \(c[28]\)[t] + 
            0.06361487254866825`\ \(c[29]\)[t] + 
            0.06880242987642335`\ \(c[30]\)[t] + 
            0.07087301895267824`\ \(c[31]\)[t] + 
            0.06983076867396242`\ \(c[32]\)[t] + 
            0.06581101988179627`\ \(c[33]\)[t] + 
            0.059070953080906326`\ \(c[34]\)[t] + 
            0.049975424961080865`\ \(c[35]\)[t] + 
            0.03897872015785999`\ \(c[36]\)[t] + 
            0.026603074225527826`\ \(c[37]\)[t] + 
            0.013414935129827233`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] - 
            0.013061910521147383`\ \(c[40]\)[t] - 
            0.025221096343682053`\ \(c[41]\)[t] - 
            0.03598035706879378`\ \(c[42]\)[t] - 
            0.04491462243337642`\ \(c[43]\)[t] - 
            0.05168708394579296`\ \(c[44]\)[t] - 
            0.056061239158567186`\ \(c[45]\)[t] - 
            0.0579084423149932`\ \(c[46]\)[t] - 
            0.05721075023890897`\ \(c[47]\)[t] - 
            0.054059052045761224`\ \(c[48]\)[t] - 
            0.04864666724309928`\ \(c[49]\)[t] - 
            0.04125878107252025`\ \(c[50]\)[t] - 
            0.03225825116512552`\ \(c[51]\)[t] - 
            0.022068459300722043`\ \(c[52]\)[t] - 
            0.011153991006822649`\ \(c[53]\)[t] - 
            3.8981718325193755`*^-17\ \(c[54]\)[t] + 
            0.010908848347331966`\ \(c[55]\)[t] + 
            0.021108961070255627`\ \(c[56]\)[t] + 
            0.030177073670601236`\ \(c[57]\)[t] + 
            0.03774739544932687`\ \(c[58]\)[t] + 
            0.04352596542803616`\ \(c[59]\)[t] + 
            0.04730167054004106`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -36, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -36]][ t]], 
          Plus[ 
            Times[ -0.18920668216016426, 
              c[ -60][ t]], 
            Times[ -0.20645618564475848, 
              c[ -59][ t]], 
            Times[ -0.21584055771952015, 
              c[ -58][ t]], 
            Times[ -0.21623620818304484, 
              c[ -57][ t]], 
            Times[ -0.20674833578317189, 
              c[ -56][ t]], 
            Times[ -0.18675027222298593, 
              c[ -55][ t]], 
            Times[ -0.15591488063143982, 
              c[ -54][ t]], 
            Times[ -0.11423673049785416, 
              c[ -53][ t]], 
            Times[ -0.062044074975450239, 
              c[ -52][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ 0.070907514257658094, 
              c[ -50][ t]], 
            Times[ 0.14938649372796384, 
              c[ -49][ t]], 
            Times[ 0.23387232094715985, 
              c[ -48][ t]], 
            Times[ 0.32256865202152191, 
              c[ -47][ t]], 
            Times[ 0.41349667156634429, 
              c[ -46][ t]], 
            Times[ 0.50455115242710469, 
              c[ -45][ t]], 
            Times[ 0.59356153372868092, 
              c[ -44][ t]], 
            Times[ 0.67835603854706361, 
              c[ -43][ t]], 
            Times[ 0.75682672864065692, 
              c[ -42][ t]], 
            Times[ 0.82699334313268846, 
              c[ -41][ t]], 
            Times[ 0.88706379305918392, 
              c[ -40][ t]], 
            Times[ 0.93548928378863916, 
              c[ -39][ t]], 
            Times[ 0.9710122092317629, 
              c[ -38][ t]], 
            Times[ 0.99270519960720693, 
              c[ -37][ t]], 
            Times[ 29.42446067513735, 
              c[ -36][ t]], 
            Times[ 0.99270519960720671, 
              c[ -35][ t]], 
            Times[ 0.9710122092317629, 
              c[ -34][ t]], 
            Times[ 0.93548928378863916, 
              c[ -33][ t]], 
            Times[ 0.88706379305918381, 
              c[ -32][ t]], 
            Times[ 0.82699334313268802, 
              c[ -31][ t]], 
            Times[ 0.75682672864065692, 
              c[ -30][ t]], 
            Times[ 0.67835603854706317, 
              c[ -29][ t]], 
            Times[ 0.59356153372868015, 
              c[ -28][ t]], 
            Times[ 0.50455115242710469, 
              c[ -27][ t]], 
            Times[ 0.41349667156634395, 
              c[ -26][ t]], 
            Times[ 0.32256865202152113, 
              c[ -25][ t]], 
            Times[ 0.23387232094715985, 
              c[ -24][ t]], 
            Times[ 0.14938649372796345, 
              c[ -23][ t]], 
            Times[ 0.070907514257657456, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.062044074975450475, 
              c[ -20][ t]], 
            Times[ -0.11423673049785445, 
              c[ -19][ t]], 
            Times[ -0.15591488063143982, 
              c[ -18][ t]], 
            Times[ -0.18675027222298607, 
              c[ -17][ t]], 
            Times[ -0.20674833578317206, 
              c[ -16][ t]], 
            Times[ -0.21623620818304484, 
              c[ -15][ t]], 
            Times[ -0.21584055771952013, 
              c[ -14][ t]], 
            Times[ -0.20645618564475834, 
              c[ -13][ t]], 
            Times[ -0.18920668216016426, 
              c[ -12][ t]], 
            Times[ -0.1653986686265376, 
              c[ -11][ t]], 
            Times[ -0.13647135277833591, 
              c[ -10][ t]], 
            Times[ -0.10394325375429328, 
              c[ -9][ t]], 
            Times[ -0.069358014945125918, 
              c[ -8][ t]], 
            Times[ -0.034231213779558796, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ 0.032022748374426029, 
              c[ -5][ t]], 
            Times[ 0.060688263076985105, 
              c[ -4][ t]], 
            Times[ 0.085044480344421705, 
              c[ -3][ t]], 
            Times[ 0.10436044624225692, 
              c[ -2][ t]], 
            Times[ 0.11814190616181255, 
              c[ -1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 0][ t]], 
            Times[ 0.12833762891430925, 
              c[ 1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 2][ t]], 
            Times[ 0.11643488132933186, 
              c[ 3][ t]], 
            Times[ 0.10337416789158609, 
              c[ 4][ t]], 
            Times[ 0.086542809078944752, 
              c[ 5][ t]], 
            Times[ 0.066820663127759972, 
              c[ 6][ t]], 
            Times[ 0.045163358568919301, 
              c[ 7][ t]], 
            Times[ 0.022561481809254675, 
              c[ 8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 9][ t]], 
            Times[ -0.021580547817547879, 
              c[ 10][ t]], 
            Times[ -0.04131966847794722, 
              c[ 11][ t]], 
            Times[ -0.058468080236789913, 
              c[ 12][ t]], 
            Times[ -0.072413370861974122, 
              c[ 13][ t]], 
            Times[ -0.082699334313268744, 
              c[ 14][ t]], 
            Times[ -0.089038438663606695, 
              c[ 15][ t]], 
            Times[ -0.091317159035181589, 
              c[ 16][ t]], 
            Times[ -0.089594193770366884, 
              c[ 17][ t]], 
            Times[ -0.084091858737850814, 
              c[ 18][ t]], 
            Times[ -0.075181213012062598, 
              c[ 19][ t]], 
            Times[ -0.063361699504227528, 
              c[ 20][ t]], 
            Times[ -0.049236278094138941, 
              c[ 21][ t]], 
            Times[ -0.033483179628681567, 
              c[ 22][ t]], 
            Times[ -0.016825511857749401, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.016273855731265604, 
              c[ 25][ t]], 
            Times[ 0.031322974491347078, 
              c[ 26][ t]], 
            Times[ 0.044547108751839919, 
              c[ 27][ t]], 
            Times[ 0.055441487066198933, 
              c[ 28][ t]], 
            Times[ 0.063614872548668253, 
              c[ 29][ t]], 
            Times[ 0.068802429876423349, 
              c[ 30][ t]], 
            Times[ 0.070873018952678238, 
              c[ 31][ t]], 
            Times[ 0.069830768673962415, 
              c[ 32][ t]], 
            Times[ 0.065811019881796273, 
              c[ 33][ t]], 
            Times[ 0.059070953080906326, 
              c[ 34][ t]], 
            Times[ 0.049975424961080865, 
              c[ 35][ t]], 
            Times[ 0.03897872015785999, 
              c[ 36][ t]], 
            Times[ 0.026603074225527826, 
              c[ 37][ t]], 
            Times[ 0.013414935129827233, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ -0.013061910521147383, 
              c[ 40][ t]], 
            Times[ -0.025221096343682053, 
              c[ 41][ t]], 
            Times[ -0.035980357068793781, 
              c[ 42][ t]], 
            Times[ -0.044914622433376419, 
              c[ 43][ t]], 
            Times[ -0.05168708394579296, 
              c[ 44][ t]], 
            Times[ -0.056061239158567186, 
              c[ 45][ t]], 
            Times[ -0.057908442314993203, 
              c[ 46][ t]], 
            Times[ -0.057210750238908967, 
              c[ 47][ t]], 
            Times[ -0.054059052045761224, 
              c[ 48][ t]], 
            Times[ -0.048646667243099281, 
              c[ 49][ t]], 
            Times[ -0.041258781072520248, 
              c[ 50][ t]], 
            Times[ -0.032258251165125519, 
              c[ 51][ t]], 
            Times[ -0.022068459300722043, 
              c[ 52][ t]], 
            Times[ -0.011153991006822649, 
              c[ 53][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ 0.010908848347331966, 
              c[ 55][ t]], 
            Times[ 0.021108961070255627, 
              c[ 56][ t]], 
            Times[ 0.030177073670601236, 
              c[ 57][ t]], 
            Times[ 0.03774739544932687, 
              c[ 58][ t]], 
            Times[ 0.043525965428036162, 
              c[ 59][ t]], 
            Times[ 0.047301670540041058, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-35\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-35\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.1653986686265376`\)\ \(c[\(-60\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-59\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-58\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-57\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-56\)]\)[t] - 
            0.206748335783172`\ \(c[\(-55\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-54\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-53\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-52\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-51\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-50\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-49\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-48\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-47\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-46\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-45\)]\)[t] + 
            0.504551152427105`\ \(c[\(-44\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-43\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-42\)]\)[t] + 
            0.7568267286406574`\ \(c[\(-41\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-40\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-39\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-38\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-37\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-36\)]\)[t] + 
            27.867256425187694`\ \(c[\(-35\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-34\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-33\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-32\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-31\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-30\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-29\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-28\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-27\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-26\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-25\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-24\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-23\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-22\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-19\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-18\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-17\)]\)[t] - 
            0.186750272222986`\ \(c[\(-16\)]\)[t] - 
            0.206748335783172`\ \(c[\(-15\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-14\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-13\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-12\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-11\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-10\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-9\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-8\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-7\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-6\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-4\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-3\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-2\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-1\)]\)[t] + 
            0.11814190616181255`\ \(c[0]\)[t] + 
            0.12613778810677614`\ \(c[1]\)[t] + 
            0.12833762891430928`\ \(c[2]\)[t] + 
            0.12496032289024853`\ \(c[3]\)[t] + 
            0.11643488132933186`\ \(c[4]\)[t] + 
            0.10337416789158609`\ \(c[5]\)[t] + 
            0.08654280907894489`\ \(c[6]\)[t] + 
            0.06682066312775997`\ \(c[7]\)[t] + 
            0.0451633585689193`\ \(c[8]\)[t] + 
            0.02256148180925487`\ \(c[9]\)[t] + 
            3.8981718325193755`*^-17\ \(c[10]\)[t] - 
            0.02158054781754788`\ \(c[11]\)[t] - 
            0.04131966847794722`\ \(c[12]\)[t] - 
            0.05846808023678991`\ \(c[13]\)[t] - 
            0.07241337086197412`\ \(c[14]\)[t] - 
            0.08269933431326874`\ \(c[15]\)[t] - 
            0.0890384386636067`\ \(c[16]\)[t] - 
            0.09131715903518159`\ \(c[17]\)[t] - 
            0.08959419377036688`\ \(c[18]\)[t] - 
            0.08409185873785081`\ \(c[19]\)[t] - 
            0.0751812130120626`\ \(c[20]\)[t] - 
            0.06336169950422753`\ \(c[21]\)[t] - 
            0.04923627809413894`\ \(c[22]\)[t] - 
            0.03348317962868157`\ \(c[23]\)[t] - 
            0.0168255118577494`\ \(c[24]\)[t] - 
            3.898171832519376`*^-17\ \(c[25]\)[t] + 
            0.016273855731265604`\ \(c[26]\)[t] + 
            0.03132297449134708`\ \(c[27]\)[t] + 
            0.04454710875183992`\ \(c[28]\)[t] + 
            0.05544148706619893`\ \(c[29]\)[t] + 
            0.06361487254866825`\ \(c[30]\)[t] + 
            0.06880242987642335`\ \(c[31]\)[t] + 
            0.07087301895267824`\ \(c[32]\)[t] + 
            0.06983076867396242`\ \(c[33]\)[t] + 
            0.06581101988179627`\ \(c[34]\)[t] + 
            0.059070953080906326`\ \(c[35]\)[t] + 
            0.049975424961080865`\ \(c[36]\)[t] + 
            0.03897872015785999`\ \(c[37]\)[t] + 
            0.026603074225527826`\ \(c[38]\)[t] + 
            0.013414935129827233`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] - 
            0.013061910521147276`\ \(c[41]\)[t] - 
            0.025221096343682053`\ \(c[42]\)[t] - 
            0.03598035706879378`\ \(c[43]\)[t] - 
            0.04491462243337629`\ \(c[44]\)[t] - 
            0.05168708394579296`\ \(c[45]\)[t] - 
            0.056061239158567186`\ \(c[46]\)[t] - 
            0.0579084423149932`\ \(c[47]\)[t] - 
            0.05721075023890897`\ \(c[48]\)[t] - 
            0.054059052045761224`\ \(c[49]\)[t] - 
            0.0486466672430994`\ \(c[50]\)[t] - 
            0.04125878107252025`\ \(c[51]\)[t] - 
            0.03225825116512552`\ \(c[52]\)[t] - 
            0.022068459300722043`\ \(c[53]\)[t] - 
            0.011153991006822649`\ \(c[54]\)[t] - 
            3.8981718325193755`*^-17\ \(c[55]\)[t] + 
            0.010908848347331785`\ \(c[56]\)[t] + 
            0.021108961070255627`\ \(c[57]\)[t] + 
            0.030177073670601236`\ \(c[58]\)[t] + 
            0.03774739544932687`\ \(c[59]\)[t] + 
            0.04352596542803616`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -35, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -35]][ t]], 
          Plus[ 
            Times[ -0.1653986686265376, 
              c[ -60][ t]], 
            Times[ -0.18920668216016434, 
              c[ -59][ t]], 
            Times[ -0.20645618564475843, 
              c[ -58][ t]], 
            Times[ -0.21584055771952013, 
              c[ -57][ t]], 
            Times[ -0.21623620818304481, 
              c[ -56][ t]], 
            Times[ -0.206748335783172, 
              c[ -55][ t]], 
            Times[ -0.18675027222298607, 
              c[ -54][ t]], 
            Times[ -0.15591488063143966, 
              c[ -53][ t]], 
            Times[ -0.11423673049785436, 
              c[ -52][ t]], 
            Times[ -0.062044074975450475, 
              c[ -51][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -50][ t]], 
            Times[ 0.070907514257657775, 
              c[ -49][ t]], 
            Times[ 0.14938649372796345, 
              c[ -48][ t]], 
            Times[ 0.23387232094716018, 
              c[ -47][ t]], 
            Times[ 0.32256865202152157, 
              c[ -46][ t]], 
            Times[ 0.41349667156634395, 
              c[ -45][ t]], 
            Times[ 0.50455115242710502, 
              c[ -44][ t]], 
            Times[ 0.59356153372868059, 
              c[ -43][ t]], 
            Times[ 0.67835603854706317, 
              c[ -42][ t]], 
            Times[ 0.75682672864065736, 
              c[ -41][ t]], 
            Times[ 0.82699334313268813, 
              c[ -40][ t]], 
            Times[ 0.88706379305918381, 
              c[ -39][ t]], 
            Times[ 0.93548928378863916, 
              c[ -38][ t]], 
            Times[ 0.9710122092317629, 
              c[ -37][ t]], 
            Times[ 0.99270519960720671, 
              c[ -36][ t]], 
            Times[ 27.867256425187694, 
              c[ -35][ t]], 
            Times[ 0.99270519960720671, 
              c[ -34][ t]], 
            Times[ 0.9710122092317629, 
              c[ -33][ t]], 
            Times[ 0.93548928378863916, 
              c[ -32][ t]], 
            Times[ 0.88706379305918381, 
              c[ -31][ t]], 
            Times[ 0.82699334313268813, 
              c[ -30][ t]], 
            Times[ 0.75682672864065692, 
              c[ -29][ t]], 
            Times[ 0.67835603854706317, 
              c[ -28][ t]], 
            Times[ 0.59356153372868059, 
              c[ -27][ t]], 
            Times[ 0.50455115242710469, 
              c[ -26][ t]], 
            Times[ 0.41349667156634395, 
              c[ -25][ t]], 
            Times[ 0.32256865202152157, 
              c[ -24][ t]], 
            Times[ 0.23387232094715985, 
              c[ -23][ t]], 
            Times[ 0.14938649372796345, 
              c[ -22][ t]], 
            Times[ 0.070907514257657775, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.062044074975450343, 
              c[ -19][ t]], 
            Times[ -0.11423673049785436, 
              c[ -18][ t]], 
            Times[ -0.15591488063143982, 
              c[ -17][ t]], 
            Times[ -0.18675027222298601, 
              c[ -16][ t]], 
            Times[ -0.206748335783172, 
              c[ -15][ t]], 
            Times[ -0.21623620818304484, 
              c[ -14][ t]], 
            Times[ -0.21584055771952015, 
              c[ -13][ t]], 
            Times[ -0.20645618564475843, 
              c[ -12][ t]], 
            Times[ -0.18920668216016426, 
              c[ -11][ t]], 
            Times[ -0.16539866862653771, 
              c[ -10][ t]], 
            Times[ -0.13647135277833605, 
              c[ -9][ t]], 
            Times[ -0.10394325375429328, 
              c[ -8][ t]], 
            Times[ -0.06935801494512607, 
              c[ -7][ t]], 
            Times[ -0.034231213779558949, 
              c[ -6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ 0.032022748374425904, 
              c[ -4][ t]], 
            Times[ 0.060688263076985105, 
              c[ -3][ t]], 
            Times[ 0.085044480344421705, 
              c[ -2][ t]], 
            Times[ 0.10436044624225685, 
              c[ -1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 0][ t]], 
            Times[ 0.12613778810677614, 
              c[ 1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 2][ t]], 
            Times[ 0.12496032289024853, 
              c[ 3][ t]], 
            Times[ 0.11643488132933186, 
              c[ 4][ t]], 
            Times[ 0.10337416789158609, 
              c[ 5][ t]], 
            Times[ 0.086542809078944891, 
              c[ 6][ t]], 
            Times[ 0.066820663127759972, 
              c[ 7][ t]], 
            Times[ 0.045163358568919301, 
              c[ 8][ t]], 
            Times[ 0.022561481809254869, 
              c[ 9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 10][ t]], 
            Times[ -0.021580547817547879, 
              c[ 11][ t]], 
            Times[ -0.04131966847794722, 
              c[ 12][ t]], 
            Times[ -0.058468080236789913, 
              c[ 13][ t]], 
            Times[ -0.072413370861974122, 
              c[ 14][ t]], 
            Times[ -0.082699334313268744, 
              c[ 15][ t]], 
            Times[ -0.089038438663606695, 
              c[ 16][ t]], 
            Times[ -0.091317159035181589, 
              c[ 17][ t]], 
            Times[ -0.089594193770366884, 
              c[ 18][ t]], 
            Times[ -0.084091858737850814, 
              c[ 19][ t]], 
            Times[ -0.075181213012062598, 
              c[ 20][ t]], 
            Times[ -0.063361699504227528, 
              c[ 21][ t]], 
            Times[ -0.049236278094138941, 
              c[ 22][ t]], 
            Times[ -0.033483179628681567, 
              c[ 23][ t]], 
            Times[ -0.016825511857749401, 
              c[ 24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ 0.016273855731265604, 
              c[ 26][ t]], 
            Times[ 0.031322974491347078, 
              c[ 27][ t]], 
            Times[ 0.044547108751839919, 
              c[ 28][ t]], 
            Times[ 0.055441487066198933, 
              c[ 29][ t]], 
            Times[ 0.063614872548668253, 
              c[ 30][ t]], 
            Times[ 0.068802429876423349, 
              c[ 31][ t]], 
            Times[ 0.070873018952678238, 
              c[ 32][ t]], 
            Times[ 0.069830768673962415, 
              c[ 33][ t]], 
            Times[ 0.065811019881796273, 
              c[ 34][ t]], 
            Times[ 0.059070953080906326, 
              c[ 35][ t]], 
            Times[ 0.049975424961080865, 
              c[ 36][ t]], 
            Times[ 0.03897872015785999, 
              c[ 37][ t]], 
            Times[ 0.026603074225527826, 
              c[ 38][ t]], 
            Times[ 0.013414935129827233, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ -0.013061910521147276, 
              c[ 41][ t]], 
            Times[ -0.025221096343682053, 
              c[ 42][ t]], 
            Times[ -0.035980357068793781, 
              c[ 43][ t]], 
            Times[ -0.044914622433376288, 
              c[ 44][ t]], 
            Times[ -0.05168708394579296, 
              c[ 45][ t]], 
            Times[ -0.056061239158567186, 
              c[ 46][ t]], 
            Times[ -0.057908442314993203, 
              c[ 47][ t]], 
            Times[ -0.057210750238908967, 
              c[ 48][ t]], 
            Times[ -0.054059052045761224, 
              c[ 49][ t]], 
            Times[ -0.048646667243099399, 
              c[ 50][ t]], 
            Times[ -0.041258781072520248, 
              c[ 51][ t]], 
            Times[ -0.032258251165125519, 
              c[ 52][ t]], 
            Times[ -0.022068459300722043, 
              c[ 53][ t]], 
            Times[ -0.011153991006822649, 
              c[ 54][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 55][ t]], 
            Times[ 0.010908848347331785, 
              c[ 56][ t]], 
            Times[ 0.021108961070255627, 
              c[ 57][ t]], 
            Times[ 0.030177073670601236, 
              c[ 58][ t]], 
            Times[ 0.03774739544932687, 
              c[ 59][ t]], 
            Times[ 0.043525965428036162, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-34\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-34\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.1364713527783359`\)\ \(c[\(-60\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-59\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-58\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-57\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-56\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-55\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-54\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-53\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-52\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-51\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-50\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-48\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-47\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-46\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-45\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-44\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-43\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-42\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-41\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-40\)]\)[t] + 
            0.826993343132688`\ \(c[\(-39\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-38\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-37\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-36\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-35\)]\)[t] + 
            26.353917083687325`\ \(c[\(-34\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-33\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-32\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-31\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-30\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-29\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-28\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-27\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-26\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-25\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-24\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-23\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-22\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-21\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-20\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-19\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-18\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-17\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-16\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-15\)]\)[t] - 
            0.206748335783172`\ \(c[\(-14\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-13\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-12\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-11\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-10\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-9\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-8\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-7\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-6\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-5\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-3\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-2\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-1\)]\)[t] + 
            0.10436044624225685`\ \(c[0]\)[t] + 
            0.11814190616181255`\ \(c[1]\)[t] + 
            0.12613778810677612`\ \(c[2]\)[t] + 
            0.12833762891430928`\ \(c[3]\)[t] + 
            0.12496032289024853`\ \(c[4]\)[t] + 
            0.11643488132933186`\ \(c[5]\)[t] + 
            0.10337416789158609`\ \(c[6]\)[t] + 
            0.08654280907894489`\ \(c[7]\)[t] + 
            0.06682066312775997`\ \(c[8]\)[t] + 
            0.0451633585689193`\ \(c[9]\)[t] + 
            0.02256148180925487`\ \(c[10]\)[t] + 
            3.8981718325193755`*^-17\ \(c[11]\)[t] - 
            0.02158054781754788`\ \(c[12]\)[t] - 
            0.04131966847794722`\ \(c[13]\)[t] - 
            0.05846808023678991`\ \(c[14]\)[t] - 
            0.07241337086197412`\ \(c[15]\)[t] - 
            0.08269933431326874`\ \(c[16]\)[t] - 
            0.0890384386636067`\ \(c[17]\)[t] - 
            0.09131715903518159`\ \(c[18]\)[t] - 
            0.08959419377036688`\ \(c[19]\)[t] - 
            0.08409185873785081`\ \(c[20]\)[t] - 
            0.0751812130120626`\ \(c[21]\)[t] - 
            0.06336169950422753`\ \(c[22]\)[t] - 
            0.04923627809413894`\ \(c[23]\)[t] - 
            0.03348317962868157`\ \(c[24]\)[t] - 
            0.0168255118577494`\ \(c[25]\)[t] - 
            3.898171832519376`*^-17\ \(c[26]\)[t] + 
            0.016273855731265604`\ \(c[27]\)[t] + 
            0.03132297449134708`\ \(c[28]\)[t] + 
            0.04454710875183992`\ \(c[29]\)[t] + 
            0.05544148706619893`\ \(c[30]\)[t] + 
            0.06361487254866825`\ \(c[31]\)[t] + 
            0.06880242987642335`\ \(c[32]\)[t] + 
            0.07087301895267824`\ \(c[33]\)[t] + 
            0.06983076867396242`\ \(c[34]\)[t] + 
            0.06581101988179627`\ \(c[35]\)[t] + 
            0.059070953080906326`\ \(c[36]\)[t] + 
            0.049975424961080865`\ \(c[37]\)[t] + 
            0.03897872015785999`\ \(c[38]\)[t] + 
            0.026603074225527826`\ \(c[39]\)[t] + 
            0.013414935129827233`\ \(c[40]\)[t] + 
            1.5206810699945212`*^-16\ \(c[41]\)[t] - 
            0.013061910521147383`\ \(c[42]\)[t] - 
            0.025221096343682053`\ \(c[43]\)[t] - 
            0.03598035706879378`\ \(c[44]\)[t] - 
            0.04491462243337642`\ \(c[45]\)[t] - 
            0.05168708394579296`\ \(c[46]\)[t] - 
            0.05606123915856713`\ \(c[47]\)[t] - 
            0.0579084423149932`\ \(c[48]\)[t] - 
            0.05721075023890897`\ \(c[49]\)[t] - 
            0.054059052045761224`\ \(c[50]\)[t] - 
            0.04864666724309928`\ \(c[51]\)[t] - 
            0.04125878107252025`\ \(c[52]\)[t] - 
            0.03225825116512568`\ \(c[53]\)[t] - 
            0.022068459300722043`\ \(c[54]\)[t] - 
            0.011153991006822649`\ \(c[55]\)[t] - 
            3.8981718325193755`*^-17\ \(c[56]\)[t] + 
            0.010908848347331966`\ \(c[57]\)[t] + 
            0.021108961070255627`\ \(c[58]\)[t] + 
            0.030177073670601094`\ \(c[59]\)[t] + 
            0.03774739544932687`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -34, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -34]][ t]], 
          Plus[ 
            Times[ -0.13647135277833591, 
              c[ -60][ t]], 
            Times[ -0.16539866862653771, 
              c[ -59][ t]], 
            Times[ -0.18920668216016426, 
              c[ -58][ t]], 
            Times[ -0.20645618564475834, 
              c[ -57][ t]], 
            Times[ -0.21584055771952015, 
              c[ -56][ t]], 
            Times[ -0.21623620818304484, 
              c[ -55][ t]], 
            Times[ -0.20674833578317206, 
              c[ -54][ t]], 
            Times[ -0.18675027222298593, 
              c[ -53][ t]], 
            Times[ -0.15591488063143982, 
              c[ -52][ t]], 
            Times[ -0.11423673049785459, 
              c[ -51][ t]], 
            Times[ -0.062044074975450239, 
              c[ -50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ 0.070907514257657456, 
              c[ -48][ t]], 
            Times[ 0.14938649372796384, 
              c[ -47][ t]], 
            Times[ 0.23387232094715985, 
              c[ -46][ t]], 
            Times[ 0.32256865202152113, 
              c[ -45][ t]], 
            Times[ 0.41349667156634429, 
              c[ -44][ t]], 
            Times[ 0.50455115242710469, 
              c[ -43][ t]], 
            Times[ 0.59356153372868015, 
              c[ -42][ t]], 
            Times[ 0.67835603854706361, 
              c[ -41][ t]], 
            Times[ 0.75682672864065692, 
              c[ -40][ t]], 
            Times[ 0.82699334313268802, 
              c[ -39][ t]], 
            Times[ 0.88706379305918381, 
              c[ -38][ t]], 
            Times[ 0.93548928378863916, 
              c[ -37][ t]], 
            Times[ 0.9710122092317629, 
              c[ -36][ t]], 
            Times[ 0.99270519960720671, 
              c[ -35][ t]], 
            Times[ 26.353917083687325, 
              c[ -34][ t]], 
            Times[ 0.99270519960720693, 
              c[ -33][ t]], 
            Times[ 0.9710122092317629, 
              c[ -32][ t]], 
            Times[ 0.93548928378863916, 
              c[ -31][ t]], 
            Times[ 0.88706379305918392, 
              c[ -30][ t]], 
            Times[ 0.82699334313268813, 
              c[ -29][ t]], 
            Times[ 0.75682672864065692, 
              c[ -28][ t]], 
            Times[ 0.67835603854706361, 
              c[ -27][ t]], 
            Times[ 0.59356153372868059, 
              c[ -26][ t]], 
            Times[ 0.50455115242710469, 
              c[ -25][ t]], 
            Times[ 0.41349667156634429, 
              c[ -24][ t]], 
            Times[ 0.32256865202152157, 
              c[ -23][ t]], 
            Times[ 0.23387232094715985, 
              c[ -22][ t]], 
            Times[ 0.14938649372796384, 
              c[ -21][ t]], 
            Times[ 0.070907514257657775, 
              c[ -20][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -19][ t]], 
            Times[ -0.062044074975450239, 
              c[ -18][ t]], 
            Times[ -0.11423673049785436, 
              c[ -17][ t]], 
            Times[ -0.15591488063143974, 
              c[ -16][ t]], 
            Times[ -0.18675027222298593, 
              c[ -15][ t]], 
            Times[ -0.206748335783172, 
              c[ -14][ t]], 
            Times[ -0.21623620818304484, 
              c[ -13][ t]], 
            Times[ -0.21584055771952015, 
              c[ -12][ t]], 
            Times[ -0.20645618564475843, 
              c[ -11][ t]], 
            Times[ -0.18920668216016426, 
              c[ -10][ t]], 
            Times[ -0.16539866862653771, 
              c[ -9][ t]], 
            Times[ -0.13647135277833605, 
              c[ -8][ t]], 
            Times[ -0.10394325375429328, 
              c[ -7][ t]], 
            Times[ -0.06935801494512607, 
              c[ -6][ t]], 
            Times[ -0.034231213779558949, 
              c[ -5][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ 0.032022748374425904, 
              c[ -3][ t]], 
            Times[ 0.060688263076985105, 
              c[ -2][ t]], 
            Times[ 0.085044480344421608, 
              c[ -1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 0][ t]], 
            Times[ 0.11814190616181255, 
              c[ 1][ t]], 
            Times[ 0.12613778810677612, 
              c[ 2][ t]], 
            Times[ 0.12833762891430928, 
              c[ 3][ t]], 
            Times[ 0.12496032289024853, 
              c[ 4][ t]], 
            Times[ 0.11643488132933186, 
              c[ 5][ t]], 
            Times[ 0.10337416789158609, 
              c[ 6][ t]], 
            Times[ 0.086542809078944891, 
              c[ 7][ t]], 
            Times[ 0.066820663127759972, 
              c[ 8][ t]], 
            Times[ 0.045163358568919301, 
              c[ 9][ t]], 
            Times[ 0.022561481809254869, 
              c[ 10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 11][ t]], 
            Times[ -0.021580547817547879, 
              c[ 12][ t]], 
            Times[ -0.04131966847794722, 
              c[ 13][ t]], 
            Times[ -0.058468080236789913, 
              c[ 14][ t]], 
            Times[ -0.072413370861974122, 
              c[ 15][ t]], 
            Times[ -0.082699334313268744, 
              c[ 16][ t]], 
            Times[ -0.089038438663606695, 
              c[ 17][ t]], 
            Times[ -0.091317159035181589, 
              c[ 18][ t]], 
            Times[ -0.089594193770366884, 
              c[ 19][ t]], 
            Times[ -0.084091858737850814, 
              c[ 20][ t]], 
            Times[ -0.075181213012062598, 
              c[ 21][ t]], 
            Times[ -0.063361699504227528, 
              c[ 22][ t]], 
            Times[ -0.049236278094138941, 
              c[ 23][ t]], 
            Times[ -0.033483179628681567, 
              c[ 24][ t]], 
            Times[ -0.016825511857749401, 
              c[ 25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ 0.016273855731265604, 
              c[ 27][ t]], 
            Times[ 0.031322974491347078, 
              c[ 28][ t]], 
            Times[ 0.044547108751839919, 
              c[ 29][ t]], 
            Times[ 0.055441487066198933, 
              c[ 30][ t]], 
            Times[ 0.063614872548668253, 
              c[ 31][ t]], 
            Times[ 0.068802429876423349, 
              c[ 32][ t]], 
            Times[ 0.070873018952678238, 
              c[ 33][ t]], 
            Times[ 0.069830768673962415, 
              c[ 34][ t]], 
            Times[ 0.065811019881796273, 
              c[ 35][ t]], 
            Times[ 0.059070953080906326, 
              c[ 36][ t]], 
            Times[ 0.049975424961080865, 
              c[ 37][ t]], 
            Times[ 0.03897872015785999, 
              c[ 38][ t]], 
            Times[ 0.026603074225527826, 
              c[ 39][ t]], 
            Times[ 0.013414935129827233, 
              c[ 40][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 41][ t]], 
            Times[ -0.013061910521147383, 
              c[ 42][ t]], 
            Times[ -0.025221096343682053, 
              c[ 43][ t]], 
            Times[ -0.035980357068793781, 
              c[ 44][ t]], 
            Times[ -0.044914622433376419, 
              c[ 45][ t]], 
            Times[ -0.05168708394579296, 
              c[ 46][ t]], 
            Times[ -0.05606123915856713, 
              c[ 47][ t]], 
            Times[ -0.057908442314993203, 
              c[ 48][ t]], 
            Times[ -0.057210750238908967, 
              c[ 49][ t]], 
            Times[ -0.054059052045761224, 
              c[ 50][ t]], 
            Times[ -0.048646667243099281, 
              c[ 51][ t]], 
            Times[ -0.041258781072520248, 
              c[ 52][ t]], 
            Times[ -0.032258251165125679, 
              c[ 53][ t]], 
            Times[ -0.022068459300722043, 
              c[ 54][ t]], 
            Times[ -0.011153991006822649, 
              c[ 55][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 56][ t]], 
            Times[ 0.010908848347331966, 
              c[ 57][ t]], 
            Times[ 0.021108961070255627, 
              c[ 58][ t]], 
            Times[ 0.030177073670601094, 
              c[ 59][ t]], 
            Times[ 0.03774739544932687, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-33\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-33\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.10394325375429328`\)\ \(c[\(-60\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-59\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-58\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-57\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-56\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-55\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-54\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-53\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-52\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-51\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-50\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-49\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-47\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-46\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-45\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-44\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-43\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-42\)]\)[t] + 
            0.5935615337286809`\ \(c[\(-41\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-40\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-39\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-38\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-37\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-36\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-35\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-34\)]\)[t] + 
            24.884442650636245`\ \(c[\(-33\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-32\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-31\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-30\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-29\)]\)[t] + 
            0.826993343132688`\ \(c[\(-28\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-27\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-26\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-25\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-24\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-23\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-22\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-21\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-20\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-17\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-16\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-15\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-14\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-13\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-12\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-11\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-10\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-9\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-8\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-7\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-6\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-5\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-2\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-1\)]\)[t] + 
            0.0850444803444217`\ \(c[0]\)[t] + 
            0.10436044624225692`\ \(c[1]\)[t] + 
            0.11814190616181255`\ \(c[2]\)[t] + 
            0.12613778810677614`\ \(c[3]\)[t] + 
            0.12833762891430925`\ \(c[4]\)[t] + 
            0.12496032289024853`\ \(c[5]\)[t] + 
            0.11643488132933186`\ \(c[6]\)[t] + 
            0.10337416789158609`\ \(c[7]\)[t] + 
            0.08654280907894475`\ \(c[8]\)[t] + 
            0.06682066312775997`\ \(c[9]\)[t] + 
            0.0451633585689193`\ \(c[10]\)[t] + 
            0.02256148180925487`\ \(c[11]\)[t] + 
            3.8981718325193755`*^-17\ \(c[12]\)[t] - 
            0.02158054781754788`\ \(c[13]\)[t] - 
            0.04131966847794722`\ \(c[14]\)[t] - 
            0.05846808023678991`\ \(c[15]\)[t] - 
            0.07241337086197412`\ \(c[16]\)[t] - 
            0.08269933431326874`\ \(c[17]\)[t] - 
            0.0890384386636067`\ \(c[18]\)[t] - 
            0.09131715903518159`\ \(c[19]\)[t] - 
            0.08959419377036688`\ \(c[20]\)[t] - 
            0.08409185873785081`\ \(c[21]\)[t] - 
            0.0751812130120626`\ \(c[22]\)[t] - 
            0.06336169950422753`\ \(c[23]\)[t] - 
            0.04923627809413894`\ \(c[24]\)[t] - 
            0.03348317962868157`\ \(c[25]\)[t] - 
            0.0168255118577494`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.016273855731265604`\ \(c[28]\)[t] + 
            0.03132297449134708`\ \(c[29]\)[t] + 
            0.04454710875183992`\ \(c[30]\)[t] + 
            0.05544148706619893`\ \(c[31]\)[t] + 
            0.06361487254866825`\ \(c[32]\)[t] + 
            0.06880242987642335`\ \(c[33]\)[t] + 
            0.07087301895267824`\ \(c[34]\)[t] + 
            0.06983076867396242`\ \(c[35]\)[t] + 
            0.06581101988179627`\ \(c[36]\)[t] + 
            0.059070953080906326`\ \(c[37]\)[t] + 
            0.049975424961080865`\ \(c[38]\)[t] + 
            0.03897872015785999`\ \(c[39]\)[t] + 
            0.026603074225527826`\ \(c[40]\)[t] + 
            0.013414935129827233`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] - 
            0.013061910521147383`\ \(c[43]\)[t] - 
            0.025221096343682053`\ \(c[44]\)[t] - 
            0.03598035706879378`\ \(c[45]\)[t] - 
            0.04491462243337642`\ \(c[46]\)[t] - 
            0.05168708394579296`\ \(c[47]\)[t] - 
            0.056061239158567186`\ \(c[48]\)[t] - 
            0.0579084423149932`\ \(c[49]\)[t] - 
            0.05721075023890897`\ \(c[50]\)[t] - 
            0.054059052045761224`\ \(c[51]\)[t] - 
            0.04864666724309928`\ \(c[52]\)[t] - 
            0.04125878107252025`\ \(c[53]\)[t] - 
            0.03225825116512552`\ \(c[54]\)[t] - 
            0.022068459300722043`\ \(c[55]\)[t] - 
            0.011153991006822649`\ \(c[56]\)[t] - 
            3.8981718325193755`*^-17\ \(c[57]\)[t] + 
            0.010908848347331966`\ \(c[58]\)[t] + 
            0.021108961070255627`\ \(c[59]\)[t] + 
            0.030177073670601236`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -33, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -33]][ t]], 
          Plus[ 
            Times[ -0.10394325375429328, 
              c[ -60][ t]], 
            Times[ -0.13647135277833616, 
              c[ -59][ t]], 
            Times[ -0.16539866862653771, 
              c[ -58][ t]], 
            Times[ -0.18920668216016426, 
              c[ -57][ t]], 
            Times[ -0.20645618564475848, 
              c[ -56][ t]], 
            Times[ -0.21584055771952015, 
              c[ -55][ t]], 
            Times[ -0.21623620818304484, 
              c[ -54][ t]], 
            Times[ -0.20674833578317189, 
              c[ -53][ t]], 
            Times[ -0.18675027222298593, 
              c[ -52][ t]], 
            Times[ -0.15591488063143982, 
              c[ -51][ t]], 
            Times[ -0.11423673049785416, 
              c[ -50][ t]], 
            Times[ -0.062044074975450239, 
              c[ -49][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ 0.070907514257658094, 
              c[ -47][ t]], 
            Times[ 0.14938649372796384, 
              c[ -46][ t]], 
            Times[ 0.23387232094715985, 
              c[ -45][ t]], 
            Times[ 0.32256865202152191, 
              c[ -44][ t]], 
            Times[ 0.41349667156634429, 
              c[ -43][ t]], 
            Times[ 0.50455115242710469, 
              c[ -42][ t]], 
            Times[ 0.59356153372868092, 
              c[ -41][ t]], 
            Times[ 0.67835603854706361, 
              c[ -40][ t]], 
            Times[ 0.75682672864065692, 
              c[ -39][ t]], 
            Times[ 0.82699334313268813, 
              c[ -38][ t]], 
            Times[ 0.88706379305918392, 
              c[ -37][ t]], 
            Times[ 0.93548928378863916, 
              c[ -36][ t]], 
            Times[ 0.9710122092317629, 
              c[ -35][ t]], 
            Times[ 0.99270519960720693, 
              c[ -34][ t]], 
            Times[ 24.884442650636245, 
              c[ -33][ t]], 
            Times[ 0.99270519960720671, 
              c[ -32][ t]], 
            Times[ 0.9710122092317629, 
              c[ -31][ t]], 
            Times[ 0.93548928378863916, 
              c[ -30][ t]], 
            Times[ 0.88706379305918381, 
              c[ -29][ t]], 
            Times[ 0.82699334313268802, 
              c[ -28][ t]], 
            Times[ 0.75682672864065692, 
              c[ -27][ t]], 
            Times[ 0.67835603854706317, 
              c[ -26][ t]], 
            Times[ 0.59356153372868015, 
              c[ -25][ t]], 
            Times[ 0.50455115242710469, 
              c[ -24][ t]], 
            Times[ 0.41349667156634395, 
              c[ -23][ t]], 
            Times[ 0.32256865202152113, 
              c[ -22][ t]], 
            Times[ 0.23387232094715985, 
              c[ -21][ t]], 
            Times[ 0.14938649372796345, 
              c[ -20][ t]], 
            Times[ 0.070907514257657622, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.062044074975450475, 
              c[ -17][ t]], 
            Times[ -0.11423673049785445, 
              c[ -16][ t]], 
            Times[ -0.15591488063143982, 
              c[ -15][ t]], 
            Times[ -0.18675027222298607, 
              c[ -14][ t]], 
            Times[ -0.20674833578317206, 
              c[ -13][ t]], 
            Times[ -0.21623620818304484, 
              c[ -12][ t]], 
            Times[ -0.21584055771952013, 
              c[ -11][ t]], 
            Times[ -0.20645618564475834, 
              c[ -10][ t]], 
            Times[ -0.18920668216016426, 
              c[ -9][ t]], 
            Times[ -0.1653986686265376, 
              c[ -8][ t]], 
            Times[ -0.13647135277833591, 
              c[ -7][ t]], 
            Times[ -0.10394325375429328, 
              c[ -6][ t]], 
            Times[ -0.069358014945125918, 
              c[ -5][ t]], 
            Times[ -0.034231213779558949, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ 0.032022748374426029, 
              c[ -2][ t]], 
            Times[ 0.060688263076985105, 
              c[ -1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 0][ t]], 
            Times[ 0.10436044624225692, 
              c[ 1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 2][ t]], 
            Times[ 0.12613778810677614, 
              c[ 3][ t]], 
            Times[ 0.12833762891430925, 
              c[ 4][ t]], 
            Times[ 0.12496032289024853, 
              c[ 5][ t]], 
            Times[ 0.11643488132933186, 
              c[ 6][ t]], 
            Times[ 0.10337416789158609, 
              c[ 7][ t]], 
            Times[ 0.086542809078944752, 
              c[ 8][ t]], 
            Times[ 0.066820663127759972, 
              c[ 9][ t]], 
            Times[ 0.045163358568919301, 
              c[ 10][ t]], 
            Times[ 0.022561481809254869, 
              c[ 11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 12][ t]], 
            Times[ -0.021580547817547879, 
              c[ 13][ t]], 
            Times[ -0.04131966847794722, 
              c[ 14][ t]], 
            Times[ -0.058468080236789913, 
              c[ 15][ t]], 
            Times[ -0.072413370861974122, 
              c[ 16][ t]], 
            Times[ -0.082699334313268744, 
              c[ 17][ t]], 
            Times[ -0.089038438663606695, 
              c[ 18][ t]], 
            Times[ -0.091317159035181589, 
              c[ 19][ t]], 
            Times[ -0.089594193770366884, 
              c[ 20][ t]], 
            Times[ -0.084091858737850814, 
              c[ 21][ t]], 
            Times[ -0.075181213012062598, 
              c[ 22][ t]], 
            Times[ -0.063361699504227528, 
              c[ 23][ t]], 
            Times[ -0.049236278094138941, 
              c[ 24][ t]], 
            Times[ -0.033483179628681567, 
              c[ 25][ t]], 
            Times[ -0.016825511857749401, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.016273855731265604, 
              c[ 28][ t]], 
            Times[ 0.031322974491347078, 
              c[ 29][ t]], 
            Times[ 0.044547108751839919, 
              c[ 30][ t]], 
            Times[ 0.055441487066198933, 
              c[ 31][ t]], 
            Times[ 0.063614872548668253, 
              c[ 32][ t]], 
            Times[ 0.068802429876423349, 
              c[ 33][ t]], 
            Times[ 0.070873018952678238, 
              c[ 34][ t]], 
            Times[ 0.069830768673962415, 
              c[ 35][ t]], 
            Times[ 0.065811019881796273, 
              c[ 36][ t]], 
            Times[ 0.059070953080906326, 
              c[ 37][ t]], 
            Times[ 0.049975424961080865, 
              c[ 38][ t]], 
            Times[ 0.03897872015785999, 
              c[ 39][ t]], 
            Times[ 0.026603074225527826, 
              c[ 40][ t]], 
            Times[ 0.013414935129827233, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ -0.013061910521147383, 
              c[ 43][ t]], 
            Times[ -0.025221096343682053, 
              c[ 44][ t]], 
            Times[ -0.035980357068793781, 
              c[ 45][ t]], 
            Times[ -0.044914622433376419, 
              c[ 46][ t]], 
            Times[ -0.05168708394579296, 
              c[ 47][ t]], 
            Times[ -0.056061239158567186, 
              c[ 48][ t]], 
            Times[ -0.057908442314993203, 
              c[ 49][ t]], 
            Times[ -0.057210750238908967, 
              c[ 50][ t]], 
            Times[ -0.054059052045761224, 
              c[ 51][ t]], 
            Times[ -0.048646667243099281, 
              c[ 52][ t]], 
            Times[ -0.041258781072520248, 
              c[ 53][ t]], 
            Times[ -0.032258251165125519, 
              c[ 54][ t]], 
            Times[ -0.022068459300722043, 
              c[ 55][ t]], 
            Times[ -0.011153991006822649, 
              c[ 56][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ 0.010908848347331966, 
              c[ 58][ t]], 
            Times[ 0.021108961070255627, 
              c[ 59][ t]], 
            Times[ 0.030177073670601236, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-32\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-32\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.06935801494512592`\)\ \(c[\(-60\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-59\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-58\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-57\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-56\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-55\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-54\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-53\)]\)[t] - 
            0.206748335783172`\ \(c[\(-52\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-51\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-50\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-49\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-48\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-47\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-46\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-45\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-44\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-43\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-42\)]\)[t] + 
            0.504551152427105`\ \(c[\(-41\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-40\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-39\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-38\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-37\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-36\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-35\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-34\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-33\)]\)[t] + 
            23.45883312603445`\ \(c[\(-32\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-31\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-30\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-29\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-28\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-27\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-26\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-25\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-24\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-23\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-22\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-21\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-20\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-19\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-18\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-16\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-15\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-14\)]\)[t] - 
            0.186750272222986`\ \(c[\(-13\)]\)[t] - 
            0.206748335783172`\ \(c[\(-12\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-11\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-10\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-9\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-8\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-7\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-6\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-5\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-4\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-3\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-1\)]\)[t] + 
            0.060688263076985105`\ \(c[0]\)[t] + 
            0.0850444803444217`\ \(c[1]\)[t] + 
            0.10436044624225685`\ \(c[2]\)[t] + 
            0.11814190616181255`\ \(c[3]\)[t] + 
            0.12613778810677614`\ \(c[4]\)[t] + 
            0.12833762891430928`\ \(c[5]\)[t] + 
            0.12496032289024853`\ \(c[6]\)[t] + 
            0.11643488132933186`\ \(c[7]\)[t] + 
            0.10337416789158609`\ \(c[8]\)[t] + 
            0.08654280907894489`\ \(c[9]\)[t] + 
            0.06682066312775997`\ \(c[10]\)[t] + 
            0.0451633585689193`\ \(c[11]\)[t] + 
            0.02256148180925487`\ \(c[12]\)[t] + 
            3.8981718325193755`*^-17\ \(c[13]\)[t] - 
            0.02158054781754788`\ \(c[14]\)[t] - 
            0.04131966847794722`\ \(c[15]\)[t] - 
            0.05846808023678991`\ \(c[16]\)[t] - 
            0.07241337086197412`\ \(c[17]\)[t] - 
            0.08269933431326874`\ \(c[18]\)[t] - 
            0.0890384386636067`\ \(c[19]\)[t] - 
            0.09131715903518159`\ \(c[20]\)[t] - 
            0.08959419377036688`\ \(c[21]\)[t] - 
            0.08409185873785081`\ \(c[22]\)[t] - 
            0.0751812130120626`\ \(c[23]\)[t] - 
            0.06336169950422753`\ \(c[24]\)[t] - 
            0.04923627809413894`\ \(c[25]\)[t] - 
            0.03348317962868157`\ \(c[26]\)[t] - 
            0.0168255118577494`\ \(c[27]\)[t] - 
            3.898171832519376`*^-17\ \(c[28]\)[t] + 
            0.016273855731265604`\ \(c[29]\)[t] + 
            0.03132297449134708`\ \(c[30]\)[t] + 
            0.04454710875183992`\ \(c[31]\)[t] + 
            0.05544148706619893`\ \(c[32]\)[t] + 
            0.06361487254866825`\ \(c[33]\)[t] + 
            0.06880242987642335`\ \(c[34]\)[t] + 
            0.07087301895267824`\ \(c[35]\)[t] + 
            0.06983076867396242`\ \(c[36]\)[t] + 
            0.06581101988179627`\ \(c[37]\)[t] + 
            0.059070953080906326`\ \(c[38]\)[t] + 
            0.049975424961080865`\ \(c[39]\)[t] + 
            0.03897872015785999`\ \(c[40]\)[t] + 
            0.026603074225527937`\ \(c[41]\)[t] + 
            0.013414935129827233`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] - 
            0.013061910521147276`\ \(c[44]\)[t] - 
            0.025221096343682053`\ \(c[45]\)[t] - 
            0.03598035706879378`\ \(c[46]\)[t] - 
            0.04491462243337629`\ \(c[47]\)[t] - 
            0.05168708394579296`\ \(c[48]\)[t] - 
            0.056061239158567186`\ \(c[49]\)[t] - 
            0.0579084423149932`\ \(c[50]\)[t] - 
            0.05721075023890897`\ \(c[51]\)[t] - 
            0.054059052045761224`\ \(c[52]\)[t] - 
            0.0486466672430994`\ \(c[53]\)[t] - 
            0.04125878107252025`\ \(c[54]\)[t] - 
            0.03225825116512552`\ \(c[55]\)[t] - 
            0.022068459300722043`\ \(c[56]\)[t] - 
            0.011153991006822649`\ \(c[57]\)[t] - 
            3.8981718325193755`*^-17\ \(c[58]\)[t] + 
            0.010908848347331785`\ \(c[59]\)[t] + 
            0.021108961070255627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -32, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -32]][ t]], 
          Plus[ 
            Times[ -0.069358014945125918, 
              c[ -60][ t]], 
            Times[ -0.1039432537542934, 
              c[ -59][ t]], 
            Times[ -0.13647135277833605, 
              c[ -58][ t]], 
            Times[ -0.1653986686265376, 
              c[ -57][ t]], 
            Times[ -0.18920668216016434, 
              c[ -56][ t]], 
            Times[ -0.20645618564475843, 
              c[ -55][ t]], 
            Times[ -0.21584055771952013, 
              c[ -54][ t]], 
            Times[ -0.21623620818304481, 
              c[ -53][ t]], 
            Times[ -0.206748335783172, 
              c[ -52][ t]], 
            Times[ -0.18675027222298607, 
              c[ -51][ t]], 
            Times[ -0.15591488063143966, 
              c[ -50][ t]], 
            Times[ -0.11423673049785436, 
              c[ -49][ t]], 
            Times[ -0.062044074975450475, 
              c[ -48][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -47][ t]], 
            Times[ 0.070907514257657775, 
              c[ -46][ t]], 
            Times[ 0.14938649372796345, 
              c[ -45][ t]], 
            Times[ 0.23387232094716018, 
              c[ -44][ t]], 
            Times[ 0.32256865202152157, 
              c[ -43][ t]], 
            Times[ 0.41349667156634395, 
              c[ -42][ t]], 
            Times[ 0.50455115242710502, 
              c[ -41][ t]], 
            Times[ 0.59356153372868059, 
              c[ -40][ t]], 
            Times[ 0.67835603854706317, 
              c[ -39][ t]], 
            Times[ 0.75682672864065692, 
              c[ -38][ t]], 
            Times[ 0.82699334313268813, 
              c[ -37][ t]], 
            Times[ 0.88706379305918381, 
              c[ -36][ t]], 
            Times[ 0.93548928378863916, 
              c[ -35][ t]], 
            Times[ 0.9710122092317629, 
              c[ -34][ t]], 
            Times[ 0.99270519960720671, 
              c[ -33][ t]], 
            Times[ 23.458833126034449, 
              c[ -32][ t]], 
            Times[ 0.99270519960720671, 
              c[ -31][ t]], 
            Times[ 0.9710122092317629, 
              c[ -30][ t]], 
            Times[ 0.93548928378863916, 
              c[ -29][ t]], 
            Times[ 0.88706379305918381, 
              c[ -28][ t]], 
            Times[ 0.82699334313268813, 
              c[ -27][ t]], 
            Times[ 0.75682672864065692, 
              c[ -26][ t]], 
            Times[ 0.67835603854706317, 
              c[ -25][ t]], 
            Times[ 0.59356153372868059, 
              c[ -24][ t]], 
            Times[ 0.50455115242710469, 
              c[ -23][ t]], 
            Times[ 0.41349667156634395, 
              c[ -22][ t]], 
            Times[ 0.32256865202152157, 
              c[ -21][ t]], 
            Times[ 0.23387232094715985, 
              c[ -20][ t]], 
            Times[ 0.14938649372796362, 
              c[ -19][ t]], 
            Times[ 0.070907514257657775, 
              c[ -18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.062044074975450343, 
              c[ -16][ t]], 
            Times[ -0.11423673049785436, 
              c[ -15][ t]], 
            Times[ -0.15591488063143982, 
              c[ -14][ t]], 
            Times[ -0.18675027222298601, 
              c[ -13][ t]], 
            Times[ -0.206748335783172, 
              c[ -12][ t]], 
            Times[ -0.21623620818304484, 
              c[ -11][ t]], 
            Times[ -0.21584055771952015, 
              c[ -10][ t]], 
            Times[ -0.20645618564475843, 
              c[ -9][ t]], 
            Times[ -0.18920668216016426, 
              c[ -8][ t]], 
            Times[ -0.16539866862653771, 
              c[ -7][ t]], 
            Times[ -0.13647135277833605, 
              c[ -6][ t]], 
            Times[ -0.10394325375429328, 
              c[ -5][ t]], 
            Times[ -0.06935801494512607, 
              c[ -4][ t]], 
            Times[ -0.034231213779558949, 
              c[ -3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ 0.032022748374425904, 
              c[ -1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 0][ t]], 
            Times[ 0.085044480344421705, 
              c[ 1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 2][ t]], 
            Times[ 0.11814190616181255, 
              c[ 3][ t]], 
            Times[ 0.12613778810677614, 
              c[ 4][ t]], 
            Times[ 0.12833762891430928, 
              c[ 5][ t]], 
            Times[ 0.12496032289024853, 
              c[ 6][ t]], 
            Times[ 0.11643488132933186, 
              c[ 7][ t]], 
            Times[ 0.10337416789158609, 
              c[ 8][ t]], 
            Times[ 0.086542809078944891, 
              c[ 9][ t]], 
            Times[ 0.066820663127759972, 
              c[ 10][ t]], 
            Times[ 0.045163358568919301, 
              c[ 11][ t]], 
            Times[ 0.022561481809254869, 
              c[ 12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 13][ t]], 
            Times[ -0.021580547817547879, 
              c[ 14][ t]], 
            Times[ -0.04131966847794722, 
              c[ 15][ t]], 
            Times[ -0.058468080236789913, 
              c[ 16][ t]], 
            Times[ -0.072413370861974122, 
              c[ 17][ t]], 
            Times[ -0.082699334313268744, 
              c[ 18][ t]], 
            Times[ -0.089038438663606695, 
              c[ 19][ t]], 
            Times[ -0.091317159035181589, 
              c[ 20][ t]], 
            Times[ -0.089594193770366884, 
              c[ 21][ t]], 
            Times[ -0.084091858737850814, 
              c[ 22][ t]], 
            Times[ -0.075181213012062598, 
              c[ 23][ t]], 
            Times[ -0.063361699504227528, 
              c[ 24][ t]], 
            Times[ -0.049236278094138941, 
              c[ 25][ t]], 
            Times[ -0.033483179628681567, 
              c[ 26][ t]], 
            Times[ -0.016825511857749401, 
              c[ 27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ 0.016273855731265604, 
              c[ 29][ t]], 
            Times[ 0.031322974491347078, 
              c[ 30][ t]], 
            Times[ 0.044547108751839919, 
              c[ 31][ t]], 
            Times[ 0.055441487066198933, 
              c[ 32][ t]], 
            Times[ 0.063614872548668253, 
              c[ 33][ t]], 
            Times[ 0.068802429876423349, 
              c[ 34][ t]], 
            Times[ 0.070873018952678238, 
              c[ 35][ t]], 
            Times[ 0.069830768673962415, 
              c[ 36][ t]], 
            Times[ 0.065811019881796273, 
              c[ 37][ t]], 
            Times[ 0.059070953080906326, 
              c[ 38][ t]], 
            Times[ 0.049975424961080865, 
              c[ 39][ t]], 
            Times[ 0.03897872015785999, 
              c[ 40][ t]], 
            Times[ 0.026603074225527937, 
              c[ 41][ t]], 
            Times[ 0.013414935129827233, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ -0.013061910521147276, 
              c[ 44][ t]], 
            Times[ -0.025221096343682053, 
              c[ 45][ t]], 
            Times[ -0.035980357068793781, 
              c[ 46][ t]], 
            Times[ -0.044914622433376288, 
              c[ 47][ t]], 
            Times[ -0.05168708394579296, 
              c[ 48][ t]], 
            Times[ -0.056061239158567186, 
              c[ 49][ t]], 
            Times[ -0.057908442314993203, 
              c[ 50][ t]], 
            Times[ -0.057210750238908967, 
              c[ 51][ t]], 
            Times[ -0.054059052045761224, 
              c[ 52][ t]], 
            Times[ -0.048646667243099399, 
              c[ 53][ t]], 
            Times[ -0.041258781072520248, 
              c[ 54][ t]], 
            Times[ -0.032258251165125519, 
              c[ 55][ t]], 
            Times[ -0.022068459300722043, 
              c[ 56][ t]], 
            Times[ -0.011153991006822649, 
              c[ 57][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 58][ t]], 
            Times[ 0.010908848347331785, 
              c[ 59][ t]], 
            Times[ 0.021108961070255627, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-31\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-31\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.034231213779558796`\)\ \(c[\(-60\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-59\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-58\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-57\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-56\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-55\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-54\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-53\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-52\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-51\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-50\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-49\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-48\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-47\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-45\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-44\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-43\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-42\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-41\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-40\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-39\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-38\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-37\)]\)[t] + 
            0.826993343132688`\ \(c[\(-36\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-35\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-34\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-33\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-32\)]\)[t] + 
            22.077088509881936`\ \(c[\(-31\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-30\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-29\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-28\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-27\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-26\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-25\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-24\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-23\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-22\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-21\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-20\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-19\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-18\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-17\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-16\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-15\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-14\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-13\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-12\)]\)[t] - 
            0.206748335783172`\ \(c[\(-11\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-10\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-9\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-8\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-7\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-6\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-5\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-4\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-3\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-2\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] + 
            0.032022748374425904`\ \(c[0]\)[t] + 
            0.060688263076985105`\ \(c[1]\)[t] + 
            0.08504448034442161`\ \(c[2]\)[t] + 
            0.10436044624225685`\ \(c[3]\)[t] + 
            0.11814190616181255`\ \(c[4]\)[t] + 
            0.12613778810677612`\ \(c[5]\)[t] + 
            0.12833762891430928`\ \(c[6]\)[t] + 
            0.12496032289024853`\ \(c[7]\)[t] + 
            0.11643488132933186`\ \(c[8]\)[t] + 
            0.10337416789158609`\ \(c[9]\)[t] + 
            0.08654280907894489`\ \(c[10]\)[t] + 
            0.06682066312775997`\ \(c[11]\)[t] + 
            0.0451633585689193`\ \(c[12]\)[t] + 
            0.02256148180925487`\ \(c[13]\)[t] + 
            3.8981718325193755`*^-17\ \(c[14]\)[t] - 
            0.02158054781754788`\ \(c[15]\)[t] - 
            0.04131966847794722`\ \(c[16]\)[t] - 
            0.05846808023678991`\ \(c[17]\)[t] - 
            0.07241337086197412`\ \(c[18]\)[t] - 
            0.08269933431326874`\ \(c[19]\)[t] - 
            0.0890384386636067`\ \(c[20]\)[t] - 
            0.09131715903518159`\ \(c[21]\)[t] - 
            0.08959419377036688`\ \(c[22]\)[t] - 
            0.08409185873785081`\ \(c[23]\)[t] - 
            0.0751812130120626`\ \(c[24]\)[t] - 
            0.06336169950422753`\ \(c[25]\)[t] - 
            0.04923627809413894`\ \(c[26]\)[t] - 
            0.03348317962868157`\ \(c[27]\)[t] - 
            0.0168255118577494`\ \(c[28]\)[t] - 
            3.898171832519376`*^-17\ \(c[29]\)[t] + 
            0.016273855731265604`\ \(c[30]\)[t] + 
            0.03132297449134708`\ \(c[31]\)[t] + 
            0.04454710875183992`\ \(c[32]\)[t] + 
            0.05544148706619893`\ \(c[33]\)[t] + 
            0.06361487254866825`\ \(c[34]\)[t] + 
            0.06880242987642335`\ \(c[35]\)[t] + 
            0.07087301895267824`\ \(c[36]\)[t] + 
            0.06983076867396242`\ \(c[37]\)[t] + 
            0.06581101988179627`\ \(c[38]\)[t] + 
            0.059070953080906326`\ \(c[39]\)[t] + 
            0.049975424961080865`\ \(c[40]\)[t] + 
            0.03897872015786009`\ \(c[41]\)[t] + 
            0.026603074225527826`\ \(c[42]\)[t] + 
            0.013414935129827233`\ \(c[43]\)[t] + 
            1.5206810699945212`*^-16\ \(c[44]\)[t] - 
            0.013061910521147383`\ \(c[45]\)[t] - 
            0.025221096343682053`\ \(c[46]\)[t] - 
            0.03598035706879378`\ \(c[47]\)[t] - 
            0.04491462243337642`\ \(c[48]\)[t] - 
            0.05168708394579296`\ \(c[49]\)[t] - 
            0.05606123915856713`\ \(c[50]\)[t] - 
            0.0579084423149932`\ \(c[51]\)[t] - 
            0.05721075023890897`\ \(c[52]\)[t] - 
            0.054059052045761224`\ \(c[53]\)[t] - 
            0.04864666724309928`\ \(c[54]\)[t] - 
            0.04125878107252025`\ \(c[55]\)[t] - 
            0.03225825116512568`\ \(c[56]\)[t] - 
            0.022068459300722043`\ \(c[57]\)[t] - 
            0.011153991006822649`\ \(c[58]\)[t] - 
            3.8981718325193755`*^-17\ \(c[59]\)[t] + 
            0.010908848347331966`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -31, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -31]][ t]], 
          Plus[ 
            Times[ -0.034231213779558796, 
              c[ -60][ t]], 
            Times[ -0.06935801494512607, 
              c[ -59][ t]], 
            Times[ -0.10394325375429328, 
              c[ -58][ t]], 
            Times[ -0.13647135277833591, 
              c[ -57][ t]], 
            Times[ -0.16539866862653771, 
              c[ -56][ t]], 
            Times[ -0.18920668216016426, 
              c[ -55][ t]], 
            Times[ -0.20645618564475834, 
              c[ -54][ t]], 
            Times[ -0.21584055771952015, 
              c[ -53][ t]], 
            Times[ -0.21623620818304484, 
              c[ -52][ t]], 
            Times[ -0.20674833578317206, 
              c[ -51][ t]], 
            Times[ -0.18675027222298593, 
              c[ -50][ t]], 
            Times[ -0.15591488063143982, 
              c[ -49][ t]], 
            Times[ -0.11423673049785459, 
              c[ -48][ t]], 
            Times[ -0.062044074975450239, 
              c[ -47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ 0.070907514257657456, 
              c[ -45][ t]], 
            Times[ 0.14938649372796384, 
              c[ -44][ t]], 
            Times[ 0.23387232094715985, 
              c[ -43][ t]], 
            Times[ 0.32256865202152113, 
              c[ -42][ t]], 
            Times[ 0.41349667156634429, 
              c[ -41][ t]], 
            Times[ 0.50455115242710469, 
              c[ -40][ t]], 
            Times[ 0.59356153372868015, 
              c[ -39][ t]], 
            Times[ 0.67835603854706317, 
              c[ -38][ t]], 
            Times[ 0.75682672864065692, 
              c[ -37][ t]], 
            Times[ 0.82699334313268802, 
              c[ -36][ t]], 
            Times[ 0.88706379305918381, 
              c[ -35][ t]], 
            Times[ 0.93548928378863916, 
              c[ -34][ t]], 
            Times[ 0.9710122092317629, 
              c[ -33][ t]], 
            Times[ 0.99270519960720671, 
              c[ -32][ t]], 
            Times[ 22.077088509881936, 
              c[ -31][ t]], 
            Times[ 0.99270519960720693, 
              c[ -30][ t]], 
            Times[ 0.9710122092317629, 
              c[ -29][ t]], 
            Times[ 0.93548928378863916, 
              c[ -28][ t]], 
            Times[ 0.88706379305918392, 
              c[ -27][ t]], 
            Times[ 0.82699334313268813, 
              c[ -26][ t]], 
            Times[ 0.75682672864065692, 
              c[ -25][ t]], 
            Times[ 0.67835603854706361, 
              c[ -24][ t]], 
            Times[ 0.59356153372868059, 
              c[ -23][ t]], 
            Times[ 0.50455115242710469, 
              c[ -22][ t]], 
            Times[ 0.41349667156634429, 
              c[ -21][ t]], 
            Times[ 0.32256865202152157, 
              c[ -20][ t]], 
            Times[ 0.23387232094715998, 
              c[ -19][ t]], 
            Times[ 0.14938649372796384, 
              c[ -18][ t]], 
            Times[ 0.070907514257657775, 
              c[ -17][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -16][ t]], 
            Times[ -0.062044074975450239, 
              c[ -15][ t]], 
            Times[ -0.11423673049785436, 
              c[ -14][ t]], 
            Times[ -0.15591488063143974, 
              c[ -13][ t]], 
            Times[ -0.18675027222298593, 
              c[ -12][ t]], 
            Times[ -0.206748335783172, 
              c[ -11][ t]], 
            Times[ -0.21623620818304484, 
              c[ -10][ t]], 
            Times[ -0.21584055771952015, 
              c[ -9][ t]], 
            Times[ -0.20645618564475843, 
              c[ -8][ t]], 
            Times[ -0.18920668216016426, 
              c[ -7][ t]], 
            Times[ -0.16539866862653771, 
              c[ -6][ t]], 
            Times[ -0.13647135277833605, 
              c[ -5][ t]], 
            Times[ -0.1039432537542934, 
              c[ -4][ t]], 
            Times[ -0.06935801494512607, 
              c[ -3][ t]], 
            Times[ -0.034231213779558949, 
              c[ -2][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 0][ t]], 
            Times[ 0.060688263076985105, 
              c[ 1][ t]], 
            Times[ 0.085044480344421608, 
              c[ 2][ t]], 
            Times[ 0.10436044624225685, 
              c[ 3][ t]], 
            Times[ 0.11814190616181255, 
              c[ 4][ t]], 
            Times[ 0.12613778810677612, 
              c[ 5][ t]], 
            Times[ 0.12833762891430928, 
              c[ 6][ t]], 
            Times[ 0.12496032289024853, 
              c[ 7][ t]], 
            Times[ 0.11643488132933186, 
              c[ 8][ t]], 
            Times[ 0.10337416789158609, 
              c[ 9][ t]], 
            Times[ 0.086542809078944891, 
              c[ 10][ t]], 
            Times[ 0.066820663127759972, 
              c[ 11][ t]], 
            Times[ 0.045163358568919301, 
              c[ 12][ t]], 
            Times[ 0.022561481809254869, 
              c[ 13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 14][ t]], 
            Times[ -0.021580547817547879, 
              c[ 15][ t]], 
            Times[ -0.04131966847794722, 
              c[ 16][ t]], 
            Times[ -0.058468080236789913, 
              c[ 17][ t]], 
            Times[ -0.072413370861974122, 
              c[ 18][ t]], 
            Times[ -0.082699334313268744, 
              c[ 19][ t]], 
            Times[ -0.089038438663606695, 
              c[ 20][ t]], 
            Times[ -0.091317159035181589, 
              c[ 21][ t]], 
            Times[ -0.089594193770366884, 
              c[ 22][ t]], 
            Times[ -0.084091858737850814, 
              c[ 23][ t]], 
            Times[ -0.075181213012062598, 
              c[ 24][ t]], 
            Times[ -0.063361699504227528, 
              c[ 25][ t]], 
            Times[ -0.049236278094138941, 
              c[ 26][ t]], 
            Times[ -0.033483179628681567, 
              c[ 27][ t]], 
            Times[ -0.016825511857749401, 
              c[ 28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ 0.016273855731265604, 
              c[ 30][ t]], 
            Times[ 0.031322974491347078, 
              c[ 31][ t]], 
            Times[ 0.044547108751839919, 
              c[ 32][ t]], 
            Times[ 0.055441487066198933, 
              c[ 33][ t]], 
            Times[ 0.063614872548668253, 
              c[ 34][ t]], 
            Times[ 0.068802429876423349, 
              c[ 35][ t]], 
            Times[ 0.070873018952678238, 
              c[ 36][ t]], 
            Times[ 0.069830768673962415, 
              c[ 37][ t]], 
            Times[ 0.065811019881796273, 
              c[ 38][ t]], 
            Times[ 0.059070953080906326, 
              c[ 39][ t]], 
            Times[ 0.049975424961080865, 
              c[ 40][ t]], 
            Times[ 0.038978720157860088, 
              c[ 41][ t]], 
            Times[ 0.026603074225527826, 
              c[ 42][ t]], 
            Times[ 0.013414935129827233, 
              c[ 43][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 44][ t]], 
            Times[ -0.013061910521147383, 
              c[ 45][ t]], 
            Times[ -0.025221096343682053, 
              c[ 46][ t]], 
            Times[ -0.035980357068793781, 
              c[ 47][ t]], 
            Times[ -0.044914622433376419, 
              c[ 48][ t]], 
            Times[ -0.05168708394579296, 
              c[ 49][ t]], 
            Times[ -0.05606123915856713, 
              c[ 50][ t]], 
            Times[ -0.057908442314993203, 
              c[ 51][ t]], 
            Times[ -0.057210750238908967, 
              c[ 52][ t]], 
            Times[ -0.054059052045761224, 
              c[ 53][ t]], 
            Times[ -0.048646667243099281, 
              c[ 54][ t]], 
            Times[ -0.041258781072520248, 
              c[ 55][ t]], 
            Times[ -0.032258251165125679, 
              c[ 56][ t]], 
            Times[ -0.022068459300722043, 
              c[ 57][ t]], 
            Times[ -0.011153991006822649, 
              c[ 58][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 59][ t]], 
            Times[ 0.010908848347331966, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-30\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-30\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-59\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-58\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-57\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-56\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-55\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-54\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-53\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-52\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-51\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-50\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-49\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-48\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-47\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-44\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-43\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-42\)]\)[t] + 
            0.3225686520215219`\ \(c[\(-41\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-40\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-39\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-38\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-37\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-36\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-35\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-34\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-33\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-32\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-31\)]\)[t] + 
            20.739208802178716`\ \(c[\(-30\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-29\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-28\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-27\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-26\)]\)[t] + 
            0.826993343132688`\ \(c[\(-25\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-24\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-23\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-22\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-21\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-20\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-19\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-18\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-17\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-14\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-13\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-12\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-11\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-10\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-9\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-8\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-7\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-6\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-5\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-4\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-3\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-2\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.03202274837442603`\ \(c[1]\)[t] + 
            0.060688263076985105`\ \(c[2]\)[t] + 
            0.0850444803444217`\ \(c[3]\)[t] + 
            0.10436044624225692`\ \(c[4]\)[t] + 
            0.11814190616181255`\ \(c[5]\)[t] + 
            0.12613778810677614`\ \(c[6]\)[t] + 
            0.12833762891430928`\ \(c[7]\)[t] + 
            0.12496032289024853`\ \(c[8]\)[t] + 
            0.11643488132933186`\ \(c[9]\)[t] + 
            0.10337416789158609`\ \(c[10]\)[t] + 
            0.08654280907894489`\ \(c[11]\)[t] + 
            0.06682066312775997`\ \(c[12]\)[t] + 
            0.0451633585689193`\ \(c[13]\)[t] + 
            0.02256148180925487`\ \(c[14]\)[t] + 
            3.8981718325193755`*^-17\ \(c[15]\)[t] - 
            0.02158054781754788`\ \(c[16]\)[t] - 
            0.04131966847794722`\ \(c[17]\)[t] - 
            0.05846808023678991`\ \(c[18]\)[t] - 
            0.07241337086197412`\ \(c[19]\)[t] - 
            0.08269933431326874`\ \(c[20]\)[t] - 
            0.0890384386636067`\ \(c[21]\)[t] - 
            0.09131715903518159`\ \(c[22]\)[t] - 
            0.08959419377036688`\ \(c[23]\)[t] - 
            0.08409185873785081`\ \(c[24]\)[t] - 
            0.0751812130120626`\ \(c[25]\)[t] - 
            0.06336169950422753`\ \(c[26]\)[t] - 
            0.04923627809413894`\ \(c[27]\)[t] - 
            0.03348317962868157`\ \(c[28]\)[t] - 
            0.0168255118577494`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.016273855731265604`\ \(c[31]\)[t] + 
            0.03132297449134708`\ \(c[32]\)[t] + 
            0.04454710875183992`\ \(c[33]\)[t] + 
            0.05544148706619893`\ \(c[34]\)[t] + 
            0.06361487254866825`\ \(c[35]\)[t] + 
            0.06880242987642335`\ \(c[36]\)[t] + 
            0.07087301895267824`\ \(c[37]\)[t] + 
            0.06983076867396242`\ \(c[38]\)[t] + 
            0.06581101988179627`\ \(c[39]\)[t] + 
            0.059070953080906326`\ \(c[40]\)[t] + 
            0.049975424961080865`\ \(c[41]\)[t] + 
            0.03897872015785999`\ \(c[42]\)[t] + 
            0.026603074225527826`\ \(c[43]\)[t] + 
            0.013414935129827233`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] - 
            0.013061910521147383`\ \(c[46]\)[t] - 
            0.025221096343682053`\ \(c[47]\)[t] - 
            0.03598035706879378`\ \(c[48]\)[t] - 
            0.04491462243337642`\ \(c[49]\)[t] - 
            0.05168708394579296`\ \(c[50]\)[t] - 
            0.056061239158567186`\ \(c[51]\)[t] - 
            0.0579084423149932`\ \(c[52]\)[t] - 
            0.05721075023890897`\ \(c[53]\)[t] - 
            0.054059052045761224`\ \(c[54]\)[t] - 
            0.04864666724309928`\ \(c[55]\)[t] - 
            0.04125878107252025`\ \(c[56]\)[t] - 
            0.03225825116512552`\ \(c[57]\)[t] - 
            0.022068459300722043`\ \(c[58]\)[t] - 
            0.011153991006822649`\ \(c[59]\)[t] - 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -30, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -30]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.034231213779559094, 
              c[ -59][ t]], 
            Times[ -0.06935801494512607, 
              c[ -58][ t]], 
            Times[ -0.10394325375429328, 
              c[ -57][ t]], 
            Times[ -0.13647135277833616, 
              c[ -56][ t]], 
            Times[ -0.16539866862653771, 
              c[ -55][ t]], 
            Times[ -0.18920668216016426, 
              c[ -54][ t]], 
            Times[ -0.20645618564475848, 
              c[ -53][ t]], 
            Times[ -0.21584055771952015, 
              c[ -52][ t]], 
            Times[ -0.21623620818304484, 
              c[ -51][ t]], 
            Times[ -0.20674833578317189, 
              c[ -50][ t]], 
            Times[ -0.18675027222298593, 
              c[ -49][ t]], 
            Times[ -0.15591488063143982, 
              c[ -48][ t]], 
            Times[ -0.11423673049785416, 
              c[ -47][ t]], 
            Times[ -0.062044074975450239, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ 0.070907514257658094, 
              c[ -44][ t]], 
            Times[ 0.14938649372796384, 
              c[ -43][ t]], 
            Times[ 0.23387232094715985, 
              c[ -42][ t]], 
            Times[ 0.32256865202152191, 
              c[ -41][ t]], 
            Times[ 0.41349667156634429, 
              c[ -40][ t]], 
            Times[ 0.50455115242710469, 
              c[ -39][ t]], 
            Times[ 0.59356153372868059, 
              c[ -38][ t]], 
            Times[ 0.67835603854706361, 
              c[ -37][ t]], 
            Times[ 0.75682672864065692, 
              c[ -36][ t]], 
            Times[ 0.82699334313268813, 
              c[ -35][ t]], 
            Times[ 0.88706379305918392, 
              c[ -34][ t]], 
            Times[ 0.93548928378863916, 
              c[ -33][ t]], 
            Times[ 0.9710122092317629, 
              c[ -32][ t]], 
            Times[ 0.99270519960720693, 
              c[ -31][ t]], 
            Times[ 20.739208802178716, 
              c[ -30][ t]], 
            Times[ 0.99270519960720671, 
              c[ -29][ t]], 
            Times[ 0.9710122092317629, 
              c[ -28][ t]], 
            Times[ 0.93548928378863916, 
              c[ -27][ t]], 
            Times[ 0.88706379305918381, 
              c[ -26][ t]], 
            Times[ 0.82699334313268802, 
              c[ -25][ t]], 
            Times[ 0.75682672864065692, 
              c[ -24][ t]], 
            Times[ 0.67835603854706317, 
              c[ -23][ t]], 
            Times[ 0.59356153372868015, 
              c[ -22][ t]], 
            Times[ 0.50455115242710469, 
              c[ -21][ t]], 
            Times[ 0.41349667156634395, 
              c[ -20][ t]], 
            Times[ 0.32256865202152135, 
              c[ -19][ t]], 
            Times[ 0.23387232094715985, 
              c[ -18][ t]], 
            Times[ 0.14938649372796345, 
              c[ -17][ t]], 
            Times[ 0.070907514257657622, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.062044074975450475, 
              c[ -14][ t]], 
            Times[ -0.11423673049785445, 
              c[ -13][ t]], 
            Times[ -0.15591488063143982, 
              c[ -12][ t]], 
            Times[ -0.18675027222298607, 
              c[ -11][ t]], 
            Times[ -0.20674833578317206, 
              c[ -10][ t]], 
            Times[ -0.21623620818304484, 
              c[ -9][ t]], 
            Times[ -0.21584055771952013, 
              c[ -8][ t]], 
            Times[ -0.20645618564475834, 
              c[ -7][ t]], 
            Times[ -0.18920668216016426, 
              c[ -6][ t]], 
            Times[ -0.1653986686265376, 
              c[ -5][ t]], 
            Times[ -0.13647135277833605, 
              c[ -4][ t]], 
            Times[ -0.10394325375429328, 
              c[ -3][ t]], 
            Times[ -0.069358014945125918, 
              c[ -2][ t]], 
            Times[ -0.034231213779558949, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.032022748374426029, 
              c[ 1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 2][ t]], 
            Times[ 0.085044480344421705, 
              c[ 3][ t]], 
            Times[ 0.10436044624225692, 
              c[ 4][ t]], 
            Times[ 0.11814190616181255, 
              c[ 5][ t]], 
            Times[ 0.12613778810677614, 
              c[ 6][ t]], 
            Times[ 0.12833762891430928, 
              c[ 7][ t]], 
            Times[ 0.12496032289024853, 
              c[ 8][ t]], 
            Times[ 0.11643488132933186, 
              c[ 9][ t]], 
            Times[ 0.10337416789158609, 
              c[ 10][ t]], 
            Times[ 0.086542809078944891, 
              c[ 11][ t]], 
            Times[ 0.066820663127759972, 
              c[ 12][ t]], 
            Times[ 0.045163358568919301, 
              c[ 13][ t]], 
            Times[ 0.022561481809254869, 
              c[ 14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 15][ t]], 
            Times[ -0.021580547817547879, 
              c[ 16][ t]], 
            Times[ -0.04131966847794722, 
              c[ 17][ t]], 
            Times[ -0.058468080236789913, 
              c[ 18][ t]], 
            Times[ -0.072413370861974122, 
              c[ 19][ t]], 
            Times[ -0.082699334313268744, 
              c[ 20][ t]], 
            Times[ -0.089038438663606695, 
              c[ 21][ t]], 
            Times[ -0.091317159035181589, 
              c[ 22][ t]], 
            Times[ -0.089594193770366884, 
              c[ 23][ t]], 
            Times[ -0.084091858737850814, 
              c[ 24][ t]], 
            Times[ -0.075181213012062598, 
              c[ 25][ t]], 
            Times[ -0.063361699504227528, 
              c[ 26][ t]], 
            Times[ -0.049236278094138941, 
              c[ 27][ t]], 
            Times[ -0.033483179628681567, 
              c[ 28][ t]], 
            Times[ -0.016825511857749401, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.016273855731265604, 
              c[ 31][ t]], 
            Times[ 0.031322974491347078, 
              c[ 32][ t]], 
            Times[ 0.044547108751839919, 
              c[ 33][ t]], 
            Times[ 0.055441487066198933, 
              c[ 34][ t]], 
            Times[ 0.063614872548668253, 
              c[ 35][ t]], 
            Times[ 0.068802429876423349, 
              c[ 36][ t]], 
            Times[ 0.070873018952678238, 
              c[ 37][ t]], 
            Times[ 0.069830768673962415, 
              c[ 38][ t]], 
            Times[ 0.065811019881796273, 
              c[ 39][ t]], 
            Times[ 0.059070953080906326, 
              c[ 40][ t]], 
            Times[ 0.049975424961080865, 
              c[ 41][ t]], 
            Times[ 0.03897872015785999, 
              c[ 42][ t]], 
            Times[ 0.026603074225527826, 
              c[ 43][ t]], 
            Times[ 0.013414935129827233, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ -0.013061910521147383, 
              c[ 46][ t]], 
            Times[ -0.025221096343682053, 
              c[ 47][ t]], 
            Times[ -0.035980357068793781, 
              c[ 48][ t]], 
            Times[ -0.044914622433376419, 
              c[ 49][ t]], 
            Times[ -0.05168708394579296, 
              c[ 50][ t]], 
            Times[ -0.056061239158567186, 
              c[ 51][ t]], 
            Times[ -0.057908442314993203, 
              c[ 52][ t]], 
            Times[ -0.057210750238908967, 
              c[ 53][ t]], 
            Times[ -0.054059052045761224, 
              c[ 54][ t]], 
            Times[ -0.048646667243099281, 
              c[ 55][ t]], 
            Times[ -0.041258781072520248, 
              c[ 56][ t]], 
            Times[ -0.032258251165125519, 
              c[ 57][ t]], 
            Times[ -0.022068459300722043, 
              c[ 58][ t]], 
            Times[ -0.011153991006822649, 
              c[ 59][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-29\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-29\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03202274837442603`\ \(c[\(-60\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-59\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-58\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-57\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-56\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-55\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-54\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-53\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-52\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-51\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-50\)]\)[t] - 
            0.206748335783172`\ \(c[\(-49\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-48\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-47\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-46\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-45\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-44\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-43\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-42\)]\)[t] + 
            0.23387232094716018`\ \(c[\(-41\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-40\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-39\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-38\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-37\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-36\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-35\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-34\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-33\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-32\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-31\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-30\)]\)[t] + 
            19.445194002924776`\ \(c[\(-29\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-28\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-27\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-26\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-25\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-24\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-23\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-22\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-21\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-20\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-19\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-18\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-17\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-16\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-15\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-13\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-12\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-11\)]\)[t] - 
            0.186750272222986`\ \(c[\(-10\)]\)[t] - 
            0.206748335783172`\ \(c[\(-9\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-8\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-7\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-6\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-5\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-4\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-3\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-2\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-1\)]\)[t] - 
            0.03423121377955895`\ \(c[0]\)[t] - 
            3.898171832519376`*^-17\ \(c[1]\)[t] + 
            0.032022748374425904`\ \(c[2]\)[t] + 
            0.060688263076985105`\ \(c[3]\)[t] + 
            0.0850444803444217`\ \(c[4]\)[t] + 
            0.10436044624225685`\ \(c[5]\)[t] + 
            0.11814190616181255`\ \(c[6]\)[t] + 
            0.12613778810677614`\ \(c[7]\)[t] + 
            0.12833762891430928`\ \(c[8]\)[t] + 
            0.12496032289024853`\ \(c[9]\)[t] + 
            0.11643488132933186`\ \(c[10]\)[t] + 
            0.10337416789158609`\ \(c[11]\)[t] + 
            0.08654280907894489`\ \(c[12]\)[t] + 
            0.06682066312775997`\ \(c[13]\)[t] + 
            0.0451633585689193`\ \(c[14]\)[t] + 
            0.02256148180925487`\ \(c[15]\)[t] + 
            3.8981718325193755`*^-17\ \(c[16]\)[t] - 
            0.02158054781754788`\ \(c[17]\)[t] - 
            0.04131966847794722`\ \(c[18]\)[t] - 
            0.05846808023678991`\ \(c[19]\)[t] - 
            0.07241337086197412`\ \(c[20]\)[t] - 
            0.08269933431326874`\ \(c[21]\)[t] - 
            0.0890384386636067`\ \(c[22]\)[t] - 
            0.09131715903518159`\ \(c[23]\)[t] - 
            0.08959419377036688`\ \(c[24]\)[t] - 
            0.08409185873785081`\ \(c[25]\)[t] - 
            0.0751812130120626`\ \(c[26]\)[t] - 
            0.06336169950422753`\ \(c[27]\)[t] - 
            0.04923627809413894`\ \(c[28]\)[t] - 
            0.03348317962868157`\ \(c[29]\)[t] - 
            0.0168255118577494`\ \(c[30]\)[t] - 
            3.898171832519376`*^-17\ \(c[31]\)[t] + 
            0.016273855731265604`\ \(c[32]\)[t] + 
            0.03132297449134708`\ \(c[33]\)[t] + 
            0.04454710875183992`\ \(c[34]\)[t] + 
            0.05544148706619893`\ \(c[35]\)[t] + 
            0.06361487254866825`\ \(c[36]\)[t] + 
            0.06880242987642335`\ \(c[37]\)[t] + 
            0.07087301895267824`\ \(c[38]\)[t] + 
            0.06983076867396242`\ \(c[39]\)[t] + 
            0.06581101988179627`\ \(c[40]\)[t] + 
            0.0590709530809064`\ \(c[41]\)[t] + 
            0.049975424961080865`\ \(c[42]\)[t] + 
            0.03897872015785999`\ \(c[43]\)[t] + 
            0.026603074225527937`\ \(c[44]\)[t] + 
            0.013414935129827233`\ \(c[45]\)[t] + 
            3.898171832519376`*^-17\ \(c[46]\)[t] - 
            0.013061910521147276`\ \(c[47]\)[t] - 
            0.025221096343682053`\ \(c[48]\)[t] - 
            0.03598035706879378`\ \(c[49]\)[t] - 
            0.04491462243337629`\ \(c[50]\)[t] - 
            0.05168708394579296`\ \(c[51]\)[t] - 
            0.056061239158567186`\ \(c[52]\)[t] - 
            0.0579084423149932`\ \(c[53]\)[t] - 
            0.05721075023890897`\ \(c[54]\)[t] - 
            0.054059052045761224`\ \(c[55]\)[t] - 
            0.0486466672430994`\ \(c[56]\)[t] - 
            0.04125878107252025`\ \(c[57]\)[t] - 
            0.03225825116512552`\ \(c[58]\)[t] - 
            0.022068459300722043`\ \(c[59]\)[t] - 
            0.011153991006822649`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -29, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -29]][ t]], 
          Plus[ 
            Times[ 0.032022748374426029, 
              c[ -60][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -59][ t]], 
            Times[ -0.034231213779558949, 
              c[ -58][ t]], 
            Times[ -0.069358014945125918, 
              c[ -57][ t]], 
            Times[ -0.1039432537542934, 
              c[ -56][ t]], 
            Times[ -0.13647135277833605, 
              c[ -55][ t]], 
            Times[ -0.1653986686265376, 
              c[ -54][ t]], 
            Times[ -0.18920668216016434, 
              c[ -53][ t]], 
            Times[ -0.20645618564475843, 
              c[ -52][ t]], 
            Times[ -0.21584055771952013, 
              c[ -51][ t]], 
            Times[ -0.21623620818304481, 
              c[ -50][ t]], 
            Times[ -0.206748335783172, 
              c[ -49][ t]], 
            Times[ -0.18675027222298607, 
              c[ -48][ t]], 
            Times[ -0.15591488063143966, 
              c[ -47][ t]], 
            Times[ -0.11423673049785436, 
              c[ -46][ t]], 
            Times[ -0.062044074975450475, 
              c[ -45][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -44][ t]], 
            Times[ 0.070907514257657775, 
              c[ -43][ t]], 
            Times[ 0.14938649372796345, 
              c[ -42][ t]], 
            Times[ 0.23387232094716018, 
              c[ -41][ t]], 
            Times[ 0.32256865202152157, 
              c[ -40][ t]], 
            Times[ 0.41349667156634395, 
              c[ -39][ t]], 
            Times[ 0.50455115242710469, 
              c[ -38][ t]], 
            Times[ 0.59356153372868059, 
              c[ -37][ t]], 
            Times[ 0.67835603854706317, 
              c[ -36][ t]], 
            Times[ 0.75682672864065692, 
              c[ -35][ t]], 
            Times[ 0.82699334313268813, 
              c[ -34][ t]], 
            Times[ 0.88706379305918381, 
              c[ -33][ t]], 
            Times[ 0.93548928378863916, 
              c[ -32][ t]], 
            Times[ 0.9710122092317629, 
              c[ -31][ t]], 
            Times[ 0.99270519960720671, 
              c[ -30][ t]], 
            Times[ 19.445194002924776, 
              c[ -29][ t]], 
            Times[ 0.99270519960720671, 
              c[ -28][ t]], 
            Times[ 0.9710122092317629, 
              c[ -27][ t]], 
            Times[ 0.93548928378863916, 
              c[ -26][ t]], 
            Times[ 0.88706379305918381, 
              c[ -25][ t]], 
            Times[ 0.82699334313268813, 
              c[ -24][ t]], 
            Times[ 0.75682672864065692, 
              c[ -23][ t]], 
            Times[ 0.67835603854706317, 
              c[ -22][ t]], 
            Times[ 0.59356153372868059, 
              c[ -21][ t]], 
            Times[ 0.50455115242710469, 
              c[ -20][ t]], 
            Times[ 0.41349667156634418, 
              c[ -19][ t]], 
            Times[ 0.32256865202152157, 
              c[ -18][ t]], 
            Times[ 0.23387232094715985, 
              c[ -17][ t]], 
            Times[ 0.14938649372796362, 
              c[ -16][ t]], 
            Times[ 0.070907514257657775, 
              c[ -15][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.062044074975450343, 
              c[ -13][ t]], 
            Times[ -0.11423673049785436, 
              c[ -12][ t]], 
            Times[ -0.15591488063143982, 
              c[ -11][ t]], 
            Times[ -0.18675027222298601, 
              c[ -10][ t]], 
            Times[ -0.206748335783172, 
              c[ -9][ t]], 
            Times[ -0.21623620818304484, 
              c[ -8][ t]], 
            Times[ -0.21584055771952015, 
              c[ -7][ t]], 
            Times[ -0.20645618564475843, 
              c[ -6][ t]], 
            Times[ -0.18920668216016426, 
              c[ -5][ t]], 
            Times[ -0.16539866862653771, 
              c[ -4][ t]], 
            Times[ -0.13647135277833605, 
              c[ -3][ t]], 
            Times[ -0.10394325375429328, 
              c[ -2][ t]], 
            Times[ -0.06935801494512607, 
              c[ -1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 0][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 2][ t]], 
            Times[ 0.060688263076985105, 
              c[ 3][ t]], 
            Times[ 0.085044480344421705, 
              c[ 4][ t]], 
            Times[ 0.10436044624225685, 
              c[ 5][ t]], 
            Times[ 0.11814190616181255, 
              c[ 6][ t]], 
            Times[ 0.12613778810677614, 
              c[ 7][ t]], 
            Times[ 0.12833762891430928, 
              c[ 8][ t]], 
            Times[ 0.12496032289024853, 
              c[ 9][ t]], 
            Times[ 0.11643488132933186, 
              c[ 10][ t]], 
            Times[ 0.10337416789158609, 
              c[ 11][ t]], 
            Times[ 0.086542809078944891, 
              c[ 12][ t]], 
            Times[ 0.066820663127759972, 
              c[ 13][ t]], 
            Times[ 0.045163358568919301, 
              c[ 14][ t]], 
            Times[ 0.022561481809254869, 
              c[ 15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 16][ t]], 
            Times[ -0.021580547817547879, 
              c[ 17][ t]], 
            Times[ -0.04131966847794722, 
              c[ 18][ t]], 
            Times[ -0.058468080236789913, 
              c[ 19][ t]], 
            Times[ -0.072413370861974122, 
              c[ 20][ t]], 
            Times[ -0.082699334313268744, 
              c[ 21][ t]], 
            Times[ -0.089038438663606695, 
              c[ 22][ t]], 
            Times[ -0.091317159035181589, 
              c[ 23][ t]], 
            Times[ -0.089594193770366884, 
              c[ 24][ t]], 
            Times[ -0.084091858737850814, 
              c[ 25][ t]], 
            Times[ -0.075181213012062598, 
              c[ 26][ t]], 
            Times[ -0.063361699504227528, 
              c[ 27][ t]], 
            Times[ -0.049236278094138941, 
              c[ 28][ t]], 
            Times[ -0.033483179628681567, 
              c[ 29][ t]], 
            Times[ -0.016825511857749401, 
              c[ 30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 31][ t]], 
            Times[ 0.016273855731265604, 
              c[ 32][ t]], 
            Times[ 0.031322974491347078, 
              c[ 33][ t]], 
            Times[ 0.044547108751839919, 
              c[ 34][ t]], 
            Times[ 0.055441487066198933, 
              c[ 35][ t]], 
            Times[ 0.063614872548668253, 
              c[ 36][ t]], 
            Times[ 0.068802429876423349, 
              c[ 37][ t]], 
            Times[ 0.070873018952678238, 
              c[ 38][ t]], 
            Times[ 0.069830768673962415, 
              c[ 39][ t]], 
            Times[ 0.065811019881796273, 
              c[ 40][ t]], 
            Times[ 0.059070953080906402, 
              c[ 41][ t]], 
            Times[ 0.049975424961080865, 
              c[ 42][ t]], 
            Times[ 0.03897872015785999, 
              c[ 43][ t]], 
            Times[ 0.026603074225527937, 
              c[ 44][ t]], 
            Times[ 0.013414935129827233, 
              c[ 45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ -0.013061910521147276, 
              c[ 47][ t]], 
            Times[ -0.025221096343682053, 
              c[ 48][ t]], 
            Times[ -0.035980357068793781, 
              c[ 49][ t]], 
            Times[ -0.044914622433376288, 
              c[ 50][ t]], 
            Times[ -0.05168708394579296, 
              c[ 51][ t]], 
            Times[ -0.056061239158567186, 
              c[ 52][ t]], 
            Times[ -0.057908442314993203, 
              c[ 53][ t]], 
            Times[ -0.057210750238908967, 
              c[ 54][ t]], 
            Times[ -0.054059052045761224, 
              c[ 55][ t]], 
            Times[ -0.048646667243099399, 
              c[ 56][ t]], 
            Times[ -0.041258781072520248, 
              c[ 57][ t]], 
            Times[ -0.032258251165125519, 
              c[ 58][ t]], 
            Times[ -0.022068459300722043, 
              c[ 59][ t]], 
            Times[ -0.011153991006822649, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-28\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-28\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06068826307698522`\ \(c[\(-60\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-59\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-57\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-56\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-55\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-54\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-53\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-52\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-51\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-50\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-49\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-48\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-47\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-46\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-45\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-42\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-41\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-40\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-39\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-38\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-37\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-36\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-35\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-34\)]\)[t] + 
            0.826993343132688`\ \(c[\(-33\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-32\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-31\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-30\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-29\)]\)[t] + 
            18.195044112120122`\ \(c[\(-28\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-27\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-26\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-25\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-24\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-23\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-22\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-21\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-20\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-19\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-18\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-17\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-16\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-15\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-14\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-13\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-12\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-11\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-10\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-9\)]\)[t] - 
            0.206748335783172`\ \(c[\(-8\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-7\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-6\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-5\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-4\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-3\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-2\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-1\)]\)[t] - 
            0.06935801494512607`\ \(c[0]\)[t] - 
            0.03423121377955895`\ \(c[1]\)[t] - 
            1.8033970416801674`*^-16\ \(c[2]\)[t] + 
            0.032022748374425904`\ \(c[3]\)[t] + 
            0.060688263076985105`\ \(c[4]\)[t] + 
            0.08504448034442161`\ \(c[5]\)[t] + 
            0.10436044624225685`\ \(c[6]\)[t] + 
            0.11814190616181253`\ \(c[7]\)[t] + 
            0.12613778810677612`\ \(c[8]\)[t] + 
            0.12833762891430928`\ \(c[9]\)[t] + 
            0.12496032289024853`\ \(c[10]\)[t] + 
            0.11643488132933186`\ \(c[11]\)[t] + 
            0.10337416789158609`\ \(c[12]\)[t] + 
            0.08654280907894489`\ \(c[13]\)[t] + 
            0.06682066312775997`\ \(c[14]\)[t] + 
            0.0451633585689193`\ \(c[15]\)[t] + 
            0.02256148180925487`\ \(c[16]\)[t] + 
            3.8981718325193755`*^-17\ \(c[17]\)[t] - 
            0.02158054781754788`\ \(c[18]\)[t] - 
            0.04131966847794722`\ \(c[19]\)[t] - 
            0.05846808023678991`\ \(c[20]\)[t] - 
            0.07241337086197412`\ \(c[21]\)[t] - 
            0.08269933431326874`\ \(c[22]\)[t] - 
            0.0890384386636067`\ \(c[23]\)[t] - 
            0.09131715903518159`\ \(c[24]\)[t] - 
            0.08959419377036688`\ \(c[25]\)[t] - 
            0.08409185873785081`\ \(c[26]\)[t] - 
            0.0751812130120626`\ \(c[27]\)[t] - 
            0.06336169950422753`\ \(c[28]\)[t] - 
            0.04923627809413894`\ \(c[29]\)[t] - 
            0.03348317962868157`\ \(c[30]\)[t] - 
            0.0168255118577494`\ \(c[31]\)[t] - 
            3.898171832519376`*^-17\ \(c[32]\)[t] + 
            0.016273855731265604`\ \(c[33]\)[t] + 
            0.03132297449134708`\ \(c[34]\)[t] + 
            0.04454710875183992`\ \(c[35]\)[t] + 
            0.05544148706619893`\ \(c[36]\)[t] + 
            0.06361487254866825`\ \(c[37]\)[t] + 
            0.06880242987642335`\ \(c[38]\)[t] + 
            0.07087301895267824`\ \(c[39]\)[t] + 
            0.06983076867396242`\ \(c[40]\)[t] + 
            0.06581101988179631`\ \(c[41]\)[t] + 
            0.059070953080906326`\ \(c[42]\)[t] + 
            0.049975424961080865`\ \(c[43]\)[t] + 
            0.03897872015786009`\ \(c[44]\)[t] + 
            0.026603074225527826`\ \(c[45]\)[t] + 
            0.013414935129827233`\ \(c[46]\)[t] + 
            1.5206810699945212`*^-16\ \(c[47]\)[t] - 
            0.013061910521147383`\ \(c[48]\)[t] - 
            0.025221096343682053`\ \(c[49]\)[t] - 
            0.03598035706879378`\ \(c[50]\)[t] - 
            0.04491462243337642`\ \(c[51]\)[t] - 
            0.05168708394579296`\ \(c[52]\)[t] - 
            0.05606123915856713`\ \(c[53]\)[t] - 
            0.0579084423149932`\ \(c[54]\)[t] - 
            0.05721075023890897`\ \(c[55]\)[t] - 
            0.054059052045761224`\ \(c[56]\)[t] - 
            0.04864666724309928`\ \(c[57]\)[t] - 
            0.04125878107252025`\ \(c[58]\)[t] - 
            0.03225825116512568`\ \(c[59]\)[t] - 
            0.022068459300722043`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -28, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -28]][ t]], 
          Plus[ 
            Times[ 0.060688263076985223, 
              c[ -60][ t]], 
            Times[ 0.032022748374425904, 
              c[ -59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ -0.034231213779558796, 
              c[ -57][ t]], 
            Times[ -0.06935801494512607, 
              c[ -56][ t]], 
            Times[ -0.10394325375429328, 
              c[ -55][ t]], 
            Times[ -0.13647135277833591, 
              c[ -54][ t]], 
            Times[ -0.16539866862653771, 
              c[ -53][ t]], 
            Times[ -0.18920668216016426, 
              c[ -52][ t]], 
            Times[ -0.20645618564475834, 
              c[ -51][ t]], 
            Times[ -0.21584055771952015, 
              c[ -50][ t]], 
            Times[ -0.21623620818304484, 
              c[ -49][ t]], 
            Times[ -0.20674833578317206, 
              c[ -48][ t]], 
            Times[ -0.18675027222298593, 
              c[ -47][ t]], 
            Times[ -0.15591488063143982, 
              c[ -46][ t]], 
            Times[ -0.11423673049785459, 
              c[ -45][ t]], 
            Times[ -0.062044074975450239, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ 0.070907514257657456, 
              c[ -42][ t]], 
            Times[ 0.14938649372796384, 
              c[ -41][ t]], 
            Times[ 0.23387232094715985, 
              c[ -40][ t]], 
            Times[ 0.32256865202152113, 
              c[ -39][ t]], 
            Times[ 0.41349667156634395, 
              c[ -38][ t]], 
            Times[ 0.50455115242710469, 
              c[ -37][ t]], 
            Times[ 0.59356153372868015, 
              c[ -36][ t]], 
            Times[ 0.67835603854706317, 
              c[ -35][ t]], 
            Times[ 0.75682672864065692, 
              c[ -34][ t]], 
            Times[ 0.82699334313268802, 
              c[ -33][ t]], 
            Times[ 0.88706379305918381, 
              c[ -32][ t]], 
            Times[ 0.93548928378863916, 
              c[ -31][ t]], 
            Times[ 0.9710122092317629, 
              c[ -30][ t]], 
            Times[ 0.99270519960720671, 
              c[ -29][ t]], 
            Times[ 18.195044112120122, 
              c[ -28][ t]], 
            Times[ 0.99270519960720693, 
              c[ -27][ t]], 
            Times[ 0.9710122092317629, 
              c[ -26][ t]], 
            Times[ 0.93548928378863916, 
              c[ -25][ t]], 
            Times[ 0.88706379305918392, 
              c[ -24][ t]], 
            Times[ 0.82699334313268813, 
              c[ -23][ t]], 
            Times[ 0.75682672864065692, 
              c[ -22][ t]], 
            Times[ 0.67835603854706361, 
              c[ -21][ t]], 
            Times[ 0.59356153372868059, 
              c[ -20][ t]], 
            Times[ 0.50455115242710491, 
              c[ -19][ t]], 
            Times[ 0.41349667156634429, 
              c[ -18][ t]], 
            Times[ 0.32256865202152157, 
              c[ -17][ t]], 
            Times[ 0.23387232094715998, 
              c[ -16][ t]], 
            Times[ 0.14938649372796384, 
              c[ -15][ t]], 
            Times[ 0.070907514257657775, 
              c[ -14][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -13][ t]], 
            Times[ -0.062044074975450239, 
              c[ -12][ t]], 
            Times[ -0.11423673049785436, 
              c[ -11][ t]], 
            Times[ -0.15591488063143974, 
              c[ -10][ t]], 
            Times[ -0.18675027222298593, 
              c[ -9][ t]], 
            Times[ -0.206748335783172, 
              c[ -8][ t]], 
            Times[ -0.21623620818304484, 
              c[ -7][ t]], 
            Times[ -0.21584055771952015, 
              c[ -6][ t]], 
            Times[ -0.20645618564475843, 
              c[ -5][ t]], 
            Times[ -0.18920668216016434, 
              c[ -4][ t]], 
            Times[ -0.16539866862653771, 
              c[ -3][ t]], 
            Times[ -0.13647135277833605, 
              c[ -2][ t]], 
            Times[ -0.1039432537542934, 
              c[ -1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 0][ t]], 
            Times[ -0.034231213779558949, 
              c[ 1][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 2][ t]], 
            Times[ 0.032022748374425904, 
              c[ 3][ t]], 
            Times[ 0.060688263076985105, 
              c[ 4][ t]], 
            Times[ 0.085044480344421608, 
              c[ 5][ t]], 
            Times[ 0.10436044624225685, 
              c[ 6][ t]], 
            Times[ 0.11814190616181253, 
              c[ 7][ t]], 
            Times[ 0.12613778810677612, 
              c[ 8][ t]], 
            Times[ 0.12833762891430928, 
              c[ 9][ t]], 
            Times[ 0.12496032289024853, 
              c[ 10][ t]], 
            Times[ 0.11643488132933186, 
              c[ 11][ t]], 
            Times[ 0.10337416789158609, 
              c[ 12][ t]], 
            Times[ 0.086542809078944891, 
              c[ 13][ t]], 
            Times[ 0.066820663127759972, 
              c[ 14][ t]], 
            Times[ 0.045163358568919301, 
              c[ 15][ t]], 
            Times[ 0.022561481809254869, 
              c[ 16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 17][ t]], 
            Times[ -0.021580547817547879, 
              c[ 18][ t]], 
            Times[ -0.04131966847794722, 
              c[ 19][ t]], 
            Times[ -0.058468080236789913, 
              c[ 20][ t]], 
            Times[ -0.072413370861974122, 
              c[ 21][ t]], 
            Times[ -0.082699334313268744, 
              c[ 22][ t]], 
            Times[ -0.089038438663606695, 
              c[ 23][ t]], 
            Times[ -0.091317159035181589, 
              c[ 24][ t]], 
            Times[ -0.089594193770366884, 
              c[ 25][ t]], 
            Times[ -0.084091858737850814, 
              c[ 26][ t]], 
            Times[ -0.075181213012062598, 
              c[ 27][ t]], 
            Times[ -0.063361699504227528, 
              c[ 28][ t]], 
            Times[ -0.049236278094138941, 
              c[ 29][ t]], 
            Times[ -0.033483179628681567, 
              c[ 30][ t]], 
            Times[ -0.016825511857749401, 
              c[ 31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ 0.016273855731265604, 
              c[ 33][ t]], 
            Times[ 0.031322974491347078, 
              c[ 34][ t]], 
            Times[ 0.044547108751839919, 
              c[ 35][ t]], 
            Times[ 0.055441487066198933, 
              c[ 36][ t]], 
            Times[ 0.063614872548668253, 
              c[ 37][ t]], 
            Times[ 0.068802429876423349, 
              c[ 38][ t]], 
            Times[ 0.070873018952678238, 
              c[ 39][ t]], 
            Times[ 0.069830768673962415, 
              c[ 40][ t]], 
            Times[ 0.065811019881796315, 
              c[ 41][ t]], 
            Times[ 0.059070953080906326, 
              c[ 42][ t]], 
            Times[ 0.049975424961080865, 
              c[ 43][ t]], 
            Times[ 0.038978720157860088, 
              c[ 44][ t]], 
            Times[ 0.026603074225527826, 
              c[ 45][ t]], 
            Times[ 0.013414935129827233, 
              c[ 46][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 47][ t]], 
            Times[ -0.013061910521147383, 
              c[ 48][ t]], 
            Times[ -0.025221096343682053, 
              c[ 49][ t]], 
            Times[ -0.035980357068793781, 
              c[ 50][ t]], 
            Times[ -0.044914622433376419, 
              c[ 51][ t]], 
            Times[ -0.05168708394579296, 
              c[ 52][ t]], 
            Times[ -0.05606123915856713, 
              c[ 53][ t]], 
            Times[ -0.057908442314993203, 
              c[ 54][ t]], 
            Times[ -0.057210750238908967, 
              c[ 55][ t]], 
            Times[ -0.054059052045761224, 
              c[ 56][ t]], 
            Times[ -0.048646667243099281, 
              c[ 57][ t]], 
            Times[ -0.041258781072520248, 
              c[ 58][ t]], 
            Times[ -0.032258251165125679, 
              c[ 59][ t]], 
            Times[ -0.022068459300722043, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-27\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-27\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.0850444803444217`\ \(c[\(-60\)]\)[t] + 
            0.060688263076985`\ \(c[\(-59\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-58\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-56\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-55\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-54\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-53\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-52\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-51\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-50\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-49\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-48\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-47\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-46\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-45\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-44\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] + 
            0.0709075142576581`\ \(c[\(-41\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-40\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-39\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-38\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-37\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-36\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-35\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-34\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-33\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-32\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-31\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-30\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-29\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-28\)]\)[t] + 
            16.98875912976476`\ \(c[\(-27\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-26\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-25\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-24\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-23\)]\)[t] + 
            0.826993343132688`\ \(c[\(-22\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-21\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-20\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-19\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-18\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-17\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-16\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-15\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-14\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-13\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-11\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-10\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-9\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-8\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-7\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-6\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-5\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-4\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-3\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-2\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-1\)]\)[t] - 
            0.10394325375429328`\ \(c[0]\)[t] - 
            0.06935801494512592`\ \(c[1]\)[t] - 
            0.03423121377955895`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.03202274837442603`\ \(c[4]\)[t] + 
            0.060688263076985105`\ \(c[5]\)[t] + 
            0.0850444803444217`\ \(c[6]\)[t] + 
            0.10436044624225685`\ \(c[7]\)[t] + 
            0.11814190616181255`\ \(c[8]\)[t] + 
            0.12613778810677614`\ \(c[9]\)[t] + 
            0.12833762891430928`\ \(c[10]\)[t] + 
            0.12496032289024853`\ \(c[11]\)[t] + 
            0.11643488132933186`\ \(c[12]\)[t] + 
            0.10337416789158609`\ \(c[13]\)[t] + 
            0.08654280907894489`\ \(c[14]\)[t] + 
            0.06682066312775997`\ \(c[15]\)[t] + 
            0.0451633585689193`\ \(c[16]\)[t] + 
            0.02256148180925487`\ \(c[17]\)[t] + 
            3.8981718325193755`*^-17\ \(c[18]\)[t] - 
            0.02158054781754788`\ \(c[19]\)[t] - 
            0.04131966847794722`\ \(c[20]\)[t] - 
            0.05846808023678991`\ \(c[21]\)[t] - 
            0.07241337086197412`\ \(c[22]\)[t] - 
            0.08269933431326874`\ \(c[23]\)[t] - 
            0.0890384386636067`\ \(c[24]\)[t] - 
            0.09131715903518159`\ \(c[25]\)[t] - 
            0.08959419377036688`\ \(c[26]\)[t] - 
            0.08409185873785081`\ \(c[27]\)[t] - 
            0.0751812130120626`\ \(c[28]\)[t] - 
            0.06336169950422753`\ \(c[29]\)[t] - 
            0.04923627809413894`\ \(c[30]\)[t] - 
            0.03348317962868157`\ \(c[31]\)[t] - 
            0.0168255118577494`\ \(c[32]\)[t] - 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.016273855731265604`\ \(c[34]\)[t] + 
            0.03132297449134708`\ \(c[35]\)[t] + 
            0.04454710875183992`\ \(c[36]\)[t] + 
            0.05544148706619893`\ \(c[37]\)[t] + 
            0.06361487254866825`\ \(c[38]\)[t] + 
            0.06880242987642335`\ \(c[39]\)[t] + 
            0.07087301895267824`\ \(c[40]\)[t] + 
            0.06983076867396242`\ \(c[41]\)[t] + 
            0.06581101988179627`\ \(c[42]\)[t] + 
            0.059070953080906326`\ \(c[43]\)[t] + 
            0.049975424961080865`\ \(c[44]\)[t] + 
            0.03897872015785999`\ \(c[45]\)[t] + 
            0.026603074225527826`\ \(c[46]\)[t] + 
            0.013414935129827233`\ \(c[47]\)[t] + 
            3.898171832519376`*^-17\ \(c[48]\)[t] - 
            0.013061910521147383`\ \(c[49]\)[t] - 
            0.025221096343682053`\ \(c[50]\)[t] - 
            0.03598035706879378`\ \(c[51]\)[t] - 
            0.04491462243337642`\ \(c[52]\)[t] - 
            0.05168708394579296`\ \(c[53]\)[t] - 
            0.056061239158567186`\ \(c[54]\)[t] - 
            0.0579084423149932`\ \(c[55]\)[t] - 
            0.05721075023890897`\ \(c[56]\)[t] - 
            0.054059052045761224`\ \(c[57]\)[t] - 
            0.04864666724309928`\ \(c[58]\)[t] - 
            0.04125878107252025`\ \(c[59]\)[t] - 
            0.03225825116512552`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -27, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -27]][ t]], 
          Plus[ 
            Times[ 0.085044480344421705, 
              c[ -60][ t]], 
            Times[ 0.060688263076985001, 
              c[ -59][ t]], 
            Times[ 0.032022748374425904, 
              c[ -58][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ -0.034231213779559094, 
              c[ -56][ t]], 
            Times[ -0.06935801494512607, 
              c[ -55][ t]], 
            Times[ -0.10394325375429328, 
              c[ -54][ t]], 
            Times[ -0.13647135277833616, 
              c[ -53][ t]], 
            Times[ -0.16539866862653771, 
              c[ -52][ t]], 
            Times[ -0.18920668216016426, 
              c[ -51][ t]], 
            Times[ -0.20645618564475848, 
              c[ -50][ t]], 
            Times[ -0.21584055771952015, 
              c[ -49][ t]], 
            Times[ -0.21623620818304484, 
              c[ -48][ t]], 
            Times[ -0.20674833578317189, 
              c[ -47][ t]], 
            Times[ -0.18675027222298593, 
              c[ -46][ t]], 
            Times[ -0.15591488063143982, 
              c[ -45][ t]], 
            Times[ -0.11423673049785416, 
              c[ -44][ t]], 
            Times[ -0.062044074975450239, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ 0.070907514257658094, 
              c[ -41][ t]], 
            Times[ 0.14938649372796384, 
              c[ -40][ t]], 
            Times[ 0.23387232094715985, 
              c[ -39][ t]], 
            Times[ 0.32256865202152157, 
              c[ -38][ t]], 
            Times[ 0.41349667156634429, 
              c[ -37][ t]], 
            Times[ 0.50455115242710469, 
              c[ -36][ t]], 
            Times[ 0.59356153372868059, 
              c[ -35][ t]], 
            Times[ 0.67835603854706361, 
              c[ -34][ t]], 
            Times[ 0.75682672864065692, 
              c[ -33][ t]], 
            Times[ 0.82699334313268813, 
              c[ -32][ t]], 
            Times[ 0.88706379305918392, 
              c[ -31][ t]], 
            Times[ 0.93548928378863916, 
              c[ -30][ t]], 
            Times[ 0.9710122092317629, 
              c[ -29][ t]], 
            Times[ 0.99270519960720693, 
              c[ -28][ t]], 
            Times[ 16.988759129764759, 
              c[ -27][ t]], 
            Times[ 0.99270519960720671, 
              c[ -26][ t]], 
            Times[ 0.9710122092317629, 
              c[ -25][ t]], 
            Times[ 0.93548928378863916, 
              c[ -24][ t]], 
            Times[ 0.88706379305918381, 
              c[ -23][ t]], 
            Times[ 0.82699334313268802, 
              c[ -22][ t]], 
            Times[ 0.75682672864065692, 
              c[ -21][ t]], 
            Times[ 0.67835603854706317, 
              c[ -20][ t]], 
            Times[ 0.59356153372868026, 
              c[ -19][ t]], 
            Times[ 0.50455115242710469, 
              c[ -18][ t]], 
            Times[ 0.41349667156634395, 
              c[ -17][ t]], 
            Times[ 0.32256865202152135, 
              c[ -16][ t]], 
            Times[ 0.23387232094715985, 
              c[ -15][ t]], 
            Times[ 0.14938649372796345, 
              c[ -14][ t]], 
            Times[ 0.070907514257657622, 
              c[ -13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.062044074975450475, 
              c[ -11][ t]], 
            Times[ -0.11423673049785445, 
              c[ -10][ t]], 
            Times[ -0.15591488063143982, 
              c[ -9][ t]], 
            Times[ -0.18675027222298607, 
              c[ -8][ t]], 
            Times[ -0.20674833578317206, 
              c[ -7][ t]], 
            Times[ -0.21623620818304484, 
              c[ -6][ t]], 
            Times[ -0.21584055771952013, 
              c[ -5][ t]], 
            Times[ -0.20645618564475843, 
              c[ -4][ t]], 
            Times[ -0.18920668216016426, 
              c[ -3][ t]], 
            Times[ -0.1653986686265376, 
              c[ -2][ t]], 
            Times[ -0.13647135277833605, 
              c[ -1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 0][ t]], 
            Times[ -0.069358014945125918, 
              c[ 1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.032022748374426029, 
              c[ 4][ t]], 
            Times[ 0.060688263076985105, 
              c[ 5][ t]], 
            Times[ 0.085044480344421705, 
              c[ 6][ t]], 
            Times[ 0.10436044624225685, 
              c[ 7][ t]], 
            Times[ 0.11814190616181255, 
              c[ 8][ t]], 
            Times[ 0.12613778810677614, 
              c[ 9][ t]], 
            Times[ 0.12833762891430928, 
              c[ 10][ t]], 
            Times[ 0.12496032289024853, 
              c[ 11][ t]], 
            Times[ 0.11643488132933186, 
              c[ 12][ t]], 
            Times[ 0.10337416789158609, 
              c[ 13][ t]], 
            Times[ 0.086542809078944891, 
              c[ 14][ t]], 
            Times[ 0.066820663127759972, 
              c[ 15][ t]], 
            Times[ 0.045163358568919301, 
              c[ 16][ t]], 
            Times[ 0.022561481809254869, 
              c[ 17][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 18][ t]], 
            Times[ -0.021580547817547879, 
              c[ 19][ t]], 
            Times[ -0.04131966847794722, 
              c[ 20][ t]], 
            Times[ -0.058468080236789913, 
              c[ 21][ t]], 
            Times[ -0.072413370861974122, 
              c[ 22][ t]], 
            Times[ -0.082699334313268744, 
              c[ 23][ t]], 
            Times[ -0.089038438663606695, 
              c[ 24][ t]], 
            Times[ -0.091317159035181589, 
              c[ 25][ t]], 
            Times[ -0.089594193770366884, 
              c[ 26][ t]], 
            Times[ -0.084091858737850814, 
              c[ 27][ t]], 
            Times[ -0.075181213012062598, 
              c[ 28][ t]], 
            Times[ -0.063361699504227528, 
              c[ 29][ t]], 
            Times[ -0.049236278094138941, 
              c[ 30][ t]], 
            Times[ -0.033483179628681567, 
              c[ 31][ t]], 
            Times[ -0.016825511857749401, 
              c[ 32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.016273855731265604, 
              c[ 34][ t]], 
            Times[ 0.031322974491347078, 
              c[ 35][ t]], 
            Times[ 0.044547108751839919, 
              c[ 36][ t]], 
            Times[ 0.055441487066198933, 
              c[ 37][ t]], 
            Times[ 0.063614872548668253, 
              c[ 38][ t]], 
            Times[ 0.068802429876423349, 
              c[ 39][ t]], 
            Times[ 0.070873018952678238, 
              c[ 40][ t]], 
            Times[ 0.069830768673962415, 
              c[ 41][ t]], 
            Times[ 0.065811019881796273, 
              c[ 42][ t]], 
            Times[ 0.059070953080906326, 
              c[ 43][ t]], 
            Times[ 0.049975424961080865, 
              c[ 44][ t]], 
            Times[ 0.03897872015785999, 
              c[ 45][ t]], 
            Times[ 0.026603074225527826, 
              c[ 46][ t]], 
            Times[ 0.013414935129827233, 
              c[ 47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ -0.013061910521147383, 
              c[ 49][ t]], 
            Times[ -0.025221096343682053, 
              c[ 50][ t]], 
            Times[ -0.035980357068793781, 
              c[ 51][ t]], 
            Times[ -0.044914622433376419, 
              c[ 52][ t]], 
            Times[ -0.05168708394579296, 
              c[ 53][ t]], 
            Times[ -0.056061239158567186, 
              c[ 54][ t]], 
            Times[ -0.057908442314993203, 
              c[ 55][ t]], 
            Times[ -0.057210750238908967, 
              c[ 56][ t]], 
            Times[ -0.054059052045761224, 
              c[ 57][ t]], 
            Times[ -0.048646667243099281, 
              c[ 58][ t]], 
            Times[ -0.041258781072520248, 
              c[ 59][ t]], 
            Times[ -0.032258251165125519, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-26\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-26\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.10436044624225692`\ \(c[\(-60\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-59\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-58\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-57\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-56\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-55\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-54\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-53\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-52\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-51\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-50\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-49\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-48\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-47\)]\)[t] - 
            0.206748335783172`\ \(c[\(-46\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-45\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-44\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-43\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-42\)]\)[t] + 
            3.216976900108398`*^-16\ \(c[\(-41\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-40\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-39\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-38\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-37\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-36\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-35\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-34\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-33\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-32\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-31\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-30\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-29\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-28\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-27\)]\)[t] + 
            15.826339055858679`\ \(c[\(-26\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-25\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-24\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-23\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-22\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-21\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-20\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-19\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-18\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-17\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-16\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-15\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-14\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-13\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-12\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-10\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-9\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-8\)]\)[t] - 
            0.186750272222986`\ \(c[\(-7\)]\)[t] - 
            0.206748335783172`\ \(c[\(-6\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-5\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-4\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-3\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-2\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-1\)]\)[t] - 
            0.13647135277833605`\ \(c[0]\)[t] - 
            0.10394325375429328`\ \(c[1]\)[t] - 
            0.06935801494512607`\ \(c[2]\)[t] - 
            0.03423121377955895`\ \(c[3]\)[t] - 
            3.898171832519376`*^-17\ \(c[4]\)[t] + 
            0.032022748374425904`\ \(c[5]\)[t] + 
            0.060688263076985105`\ \(c[6]\)[t] + 
            0.0850444803444217`\ \(c[7]\)[t] + 
            0.10436044624225685`\ \(c[8]\)[t] + 
            0.11814190616181255`\ \(c[9]\)[t] + 
            0.12613778810677614`\ \(c[10]\)[t] + 
            0.12833762891430928`\ \(c[11]\)[t] + 
            0.12496032289024853`\ \(c[12]\)[t] + 
            0.11643488132933186`\ \(c[13]\)[t] + 
            0.10337416789158609`\ \(c[14]\)[t] + 
            0.08654280907894489`\ \(c[15]\)[t] + 
            0.06682066312775997`\ \(c[16]\)[t] + 
            0.0451633585689193`\ \(c[17]\)[t] + 
            0.02256148180925487`\ \(c[18]\)[t] + 
            3.8981718325193755`*^-17\ \(c[19]\)[t] - 
            0.02158054781754788`\ \(c[20]\)[t] - 
            0.04131966847794722`\ \(c[21]\)[t] - 
            0.05846808023678991`\ \(c[22]\)[t] - 
            0.07241337086197412`\ \(c[23]\)[t] - 
            0.08269933431326874`\ \(c[24]\)[t] - 
            0.0890384386636067`\ \(c[25]\)[t] - 
            0.09131715903518159`\ \(c[26]\)[t] - 
            0.08959419377036688`\ \(c[27]\)[t] - 
            0.08409185873785081`\ \(c[28]\)[t] - 
            0.0751812130120626`\ \(c[29]\)[t] - 
            0.06336169950422753`\ \(c[30]\)[t] - 
            0.04923627809413894`\ \(c[31]\)[t] - 
            0.03348317962868157`\ \(c[32]\)[t] - 
            0.0168255118577494`\ \(c[33]\)[t] - 
            3.898171832519376`*^-17\ \(c[34]\)[t] + 
            0.016273855731265604`\ \(c[35]\)[t] + 
            0.03132297449134708`\ \(c[36]\)[t] + 
            0.04454710875183992`\ \(c[37]\)[t] + 
            0.05544148706619893`\ \(c[38]\)[t] + 
            0.06361487254866825`\ \(c[39]\)[t] + 
            0.06880242987642335`\ \(c[40]\)[t] + 
            0.07087301895267824`\ \(c[41]\)[t] + 
            0.06983076867396242`\ \(c[42]\)[t] + 
            0.06581101988179627`\ \(c[43]\)[t] + 
            0.0590709530809064`\ \(c[44]\)[t] + 
            0.049975424961080865`\ \(c[45]\)[t] + 
            0.03897872015785999`\ \(c[46]\)[t] + 
            0.026603074225527937`\ \(c[47]\)[t] + 
            0.013414935129827233`\ \(c[48]\)[t] + 
            3.898171832519376`*^-17\ \(c[49]\)[t] - 
            0.013061910521147276`\ \(c[50]\)[t] - 
            0.025221096343682053`\ \(c[51]\)[t] - 
            0.03598035706879378`\ \(c[52]\)[t] - 
            0.04491462243337629`\ \(c[53]\)[t] - 
            0.05168708394579296`\ \(c[54]\)[t] - 
            0.056061239158567186`\ \(c[55]\)[t] - 
            0.0579084423149932`\ \(c[56]\)[t] - 
            0.05721075023890897`\ \(c[57]\)[t] - 
            0.054059052045761224`\ \(c[58]\)[t] - 
            0.0486466672430994`\ \(c[59]\)[t] - 
            0.04125878107252025`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -26, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -26]][ t]], 
          Plus[ 
            Times[ 0.10436044624225692, 
              c[ -60][ t]], 
            Times[ 0.085044480344421608, 
              c[ -59][ t]], 
            Times[ 0.060688263076985105, 
              c[ -58][ t]], 
            Times[ 0.032022748374426029, 
              c[ -57][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -56][ t]], 
            Times[ -0.034231213779558949, 
              c[ -55][ t]], 
            Times[ -0.069358014945125918, 
              c[ -54][ t]], 
            Times[ -0.1039432537542934, 
              c[ -53][ t]], 
            Times[ -0.13647135277833605, 
              c[ -52][ t]], 
            Times[ -0.1653986686265376, 
              c[ -51][ t]], 
            Times[ -0.18920668216016434, 
              c[ -50][ t]], 
            Times[ -0.20645618564475843, 
              c[ -49][ t]], 
            Times[ -0.21584055771952013, 
              c[ -48][ t]], 
            Times[ -0.21623620818304481, 
              c[ -47][ t]], 
            Times[ -0.206748335783172, 
              c[ -46][ t]], 
            Times[ -0.18675027222298607, 
              c[ -45][ t]], 
            Times[ -0.15591488063143966, 
              c[ -44][ t]], 
            Times[ -0.11423673049785436, 
              c[ -43][ t]], 
            Times[ -0.062044074975450475, 
              c[ -42][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ -41][ t]], 
            Times[ 0.070907514257657775, 
              c[ -40][ t]], 
            Times[ 0.14938649372796345, 
              c[ -39][ t]], 
            Times[ 0.23387232094715985, 
              c[ -38][ t]], 
            Times[ 0.32256865202152157, 
              c[ -37][ t]], 
            Times[ 0.41349667156634395, 
              c[ -36][ t]], 
            Times[ 0.50455115242710469, 
              c[ -35][ t]], 
            Times[ 0.59356153372868059, 
              c[ -34][ t]], 
            Times[ 0.67835603854706317, 
              c[ -33][ t]], 
            Times[ 0.75682672864065692, 
              c[ -32][ t]], 
            Times[ 0.82699334313268813, 
              c[ -31][ t]], 
            Times[ 0.88706379305918381, 
              c[ -30][ t]], 
            Times[ 0.93548928378863916, 
              c[ -29][ t]], 
            Times[ 0.9710122092317629, 
              c[ -28][ t]], 
            Times[ 0.99270519960720671, 
              c[ -27][ t]], 
            Times[ 15.826339055858679, 
              c[ -26][ t]], 
            Times[ 0.99270519960720671, 
              c[ -25][ t]], 
            Times[ 0.9710122092317629, 
              c[ -24][ t]], 
            Times[ 0.93548928378863916, 
              c[ -23][ t]], 
            Times[ 0.88706379305918381, 
              c[ -22][ t]], 
            Times[ 0.82699334313268813, 
              c[ -21][ t]], 
            Times[ 0.75682672864065692, 
              c[ -20][ t]], 
            Times[ 0.67835603854706339, 
              c[ -19][ t]], 
            Times[ 0.59356153372868059, 
              c[ -18][ t]], 
            Times[ 0.50455115242710469, 
              c[ -17][ t]], 
            Times[ 0.41349667156634418, 
              c[ -16][ t]], 
            Times[ 0.32256865202152157, 
              c[ -15][ t]], 
            Times[ 0.23387232094715985, 
              c[ -14][ t]], 
            Times[ 0.14938649372796362, 
              c[ -13][ t]], 
            Times[ 0.070907514257657775, 
              c[ -12][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.062044074975450343, 
              c[ -10][ t]], 
            Times[ -0.11423673049785436, 
              c[ -9][ t]], 
            Times[ -0.15591488063143982, 
              c[ -8][ t]], 
            Times[ -0.18675027222298601, 
              c[ -7][ t]], 
            Times[ -0.206748335783172, 
              c[ -6][ t]], 
            Times[ -0.21623620818304484, 
              c[ -5][ t]], 
            Times[ -0.21584055771952015, 
              c[ -4][ t]], 
            Times[ -0.20645618564475843, 
              c[ -3][ t]], 
            Times[ -0.18920668216016426, 
              c[ -2][ t]], 
            Times[ -0.16539866862653771, 
              c[ -1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 0][ t]], 
            Times[ -0.10394325375429328, 
              c[ 1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 2][ t]], 
            Times[ -0.034231213779558949, 
              c[ 3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 4][ t]], 
            Times[ 0.032022748374425904, 
              c[ 5][ t]], 
            Times[ 0.060688263076985105, 
              c[ 6][ t]], 
            Times[ 0.085044480344421705, 
              c[ 7][ t]], 
            Times[ 0.10436044624225685, 
              c[ 8][ t]], 
            Times[ 0.11814190616181255, 
              c[ 9][ t]], 
            Times[ 0.12613778810677614, 
              c[ 10][ t]], 
            Times[ 0.12833762891430928, 
              c[ 11][ t]], 
            Times[ 0.12496032289024853, 
              c[ 12][ t]], 
            Times[ 0.11643488132933186, 
              c[ 13][ t]], 
            Times[ 0.10337416789158609, 
              c[ 14][ t]], 
            Times[ 0.086542809078944891, 
              c[ 15][ t]], 
            Times[ 0.066820663127759972, 
              c[ 16][ t]], 
            Times[ 0.045163358568919301, 
              c[ 17][ t]], 
            Times[ 0.022561481809254869, 
              c[ 18][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 19][ t]], 
            Times[ -0.021580547817547879, 
              c[ 20][ t]], 
            Times[ -0.04131966847794722, 
              c[ 21][ t]], 
            Times[ -0.058468080236789913, 
              c[ 22][ t]], 
            Times[ -0.072413370861974122, 
              c[ 23][ t]], 
            Times[ -0.082699334313268744, 
              c[ 24][ t]], 
            Times[ -0.089038438663606695, 
              c[ 25][ t]], 
            Times[ -0.091317159035181589, 
              c[ 26][ t]], 
            Times[ -0.089594193770366884, 
              c[ 27][ t]], 
            Times[ -0.084091858737850814, 
              c[ 28][ t]], 
            Times[ -0.075181213012062598, 
              c[ 29][ t]], 
            Times[ -0.063361699504227528, 
              c[ 30][ t]], 
            Times[ -0.049236278094138941, 
              c[ 31][ t]], 
            Times[ -0.033483179628681567, 
              c[ 32][ t]], 
            Times[ -0.016825511857749401, 
              c[ 33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 34][ t]], 
            Times[ 0.016273855731265604, 
              c[ 35][ t]], 
            Times[ 0.031322974491347078, 
              c[ 36][ t]], 
            Times[ 0.044547108751839919, 
              c[ 37][ t]], 
            Times[ 0.055441487066198933, 
              c[ 38][ t]], 
            Times[ 0.063614872548668253, 
              c[ 39][ t]], 
            Times[ 0.068802429876423349, 
              c[ 40][ t]], 
            Times[ 0.070873018952678238, 
              c[ 41][ t]], 
            Times[ 0.069830768673962415, 
              c[ 42][ t]], 
            Times[ 0.065811019881796273, 
              c[ 43][ t]], 
            Times[ 0.059070953080906402, 
              c[ 44][ t]], 
            Times[ 0.049975424961080865, 
              c[ 45][ t]], 
            Times[ 0.03897872015785999, 
              c[ 46][ t]], 
            Times[ 0.026603074225527937, 
              c[ 47][ t]], 
            Times[ 0.013414935129827233, 
              c[ 48][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ -0.013061910521147276, 
              c[ 50][ t]], 
            Times[ -0.025221096343682053, 
              c[ 51][ t]], 
            Times[ -0.035980357068793781, 
              c[ 52][ t]], 
            Times[ -0.044914622433376288, 
              c[ 53][ t]], 
            Times[ -0.05168708394579296, 
              c[ 54][ t]], 
            Times[ -0.056061239158567186, 
              c[ 55][ t]], 
            Times[ -0.057908442314993203, 
              c[ 56][ t]], 
            Times[ -0.057210750238908967, 
              c[ 57][ t]], 
            Times[ -0.054059052045761224, 
              c[ 58][ t]], 
            Times[ -0.048646667243099399, 
              c[ 59][ t]], 
            Times[ -0.041258781072520248, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-25\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-25\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.1181419061618126`\ \(c[\(-60\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-59\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-58\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-57\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-56\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-54\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-53\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-52\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-51\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-50\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-49\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-48\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-47\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-46\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-45\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-44\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-43\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-42\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-39\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-38\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-37\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-36\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-35\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-34\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-33\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-32\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-31\)]\)[t] + 
            0.826993343132688`\ \(c[\(-30\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-29\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-28\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-27\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-26\)]\)[t] + 
            14.707783890401883`\ \(c[\(-25\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-24\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-23\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-22\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-21\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-20\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-19\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-18\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-17\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-16\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-15\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-14\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-13\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-12\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-11\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-10\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-9\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-8\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-7\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-6\)]\)[t] - 
            0.206748335783172`\ \(c[\(-5\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-4\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-3\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-2\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-1\)]\)[t] - 
            0.1653986686265377`\ \(c[0]\)[t] - 
            0.13647135277833605`\ \(c[1]\)[t] - 
            0.1039432537542934`\ \(c[2]\)[t] - 
            0.06935801494512607`\ \(c[3]\)[t] - 
            0.03423121377955895`\ \(c[4]\)[t] - 
            1.8033970416801674`*^-16\ \(c[5]\)[t] + 
            0.032022748374425904`\ \(c[6]\)[t] + 
            0.060688263076985`\ \(c[7]\)[t] + 
            0.08504448034442161`\ \(c[8]\)[t] + 
            0.10436044624225685`\ \(c[9]\)[t] + 
            0.11814190616181253`\ \(c[10]\)[t] + 
            0.12613778810677612`\ \(c[11]\)[t] + 
            0.12833762891430928`\ \(c[12]\)[t] + 
            0.12496032289024853`\ \(c[13]\)[t] + 
            0.11643488132933186`\ \(c[14]\)[t] + 
            0.10337416789158609`\ \(c[15]\)[t] + 
            0.08654280907894489`\ \(c[16]\)[t] + 
            0.06682066312775997`\ \(c[17]\)[t] + 
            0.0451633585689193`\ \(c[18]\)[t] + 
            0.02256148180925487`\ \(c[19]\)[t] + 
            3.8981718325193755`*^-17\ \(c[20]\)[t] - 
            0.02158054781754788`\ \(c[21]\)[t] - 
            0.04131966847794722`\ \(c[22]\)[t] - 
            0.05846808023678991`\ \(c[23]\)[t] - 
            0.07241337086197412`\ \(c[24]\)[t] - 
            0.08269933431326874`\ \(c[25]\)[t] - 
            0.0890384386636067`\ \(c[26]\)[t] - 
            0.09131715903518159`\ \(c[27]\)[t] - 
            0.08959419377036688`\ \(c[28]\)[t] - 
            0.08409185873785081`\ \(c[29]\)[t] - 
            0.0751812130120626`\ \(c[30]\)[t] - 
            0.06336169950422753`\ \(c[31]\)[t] - 
            0.04923627809413894`\ \(c[32]\)[t] - 
            0.03348317962868157`\ \(c[33]\)[t] - 
            0.0168255118577494`\ \(c[34]\)[t] - 
            3.898171832519376`*^-17\ \(c[35]\)[t] + 
            0.016273855731265604`\ \(c[36]\)[t] + 
            0.03132297449134708`\ \(c[37]\)[t] + 
            0.04454710875183992`\ \(c[38]\)[t] + 
            0.05544148706619893`\ \(c[39]\)[t] + 
            0.06361487254866825`\ \(c[40]\)[t] + 
            0.06880242987642332`\ \(c[41]\)[t] + 
            0.07087301895267824`\ \(c[42]\)[t] + 
            0.06983076867396242`\ \(c[43]\)[t] + 
            0.06581101988179631`\ \(c[44]\)[t] + 
            0.059070953080906326`\ \(c[45]\)[t] + 
            0.049975424961080865`\ \(c[46]\)[t] + 
            0.03897872015786009`\ \(c[47]\)[t] + 
            0.026603074225527826`\ \(c[48]\)[t] + 
            0.013414935129827233`\ \(c[49]\)[t] + 
            1.5206810699945212`*^-16\ \(c[50]\)[t] - 
            0.013061910521147383`\ \(c[51]\)[t] - 
            0.025221096343682053`\ \(c[52]\)[t] - 
            0.03598035706879378`\ \(c[53]\)[t] - 
            0.04491462243337642`\ \(c[54]\)[t] - 
            0.05168708394579296`\ \(c[55]\)[t] - 
            0.05606123915856713`\ \(c[56]\)[t] - 
            0.0579084423149932`\ \(c[57]\)[t] - 
            0.05721075023890897`\ \(c[58]\)[t] - 
            0.054059052045761224`\ \(c[59]\)[t] - 
            0.04864666724309928`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -25, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -25]][ t]], 
          Plus[ 
            Times[ 0.1181419061618126, 
              c[ -60][ t]], 
            Times[ 0.10436044624225685, 
              c[ -59][ t]], 
            Times[ 0.085044480344421705, 
              c[ -58][ t]], 
            Times[ 0.060688263076985223, 
              c[ -57][ t]], 
            Times[ 0.032022748374425904, 
              c[ -56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ -0.034231213779558796, 
              c[ -54][ t]], 
            Times[ -0.06935801494512607, 
              c[ -53][ t]], 
            Times[ -0.10394325375429328, 
              c[ -52][ t]], 
            Times[ -0.13647135277833591, 
              c[ -51][ t]], 
            Times[ -0.16539866862653771, 
              c[ -50][ t]], 
            Times[ -0.18920668216016426, 
              c[ -49][ t]], 
            Times[ -0.20645618564475834, 
              c[ -48][ t]], 
            Times[ -0.21584055771952015, 
              c[ -47][ t]], 
            Times[ -0.21623620818304484, 
              c[ -46][ t]], 
            Times[ -0.20674833578317206, 
              c[ -45][ t]], 
            Times[ -0.18675027222298593, 
              c[ -44][ t]], 
            Times[ -0.15591488063143982, 
              c[ -43][ t]], 
            Times[ -0.11423673049785459, 
              c[ -42][ t]], 
            Times[ -0.062044074975450239, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ 0.070907514257657456, 
              c[ -39][ t]], 
            Times[ 0.14938649372796345, 
              c[ -38][ t]], 
            Times[ 0.23387232094715985, 
              c[ -37][ t]], 
            Times[ 0.32256865202152113, 
              c[ -36][ t]], 
            Times[ 0.41349667156634395, 
              c[ -35][ t]], 
            Times[ 0.50455115242710469, 
              c[ -34][ t]], 
            Times[ 0.59356153372868015, 
              c[ -33][ t]], 
            Times[ 0.67835603854706317, 
              c[ -32][ t]], 
            Times[ 0.75682672864065692, 
              c[ -31][ t]], 
            Times[ 0.82699334313268802, 
              c[ -30][ t]], 
            Times[ 0.88706379305918381, 
              c[ -29][ t]], 
            Times[ 0.93548928378863916, 
              c[ -28][ t]], 
            Times[ 0.9710122092317629, 
              c[ -27][ t]], 
            Times[ 0.99270519960720671, 
              c[ -26][ t]], 
            Times[ 14.707783890401883, 
              c[ -25][ t]], 
            Times[ 0.99270519960720693, 
              c[ -24][ t]], 
            Times[ 0.9710122092317629, 
              c[ -23][ t]], 
            Times[ 0.93548928378863916, 
              c[ -22][ t]], 
            Times[ 0.88706379305918392, 
              c[ -21][ t]], 
            Times[ 0.82699334313268813, 
              c[ -20][ t]], 
            Times[ 0.75682672864065714, 
              c[ -19][ t]], 
            Times[ 0.67835603854706361, 
              c[ -18][ t]], 
            Times[ 0.59356153372868059, 
              c[ -17][ t]], 
            Times[ 0.50455115242710491, 
              c[ -16][ t]], 
            Times[ 0.41349667156634429, 
              c[ -15][ t]], 
            Times[ 0.32256865202152157, 
              c[ -14][ t]], 
            Times[ 0.23387232094715998, 
              c[ -13][ t]], 
            Times[ 0.14938649372796384, 
              c[ -12][ t]], 
            Times[ 0.070907514257657775, 
              c[ -11][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -10][ t]], 
            Times[ -0.062044074975450239, 
              c[ -9][ t]], 
            Times[ -0.11423673049785436, 
              c[ -8][ t]], 
            Times[ -0.15591488063143974, 
              c[ -7][ t]], 
            Times[ -0.18675027222298593, 
              c[ -6][ t]], 
            Times[ -0.206748335783172, 
              c[ -5][ t]], 
            Times[ -0.21623620818304481, 
              c[ -4][ t]], 
            Times[ -0.21584055771952015, 
              c[ -3][ t]], 
            Times[ -0.20645618564475843, 
              c[ -2][ t]], 
            Times[ -0.18920668216016434, 
              c[ -1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 0][ t]], 
            Times[ -0.13647135277833605, 
              c[ 1][ t]], 
            Times[ -0.1039432537542934, 
              c[ 2][ t]], 
            Times[ -0.06935801494512607, 
              c[ 3][ t]], 
            Times[ -0.034231213779558949, 
              c[ 4][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 5][ t]], 
            Times[ 0.032022748374425904, 
              c[ 6][ t]], 
            Times[ 0.060688263076985001, 
              c[ 7][ t]], 
            Times[ 0.085044480344421608, 
              c[ 8][ t]], 
            Times[ 0.10436044624225685, 
              c[ 9][ t]], 
            Times[ 0.11814190616181253, 
              c[ 10][ t]], 
            Times[ 0.12613778810677612, 
              c[ 11][ t]], 
            Times[ 0.12833762891430928, 
              c[ 12][ t]], 
            Times[ 0.12496032289024853, 
              c[ 13][ t]], 
            Times[ 0.11643488132933186, 
              c[ 14][ t]], 
            Times[ 0.10337416789158609, 
              c[ 15][ t]], 
            Times[ 0.086542809078944891, 
              c[ 16][ t]], 
            Times[ 0.066820663127759972, 
              c[ 17][ t]], 
            Times[ 0.045163358568919301, 
              c[ 18][ t]], 
            Times[ 0.022561481809254869, 
              c[ 19][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 20][ t]], 
            Times[ -0.021580547817547879, 
              c[ 21][ t]], 
            Times[ -0.04131966847794722, 
              c[ 22][ t]], 
            Times[ -0.058468080236789913, 
              c[ 23][ t]], 
            Times[ -0.072413370861974122, 
              c[ 24][ t]], 
            Times[ -0.082699334313268744, 
              c[ 25][ t]], 
            Times[ -0.089038438663606695, 
              c[ 26][ t]], 
            Times[ -0.091317159035181589, 
              c[ 27][ t]], 
            Times[ -0.089594193770366884, 
              c[ 28][ t]], 
            Times[ -0.084091858737850814, 
              c[ 29][ t]], 
            Times[ -0.075181213012062598, 
              c[ 30][ t]], 
            Times[ -0.063361699504227528, 
              c[ 31][ t]], 
            Times[ -0.049236278094138941, 
              c[ 32][ t]], 
            Times[ -0.033483179628681567, 
              c[ 33][ t]], 
            Times[ -0.016825511857749401, 
              c[ 34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ 0.016273855731265604, 
              c[ 36][ t]], 
            Times[ 0.031322974491347078, 
              c[ 37][ t]], 
            Times[ 0.044547108751839919, 
              c[ 38][ t]], 
            Times[ 0.055441487066198933, 
              c[ 39][ t]], 
            Times[ 0.063614872548668253, 
              c[ 40][ t]], 
            Times[ 0.068802429876423321, 
              c[ 41][ t]], 
            Times[ 0.070873018952678238, 
              c[ 42][ t]], 
            Times[ 0.069830768673962415, 
              c[ 43][ t]], 
            Times[ 0.065811019881796315, 
              c[ 44][ t]], 
            Times[ 0.059070953080906326, 
              c[ 45][ t]], 
            Times[ 0.049975424961080865, 
              c[ 46][ t]], 
            Times[ 0.038978720157860088, 
              c[ 47][ t]], 
            Times[ 0.026603074225527826, 
              c[ 48][ t]], 
            Times[ 0.013414935129827233, 
              c[ 49][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 50][ t]], 
            Times[ -0.013061910521147383, 
              c[ 51][ t]], 
            Times[ -0.025221096343682053, 
              c[ 52][ t]], 
            Times[ -0.035980357068793781, 
              c[ 53][ t]], 
            Times[ -0.044914622433376419, 
              c[ 54][ t]], 
            Times[ -0.05168708394579296, 
              c[ 55][ t]], 
            Times[ -0.05606123915856713, 
              c[ 56][ t]], 
            Times[ -0.057908442314993203, 
              c[ 57][ t]], 
            Times[ -0.057210750238908967, 
              c[ 58][ t]], 
            Times[ -0.054059052045761224, 
              c[ 59][ t]], 
            Times[ -0.048646667243099281, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-24\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-24\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12613778810677614`\ \(c[\(-60\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-59\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-58\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-57\)]\)[t] + 
            0.060688263076985`\ \(c[\(-56\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-55\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-53\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-52\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-51\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-50\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-49\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-48\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-47\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-46\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-45\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-44\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-43\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-42\)]\)[t] - 
            0.11423673049785416`\ \(c[\(-41\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-38\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-37\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-36\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-35\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-34\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-33\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-32\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-31\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-30\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-29\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-28\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-27\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-26\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-25\)]\)[t] + 
            13.633093633394378`\ \(c[\(-24\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-23\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-22\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-21\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-20\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-19\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-18\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-17\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-16\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-15\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-14\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-13\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-12\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-11\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-10\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-8\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-7\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-6\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-5\)]\)[t] - 
            0.206748335783172`\ \(c[\(-4\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-3\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-2\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-1\)]\)[t] - 
            0.18920668216016426`\ \(c[0]\)[t] - 
            0.1653986686265376`\ \(c[1]\)[t] - 
            0.13647135277833605`\ \(c[2]\)[t] - 
            0.10394325375429328`\ \(c[3]\)[t] - 
            0.06935801494512592`\ \(c[4]\)[t] - 
            0.03423121377955895`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.032022748374425904`\ \(c[7]\)[t] + 
            0.060688263076985105`\ \(c[8]\)[t] + 
            0.0850444803444217`\ \(c[9]\)[t] + 
            0.10436044624225685`\ \(c[10]\)[t] + 
            0.11814190616181255`\ \(c[11]\)[t] + 
            0.12613778810677614`\ \(c[12]\)[t] + 
            0.12833762891430928`\ \(c[13]\)[t] + 
            0.12496032289024853`\ \(c[14]\)[t] + 
            0.11643488132933186`\ \(c[15]\)[t] + 
            0.10337416789158609`\ \(c[16]\)[t] + 
            0.08654280907894489`\ \(c[17]\)[t] + 
            0.06682066312775997`\ \(c[18]\)[t] + 
            0.0451633585689193`\ \(c[19]\)[t] + 
            0.02256148180925487`\ \(c[20]\)[t] + 
            3.8981718325193755`*^-17\ \(c[21]\)[t] - 
            0.02158054781754788`\ \(c[22]\)[t] - 
            0.04131966847794722`\ \(c[23]\)[t] - 
            0.05846808023678991`\ \(c[24]\)[t] - 
            0.07241337086197412`\ \(c[25]\)[t] - 
            0.08269933431326874`\ \(c[26]\)[t] - 
            0.0890384386636067`\ \(c[27]\)[t] - 
            0.09131715903518159`\ \(c[28]\)[t] - 
            0.08959419377036688`\ \(c[29]\)[t] - 
            0.08409185873785081`\ \(c[30]\)[t] - 
            0.0751812130120626`\ \(c[31]\)[t] - 
            0.06336169950422753`\ \(c[32]\)[t] - 
            0.04923627809413894`\ \(c[33]\)[t] - 
            0.03348317962868157`\ \(c[34]\)[t] - 
            0.0168255118577494`\ \(c[35]\)[t] - 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.016273855731265604`\ \(c[37]\)[t] + 
            0.03132297449134708`\ \(c[38]\)[t] + 
            0.04454710875183992`\ \(c[39]\)[t] + 
            0.05544148706619893`\ \(c[40]\)[t] + 
            0.06361487254866825`\ \(c[41]\)[t] + 
            0.06880242987642335`\ \(c[42]\)[t] + 
            0.07087301895267824`\ \(c[43]\)[t] + 
            0.06983076867396242`\ \(c[44]\)[t] + 
            0.06581101988179627`\ \(c[45]\)[t] + 
            0.059070953080906326`\ \(c[46]\)[t] + 
            0.049975424961080865`\ \(c[47]\)[t] + 
            0.03897872015785999`\ \(c[48]\)[t] + 
            0.026603074225527826`\ \(c[49]\)[t] + 
            0.013414935129827233`\ \(c[50]\)[t] + 
            3.898171832519376`*^-17\ \(c[51]\)[t] - 
            0.013061910521147383`\ \(c[52]\)[t] - 
            0.025221096343682053`\ \(c[53]\)[t] - 
            0.03598035706879378`\ \(c[54]\)[t] - 
            0.04491462243337642`\ \(c[55]\)[t] - 
            0.05168708394579296`\ \(c[56]\)[t] - 
            0.056061239158567186`\ \(c[57]\)[t] - 
            0.0579084423149932`\ \(c[58]\)[t] - 
            0.05721075023890897`\ \(c[59]\)[t] - 
            0.054059052045761224`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -24, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -24]][ t]], 
          Plus[ 
            Times[ 0.12613778810677614, 
              c[ -60][ t]], 
            Times[ 0.11814190616181253, 
              c[ -59][ t]], 
            Times[ 0.10436044624225685, 
              c[ -58][ t]], 
            Times[ 0.085044480344421705, 
              c[ -57][ t]], 
            Times[ 0.060688263076985001, 
              c[ -56][ t]], 
            Times[ 0.032022748374425904, 
              c[ -55][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ -0.034231213779559094, 
              c[ -53][ t]], 
            Times[ -0.06935801494512607, 
              c[ -52][ t]], 
            Times[ -0.10394325375429328, 
              c[ -51][ t]], 
            Times[ -0.13647135277833616, 
              c[ -50][ t]], 
            Times[ -0.16539866862653771, 
              c[ -49][ t]], 
            Times[ -0.18920668216016426, 
              c[ -48][ t]], 
            Times[ -0.20645618564475848, 
              c[ -47][ t]], 
            Times[ -0.21584055771952015, 
              c[ -46][ t]], 
            Times[ -0.21623620818304484, 
              c[ -45][ t]], 
            Times[ -0.20674833578317189, 
              c[ -44][ t]], 
            Times[ -0.18675027222298593, 
              c[ -43][ t]], 
            Times[ -0.15591488063143982, 
              c[ -42][ t]], 
            Times[ -0.11423673049785416, 
              c[ -41][ t]], 
            Times[ -0.062044074975450239, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ 0.070907514257657775, 
              c[ -38][ t]], 
            Times[ 0.14938649372796384, 
              c[ -37][ t]], 
            Times[ 0.23387232094715985, 
              c[ -36][ t]], 
            Times[ 0.32256865202152157, 
              c[ -35][ t]], 
            Times[ 0.41349667156634429, 
              c[ -34][ t]], 
            Times[ 0.50455115242710469, 
              c[ -33][ t]], 
            Times[ 0.59356153372868059, 
              c[ -32][ t]], 
            Times[ 0.67835603854706361, 
              c[ -31][ t]], 
            Times[ 0.75682672864065692, 
              c[ -30][ t]], 
            Times[ 0.82699334313268813, 
              c[ -29][ t]], 
            Times[ 0.88706379305918392, 
              c[ -28][ t]], 
            Times[ 0.93548928378863916, 
              c[ -27][ t]], 
            Times[ 0.9710122092317629, 
              c[ -26][ t]], 
            Times[ 0.99270519960720693, 
              c[ -25][ t]], 
            Times[ 13.633093633394378, 
              c[ -24][ t]], 
            Times[ 0.99270519960720671, 
              c[ -23][ t]], 
            Times[ 0.9710122092317629, 
              c[ -22][ t]], 
            Times[ 0.93548928378863916, 
              c[ -21][ t]], 
            Times[ 0.88706379305918381, 
              c[ -20][ t]], 
            Times[ 0.82699334313268813, 
              c[ -19][ t]], 
            Times[ 0.75682672864065692, 
              c[ -18][ t]], 
            Times[ 0.67835603854706317, 
              c[ -17][ t]], 
            Times[ 0.59356153372868026, 
              c[ -16][ t]], 
            Times[ 0.50455115242710469, 
              c[ -15][ t]], 
            Times[ 0.41349667156634395, 
              c[ -14][ t]], 
            Times[ 0.32256865202152135, 
              c[ -13][ t]], 
            Times[ 0.23387232094715985, 
              c[ -12][ t]], 
            Times[ 0.14938649372796345, 
              c[ -11][ t]], 
            Times[ 0.070907514257657622, 
              c[ -10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.062044074975450475, 
              c[ -8][ t]], 
            Times[ -0.11423673049785445, 
              c[ -7][ t]], 
            Times[ -0.15591488063143982, 
              c[ -6][ t]], 
            Times[ -0.18675027222298607, 
              c[ -5][ t]], 
            Times[ -0.206748335783172, 
              c[ -4][ t]], 
            Times[ -0.21623620818304484, 
              c[ -3][ t]], 
            Times[ -0.21584055771952013, 
              c[ -2][ t]], 
            Times[ -0.20645618564475843, 
              c[ -1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 0][ t]], 
            Times[ -0.1653986686265376, 
              c[ 1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 2][ t]], 
            Times[ -0.10394325375429328, 
              c[ 3][ t]], 
            Times[ -0.069358014945125918, 
              c[ 4][ t]], 
            Times[ -0.034231213779558949, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.032022748374425904, 
              c[ 7][ t]], 
            Times[ 0.060688263076985105, 
              c[ 8][ t]], 
            Times[ 0.085044480344421705, 
              c[ 9][ t]], 
            Times[ 0.10436044624225685, 
              c[ 10][ t]], 
            Times[ 0.11814190616181255, 
              c[ 11][ t]], 
            Times[ 0.12613778810677614, 
              c[ 12][ t]], 
            Times[ 0.12833762891430928, 
              c[ 13][ t]], 
            Times[ 0.12496032289024853, 
              c[ 14][ t]], 
            Times[ 0.11643488132933186, 
              c[ 15][ t]], 
            Times[ 0.10337416789158609, 
              c[ 16][ t]], 
            Times[ 0.086542809078944891, 
              c[ 17][ t]], 
            Times[ 0.066820663127759972, 
              c[ 18][ t]], 
            Times[ 0.045163358568919301, 
              c[ 19][ t]], 
            Times[ 0.022561481809254869, 
              c[ 20][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 21][ t]], 
            Times[ -0.021580547817547879, 
              c[ 22][ t]], 
            Times[ -0.04131966847794722, 
              c[ 23][ t]], 
            Times[ -0.058468080236789913, 
              c[ 24][ t]], 
            Times[ -0.072413370861974122, 
              c[ 25][ t]], 
            Times[ -0.082699334313268744, 
              c[ 26][ t]], 
            Times[ -0.089038438663606695, 
              c[ 27][ t]], 
            Times[ -0.091317159035181589, 
              c[ 28][ t]], 
            Times[ -0.089594193770366884, 
              c[ 29][ t]], 
            Times[ -0.084091858737850814, 
              c[ 30][ t]], 
            Times[ -0.075181213012062598, 
              c[ 31][ t]], 
            Times[ -0.063361699504227528, 
              c[ 32][ t]], 
            Times[ -0.049236278094138941, 
              c[ 33][ t]], 
            Times[ -0.033483179628681567, 
              c[ 34][ t]], 
            Times[ -0.016825511857749401, 
              c[ 35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.016273855731265604, 
              c[ 37][ t]], 
            Times[ 0.031322974491347078, 
              c[ 38][ t]], 
            Times[ 0.044547108751839919, 
              c[ 39][ t]], 
            Times[ 0.055441487066198933, 
              c[ 40][ t]], 
            Times[ 0.063614872548668253, 
              c[ 41][ t]], 
            Times[ 0.068802429876423349, 
              c[ 42][ t]], 
            Times[ 0.070873018952678238, 
              c[ 43][ t]], 
            Times[ 0.069830768673962415, 
              c[ 44][ t]], 
            Times[ 0.065811019881796273, 
              c[ 45][ t]], 
            Times[ 0.059070953080906326, 
              c[ 46][ t]], 
            Times[ 0.049975424961080865, 
              c[ 47][ t]], 
            Times[ 0.03897872015785999, 
              c[ 48][ t]], 
            Times[ 0.026603074225527826, 
              c[ 49][ t]], 
            Times[ 0.013414935129827233, 
              c[ 50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ -0.013061910521147383, 
              c[ 52][ t]], 
            Times[ -0.025221096343682053, 
              c[ 53][ t]], 
            Times[ -0.035980357068793781, 
              c[ 54][ t]], 
            Times[ -0.044914622433376419, 
              c[ 55][ t]], 
            Times[ -0.05168708394579296, 
              c[ 56][ t]], 
            Times[ -0.056061239158567186, 
              c[ 57][ t]], 
            Times[ -0.057908442314993203, 
              c[ 58][ t]], 
            Times[ -0.057210750238908967, 
              c[ 59][ t]], 
            Times[ -0.054059052045761224, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-23\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-23\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12833762891430925`\ \(c[\(-60\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-59\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-58\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-57\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-56\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-55\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-54\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-53\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-52\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-51\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-50\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-49\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-48\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-47\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-46\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-45\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-44\)]\)[t] - 
            0.206748335783172`\ \(c[\(-43\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-42\)]\)[t] - 
            0.15591488063143966`\ \(c[\(-41\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-40\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-39\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-37\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-36\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-35\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-34\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-33\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-32\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-31\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-30\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-29\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-28\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-27\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-26\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-25\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-24\)]\)[t] + 
            12.602268284836155`\ \(c[\(-23\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-22\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-21\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-20\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-19\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-18\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-17\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-16\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-15\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-14\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-13\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-12\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-11\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-10\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-9\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-7\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-6\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-5\)]\)[t] - 
            0.186750272222986`\ \(c[\(-4\)]\)[t] - 
            0.206748335783172`\ \(c[\(-3\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-2\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-1\)]\)[t] - 
            0.20645618564475843`\ \(c[0]\)[t] - 
            0.18920668216016426`\ \(c[1]\)[t] - 
            0.1653986686265377`\ \(c[2]\)[t] - 
            0.13647135277833605`\ \(c[3]\)[t] - 
            0.10394325375429328`\ \(c[4]\)[t] - 
            0.06935801494512607`\ \(c[5]\)[t] - 
            0.03423121377955895`\ \(c[6]\)[t] - 
            3.898171832519376`*^-17\ \(c[7]\)[t] + 
            0.032022748374425904`\ \(c[8]\)[t] + 
            0.060688263076985105`\ \(c[9]\)[t] + 
            0.0850444803444217`\ \(c[10]\)[t] + 
            0.10436044624225685`\ \(c[11]\)[t] + 
            0.11814190616181255`\ \(c[12]\)[t] + 
            0.12613778810677614`\ \(c[13]\)[t] + 
            0.12833762891430928`\ \(c[14]\)[t] + 
            0.12496032289024853`\ \(c[15]\)[t] + 
            0.11643488132933186`\ \(c[16]\)[t] + 
            0.10337416789158609`\ \(c[17]\)[t] + 
            0.08654280907894489`\ \(c[18]\)[t] + 
            0.06682066312775997`\ \(c[19]\)[t] + 
            0.0451633585689193`\ \(c[20]\)[t] + 
            0.02256148180925487`\ \(c[21]\)[t] + 
            3.8981718325193755`*^-17\ \(c[22]\)[t] - 
            0.02158054781754788`\ \(c[23]\)[t] - 
            0.04131966847794722`\ \(c[24]\)[t] - 
            0.05846808023678991`\ \(c[25]\)[t] - 
            0.07241337086197412`\ \(c[26]\)[t] - 
            0.08269933431326874`\ \(c[27]\)[t] - 
            0.0890384386636067`\ \(c[28]\)[t] - 
            0.09131715903518159`\ \(c[29]\)[t] - 
            0.08959419377036688`\ \(c[30]\)[t] - 
            0.08409185873785081`\ \(c[31]\)[t] - 
            0.0751812130120626`\ \(c[32]\)[t] - 
            0.06336169950422753`\ \(c[33]\)[t] - 
            0.04923627809413894`\ \(c[34]\)[t] - 
            0.03348317962868157`\ \(c[35]\)[t] - 
            0.0168255118577494`\ \(c[36]\)[t] - 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.016273855731265604`\ \(c[38]\)[t] + 
            0.03132297449134708`\ \(c[39]\)[t] + 
            0.04454710875183992`\ \(c[40]\)[t] + 
            0.055441487066198857`\ \(c[41]\)[t] + 
            0.06361487254866825`\ \(c[42]\)[t] + 
            0.06880242987642335`\ \(c[43]\)[t] + 
            0.07087301895267824`\ \(c[44]\)[t] + 
            0.06983076867396242`\ \(c[45]\)[t] + 
            0.06581101988179627`\ \(c[46]\)[t] + 
            0.0590709530809064`\ \(c[47]\)[t] + 
            0.049975424961080865`\ \(c[48]\)[t] + 
            0.03897872015785999`\ \(c[49]\)[t] + 
            0.026603074225527937`\ \(c[50]\)[t] + 
            0.013414935129827233`\ \(c[51]\)[t] + 
            3.898171832519376`*^-17\ \(c[52]\)[t] - 
            0.013061910521147276`\ \(c[53]\)[t] - 
            0.025221096343682053`\ \(c[54]\)[t] - 
            0.03598035706879378`\ \(c[55]\)[t] - 
            0.04491462243337629`\ \(c[56]\)[t] - 
            0.05168708394579296`\ \(c[57]\)[t] - 
            0.056061239158567186`\ \(c[58]\)[t] - 
            0.0579084423149932`\ \(c[59]\)[t] - 
            0.05721075023890897`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -23, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -23]][ t]], 
          Plus[ 
            Times[ 0.12833762891430925, 
              c[ -60][ t]], 
            Times[ 0.12613778810677612, 
              c[ -59][ t]], 
            Times[ 0.11814190616181255, 
              c[ -58][ t]], 
            Times[ 0.10436044624225692, 
              c[ -57][ t]], 
            Times[ 0.085044480344421608, 
              c[ -56][ t]], 
            Times[ 0.060688263076985105, 
              c[ -55][ t]], 
            Times[ 0.032022748374426029, 
              c[ -54][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -53][ t]], 
            Times[ -0.034231213779558949, 
              c[ -52][ t]], 
            Times[ -0.069358014945125918, 
              c[ -51][ t]], 
            Times[ -0.1039432537542934, 
              c[ -50][ t]], 
            Times[ -0.13647135277833605, 
              c[ -49][ t]], 
            Times[ -0.1653986686265376, 
              c[ -48][ t]], 
            Times[ -0.18920668216016434, 
              c[ -47][ t]], 
            Times[ -0.20645618564475843, 
              c[ -46][ t]], 
            Times[ -0.21584055771952013, 
              c[ -45][ t]], 
            Times[ -0.21623620818304481, 
              c[ -44][ t]], 
            Times[ -0.206748335783172, 
              c[ -43][ t]], 
            Times[ -0.18675027222298607, 
              c[ -42][ t]], 
            Times[ -0.15591488063143966, 
              c[ -41][ t]], 
            Times[ -0.11423673049785436, 
              c[ -40][ t]], 
            Times[ -0.062044074975450475, 
              c[ -39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ 0.070907514257657775, 
              c[ -37][ t]], 
            Times[ 0.14938649372796345, 
              c[ -36][ t]], 
            Times[ 0.23387232094715985, 
              c[ -35][ t]], 
            Times[ 0.32256865202152157, 
              c[ -34][ t]], 
            Times[ 0.41349667156634395, 
              c[ -33][ t]], 
            Times[ 0.50455115242710469, 
              c[ -32][ t]], 
            Times[ 0.59356153372868059, 
              c[ -31][ t]], 
            Times[ 0.67835603854706317, 
              c[ -30][ t]], 
            Times[ 0.75682672864065692, 
              c[ -29][ t]], 
            Times[ 0.82699334313268813, 
              c[ -28][ t]], 
            Times[ 0.88706379305918381, 
              c[ -27][ t]], 
            Times[ 0.93548928378863916, 
              c[ -26][ t]], 
            Times[ 0.9710122092317629, 
              c[ -25][ t]], 
            Times[ 0.99270519960720671, 
              c[ -24][ t]], 
            Times[ 12.602268284836155, 
              c[ -23][ t]], 
            Times[ 0.99270519960720671, 
              c[ -22][ t]], 
            Times[ 0.9710122092317629, 
              c[ -21][ t]], 
            Times[ 0.93548928378863916, 
              c[ -20][ t]], 
            Times[ 0.88706379305918381, 
              c[ -19][ t]], 
            Times[ 0.82699334313268813, 
              c[ -18][ t]], 
            Times[ 0.75682672864065692, 
              c[ -17][ t]], 
            Times[ 0.67835603854706339, 
              c[ -16][ t]], 
            Times[ 0.59356153372868059, 
              c[ -15][ t]], 
            Times[ 0.50455115242710469, 
              c[ -14][ t]], 
            Times[ 0.41349667156634418, 
              c[ -13][ t]], 
            Times[ 0.32256865202152157, 
              c[ -12][ t]], 
            Times[ 0.23387232094715985, 
              c[ -11][ t]], 
            Times[ 0.14938649372796362, 
              c[ -10][ t]], 
            Times[ 0.070907514257657775, 
              c[ -9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ -0.062044074975450343, 
              c[ -7][ t]], 
            Times[ -0.11423673049785436, 
              c[ -6][ t]], 
            Times[ -0.15591488063143982, 
              c[ -5][ t]], 
            Times[ -0.18675027222298601, 
              c[ -4][ t]], 
            Times[ -0.206748335783172, 
              c[ -3][ t]], 
            Times[ -0.21623620818304484, 
              c[ -2][ t]], 
            Times[ -0.21584055771952015, 
              c[ -1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 0][ t]], 
            Times[ -0.18920668216016426, 
              c[ 1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 2][ t]], 
            Times[ -0.13647135277833605, 
              c[ 3][ t]], 
            Times[ -0.10394325375429328, 
              c[ 4][ t]], 
            Times[ -0.06935801494512607, 
              c[ 5][ t]], 
            Times[ -0.034231213779558949, 
              c[ 6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ 0.032022748374425904, 
              c[ 8][ t]], 
            Times[ 0.060688263076985105, 
              c[ 9][ t]], 
            Times[ 0.085044480344421705, 
              c[ 10][ t]], 
            Times[ 0.10436044624225685, 
              c[ 11][ t]], 
            Times[ 0.11814190616181255, 
              c[ 12][ t]], 
            Times[ 0.12613778810677614, 
              c[ 13][ t]], 
            Times[ 0.12833762891430928, 
              c[ 14][ t]], 
            Times[ 0.12496032289024853, 
              c[ 15][ t]], 
            Times[ 0.11643488132933186, 
              c[ 16][ t]], 
            Times[ 0.10337416789158609, 
              c[ 17][ t]], 
            Times[ 0.086542809078944891, 
              c[ 18][ t]], 
            Times[ 0.066820663127759972, 
              c[ 19][ t]], 
            Times[ 0.045163358568919301, 
              c[ 20][ t]], 
            Times[ 0.022561481809254869, 
              c[ 21][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 22][ t]], 
            Times[ -0.021580547817547879, 
              c[ 23][ t]], 
            Times[ -0.04131966847794722, 
              c[ 24][ t]], 
            Times[ -0.058468080236789913, 
              c[ 25][ t]], 
            Times[ -0.072413370861974122, 
              c[ 26][ t]], 
            Times[ -0.082699334313268744, 
              c[ 27][ t]], 
            Times[ -0.089038438663606695, 
              c[ 28][ t]], 
            Times[ -0.091317159035181589, 
              c[ 29][ t]], 
            Times[ -0.089594193770366884, 
              c[ 30][ t]], 
            Times[ -0.084091858737850814, 
              c[ 31][ t]], 
            Times[ -0.075181213012062598, 
              c[ 32][ t]], 
            Times[ -0.063361699504227528, 
              c[ 33][ t]], 
            Times[ -0.049236278094138941, 
              c[ 34][ t]], 
            Times[ -0.033483179628681567, 
              c[ 35][ t]], 
            Times[ -0.016825511857749401, 
              c[ 36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.016273855731265604, 
              c[ 38][ t]], 
            Times[ 0.031322974491347078, 
              c[ 39][ t]], 
            Times[ 0.044547108751839919, 
              c[ 40][ t]], 
            Times[ 0.055441487066198857, 
              c[ 41][ t]], 
            Times[ 0.063614872548668253, 
              c[ 42][ t]], 
            Times[ 0.068802429876423349, 
              c[ 43][ t]], 
            Times[ 0.070873018952678238, 
              c[ 44][ t]], 
            Times[ 0.069830768673962415, 
              c[ 45][ t]], 
            Times[ 0.065811019881796273, 
              c[ 46][ t]], 
            Times[ 0.059070953080906402, 
              c[ 47][ t]], 
            Times[ 0.049975424961080865, 
              c[ 48][ t]], 
            Times[ 0.03897872015785999, 
              c[ 49][ t]], 
            Times[ 0.026603074225527937, 
              c[ 50][ t]], 
            Times[ 0.013414935129827233, 
              c[ 51][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ -0.013061910521147276, 
              c[ 53][ t]], 
            Times[ -0.025221096343682053, 
              c[ 54][ t]], 
            Times[ -0.035980357068793781, 
              c[ 55][ t]], 
            Times[ -0.044914622433376288, 
              c[ 56][ t]], 
            Times[ -0.05168708394579296, 
              c[ 57][ t]], 
            Times[ -0.056061239158567186, 
              c[ 58][ t]], 
            Times[ -0.057908442314993203, 
              c[ 59][ t]], 
            Times[ -0.057210750238908967, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-22\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-22\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.12496032289024847`\ \(c[\(-60\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-59\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-58\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-57\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-56\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-55\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-54\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-53\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-51\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-50\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-49\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-48\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-47\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-46\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-45\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-44\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-43\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-42\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-41\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-40\)]\)[t] - 
            0.11423673049785459`\ \(c[\(-39\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] + 
            0.07090751425765746`\ \(c[\(-36\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-35\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-34\)]\)[t] + 
            0.32256865202152113`\ \(c[\(-33\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-32\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-31\)]\)[t] + 
            0.5935615337286801`\ \(c[\(-30\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-29\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-28\)]\)[t] + 
            0.826993343132688`\ \(c[\(-27\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-26\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-25\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-24\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-23\)]\)[t] + 
            11.615307844727218`\ \(c[\(-22\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-21\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-20\)]\)[t] + 
            0.9354892837886394`\ \(c[\(-19\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-18\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-17\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-16\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-15\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-14\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-13\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-12\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-11\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-10\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-9\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-8\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-7\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-6\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-5\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-4\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-3\)]\)[t] - 
            0.206748335783172`\ \(c[\(-2\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-1\)]\)[t] - 
            0.21584055771952015`\ \(c[0]\)[t] - 
            0.20645618564475843`\ \(c[1]\)[t] - 
            0.18920668216016434`\ \(c[2]\)[t] - 
            0.1653986686265377`\ \(c[3]\)[t] - 
            0.13647135277833605`\ \(c[4]\)[t] - 
            0.1039432537542934`\ \(c[5]\)[t] - 
            0.06935801494512607`\ \(c[6]\)[t] - 
            0.034231213779559094`\ \(c[7]\)[t] - 
            1.8033970416801674`*^-16\ \(c[8]\)[t] + 
            0.032022748374425904`\ \(c[9]\)[t] + 
            0.060688263076985`\ \(c[10]\)[t] + 
            0.08504448034442161`\ \(c[11]\)[t] + 
            0.10436044624225685`\ \(c[12]\)[t] + 
            0.11814190616181253`\ \(c[13]\)[t] + 
            0.12613778810677612`\ \(c[14]\)[t] + 
            0.12833762891430928`\ \(c[15]\)[t] + 
            0.12496032289024853`\ \(c[16]\)[t] + 
            0.11643488132933186`\ \(c[17]\)[t] + 
            0.10337416789158609`\ \(c[18]\)[t] + 
            0.08654280907894489`\ \(c[19]\)[t] + 
            0.06682066312775997`\ \(c[20]\)[t] + 
            0.0451633585689193`\ \(c[21]\)[t] + 
            0.02256148180925487`\ \(c[22]\)[t] + 
            3.8981718325193755`*^-17\ \(c[23]\)[t] - 
            0.02158054781754788`\ \(c[24]\)[t] - 
            0.04131966847794722`\ \(c[25]\)[t] - 
            0.05846808023678991`\ \(c[26]\)[t] - 
            0.07241337086197412`\ \(c[27]\)[t] - 
            0.08269933431326874`\ \(c[28]\)[t] - 
            0.0890384386636067`\ \(c[29]\)[t] - 
            0.09131715903518159`\ \(c[30]\)[t] - 
            0.08959419377036688`\ \(c[31]\)[t] - 
            0.08409185873785081`\ \(c[32]\)[t] - 
            0.0751812130120626`\ \(c[33]\)[t] - 
            0.06336169950422753`\ \(c[34]\)[t] - 
            0.04923627809413894`\ \(c[35]\)[t] - 
            0.03348317962868157`\ \(c[36]\)[t] - 
            0.0168255118577494`\ \(c[37]\)[t] - 
            3.898171832519376`*^-17\ \(c[38]\)[t] + 
            0.016273855731265604`\ \(c[39]\)[t] + 
            0.03132297449134708`\ \(c[40]\)[t] + 
            0.044547108751839815`\ \(c[41]\)[t] + 
            0.05544148706619893`\ \(c[42]\)[t] + 
            0.06361487254866825`\ \(c[43]\)[t] + 
            0.06880242987642332`\ \(c[44]\)[t] + 
            0.07087301895267824`\ \(c[45]\)[t] + 
            0.06983076867396242`\ \(c[46]\)[t] + 
            0.06581101988179631`\ \(c[47]\)[t] + 
            0.059070953080906326`\ \(c[48]\)[t] + 
            0.049975424961080865`\ \(c[49]\)[t] + 
            0.03897872015786009`\ \(c[50]\)[t] + 
            0.026603074225527826`\ \(c[51]\)[t] + 
            0.013414935129827233`\ \(c[52]\)[t] + 
            1.5206810699945212`*^-16\ \(c[53]\)[t] - 
            0.013061910521147383`\ \(c[54]\)[t] - 
            0.025221096343682053`\ \(c[55]\)[t] - 
            0.03598035706879378`\ \(c[56]\)[t] - 
            0.04491462243337642`\ \(c[57]\)[t] - 
            0.05168708394579296`\ \(c[58]\)[t] - 
            0.05606123915856713`\ \(c[59]\)[t] - 
            0.0579084423149932`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -22, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -22]][ t]], 
          Plus[ 
            Times[ 0.12496032289024847, 
              c[ -60][ t]], 
            Times[ 0.12833762891430928, 
              c[ -59][ t]], 
            Times[ 0.12613778810677614, 
              c[ -58][ t]], 
            Times[ 0.1181419061618126, 
              c[ -57][ t]], 
            Times[ 0.10436044624225685, 
              c[ -56][ t]], 
            Times[ 0.085044480344421705, 
              c[ -55][ t]], 
            Times[ 0.060688263076985223, 
              c[ -54][ t]], 
            Times[ 0.032022748374425904, 
              c[ -53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ -0.034231213779558796, 
              c[ -51][ t]], 
            Times[ -0.06935801494512607, 
              c[ -50][ t]], 
            Times[ -0.10394325375429328, 
              c[ -49][ t]], 
            Times[ -0.13647135277833591, 
              c[ -48][ t]], 
            Times[ -0.16539866862653771, 
              c[ -47][ t]], 
            Times[ -0.18920668216016426, 
              c[ -46][ t]], 
            Times[ -0.20645618564475834, 
              c[ -45][ t]], 
            Times[ -0.21584055771952015, 
              c[ -44][ t]], 
            Times[ -0.21623620818304484, 
              c[ -43][ t]], 
            Times[ -0.20674833578317206, 
              c[ -42][ t]], 
            Times[ -0.18675027222298593, 
              c[ -41][ t]], 
            Times[ -0.15591488063143982, 
              c[ -40][ t]], 
            Times[ -0.11423673049785459, 
              c[ -39][ t]], 
            Times[ -0.062044074975450475, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ 0.070907514257657456, 
              c[ -36][ t]], 
            Times[ 0.14938649372796345, 
              c[ -35][ t]], 
            Times[ 0.23387232094715985, 
              c[ -34][ t]], 
            Times[ 0.32256865202152113, 
              c[ -33][ t]], 
            Times[ 0.41349667156634395, 
              c[ -32][ t]], 
            Times[ 0.50455115242710469, 
              c[ -31][ t]], 
            Times[ 0.59356153372868015, 
              c[ -30][ t]], 
            Times[ 0.67835603854706317, 
              c[ -29][ t]], 
            Times[ 0.75682672864065692, 
              c[ -28][ t]], 
            Times[ 0.82699334313268802, 
              c[ -27][ t]], 
            Times[ 0.88706379305918381, 
              c[ -26][ t]], 
            Times[ 0.93548928378863916, 
              c[ -25][ t]], 
            Times[ 0.9710122092317629, 
              c[ -24][ t]], 
            Times[ 0.99270519960720671, 
              c[ -23][ t]], 
            Times[ 11.615307844727218, 
              c[ -22][ t]], 
            Times[ 0.99270519960720693, 
              c[ -21][ t]], 
            Times[ 0.9710122092317629, 
              c[ -20][ t]], 
            Times[ 0.93548928378863938, 
              c[ -19][ t]], 
            Times[ 0.88706379305918392, 
              c[ -18][ t]], 
            Times[ 0.82699334313268813, 
              c[ -17][ t]], 
            Times[ 0.75682672864065714, 
              c[ -16][ t]], 
            Times[ 0.67835603854706361, 
              c[ -15][ t]], 
            Times[ 0.59356153372868059, 
              c[ -14][ t]], 
            Times[ 0.50455115242710491, 
              c[ -13][ t]], 
            Times[ 0.41349667156634429, 
              c[ -12][ t]], 
            Times[ 0.32256865202152157, 
              c[ -11][ t]], 
            Times[ 0.23387232094715998, 
              c[ -10][ t]], 
            Times[ 0.14938649372796384, 
              c[ -9][ t]], 
            Times[ 0.070907514257657775, 
              c[ -8][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -7][ t]], 
            Times[ -0.062044074975450239, 
              c[ -6][ t]], 
            Times[ -0.11423673049785436, 
              c[ -5][ t]], 
            Times[ -0.15591488063143974, 
              c[ -4][ t]], 
            Times[ -0.18675027222298593, 
              c[ -3][ t]], 
            Times[ -0.206748335783172, 
              c[ -2][ t]], 
            Times[ -0.21623620818304481, 
              c[ -1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 0][ t]], 
            Times[ -0.20645618564475843, 
              c[ 1][ t]], 
            Times[ -0.18920668216016434, 
              c[ 2][ t]], 
            Times[ -0.16539866862653771, 
              c[ 3][ t]], 
            Times[ -0.13647135277833605, 
              c[ 4][ t]], 
            Times[ -0.1039432537542934, 
              c[ 5][ t]], 
            Times[ -0.06935801494512607, 
              c[ 6][ t]], 
            Times[ -0.034231213779559094, 
              c[ 7][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 8][ t]], 
            Times[ 0.032022748374425904, 
              c[ 9][ t]], 
            Times[ 0.060688263076985001, 
              c[ 10][ t]], 
            Times[ 0.085044480344421608, 
              c[ 11][ t]], 
            Times[ 0.10436044624225685, 
              c[ 12][ t]], 
            Times[ 0.11814190616181253, 
              c[ 13][ t]], 
            Times[ 0.12613778810677612, 
              c[ 14][ t]], 
            Times[ 0.12833762891430928, 
              c[ 15][ t]], 
            Times[ 0.12496032289024853, 
              c[ 16][ t]], 
            Times[ 0.11643488132933186, 
              c[ 17][ t]], 
            Times[ 0.10337416789158609, 
              c[ 18][ t]], 
            Times[ 0.086542809078944891, 
              c[ 19][ t]], 
            Times[ 0.066820663127759972, 
              c[ 20][ t]], 
            Times[ 0.045163358568919301, 
              c[ 21][ t]], 
            Times[ 0.022561481809254869, 
              c[ 22][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 23][ t]], 
            Times[ -0.021580547817547879, 
              c[ 24][ t]], 
            Times[ -0.04131966847794722, 
              c[ 25][ t]], 
            Times[ -0.058468080236789913, 
              c[ 26][ t]], 
            Times[ -0.072413370861974122, 
              c[ 27][ t]], 
            Times[ -0.082699334313268744, 
              c[ 28][ t]], 
            Times[ -0.089038438663606695, 
              c[ 29][ t]], 
            Times[ -0.091317159035181589, 
              c[ 30][ t]], 
            Times[ -0.089594193770366884, 
              c[ 31][ t]], 
            Times[ -0.084091858737850814, 
              c[ 32][ t]], 
            Times[ -0.075181213012062598, 
              c[ 33][ t]], 
            Times[ -0.063361699504227528, 
              c[ 34][ t]], 
            Times[ -0.049236278094138941, 
              c[ 35][ t]], 
            Times[ -0.033483179628681567, 
              c[ 36][ t]], 
            Times[ -0.016825511857749401, 
              c[ 37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ 0.016273855731265604, 
              c[ 39][ t]], 
            Times[ 0.031322974491347078, 
              c[ 40][ t]], 
            Times[ 0.044547108751839815, 
              c[ 41][ t]], 
            Times[ 0.055441487066198933, 
              c[ 42][ t]], 
            Times[ 0.063614872548668253, 
              c[ 43][ t]], 
            Times[ 0.068802429876423321, 
              c[ 44][ t]], 
            Times[ 0.070873018952678238, 
              c[ 45][ t]], 
            Times[ 0.069830768673962415, 
              c[ 46][ t]], 
            Times[ 0.065811019881796315, 
              c[ 47][ t]], 
            Times[ 0.059070953080906326, 
              c[ 48][ t]], 
            Times[ 0.049975424961080865, 
              c[ 49][ t]], 
            Times[ 0.038978720157860088, 
              c[ 50][ t]], 
            Times[ 0.026603074225527826, 
              c[ 51][ t]], 
            Times[ 0.013414935129827233, 
              c[ 52][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 53][ t]], 
            Times[ -0.013061910521147383, 
              c[ 54][ t]], 
            Times[ -0.025221096343682053, 
              c[ 55][ t]], 
            Times[ -0.035980357068793781, 
              c[ 56][ t]], 
            Times[ -0.044914622433376419, 
              c[ 57][ t]], 
            Times[ -0.05168708394579296, 
              c[ 58][ t]], 
            Times[ -0.05606123915856713, 
              c[ 59][ t]], 
            Times[ -0.057908442314993203, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-21\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-21\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.11643488132933186`\ \(c[\(-60\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-59\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-58\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-57\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-56\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-55\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-54\)]\)[t] + 
            0.060688263076985`\ \(c[\(-53\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-52\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-50\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-49\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-48\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-47\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-46\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-45\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-44\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-43\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-42\)]\)[t] - 
            0.2067483357831719`\ \(c[\(-41\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-40\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-39\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-38\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-35\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-34\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-33\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-32\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-31\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-30\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-29\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-28\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-27\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-26\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-25\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-24\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-23\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-22\)]\)[t] + 
            10.67221231306757`\ \(c[\(-21\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-20\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-19\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-18\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-17\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-16\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-15\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-14\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-13\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-12\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-11\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-10\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-9\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-8\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-7\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-5\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-4\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-3\)]\)[t] - 
            0.186750272222986`\ \(c[\(-2\)]\)[t] - 
            0.206748335783172`\ \(c[\(-1\)]\)[t] - 
            0.21623620818304484`\ \(c[0]\)[t] - 
            0.21584055771952013`\ \(c[1]\)[t] - 
            0.20645618564475843`\ \(c[2]\)[t] - 
            0.18920668216016426`\ \(c[3]\)[t] - 
            0.1653986686265376`\ \(c[4]\)[t] - 
            0.13647135277833605`\ \(c[5]\)[t] - 
            0.10394325375429328`\ \(c[6]\)[t] - 
            0.06935801494512607`\ \(c[7]\)[t] - 
            0.03423121377955895`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.032022748374425904`\ \(c[10]\)[t] + 
            0.060688263076985105`\ \(c[11]\)[t] + 
            0.0850444803444217`\ \(c[12]\)[t] + 
            0.10436044624225685`\ \(c[13]\)[t] + 
            0.11814190616181255`\ \(c[14]\)[t] + 
            0.12613778810677614`\ \(c[15]\)[t] + 
            0.12833762891430928`\ \(c[16]\)[t] + 
            0.12496032289024853`\ \(c[17]\)[t] + 
            0.11643488132933186`\ \(c[18]\)[t] + 
            0.10337416789158609`\ \(c[19]\)[t] + 
            0.08654280907894489`\ \(c[20]\)[t] + 
            0.06682066312775997`\ \(c[21]\)[t] + 
            0.0451633585689193`\ \(c[22]\)[t] + 
            0.02256148180925487`\ \(c[23]\)[t] + 
            3.8981718325193755`*^-17\ \(c[24]\)[t] - 
            0.02158054781754788`\ \(c[25]\)[t] - 
            0.04131966847794722`\ \(c[26]\)[t] - 
            0.05846808023678991`\ \(c[27]\)[t] - 
            0.07241337086197412`\ \(c[28]\)[t] - 
            0.08269933431326874`\ \(c[29]\)[t] - 
            0.0890384386636067`\ \(c[30]\)[t] - 
            0.09131715903518159`\ \(c[31]\)[t] - 
            0.08959419377036688`\ \(c[32]\)[t] - 
            0.08409185873785081`\ \(c[33]\)[t] - 
            0.0751812130120626`\ \(c[34]\)[t] - 
            0.06336169950422753`\ \(c[35]\)[t] - 
            0.04923627809413894`\ \(c[36]\)[t] - 
            0.03348317962868157`\ \(c[37]\)[t] - 
            0.0168255118577494`\ \(c[38]\)[t] - 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.016273855731265604`\ \(c[40]\)[t] + 
            0.03132297449134708`\ \(c[41]\)[t] + 
            0.04454710875183992`\ \(c[42]\)[t] + 
            0.05544148706619893`\ \(c[43]\)[t] + 
            0.06361487254866825`\ \(c[44]\)[t] + 
            0.06880242987642335`\ \(c[45]\)[t] + 
            0.07087301895267824`\ \(c[46]\)[t] + 
            0.06983076867396242`\ \(c[47]\)[t] + 
            0.06581101988179627`\ \(c[48]\)[t] + 
            0.059070953080906326`\ \(c[49]\)[t] + 
            0.049975424961080865`\ \(c[50]\)[t] + 
            0.03897872015785999`\ \(c[51]\)[t] + 
            0.026603074225527826`\ \(c[52]\)[t] + 
            0.013414935129827233`\ \(c[53]\)[t] + 
            3.898171832519376`*^-17\ \(c[54]\)[t] - 
            0.013061910521147383`\ \(c[55]\)[t] - 
            0.025221096343682053`\ \(c[56]\)[t] - 
            0.03598035706879378`\ \(c[57]\)[t] - 
            0.04491462243337642`\ \(c[58]\)[t] - 
            0.05168708394579296`\ \(c[59]\)[t] - 
            0.056061239158567186`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -21, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -21]][ t]], 
          Plus[ 
            Times[ 0.11643488132933186, 
              c[ -60][ t]], 
            Times[ 0.12496032289024853, 
              c[ -59][ t]], 
            Times[ 0.12833762891430928, 
              c[ -58][ t]], 
            Times[ 0.12613778810677614, 
              c[ -57][ t]], 
            Times[ 0.11814190616181253, 
              c[ -56][ t]], 
            Times[ 0.10436044624225685, 
              c[ -55][ t]], 
            Times[ 0.085044480344421705, 
              c[ -54][ t]], 
            Times[ 0.060688263076985001, 
              c[ -53][ t]], 
            Times[ 0.032022748374425904, 
              c[ -52][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ -0.034231213779559094, 
              c[ -50][ t]], 
            Times[ -0.06935801494512607, 
              c[ -49][ t]], 
            Times[ -0.10394325375429328, 
              c[ -48][ t]], 
            Times[ -0.13647135277833616, 
              c[ -47][ t]], 
            Times[ -0.16539866862653771, 
              c[ -46][ t]], 
            Times[ -0.18920668216016426, 
              c[ -45][ t]], 
            Times[ -0.20645618564475848, 
              c[ -44][ t]], 
            Times[ -0.21584055771952015, 
              c[ -43][ t]], 
            Times[ -0.21623620818304484, 
              c[ -42][ t]], 
            Times[ -0.20674833578317189, 
              c[ -41][ t]], 
            Times[ -0.18675027222298593, 
              c[ -40][ t]], 
            Times[ -0.15591488063143982, 
              c[ -39][ t]], 
            Times[ -0.11423673049785436, 
              c[ -38][ t]], 
            Times[ -0.062044074975450239, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ 0.070907514257657775, 
              c[ -35][ t]], 
            Times[ 0.14938649372796384, 
              c[ -34][ t]], 
            Times[ 0.23387232094715985, 
              c[ -33][ t]], 
            Times[ 0.32256865202152157, 
              c[ -32][ t]], 
            Times[ 0.41349667156634429, 
              c[ -31][ t]], 
            Times[ 0.50455115242710469, 
              c[ -30][ t]], 
            Times[ 0.59356153372868059, 
              c[ -29][ t]], 
            Times[ 0.67835603854706361, 
              c[ -28][ t]], 
            Times[ 0.75682672864065692, 
              c[ -27][ t]], 
            Times[ 0.82699334313268813, 
              c[ -26][ t]], 
            Times[ 0.88706379305918392, 
              c[ -25][ t]], 
            Times[ 0.93548928378863916, 
              c[ -24][ t]], 
            Times[ 0.9710122092317629, 
              c[ -23][ t]], 
            Times[ 0.99270519960720693, 
              c[ -22][ t]], 
            Times[ 10.67221231306757, 
              c[ -21][ t]], 
            Times[ 0.99270519960720671, 
              c[ -20][ t]], 
            Times[ 0.9710122092317629, 
              c[ -19][ t]], 
            Times[ 0.93548928378863916, 
              c[ -18][ t]], 
            Times[ 0.88706379305918381, 
              c[ -17][ t]], 
            Times[ 0.82699334313268813, 
              c[ -16][ t]], 
            Times[ 0.75682672864065692, 
              c[ -15][ t]], 
            Times[ 0.67835603854706317, 
              c[ -14][ t]], 
            Times[ 0.59356153372868026, 
              c[ -13][ t]], 
            Times[ 0.50455115242710469, 
              c[ -12][ t]], 
            Times[ 0.41349667156634395, 
              c[ -11][ t]], 
            Times[ 0.32256865202152135, 
              c[ -10][ t]], 
            Times[ 0.23387232094715985, 
              c[ -9][ t]], 
            Times[ 0.14938649372796345, 
              c[ -8][ t]], 
            Times[ 0.070907514257657622, 
              c[ -7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.062044074975450475, 
              c[ -5][ t]], 
            Times[ -0.11423673049785445, 
              c[ -4][ t]], 
            Times[ -0.15591488063143982, 
              c[ -3][ t]], 
            Times[ -0.18675027222298601, 
              c[ -2][ t]], 
            Times[ -0.206748335783172, 
              c[ -1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 0][ t]], 
            Times[ -0.21584055771952013, 
              c[ 1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 2][ t]], 
            Times[ -0.18920668216016426, 
              c[ 3][ t]], 
            Times[ -0.1653986686265376, 
              c[ 4][ t]], 
            Times[ -0.13647135277833605, 
              c[ 5][ t]], 
            Times[ -0.10394325375429328, 
              c[ 6][ t]], 
            Times[ -0.06935801494512607, 
              c[ 7][ t]], 
            Times[ -0.034231213779558949, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.032022748374425904, 
              c[ 10][ t]], 
            Times[ 0.060688263076985105, 
              c[ 11][ t]], 
            Times[ 0.085044480344421705, 
              c[ 12][ t]], 
            Times[ 0.10436044624225685, 
              c[ 13][ t]], 
            Times[ 0.11814190616181255, 
              c[ 14][ t]], 
            Times[ 0.12613778810677614, 
              c[ 15][ t]], 
            Times[ 0.12833762891430928, 
              c[ 16][ t]], 
            Times[ 0.12496032289024853, 
              c[ 17][ t]], 
            Times[ 0.11643488132933186, 
              c[ 18][ t]], 
            Times[ 0.10337416789158609, 
              c[ 19][ t]], 
            Times[ 0.086542809078944891, 
              c[ 20][ t]], 
            Times[ 0.066820663127759972, 
              c[ 21][ t]], 
            Times[ 0.045163358568919301, 
              c[ 22][ t]], 
            Times[ 0.022561481809254869, 
              c[ 23][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 24][ t]], 
            Times[ -0.021580547817547879, 
              c[ 25][ t]], 
            Times[ -0.04131966847794722, 
              c[ 26][ t]], 
            Times[ -0.058468080236789913, 
              c[ 27][ t]], 
            Times[ -0.072413370861974122, 
              c[ 28][ t]], 
            Times[ -0.082699334313268744, 
              c[ 29][ t]], 
            Times[ -0.089038438663606695, 
              c[ 30][ t]], 
            Times[ -0.091317159035181589, 
              c[ 31][ t]], 
            Times[ -0.089594193770366884, 
              c[ 32][ t]], 
            Times[ -0.084091858737850814, 
              c[ 33][ t]], 
            Times[ -0.075181213012062598, 
              c[ 34][ t]], 
            Times[ -0.063361699504227528, 
              c[ 35][ t]], 
            Times[ -0.049236278094138941, 
              c[ 36][ t]], 
            Times[ -0.033483179628681567, 
              c[ 37][ t]], 
            Times[ -0.016825511857749401, 
              c[ 38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.016273855731265604, 
              c[ 40][ t]], 
            Times[ 0.031322974491347078, 
              c[ 41][ t]], 
            Times[ 0.044547108751839919, 
              c[ 42][ t]], 
            Times[ 0.055441487066198933, 
              c[ 43][ t]], 
            Times[ 0.063614872548668253, 
              c[ 44][ t]], 
            Times[ 0.068802429876423349, 
              c[ 45][ t]], 
            Times[ 0.070873018952678238, 
              c[ 46][ t]], 
            Times[ 0.069830768673962415, 
              c[ 47][ t]], 
            Times[ 0.065811019881796273, 
              c[ 48][ t]], 
            Times[ 0.059070953080906326, 
              c[ 49][ t]], 
            Times[ 0.049975424961080865, 
              c[ 50][ t]], 
            Times[ 0.03897872015785999, 
              c[ 51][ t]], 
            Times[ 0.026603074225527826, 
              c[ 52][ t]], 
            Times[ 0.013414935129827233, 
              c[ 53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ -0.013061910521147383, 
              c[ 55][ t]], 
            Times[ -0.025221096343682053, 
              c[ 56][ t]], 
            Times[ -0.035980357068793781, 
              c[ 57][ t]], 
            Times[ -0.044914622433376419, 
              c[ 58][ t]], 
            Times[ -0.05168708394579296, 
              c[ 59][ t]], 
            Times[ -0.056061239158567186, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-20\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-20\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.10337416789158595`\ \(c[\(-60\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-59\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-58\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-57\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-56\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-55\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-54\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-53\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-52\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-51\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-50\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-49\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-48\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-47\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-46\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-45\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-44\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-43\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-42\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-41\)]\)[t] - 
            0.206748335783172`\ \(c[\(-40\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-39\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-38\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-37\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-36\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-34\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-33\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-32\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-31\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-30\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-29\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-28\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-27\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-26\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-25\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-24\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-23\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-22\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-21\)]\)[t] + 
            9.772981689857206`\ \(c[\(-20\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-19\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-18\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-17\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-16\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-15\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-14\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-13\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-12\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-11\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-10\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-9\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-8\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-7\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-6\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-4\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-3\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-2\)]\)[t] - 
            0.186750272222986`\ \(c[\(-1\)]\)[t] - 
            0.206748335783172`\ \(c[0]\)[t] - 
            0.21623620818304484`\ \(c[1]\)[t] - 
            0.21584055771952015`\ \(c[2]\)[t] - 
            0.20645618564475843`\ \(c[3]\)[t] - 
            0.18920668216016426`\ \(c[4]\)[t] - 
            0.1653986686265377`\ \(c[5]\)[t] - 
            0.13647135277833605`\ \(c[6]\)[t] - 
            0.10394325375429328`\ \(c[7]\)[t] - 
            0.06935801494512607`\ \(c[8]\)[t] - 
            0.03423121377955895`\ \(c[9]\)[t] - 
            3.898171832519376`*^-17\ \(c[10]\)[t] + 
            0.032022748374425904`\ \(c[11]\)[t] + 
            0.060688263076985105`\ \(c[12]\)[t] + 
            0.0850444803444217`\ \(c[13]\)[t] + 
            0.10436044624225685`\ \(c[14]\)[t] + 
            0.11814190616181255`\ \(c[15]\)[t] + 
            0.12613778810677614`\ \(c[16]\)[t] + 
            0.12833762891430928`\ \(c[17]\)[t] + 
            0.12496032289024853`\ \(c[18]\)[t] + 
            0.11643488132933186`\ \(c[19]\)[t] + 
            0.10337416789158609`\ \(c[20]\)[t] + 
            0.08654280907894489`\ \(c[21]\)[t] + 
            0.06682066312775997`\ \(c[22]\)[t] + 
            0.0451633585689193`\ \(c[23]\)[t] + 
            0.02256148180925487`\ \(c[24]\)[t] + 
            3.8981718325193755`*^-17\ \(c[25]\)[t] - 
            0.02158054781754788`\ \(c[26]\)[t] - 
            0.04131966847794722`\ \(c[27]\)[t] - 
            0.05846808023678991`\ \(c[28]\)[t] - 
            0.07241337086197412`\ \(c[29]\)[t] - 
            0.08269933431326874`\ \(c[30]\)[t] - 
            0.0890384386636067`\ \(c[31]\)[t] - 
            0.09131715903518159`\ \(c[32]\)[t] - 
            0.08959419377036688`\ \(c[33]\)[t] - 
            0.08409185873785081`\ \(c[34]\)[t] - 
            0.0751812130120626`\ \(c[35]\)[t] - 
            0.06336169950422753`\ \(c[36]\)[t] - 
            0.04923627809413894`\ \(c[37]\)[t] - 
            0.03348317962868157`\ \(c[38]\)[t] - 
            0.0168255118577494`\ \(c[39]\)[t] - 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.01627385573126547`\ \(c[41]\)[t] + 
            0.03132297449134708`\ \(c[42]\)[t] + 
            0.04454710875183992`\ \(c[43]\)[t] + 
            0.055441487066198857`\ \(c[44]\)[t] + 
            0.06361487254866825`\ \(c[45]\)[t] + 
            0.06880242987642335`\ \(c[46]\)[t] + 
            0.07087301895267824`\ \(c[47]\)[t] + 
            0.06983076867396242`\ \(c[48]\)[t] + 
            0.06581101988179627`\ \(c[49]\)[t] + 
            0.0590709530809064`\ \(c[50]\)[t] + 
            0.049975424961080865`\ \(c[51]\)[t] + 
            0.03897872015785999`\ \(c[52]\)[t] + 
            0.026603074225527937`\ \(c[53]\)[t] + 
            0.013414935129827233`\ \(c[54]\)[t] + 
            3.898171832519376`*^-17\ \(c[55]\)[t] - 
            0.013061910521147276`\ \(c[56]\)[t] - 
            0.025221096343682053`\ \(c[57]\)[t] - 
            0.03598035706879378`\ \(c[58]\)[t] - 
            0.04491462243337629`\ \(c[59]\)[t] - 
            0.05168708394579296`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -20, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -20]][ t]], 
          Plus[ 
            Times[ 0.10337416789158595, 
              c[ -60][ t]], 
            Times[ 0.11643488132933186, 
              c[ -59][ t]], 
            Times[ 0.12496032289024853, 
              c[ -58][ t]], 
            Times[ 0.12833762891430925, 
              c[ -57][ t]], 
            Times[ 0.12613778810677612, 
              c[ -56][ t]], 
            Times[ 0.11814190616181255, 
              c[ -55][ t]], 
            Times[ 0.10436044624225692, 
              c[ -54][ t]], 
            Times[ 0.085044480344421608, 
              c[ -53][ t]], 
            Times[ 0.060688263076985105, 
              c[ -52][ t]], 
            Times[ 0.032022748374426029, 
              c[ -51][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -50][ t]], 
            Times[ -0.034231213779558949, 
              c[ -49][ t]], 
            Times[ -0.069358014945125918, 
              c[ -48][ t]], 
            Times[ -0.1039432537542934, 
              c[ -47][ t]], 
            Times[ -0.13647135277833605, 
              c[ -46][ t]], 
            Times[ -0.1653986686265376, 
              c[ -45][ t]], 
            Times[ -0.18920668216016434, 
              c[ -44][ t]], 
            Times[ -0.20645618564475843, 
              c[ -43][ t]], 
            Times[ -0.21584055771952013, 
              c[ -42][ t]], 
            Times[ -0.21623620818304481, 
              c[ -41][ t]], 
            Times[ -0.206748335783172, 
              c[ -40][ t]], 
            Times[ -0.18675027222298607, 
              c[ -39][ t]], 
            Times[ -0.15591488063143982, 
              c[ -38][ t]], 
            Times[ -0.11423673049785436, 
              c[ -37][ t]], 
            Times[ -0.062044074975450475, 
              c[ -36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ 0.070907514257657775, 
              c[ -34][ t]], 
            Times[ 0.14938649372796345, 
              c[ -33][ t]], 
            Times[ 0.23387232094715985, 
              c[ -32][ t]], 
            Times[ 0.32256865202152157, 
              c[ -31][ t]], 
            Times[ 0.41349667156634395, 
              c[ -30][ t]], 
            Times[ 0.50455115242710469, 
              c[ -29][ t]], 
            Times[ 0.59356153372868059, 
              c[ -28][ t]], 
            Times[ 0.67835603854706317, 
              c[ -27][ t]], 
            Times[ 0.75682672864065692, 
              c[ -26][ t]], 
            Times[ 0.82699334313268813, 
              c[ -25][ t]], 
            Times[ 0.88706379305918381, 
              c[ -24][ t]], 
            Times[ 0.93548928378863916, 
              c[ -23][ t]], 
            Times[ 0.9710122092317629, 
              c[ -22][ t]], 
            Times[ 0.99270519960720671, 
              c[ -21][ t]], 
            Times[ 9.7729816898572057, 
              c[ -20][ t]], 
            Times[ 0.99270519960720693, 
              c[ -19][ t]], 
            Times[ 0.9710122092317629, 
              c[ -18][ t]], 
            Times[ 0.93548928378863916, 
              c[ -17][ t]], 
            Times[ 0.88706379305918381, 
              c[ -16][ t]], 
            Times[ 0.82699334313268813, 
              c[ -15][ t]], 
            Times[ 0.75682672864065692, 
              c[ -14][ t]], 
            Times[ 0.67835603854706339, 
              c[ -13][ t]], 
            Times[ 0.59356153372868059, 
              c[ -12][ t]], 
            Times[ 0.50455115242710469, 
              c[ -11][ t]], 
            Times[ 0.41349667156634418, 
              c[ -10][ t]], 
            Times[ 0.32256865202152157, 
              c[ -9][ t]], 
            Times[ 0.23387232094715985, 
              c[ -8][ t]], 
            Times[ 0.14938649372796362, 
              c[ -7][ t]], 
            Times[ 0.070907514257657775, 
              c[ -6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ -0.062044074975450343, 
              c[ -4][ t]], 
            Times[ -0.11423673049785436, 
              c[ -3][ t]], 
            Times[ -0.15591488063143974, 
              c[ -2][ t]], 
            Times[ -0.18675027222298601, 
              c[ -1][ t]], 
            Times[ -0.206748335783172, 
              c[ 0][ t]], 
            Times[ -0.21623620818304484, 
              c[ 1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 2][ t]], 
            Times[ -0.20645618564475843, 
              c[ 3][ t]], 
            Times[ -0.18920668216016426, 
              c[ 4][ t]], 
            Times[ -0.16539866862653771, 
              c[ 5][ t]], 
            Times[ -0.13647135277833605, 
              c[ 6][ t]], 
            Times[ -0.10394325375429328, 
              c[ 7][ t]], 
            Times[ -0.06935801494512607, 
              c[ 8][ t]], 
            Times[ -0.034231213779558949, 
              c[ 9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ 0.032022748374425904, 
              c[ 11][ t]], 
            Times[ 0.060688263076985105, 
              c[ 12][ t]], 
            Times[ 0.085044480344421705, 
              c[ 13][ t]], 
            Times[ 0.10436044624225685, 
              c[ 14][ t]], 
            Times[ 0.11814190616181255, 
              c[ 15][ t]], 
            Times[ 0.12613778810677614, 
              c[ 16][ t]], 
            Times[ 0.12833762891430928, 
              c[ 17][ t]], 
            Times[ 0.12496032289024853, 
              c[ 18][ t]], 
            Times[ 0.11643488132933186, 
              c[ 19][ t]], 
            Times[ 0.10337416789158609, 
              c[ 20][ t]], 
            Times[ 0.086542809078944891, 
              c[ 21][ t]], 
            Times[ 0.066820663127759972, 
              c[ 22][ t]], 
            Times[ 0.045163358568919301, 
              c[ 23][ t]], 
            Times[ 0.022561481809254869, 
              c[ 24][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 25][ t]], 
            Times[ -0.021580547817547879, 
              c[ 26][ t]], 
            Times[ -0.04131966847794722, 
              c[ 27][ t]], 
            Times[ -0.058468080236789913, 
              c[ 28][ t]], 
            Times[ -0.072413370861974122, 
              c[ 29][ t]], 
            Times[ -0.082699334313268744, 
              c[ 30][ t]], 
            Times[ -0.089038438663606695, 
              c[ 31][ t]], 
            Times[ -0.091317159035181589, 
              c[ 32][ t]], 
            Times[ -0.089594193770366884, 
              c[ 33][ t]], 
            Times[ -0.084091858737850814, 
              c[ 34][ t]], 
            Times[ -0.075181213012062598, 
              c[ 35][ t]], 
            Times[ -0.063361699504227528, 
              c[ 36][ t]], 
            Times[ -0.049236278094138941, 
              c[ 37][ t]], 
            Times[ -0.033483179628681567, 
              c[ 38][ t]], 
            Times[ -0.016825511857749401, 
              c[ 39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.016273855731265469, 
              c[ 41][ t]], 
            Times[ 0.031322974491347078, 
              c[ 42][ t]], 
            Times[ 0.044547108751839919, 
              c[ 43][ t]], 
            Times[ 0.055441487066198857, 
              c[ 44][ t]], 
            Times[ 0.063614872548668253, 
              c[ 45][ t]], 
            Times[ 0.068802429876423349, 
              c[ 46][ t]], 
            Times[ 0.070873018952678238, 
              c[ 47][ t]], 
            Times[ 0.069830768673962415, 
              c[ 48][ t]], 
            Times[ 0.065811019881796273, 
              c[ 49][ t]], 
            Times[ 0.059070953080906402, 
              c[ 50][ t]], 
            Times[ 0.049975424961080865, 
              c[ 51][ t]], 
            Times[ 0.03897872015785999, 
              c[ 52][ t]], 
            Times[ 0.026603074225527937, 
              c[ 53][ t]], 
            Times[ 0.013414935129827233, 
              c[ 54][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ -0.013061910521147276, 
              c[ 56][ t]], 
            Times[ -0.025221096343682053, 
              c[ 57][ t]], 
            Times[ -0.035980357068793781, 
              c[ 58][ t]], 
            Times[ -0.044914622433376288, 
              c[ 59][ t]], 
            Times[ -0.05168708394579296, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-19\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-19\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.08654280907894475`\ \(c[\(-60\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-59\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-58\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-57\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-56\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-55\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-54\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-53\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-52\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-51\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-50\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-48\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-47\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-46\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-45\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-44\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-43\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-42\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-41\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-40\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-39\)]\)[t] - 
            0.186750272222986`\ \(c[\(-38\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-37\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-36\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-35\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-34\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-33\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-32\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-31\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-30\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-29\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-28\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-27\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-26\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-25\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-24\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-23\)]\)[t] + 
            0.9354892837886394`\ \(c[\(-22\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-21\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-20\)]\)[t] + 
            8.91761597509613`\ \(c[\(-19\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-18\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-17\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-16\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-15\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-14\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-13\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-12\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-11\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-10\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-9\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-8\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-7\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-6\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-5\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-4\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-3\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-2\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-1\)]\)[t] - 
            0.186750272222986`\ \(c[0]\)[t] - 
            0.206748335783172`\ \(c[1]\)[t] - 
            0.21623620818304484`\ \(c[2]\)[t] - 
            0.21584055771952015`\ \(c[3]\)[t] - 
            0.20645618564475843`\ \(c[4]\)[t] - 
            0.18920668216016426`\ \(c[5]\)[t] - 
            0.1653986686265377`\ \(c[6]\)[t] - 
            0.13647135277833605`\ \(c[7]\)[t] - 
            0.10394325375429328`\ \(c[8]\)[t] - 
            0.06935801494512607`\ \(c[9]\)[t] - 
            0.03423121377955895`\ \(c[10]\)[t] - 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.032022748374425904`\ \(c[12]\)[t] + 
            0.060688263076985105`\ \(c[13]\)[t] + 
            0.0850444803444217`\ \(c[14]\)[t] + 
            0.10436044624225685`\ \(c[15]\)[t] + 
            0.11814190616181255`\ \(c[16]\)[t] + 
            0.12613778810677614`\ \(c[17]\)[t] + 
            0.12833762891430928`\ \(c[18]\)[t] + 
            0.12496032289024853`\ \(c[19]\)[t] + 
            0.11643488132933186`\ \(c[20]\)[t] + 
            0.10337416789158609`\ \(c[21]\)[t] + 
            0.08654280907894489`\ \(c[22]\)[t] + 
            0.06682066312775997`\ \(c[23]\)[t] + 
            0.0451633585689193`\ \(c[24]\)[t] + 
            0.02256148180925487`\ \(c[25]\)[t] + 
            3.8981718325193755`*^-17\ \(c[26]\)[t] - 
            0.02158054781754788`\ \(c[27]\)[t] - 
            0.04131966847794722`\ \(c[28]\)[t] - 
            0.05846808023678991`\ \(c[29]\)[t] - 
            0.07241337086197412`\ \(c[30]\)[t] - 
            0.08269933431326874`\ \(c[31]\)[t] - 
            0.0890384386636067`\ \(c[32]\)[t] - 
            0.09131715903518159`\ \(c[33]\)[t] - 
            0.08959419377036688`\ \(c[34]\)[t] - 
            0.08409185873785081`\ \(c[35]\)[t] - 
            0.0751812130120626`\ \(c[36]\)[t] - 
            0.06336169950422753`\ \(c[37]\)[t] - 
            0.04923627809413894`\ \(c[38]\)[t] - 
            0.03348317962868157`\ \(c[39]\)[t] - 
            0.0168255118577494`\ \(c[40]\)[t] - 
            1.8033970416801674`*^-16\ \(c[41]\)[t] + 
            0.016273855731265604`\ \(c[42]\)[t] + 
            0.03132297449134708`\ \(c[43]\)[t] + 
            0.044547108751839815`\ \(c[44]\)[t] + 
            0.05544148706619893`\ \(c[45]\)[t] + 
            0.06361487254866825`\ \(c[46]\)[t] + 
            0.06880242987642332`\ \(c[47]\)[t] + 
            0.07087301895267824`\ \(c[48]\)[t] + 
            0.06983076867396242`\ \(c[49]\)[t] + 
            0.06581101988179631`\ \(c[50]\)[t] + 
            0.059070953080906326`\ \(c[51]\)[t] + 
            0.049975424961080865`\ \(c[52]\)[t] + 
            0.03897872015786009`\ \(c[53]\)[t] + 
            0.026603074225527826`\ \(c[54]\)[t] + 
            0.013414935129827233`\ \(c[55]\)[t] + 
            1.5206810699945212`*^-16\ \(c[56]\)[t] - 
            0.013061910521147383`\ \(c[57]\)[t] - 
            0.025221096343682053`\ \(c[58]\)[t] - 
            0.03598035706879378`\ \(c[59]\)[t] - 
            0.04491462243337642`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -19, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -19]][ t]], 
          Plus[ 
            Times[ 0.086542809078944752, 
              c[ -60][ t]], 
            Times[ 0.10337416789158609, 
              c[ -59][ t]], 
            Times[ 0.11643488132933186, 
              c[ -58][ t]], 
            Times[ 0.12496032289024847, 
              c[ -57][ t]], 
            Times[ 0.12833762891430928, 
              c[ -56][ t]], 
            Times[ 0.12613778810677614, 
              c[ -55][ t]], 
            Times[ 0.1181419061618126, 
              c[ -54][ t]], 
            Times[ 0.10436044624225685, 
              c[ -53][ t]], 
            Times[ 0.085044480344421705, 
              c[ -52][ t]], 
            Times[ 0.060688263076985223, 
              c[ -51][ t]], 
            Times[ 0.032022748374425904, 
              c[ -50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ -0.034231213779558796, 
              c[ -48][ t]], 
            Times[ -0.06935801494512607, 
              c[ -47][ t]], 
            Times[ -0.10394325375429328, 
              c[ -46][ t]], 
            Times[ -0.13647135277833591, 
              c[ -45][ t]], 
            Times[ -0.16539866862653771, 
              c[ -44][ t]], 
            Times[ -0.18920668216016426, 
              c[ -43][ t]], 
            Times[ -0.20645618564475834, 
              c[ -42][ t]], 
            Times[ -0.21584055771952015, 
              c[ -41][ t]], 
            Times[ -0.21623620818304484, 
              c[ -40][ t]], 
            Times[ -0.20674833578317206, 
              c[ -39][ t]], 
            Times[ -0.18675027222298601, 
              c[ -38][ t]], 
            Times[ -0.15591488063143974, 
              c[ -37][ t]], 
            Times[ -0.11423673049785445, 
              c[ -36][ t]], 
            Times[ -0.062044074975450343, 
              c[ -35][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -34][ t]], 
            Times[ 0.070907514257657622, 
              c[ -33][ t]], 
            Times[ 0.14938649372796362, 
              c[ -32][ t]], 
            Times[ 0.23387232094715998, 
              c[ -31][ t]], 
            Times[ 0.32256865202152135, 
              c[ -30][ t]], 
            Times[ 0.41349667156634418, 
              c[ -29][ t]], 
            Times[ 0.50455115242710491, 
              c[ -28][ t]], 
            Times[ 0.59356153372868026, 
              c[ -27][ t]], 
            Times[ 0.67835603854706339, 
              c[ -26][ t]], 
            Times[ 0.75682672864065714, 
              c[ -25][ t]], 
            Times[ 0.82699334313268813, 
              c[ -24][ t]], 
            Times[ 0.88706379305918381, 
              c[ -23][ t]], 
            Times[ 0.93548928378863938, 
              c[ -22][ t]], 
            Times[ 0.9710122092317629, 
              c[ -21][ t]], 
            Times[ 0.99270519960720693, 
              c[ -20][ t]], 
            Times[ 8.9176159750961297, 
              c[ -19][ t]], 
            Times[ 0.99270519960720693, 
              c[ -18][ t]], 
            Times[ 0.9710122092317629, 
              c[ -17][ t]], 
            Times[ 0.93548928378863916, 
              c[ -16][ t]], 
            Times[ 0.88706379305918381, 
              c[ -15][ t]], 
            Times[ 0.82699334313268813, 
              c[ -14][ t]], 
            Times[ 0.75682672864065692, 
              c[ -13][ t]], 
            Times[ 0.67835603854706339, 
              c[ -12][ t]], 
            Times[ 0.59356153372868026, 
              c[ -11][ t]], 
            Times[ 0.50455115242710469, 
              c[ -10][ t]], 
            Times[ 0.41349667156634418, 
              c[ -9][ t]], 
            Times[ 0.32256865202152157, 
              c[ -8][ t]], 
            Times[ 0.23387232094715985, 
              c[ -7][ t]], 
            Times[ 0.14938649372796362, 
              c[ -6][ t]], 
            Times[ 0.070907514257657775, 
              c[ -5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -4][ t]], 
            Times[ -0.062044074975450343, 
              c[ -3][ t]], 
            Times[ -0.11423673049785436, 
              c[ -2][ t]], 
            Times[ -0.15591488063143982, 
              c[ -1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 0][ t]], 
            Times[ -0.206748335783172, 
              c[ 1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 2][ t]], 
            Times[ -0.21584055771952015, 
              c[ 3][ t]], 
            Times[ -0.20645618564475843, 
              c[ 4][ t]], 
            Times[ -0.18920668216016426, 
              c[ 5][ t]], 
            Times[ -0.16539866862653771, 
              c[ 6][ t]], 
            Times[ -0.13647135277833605, 
              c[ 7][ t]], 
            Times[ -0.10394325375429328, 
              c[ 8][ t]], 
            Times[ -0.06935801494512607, 
              c[ 9][ t]], 
            Times[ -0.034231213779558949, 
              c[ 10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.032022748374425904, 
              c[ 12][ t]], 
            Times[ 0.060688263076985105, 
              c[ 13][ t]], 
            Times[ 0.085044480344421705, 
              c[ 14][ t]], 
            Times[ 0.10436044624225685, 
              c[ 15][ t]], 
            Times[ 0.11814190616181255, 
              c[ 16][ t]], 
            Times[ 0.12613778810677614, 
              c[ 17][ t]], 
            Times[ 0.12833762891430928, 
              c[ 18][ t]], 
            Times[ 0.12496032289024853, 
              c[ 19][ t]], 
            Times[ 0.11643488132933186, 
              c[ 20][ t]], 
            Times[ 0.10337416789158609, 
              c[ 21][ t]], 
            Times[ 0.086542809078944891, 
              c[ 22][ t]], 
            Times[ 0.066820663127759972, 
              c[ 23][ t]], 
            Times[ 0.045163358568919301, 
              c[ 24][ t]], 
            Times[ 0.022561481809254869, 
              c[ 25][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 26][ t]], 
            Times[ -0.021580547817547879, 
              c[ 27][ t]], 
            Times[ -0.04131966847794722, 
              c[ 28][ t]], 
            Times[ -0.058468080236789913, 
              c[ 29][ t]], 
            Times[ -0.072413370861974122, 
              c[ 30][ t]], 
            Times[ -0.082699334313268744, 
              c[ 31][ t]], 
            Times[ -0.089038438663606695, 
              c[ 32][ t]], 
            Times[ -0.091317159035181589, 
              c[ 33][ t]], 
            Times[ -0.089594193770366884, 
              c[ 34][ t]], 
            Times[ -0.084091858737850814, 
              c[ 35][ t]], 
            Times[ -0.075181213012062598, 
              c[ 36][ t]], 
            Times[ -0.063361699504227528, 
              c[ 37][ t]], 
            Times[ -0.049236278094138941, 
              c[ 38][ t]], 
            Times[ -0.033483179628681567, 
              c[ 39][ t]], 
            Times[ -0.016825511857749401, 
              c[ 40][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 41][ t]], 
            Times[ 0.016273855731265604, 
              c[ 42][ t]], 
            Times[ 0.031322974491347078, 
              c[ 43][ t]], 
            Times[ 0.044547108751839815, 
              c[ 44][ t]], 
            Times[ 0.055441487066198933, 
              c[ 45][ t]], 
            Times[ 0.063614872548668253, 
              c[ 46][ t]], 
            Times[ 0.068802429876423321, 
              c[ 47][ t]], 
            Times[ 0.070873018952678238, 
              c[ 48][ t]], 
            Times[ 0.069830768673962415, 
              c[ 49][ t]], 
            Times[ 0.065811019881796315, 
              c[ 50][ t]], 
            Times[ 0.059070953080906326, 
              c[ 51][ t]], 
            Times[ 0.049975424961080865, 
              c[ 52][ t]], 
            Times[ 0.038978720157860088, 
              c[ 53][ t]], 
            Times[ 0.026603074225527826, 
              c[ 54][ t]], 
            Times[ 0.013414935129827233, 
              c[ 55][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 56][ t]], 
            Times[ -0.013061910521147383, 
              c[ 57][ t]], 
            Times[ -0.025221096343682053, 
              c[ 58][ t]], 
            Times[ -0.035980357068793781, 
              c[ 59][ t]], 
            Times[ -0.044914622433376419, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-18\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-18\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06682066312775997`\ \(c[\(-60\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-59\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-58\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-57\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-56\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-55\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-54\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-53\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-52\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-51\)]\)[t] + 
            0.060688263076985`\ \(c[\(-50\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-49\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-47\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-46\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-45\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-44\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-43\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-42\)]\)[t] - 
            0.20645618564475848`\ \(c[\(-41\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-40\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-39\)]\)[t] - 
            0.206748335783172`\ \(c[\(-38\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-37\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-36\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-35\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-32\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-31\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-30\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-29\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-28\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-27\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-26\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-25\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-24\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-23\)]\)[t] + 
            0.8870637930591839`\ \(c[\(-22\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-21\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-20\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-19\)]\)[t] + 
            8.106115168784338`\ \(c[\(-18\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-17\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-16\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-15\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-14\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-13\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-12\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-11\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-10\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-9\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-8\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-7\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-6\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-5\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-4\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-2\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-1\)]\)[t] - 
            0.15591488063143982`\ \(c[0]\)[t] - 
            0.186750272222986`\ \(c[1]\)[t] - 
            0.206748335783172`\ \(c[2]\)[t] - 
            0.21623620818304484`\ \(c[3]\)[t] - 
            0.21584055771952013`\ \(c[4]\)[t] - 
            0.20645618564475843`\ \(c[5]\)[t] - 
            0.18920668216016426`\ \(c[6]\)[t] - 
            0.1653986686265377`\ \(c[7]\)[t] - 
            0.13647135277833605`\ \(c[8]\)[t] - 
            0.10394325375429328`\ \(c[9]\)[t] - 
            0.06935801494512607`\ \(c[10]\)[t] - 
            0.03423121377955895`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.032022748374425904`\ \(c[13]\)[t] + 
            0.060688263076985105`\ \(c[14]\)[t] + 
            0.0850444803444217`\ \(c[15]\)[t] + 
            0.10436044624225685`\ \(c[16]\)[t] + 
            0.11814190616181255`\ \(c[17]\)[t] + 
            0.12613778810677614`\ \(c[18]\)[t] + 
            0.12833762891430928`\ \(c[19]\)[t] + 
            0.12496032289024853`\ \(c[20]\)[t] + 
            0.11643488132933186`\ \(c[21]\)[t] + 
            0.10337416789158609`\ \(c[22]\)[t] + 
            0.08654280907894489`\ \(c[23]\)[t] + 
            0.06682066312775997`\ \(c[24]\)[t] + 
            0.0451633585689193`\ \(c[25]\)[t] + 
            0.02256148180925487`\ \(c[26]\)[t] + 
            3.8981718325193755`*^-17\ \(c[27]\)[t] - 
            0.02158054781754788`\ \(c[28]\)[t] - 
            0.04131966847794722`\ \(c[29]\)[t] - 
            0.05846808023678991`\ \(c[30]\)[t] - 
            0.07241337086197412`\ \(c[31]\)[t] - 
            0.08269933431326874`\ \(c[32]\)[t] - 
            0.0890384386636067`\ \(c[33]\)[t] - 
            0.09131715903518159`\ \(c[34]\)[t] - 
            0.08959419377036688`\ \(c[35]\)[t] - 
            0.08409185873785081`\ \(c[36]\)[t] - 
            0.0751812130120626`\ \(c[37]\)[t] - 
            0.06336169950422753`\ \(c[38]\)[t] - 
            0.04923627809413894`\ \(c[39]\)[t] - 
            0.03348317962868157`\ \(c[40]\)[t] - 
            0.0168255118577494`\ \(c[41]\)[t] - 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.016273855731265604`\ \(c[43]\)[t] + 
            0.03132297449134708`\ \(c[44]\)[t] + 
            0.04454710875183992`\ \(c[45]\)[t] + 
            0.05544148706619893`\ \(c[46]\)[t] + 
            0.06361487254866825`\ \(c[47]\)[t] + 
            0.06880242987642335`\ \(c[48]\)[t] + 
            0.07087301895267824`\ \(c[49]\)[t] + 
            0.06983076867396242`\ \(c[50]\)[t] + 
            0.06581101988179627`\ \(c[51]\)[t] + 
            0.059070953080906326`\ \(c[52]\)[t] + 
            0.049975424961080865`\ \(c[53]\)[t] + 
            0.03897872015785999`\ \(c[54]\)[t] + 
            0.026603074225527826`\ \(c[55]\)[t] + 
            0.013414935129827233`\ \(c[56]\)[t] + 
            3.898171832519376`*^-17\ \(c[57]\)[t] - 
            0.013061910521147383`\ \(c[58]\)[t] - 
            0.025221096343682053`\ \(c[59]\)[t] - 
            0.03598035706879378`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -18, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -18]][ t]], 
          Plus[ 
            Times[ 0.066820663127759972, 
              c[ -60][ t]], 
            Times[ 0.086542809078944891, 
              c[ -59][ t]], 
            Times[ 0.10337416789158609, 
              c[ -58][ t]], 
            Times[ 0.11643488132933186, 
              c[ -57][ t]], 
            Times[ 0.12496032289024853, 
              c[ -56][ t]], 
            Times[ 0.12833762891430928, 
              c[ -55][ t]], 
            Times[ 0.12613778810677614, 
              c[ -54][ t]], 
            Times[ 0.11814190616181253, 
              c[ -53][ t]], 
            Times[ 0.10436044624225685, 
              c[ -52][ t]], 
            Times[ 0.085044480344421705, 
              c[ -51][ t]], 
            Times[ 0.060688263076985001, 
              c[ -50][ t]], 
            Times[ 0.032022748374425904, 
              c[ -49][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ -0.034231213779559094, 
              c[ -47][ t]], 
            Times[ -0.06935801494512607, 
              c[ -46][ t]], 
            Times[ -0.10394325375429328, 
              c[ -45][ t]], 
            Times[ -0.13647135277833616, 
              c[ -44][ t]], 
            Times[ -0.16539866862653771, 
              c[ -43][ t]], 
            Times[ -0.18920668216016426, 
              c[ -42][ t]], 
            Times[ -0.20645618564475848, 
              c[ -41][ t]], 
            Times[ -0.21584055771952015, 
              c[ -40][ t]], 
            Times[ -0.21623620818304484, 
              c[ -39][ t]], 
            Times[ -0.206748335783172, 
              c[ -38][ t]], 
            Times[ -0.18675027222298593, 
              c[ -37][ t]], 
            Times[ -0.15591488063143982, 
              c[ -36][ t]], 
            Times[ -0.11423673049785436, 
              c[ -35][ t]], 
            Times[ -0.062044074975450239, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ 0.070907514257657775, 
              c[ -32][ t]], 
            Times[ 0.14938649372796384, 
              c[ -31][ t]], 
            Times[ 0.23387232094715985, 
              c[ -30][ t]], 
            Times[ 0.32256865202152157, 
              c[ -29][ t]], 
            Times[ 0.41349667156634429, 
              c[ -28][ t]], 
            Times[ 0.50455115242710469, 
              c[ -27][ t]], 
            Times[ 0.59356153372868059, 
              c[ -26][ t]], 
            Times[ 0.67835603854706361, 
              c[ -25][ t]], 
            Times[ 0.75682672864065692, 
              c[ -24][ t]], 
            Times[ 0.82699334313268813, 
              c[ -23][ t]], 
            Times[ 0.88706379305918392, 
              c[ -22][ t]], 
            Times[ 0.93548928378863916, 
              c[ -21][ t]], 
            Times[ 0.9710122092317629, 
              c[ -20][ t]], 
            Times[ 0.99270519960720693, 
              c[ -19][ t]], 
            Times[ 8.1061151687843385, 
              c[ -18][ t]], 
            Times[ 0.99270519960720671, 
              c[ -17][ t]], 
            Times[ 0.9710122092317629, 
              c[ -16][ t]], 
            Times[ 0.93548928378863916, 
              c[ -15][ t]], 
            Times[ 0.88706379305918381, 
              c[ -14][ t]], 
            Times[ 0.82699334313268813, 
              c[ -13][ t]], 
            Times[ 0.75682672864065692, 
              c[ -12][ t]], 
            Times[ 0.67835603854706317, 
              c[ -11][ t]], 
            Times[ 0.59356153372868026, 
              c[ -10][ t]], 
            Times[ 0.50455115242710469, 
              c[ -9][ t]], 
            Times[ 0.41349667156634395, 
              c[ -8][ t]], 
            Times[ 0.32256865202152135, 
              c[ -7][ t]], 
            Times[ 0.23387232094715985, 
              c[ -6][ t]], 
            Times[ 0.14938649372796345, 
              c[ -5][ t]], 
            Times[ 0.070907514257657622, 
              c[ -4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.062044074975450343, 
              c[ -2][ t]], 
            Times[ -0.11423673049785445, 
              c[ -1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 0][ t]], 
            Times[ -0.18675027222298601, 
              c[ 1][ t]], 
            Times[ -0.206748335783172, 
              c[ 2][ t]], 
            Times[ -0.21623620818304484, 
              c[ 3][ t]], 
            Times[ -0.21584055771952013, 
              c[ 4][ t]], 
            Times[ -0.20645618564475843, 
              c[ 5][ t]], 
            Times[ -0.18920668216016426, 
              c[ 6][ t]], 
            Times[ -0.16539866862653771, 
              c[ 7][ t]], 
            Times[ -0.13647135277833605, 
              c[ 8][ t]], 
            Times[ -0.10394325375429328, 
              c[ 9][ t]], 
            Times[ -0.06935801494512607, 
              c[ 10][ t]], 
            Times[ -0.034231213779558949, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.032022748374425904, 
              c[ 13][ t]], 
            Times[ 0.060688263076985105, 
              c[ 14][ t]], 
            Times[ 0.085044480344421705, 
              c[ 15][ t]], 
            Times[ 0.10436044624225685, 
              c[ 16][ t]], 
            Times[ 0.11814190616181255, 
              c[ 17][ t]], 
            Times[ 0.12613778810677614, 
              c[ 18][ t]], 
            Times[ 0.12833762891430928, 
              c[ 19][ t]], 
            Times[ 0.12496032289024853, 
              c[ 20][ t]], 
            Times[ 0.11643488132933186, 
              c[ 21][ t]], 
            Times[ 0.10337416789158609, 
              c[ 22][ t]], 
            Times[ 0.086542809078944891, 
              c[ 23][ t]], 
            Times[ 0.066820663127759972, 
              c[ 24][ t]], 
            Times[ 0.045163358568919301, 
              c[ 25][ t]], 
            Times[ 0.022561481809254869, 
              c[ 26][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 27][ t]], 
            Times[ -0.021580547817547879, 
              c[ 28][ t]], 
            Times[ -0.04131966847794722, 
              c[ 29][ t]], 
            Times[ -0.058468080236789913, 
              c[ 30][ t]], 
            Times[ -0.072413370861974122, 
              c[ 31][ t]], 
            Times[ -0.082699334313268744, 
              c[ 32][ t]], 
            Times[ -0.089038438663606695, 
              c[ 33][ t]], 
            Times[ -0.091317159035181589, 
              c[ 34][ t]], 
            Times[ -0.089594193770366884, 
              c[ 35][ t]], 
            Times[ -0.084091858737850814, 
              c[ 36][ t]], 
            Times[ -0.075181213012062598, 
              c[ 37][ t]], 
            Times[ -0.063361699504227528, 
              c[ 38][ t]], 
            Times[ -0.049236278094138941, 
              c[ 39][ t]], 
            Times[ -0.033483179628681567, 
              c[ 40][ t]], 
            Times[ -0.016825511857749401, 
              c[ 41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.016273855731265604, 
              c[ 43][ t]], 
            Times[ 0.031322974491347078, 
              c[ 44][ t]], 
            Times[ 0.044547108751839919, 
              c[ 45][ t]], 
            Times[ 0.055441487066198933, 
              c[ 46][ t]], 
            Times[ 0.063614872548668253, 
              c[ 47][ t]], 
            Times[ 0.068802429876423349, 
              c[ 48][ t]], 
            Times[ 0.070873018952678238, 
              c[ 49][ t]], 
            Times[ 0.069830768673962415, 
              c[ 50][ t]], 
            Times[ 0.065811019881796273, 
              c[ 51][ t]], 
            Times[ 0.059070953080906326, 
              c[ 52][ t]], 
            Times[ 0.049975424961080865, 
              c[ 53][ t]], 
            Times[ 0.03897872015785999, 
              c[ 54][ t]], 
            Times[ 0.026603074225527826, 
              c[ 55][ t]], 
            Times[ 0.013414935129827233, 
              c[ 56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ -0.013061910521147383, 
              c[ 58][ t]], 
            Times[ -0.025221096343682053, 
              c[ 59][ t]], 
            Times[ -0.035980357068793781, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-17\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-17\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.045163358568919114`\ \(c[\(-60\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-59\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-58\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-57\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-56\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-55\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-54\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-53\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-52\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-51\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-50\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-49\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-48\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-47\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-46\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-45\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-44\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-43\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-42\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-41\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-40\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-39\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-38\)]\)[t] - 
            0.206748335783172`\ \(c[\(-37\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-36\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-35\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-34\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-33\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-31\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-30\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-29\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-28\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-27\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-26\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-25\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-24\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-23\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-22\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-21\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-20\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-19\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-18\)]\)[t] + 
            7.338479270921831`\ \(c[\(-17\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-16\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-15\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-14\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-13\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-12\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-11\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-10\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-9\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-8\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-7\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-6\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-5\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-4\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-3\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-2\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-1\)]\)[t] - 
            0.11423673049785436`\ \(c[0]\)[t] - 
            0.15591488063143974`\ \(c[1]\)[t] - 
            0.186750272222986`\ \(c[2]\)[t] - 
            0.206748335783172`\ \(c[3]\)[t] - 
            0.21623620818304484`\ \(c[4]\)[t] - 
            0.21584055771952015`\ \(c[5]\)[t] - 
            0.20645618564475843`\ \(c[6]\)[t] - 
            0.18920668216016426`\ \(c[7]\)[t] - 
            0.1653986686265377`\ \(c[8]\)[t] - 
            0.13647135277833605`\ \(c[9]\)[t] - 
            0.10394325375429328`\ \(c[10]\)[t] - 
            0.06935801494512607`\ \(c[11]\)[t] - 
            0.03423121377955895`\ \(c[12]\)[t] - 
            3.898171832519376`*^-17\ \(c[13]\)[t] + 
            0.032022748374425904`\ \(c[14]\)[t] + 
            0.060688263076985105`\ \(c[15]\)[t] + 
            0.0850444803444217`\ \(c[16]\)[t] + 
            0.10436044624225685`\ \(c[17]\)[t] + 
            0.11814190616181255`\ \(c[18]\)[t] + 
            0.12613778810677614`\ \(c[19]\)[t] + 
            0.12833762891430928`\ \(c[20]\)[t] + 
            0.12496032289024853`\ \(c[21]\)[t] + 
            0.11643488132933186`\ \(c[22]\)[t] + 
            0.10337416789158609`\ \(c[23]\)[t] + 
            0.08654280907894489`\ \(c[24]\)[t] + 
            0.06682066312775997`\ \(c[25]\)[t] + 
            0.0451633585689193`\ \(c[26]\)[t] + 
            0.02256148180925487`\ \(c[27]\)[t] + 
            3.8981718325193755`*^-17\ \(c[28]\)[t] - 
            0.02158054781754788`\ \(c[29]\)[t] - 
            0.04131966847794722`\ \(c[30]\)[t] - 
            0.05846808023678991`\ \(c[31]\)[t] - 
            0.07241337086197412`\ \(c[32]\)[t] - 
            0.08269933431326874`\ \(c[33]\)[t] - 
            0.0890384386636067`\ \(c[34]\)[t] - 
            0.09131715903518159`\ \(c[35]\)[t] - 
            0.08959419377036688`\ \(c[36]\)[t] - 
            0.08409185873785081`\ \(c[37]\)[t] - 
            0.0751812130120626`\ \(c[38]\)[t] - 
            0.06336169950422753`\ \(c[39]\)[t] - 
            0.04923627809413894`\ \(c[40]\)[t] - 
            0.033483179628681706`\ \(c[41]\)[t] - 
            0.0168255118577494`\ \(c[42]\)[t] - 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.01627385573126547`\ \(c[44]\)[t] + 
            0.03132297449134708`\ \(c[45]\)[t] + 
            0.04454710875183992`\ \(c[46]\)[t] + 
            0.055441487066198857`\ \(c[47]\)[t] + 
            0.06361487254866825`\ \(c[48]\)[t] + 
            0.06880242987642335`\ \(c[49]\)[t] + 
            0.07087301895267824`\ \(c[50]\)[t] + 
            0.06983076867396242`\ \(c[51]\)[t] + 
            0.06581101988179627`\ \(c[52]\)[t] + 
            0.0590709530809064`\ \(c[53]\)[t] + 
            0.049975424961080865`\ \(c[54]\)[t] + 
            0.03897872015785999`\ \(c[55]\)[t] + 
            0.026603074225527937`\ \(c[56]\)[t] + 
            0.013414935129827233`\ \(c[57]\)[t] + 
            3.898171832519376`*^-17\ \(c[58]\)[t] - 
            0.013061910521147276`\ \(c[59]\)[t] - 
            0.025221096343682053`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -17, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -17]][ t]], 
          Plus[ 
            Times[ 0.045163358568919114, 
              c[ -60][ t]], 
            Times[ 0.066820663127759972, 
              c[ -59][ t]], 
            Times[ 0.086542809078944891, 
              c[ -58][ t]], 
            Times[ 0.10337416789158595, 
              c[ -57][ t]], 
            Times[ 0.11643488132933186, 
              c[ -56][ t]], 
            Times[ 0.12496032289024853, 
              c[ -55][ t]], 
            Times[ 0.12833762891430925, 
              c[ -54][ t]], 
            Times[ 0.12613778810677612, 
              c[ -53][ t]], 
            Times[ 0.11814190616181255, 
              c[ -52][ t]], 
            Times[ 0.10436044624225692, 
              c[ -51][ t]], 
            Times[ 0.085044480344421608, 
              c[ -50][ t]], 
            Times[ 0.060688263076985105, 
              c[ -49][ t]], 
            Times[ 0.032022748374426029, 
              c[ -48][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -47][ t]], 
            Times[ -0.034231213779558949, 
              c[ -46][ t]], 
            Times[ -0.069358014945125918, 
              c[ -45][ t]], 
            Times[ -0.1039432537542934, 
              c[ -44][ t]], 
            Times[ -0.13647135277833605, 
              c[ -43][ t]], 
            Times[ -0.1653986686265376, 
              c[ -42][ t]], 
            Times[ -0.18920668216016434, 
              c[ -41][ t]], 
            Times[ -0.20645618564475843, 
              c[ -40][ t]], 
            Times[ -0.21584055771952013, 
              c[ -39][ t]], 
            Times[ -0.21623620818304484, 
              c[ -38][ t]], 
            Times[ -0.206748335783172, 
              c[ -37][ t]], 
            Times[ -0.18675027222298607, 
              c[ -36][ t]], 
            Times[ -0.15591488063143982, 
              c[ -35][ t]], 
            Times[ -0.11423673049785436, 
              c[ -34][ t]], 
            Times[ -0.062044074975450475, 
              c[ -33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ 0.070907514257657775, 
              c[ -31][ t]], 
            Times[ 0.14938649372796345, 
              c[ -30][ t]], 
            Times[ 0.23387232094715985, 
              c[ -29][ t]], 
            Times[ 0.32256865202152157, 
              c[ -28][ t]], 
            Times[ 0.41349667156634395, 
              c[ -27][ t]], 
            Times[ 0.50455115242710469, 
              c[ -26][ t]], 
            Times[ 0.59356153372868059, 
              c[ -25][ t]], 
            Times[ 0.67835603854706317, 
              c[ -24][ t]], 
            Times[ 0.75682672864065692, 
              c[ -23][ t]], 
            Times[ 0.82699334313268813, 
              c[ -22][ t]], 
            Times[ 0.88706379305918381, 
              c[ -21][ t]], 
            Times[ 0.93548928378863916, 
              c[ -20][ t]], 
            Times[ 0.9710122092317629, 
              c[ -19][ t]], 
            Times[ 0.99270519960720671, 
              c[ -18][ t]], 
            Times[ 7.3384792709218312, 
              c[ -17][ t]], 
            Times[ 0.99270519960720693, 
              c[ -16][ t]], 
            Times[ 0.9710122092317629, 
              c[ -15][ t]], 
            Times[ 0.93548928378863916, 
              c[ -14][ t]], 
            Times[ 0.88706379305918381, 
              c[ -13][ t]], 
            Times[ 0.82699334313268813, 
              c[ -12][ t]], 
            Times[ 0.75682672864065692, 
              c[ -11][ t]], 
            Times[ 0.67835603854706339, 
              c[ -10][ t]], 
            Times[ 0.59356153372868059, 
              c[ -9][ t]], 
            Times[ 0.50455115242710469, 
              c[ -8][ t]], 
            Times[ 0.41349667156634418, 
              c[ -7][ t]], 
            Times[ 0.32256865202152157, 
              c[ -6][ t]], 
            Times[ 0.23387232094715985, 
              c[ -5][ t]], 
            Times[ 0.14938649372796362, 
              c[ -4][ t]], 
            Times[ 0.070907514257657775, 
              c[ -3][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -2][ t]], 
            Times[ -0.062044074975450343, 
              c[ -1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 0][ t]], 
            Times[ -0.15591488063143974, 
              c[ 1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 2][ t]], 
            Times[ -0.206748335783172, 
              c[ 3][ t]], 
            Times[ -0.21623620818304484, 
              c[ 4][ t]], 
            Times[ -0.21584055771952015, 
              c[ 5][ t]], 
            Times[ -0.20645618564475843, 
              c[ 6][ t]], 
            Times[ -0.18920668216016426, 
              c[ 7][ t]], 
            Times[ -0.16539866862653771, 
              c[ 8][ t]], 
            Times[ -0.13647135277833605, 
              c[ 9][ t]], 
            Times[ -0.10394325375429328, 
              c[ 10][ t]], 
            Times[ -0.06935801494512607, 
              c[ 11][ t]], 
            Times[ -0.034231213779558949, 
              c[ 12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ 0.032022748374425904, 
              c[ 14][ t]], 
            Times[ 0.060688263076985105, 
              c[ 15][ t]], 
            Times[ 0.085044480344421705, 
              c[ 16][ t]], 
            Times[ 0.10436044624225685, 
              c[ 17][ t]], 
            Times[ 0.11814190616181255, 
              c[ 18][ t]], 
            Times[ 0.12613778810677614, 
              c[ 19][ t]], 
            Times[ 0.12833762891430928, 
              c[ 20][ t]], 
            Times[ 0.12496032289024853, 
              c[ 21][ t]], 
            Times[ 0.11643488132933186, 
              c[ 22][ t]], 
            Times[ 0.10337416789158609, 
              c[ 23][ t]], 
            Times[ 0.086542809078944891, 
              c[ 24][ t]], 
            Times[ 0.066820663127759972, 
              c[ 25][ t]], 
            Times[ 0.045163358568919301, 
              c[ 26][ t]], 
            Times[ 0.022561481809254869, 
              c[ 27][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 28][ t]], 
            Times[ -0.021580547817547879, 
              c[ 29][ t]], 
            Times[ -0.04131966847794722, 
              c[ 30][ t]], 
            Times[ -0.058468080236789913, 
              c[ 31][ t]], 
            Times[ -0.072413370861974122, 
              c[ 32][ t]], 
            Times[ -0.082699334313268744, 
              c[ 33][ t]], 
            Times[ -0.089038438663606695, 
              c[ 34][ t]], 
            Times[ -0.091317159035181589, 
              c[ 35][ t]], 
            Times[ -0.089594193770366884, 
              c[ 36][ t]], 
            Times[ -0.084091858737850814, 
              c[ 37][ t]], 
            Times[ -0.075181213012062598, 
              c[ 38][ t]], 
            Times[ -0.063361699504227528, 
              c[ 39][ t]], 
            Times[ -0.049236278094138941, 
              c[ 40][ t]], 
            Times[ -0.033483179628681706, 
              c[ 41][ t]], 
            Times[ -0.016825511857749401, 
              c[ 42][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.016273855731265469, 
              c[ 44][ t]], 
            Times[ 0.031322974491347078, 
              c[ 45][ t]], 
            Times[ 0.044547108751839919, 
              c[ 46][ t]], 
            Times[ 0.055441487066198857, 
              c[ 47][ t]], 
            Times[ 0.063614872548668253, 
              c[ 48][ t]], 
            Times[ 0.068802429876423349, 
              c[ 49][ t]], 
            Times[ 0.070873018952678238, 
              c[ 50][ t]], 
            Times[ 0.069830768673962415, 
              c[ 51][ t]], 
            Times[ 0.065811019881796273, 
              c[ 52][ t]], 
            Times[ 0.059070953080906402, 
              c[ 53][ t]], 
            Times[ 0.049975424961080865, 
              c[ 54][ t]], 
            Times[ 0.03897872015785999, 
              c[ 55][ t]], 
            Times[ 0.026603074225527937, 
              c[ 56][ t]], 
            Times[ 0.013414935129827233, 
              c[ 57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ -0.013061910521147276, 
              c[ 59][ t]], 
            Times[ -0.025221096343682053, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-16\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-16\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.022561481809254675`\ \(c[\(-60\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-59\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-58\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-57\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-56\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-55\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-54\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-53\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-52\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-51\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-50\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-49\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-48\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-47\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-45\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-44\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-43\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-42\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-41\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-40\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-39\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-38\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-37\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-36\)]\)[t] - 
            0.186750272222986`\ \(c[\(-35\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-34\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-33\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-32\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-31\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-30\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-29\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-28\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-27\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-26\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-25\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-24\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-23\)]\)[t] + 
            0.7568267286406571`\ \(c[\(-22\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-21\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-20\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-19\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-18\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-17\)]\)[t] + 
            6.614708281508612`\ \(c[\(-16\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-15\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-14\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-13\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-12\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-11\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-10\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-9\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-8\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-7\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-6\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-5\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-4\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-3\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-2\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-1\)]\)[t] - 
            0.06204407497545034`\ \(c[0]\)[t] - 
            0.11423673049785436`\ \(c[1]\)[t] - 
            0.15591488063143982`\ \(c[2]\)[t] - 
            0.186750272222986`\ \(c[3]\)[t] - 
            0.206748335783172`\ \(c[4]\)[t] - 
            0.21623620818304484`\ \(c[5]\)[t] - 
            0.21584055771952015`\ \(c[6]\)[t] - 
            0.20645618564475843`\ \(c[7]\)[t] - 
            0.18920668216016426`\ \(c[8]\)[t] - 
            0.1653986686265377`\ \(c[9]\)[t] - 
            0.13647135277833605`\ \(c[10]\)[t] - 
            0.10394325375429328`\ \(c[11]\)[t] - 
            0.06935801494512607`\ \(c[12]\)[t] - 
            0.03423121377955895`\ \(c[13]\)[t] - 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.032022748374425904`\ \(c[15]\)[t] + 
            0.060688263076985105`\ \(c[16]\)[t] + 
            0.0850444803444217`\ \(c[17]\)[t] + 
            0.10436044624225685`\ \(c[18]\)[t] + 
            0.11814190616181255`\ \(c[19]\)[t] + 
            0.12613778810677614`\ \(c[20]\)[t] + 
            0.12833762891430928`\ \(c[21]\)[t] + 
            0.12496032289024853`\ \(c[22]\)[t] + 
            0.11643488132933186`\ \(c[23]\)[t] + 
            0.10337416789158609`\ \(c[24]\)[t] + 
            0.08654280907894489`\ \(c[25]\)[t] + 
            0.06682066312775997`\ \(c[26]\)[t] + 
            0.0451633585689193`\ \(c[27]\)[t] + 
            0.02256148180925487`\ \(c[28]\)[t] + 
            3.8981718325193755`*^-17\ \(c[29]\)[t] - 
            0.02158054781754788`\ \(c[30]\)[t] - 
            0.04131966847794722`\ \(c[31]\)[t] - 
            0.05846808023678991`\ \(c[32]\)[t] - 
            0.07241337086197412`\ \(c[33]\)[t] - 
            0.08269933431326874`\ \(c[34]\)[t] - 
            0.0890384386636067`\ \(c[35]\)[t] - 
            0.09131715903518159`\ \(c[36]\)[t] - 
            0.08959419377036688`\ \(c[37]\)[t] - 
            0.08409185873785081`\ \(c[38]\)[t] - 
            0.0751812130120626`\ \(c[39]\)[t] - 
            0.06336169950422753`\ \(c[40]\)[t] - 
            0.049236278094139066`\ \(c[41]\)[t] - 
            0.03348317962868157`\ \(c[42]\)[t] - 
            0.0168255118577494`\ \(c[43]\)[t] - 
            1.8033970416801674`*^-16\ \(c[44]\)[t] + 
            0.016273855731265604`\ \(c[45]\)[t] + 
            0.03132297449134708`\ \(c[46]\)[t] + 
            0.044547108751839815`\ \(c[47]\)[t] + 
            0.05544148706619893`\ \(c[48]\)[t] + 
            0.06361487254866825`\ \(c[49]\)[t] + 
            0.06880242987642332`\ \(c[50]\)[t] + 
            0.07087301895267824`\ \(c[51]\)[t] + 
            0.06983076867396242`\ \(c[52]\)[t] + 
            0.06581101988179631`\ \(c[53]\)[t] + 
            0.059070953080906326`\ \(c[54]\)[t] + 
            0.049975424961080865`\ \(c[55]\)[t] + 
            0.03897872015786009`\ \(c[56]\)[t] + 
            0.026603074225527826`\ \(c[57]\)[t] + 
            0.013414935129827233`\ \(c[58]\)[t] + 
            1.5206810699945212`*^-16\ \(c[59]\)[t] - 
            0.013061910521147383`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -16, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -16]][ t]], 
          Plus[ 
            Times[ 0.022561481809254675, 
              c[ -60][ t]], 
            Times[ 0.045163358568919301, 
              c[ -59][ t]], 
            Times[ 0.066820663127759972, 
              c[ -58][ t]], 
            Times[ 0.086542809078944752, 
              c[ -57][ t]], 
            Times[ 0.10337416789158609, 
              c[ -56][ t]], 
            Times[ 0.11643488132933186, 
              c[ -55][ t]], 
            Times[ 0.12496032289024847, 
              c[ -54][ t]], 
            Times[ 0.12833762891430928, 
              c[ -53][ t]], 
            Times[ 0.12613778810677614, 
              c[ -52][ t]], 
            Times[ 0.1181419061618126, 
              c[ -51][ t]], 
            Times[ 0.10436044624225685, 
              c[ -50][ t]], 
            Times[ 0.085044480344421705, 
              c[ -49][ t]], 
            Times[ 0.060688263076985223, 
              c[ -48][ t]], 
            Times[ 0.032022748374425904, 
              c[ -47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ -0.034231213779558796, 
              c[ -45][ t]], 
            Times[ -0.06935801494512607, 
              c[ -44][ t]], 
            Times[ -0.10394325375429328, 
              c[ -43][ t]], 
            Times[ -0.13647135277833591, 
              c[ -42][ t]], 
            Times[ -0.16539866862653771, 
              c[ -41][ t]], 
            Times[ -0.18920668216016426, 
              c[ -40][ t]], 
            Times[ -0.20645618564475834, 
              c[ -39][ t]], 
            Times[ -0.21584055771952015, 
              c[ -38][ t]], 
            Times[ -0.21623620818304484, 
              c[ -37][ t]], 
            Times[ -0.20674833578317206, 
              c[ -36][ t]], 
            Times[ -0.18675027222298601, 
              c[ -35][ t]], 
            Times[ -0.15591488063143974, 
              c[ -34][ t]], 
            Times[ -0.11423673049785445, 
              c[ -33][ t]], 
            Times[ -0.062044074975450343, 
              c[ -32][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -31][ t]], 
            Times[ 0.070907514257657622, 
              c[ -30][ t]], 
            Times[ 0.14938649372796362, 
              c[ -29][ t]], 
            Times[ 0.23387232094715998, 
              c[ -28][ t]], 
            Times[ 0.32256865202152135, 
              c[ -27][ t]], 
            Times[ 0.41349667156634418, 
              c[ -26][ t]], 
            Times[ 0.50455115242710491, 
              c[ -25][ t]], 
            Times[ 0.59356153372868026, 
              c[ -24][ t]], 
            Times[ 0.67835603854706339, 
              c[ -23][ t]], 
            Times[ 0.75682672864065714, 
              c[ -22][ t]], 
            Times[ 0.82699334313268813, 
              c[ -21][ t]], 
            Times[ 0.88706379305918381, 
              c[ -20][ t]], 
            Times[ 0.93548928378863916, 
              c[ -19][ t]], 
            Times[ 0.9710122092317629, 
              c[ -18][ t]], 
            Times[ 0.99270519960720693, 
              c[ -17][ t]], 
            Times[ 6.6147082815086122, 
              c[ -16][ t]], 
            Times[ 0.99270519960720693, 
              c[ -15][ t]], 
            Times[ 0.9710122092317629, 
              c[ -14][ t]], 
            Times[ 0.93548928378863916, 
              c[ -13][ t]], 
            Times[ 0.88706379305918381, 
              c[ -12][ t]], 
            Times[ 0.82699334313268813, 
              c[ -11][ t]], 
            Times[ 0.75682672864065692, 
              c[ -10][ t]], 
            Times[ 0.67835603854706339, 
              c[ -9][ t]], 
            Times[ 0.59356153372868048, 
              c[ -8][ t]], 
            Times[ 0.50455115242710469, 
              c[ -7][ t]], 
            Times[ 0.41349667156634418, 
              c[ -6][ t]], 
            Times[ 0.32256865202152157, 
              c[ -5][ t]], 
            Times[ 0.23387232094715985, 
              c[ -4][ t]], 
            Times[ 0.14938649372796362, 
              c[ -3][ t]], 
            Times[ 0.070907514257657775, 
              c[ -2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 0][ t]], 
            Times[ -0.11423673049785436, 
              c[ 1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 2][ t]], 
            Times[ -0.18675027222298601, 
              c[ 3][ t]], 
            Times[ -0.206748335783172, 
              c[ 4][ t]], 
            Times[ -0.21623620818304484, 
              c[ 5][ t]], 
            Times[ -0.21584055771952015, 
              c[ 6][ t]], 
            Times[ -0.20645618564475843, 
              c[ 7][ t]], 
            Times[ -0.18920668216016426, 
              c[ 8][ t]], 
            Times[ -0.16539866862653771, 
              c[ 9][ t]], 
            Times[ -0.13647135277833605, 
              c[ 10][ t]], 
            Times[ -0.10394325375429328, 
              c[ 11][ t]], 
            Times[ -0.06935801494512607, 
              c[ 12][ t]], 
            Times[ -0.034231213779558949, 
              c[ 13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.032022748374425904, 
              c[ 15][ t]], 
            Times[ 0.060688263076985105, 
              c[ 16][ t]], 
            Times[ 0.085044480344421705, 
              c[ 17][ t]], 
            Times[ 0.10436044624225685, 
              c[ 18][ t]], 
            Times[ 0.11814190616181255, 
              c[ 19][ t]], 
            Times[ 0.12613778810677614, 
              c[ 20][ t]], 
            Times[ 0.12833762891430928, 
              c[ 21][ t]], 
            Times[ 0.12496032289024853, 
              c[ 22][ t]], 
            Times[ 0.11643488132933186, 
              c[ 23][ t]], 
            Times[ 0.10337416789158609, 
              c[ 24][ t]], 
            Times[ 0.086542809078944891, 
              c[ 25][ t]], 
            Times[ 0.066820663127759972, 
              c[ 26][ t]], 
            Times[ 0.045163358568919301, 
              c[ 27][ t]], 
            Times[ 0.022561481809254869, 
              c[ 28][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 29][ t]], 
            Times[ -0.021580547817547879, 
              c[ 30][ t]], 
            Times[ -0.04131966847794722, 
              c[ 31][ t]], 
            Times[ -0.058468080236789913, 
              c[ 32][ t]], 
            Times[ -0.072413370861974122, 
              c[ 33][ t]], 
            Times[ -0.082699334313268744, 
              c[ 34][ t]], 
            Times[ -0.089038438663606695, 
              c[ 35][ t]], 
            Times[ -0.091317159035181589, 
              c[ 36][ t]], 
            Times[ -0.089594193770366884, 
              c[ 37][ t]], 
            Times[ -0.084091858737850814, 
              c[ 38][ t]], 
            Times[ -0.075181213012062598, 
              c[ 39][ t]], 
            Times[ -0.063361699504227528, 
              c[ 40][ t]], 
            Times[ -0.049236278094139066, 
              c[ 41][ t]], 
            Times[ -0.033483179628681567, 
              c[ 42][ t]], 
            Times[ -0.016825511857749401, 
              c[ 43][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 44][ t]], 
            Times[ 0.016273855731265604, 
              c[ 45][ t]], 
            Times[ 0.031322974491347078, 
              c[ 46][ t]], 
            Times[ 0.044547108751839815, 
              c[ 47][ t]], 
            Times[ 0.055441487066198933, 
              c[ 48][ t]], 
            Times[ 0.063614872548668253, 
              c[ 49][ t]], 
            Times[ 0.068802429876423321, 
              c[ 50][ t]], 
            Times[ 0.070873018952678238, 
              c[ 51][ t]], 
            Times[ 0.069830768673962415, 
              c[ 52][ t]], 
            Times[ 0.065811019881796315, 
              c[ 53][ t]], 
            Times[ 0.059070953080906326, 
              c[ 54][ t]], 
            Times[ 0.049975424961080865, 
              c[ 55][ t]], 
            Times[ 0.038978720157860088, 
              c[ 56][ t]], 
            Times[ 0.026603074225527826, 
              c[ 57][ t]], 
            Times[ 0.013414935129827233, 
              c[ 58][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ 59][ t]], 
            Times[ -0.013061910521147383, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-15\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-15\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.8981718325193755`*^-17\ \(c[\(-60\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-59\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-58\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-57\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-56\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-55\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-54\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-53\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-52\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-51\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-50\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-49\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-48\)]\)[t] + 
            0.060688263076985`\ \(c[\(-47\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-46\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-44\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-43\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-42\)]\)[t] - 
            0.13647135277833616`\ \(c[\(-41\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-40\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-39\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-38\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-37\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-36\)]\)[t] - 
            0.206748335783172`\ \(c[\(-35\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-34\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-33\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-32\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-29\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-28\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-27\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-26\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-25\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-24\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-23\)]\)[t] + 
            0.6783560385470636`\ \(c[\(-22\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-21\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-20\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-19\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-18\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-17\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-16\)]\)[t] + 
            5.934802200544679`\ \(c[\(-15\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-14\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-13\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-12\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-11\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-10\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-9\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-8\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-7\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-6\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-5\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-4\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-3\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-2\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-1\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.06204407497545034`\ \(c[1]\)[t] - 
            0.11423673049785445`\ \(c[2]\)[t] - 
            0.15591488063143982`\ \(c[3]\)[t] - 
            0.186750272222986`\ \(c[4]\)[t] - 
            0.206748335783172`\ \(c[5]\)[t] - 
            0.21623620818304484`\ \(c[6]\)[t] - 
            0.21584055771952015`\ \(c[7]\)[t] - 
            0.20645618564475843`\ \(c[8]\)[t] - 
            0.18920668216016426`\ \(c[9]\)[t] - 
            0.1653986686265377`\ \(c[10]\)[t] - 
            0.13647135277833605`\ \(c[11]\)[t] - 
            0.10394325375429328`\ \(c[12]\)[t] - 
            0.06935801494512607`\ \(c[13]\)[t] - 
            0.03423121377955895`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.032022748374425904`\ \(c[16]\)[t] + 
            0.060688263076985105`\ \(c[17]\)[t] + 
            0.0850444803444217`\ \(c[18]\)[t] + 
            0.10436044624225685`\ \(c[19]\)[t] + 
            0.11814190616181255`\ \(c[20]\)[t] + 
            0.12613778810677614`\ \(c[21]\)[t] + 
            0.12833762891430928`\ \(c[22]\)[t] + 
            0.12496032289024853`\ \(c[23]\)[t] + 
            0.11643488132933186`\ \(c[24]\)[t] + 
            0.10337416789158609`\ \(c[25]\)[t] + 
            0.08654280907894489`\ \(c[26]\)[t] + 
            0.06682066312775997`\ \(c[27]\)[t] + 
            0.0451633585689193`\ \(c[28]\)[t] + 
            0.02256148180925487`\ \(c[29]\)[t] + 
            3.8981718325193755`*^-17\ \(c[30]\)[t] - 
            0.02158054781754788`\ \(c[31]\)[t] - 
            0.04131966847794722`\ \(c[32]\)[t] - 
            0.05846808023678991`\ \(c[33]\)[t] - 
            0.07241337086197412`\ \(c[34]\)[t] - 
            0.08269933431326874`\ \(c[35]\)[t] - 
            0.0890384386636067`\ \(c[36]\)[t] - 
            0.09131715903518159`\ \(c[37]\)[t] - 
            0.08959419377036688`\ \(c[38]\)[t] - 
            0.08409185873785081`\ \(c[39]\)[t] - 
            0.0751812130120626`\ \(c[40]\)[t] - 
            0.06336169950422753`\ \(c[41]\)[t] - 
            0.04923627809413894`\ \(c[42]\)[t] - 
            0.03348317962868157`\ \(c[43]\)[t] - 
            0.0168255118577494`\ \(c[44]\)[t] - 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.016273855731265604`\ \(c[46]\)[t] + 
            0.03132297449134708`\ \(c[47]\)[t] + 
            0.04454710875183992`\ \(c[48]\)[t] + 
            0.05544148706619893`\ \(c[49]\)[t] + 
            0.06361487254866825`\ \(c[50]\)[t] + 
            0.06880242987642335`\ \(c[51]\)[t] + 
            0.07087301895267824`\ \(c[52]\)[t] + 
            0.06983076867396242`\ \(c[53]\)[t] + 
            0.06581101988179627`\ \(c[54]\)[t] + 
            0.059070953080906326`\ \(c[55]\)[t] + 
            0.049975424961080865`\ \(c[56]\)[t] + 
            0.03897872015785999`\ \(c[57]\)[t] + 
            0.026603074225527826`\ \(c[58]\)[t] + 
            0.013414935129827233`\ \(c[59]\)[t] + 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -15, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -15]][ t]], 
          Plus[ 
            Times[ 3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ 0.022561481809254869, 
              c[ -59][ t]], 
            Times[ 0.045163358568919301, 
              c[ -58][ t]], 
            Times[ 0.066820663127759972, 
              c[ -57][ t]], 
            Times[ 0.086542809078944891, 
              c[ -56][ t]], 
            Times[ 0.10337416789158609, 
              c[ -55][ t]], 
            Times[ 0.11643488132933186, 
              c[ -54][ t]], 
            Times[ 0.12496032289024853, 
              c[ -53][ t]], 
            Times[ 0.12833762891430928, 
              c[ -52][ t]], 
            Times[ 0.12613778810677614, 
              c[ -51][ t]], 
            Times[ 0.11814190616181253, 
              c[ -50][ t]], 
            Times[ 0.10436044624225685, 
              c[ -49][ t]], 
            Times[ 0.085044480344421705, 
              c[ -48][ t]], 
            Times[ 0.060688263076985001, 
              c[ -47][ t]], 
            Times[ 0.032022748374425904, 
              c[ -46][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.034231213779559094, 
              c[ -44][ t]], 
            Times[ -0.06935801494512607, 
              c[ -43][ t]], 
            Times[ -0.10394325375429328, 
              c[ -42][ t]], 
            Times[ -0.13647135277833616, 
              c[ -41][ t]], 
            Times[ -0.16539866862653771, 
              c[ -40][ t]], 
            Times[ -0.18920668216016426, 
              c[ -39][ t]], 
            Times[ -0.20645618564475843, 
              c[ -38][ t]], 
            Times[ -0.21584055771952015, 
              c[ -37][ t]], 
            Times[ -0.21623620818304484, 
              c[ -36][ t]], 
            Times[ -0.206748335783172, 
              c[ -35][ t]], 
            Times[ -0.18675027222298593, 
              c[ -34][ t]], 
            Times[ -0.15591488063143982, 
              c[ -33][ t]], 
            Times[ -0.11423673049785436, 
              c[ -32][ t]], 
            Times[ -0.062044074975450239, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.070907514257657775, 
              c[ -29][ t]], 
            Times[ 0.14938649372796384, 
              c[ -28][ t]], 
            Times[ 0.23387232094715985, 
              c[ -27][ t]], 
            Times[ 0.32256865202152157, 
              c[ -26][ t]], 
            Times[ 0.41349667156634429, 
              c[ -25][ t]], 
            Times[ 0.50455115242710469, 
              c[ -24][ t]], 
            Times[ 0.59356153372868059, 
              c[ -23][ t]], 
            Times[ 0.67835603854706361, 
              c[ -22][ t]], 
            Times[ 0.75682672864065692, 
              c[ -21][ t]], 
            Times[ 0.82699334313268813, 
              c[ -20][ t]], 
            Times[ 0.88706379305918381, 
              c[ -19][ t]], 
            Times[ 0.93548928378863916, 
              c[ -18][ t]], 
            Times[ 0.9710122092317629, 
              c[ -17][ t]], 
            Times[ 0.99270519960720693, 
              c[ -16][ t]], 
            Times[ 5.934802200544679, 
              c[ -15][ t]], 
            Times[ 0.99270519960720671, 
              c[ -14][ t]], 
            Times[ 0.9710122092317629, 
              c[ -13][ t]], 
            Times[ 0.93548928378863916, 
              c[ -12][ t]], 
            Times[ 0.88706379305918381, 
              c[ -11][ t]], 
            Times[ 0.82699334313268813, 
              c[ -10][ t]], 
            Times[ 0.75682672864065692, 
              c[ -9][ t]], 
            Times[ 0.67835603854706328, 
              c[ -8][ t]], 
            Times[ 0.59356153372868026, 
              c[ -7][ t]], 
            Times[ 0.50455115242710469, 
              c[ -6][ t]], 
            Times[ 0.41349667156634395, 
              c[ -5][ t]], 
            Times[ 0.32256865202152135, 
              c[ -4][ t]], 
            Times[ 0.23387232094715985, 
              c[ -3][ t]], 
            Times[ 0.14938649372796362, 
              c[ -2][ t]], 
            Times[ 0.070907514257657622, 
              c[ -1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.062044074975450343, 
              c[ 1][ t]], 
            Times[ -0.11423673049785445, 
              c[ 2][ t]], 
            Times[ -0.15591488063143982, 
              c[ 3][ t]], 
            Times[ -0.18675027222298601, 
              c[ 4][ t]], 
            Times[ -0.206748335783172, 
              c[ 5][ t]], 
            Times[ -0.21623620818304484, 
              c[ 6][ t]], 
            Times[ -0.21584055771952015, 
              c[ 7][ t]], 
            Times[ -0.20645618564475843, 
              c[ 8][ t]], 
            Times[ -0.18920668216016426, 
              c[ 9][ t]], 
            Times[ -0.16539866862653771, 
              c[ 10][ t]], 
            Times[ -0.13647135277833605, 
              c[ 11][ t]], 
            Times[ -0.10394325375429328, 
              c[ 12][ t]], 
            Times[ -0.06935801494512607, 
              c[ 13][ t]], 
            Times[ -0.034231213779558949, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.032022748374425904, 
              c[ 16][ t]], 
            Times[ 0.060688263076985105, 
              c[ 17][ t]], 
            Times[ 0.085044480344421705, 
              c[ 18][ t]], 
            Times[ 0.10436044624225685, 
              c[ 19][ t]], 
            Times[ 0.11814190616181255, 
              c[ 20][ t]], 
            Times[ 0.12613778810677614, 
              c[ 21][ t]], 
            Times[ 0.12833762891430928, 
              c[ 22][ t]], 
            Times[ 0.12496032289024853, 
              c[ 23][ t]], 
            Times[ 0.11643488132933186, 
              c[ 24][ t]], 
            Times[ 0.10337416789158609, 
              c[ 25][ t]], 
            Times[ 0.086542809078944891, 
              c[ 26][ t]], 
            Times[ 0.066820663127759972, 
              c[ 27][ t]], 
            Times[ 0.045163358568919301, 
              c[ 28][ t]], 
            Times[ 0.022561481809254869, 
              c[ 29][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 30][ t]], 
            Times[ -0.021580547817547879, 
              c[ 31][ t]], 
            Times[ -0.04131966847794722, 
              c[ 32][ t]], 
            Times[ -0.058468080236789913, 
              c[ 33][ t]], 
            Times[ -0.072413370861974122, 
              c[ 34][ t]], 
            Times[ -0.082699334313268744, 
              c[ 35][ t]], 
            Times[ -0.089038438663606695, 
              c[ 36][ t]], 
            Times[ -0.091317159035181589, 
              c[ 37][ t]], 
            Times[ -0.089594193770366884, 
              c[ 38][ t]], 
            Times[ -0.084091858737850814, 
              c[ 39][ t]], 
            Times[ -0.075181213012062598, 
              c[ 40][ t]], 
            Times[ -0.063361699504227528, 
              c[ 41][ t]], 
            Times[ -0.049236278094138941, 
              c[ 42][ t]], 
            Times[ -0.033483179628681567, 
              c[ 43][ t]], 
            Times[ -0.016825511857749401, 
              c[ 44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.016273855731265604, 
              c[ 46][ t]], 
            Times[ 0.031322974491347078, 
              c[ 47][ t]], 
            Times[ 0.044547108751839919, 
              c[ 48][ t]], 
            Times[ 0.055441487066198933, 
              c[ 49][ t]], 
            Times[ 0.063614872548668253, 
              c[ 50][ t]], 
            Times[ 0.068802429876423349, 
              c[ 51][ t]], 
            Times[ 0.070873018952678238, 
              c[ 52][ t]], 
            Times[ 0.069830768673962415, 
              c[ 53][ t]], 
            Times[ 0.065811019881796273, 
              c[ 54][ t]], 
            Times[ 0.059070953080906326, 
              c[ 55][ t]], 
            Times[ 0.049975424961080865, 
              c[ 56][ t]], 
            Times[ 0.03897872015785999, 
              c[ 57][ t]], 
            Times[ 0.026603074225527826, 
              c[ 58][ t]], 
            Times[ 0.013414935129827233, 
              c[ 59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-14\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-14\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.021580547817548056`\)\ \(c[\(-60\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-59\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-58\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-57\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-56\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-55\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-54\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-53\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-52\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-51\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-50\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-49\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-48\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-47\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-46\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-45\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-44\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-43\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-42\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-41\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-40\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-39\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-38\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-37\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-36\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-35\)]\)[t] - 
            0.206748335783172`\ \(c[\(-34\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-33\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-32\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-31\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-30\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-28\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-27\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-26\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-25\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-24\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-23\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-22\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-21\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-20\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-19\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-18\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-17\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-16\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-15\)]\)[t] + 
            5.298761028030031`\ \(c[\(-14\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-13\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-12\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-11\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-10\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-9\)]\)[t] + 
            0.756826728640657`\ \(c[\(-8\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-7\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-6\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-5\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-4\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-3\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-2\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-1\)]\)[t] + 
            0.07090751425765777`\ \(c[0]\)[t] + 
            1.8033970416801674`*^-16\ \(c[1]\)[t] - 
            0.06204407497545034`\ \(c[2]\)[t] - 
            0.11423673049785436`\ \(c[3]\)[t] - 
            0.15591488063143974`\ \(c[4]\)[t] - 
            0.18675027222298593`\ \(c[5]\)[t] - 
            0.206748335783172`\ \(c[6]\)[t] - 
            0.21623620818304484`\ \(c[7]\)[t] - 
            0.21584055771952015`\ \(c[8]\)[t] - 
            0.20645618564475843`\ \(c[9]\)[t] - 
            0.18920668216016426`\ \(c[10]\)[t] - 
            0.1653986686265377`\ \(c[11]\)[t] - 
            0.13647135277833605`\ \(c[12]\)[t] - 
            0.10394325375429328`\ \(c[13]\)[t] - 
            0.06935801494512607`\ \(c[14]\)[t] - 
            0.03423121377955895`\ \(c[15]\)[t] - 
            3.898171832519376`*^-17\ \(c[16]\)[t] + 
            0.032022748374425904`\ \(c[17]\)[t] + 
            0.060688263076985105`\ \(c[18]\)[t] + 
            0.0850444803444217`\ \(c[19]\)[t] + 
            0.10436044624225685`\ \(c[20]\)[t] + 
            0.11814190616181255`\ \(c[21]\)[t] + 
            0.12613778810677612`\ \(c[22]\)[t] + 
            0.12833762891430928`\ \(c[23]\)[t] + 
            0.12496032289024853`\ \(c[24]\)[t] + 
            0.11643488132933186`\ \(c[25]\)[t] + 
            0.10337416789158609`\ \(c[26]\)[t] + 
            0.08654280907894489`\ \(c[27]\)[t] + 
            0.06682066312775997`\ \(c[28]\)[t] + 
            0.0451633585689193`\ \(c[29]\)[t] + 
            0.02256148180925487`\ \(c[30]\)[t] + 
            3.8981718325193755`*^-17\ \(c[31]\)[t] - 
            0.02158054781754788`\ \(c[32]\)[t] - 
            0.04131966847794722`\ \(c[33]\)[t] - 
            0.05846808023678991`\ \(c[34]\)[t] - 
            0.07241337086197412`\ \(c[35]\)[t] - 
            0.08269933431326874`\ \(c[36]\)[t] - 
            0.0890384386636067`\ \(c[37]\)[t] - 
            0.09131715903518159`\ \(c[38]\)[t] - 
            0.08959419377036688`\ \(c[39]\)[t] - 
            0.08409185873785081`\ \(c[40]\)[t] - 
            0.0751812130120627`\ \(c[41]\)[t] - 
            0.06336169950422753`\ \(c[42]\)[t] - 
            0.04923627809413894`\ \(c[43]\)[t] - 
            0.033483179628681706`\ \(c[44]\)[t] - 
            0.0168255118577494`\ \(c[45]\)[t] - 
            3.898171832519376`*^-17\ \(c[46]\)[t] + 
            0.01627385573126547`\ \(c[47]\)[t] + 
            0.03132297449134708`\ \(c[48]\)[t] + 
            0.04454710875183992`\ \(c[49]\)[t] + 
            0.055441487066198857`\ \(c[50]\)[t] + 
            0.06361487254866825`\ \(c[51]\)[t] + 
            0.06880242987642335`\ \(c[52]\)[t] + 
            0.07087301895267824`\ \(c[53]\)[t] + 
            0.06983076867396242`\ \(c[54]\)[t] + 
            0.06581101988179627`\ \(c[55]\)[t] + 
            0.0590709530809064`\ \(c[56]\)[t] + 
            0.049975424961080865`\ \(c[57]\)[t] + 
            0.03897872015785999`\ \(c[58]\)[t] + 
            0.026603074225527937`\ \(c[59]\)[t] + 
            0.013414935129827233`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -14, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -14]][ t]], 
          Plus[ 
            Times[ -0.021580547817548056, 
              c[ -60][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -59][ t]], 
            Times[ 0.022561481809254869, 
              c[ -58][ t]], 
            Times[ 0.045163358568919114, 
              c[ -57][ t]], 
            Times[ 0.066820663127759972, 
              c[ -56][ t]], 
            Times[ 0.086542809078944891, 
              c[ -55][ t]], 
            Times[ 0.10337416789158595, 
              c[ -54][ t]], 
            Times[ 0.11643488132933186, 
              c[ -53][ t]], 
            Times[ 0.12496032289024853, 
              c[ -52][ t]], 
            Times[ 0.12833762891430925, 
              c[ -51][ t]], 
            Times[ 0.12613778810677612, 
              c[ -50][ t]], 
            Times[ 0.11814190616181255, 
              c[ -49][ t]], 
            Times[ 0.10436044624225692, 
              c[ -48][ t]], 
            Times[ 0.085044480344421608, 
              c[ -47][ t]], 
            Times[ 0.060688263076985105, 
              c[ -46][ t]], 
            Times[ 0.032022748374426029, 
              c[ -45][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -44][ t]], 
            Times[ -0.034231213779558949, 
              c[ -43][ t]], 
            Times[ -0.069358014945125918, 
              c[ -42][ t]], 
            Times[ -0.1039432537542934, 
              c[ -41][ t]], 
            Times[ -0.13647135277833605, 
              c[ -40][ t]], 
            Times[ -0.1653986686265376, 
              c[ -39][ t]], 
            Times[ -0.18920668216016426, 
              c[ -38][ t]], 
            Times[ -0.20645618564475843, 
              c[ -37][ t]], 
            Times[ -0.21584055771952013, 
              c[ -36][ t]], 
            Times[ -0.21623620818304484, 
              c[ -35][ t]], 
            Times[ -0.206748335783172, 
              c[ -34][ t]], 
            Times[ -0.18675027222298607, 
              c[ -33][ t]], 
            Times[ -0.15591488063143982, 
              c[ -32][ t]], 
            Times[ -0.11423673049785436, 
              c[ -31][ t]], 
            Times[ -0.062044074975450475, 
              c[ -30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ 0.070907514257657775, 
              c[ -28][ t]], 
            Times[ 0.14938649372796345, 
              c[ -27][ t]], 
            Times[ 0.23387232094715985, 
              c[ -26][ t]], 
            Times[ 0.32256865202152157, 
              c[ -25][ t]], 
            Times[ 0.41349667156634395, 
              c[ -24][ t]], 
            Times[ 0.50455115242710469, 
              c[ -23][ t]], 
            Times[ 0.59356153372868059, 
              c[ -22][ t]], 
            Times[ 0.67835603854706317, 
              c[ -21][ t]], 
            Times[ 0.75682672864065692, 
              c[ -20][ t]], 
            Times[ 0.82699334313268813, 
              c[ -19][ t]], 
            Times[ 0.88706379305918381, 
              c[ -18][ t]], 
            Times[ 0.93548928378863916, 
              c[ -17][ t]], 
            Times[ 0.9710122092317629, 
              c[ -16][ t]], 
            Times[ 0.99270519960720671, 
              c[ -15][ t]], 
            Times[ 5.2987610280300306, 
              c[ -14][ t]], 
            Times[ 0.99270519960720693, 
              c[ -13][ t]], 
            Times[ 0.9710122092317629, 
              c[ -12][ t]], 
            Times[ 0.93548928378863916, 
              c[ -11][ t]], 
            Times[ 0.88706379305918381, 
              c[ -10][ t]], 
            Times[ 0.82699334313268813, 
              c[ -9][ t]], 
            Times[ 0.75682672864065703, 
              c[ -8][ t]], 
            Times[ 0.67835603854706339, 
              c[ -7][ t]], 
            Times[ 0.59356153372868059, 
              c[ -6][ t]], 
            Times[ 0.50455115242710469, 
              c[ -5][ t]], 
            Times[ 0.41349667156634418, 
              c[ -4][ t]], 
            Times[ 0.32256865202152157, 
              c[ -3][ t]], 
            Times[ 0.23387232094715998, 
              c[ -2][ t]], 
            Times[ 0.14938649372796362, 
              c[ -1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 0][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 2][ t]], 
            Times[ -0.11423673049785436, 
              c[ 3][ t]], 
            Times[ -0.15591488063143974, 
              c[ 4][ t]], 
            Times[ -0.18675027222298593, 
              c[ 5][ t]], 
            Times[ -0.206748335783172, 
              c[ 6][ t]], 
            Times[ -0.21623620818304484, 
              c[ 7][ t]], 
            Times[ -0.21584055771952015, 
              c[ 8][ t]], 
            Times[ -0.20645618564475843, 
              c[ 9][ t]], 
            Times[ -0.18920668216016426, 
              c[ 10][ t]], 
            Times[ -0.16539866862653771, 
              c[ 11][ t]], 
            Times[ -0.13647135277833605, 
              c[ 12][ t]], 
            Times[ -0.10394325375429328, 
              c[ 13][ t]], 
            Times[ -0.06935801494512607, 
              c[ 14][ t]], 
            Times[ -0.034231213779558949, 
              c[ 15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ 0.032022748374425904, 
              c[ 17][ t]], 
            Times[ 0.060688263076985105, 
              c[ 18][ t]], 
            Times[ 0.085044480344421705, 
              c[ 19][ t]], 
            Times[ 0.10436044624225685, 
              c[ 20][ t]], 
            Times[ 0.11814190616181255, 
              c[ 21][ t]], 
            Times[ 0.12613778810677612, 
              c[ 22][ t]], 
            Times[ 0.12833762891430928, 
              c[ 23][ t]], 
            Times[ 0.12496032289024853, 
              c[ 24][ t]], 
            Times[ 0.11643488132933186, 
              c[ 25][ t]], 
            Times[ 0.10337416789158609, 
              c[ 26][ t]], 
            Times[ 0.086542809078944891, 
              c[ 27][ t]], 
            Times[ 0.066820663127759972, 
              c[ 28][ t]], 
            Times[ 0.045163358568919301, 
              c[ 29][ t]], 
            Times[ 0.022561481809254869, 
              c[ 30][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 31][ t]], 
            Times[ -0.021580547817547879, 
              c[ 32][ t]], 
            Times[ -0.04131966847794722, 
              c[ 33][ t]], 
            Times[ -0.058468080236789913, 
              c[ 34][ t]], 
            Times[ -0.072413370861974122, 
              c[ 35][ t]], 
            Times[ -0.082699334313268744, 
              c[ 36][ t]], 
            Times[ -0.089038438663606695, 
              c[ 37][ t]], 
            Times[ -0.091317159035181589, 
              c[ 38][ t]], 
            Times[ -0.089594193770366884, 
              c[ 39][ t]], 
            Times[ -0.084091858737850814, 
              c[ 40][ t]], 
            Times[ -0.075181213012062695, 
              c[ 41][ t]], 
            Times[ -0.063361699504227528, 
              c[ 42][ t]], 
            Times[ -0.049236278094138941, 
              c[ 43][ t]], 
            Times[ -0.033483179628681706, 
              c[ 44][ t]], 
            Times[ -0.016825511857749401, 
              c[ 45][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ 0.016273855731265469, 
              c[ 47][ t]], 
            Times[ 0.031322974491347078, 
              c[ 48][ t]], 
            Times[ 0.044547108751839919, 
              c[ 49][ t]], 
            Times[ 0.055441487066198857, 
              c[ 50][ t]], 
            Times[ 0.063614872548668253, 
              c[ 51][ t]], 
            Times[ 0.068802429876423349, 
              c[ 52][ t]], 
            Times[ 0.070873018952678238, 
              c[ 53][ t]], 
            Times[ 0.069830768673962415, 
              c[ 54][ t]], 
            Times[ 0.065811019881796273, 
              c[ 55][ t]], 
            Times[ 0.059070953080906402, 
              c[ 56][ t]], 
            Times[ 0.049975424961080865, 
              c[ 57][ t]], 
            Times[ 0.03897872015785999, 
              c[ 58][ t]], 
            Times[ 0.026603074225527937, 
              c[ 59][ t]], 
            Times[ 0.013414935129827233, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-13\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-13\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04131966847794737`\)\ \(c[\(-60\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-59\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-58\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-57\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-56\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-55\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-54\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-53\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-52\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-51\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-50\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-49\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-48\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-47\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-46\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-45\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-44\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-42\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-41\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-40\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-39\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-38\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-37\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-36\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-35\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-34\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-33\)]\)[t] - 
            0.186750272222986`\ \(c[\(-32\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-31\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-30\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-29\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-28\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-27\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-26\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-25\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-24\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-23\)]\)[t] + 
            0.5045511524271049`\ \(c[\(-22\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-21\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-20\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-19\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-18\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-17\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-16\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-15\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-14\)]\)[t] + 
            4.70658476396467`\ \(c[\(-13\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-12\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-11\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-10\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-9\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-8\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-7\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-6\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-5\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-4\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-3\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-2\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-1\)]\)[t] + 
            0.14938649372796362`\ \(c[0]\)[t] + 
            0.07090751425765777`\ \(c[1]\)[t] + 
            3.898171832519376`*^-17\ \(c[2]\)[t] - 
            0.06204407497545034`\ \(c[3]\)[t] - 
            0.11423673049785436`\ \(c[4]\)[t] - 
            0.15591488063143982`\ \(c[5]\)[t] - 
            0.186750272222986`\ \(c[6]\)[t] - 
            0.206748335783172`\ \(c[7]\)[t] - 
            0.21623620818304484`\ \(c[8]\)[t] - 
            0.21584055771952015`\ \(c[9]\)[t] - 
            0.20645618564475843`\ \(c[10]\)[t] - 
            0.18920668216016426`\ \(c[11]\)[t] - 
            0.1653986686265377`\ \(c[12]\)[t] - 
            0.13647135277833605`\ \(c[13]\)[t] - 
            0.10394325375429328`\ \(c[14]\)[t] - 
            0.06935801494512607`\ \(c[15]\)[t] - 
            0.03423121377955895`\ \(c[16]\)[t] - 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.032022748374425904`\ \(c[18]\)[t] + 
            0.060688263076985105`\ \(c[19]\)[t] + 
            0.0850444803444217`\ \(c[20]\)[t] + 
            0.10436044624225685`\ \(c[21]\)[t] + 
            0.11814190616181253`\ \(c[22]\)[t] + 
            0.12613778810677614`\ \(c[23]\)[t] + 
            0.12833762891430928`\ \(c[24]\)[t] + 
            0.12496032289024853`\ \(c[25]\)[t] + 
            0.11643488132933186`\ \(c[26]\)[t] + 
            0.10337416789158609`\ \(c[27]\)[t] + 
            0.08654280907894489`\ \(c[28]\)[t] + 
            0.06682066312775997`\ \(c[29]\)[t] + 
            0.0451633585689193`\ \(c[30]\)[t] + 
            0.02256148180925487`\ \(c[31]\)[t] + 
            3.8981718325193755`*^-17\ \(c[32]\)[t] - 
            0.02158054781754788`\ \(c[33]\)[t] - 
            0.04131966847794722`\ \(c[34]\)[t] - 
            0.05846808023678991`\ \(c[35]\)[t] - 
            0.07241337086197412`\ \(c[36]\)[t] - 
            0.08269933431326874`\ \(c[37]\)[t] - 
            0.0890384386636067`\ \(c[38]\)[t] - 
            0.09131715903518159`\ \(c[39]\)[t] - 
            0.08959419377036688`\ \(c[40]\)[t] - 
            0.08409185873785086`\ \(c[41]\)[t] - 
            0.0751812130120626`\ \(c[42]\)[t] - 
            0.06336169950422753`\ \(c[43]\)[t] - 
            0.049236278094139066`\ \(c[44]\)[t] - 
            0.03348317962868157`\ \(c[45]\)[t] - 
            0.0168255118577494`\ \(c[46]\)[t] - 
            1.8033970416801674`*^-16\ \(c[47]\)[t] + 
            0.016273855731265604`\ \(c[48]\)[t] + 
            0.03132297449134708`\ \(c[49]\)[t] + 
            0.044547108751839815`\ \(c[50]\)[t] + 
            0.05544148706619893`\ \(c[51]\)[t] + 
            0.06361487254866825`\ \(c[52]\)[t] + 
            0.06880242987642332`\ \(c[53]\)[t] + 
            0.07087301895267824`\ \(c[54]\)[t] + 
            0.06983076867396242`\ \(c[55]\)[t] + 
            0.06581101988179631`\ \(c[56]\)[t] + 
            0.059070953080906326`\ \(c[57]\)[t] + 
            0.049975424961080865`\ \(c[58]\)[t] + 
            0.03897872015786009`\ \(c[59]\)[t] + 
            0.026603074225527826`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -13, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -13]][ t]], 
          Plus[ 
            Times[ -0.041319668477947373, 
              c[ -60][ t]], 
            Times[ -0.021580547817547879, 
              c[ -59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -58][ t]], 
            Times[ 0.022561481809254675, 
              c[ -57][ t]], 
            Times[ 0.045163358568919301, 
              c[ -56][ t]], 
            Times[ 0.066820663127759972, 
              c[ -55][ t]], 
            Times[ 0.086542809078944752, 
              c[ -54][ t]], 
            Times[ 0.10337416789158609, 
              c[ -53][ t]], 
            Times[ 0.11643488132933186, 
              c[ -52][ t]], 
            Times[ 0.12496032289024847, 
              c[ -51][ t]], 
            Times[ 0.12833762891430928, 
              c[ -50][ t]], 
            Times[ 0.12613778810677614, 
              c[ -49][ t]], 
            Times[ 0.1181419061618126, 
              c[ -48][ t]], 
            Times[ 0.10436044624225685, 
              c[ -47][ t]], 
            Times[ 0.085044480344421705, 
              c[ -46][ t]], 
            Times[ 0.060688263076985223, 
              c[ -45][ t]], 
            Times[ 0.032022748374425904, 
              c[ -44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.034231213779558796, 
              c[ -42][ t]], 
            Times[ -0.06935801494512607, 
              c[ -41][ t]], 
            Times[ -0.10394325375429328, 
              c[ -40][ t]], 
            Times[ -0.13647135277833591, 
              c[ -39][ t]], 
            Times[ -0.16539866862653771, 
              c[ -38][ t]], 
            Times[ -0.18920668216016426, 
              c[ -37][ t]], 
            Times[ -0.20645618564475834, 
              c[ -36][ t]], 
            Times[ -0.21584055771952015, 
              c[ -35][ t]], 
            Times[ -0.21623620818304484, 
              c[ -34][ t]], 
            Times[ -0.20674833578317206, 
              c[ -33][ t]], 
            Times[ -0.18675027222298601, 
              c[ -32][ t]], 
            Times[ -0.15591488063143974, 
              c[ -31][ t]], 
            Times[ -0.11423673049785445, 
              c[ -30][ t]], 
            Times[ -0.062044074975450343, 
              c[ -29][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -28][ t]], 
            Times[ 0.070907514257657622, 
              c[ -27][ t]], 
            Times[ 0.14938649372796362, 
              c[ -26][ t]], 
            Times[ 0.23387232094715998, 
              c[ -25][ t]], 
            Times[ 0.32256865202152135, 
              c[ -24][ t]], 
            Times[ 0.41349667156634418, 
              c[ -23][ t]], 
            Times[ 0.50455115242710491, 
              c[ -22][ t]], 
            Times[ 0.59356153372868026, 
              c[ -21][ t]], 
            Times[ 0.67835603854706339, 
              c[ -20][ t]], 
            Times[ 0.75682672864065692, 
              c[ -19][ t]], 
            Times[ 0.82699334313268813, 
              c[ -18][ t]], 
            Times[ 0.88706379305918381, 
              c[ -17][ t]], 
            Times[ 0.93548928378863916, 
              c[ -16][ t]], 
            Times[ 0.9710122092317629, 
              c[ -15][ t]], 
            Times[ 0.99270519960720693, 
              c[ -14][ t]], 
            Times[ 4.7065847639646696, 
              c[ -13][ t]], 
            Times[ 0.99270519960720693, 
              c[ -12][ t]], 
            Times[ 0.9710122092317629, 
              c[ -11][ t]], 
            Times[ 0.93548928378863916, 
              c[ -10][ t]], 
            Times[ 0.88706379305918381, 
              c[ -9][ t]], 
            Times[ 0.82699334313268824, 
              c[ -8][ t]], 
            Times[ 0.75682672864065692, 
              c[ -7][ t]], 
            Times[ 0.67835603854706339, 
              c[ -6][ t]], 
            Times[ 0.59356153372868048, 
              c[ -5][ t]], 
            Times[ 0.50455115242710469, 
              c[ -4][ t]], 
            Times[ 0.41349667156634418, 
              c[ -3][ t]], 
            Times[ 0.32256865202152157, 
              c[ -2][ t]], 
            Times[ 0.23387232094715985, 
              c[ -1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 0][ t]], 
            Times[ 0.070907514257657775, 
              c[ 1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ -0.062044074975450343, 
              c[ 3][ t]], 
            Times[ -0.11423673049785436, 
              c[ 4][ t]], 
            Times[ -0.15591488063143982, 
              c[ 5][ t]], 
            Times[ -0.18675027222298601, 
              c[ 6][ t]], 
            Times[ -0.206748335783172, 
              c[ 7][ t]], 
            Times[ -0.21623620818304484, 
              c[ 8][ t]], 
            Times[ -0.21584055771952015, 
              c[ 9][ t]], 
            Times[ -0.20645618564475843, 
              c[ 10][ t]], 
            Times[ -0.18920668216016426, 
              c[ 11][ t]], 
            Times[ -0.16539866862653771, 
              c[ 12][ t]], 
            Times[ -0.13647135277833605, 
              c[ 13][ t]], 
            Times[ -0.10394325375429328, 
              c[ 14][ t]], 
            Times[ -0.06935801494512607, 
              c[ 15][ t]], 
            Times[ -0.034231213779558949, 
              c[ 16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.032022748374425904, 
              c[ 18][ t]], 
            Times[ 0.060688263076985105, 
              c[ 19][ t]], 
            Times[ 0.085044480344421705, 
              c[ 20][ t]], 
            Times[ 0.10436044624225685, 
              c[ 21][ t]], 
            Times[ 0.11814190616181253, 
              c[ 22][ t]], 
            Times[ 0.12613778810677614, 
              c[ 23][ t]], 
            Times[ 0.12833762891430928, 
              c[ 24][ t]], 
            Times[ 0.12496032289024853, 
              c[ 25][ t]], 
            Times[ 0.11643488132933186, 
              c[ 26][ t]], 
            Times[ 0.10337416789158609, 
              c[ 27][ t]], 
            Times[ 0.086542809078944891, 
              c[ 28][ t]], 
            Times[ 0.066820663127759972, 
              c[ 29][ t]], 
            Times[ 0.045163358568919301, 
              c[ 30][ t]], 
            Times[ 0.022561481809254869, 
              c[ 31][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 32][ t]], 
            Times[ -0.021580547817547879, 
              c[ 33][ t]], 
            Times[ -0.04131966847794722, 
              c[ 34][ t]], 
            Times[ -0.058468080236789913, 
              c[ 35][ t]], 
            Times[ -0.072413370861974122, 
              c[ 36][ t]], 
            Times[ -0.082699334313268744, 
              c[ 37][ t]], 
            Times[ -0.089038438663606695, 
              c[ 38][ t]], 
            Times[ -0.091317159035181589, 
              c[ 39][ t]], 
            Times[ -0.089594193770366884, 
              c[ 40][ t]], 
            Times[ -0.084091858737850855, 
              c[ 41][ t]], 
            Times[ -0.075181213012062598, 
              c[ 42][ t]], 
            Times[ -0.063361699504227528, 
              c[ 43][ t]], 
            Times[ -0.049236278094139066, 
              c[ 44][ t]], 
            Times[ -0.033483179628681567, 
              c[ 45][ t]], 
            Times[ -0.016825511857749401, 
              c[ 46][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 47][ t]], 
            Times[ 0.016273855731265604, 
              c[ 48][ t]], 
            Times[ 0.031322974491347078, 
              c[ 49][ t]], 
            Times[ 0.044547108751839815, 
              c[ 50][ t]], 
            Times[ 0.055441487066198933, 
              c[ 51][ t]], 
            Times[ 0.063614872548668253, 
              c[ 52][ t]], 
            Times[ 0.068802429876423321, 
              c[ 53][ t]], 
            Times[ 0.070873018952678238, 
              c[ 54][ t]], 
            Times[ 0.069830768673962415, 
              c[ 55][ t]], 
            Times[ 0.065811019881796315, 
              c[ 56][ t]], 
            Times[ 0.059070953080906326, 
              c[ 57][ t]], 
            Times[ 0.049975424961080865, 
              c[ 58][ t]], 
            Times[ 0.038978720157860088, 
              c[ 59][ t]], 
            Times[ 0.026603074225527826, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-12\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-12\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05846808023678991`\)\ \(c[\(-60\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-59\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-58\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-56\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-55\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-54\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-53\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-52\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-51\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-50\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-49\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-48\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-47\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-46\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-45\)]\)[t] + 
            0.060688263076985`\ \(c[\(-44\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-43\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-41\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-40\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-39\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-38\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-37\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-36\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-35\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-34\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-33\)]\)[t] - 
            0.206748335783172`\ \(c[\(-32\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-31\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-30\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-29\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-26\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-25\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-24\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-23\)]\)[t] + 
            0.4134966715663443`\ \(c[\(-22\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-21\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-20\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-19\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-18\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-17\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-16\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-15\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-14\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-13\)]\)[t] + 
            4.158273408348594`\ \(c[\(-12\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-11\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-10\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-9\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-8\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-7\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-6\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-5\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-4\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-3\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-2\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-1\)]\)[t] + 
            0.23387232094715985`\ \(c[0]\)[t] + 
            0.14938649372796362`\ \(c[1]\)[t] + 
            0.07090751425765762`\ \(c[2]\)[t] + 
            3.898171832519376`*^-17\ \(c[3]\)[t] - 
            0.06204407497545034`\ \(c[4]\)[t] - 
            0.11423673049785436`\ \(c[5]\)[t] - 
            0.15591488063143982`\ \(c[6]\)[t] - 
            0.186750272222986`\ \(c[7]\)[t] - 
            0.206748335783172`\ \(c[8]\)[t] - 
            0.21623620818304484`\ \(c[9]\)[t] - 
            0.21584055771952015`\ \(c[10]\)[t] - 
            0.20645618564475843`\ \(c[11]\)[t] - 
            0.18920668216016426`\ \(c[12]\)[t] - 
            0.1653986686265377`\ \(c[13]\)[t] - 
            0.13647135277833605`\ \(c[14]\)[t] - 
            0.10394325375429328`\ \(c[15]\)[t] - 
            0.06935801494512607`\ \(c[16]\)[t] - 
            0.03423121377955895`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.032022748374425904`\ \(c[19]\)[t] + 
            0.060688263076985105`\ \(c[20]\)[t] + 
            0.0850444803444217`\ \(c[21]\)[t] + 
            0.10436044624225685`\ \(c[22]\)[t] + 
            0.11814190616181255`\ \(c[23]\)[t] + 
            0.12613778810677614`\ \(c[24]\)[t] + 
            0.12833762891430928`\ \(c[25]\)[t] + 
            0.12496032289024853`\ \(c[26]\)[t] + 
            0.11643488132933186`\ \(c[27]\)[t] + 
            0.10337416789158609`\ \(c[28]\)[t] + 
            0.08654280907894489`\ \(c[29]\)[t] + 
            0.06682066312775997`\ \(c[30]\)[t] + 
            0.0451633585689193`\ \(c[31]\)[t] + 
            0.02256148180925487`\ \(c[32]\)[t] + 
            3.8981718325193755`*^-17\ \(c[33]\)[t] - 
            0.02158054781754788`\ \(c[34]\)[t] - 
            0.04131966847794722`\ \(c[35]\)[t] - 
            0.05846808023678991`\ \(c[36]\)[t] - 
            0.07241337086197412`\ \(c[37]\)[t] - 
            0.08269933431326874`\ \(c[38]\)[t] - 
            0.0890384386636067`\ \(c[39]\)[t] - 
            0.09131715903518159`\ \(c[40]\)[t] - 
            0.08959419377036688`\ \(c[41]\)[t] - 
            0.08409185873785081`\ \(c[42]\)[t] - 
            0.0751812130120626`\ \(c[43]\)[t] - 
            0.06336169950422753`\ \(c[44]\)[t] - 
            0.04923627809413894`\ \(c[45]\)[t] - 
            0.03348317962868157`\ \(c[46]\)[t] - 
            0.0168255118577494`\ \(c[47]\)[t] - 
            3.898171832519376`*^-17\ \(c[48]\)[t] + 
            0.016273855731265604`\ \(c[49]\)[t] + 
            0.03132297449134708`\ \(c[50]\)[t] + 
            0.04454710875183992`\ \(c[51]\)[t] + 
            0.05544148706619893`\ \(c[52]\)[t] + 
            0.06361487254866825`\ \(c[53]\)[t] + 
            0.06880242987642335`\ \(c[54]\)[t] + 
            0.07087301895267824`\ \(c[55]\)[t] + 
            0.06983076867396242`\ \(c[56]\)[t] + 
            0.06581101988179627`\ \(c[57]\)[t] + 
            0.059070953080906326`\ \(c[58]\)[t] + 
            0.049975424961080865`\ \(c[59]\)[t] + 
            0.03897872015785999`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -12, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -12]][ t]], 
          Plus[ 
            Times[ -0.058468080236789913, 
              c[ -60][ t]], 
            Times[ -0.04131966847794722, 
              c[ -59][ t]], 
            Times[ -0.021580547817547879, 
              c[ -58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ 0.022561481809254869, 
              c[ -56][ t]], 
            Times[ 0.045163358568919301, 
              c[ -55][ t]], 
            Times[ 0.066820663127759972, 
              c[ -54][ t]], 
            Times[ 0.086542809078944891, 
              c[ -53][ t]], 
            Times[ 0.10337416789158609, 
              c[ -52][ t]], 
            Times[ 0.11643488132933186, 
              c[ -51][ t]], 
            Times[ 0.12496032289024853, 
              c[ -50][ t]], 
            Times[ 0.12833762891430928, 
              c[ -49][ t]], 
            Times[ 0.12613778810677614, 
              c[ -48][ t]], 
            Times[ 0.11814190616181253, 
              c[ -47][ t]], 
            Times[ 0.10436044624225685, 
              c[ -46][ t]], 
            Times[ 0.085044480344421705, 
              c[ -45][ t]], 
            Times[ 0.060688263076985001, 
              c[ -44][ t]], 
            Times[ 0.032022748374425904, 
              c[ -43][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.034231213779559094, 
              c[ -41][ t]], 
            Times[ -0.06935801494512607, 
              c[ -40][ t]], 
            Times[ -0.10394325375429328, 
              c[ -39][ t]], 
            Times[ -0.13647135277833605, 
              c[ -38][ t]], 
            Times[ -0.16539866862653771, 
              c[ -37][ t]], 
            Times[ -0.18920668216016426, 
              c[ -36][ t]], 
            Times[ -0.20645618564475843, 
              c[ -35][ t]], 
            Times[ -0.21584055771952015, 
              c[ -34][ t]], 
            Times[ -0.21623620818304484, 
              c[ -33][ t]], 
            Times[ -0.206748335783172, 
              c[ -32][ t]], 
            Times[ -0.18675027222298593, 
              c[ -31][ t]], 
            Times[ -0.15591488063143982, 
              c[ -30][ t]], 
            Times[ -0.11423673049785436, 
              c[ -29][ t]], 
            Times[ -0.062044074975450239, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.070907514257657775, 
              c[ -26][ t]], 
            Times[ 0.14938649372796384, 
              c[ -25][ t]], 
            Times[ 0.23387232094715985, 
              c[ -24][ t]], 
            Times[ 0.32256865202152157, 
              c[ -23][ t]], 
            Times[ 0.41349667156634429, 
              c[ -22][ t]], 
            Times[ 0.50455115242710469, 
              c[ -21][ t]], 
            Times[ 0.59356153372868059, 
              c[ -20][ t]], 
            Times[ 0.67835603854706339, 
              c[ -19][ t]], 
            Times[ 0.75682672864065692, 
              c[ -18][ t]], 
            Times[ 0.82699334313268813, 
              c[ -17][ t]], 
            Times[ 0.88706379305918381, 
              c[ -16][ t]], 
            Times[ 0.93548928378863916, 
              c[ -15][ t]], 
            Times[ 0.9710122092317629, 
              c[ -14][ t]], 
            Times[ 0.99270519960720693, 
              c[ -13][ t]], 
            Times[ 4.1582734083485944, 
              c[ -12][ t]], 
            Times[ 0.99270519960720671, 
              c[ -11][ t]], 
            Times[ 0.9710122092317629, 
              c[ -10][ t]], 
            Times[ 0.93548928378863916, 
              c[ -9][ t]], 
            Times[ 0.8870637930591837, 
              c[ -8][ t]], 
            Times[ 0.82699334313268813, 
              c[ -7][ t]], 
            Times[ 0.75682672864065692, 
              c[ -6][ t]], 
            Times[ 0.67835603854706328, 
              c[ -5][ t]], 
            Times[ 0.59356153372868026, 
              c[ -4][ t]], 
            Times[ 0.50455115242710469, 
              c[ -3][ t]], 
            Times[ 0.41349667156634418, 
              c[ -2][ t]], 
            Times[ 0.32256865202152135, 
              c[ -1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 0][ t]], 
            Times[ 0.14938649372796362, 
              c[ 1][ t]], 
            Times[ 0.070907514257657622, 
              c[ 2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ -0.062044074975450343, 
              c[ 4][ t]], 
            Times[ -0.11423673049785436, 
              c[ 5][ t]], 
            Times[ -0.15591488063143982, 
              c[ 6][ t]], 
            Times[ -0.18675027222298601, 
              c[ 7][ t]], 
            Times[ -0.206748335783172, 
              c[ 8][ t]], 
            Times[ -0.21623620818304484, 
              c[ 9][ t]], 
            Times[ -0.21584055771952015, 
              c[ 10][ t]], 
            Times[ -0.20645618564475843, 
              c[ 11][ t]], 
            Times[ -0.18920668216016426, 
              c[ 12][ t]], 
            Times[ -0.16539866862653771, 
              c[ 13][ t]], 
            Times[ -0.13647135277833605, 
              c[ 14][ t]], 
            Times[ -0.10394325375429328, 
              c[ 15][ t]], 
            Times[ -0.06935801494512607, 
              c[ 16][ t]], 
            Times[ -0.034231213779558949, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.032022748374425904, 
              c[ 19][ t]], 
            Times[ 0.060688263076985105, 
              c[ 20][ t]], 
            Times[ 0.085044480344421705, 
              c[ 21][ t]], 
            Times[ 0.10436044624225685, 
              c[ 22][ t]], 
            Times[ 0.11814190616181255, 
              c[ 23][ t]], 
            Times[ 0.12613778810677614, 
              c[ 24][ t]], 
            Times[ 0.12833762891430928, 
              c[ 25][ t]], 
            Times[ 0.12496032289024853, 
              c[ 26][ t]], 
            Times[ 0.11643488132933186, 
              c[ 27][ t]], 
            Times[ 0.10337416789158609, 
              c[ 28][ t]], 
            Times[ 0.086542809078944891, 
              c[ 29][ t]], 
            Times[ 0.066820663127759972, 
              c[ 30][ t]], 
            Times[ 0.045163358568919301, 
              c[ 31][ t]], 
            Times[ 0.022561481809254869, 
              c[ 32][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 33][ t]], 
            Times[ -0.021580547817547879, 
              c[ 34][ t]], 
            Times[ -0.04131966847794722, 
              c[ 35][ t]], 
            Times[ -0.058468080236789913, 
              c[ 36][ t]], 
            Times[ -0.072413370861974122, 
              c[ 37][ t]], 
            Times[ -0.082699334313268744, 
              c[ 38][ t]], 
            Times[ -0.089038438663606695, 
              c[ 39][ t]], 
            Times[ -0.091317159035181589, 
              c[ 40][ t]], 
            Times[ -0.089594193770366884, 
              c[ 41][ t]], 
            Times[ -0.084091858737850814, 
              c[ 42][ t]], 
            Times[ -0.075181213012062598, 
              c[ 43][ t]], 
            Times[ -0.063361699504227528, 
              c[ 44][ t]], 
            Times[ -0.049236278094138941, 
              c[ 45][ t]], 
            Times[ -0.033483179628681567, 
              c[ 46][ t]], 
            Times[ -0.016825511857749401, 
              c[ 47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ 0.016273855731265604, 
              c[ 49][ t]], 
            Times[ 0.031322974491347078, 
              c[ 50][ t]], 
            Times[ 0.044547108751839919, 
              c[ 51][ t]], 
            Times[ 0.055441487066198933, 
              c[ 52][ t]], 
            Times[ 0.063614872548668253, 
              c[ 53][ t]], 
            Times[ 0.068802429876423349, 
              c[ 54][ t]], 
            Times[ 0.070873018952678238, 
              c[ 55][ t]], 
            Times[ 0.069830768673962415, 
              c[ 56][ t]], 
            Times[ 0.065811019881796273, 
              c[ 57][ t]], 
            Times[ 0.059070953080906326, 
              c[ 58][ t]], 
            Times[ 0.049975424961080865, 
              c[ 59][ t]], 
            Times[ 0.03897872015785999, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-11\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-11\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.07241337086197425`\)\ \(c[\(-60\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-59\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-58\)]\)[t] - 
            0.021580547817548056`\ \(c[\(-57\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-56\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-55\)]\)[t] + 
            0.045163358568919114`\ \(c[\(-54\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-53\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-52\)]\)[t] + 
            0.10337416789158595`\ \(c[\(-51\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-50\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-49\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-48\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-47\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-46\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-45\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-44\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-43\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-42\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-41\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-40\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-39\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-38\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-37\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-36\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-35\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-34\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-33\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-32\)]\)[t] - 
            0.206748335783172`\ \(c[\(-31\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-30\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-29\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-28\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-27\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-25\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-24\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-23\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-22\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-21\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-20\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-19\)]\)[t] + 
            0.6783560385470632`\ \(c[\(-18\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-17\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-16\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-15\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-14\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-13\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-12\)]\)[t] + 
            3.6538269611818044`\ \(c[\(-11\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-10\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-9\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-8\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-7\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-6\)]\)[t] + 
            0.756826728640657`\ \(c[\(-5\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-4\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-3\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-2\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-1\)]\)[t] + 
            0.3225686520215216`\ \(c[0]\)[t] + 
            0.23387232094715998`\ \(c[1]\)[t] + 
            0.14938649372796362`\ \(c[2]\)[t] + 
            0.07090751425765777`\ \(c[3]\)[t] + 
            1.8033970416801674`*^-16\ \(c[4]\)[t] - 
            0.06204407497545024`\ \(c[5]\)[t] - 
            0.11423673049785436`\ \(c[6]\)[t] - 
            0.15591488063143974`\ \(c[7]\)[t] - 
            0.18675027222298593`\ \(c[8]\)[t] - 
            0.206748335783172`\ \(c[9]\)[t] - 
            0.21623620818304484`\ \(c[10]\)[t] - 
            0.21584055771952015`\ \(c[11]\)[t] - 
            0.20645618564475843`\ \(c[12]\)[t] - 
            0.18920668216016426`\ \(c[13]\)[t] - 
            0.1653986686265377`\ \(c[14]\)[t] - 
            0.13647135277833605`\ \(c[15]\)[t] - 
            0.10394325375429328`\ \(c[16]\)[t] - 
            0.06935801494512607`\ \(c[17]\)[t] - 
            0.03423121377955895`\ \(c[18]\)[t] - 
            3.898171832519376`*^-17\ \(c[19]\)[t] + 
            0.032022748374425904`\ \(c[20]\)[t] + 
            0.060688263076985105`\ \(c[21]\)[t] + 
            0.08504448034442161`\ \(c[22]\)[t] + 
            0.10436044624225685`\ \(c[23]\)[t] + 
            0.11814190616181255`\ \(c[24]\)[t] + 
            0.12613778810677612`\ \(c[25]\)[t] + 
            0.12833762891430928`\ \(c[26]\)[t] + 
            0.12496032289024853`\ \(c[27]\)[t] + 
            0.11643488132933186`\ \(c[28]\)[t] + 
            0.10337416789158609`\ \(c[29]\)[t] + 
            0.08654280907894489`\ \(c[30]\)[t] + 
            0.06682066312775997`\ \(c[31]\)[t] + 
            0.0451633585689193`\ \(c[32]\)[t] + 
            0.02256148180925487`\ \(c[33]\)[t] + 
            3.8981718325193755`*^-17\ \(c[34]\)[t] - 
            0.02158054781754788`\ \(c[35]\)[t] - 
            0.04131966847794722`\ \(c[36]\)[t] - 
            0.05846808023678991`\ \(c[37]\)[t] - 
            0.07241337086197412`\ \(c[38]\)[t] - 
            0.08269933431326874`\ \(c[39]\)[t] - 
            0.0890384386636067`\ \(c[40]\)[t] - 
            0.0913171590351816`\ \(c[41]\)[t] - 
            0.08959419377036688`\ \(c[42]\)[t] - 
            0.08409185873785081`\ \(c[43]\)[t] - 
            0.0751812130120627`\ \(c[44]\)[t] - 
            0.06336169950422753`\ \(c[45]\)[t] - 
            0.04923627809413894`\ \(c[46]\)[t] - 
            0.033483179628681706`\ \(c[47]\)[t] - 
            0.0168255118577494`\ \(c[48]\)[t] - 
            3.898171832519376`*^-17\ \(c[49]\)[t] + 
            0.01627385573126547`\ \(c[50]\)[t] + 
            0.03132297449134708`\ \(c[51]\)[t] + 
            0.04454710875183992`\ \(c[52]\)[t] + 
            0.055441487066198857`\ \(c[53]\)[t] + 
            0.06361487254866825`\ \(c[54]\)[t] + 
            0.06880242987642335`\ \(c[55]\)[t] + 
            0.07087301895267824`\ \(c[56]\)[t] + 
            0.06983076867396242`\ \(c[57]\)[t] + 
            0.06581101988179627`\ \(c[58]\)[t] + 
            0.0590709530809064`\ \(c[59]\)[t] + 
            0.049975424961080865`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -11, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -11]][ t]], 
          Plus[ 
            Times[ -0.072413370861974247, 
              c[ -60][ t]], 
            Times[ -0.058468080236789913, 
              c[ -59][ t]], 
            Times[ -0.04131966847794722, 
              c[ -58][ t]], 
            Times[ -0.021580547817548056, 
              c[ -57][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -56][ t]], 
            Times[ 0.022561481809254869, 
              c[ -55][ t]], 
            Times[ 0.045163358568919114, 
              c[ -54][ t]], 
            Times[ 0.066820663127759972, 
              c[ -53][ t]], 
            Times[ 0.086542809078944891, 
              c[ -52][ t]], 
            Times[ 0.10337416789158595, 
              c[ -51][ t]], 
            Times[ 0.11643488132933186, 
              c[ -50][ t]], 
            Times[ 0.12496032289024853, 
              c[ -49][ t]], 
            Times[ 0.12833762891430925, 
              c[ -48][ t]], 
            Times[ 0.12613778810677612, 
              c[ -47][ t]], 
            Times[ 0.11814190616181255, 
              c[ -46][ t]], 
            Times[ 0.10436044624225692, 
              c[ -45][ t]], 
            Times[ 0.085044480344421608, 
              c[ -44][ t]], 
            Times[ 0.060688263076985105, 
              c[ -43][ t]], 
            Times[ 0.032022748374426029, 
              c[ -42][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -41][ t]], 
            Times[ -0.034231213779558949, 
              c[ -40][ t]], 
            Times[ -0.069358014945125918, 
              c[ -39][ t]], 
            Times[ -0.10394325375429328, 
              c[ -38][ t]], 
            Times[ -0.13647135277833605, 
              c[ -37][ t]], 
            Times[ -0.1653986686265376, 
              c[ -36][ t]], 
            Times[ -0.18920668216016426, 
              c[ -35][ t]], 
            Times[ -0.20645618564475843, 
              c[ -34][ t]], 
            Times[ -0.21584055771952013, 
              c[ -33][ t]], 
            Times[ -0.21623620818304484, 
              c[ -32][ t]], 
            Times[ -0.206748335783172, 
              c[ -31][ t]], 
            Times[ -0.18675027222298607, 
              c[ -30][ t]], 
            Times[ -0.15591488063143982, 
              c[ -29][ t]], 
            Times[ -0.11423673049785436, 
              c[ -28][ t]], 
            Times[ -0.062044074975450475, 
              c[ -27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ 0.070907514257657775, 
              c[ -25][ t]], 
            Times[ 0.14938649372796345, 
              c[ -24][ t]], 
            Times[ 0.23387232094715985, 
              c[ -23][ t]], 
            Times[ 0.32256865202152157, 
              c[ -22][ t]], 
            Times[ 0.41349667156634395, 
              c[ -21][ t]], 
            Times[ 0.50455115242710469, 
              c[ -20][ t]], 
            Times[ 0.59356153372868026, 
              c[ -19][ t]], 
            Times[ 0.67835603854706317, 
              c[ -18][ t]], 
            Times[ 0.75682672864065692, 
              c[ -17][ t]], 
            Times[ 0.82699334313268813, 
              c[ -16][ t]], 
            Times[ 0.88706379305918381, 
              c[ -15][ t]], 
            Times[ 0.93548928378863916, 
              c[ -14][ t]], 
            Times[ 0.9710122092317629, 
              c[ -13][ t]], 
            Times[ 0.99270519960720671, 
              c[ -12][ t]], 
            Times[ 3.6538269611818044, 
              c[ -11][ t]], 
            Times[ 0.99270519960720693, 
              c[ -10][ t]], 
            Times[ 0.9710122092317629, 
              c[ -9][ t]], 
            Times[ 0.93548928378863916, 
              c[ -8][ t]], 
            Times[ 0.88706379305918381, 
              c[ -7][ t]], 
            Times[ 0.82699334313268813, 
              c[ -6][ t]], 
            Times[ 0.75682672864065703, 
              c[ -5][ t]], 
            Times[ 0.67835603854706339, 
              c[ -4][ t]], 
            Times[ 0.59356153372868059, 
              c[ -3][ t]], 
            Times[ 0.50455115242710469, 
              c[ -2][ t]], 
            Times[ 0.41349667156634418, 
              c[ -1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 0][ t]], 
            Times[ 0.23387232094715998, 
              c[ 1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 2][ t]], 
            Times[ 0.070907514257657775, 
              c[ 3][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ -0.062044074975450239, 
              c[ 5][ t]], 
            Times[ -0.11423673049785436, 
              c[ 6][ t]], 
            Times[ -0.15591488063143974, 
              c[ 7][ t]], 
            Times[ -0.18675027222298593, 
              c[ 8][ t]], 
            Times[ -0.206748335783172, 
              c[ 9][ t]], 
            Times[ -0.21623620818304484, 
              c[ 10][ t]], 
            Times[ -0.21584055771952015, 
              c[ 11][ t]], 
            Times[ -0.20645618564475843, 
              c[ 12][ t]], 
            Times[ -0.18920668216016426, 
              c[ 13][ t]], 
            Times[ -0.16539866862653771, 
              c[ 14][ t]], 
            Times[ -0.13647135277833605, 
              c[ 15][ t]], 
            Times[ -0.10394325375429328, 
              c[ 16][ t]], 
            Times[ -0.06935801494512607, 
              c[ 17][ t]], 
            Times[ -0.034231213779558949, 
              c[ 18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ 0.032022748374425904, 
              c[ 20][ t]], 
            Times[ 0.060688263076985105, 
              c[ 21][ t]], 
            Times[ 0.085044480344421608, 
              c[ 22][ t]], 
            Times[ 0.10436044624225685, 
              c[ 23][ t]], 
            Times[ 0.11814190616181255, 
              c[ 24][ t]], 
            Times[ 0.12613778810677612, 
              c[ 25][ t]], 
            Times[ 0.12833762891430928, 
              c[ 26][ t]], 
            Times[ 0.12496032289024853, 
              c[ 27][ t]], 
            Times[ 0.11643488132933186, 
              c[ 28][ t]], 
            Times[ 0.10337416789158609, 
              c[ 29][ t]], 
            Times[ 0.086542809078944891, 
              c[ 30][ t]], 
            Times[ 0.066820663127759972, 
              c[ 31][ t]], 
            Times[ 0.045163358568919301, 
              c[ 32][ t]], 
            Times[ 0.022561481809254869, 
              c[ 33][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 34][ t]], 
            Times[ -0.021580547817547879, 
              c[ 35][ t]], 
            Times[ -0.04131966847794722, 
              c[ 36][ t]], 
            Times[ -0.058468080236789913, 
              c[ 37][ t]], 
            Times[ -0.072413370861974122, 
              c[ 38][ t]], 
            Times[ -0.082699334313268744, 
              c[ 39][ t]], 
            Times[ -0.089038438663606695, 
              c[ 40][ t]], 
            Times[ -0.091317159035181603, 
              c[ 41][ t]], 
            Times[ -0.089594193770366884, 
              c[ 42][ t]], 
            Times[ -0.084091858737850814, 
              c[ 43][ t]], 
            Times[ -0.075181213012062695, 
              c[ 44][ t]], 
            Times[ -0.063361699504227528, 
              c[ 45][ t]], 
            Times[ -0.049236278094138941, 
              c[ 46][ t]], 
            Times[ -0.033483179628681706, 
              c[ 47][ t]], 
            Times[ -0.016825511857749401, 
              c[ 48][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ 0.016273855731265469, 
              c[ 50][ t]], 
            Times[ 0.031322974491347078, 
              c[ 51][ t]], 
            Times[ 0.044547108751839919, 
              c[ 52][ t]], 
            Times[ 0.055441487066198857, 
              c[ 53][ t]], 
            Times[ 0.063614872548668253, 
              c[ 54][ t]], 
            Times[ 0.068802429876423349, 
              c[ 55][ t]], 
            Times[ 0.070873018952678238, 
              c[ 56][ t]], 
            Times[ 0.069830768673962415, 
              c[ 57][ t]], 
            Times[ 0.065811019881796273, 
              c[ 58][ t]], 
            Times[ 0.059070953080906402, 
              c[ 59][ t]], 
            Times[ 0.049975424961080865, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-10\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-10\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08269933431326881`\)\ \(c[\(-60\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-59\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-58\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-57\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-56\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-55\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-54\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-53\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-52\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-51\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-50\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-49\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-48\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-47\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-46\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-45\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-44\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-43\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-42\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-41\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-39\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-38\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-37\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-36\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-35\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-34\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-33\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-32\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-31\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-30\)]\)[t] - 
            0.186750272222986`\ \(c[\(-29\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-28\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-27\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-26\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-25\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-24\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-23\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-22\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-21\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-20\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-19\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-18\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-17\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-16\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-15\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-14\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-13\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-12\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-11\)]\)[t] + 
            3.1932454224643014`\ \(c[\(-10\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-9\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-8\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-7\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-6\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-5\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-4\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-3\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-2\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-1\)]\)[t] + 
            0.4134966715663442`\ \(c[0]\)[t] + 
            0.3225686520215216`\ \(c[1]\)[t] + 
            0.23387232094715985`\ \(c[2]\)[t] + 
            0.14938649372796362`\ \(c[3]\)[t] + 
            0.07090751425765777`\ \(c[4]\)[t] + 
            3.898171832519376`*^-17\ \(c[5]\)[t] - 
            0.06204407497545034`\ \(c[6]\)[t] - 
            0.11423673049785436`\ \(c[7]\)[t] - 
            0.15591488063143982`\ \(c[8]\)[t] - 
            0.186750272222986`\ \(c[9]\)[t] - 
            0.206748335783172`\ \(c[10]\)[t] - 
            0.21623620818304484`\ \(c[11]\)[t] - 
            0.21584055771952015`\ \(c[12]\)[t] - 
            0.20645618564475843`\ \(c[13]\)[t] - 
            0.18920668216016426`\ \(c[14]\)[t] - 
            0.1653986686265377`\ \(c[15]\)[t] - 
            0.13647135277833605`\ \(c[16]\)[t] - 
            0.10394325375429328`\ \(c[17]\)[t] - 
            0.06935801494512607`\ \(c[18]\)[t] - 
            0.03423121377955895`\ \(c[19]\)[t] - 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.032022748374425904`\ \(c[21]\)[t] + 
            0.060688263076985`\ \(c[22]\)[t] + 
            0.0850444803444217`\ \(c[23]\)[t] + 
            0.10436044624225685`\ \(c[24]\)[t] + 
            0.11814190616181253`\ \(c[25]\)[t] + 
            0.12613778810677614`\ \(c[26]\)[t] + 
            0.12833762891430928`\ \(c[27]\)[t] + 
            0.12496032289024853`\ \(c[28]\)[t] + 
            0.11643488132933186`\ \(c[29]\)[t] + 
            0.10337416789158609`\ \(c[30]\)[t] + 
            0.08654280907894489`\ \(c[31]\)[t] + 
            0.06682066312775997`\ \(c[32]\)[t] + 
            0.0451633585689193`\ \(c[33]\)[t] + 
            0.02256148180925487`\ \(c[34]\)[t] + 
            3.8981718325193755`*^-17\ \(c[35]\)[t] - 
            0.02158054781754788`\ \(c[36]\)[t] - 
            0.04131966847794722`\ \(c[37]\)[t] - 
            0.05846808023678991`\ \(c[38]\)[t] - 
            0.07241337086197412`\ \(c[39]\)[t] - 
            0.08269933431326874`\ \(c[40]\)[t] - 
            0.08903843866360665`\ \(c[41]\)[t] - 
            0.09131715903518159`\ \(c[42]\)[t] - 
            0.08959419377036688`\ \(c[43]\)[t] - 
            0.08409185873785086`\ \(c[44]\)[t] - 
            0.0751812130120626`\ \(c[45]\)[t] - 
            0.06336169950422753`\ \(c[46]\)[t] - 
            0.049236278094139066`\ \(c[47]\)[t] - 
            0.03348317962868157`\ \(c[48]\)[t] - 
            0.0168255118577494`\ \(c[49]\)[t] - 
            1.8033970416801674`*^-16\ \(c[50]\)[t] + 
            0.016273855731265604`\ \(c[51]\)[t] + 
            0.03132297449134708`\ \(c[52]\)[t] + 
            0.044547108751839815`\ \(c[53]\)[t] + 
            0.05544148706619893`\ \(c[54]\)[t] + 
            0.06361487254866825`\ \(c[55]\)[t] + 
            0.06880242987642332`\ \(c[56]\)[t] + 
            0.07087301895267824`\ \(c[57]\)[t] + 
            0.06983076867396242`\ \(c[58]\)[t] + 
            0.06581101988179631`\ \(c[59]\)[t] + 
            0.059070953080906326`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -10, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -10]][ t]], 
          Plus[ 
            Times[ -0.082699334313268813, 
              c[ -60][ t]], 
            Times[ -0.072413370861974122, 
              c[ -59][ t]], 
            Times[ -0.058468080236789913, 
              c[ -58][ t]], 
            Times[ -0.041319668477947373, 
              c[ -57][ t]], 
            Times[ -0.021580547817547879, 
              c[ -56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -55][ t]], 
            Times[ 0.022561481809254675, 
              c[ -54][ t]], 
            Times[ 0.045163358568919301, 
              c[ -53][ t]], 
            Times[ 0.066820663127759972, 
              c[ -52][ t]], 
            Times[ 0.086542809078944752, 
              c[ -51][ t]], 
            Times[ 0.10337416789158609, 
              c[ -50][ t]], 
            Times[ 0.11643488132933186, 
              c[ -49][ t]], 
            Times[ 0.12496032289024847, 
              c[ -48][ t]], 
            Times[ 0.12833762891430928, 
              c[ -47][ t]], 
            Times[ 0.12613778810677614, 
              c[ -46][ t]], 
            Times[ 0.1181419061618126, 
              c[ -45][ t]], 
            Times[ 0.10436044624225685, 
              c[ -44][ t]], 
            Times[ 0.085044480344421705, 
              c[ -43][ t]], 
            Times[ 0.060688263076985223, 
              c[ -42][ t]], 
            Times[ 0.032022748374425904, 
              c[ -41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.034231213779558796, 
              c[ -39][ t]], 
            Times[ -0.06935801494512607, 
              c[ -38][ t]], 
            Times[ -0.10394325375429328, 
              c[ -37][ t]], 
            Times[ -0.13647135277833591, 
              c[ -36][ t]], 
            Times[ -0.16539866862653771, 
              c[ -35][ t]], 
            Times[ -0.18920668216016426, 
              c[ -34][ t]], 
            Times[ -0.20645618564475834, 
              c[ -33][ t]], 
            Times[ -0.21584055771952015, 
              c[ -32][ t]], 
            Times[ -0.21623620818304484, 
              c[ -31][ t]], 
            Times[ -0.20674833578317206, 
              c[ -30][ t]], 
            Times[ -0.18675027222298601, 
              c[ -29][ t]], 
            Times[ -0.15591488063143974, 
              c[ -28][ t]], 
            Times[ -0.11423673049785445, 
              c[ -27][ t]], 
            Times[ -0.062044074975450343, 
              c[ -26][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -25][ t]], 
            Times[ 0.070907514257657622, 
              c[ -24][ t]], 
            Times[ 0.14938649372796362, 
              c[ -23][ t]], 
            Times[ 0.23387232094715998, 
              c[ -22][ t]], 
            Times[ 0.32256865202152135, 
              c[ -21][ t]], 
            Times[ 0.41349667156634418, 
              c[ -20][ t]], 
            Times[ 0.50455115242710469, 
              c[ -19][ t]], 
            Times[ 0.59356153372868026, 
              c[ -18][ t]], 
            Times[ 0.67835603854706339, 
              c[ -17][ t]], 
            Times[ 0.75682672864065692, 
              c[ -16][ t]], 
            Times[ 0.82699334313268813, 
              c[ -15][ t]], 
            Times[ 0.88706379305918381, 
              c[ -14][ t]], 
            Times[ 0.93548928378863916, 
              c[ -13][ t]], 
            Times[ 0.9710122092317629, 
              c[ -12][ t]], 
            Times[ 0.99270519960720693, 
              c[ -11][ t]], 
            Times[ 3.1932454224643014, 
              c[ -10][ t]], 
            Times[ 0.99270519960720693, 
              c[ -9][ t]], 
            Times[ 0.9710122092317629, 
              c[ -8][ t]], 
            Times[ 0.93548928378863916, 
              c[ -7][ t]], 
            Times[ 0.88706379305918381, 
              c[ -6][ t]], 
            Times[ 0.82699334313268824, 
              c[ -5][ t]], 
            Times[ 0.75682672864065692, 
              c[ -4][ t]], 
            Times[ 0.67835603854706339, 
              c[ -3][ t]], 
            Times[ 0.59356153372868048, 
              c[ -2][ t]], 
            Times[ 0.50455115242710469, 
              c[ -1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 0][ t]], 
            Times[ 0.32256865202152157, 
              c[ 1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 2][ t]], 
            Times[ 0.14938649372796362, 
              c[ 3][ t]], 
            Times[ 0.070907514257657775, 
              c[ 4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ -0.062044074975450343, 
              c[ 6][ t]], 
            Times[ -0.11423673049785436, 
              c[ 7][ t]], 
            Times[ -0.15591488063143982, 
              c[ 8][ t]], 
            Times[ -0.18675027222298601, 
              c[ 9][ t]], 
            Times[ -0.206748335783172, 
              c[ 10][ t]], 
            Times[ -0.21623620818304484, 
              c[ 11][ t]], 
            Times[ -0.21584055771952015, 
              c[ 12][ t]], 
            Times[ -0.20645618564475843, 
              c[ 13][ t]], 
            Times[ -0.18920668216016426, 
              c[ 14][ t]], 
            Times[ -0.16539866862653771, 
              c[ 15][ t]], 
            Times[ -0.13647135277833605, 
              c[ 16][ t]], 
            Times[ -0.10394325375429328, 
              c[ 17][ t]], 
            Times[ -0.06935801494512607, 
              c[ 18][ t]], 
            Times[ -0.034231213779558949, 
              c[ 19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.032022748374425904, 
              c[ 21][ t]], 
            Times[ 0.060688263076985001, 
              c[ 22][ t]], 
            Times[ 0.085044480344421705, 
              c[ 23][ t]], 
            Times[ 0.10436044624225685, 
              c[ 24][ t]], 
            Times[ 0.11814190616181253, 
              c[ 25][ t]], 
            Times[ 0.12613778810677614, 
              c[ 26][ t]], 
            Times[ 0.12833762891430928, 
              c[ 27][ t]], 
            Times[ 0.12496032289024853, 
              c[ 28][ t]], 
            Times[ 0.11643488132933186, 
              c[ 29][ t]], 
            Times[ 0.10337416789158609, 
              c[ 30][ t]], 
            Times[ 0.086542809078944891, 
              c[ 31][ t]], 
            Times[ 0.066820663127759972, 
              c[ 32][ t]], 
            Times[ 0.045163358568919301, 
              c[ 33][ t]], 
            Times[ 0.022561481809254869, 
              c[ 34][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 35][ t]], 
            Times[ -0.021580547817547879, 
              c[ 36][ t]], 
            Times[ -0.04131966847794722, 
              c[ 37][ t]], 
            Times[ -0.058468080236789913, 
              c[ 38][ t]], 
            Times[ -0.072413370861974122, 
              c[ 39][ t]], 
            Times[ -0.082699334313268744, 
              c[ 40][ t]], 
            Times[ -0.089038438663606653, 
              c[ 41][ t]], 
            Times[ -0.091317159035181589, 
              c[ 42][ t]], 
            Times[ -0.089594193770366884, 
              c[ 43][ t]], 
            Times[ -0.084091858737850855, 
              c[ 44][ t]], 
            Times[ -0.075181213012062598, 
              c[ 45][ t]], 
            Times[ -0.063361699504227528, 
              c[ 46][ t]], 
            Times[ -0.049236278094139066, 
              c[ 47][ t]], 
            Times[ -0.033483179628681567, 
              c[ 48][ t]], 
            Times[ -0.016825511857749401, 
              c[ 49][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 50][ t]], 
            Times[ 0.016273855731265604, 
              c[ 51][ t]], 
            Times[ 0.031322974491347078, 
              c[ 52][ t]], 
            Times[ 0.044547108751839815, 
              c[ 53][ t]], 
            Times[ 0.055441487066198933, 
              c[ 54][ t]], 
            Times[ 0.063614872548668253, 
              c[ 55][ t]], 
            Times[ 0.068802429876423321, 
              c[ 56][ t]], 
            Times[ 0.070873018952678238, 
              c[ 57][ t]], 
            Times[ 0.069830768673962415, 
              c[ 58][ t]], 
            Times[ 0.065811019881796315, 
              c[ 59][ t]], 
            Times[ 0.059070953080906326, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-9\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-9\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0890384386636067`\)\ \(c[\(-60\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-59\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-58\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-57\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-56\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-55\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-53\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-52\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-51\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-50\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-49\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-48\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-47\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-46\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-45\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-44\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-43\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-42\)]\)[t] + 
            0.060688263076985`\ \(c[\(-41\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-40\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-38\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-37\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-36\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-35\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-34\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-33\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-32\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-31\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-30\)]\)[t] - 
            0.206748335783172`\ \(c[\(-29\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-28\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-27\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-26\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-23\)]\)[t] + 
            0.14938649372796384`\ \(c[\(-22\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-21\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-20\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-19\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-18\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-17\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-16\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-15\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-14\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-13\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-12\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-11\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-10\)]\)[t] + 
            2.7765287921960846`\ \(c[\(-9\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-8\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-7\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-6\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-5\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-4\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-3\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-2\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-1\)]\)[t] + 
            0.5045511524271047`\ \(c[0]\)[t] + 
            0.4134966715663442`\ \(c[1]\)[t] + 
            0.32256865202152135`\ \(c[2]\)[t] + 
            0.23387232094715985`\ \(c[3]\)[t] + 
            0.14938649372796362`\ \(c[4]\)[t] + 
            0.07090751425765777`\ \(c[5]\)[t] + 
            3.898171832519376`*^-17\ \(c[6]\)[t] - 
            0.06204407497545034`\ \(c[7]\)[t] - 
            0.11423673049785436`\ \(c[8]\)[t] - 
            0.15591488063143982`\ \(c[9]\)[t] - 
            0.186750272222986`\ \(c[10]\)[t] - 
            0.206748335783172`\ \(c[11]\)[t] - 
            0.21623620818304484`\ \(c[12]\)[t] - 
            0.21584055771952015`\ \(c[13]\)[t] - 
            0.20645618564475843`\ \(c[14]\)[t] - 
            0.18920668216016426`\ \(c[15]\)[t] - 
            0.1653986686265377`\ \(c[16]\)[t] - 
            0.13647135277833605`\ \(c[17]\)[t] - 
            0.10394325375429328`\ \(c[18]\)[t] - 
            0.06935801494512607`\ \(c[19]\)[t] - 
            0.03423121377955895`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.032022748374425904`\ \(c[22]\)[t] + 
            0.060688263076985105`\ \(c[23]\)[t] + 
            0.0850444803444217`\ \(c[24]\)[t] + 
            0.10436044624225685`\ \(c[25]\)[t] + 
            0.11814190616181255`\ \(c[26]\)[t] + 
            0.12613778810677614`\ \(c[27]\)[t] + 
            0.12833762891430928`\ \(c[28]\)[t] + 
            0.12496032289024853`\ \(c[29]\)[t] + 
            0.11643488132933186`\ \(c[30]\)[t] + 
            0.10337416789158609`\ \(c[31]\)[t] + 
            0.08654280907894489`\ \(c[32]\)[t] + 
            0.06682066312775997`\ \(c[33]\)[t] + 
            0.0451633585689193`\ \(c[34]\)[t] + 
            0.02256148180925487`\ \(c[35]\)[t] + 
            3.8981718325193755`*^-17\ \(c[36]\)[t] - 
            0.02158054781754788`\ \(c[37]\)[t] - 
            0.04131966847794722`\ \(c[38]\)[t] - 
            0.05846808023678991`\ \(c[39]\)[t] - 
            0.07241337086197412`\ \(c[40]\)[t] - 
            0.08269933431326874`\ \(c[41]\)[t] - 
            0.0890384386636067`\ \(c[42]\)[t] - 
            0.09131715903518159`\ \(c[43]\)[t] - 
            0.08959419377036688`\ \(c[44]\)[t] - 
            0.08409185873785081`\ \(c[45]\)[t] - 
            0.0751812130120626`\ \(c[46]\)[t] - 
            0.06336169950422753`\ \(c[47]\)[t] - 
            0.04923627809413894`\ \(c[48]\)[t] - 
            0.03348317962868157`\ \(c[49]\)[t] - 
            0.0168255118577494`\ \(c[50]\)[t] - 
            3.898171832519376`*^-17\ \(c[51]\)[t] + 
            0.016273855731265604`\ \(c[52]\)[t] + 
            0.03132297449134708`\ \(c[53]\)[t] + 
            0.04454710875183992`\ \(c[54]\)[t] + 
            0.05544148706619893`\ \(c[55]\)[t] + 
            0.06361487254866825`\ \(c[56]\)[t] + 
            0.06880242987642335`\ \(c[57]\)[t] + 
            0.07087301895267824`\ \(c[58]\)[t] + 
            0.06983076867396242`\ \(c[59]\)[t] + 
            0.06581101988179627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -9, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -9]][ t]], 
          Plus[ 
            Times[ -0.089038438663606695, 
              c[ -60][ t]], 
            Times[ -0.082699334313268744, 
              c[ -59][ t]], 
            Times[ -0.072413370861974122, 
              c[ -58][ t]], 
            Times[ -0.058468080236789913, 
              c[ -57][ t]], 
            Times[ -0.04131966847794722, 
              c[ -56][ t]], 
            Times[ -0.021580547817547879, 
              c[ -55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ 0.022561481809254869, 
              c[ -53][ t]], 
            Times[ 0.045163358568919301, 
              c[ -52][ t]], 
            Times[ 0.066820663127759972, 
              c[ -51][ t]], 
            Times[ 0.086542809078944891, 
              c[ -50][ t]], 
            Times[ 0.10337416789158609, 
              c[ -49][ t]], 
            Times[ 0.11643488132933186, 
              c[ -48][ t]], 
            Times[ 0.12496032289024853, 
              c[ -47][ t]], 
            Times[ 0.12833762891430928, 
              c[ -46][ t]], 
            Times[ 0.12613778810677614, 
              c[ -45][ t]], 
            Times[ 0.11814190616181253, 
              c[ -44][ t]], 
            Times[ 0.10436044624225685, 
              c[ -43][ t]], 
            Times[ 0.085044480344421705, 
              c[ -42][ t]], 
            Times[ 0.060688263076985001, 
              c[ -41][ t]], 
            Times[ 0.032022748374425904, 
              c[ -40][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.034231213779558949, 
              c[ -38][ t]], 
            Times[ -0.06935801494512607, 
              c[ -37][ t]], 
            Times[ -0.10394325375429328, 
              c[ -36][ t]], 
            Times[ -0.13647135277833605, 
              c[ -35][ t]], 
            Times[ -0.16539866862653771, 
              c[ -34][ t]], 
            Times[ -0.18920668216016426, 
              c[ -33][ t]], 
            Times[ -0.20645618564475843, 
              c[ -32][ t]], 
            Times[ -0.21584055771952015, 
              c[ -31][ t]], 
            Times[ -0.21623620818304484, 
              c[ -30][ t]], 
            Times[ -0.206748335783172, 
              c[ -29][ t]], 
            Times[ -0.18675027222298593, 
              c[ -28][ t]], 
            Times[ -0.15591488063143982, 
              c[ -27][ t]], 
            Times[ -0.11423673049785436, 
              c[ -26][ t]], 
            Times[ -0.062044074975450239, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.070907514257657775, 
              c[ -23][ t]], 
            Times[ 0.14938649372796384, 
              c[ -22][ t]], 
            Times[ 0.23387232094715985, 
              c[ -21][ t]], 
            Times[ 0.32256865202152157, 
              c[ -20][ t]], 
            Times[ 0.41349667156634418, 
              c[ -19][ t]], 
            Times[ 0.50455115242710469, 
              c[ -18][ t]], 
            Times[ 0.59356153372868059, 
              c[ -17][ t]], 
            Times[ 0.67835603854706339, 
              c[ -16][ t]], 
            Times[ 0.75682672864065692, 
              c[ -15][ t]], 
            Times[ 0.82699334313268813, 
              c[ -14][ t]], 
            Times[ 0.88706379305918381, 
              c[ -13][ t]], 
            Times[ 0.93548928378863916, 
              c[ -12][ t]], 
            Times[ 0.9710122092317629, 
              c[ -11][ t]], 
            Times[ 0.99270519960720693, 
              c[ -10][ t]], 
            Times[ 2.7765287921960846, 
              c[ -9][ t]], 
            Times[ 0.99270519960720671, 
              c[ -8][ t]], 
            Times[ 0.9710122092317629, 
              c[ -7][ t]], 
            Times[ 0.93548928378863916, 
              c[ -6][ t]], 
            Times[ 0.8870637930591837, 
              c[ -5][ t]], 
            Times[ 0.82699334313268813, 
              c[ -4][ t]], 
            Times[ 0.75682672864065692, 
              c[ -3][ t]], 
            Times[ 0.67835603854706328, 
              c[ -2][ t]], 
            Times[ 0.59356153372868048, 
              c[ -1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 0][ t]], 
            Times[ 0.41349667156634418, 
              c[ 1][ t]], 
            Times[ 0.32256865202152135, 
              c[ 2][ t]], 
            Times[ 0.23387232094715985, 
              c[ 3][ t]], 
            Times[ 0.14938649372796362, 
              c[ 4][ t]], 
            Times[ 0.070907514257657775, 
              c[ 5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ -0.062044074975450343, 
              c[ 7][ t]], 
            Times[ -0.11423673049785436, 
              c[ 8][ t]], 
            Times[ -0.15591488063143982, 
              c[ 9][ t]], 
            Times[ -0.18675027222298601, 
              c[ 10][ t]], 
            Times[ -0.206748335783172, 
              c[ 11][ t]], 
            Times[ -0.21623620818304484, 
              c[ 12][ t]], 
            Times[ -0.21584055771952015, 
              c[ 13][ t]], 
            Times[ -0.20645618564475843, 
              c[ 14][ t]], 
            Times[ -0.18920668216016426, 
              c[ 15][ t]], 
            Times[ -0.16539866862653771, 
              c[ 16][ t]], 
            Times[ -0.13647135277833605, 
              c[ 17][ t]], 
            Times[ -0.10394325375429328, 
              c[ 18][ t]], 
            Times[ -0.06935801494512607, 
              c[ 19][ t]], 
            Times[ -0.034231213779558949, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.032022748374425904, 
              c[ 22][ t]], 
            Times[ 0.060688263076985105, 
              c[ 23][ t]], 
            Times[ 0.085044480344421705, 
              c[ 24][ t]], 
            Times[ 0.10436044624225685, 
              c[ 25][ t]], 
            Times[ 0.11814190616181255, 
              c[ 26][ t]], 
            Times[ 0.12613778810677614, 
              c[ 27][ t]], 
            Times[ 0.12833762891430928, 
              c[ 28][ t]], 
            Times[ 0.12496032289024853, 
              c[ 29][ t]], 
            Times[ 0.11643488132933186, 
              c[ 30][ t]], 
            Times[ 0.10337416789158609, 
              c[ 31][ t]], 
            Times[ 0.086542809078944891, 
              c[ 32][ t]], 
            Times[ 0.066820663127759972, 
              c[ 33][ t]], 
            Times[ 0.045163358568919301, 
              c[ 34][ t]], 
            Times[ 0.022561481809254869, 
              c[ 35][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 36][ t]], 
            Times[ -0.021580547817547879, 
              c[ 37][ t]], 
            Times[ -0.04131966847794722, 
              c[ 38][ t]], 
            Times[ -0.058468080236789913, 
              c[ 39][ t]], 
            Times[ -0.072413370861974122, 
              c[ 40][ t]], 
            Times[ -0.082699334313268744, 
              c[ 41][ t]], 
            Times[ -0.089038438663606695, 
              c[ 42][ t]], 
            Times[ -0.091317159035181589, 
              c[ 43][ t]], 
            Times[ -0.089594193770366884, 
              c[ 44][ t]], 
            Times[ -0.084091858737850814, 
              c[ 45][ t]], 
            Times[ -0.075181213012062598, 
              c[ 46][ t]], 
            Times[ -0.063361699504227528, 
              c[ 47][ t]], 
            Times[ -0.049236278094138941, 
              c[ 48][ t]], 
            Times[ -0.033483179628681567, 
              c[ 49][ t]], 
            Times[ -0.016825511857749401, 
              c[ 50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ 0.016273855731265604, 
              c[ 52][ t]], 
            Times[ 0.031322974491347078, 
              c[ 53][ t]], 
            Times[ 0.044547108751839919, 
              c[ 54][ t]], 
            Times[ 0.055441487066198933, 
              c[ 55][ t]], 
            Times[ 0.063614872548668253, 
              c[ 56][ t]], 
            Times[ 0.068802429876423349, 
              c[ 57][ t]], 
            Times[ 0.070873018952678238, 
              c[ 58][ t]], 
            Times[ 0.069830768673962415, 
              c[ 59][ t]], 
            Times[ 0.065811019881796273, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-8\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-8\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.09131715903518159`\)\ \(c[\(-60\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-59\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-58\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-57\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-56\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-55\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-54\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-53\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-52\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-51\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-50\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-49\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-48\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-47\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-46\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-45\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-44\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-43\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-42\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-41\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-40\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-39\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-37\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-36\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-35\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-34\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-33\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-32\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-31\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-30\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-29\)]\)[t] - 
            0.206748335783172`\ \(c[\(-28\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-27\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-26\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-25\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-22\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-21\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-20\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-19\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-18\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-17\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-16\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-15\)]\)[t] + 
            0.756826728640657`\ \(c[\(-14\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-13\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-12\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-11\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-10\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-9\)]\)[t] + 
            2.403677070377153`\ \(c[\(-8\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-7\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-6\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-5\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-4\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-3\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-2\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-1\)]\)[t] + 
            0.5935615337286805`\ \(c[0]\)[t] + 
            0.5045511524271047`\ \(c[1]\)[t] + 
            0.4134966715663442`\ \(c[2]\)[t] + 
            0.3225686520215216`\ \(c[3]\)[t] + 
            0.23387232094715985`\ \(c[4]\)[t] + 
            0.14938649372796362`\ \(c[5]\)[t] + 
            0.07090751425765777`\ \(c[6]\)[t] + 
            3.898171832519376`*^-17\ \(c[7]\)[t] - 
            0.06204407497545034`\ \(c[8]\)[t] - 
            0.11423673049785436`\ \(c[9]\)[t] - 
            0.15591488063143982`\ \(c[10]\)[t] - 
            0.18675027222298593`\ \(c[11]\)[t] - 
            0.206748335783172`\ \(c[12]\)[t] - 
            0.21623620818304484`\ \(c[13]\)[t] - 
            0.21584055771952015`\ \(c[14]\)[t] - 
            0.20645618564475843`\ \(c[15]\)[t] - 
            0.18920668216016426`\ \(c[16]\)[t] - 
            0.1653986686265377`\ \(c[17]\)[t] - 
            0.13647135277833605`\ \(c[18]\)[t] - 
            0.10394325375429328`\ \(c[19]\)[t] - 
            0.06935801494512607`\ \(c[20]\)[t] - 
            0.03423121377955895`\ \(c[21]\)[t] - 
            1.8033970416801674`*^-16\ \(c[22]\)[t] + 
            0.032022748374425904`\ \(c[23]\)[t] + 
            0.060688263076985105`\ \(c[24]\)[t] + 
            0.08504448034442161`\ \(c[25]\)[t] + 
            0.10436044624225685`\ \(c[26]\)[t] + 
            0.11814190616181255`\ \(c[27]\)[t] + 
            0.12613778810677612`\ \(c[28]\)[t] + 
            0.12833762891430928`\ \(c[29]\)[t] + 
            0.12496032289024853`\ \(c[30]\)[t] + 
            0.11643488132933186`\ \(c[31]\)[t] + 
            0.10337416789158609`\ \(c[32]\)[t] + 
            0.08654280907894475`\ \(c[33]\)[t] + 
            0.06682066312775997`\ \(c[34]\)[t] + 
            0.0451633585689193`\ \(c[35]\)[t] + 
            0.022561481809254675`\ \(c[36]\)[t] + 
            3.8981718325193755`*^-17\ \(c[37]\)[t] - 
            0.02158054781754788`\ \(c[38]\)[t] - 
            0.04131966847794737`\ \(c[39]\)[t] - 
            0.05846808023678991`\ \(c[40]\)[t] - 
            0.07241337086197412`\ \(c[41]\)[t] - 
            0.08269933431326881`\ \(c[42]\)[t] - 
            0.0890384386636067`\ \(c[43]\)[t] - 
            0.09131715903518159`\ \(c[44]\)[t] - 
            0.08959419377036684`\ \(c[45]\)[t] - 
            0.08409185873785081`\ \(c[46]\)[t] - 
            0.0751812130120626`\ \(c[47]\)[t] - 
            0.0633616995042274`\ \(c[48]\)[t] - 
            0.04923627809413894`\ \(c[49]\)[t] - 
            0.03348317962868157`\ \(c[50]\)[t] - 
            0.016825511857749262`\ \(c[51]\)[t] - 
            3.898171832519376`*^-17\ \(c[52]\)[t] + 
            0.016273855731265604`\ \(c[53]\)[t] + 
            0.0313229744913472`\ \(c[54]\)[t] + 
            0.04454710875183992`\ \(c[55]\)[t] + 
            0.05544148706619893`\ \(c[56]\)[t] + 
            0.06361487254866832`\ \(c[57]\)[t] + 
            0.06880242987642335`\ \(c[58]\)[t] + 
            0.07087301895267824`\ \(c[59]\)[t] + 
            0.06983076867396239`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -8, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -8]][ t]], 
          Plus[ 
            Times[ -0.091317159035181589, 
              c[ -60][ t]], 
            Times[ -0.089038438663606653, 
              c[ -59][ t]], 
            Times[ -0.082699334313268744, 
              c[ -58][ t]], 
            Times[ -0.072413370861974122, 
              c[ -57][ t]], 
            Times[ -0.058468080236789774, 
              c[ -56][ t]], 
            Times[ -0.04131966847794722, 
              c[ -55][ t]], 
            Times[ -0.021580547817547879, 
              c[ -54][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -53][ t]], 
            Times[ 0.022561481809254869, 
              c[ -52][ t]], 
            Times[ 0.045163358568919301, 
              c[ -51][ t]], 
            Times[ 0.066820663127760152, 
              c[ -50][ t]], 
            Times[ 0.086542809078944891, 
              c[ -49][ t]], 
            Times[ 0.10337416789158609, 
              c[ -48][ t]], 
            Times[ 0.11643488132933195, 
              c[ -47][ t]], 
            Times[ 0.12496032289024853, 
              c[ -46][ t]], 
            Times[ 0.12833762891430925, 
              c[ -45][ t]], 
            Times[ 0.12613778810677612, 
              c[ -44][ t]], 
            Times[ 0.11814190616181255, 
              c[ -43][ t]], 
            Times[ 0.10436044624225692, 
              c[ -42][ t]], 
            Times[ 0.085044480344421608, 
              c[ -41][ t]], 
            Times[ 0.060688263076985105, 
              c[ -40][ t]], 
            Times[ 0.032022748374426029, 
              c[ -39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ -0.034231213779558949, 
              c[ -37][ t]], 
            Times[ -0.069358014945125918, 
              c[ -36][ t]], 
            Times[ -0.10394325375429328, 
              c[ -35][ t]], 
            Times[ -0.13647135277833605, 
              c[ -34][ t]], 
            Times[ -0.1653986686265376, 
              c[ -33][ t]], 
            Times[ -0.18920668216016426, 
              c[ -32][ t]], 
            Times[ -0.20645618564475843, 
              c[ -31][ t]], 
            Times[ -0.21584055771952013, 
              c[ -30][ t]], 
            Times[ -0.21623620818304484, 
              c[ -29][ t]], 
            Times[ -0.206748335783172, 
              c[ -28][ t]], 
            Times[ -0.18675027222298607, 
              c[ -27][ t]], 
            Times[ -0.15591488063143982, 
              c[ -26][ t]], 
            Times[ -0.11423673049785436, 
              c[ -25][ t]], 
            Times[ -0.062044074975450475, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ 0.070907514257657775, 
              c[ -22][ t]], 
            Times[ 0.14938649372796345, 
              c[ -21][ t]], 
            Times[ 0.23387232094715985, 
              c[ -20][ t]], 
            Times[ 0.32256865202152157, 
              c[ -19][ t]], 
            Times[ 0.41349667156634395, 
              c[ -18][ t]], 
            Times[ 0.50455115242710469, 
              c[ -17][ t]], 
            Times[ 0.59356153372868048, 
              c[ -16][ t]], 
            Times[ 0.67835603854706328, 
              c[ -15][ t]], 
            Times[ 0.75682672864065703, 
              c[ -14][ t]], 
            Times[ 0.82699334313268824, 
              c[ -13][ t]], 
            Times[ 0.8870637930591837, 
              c[ -12][ t]], 
            Times[ 0.93548928378863916, 
              c[ -11][ t]], 
            Times[ 0.9710122092317629, 
              c[ -10][ t]], 
            Times[ 0.99270519960720671, 
              c[ -9][ t]], 
            Times[ 2.4036770703771531, 
              c[ -8][ t]], 
            Times[ 0.99270519960720671, 
              c[ -7][ t]], 
            Times[ 0.9710122092317629, 
              c[ -6][ t]], 
            Times[ 0.93548928378863916, 
              c[ -5][ t]], 
            Times[ 0.88706379305918381, 
              c[ -4][ t]], 
            Times[ 0.82699334313268824, 
              c[ -3][ t]], 
            Times[ 0.75682672864065692, 
              c[ -2][ t]], 
            Times[ 0.67835603854706339, 
              c[ -1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 0][ t]], 
            Times[ 0.50455115242710469, 
              c[ 1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 2][ t]], 
            Times[ 0.32256865202152157, 
              c[ 3][ t]], 
            Times[ 0.23387232094715985, 
              c[ 4][ t]], 
            Times[ 0.14938649372796362, 
              c[ 5][ t]], 
            Times[ 0.070907514257657775, 
              c[ 6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ -0.062044074975450343, 
              c[ 8][ t]], 
            Times[ -0.11423673049785436, 
              c[ 9][ t]], 
            Times[ -0.15591488063143982, 
              c[ 10][ t]], 
            Times[ -0.18675027222298593, 
              c[ 11][ t]], 
            Times[ -0.206748335783172, 
              c[ 12][ t]], 
            Times[ -0.21623620818304484, 
              c[ 13][ t]], 
            Times[ -0.21584055771952015, 
              c[ 14][ t]], 
            Times[ -0.20645618564475843, 
              c[ 15][ t]], 
            Times[ -0.18920668216016426, 
              c[ 16][ t]], 
            Times[ -0.16539866862653771, 
              c[ 17][ t]], 
            Times[ -0.13647135277833605, 
              c[ 18][ t]], 
            Times[ -0.10394325375429328, 
              c[ 19][ t]], 
            Times[ -0.06935801494512607, 
              c[ 20][ t]], 
            Times[ -0.034231213779558949, 
              c[ 21][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 22][ t]], 
            Times[ 0.032022748374425904, 
              c[ 23][ t]], 
            Times[ 0.060688263076985105, 
              c[ 24][ t]], 
            Times[ 0.085044480344421608, 
              c[ 25][ t]], 
            Times[ 0.10436044624225685, 
              c[ 26][ t]], 
            Times[ 0.11814190616181255, 
              c[ 27][ t]], 
            Times[ 0.12613778810677612, 
              c[ 28][ t]], 
            Times[ 0.12833762891430928, 
              c[ 29][ t]], 
            Times[ 0.12496032289024853, 
              c[ 30][ t]], 
            Times[ 0.11643488132933186, 
              c[ 31][ t]], 
            Times[ 0.10337416789158609, 
              c[ 32][ t]], 
            Times[ 0.086542809078944752, 
              c[ 33][ t]], 
            Times[ 0.066820663127759972, 
              c[ 34][ t]], 
            Times[ 0.045163358568919301, 
              c[ 35][ t]], 
            Times[ 0.022561481809254675, 
              c[ 36][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 37][ t]], 
            Times[ -0.021580547817547879, 
              c[ 38][ t]], 
            Times[ -0.041319668477947373, 
              c[ 39][ t]], 
            Times[ -0.058468080236789913, 
              c[ 40][ t]], 
            Times[ -0.072413370861974122, 
              c[ 41][ t]], 
            Times[ -0.082699334313268813, 
              c[ 42][ t]], 
            Times[ -0.089038438663606695, 
              c[ 43][ t]], 
            Times[ -0.091317159035181589, 
              c[ 44][ t]], 
            Times[ -0.089594193770366842, 
              c[ 45][ t]], 
            Times[ -0.084091858737850814, 
              c[ 46][ t]], 
            Times[ -0.075181213012062598, 
              c[ 47][ t]], 
            Times[ -0.063361699504227403, 
              c[ 48][ t]], 
            Times[ -0.049236278094138941, 
              c[ 49][ t]], 
            Times[ -0.033483179628681567, 
              c[ 50][ t]], 
            Times[ -0.016825511857749262, 
              c[ 51][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ 0.016273855731265604, 
              c[ 53][ t]], 
            Times[ 0.031322974491347202, 
              c[ 54][ t]], 
            Times[ 0.044547108751839919, 
              c[ 55][ t]], 
            Times[ 0.055441487066198933, 
              c[ 56][ t]], 
            Times[ 0.063614872548668322, 
              c[ 57][ t]], 
            Times[ 0.068802429876423349, 
              c[ 58][ t]], 
            Times[ 0.070873018952678238, 
              c[ 59][ t]], 
            Times[ 0.069830768673962387, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-7\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-7\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08959419377036684`\)\ \(c[\(-60\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-59\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-58\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-57\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-56\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-55\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-54\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-53\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-52\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-51\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-50\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-49\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-48\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-47\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-46\)]\)[t] + 
            0.12496032289024847`\ \(c[\(-45\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-44\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-43\)]\)[t] + 
            0.1181419061618126`\ \(c[\(-42\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-41\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-40\)]\)[t] + 
            0.06068826307698522`\ \(c[\(-39\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-38\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.034231213779558796`\ \(c[\(-36\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-35\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-34\)]\)[t] - 
            0.1364713527783359`\ \(c[\(-33\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-32\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-31\)]\)[t] - 
            0.20645618564475834`\ \(c[\(-30\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-29\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-28\)]\)[t] - 
            0.20674833578317206`\ \(c[\(-27\)]\)[t] - 
            0.186750272222986`\ \(c[\(-26\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-25\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-24\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-23\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-22\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-21\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-20\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-19\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-18\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-17\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-16\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-15\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-14\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-13\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-12\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-11\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-10\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-9\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-8\)]\)[t] + 
            2.0746902570075076`\ \(c[\(-7\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-6\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-5\)]\)[t] + 
            0.935489283788639`\ \(c[\(-4\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-3\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-2\)]\)[t] + 
            0.756826728640657`\ \(c[\(-1\)]\)[t] + 
            0.6783560385470634`\ \(c[0]\)[t] + 
            0.5935615337286805`\ \(c[1]\)[t] + 
            0.5045511524271047`\ \(c[2]\)[t] + 
            0.4134966715663442`\ \(c[3]\)[t] + 
            0.3225686520215216`\ \(c[4]\)[t] + 
            0.23387232094715985`\ \(c[5]\)[t] + 
            0.14938649372796362`\ \(c[6]\)[t] + 
            0.07090751425765777`\ \(c[7]\)[t] + 
            3.898171832519376`*^-17\ \(c[8]\)[t] - 
            0.06204407497545034`\ \(c[9]\)[t] - 
            0.11423673049785436`\ \(c[10]\)[t] - 
            0.15591488063143974`\ \(c[11]\)[t] - 
            0.186750272222986`\ \(c[12]\)[t] - 
            0.206748335783172`\ \(c[13]\)[t] - 
            0.21623620818304484`\ \(c[14]\)[t] - 
            0.21584055771952015`\ \(c[15]\)[t] - 
            0.20645618564475843`\ \(c[16]\)[t] - 
            0.18920668216016426`\ \(c[17]\)[t] - 
            0.1653986686265377`\ \(c[18]\)[t] - 
            0.13647135277833605`\ \(c[19]\)[t] - 
            0.10394325375429328`\ \(c[20]\)[t] - 
            0.06935801494512607`\ \(c[21]\)[t] - 
            0.034231213779559094`\ \(c[22]\)[t] - 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.032022748374425904`\ \(c[24]\)[t] + 
            0.060688263076985`\ \(c[25]\)[t] + 
            0.0850444803444217`\ \(c[26]\)[t] + 
            0.10436044624225685`\ \(c[27]\)[t] + 
            0.11814190616181253`\ \(c[28]\)[t] + 
            0.12613778810677614`\ \(c[29]\)[t] + 
            0.12833762891430928`\ \(c[30]\)[t] + 
            0.12496032289024853`\ \(c[31]\)[t] + 
            0.11643488132933186`\ \(c[32]\)[t] + 
            0.10337416789158609`\ \(c[33]\)[t] + 
            0.08654280907894489`\ \(c[34]\)[t] + 
            0.06682066312775997`\ \(c[35]\)[t] + 
            0.0451633585689193`\ \(c[36]\)[t] + 
            0.02256148180925487`\ \(c[37]\)[t] + 
            3.8981718325193755`*^-17\ \(c[38]\)[t] - 
            0.02158054781754788`\ \(c[39]\)[t] - 
            0.04131966847794722`\ \(c[40]\)[t] - 
            0.058468080236789774`\ \(c[41]\)[t] - 
            0.07241337086197412`\ \(c[42]\)[t] - 
            0.08269933431326874`\ \(c[43]\)[t] - 
            0.08903843866360665`\ \(c[44]\)[t] - 
            0.09131715903518159`\ \(c[45]\)[t] - 
            0.08959419377036688`\ \(c[46]\)[t] - 
            0.08409185873785086`\ \(c[47]\)[t] - 
            0.0751812130120626`\ \(c[48]\)[t] - 
            0.06336169950422753`\ \(c[49]\)[t] - 
            0.049236278094139066`\ \(c[50]\)[t] - 
            0.03348317962868157`\ \(c[51]\)[t] - 
            0.0168255118577494`\ \(c[52]\)[t] - 
            1.8033970416801674`*^-16\ \(c[53]\)[t] + 
            0.016273855731265604`\ \(c[54]\)[t] + 
            0.03132297449134708`\ \(c[55]\)[t] + 
            0.044547108751839815`\ \(c[56]\)[t] + 
            0.05544148706619893`\ \(c[57]\)[t] + 
            0.06361487254866825`\ \(c[58]\)[t] + 
            0.06880242987642332`\ \(c[59]\)[t] + 
            0.07087301895267824`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -7, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -7]][ t]], 
          Plus[ 
            Times[ -0.089594193770366842, 
              c[ -60][ t]], 
            Times[ -0.091317159035181589, 
              c[ -59][ t]], 
            Times[ -0.089038438663606695, 
              c[ -58][ t]], 
            Times[ -0.082699334313268813, 
              c[ -57][ t]], 
            Times[ -0.072413370861974122, 
              c[ -56][ t]], 
            Times[ -0.058468080236789913, 
              c[ -55][ t]], 
            Times[ -0.041319668477947373, 
              c[ -54][ t]], 
            Times[ -0.021580547817547879, 
              c[ -53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -52][ t]], 
            Times[ 0.022561481809254675, 
              c[ -51][ t]], 
            Times[ 0.045163358568919301, 
              c[ -50][ t]], 
            Times[ 0.066820663127759972, 
              c[ -49][ t]], 
            Times[ 0.086542809078944752, 
              c[ -48][ t]], 
            Times[ 0.10337416789158609, 
              c[ -47][ t]], 
            Times[ 0.11643488132933186, 
              c[ -46][ t]], 
            Times[ 0.12496032289024847, 
              c[ -45][ t]], 
            Times[ 0.12833762891430928, 
              c[ -44][ t]], 
            Times[ 0.12613778810677614, 
              c[ -43][ t]], 
            Times[ 0.1181419061618126, 
              c[ -42][ t]], 
            Times[ 0.10436044624225685, 
              c[ -41][ t]], 
            Times[ 0.085044480344421705, 
              c[ -40][ t]], 
            Times[ 0.060688263076985223, 
              c[ -39][ t]], 
            Times[ 0.032022748374425904, 
              c[ -38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.034231213779558796, 
              c[ -36][ t]], 
            Times[ -0.06935801494512607, 
              c[ -35][ t]], 
            Times[ -0.10394325375429328, 
              c[ -34][ t]], 
            Times[ -0.13647135277833591, 
              c[ -33][ t]], 
            Times[ -0.16539866862653771, 
              c[ -32][ t]], 
            Times[ -0.18920668216016426, 
              c[ -31][ t]], 
            Times[ -0.20645618564475834, 
              c[ -30][ t]], 
            Times[ -0.21584055771952015, 
              c[ -29][ t]], 
            Times[ -0.21623620818304484, 
              c[ -28][ t]], 
            Times[ -0.20674833578317206, 
              c[ -27][ t]], 
            Times[ -0.18675027222298601, 
              c[ -26][ t]], 
            Times[ -0.15591488063143974, 
              c[ -25][ t]], 
            Times[ -0.11423673049785445, 
              c[ -24][ t]], 
            Times[ -0.062044074975450343, 
              c[ -23][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -22][ t]], 
            Times[ 0.070907514257657622, 
              c[ -21][ t]], 
            Times[ 0.14938649372796362, 
              c[ -20][ t]], 
            Times[ 0.23387232094715985, 
              c[ -19][ t]], 
            Times[ 0.32256865202152135, 
              c[ -18][ t]], 
            Times[ 0.41349667156634418, 
              c[ -17][ t]], 
            Times[ 0.50455115242710469, 
              c[ -16][ t]], 
            Times[ 0.59356153372868026, 
              c[ -15][ t]], 
            Times[ 0.67835603854706339, 
              c[ -14][ t]], 
            Times[ 0.75682672864065692, 
              c[ -13][ t]], 
            Times[ 0.82699334313268813, 
              c[ -12][ t]], 
            Times[ 0.88706379305918381, 
              c[ -11][ t]], 
            Times[ 0.93548928378863916, 
              c[ -10][ t]], 
            Times[ 0.9710122092317629, 
              c[ -9][ t]], 
            Times[ 0.99270519960720671, 
              c[ -8][ t]], 
            Times[ 2.0746902570075076, 
              c[ -7][ t]], 
            Times[ 0.99270519960720693, 
              c[ -6][ t]], 
            Times[ 0.9710122092317629, 
              c[ -5][ t]], 
            Times[ 0.93548928378863905, 
              c[ -4][ t]], 
            Times[ 0.88706379305918381, 
              c[ -3][ t]], 
            Times[ 0.82699334313268824, 
              c[ -2][ t]], 
            Times[ 0.75682672864065703, 
              c[ -1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 0][ t]], 
            Times[ 0.59356153372868048, 
              c[ 1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 2][ t]], 
            Times[ 0.41349667156634418, 
              c[ 3][ t]], 
            Times[ 0.32256865202152157, 
              c[ 4][ t]], 
            Times[ 0.23387232094715985, 
              c[ 5][ t]], 
            Times[ 0.14938649372796362, 
              c[ 6][ t]], 
            Times[ 0.070907514257657775, 
              c[ 7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ -0.062044074975450343, 
              c[ 9][ t]], 
            Times[ -0.11423673049785436, 
              c[ 10][ t]], 
            Times[ -0.15591488063143974, 
              c[ 11][ t]], 
            Times[ -0.18675027222298601, 
              c[ 12][ t]], 
            Times[ -0.206748335783172, 
              c[ 13][ t]], 
            Times[ -0.21623620818304484, 
              c[ 14][ t]], 
            Times[ -0.21584055771952015, 
              c[ 15][ t]], 
            Times[ -0.20645618564475843, 
              c[ 16][ t]], 
            Times[ -0.18920668216016426, 
              c[ 17][ t]], 
            Times[ -0.16539866862653771, 
              c[ 18][ t]], 
            Times[ -0.13647135277833605, 
              c[ 19][ t]], 
            Times[ -0.10394325375429328, 
              c[ 20][ t]], 
            Times[ -0.06935801494512607, 
              c[ 21][ t]], 
            Times[ -0.034231213779559094, 
              c[ 22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.032022748374425904, 
              c[ 24][ t]], 
            Times[ 0.060688263076985001, 
              c[ 25][ t]], 
            Times[ 0.085044480344421705, 
              c[ 26][ t]], 
            Times[ 0.10436044624225685, 
              c[ 27][ t]], 
            Times[ 0.11814190616181253, 
              c[ 28][ t]], 
            Times[ 0.12613778810677614, 
              c[ 29][ t]], 
            Times[ 0.12833762891430928, 
              c[ 30][ t]], 
            Times[ 0.12496032289024853, 
              c[ 31][ t]], 
            Times[ 0.11643488132933186, 
              c[ 32][ t]], 
            Times[ 0.10337416789158609, 
              c[ 33][ t]], 
            Times[ 0.086542809078944891, 
              c[ 34][ t]], 
            Times[ 0.066820663127759972, 
              c[ 35][ t]], 
            Times[ 0.045163358568919301, 
              c[ 36][ t]], 
            Times[ 0.022561481809254869, 
              c[ 37][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 38][ t]], 
            Times[ -0.021580547817547879, 
              c[ 39][ t]], 
            Times[ -0.04131966847794722, 
              c[ 40][ t]], 
            Times[ -0.058468080236789774, 
              c[ 41][ t]], 
            Times[ -0.072413370861974122, 
              c[ 42][ t]], 
            Times[ -0.082699334313268744, 
              c[ 43][ t]], 
            Times[ -0.089038438663606653, 
              c[ 44][ t]], 
            Times[ -0.091317159035181589, 
              c[ 45][ t]], 
            Times[ -0.089594193770366884, 
              c[ 46][ t]], 
            Times[ -0.084091858737850855, 
              c[ 47][ t]], 
            Times[ -0.075181213012062598, 
              c[ 48][ t]], 
            Times[ -0.063361699504227528, 
              c[ 49][ t]], 
            Times[ -0.049236278094139066, 
              c[ 50][ t]], 
            Times[ -0.033483179628681567, 
              c[ 51][ t]], 
            Times[ -0.016825511857749401, 
              c[ 52][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 53][ t]], 
            Times[ 0.016273855731265604, 
              c[ 54][ t]], 
            Times[ 0.031322974491347078, 
              c[ 55][ t]], 
            Times[ 0.044547108751839815, 
              c[ 56][ t]], 
            Times[ 0.055441487066198933, 
              c[ 57][ t]], 
            Times[ 0.063614872548668253, 
              c[ 58][ t]], 
            Times[ 0.068802429876423321, 
              c[ 59][ t]], 
            Times[ 0.070873018952678238, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-6\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-6\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.08409185873785081`\)\ \(c[\(-60\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-59\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-58\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-57\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-56\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-55\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-54\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-53\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-52\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-50\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-49\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-48\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-47\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-46\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-45\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-44\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-43\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-42\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-41\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-40\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-39\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-38\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-37\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-35\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-34\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-33\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-32\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-31\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-30\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-29\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-28\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-27\)]\)[t] - 
            0.206748335783172`\ \(c[\(-26\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-25\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-24\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-23\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-20\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-19\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-18\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-17\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-16\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-15\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-14\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-13\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-12\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-11\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-10\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-9\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-8\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-7\)]\)[t] + 
            1.7895683520871486`\ \(c[\(-6\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-5\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-4\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-3\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-2\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-1\)]\)[t] + 
            0.7568267286406569`\ \(c[0]\)[t] + 
            0.6783560385470633`\ \(c[1]\)[t] + 
            0.5935615337286805`\ \(c[2]\)[t] + 
            0.5045511524271047`\ \(c[3]\)[t] + 
            0.4134966715663442`\ \(c[4]\)[t] + 
            0.3225686520215216`\ \(c[5]\)[t] + 
            0.23387232094715985`\ \(c[6]\)[t] + 
            0.14938649372796362`\ \(c[7]\)[t] + 
            0.07090751425765777`\ \(c[8]\)[t] + 
            3.898171832519376`*^-17\ \(c[9]\)[t] - 
            0.06204407497545034`\ \(c[10]\)[t] - 
            0.11423673049785436`\ \(c[11]\)[t] - 
            0.15591488063143982`\ \(c[12]\)[t] - 
            0.186750272222986`\ \(c[13]\)[t] - 
            0.206748335783172`\ \(c[14]\)[t] - 
            0.21623620818304484`\ \(c[15]\)[t] - 
            0.21584055771952015`\ \(c[16]\)[t] - 
            0.20645618564475843`\ \(c[17]\)[t] - 
            0.18920668216016426`\ \(c[18]\)[t] - 
            0.1653986686265377`\ \(c[19]\)[t] - 
            0.13647135277833605`\ \(c[20]\)[t] - 
            0.10394325375429328`\ \(c[21]\)[t] - 
            0.06935801494512607`\ \(c[22]\)[t] - 
            0.03423121377955895`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.032022748374425904`\ \(c[25]\)[t] + 
            0.060688263076985105`\ \(c[26]\)[t] + 
            0.0850444803444217`\ \(c[27]\)[t] + 
            0.10436044624225685`\ \(c[28]\)[t] + 
            0.11814190616181255`\ \(c[29]\)[t] + 
            0.12613778810677614`\ \(c[30]\)[t] + 
            0.12833762891430928`\ \(c[31]\)[t] + 
            0.12496032289024853`\ \(c[32]\)[t] + 
            0.11643488132933186`\ \(c[33]\)[t] + 
            0.10337416789158609`\ \(c[34]\)[t] + 
            0.08654280907894489`\ \(c[35]\)[t] + 
            0.06682066312775997`\ \(c[36]\)[t] + 
            0.0451633585689193`\ \(c[37]\)[t] + 
            0.02256148180925487`\ \(c[38]\)[t] + 
            3.8981718325193755`*^-17\ \(c[39]\)[t] - 
            0.02158054781754788`\ \(c[40]\)[t] - 
            0.04131966847794722`\ \(c[41]\)[t] - 
            0.05846808023678991`\ \(c[42]\)[t] - 
            0.07241337086197412`\ \(c[43]\)[t] - 
            0.08269933431326874`\ \(c[44]\)[t] - 
            0.0890384386636067`\ \(c[45]\)[t] - 
            0.09131715903518159`\ \(c[46]\)[t] - 
            0.08959419377036688`\ \(c[47]\)[t] - 
            0.08409185873785081`\ \(c[48]\)[t] - 
            0.0751812130120626`\ \(c[49]\)[t] - 
            0.06336169950422753`\ \(c[50]\)[t] - 
            0.04923627809413894`\ \(c[51]\)[t] - 
            0.03348317962868157`\ \(c[52]\)[t] - 
            0.0168255118577494`\ \(c[53]\)[t] - 
            3.898171832519376`*^-17\ \(c[54]\)[t] + 
            0.016273855731265604`\ \(c[55]\)[t] + 
            0.03132297449134708`\ \(c[56]\)[t] + 
            0.04454710875183992`\ \(c[57]\)[t] + 
            0.05544148706619893`\ \(c[58]\)[t] + 
            0.06361487254866825`\ \(c[59]\)[t] + 
            0.06880242987642335`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -6, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -6]][ t]], 
          Plus[ 
            Times[ -0.084091858737850814, 
              c[ -60][ t]], 
            Times[ -0.089594193770366884, 
              c[ -59][ t]], 
            Times[ -0.091317159035181589, 
              c[ -58][ t]], 
            Times[ -0.089038438663606695, 
              c[ -57][ t]], 
            Times[ -0.082699334313268744, 
              c[ -56][ t]], 
            Times[ -0.072413370861974122, 
              c[ -55][ t]], 
            Times[ -0.058468080236789913, 
              c[ -54][ t]], 
            Times[ -0.04131966847794722, 
              c[ -53][ t]], 
            Times[ -0.021580547817547879, 
              c[ -52][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ 0.022561481809254869, 
              c[ -50][ t]], 
            Times[ 0.045163358568919301, 
              c[ -49][ t]], 
            Times[ 0.066820663127759972, 
              c[ -48][ t]], 
            Times[ 0.086542809078944891, 
              c[ -47][ t]], 
            Times[ 0.10337416789158609, 
              c[ -46][ t]], 
            Times[ 0.11643488132933186, 
              c[ -45][ t]], 
            Times[ 0.12496032289024853, 
              c[ -44][ t]], 
            Times[ 0.12833762891430928, 
              c[ -43][ t]], 
            Times[ 0.12613778810677614, 
              c[ -42][ t]], 
            Times[ 0.11814190616181253, 
              c[ -41][ t]], 
            Times[ 0.10436044624225685, 
              c[ -40][ t]], 
            Times[ 0.085044480344421705, 
              c[ -39][ t]], 
            Times[ 0.060688263076985105, 
              c[ -38][ t]], 
            Times[ 0.032022748374425904, 
              c[ -37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.034231213779558949, 
              c[ -35][ t]], 
            Times[ -0.06935801494512607, 
              c[ -34][ t]], 
            Times[ -0.10394325375429328, 
              c[ -33][ t]], 
            Times[ -0.13647135277833605, 
              c[ -32][ t]], 
            Times[ -0.16539866862653771, 
              c[ -31][ t]], 
            Times[ -0.18920668216016426, 
              c[ -30][ t]], 
            Times[ -0.20645618564475843, 
              c[ -29][ t]], 
            Times[ -0.21584055771952015, 
              c[ -28][ t]], 
            Times[ -0.21623620818304484, 
              c[ -27][ t]], 
            Times[ -0.206748335783172, 
              c[ -26][ t]], 
            Times[ -0.18675027222298593, 
              c[ -25][ t]], 
            Times[ -0.15591488063143982, 
              c[ -24][ t]], 
            Times[ -0.11423673049785436, 
              c[ -23][ t]], 
            Times[ -0.062044074975450239, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.070907514257657775, 
              c[ -20][ t]], 
            Times[ 0.14938649372796362, 
              c[ -19][ t]], 
            Times[ 0.23387232094715985, 
              c[ -18][ t]], 
            Times[ 0.32256865202152157, 
              c[ -17][ t]], 
            Times[ 0.41349667156634418, 
              c[ -16][ t]], 
            Times[ 0.50455115242710469, 
              c[ -15][ t]], 
            Times[ 0.59356153372868059, 
              c[ -14][ t]], 
            Times[ 0.67835603854706339, 
              c[ -13][ t]], 
            Times[ 0.75682672864065692, 
              c[ -12][ t]], 
            Times[ 0.82699334313268813, 
              c[ -11][ t]], 
            Times[ 0.88706379305918381, 
              c[ -10][ t]], 
            Times[ 0.93548928378863916, 
              c[ -9][ t]], 
            Times[ 0.9710122092317629, 
              c[ -8][ t]], 
            Times[ 0.99270519960720693, 
              c[ -7][ t]], 
            Times[ 1.7895683520871486, 
              c[ -6][ t]], 
            Times[ 0.99270519960720671, 
              c[ -5][ t]], 
            Times[ 0.9710122092317629, 
              c[ -4][ t]], 
            Times[ 0.93548928378863916, 
              c[ -3][ t]], 
            Times[ 0.8870637930591837, 
              c[ -2][ t]], 
            Times[ 0.82699334313268824, 
              c[ -1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 0][ t]], 
            Times[ 0.67835603854706328, 
              c[ 1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 2][ t]], 
            Times[ 0.50455115242710469, 
              c[ 3][ t]], 
            Times[ 0.41349667156634418, 
              c[ 4][ t]], 
            Times[ 0.32256865202152157, 
              c[ 5][ t]], 
            Times[ 0.23387232094715985, 
              c[ 6][ t]], 
            Times[ 0.14938649372796362, 
              c[ 7][ t]], 
            Times[ 0.070907514257657775, 
              c[ 8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ -0.062044074975450343, 
              c[ 10][ t]], 
            Times[ -0.11423673049785436, 
              c[ 11][ t]], 
            Times[ -0.15591488063143982, 
              c[ 12][ t]], 
            Times[ -0.18675027222298601, 
              c[ 13][ t]], 
            Times[ -0.206748335783172, 
              c[ 14][ t]], 
            Times[ -0.21623620818304484, 
              c[ 15][ t]], 
            Times[ -0.21584055771952015, 
              c[ 16][ t]], 
            Times[ -0.20645618564475843, 
              c[ 17][ t]], 
            Times[ -0.18920668216016426, 
              c[ 18][ t]], 
            Times[ -0.16539866862653771, 
              c[ 19][ t]], 
            Times[ -0.13647135277833605, 
              c[ 20][ t]], 
            Times[ -0.10394325375429328, 
              c[ 21][ t]], 
            Times[ -0.06935801494512607, 
              c[ 22][ t]], 
            Times[ -0.034231213779558949, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.032022748374425904, 
              c[ 25][ t]], 
            Times[ 0.060688263076985105, 
              c[ 26][ t]], 
            Times[ 0.085044480344421705, 
              c[ 27][ t]], 
            Times[ 0.10436044624225685, 
              c[ 28][ t]], 
            Times[ 0.11814190616181255, 
              c[ 29][ t]], 
            Times[ 0.12613778810677614, 
              c[ 30][ t]], 
            Times[ 0.12833762891430928, 
              c[ 31][ t]], 
            Times[ 0.12496032289024853, 
              c[ 32][ t]], 
            Times[ 0.11643488132933186, 
              c[ 33][ t]], 
            Times[ 0.10337416789158609, 
              c[ 34][ t]], 
            Times[ 0.086542809078944891, 
              c[ 35][ t]], 
            Times[ 0.066820663127759972, 
              c[ 36][ t]], 
            Times[ 0.045163358568919301, 
              c[ 37][ t]], 
            Times[ 0.022561481809254869, 
              c[ 38][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 39][ t]], 
            Times[ -0.021580547817547879, 
              c[ 40][ t]], 
            Times[ -0.04131966847794722, 
              c[ 41][ t]], 
            Times[ -0.058468080236789913, 
              c[ 42][ t]], 
            Times[ -0.072413370861974122, 
              c[ 43][ t]], 
            Times[ -0.082699334313268744, 
              c[ 44][ t]], 
            Times[ -0.089038438663606695, 
              c[ 45][ t]], 
            Times[ -0.091317159035181589, 
              c[ 46][ t]], 
            Times[ -0.089594193770366884, 
              c[ 47][ t]], 
            Times[ -0.084091858737850814, 
              c[ 48][ t]], 
            Times[ -0.075181213012062598, 
              c[ 49][ t]], 
            Times[ -0.063361699504227528, 
              c[ 50][ t]], 
            Times[ -0.049236278094138941, 
              c[ 51][ t]], 
            Times[ -0.033483179628681567, 
              c[ 52][ t]], 
            Times[ -0.016825511857749401, 
              c[ 53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ 0.016273855731265604, 
              c[ 55][ t]], 
            Times[ 0.031322974491347078, 
              c[ 56][ t]], 
            Times[ 0.044547108751839919, 
              c[ 57][ t]], 
            Times[ 0.055441487066198933, 
              c[ 58][ t]], 
            Times[ 0.063614872548668253, 
              c[ 59][ t]], 
            Times[ 0.068802429876423349, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-5\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-5\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0751812130120626`\)\ \(c[\(-60\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-59\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-58\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-57\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-56\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-55\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-54\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-53\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-52\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-51\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-50\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-49\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-48\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-47\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-46\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-45\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-44\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-43\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-42\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-41\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-40\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-39\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-38\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-37\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-36\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-34\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-33\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-32\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-31\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-30\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-29\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-28\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-27\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-26\)]\)[t] - 
            0.206748335783172`\ \(c[\(-25\)]\)[t] - 
            0.18675027222298607`\ \(c[\(-24\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-23\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-22\)]\)[t] - 
            0.062044074975450475`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-19\)]\)[t] + 
            0.14938649372796345`\ \(c[\(-18\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-17\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-16\)]\)[t] + 
            0.41349667156634395`\ \(c[\(-15\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-14\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-13\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-12\)]\)[t] + 
            0.756826728640657`\ \(c[\(-11\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-10\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-9\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-8\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-7\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-6\)]\)[t] + 
            1.5483113556160752`\ \(c[\(-5\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-4\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-3\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-2\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-1\)]\)[t] + 
            0.8269933431326882`\ \(c[0]\)[t] + 
            0.7568267286406569`\ \(c[1]\)[t] + 
            0.6783560385470634`\ \(c[2]\)[t] + 
            0.5935615337286805`\ \(c[3]\)[t] + 
            0.5045511524271047`\ \(c[4]\)[t] + 
            0.4134966715663442`\ \(c[5]\)[t] + 
            0.3225686520215216`\ \(c[6]\)[t] + 
            0.23387232094715985`\ \(c[7]\)[t] + 
            0.14938649372796362`\ \(c[8]\)[t] + 
            0.07090751425765777`\ \(c[9]\)[t] + 
            3.898171832519376`*^-17\ \(c[10]\)[t] - 
            0.06204407497545024`\ \(c[11]\)[t] - 
            0.11423673049785436`\ \(c[12]\)[t] - 
            0.15591488063143982`\ \(c[13]\)[t] - 
            0.18675027222298593`\ \(c[14]\)[t] - 
            0.206748335783172`\ \(c[15]\)[t] - 
            0.21623620818304484`\ \(c[16]\)[t] - 
            0.21584055771952015`\ \(c[17]\)[t] - 
            0.20645618564475843`\ \(c[18]\)[t] - 
            0.18920668216016426`\ \(c[19]\)[t] - 
            0.1653986686265377`\ \(c[20]\)[t] - 
            0.13647135277833605`\ \(c[21]\)[t] - 
            0.1039432537542934`\ \(c[22]\)[t] - 
            0.06935801494512607`\ \(c[23]\)[t] - 
            0.03423121377955895`\ \(c[24]\)[t] - 
            1.8033970416801674`*^-16\ \(c[25]\)[t] + 
            0.032022748374425904`\ \(c[26]\)[t] + 
            0.060688263076985105`\ \(c[27]\)[t] + 
            0.08504448034442161`\ \(c[28]\)[t] + 
            0.10436044624225685`\ \(c[29]\)[t] + 
            0.11814190616181255`\ \(c[30]\)[t] + 
            0.12613778810677612`\ \(c[31]\)[t] + 
            0.12833762891430928`\ \(c[32]\)[t] + 
            0.12496032289024853`\ \(c[33]\)[t] + 
            0.11643488132933186`\ \(c[34]\)[t] + 
            0.10337416789158609`\ \(c[35]\)[t] + 
            0.08654280907894475`\ \(c[36]\)[t] + 
            0.06682066312775997`\ \(c[37]\)[t] + 
            0.0451633585689193`\ \(c[38]\)[t] + 
            0.022561481809254675`\ \(c[39]\)[t] + 
            3.8981718325193755`*^-17\ \(c[40]\)[t] - 
            0.02158054781754788`\ \(c[41]\)[t] - 
            0.04131966847794737`\ \(c[42]\)[t] - 
            0.05846808023678991`\ \(c[43]\)[t] - 
            0.07241337086197412`\ \(c[44]\)[t] - 
            0.08269933431326881`\ \(c[45]\)[t] - 
            0.0890384386636067`\ \(c[46]\)[t] - 
            0.09131715903518159`\ \(c[47]\)[t] - 
            0.08959419377036684`\ \(c[48]\)[t] - 
            0.08409185873785081`\ \(c[49]\)[t] - 
            0.0751812130120626`\ \(c[50]\)[t] - 
            0.0633616995042274`\ \(c[51]\)[t] - 
            0.04923627809413894`\ \(c[52]\)[t] - 
            0.03348317962868157`\ \(c[53]\)[t] - 
            0.016825511857749262`\ \(c[54]\)[t] - 
            3.898171832519376`*^-17\ \(c[55]\)[t] + 
            0.016273855731265604`\ \(c[56]\)[t] + 
            0.0313229744913472`\ \(c[57]\)[t] + 
            0.04454710875183992`\ \(c[58]\)[t] + 
            0.05544148706619893`\ \(c[59]\)[t] + 
            0.06361487254866832`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -5, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -5]][ t]], 
          Plus[ 
            Times[ -0.075181213012062598, 
              c[ -60][ t]], 
            Times[ -0.084091858737850855, 
              c[ -59][ t]], 
            Times[ -0.089594193770366884, 
              c[ -58][ t]], 
            Times[ -0.091317159035181589, 
              c[ -57][ t]], 
            Times[ -0.089038438663606653, 
              c[ -56][ t]], 
            Times[ -0.082699334313268744, 
              c[ -55][ t]], 
            Times[ -0.072413370861974122, 
              c[ -54][ t]], 
            Times[ -0.058468080236789774, 
              c[ -53][ t]], 
            Times[ -0.04131966847794722, 
              c[ -52][ t]], 
            Times[ -0.021580547817547879, 
              c[ -51][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -50][ t]], 
            Times[ 0.022561481809254869, 
              c[ -49][ t]], 
            Times[ 0.045163358568919301, 
              c[ -48][ t]], 
            Times[ 0.066820663127760152, 
              c[ -47][ t]], 
            Times[ 0.086542809078944891, 
              c[ -46][ t]], 
            Times[ 0.10337416789158609, 
              c[ -45][ t]], 
            Times[ 0.11643488132933195, 
              c[ -44][ t]], 
            Times[ 0.12496032289024853, 
              c[ -43][ t]], 
            Times[ 0.12833762891430925, 
              c[ -42][ t]], 
            Times[ 0.12613778810677612, 
              c[ -41][ t]], 
            Times[ 0.11814190616181255, 
              c[ -40][ t]], 
            Times[ 0.10436044624225692, 
              c[ -39][ t]], 
            Times[ 0.085044480344421705, 
              c[ -38][ t]], 
            Times[ 0.060688263076985105, 
              c[ -37][ t]], 
            Times[ 0.032022748374426029, 
              c[ -36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ -0.034231213779558949, 
              c[ -34][ t]], 
            Times[ -0.069358014945125918, 
              c[ -33][ t]], 
            Times[ -0.10394325375429328, 
              c[ -32][ t]], 
            Times[ -0.13647135277833605, 
              c[ -31][ t]], 
            Times[ -0.1653986686265376, 
              c[ -30][ t]], 
            Times[ -0.18920668216016426, 
              c[ -29][ t]], 
            Times[ -0.20645618564475843, 
              c[ -28][ t]], 
            Times[ -0.21584055771952013, 
              c[ -27][ t]], 
            Times[ -0.21623620818304484, 
              c[ -26][ t]], 
            Times[ -0.206748335783172, 
              c[ -25][ t]], 
            Times[ -0.18675027222298607, 
              c[ -24][ t]], 
            Times[ -0.15591488063143982, 
              c[ -23][ t]], 
            Times[ -0.11423673049785436, 
              c[ -22][ t]], 
            Times[ -0.062044074975450475, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ 0.070907514257657775, 
              c[ -19][ t]], 
            Times[ 0.14938649372796345, 
              c[ -18][ t]], 
            Times[ 0.23387232094715985, 
              c[ -17][ t]], 
            Times[ 0.32256865202152157, 
              c[ -16][ t]], 
            Times[ 0.41349667156634395, 
              c[ -15][ t]], 
            Times[ 0.50455115242710469, 
              c[ -14][ t]], 
            Times[ 0.59356153372868048, 
              c[ -13][ t]], 
            Times[ 0.67835603854706328, 
              c[ -12][ t]], 
            Times[ 0.75682672864065703, 
              c[ -11][ t]], 
            Times[ 0.82699334313268824, 
              c[ -10][ t]], 
            Times[ 0.8870637930591837, 
              c[ -9][ t]], 
            Times[ 0.93548928378863916, 
              c[ -8][ t]], 
            Times[ 0.9710122092317629, 
              c[ -7][ t]], 
            Times[ 0.99270519960720671, 
              c[ -6][ t]], 
            Times[ 1.5483113556160752, 
              c[ -5][ t]], 
            Times[ 0.99270519960720693, 
              c[ -4][ t]], 
            Times[ 0.9710122092317629, 
              c[ -3][ t]], 
            Times[ 0.93548928378863916, 
              c[ -2][ t]], 
            Times[ 0.88706379305918381, 
              c[ -1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 0][ t]], 
            Times[ 0.75682672864065692, 
              c[ 1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 2][ t]], 
            Times[ 0.59356153372868048, 
              c[ 3][ t]], 
            Times[ 0.50455115242710469, 
              c[ 4][ t]], 
            Times[ 0.41349667156634418, 
              c[ 5][ t]], 
            Times[ 0.32256865202152157, 
              c[ 6][ t]], 
            Times[ 0.23387232094715985, 
              c[ 7][ t]], 
            Times[ 0.14938649372796362, 
              c[ 8][ t]], 
            Times[ 0.070907514257657775, 
              c[ 9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ -0.062044074975450239, 
              c[ 11][ t]], 
            Times[ -0.11423673049785436, 
              c[ 12][ t]], 
            Times[ -0.15591488063143982, 
              c[ 13][ t]], 
            Times[ -0.18675027222298593, 
              c[ 14][ t]], 
            Times[ -0.206748335783172, 
              c[ 15][ t]], 
            Times[ -0.21623620818304484, 
              c[ 16][ t]], 
            Times[ -0.21584055771952015, 
              c[ 17][ t]], 
            Times[ -0.20645618564475843, 
              c[ 18][ t]], 
            Times[ -0.18920668216016426, 
              c[ 19][ t]], 
            Times[ -0.16539866862653771, 
              c[ 20][ t]], 
            Times[ -0.13647135277833605, 
              c[ 21][ t]], 
            Times[ -0.1039432537542934, 
              c[ 22][ t]], 
            Times[ -0.06935801494512607, 
              c[ 23][ t]], 
            Times[ -0.034231213779558949, 
              c[ 24][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 25][ t]], 
            Times[ 0.032022748374425904, 
              c[ 26][ t]], 
            Times[ 0.060688263076985105, 
              c[ 27][ t]], 
            Times[ 0.085044480344421608, 
              c[ 28][ t]], 
            Times[ 0.10436044624225685, 
              c[ 29][ t]], 
            Times[ 0.11814190616181255, 
              c[ 30][ t]], 
            Times[ 0.12613778810677612, 
              c[ 31][ t]], 
            Times[ 0.12833762891430928, 
              c[ 32][ t]], 
            Times[ 0.12496032289024853, 
              c[ 33][ t]], 
            Times[ 0.11643488132933186, 
              c[ 34][ t]], 
            Times[ 0.10337416789158609, 
              c[ 35][ t]], 
            Times[ 0.086542809078944752, 
              c[ 36][ t]], 
            Times[ 0.066820663127759972, 
              c[ 37][ t]], 
            Times[ 0.045163358568919301, 
              c[ 38][ t]], 
            Times[ 0.022561481809254675, 
              c[ 39][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 40][ t]], 
            Times[ -0.021580547817547879, 
              c[ 41][ t]], 
            Times[ -0.041319668477947373, 
              c[ 42][ t]], 
            Times[ -0.058468080236789913, 
              c[ 43][ t]], 
            Times[ -0.072413370861974122, 
              c[ 44][ t]], 
            Times[ -0.082699334313268813, 
              c[ 45][ t]], 
            Times[ -0.089038438663606695, 
              c[ 46][ t]], 
            Times[ -0.091317159035181589, 
              c[ 47][ t]], 
            Times[ -0.089594193770366842, 
              c[ 48][ t]], 
            Times[ -0.084091858737850814, 
              c[ 49][ t]], 
            Times[ -0.075181213012062598, 
              c[ 50][ t]], 
            Times[ -0.063361699504227403, 
              c[ 51][ t]], 
            Times[ -0.049236278094138941, 
              c[ 52][ t]], 
            Times[ -0.033483179628681567, 
              c[ 53][ t]], 
            Times[ -0.016825511857749262, 
              c[ 54][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ 0.016273855731265604, 
              c[ 56][ t]], 
            Times[ 0.031322974491347202, 
              c[ 57][ t]], 
            Times[ 0.044547108751839919, 
              c[ 58][ t]], 
            Times[ 0.055441487066198933, 
              c[ 59][ t]], 
            Times[ 0.063614872548668322, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-4\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-4\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0633616995042274`\)\ \(c[\(-60\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-59\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-58\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-57\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-56\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-55\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-54\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-53\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-52\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-51\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-50\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-49\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-48\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-47\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-46\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-45\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-44\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-43\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-42\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-41\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-40\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-39\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-38\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-37\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-36\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-35\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-34\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-33\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-32\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-31\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-30\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-29\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-28\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-27\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-26\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-25\)]\)[t] - 
            0.206748335783172`\ \(c[\(-24\)]\)[t] - 
            0.186750272222986`\ \(c[\(-23\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-22\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-21\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-20\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-18\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-17\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-16\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-15\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-14\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-13\)]\)[t] + 
            0.5935615337286803`\ \(c[\(-12\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-11\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-10\)]\)[t] + 
            0.8269933431326881`\ \(c[\(-9\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-8\)]\)[t] + 
            0.935489283788639`\ \(c[\(-7\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-6\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-5\)]\)[t] + 
            1.3509192675942883`\ \(c[\(-4\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-3\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-2\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-1\)]\)[t] + 
            0.8870637930591838`\ \(c[0]\)[t] + 
            0.8269933431326882`\ \(c[1]\)[t] + 
            0.7568267286406569`\ \(c[2]\)[t] + 
            0.6783560385470634`\ \(c[3]\)[t] + 
            0.5935615337286805`\ \(c[4]\)[t] + 
            0.5045511524271047`\ \(c[5]\)[t] + 
            0.4134966715663442`\ \(c[6]\)[t] + 
            0.3225686520215216`\ \(c[7]\)[t] + 
            0.23387232094715985`\ \(c[8]\)[t] + 
            0.14938649372796362`\ \(c[9]\)[t] + 
            0.07090751425765777`\ \(c[10]\)[t] + 
            1.8033970416801674`*^-16\ \(c[11]\)[t] - 
            0.06204407497545034`\ \(c[12]\)[t] - 
            0.11423673049785436`\ \(c[13]\)[t] - 
            0.15591488063143974`\ \(c[14]\)[t] - 
            0.186750272222986`\ \(c[15]\)[t] - 
            0.206748335783172`\ \(c[16]\)[t] - 
            0.21623620818304484`\ \(c[17]\)[t] - 
            0.21584055771952013`\ \(c[18]\)[t] - 
            0.20645618564475843`\ \(c[19]\)[t] - 
            0.18920668216016426`\ \(c[20]\)[t] - 
            0.1653986686265376`\ \(c[21]\)[t] - 
            0.13647135277833605`\ \(c[22]\)[t] - 
            0.10394325375429328`\ \(c[23]\)[t] - 
            0.06935801494512592`\ \(c[24]\)[t] - 
            0.03423121377955895`\ \(c[25]\)[t] - 
            3.898171832519376`*^-17\ \(c[26]\)[t] + 
            0.03202274837442603`\ \(c[27]\)[t] + 
            0.060688263076985105`\ \(c[28]\)[t] + 
            0.0850444803444217`\ \(c[29]\)[t] + 
            0.10436044624225692`\ \(c[30]\)[t] + 
            0.11814190616181255`\ \(c[31]\)[t] + 
            0.12613778810677614`\ \(c[32]\)[t] + 
            0.12833762891430925`\ \(c[33]\)[t] + 
            0.12496032289024853`\ \(c[34]\)[t] + 
            0.11643488132933186`\ \(c[35]\)[t] + 
            0.10337416789158609`\ \(c[36]\)[t] + 
            0.08654280907894489`\ \(c[37]\)[t] + 
            0.06682066312775997`\ \(c[38]\)[t] + 
            0.0451633585689193`\ \(c[39]\)[t] + 
            0.02256148180925487`\ \(c[40]\)[t] + 
            2.274590327822911`*^-16\ \(c[41]\)[t] - 
            0.02158054781754788`\ \(c[42]\)[t] - 
            0.04131966847794722`\ \(c[43]\)[t] - 
            0.058468080236789774`\ \(c[44]\)[t] - 
            0.07241337086197412`\ \(c[45]\)[t] - 
            0.08269933431326874`\ \(c[46]\)[t] - 
            0.08903843866360665`\ \(c[47]\)[t] - 
            0.09131715903518159`\ \(c[48]\)[t] - 
            0.08959419377036688`\ \(c[49]\)[t] - 
            0.08409185873785086`\ \(c[50]\)[t] - 
            0.0751812130120626`\ \(c[51]\)[t] - 
            0.06336169950422753`\ \(c[52]\)[t] - 
            0.049236278094139066`\ \(c[53]\)[t] - 
            0.03348317962868157`\ \(c[54]\)[t] - 
            0.0168255118577494`\ \(c[55]\)[t] - 
            1.8033970416801674`*^-16\ \(c[56]\)[t] + 
            0.016273855731265604`\ \(c[57]\)[t] + 
            0.03132297449134708`\ \(c[58]\)[t] + 
            0.044547108751839815`\ \(c[59]\)[t] + 
            0.05544148706619893`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -4, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -4]][ t]], 
          Plus[ 
            Times[ -0.063361699504227403, 
              c[ -60][ t]], 
            Times[ -0.075181213012062598, 
              c[ -59][ t]], 
            Times[ -0.084091858737850814, 
              c[ -58][ t]], 
            Times[ -0.089594193770366842, 
              c[ -57][ t]], 
            Times[ -0.091317159035181589, 
              c[ -56][ t]], 
            Times[ -0.089038438663606695, 
              c[ -55][ t]], 
            Times[ -0.082699334313268813, 
              c[ -54][ t]], 
            Times[ -0.072413370861974122, 
              c[ -53][ t]], 
            Times[ -0.058468080236789913, 
              c[ -52][ t]], 
            Times[ -0.041319668477947373, 
              c[ -51][ t]], 
            Times[ -0.021580547817547879, 
              c[ -50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -49][ t]], 
            Times[ 0.022561481809254675, 
              c[ -48][ t]], 
            Times[ 0.045163358568919301, 
              c[ -47][ t]], 
            Times[ 0.066820663127759972, 
              c[ -46][ t]], 
            Times[ 0.086542809078944752, 
              c[ -45][ t]], 
            Times[ 0.10337416789158609, 
              c[ -44][ t]], 
            Times[ 0.11643488132933186, 
              c[ -43][ t]], 
            Times[ 0.12496032289024853, 
              c[ -42][ t]], 
            Times[ 0.12833762891430925, 
              c[ -41][ t]], 
            Times[ 0.12613778810677612, 
              c[ -40][ t]], 
            Times[ 0.11814190616181255, 
              c[ -39][ t]], 
            Times[ 0.10436044624225685, 
              c[ -38][ t]], 
            Times[ 0.085044480344421608, 
              c[ -37][ t]], 
            Times[ 0.060688263076985105, 
              c[ -36][ t]], 
            Times[ 0.032022748374425904, 
              c[ -35][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -34][ t]], 
            Times[ -0.034231213779558949, 
              c[ -33][ t]], 
            Times[ -0.06935801494512607, 
              c[ -32][ t]], 
            Times[ -0.1039432537542934, 
              c[ -31][ t]], 
            Times[ -0.13647135277833605, 
              c[ -30][ t]], 
            Times[ -0.16539866862653771, 
              c[ -29][ t]], 
            Times[ -0.18920668216016434, 
              c[ -28][ t]], 
            Times[ -0.20645618564475843, 
              c[ -27][ t]], 
            Times[ -0.21584055771952015, 
              c[ -26][ t]], 
            Times[ -0.21623620818304481, 
              c[ -25][ t]], 
            Times[ -0.206748335783172, 
              c[ -24][ t]], 
            Times[ -0.18675027222298601, 
              c[ -23][ t]], 
            Times[ -0.15591488063143974, 
              c[ -22][ t]], 
            Times[ -0.11423673049785445, 
              c[ -21][ t]], 
            Times[ -0.062044074975450343, 
              c[ -20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ 0.070907514257657622, 
              c[ -18][ t]], 
            Times[ 0.14938649372796362, 
              c[ -17][ t]], 
            Times[ 0.23387232094715985, 
              c[ -16][ t]], 
            Times[ 0.32256865202152135, 
              c[ -15][ t]], 
            Times[ 0.41349667156634418, 
              c[ -14][ t]], 
            Times[ 0.50455115242710469, 
              c[ -13][ t]], 
            Times[ 0.59356153372868026, 
              c[ -12][ t]], 
            Times[ 0.67835603854706339, 
              c[ -11][ t]], 
            Times[ 0.75682672864065692, 
              c[ -10][ t]], 
            Times[ 0.82699334313268813, 
              c[ -9][ t]], 
            Times[ 0.88706379305918381, 
              c[ -8][ t]], 
            Times[ 0.93548928378863905, 
              c[ -7][ t]], 
            Times[ 0.9710122092317629, 
              c[ -6][ t]], 
            Times[ 0.99270519960720693, 
              c[ -5][ t]], 
            Times[ 1.3509192675942883, 
              c[ -4][ t]], 
            Times[ 0.99270519960720693, 
              c[ -3][ t]], 
            Times[ 0.9710122092317629, 
              c[ -2][ t]], 
            Times[ 0.93548928378863916, 
              c[ -1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 0][ t]], 
            Times[ 0.82699334313268824, 
              c[ 1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 2][ t]], 
            Times[ 0.67835603854706339, 
              c[ 3][ t]], 
            Times[ 0.59356153372868048, 
              c[ 4][ t]], 
            Times[ 0.50455115242710469, 
              c[ 5][ t]], 
            Times[ 0.41349667156634418, 
              c[ 6][ t]], 
            Times[ 0.32256865202152157, 
              c[ 7][ t]], 
            Times[ 0.23387232094715985, 
              c[ 8][ t]], 
            Times[ 0.14938649372796362, 
              c[ 9][ t]], 
            Times[ 0.070907514257657775, 
              c[ 10][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 11][ t]], 
            Times[ -0.062044074975450343, 
              c[ 12][ t]], 
            Times[ -0.11423673049785436, 
              c[ 13][ t]], 
            Times[ -0.15591488063143974, 
              c[ 14][ t]], 
            Times[ -0.18675027222298601, 
              c[ 15][ t]], 
            Times[ -0.206748335783172, 
              c[ 16][ t]], 
            Times[ -0.21623620818304484, 
              c[ 17][ t]], 
            Times[ -0.21584055771952013, 
              c[ 18][ t]], 
            Times[ -0.20645618564475843, 
              c[ 19][ t]], 
            Times[ -0.18920668216016426, 
              c[ 20][ t]], 
            Times[ -0.1653986686265376, 
              c[ 21][ t]], 
            Times[ -0.13647135277833605, 
              c[ 22][ t]], 
            Times[ -0.10394325375429328, 
              c[ 23][ t]], 
            Times[ -0.069358014945125918, 
              c[ 24][ t]], 
            Times[ -0.034231213779558949, 
              c[ 25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ 0.032022748374426029, 
              c[ 27][ t]], 
            Times[ 0.060688263076985105, 
              c[ 28][ t]], 
            Times[ 0.085044480344421705, 
              c[ 29][ t]], 
            Times[ 0.10436044624225692, 
              c[ 30][ t]], 
            Times[ 0.11814190616181255, 
              c[ 31][ t]], 
            Times[ 0.12613778810677614, 
              c[ 32][ t]], 
            Times[ 0.12833762891430925, 
              c[ 33][ t]], 
            Times[ 0.12496032289024853, 
              c[ 34][ t]], 
            Times[ 0.11643488132933186, 
              c[ 35][ t]], 
            Times[ 0.10337416789158609, 
              c[ 36][ t]], 
            Times[ 0.086542809078944891, 
              c[ 37][ t]], 
            Times[ 0.066820663127759972, 
              c[ 38][ t]], 
            Times[ 0.045163358568919301, 
              c[ 39][ t]], 
            Times[ 0.022561481809254869, 
              c[ 40][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 41][ t]], 
            Times[ -0.021580547817547879, 
              c[ 42][ t]], 
            Times[ -0.04131966847794722, 
              c[ 43][ t]], 
            Times[ -0.058468080236789774, 
              c[ 44][ t]], 
            Times[ -0.072413370861974122, 
              c[ 45][ t]], 
            Times[ -0.082699334313268744, 
              c[ 46][ t]], 
            Times[ -0.089038438663606653, 
              c[ 47][ t]], 
            Times[ -0.091317159035181589, 
              c[ 48][ t]], 
            Times[ -0.089594193770366884, 
              c[ 49][ t]], 
            Times[ -0.084091858737850855, 
              c[ 50][ t]], 
            Times[ -0.075181213012062598, 
              c[ 51][ t]], 
            Times[ -0.063361699504227528, 
              c[ 52][ t]], 
            Times[ -0.049236278094139066, 
              c[ 53][ t]], 
            Times[ -0.033483179628681567, 
              c[ 54][ t]], 
            Times[ -0.016825511857749401, 
              c[ 55][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 56][ t]], 
            Times[ 0.016273855731265604, 
              c[ 57][ t]], 
            Times[ 0.031322974491347078, 
              c[ 58][ t]], 
            Times[ 0.044547108751839815, 
              c[ 59][ t]], 
            Times[ 0.055441487066198933, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-3\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-3\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04923627809413894`\)\ \(c[\(-60\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-59\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-58\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-57\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-56\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-55\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-54\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-53\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-52\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-51\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-50\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-49\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-47\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-46\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-45\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-44\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-43\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-42\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-41\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-40\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-39\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-38\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-37\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-36\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-35\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-34\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-32\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-31\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-30\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-29\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-28\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-27\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-26\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-25\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-24\)]\)[t] - 
            0.206748335783172`\ \(c[\(-23\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-22\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-21\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-20\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-17\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-16\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-15\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-14\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-13\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-12\)]\)[t] + 
            0.5935615337286806`\ \(c[\(-11\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-10\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-9\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-8\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-7\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-6\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-5\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-4\)]\)[t] + 
            1.1973920880217872`\ \(c[\(-3\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-2\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-1\)]\)[t] + 
            0.9354892837886392`\ \(c[0]\)[t] + 
            0.8870637930591838`\ \(c[1]\)[t] + 
            0.8269933431326882`\ \(c[2]\)[t] + 
            0.7568267286406569`\ \(c[3]\)[t] + 
            0.6783560385470634`\ \(c[4]\)[t] + 
            0.5935615337286805`\ \(c[5]\)[t] + 
            0.5045511524271047`\ \(c[6]\)[t] + 
            0.4134966715663442`\ \(c[7]\)[t] + 
            0.3225686520215216`\ \(c[8]\)[t] + 
            0.23387232094715985`\ \(c[9]\)[t] + 
            0.14938649372796362`\ \(c[10]\)[t] + 
            0.07090751425765777`\ \(c[11]\)[t] + 
            3.898171832519376`*^-17\ \(c[12]\)[t] - 
            0.06204407497545034`\ \(c[13]\)[t] - 
            0.11423673049785436`\ \(c[14]\)[t] - 
            0.15591488063143982`\ \(c[15]\)[t] - 
            0.186750272222986`\ \(c[16]\)[t] - 
            0.206748335783172`\ \(c[17]\)[t] - 
            0.21623620818304484`\ \(c[18]\)[t] - 
            0.21584055771952015`\ \(c[19]\)[t] - 
            0.20645618564475843`\ \(c[20]\)[t] - 
            0.18920668216016426`\ \(c[21]\)[t] - 
            0.1653986686265377`\ \(c[22]\)[t] - 
            0.13647135277833605`\ \(c[23]\)[t] - 
            0.10394325375429328`\ \(c[24]\)[t] - 
            0.06935801494512607`\ \(c[25]\)[t] - 
            0.03423121377955895`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.032022748374425904`\ \(c[28]\)[t] + 
            0.060688263076985105`\ \(c[29]\)[t] + 
            0.0850444803444217`\ \(c[30]\)[t] + 
            0.10436044624225685`\ \(c[31]\)[t] + 
            0.11814190616181255`\ \(c[32]\)[t] + 
            0.12613778810677614`\ \(c[33]\)[t] + 
            0.12833762891430928`\ \(c[34]\)[t] + 
            0.12496032289024853`\ \(c[35]\)[t] + 
            0.11643488132933186`\ \(c[36]\)[t] + 
            0.10337416789158609`\ \(c[37]\)[t] + 
            0.08654280907894489`\ \(c[38]\)[t] + 
            0.06682066312775997`\ \(c[39]\)[t] + 
            0.0451633585689193`\ \(c[40]\)[t] + 
            0.02256148180925487`\ \(c[41]\)[t] + 
            3.8981718325193755`*^-17\ \(c[42]\)[t] - 
            0.02158054781754788`\ \(c[43]\)[t] - 
            0.04131966847794722`\ \(c[44]\)[t] - 
            0.05846808023678991`\ \(c[45]\)[t] - 
            0.07241337086197412`\ \(c[46]\)[t] - 
            0.08269933431326874`\ \(c[47]\)[t] - 
            0.0890384386636067`\ \(c[48]\)[t] - 
            0.09131715903518159`\ \(c[49]\)[t] - 
            0.08959419377036688`\ \(c[50]\)[t] - 
            0.08409185873785081`\ \(c[51]\)[t] - 
            0.0751812130120626`\ \(c[52]\)[t] - 
            0.06336169950422753`\ \(c[53]\)[t] - 
            0.04923627809413894`\ \(c[54]\)[t] - 
            0.03348317962868157`\ \(c[55]\)[t] - 
            0.0168255118577494`\ \(c[56]\)[t] - 
            3.898171832519376`*^-17\ \(c[57]\)[t] + 
            0.016273855731265604`\ \(c[58]\)[t] + 
            0.03132297449134708`\ \(c[59]\)[t] + 
            0.04454710875183992`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -3, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -3]][ t]], 
          Plus[ 
            Times[ -0.049236278094138941, 
              c[ -60][ t]], 
            Times[ -0.063361699504227528, 
              c[ -59][ t]], 
            Times[ -0.075181213012062598, 
              c[ -58][ t]], 
            Times[ -0.084091858737850814, 
              c[ -57][ t]], 
            Times[ -0.089594193770366884, 
              c[ -56][ t]], 
            Times[ -0.091317159035181589, 
              c[ -55][ t]], 
            Times[ -0.089038438663606695, 
              c[ -54][ t]], 
            Times[ -0.082699334313268744, 
              c[ -53][ t]], 
            Times[ -0.072413370861974122, 
              c[ -52][ t]], 
            Times[ -0.058468080236789913, 
              c[ -51][ t]], 
            Times[ -0.04131966847794722, 
              c[ -50][ t]], 
            Times[ -0.021580547817547879, 
              c[ -49][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ 0.022561481809254869, 
              c[ -47][ t]], 
            Times[ 0.045163358568919301, 
              c[ -46][ t]], 
            Times[ 0.066820663127759972, 
              c[ -45][ t]], 
            Times[ 0.086542809078944891, 
              c[ -44][ t]], 
            Times[ 0.10337416789158609, 
              c[ -43][ t]], 
            Times[ 0.11643488132933186, 
              c[ -42][ t]], 
            Times[ 0.12496032289024853, 
              c[ -41][ t]], 
            Times[ 0.12833762891430928, 
              c[ -40][ t]], 
            Times[ 0.12613778810677614, 
              c[ -39][ t]], 
            Times[ 0.11814190616181255, 
              c[ -38][ t]], 
            Times[ 0.10436044624225685, 
              c[ -37][ t]], 
            Times[ 0.085044480344421705, 
              c[ -36][ t]], 
            Times[ 0.060688263076985105, 
              c[ -35][ t]], 
            Times[ 0.032022748374425904, 
              c[ -34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.034231213779558949, 
              c[ -32][ t]], 
            Times[ -0.06935801494512607, 
              c[ -31][ t]], 
            Times[ -0.10394325375429328, 
              c[ -30][ t]], 
            Times[ -0.13647135277833605, 
              c[ -29][ t]], 
            Times[ -0.16539866862653771, 
              c[ -28][ t]], 
            Times[ -0.18920668216016426, 
              c[ -27][ t]], 
            Times[ -0.20645618564475843, 
              c[ -26][ t]], 
            Times[ -0.21584055771952015, 
              c[ -25][ t]], 
            Times[ -0.21623620818304484, 
              c[ -24][ t]], 
            Times[ -0.206748335783172, 
              c[ -23][ t]], 
            Times[ -0.18675027222298593, 
              c[ -22][ t]], 
            Times[ -0.15591488063143982, 
              c[ -21][ t]], 
            Times[ -0.11423673049785436, 
              c[ -20][ t]], 
            Times[ -0.062044074975450343, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.070907514257657775, 
              c[ -17][ t]], 
            Times[ 0.14938649372796362, 
              c[ -16][ t]], 
            Times[ 0.23387232094715985, 
              c[ -15][ t]], 
            Times[ 0.32256865202152157, 
              c[ -14][ t]], 
            Times[ 0.41349667156634418, 
              c[ -13][ t]], 
            Times[ 0.50455115242710469, 
              c[ -12][ t]], 
            Times[ 0.59356153372868059, 
              c[ -11][ t]], 
            Times[ 0.67835603854706339, 
              c[ -10][ t]], 
            Times[ 0.75682672864065692, 
              c[ -9][ t]], 
            Times[ 0.82699334313268824, 
              c[ -8][ t]], 
            Times[ 0.88706379305918381, 
              c[ -7][ t]], 
            Times[ 0.93548928378863916, 
              c[ -6][ t]], 
            Times[ 0.9710122092317629, 
              c[ -5][ t]], 
            Times[ 0.99270519960720693, 
              c[ -4][ t]], 
            Times[ 1.1973920880217872, 
              c[ -3][ t]], 
            Times[ 0.99270519960720671, 
              c[ -2][ t]], 
            Times[ 0.9710122092317629, 
              c[ -1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 0][ t]], 
            Times[ 0.88706379305918381, 
              c[ 1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 2][ t]], 
            Times[ 0.75682672864065692, 
              c[ 3][ t]], 
            Times[ 0.67835603854706339, 
              c[ 4][ t]], 
            Times[ 0.59356153372868048, 
              c[ 5][ t]], 
            Times[ 0.50455115242710469, 
              c[ 6][ t]], 
            Times[ 0.41349667156634418, 
              c[ 7][ t]], 
            Times[ 0.32256865202152157, 
              c[ 8][ t]], 
            Times[ 0.23387232094715985, 
              c[ 9][ t]], 
            Times[ 0.14938649372796362, 
              c[ 10][ t]], 
            Times[ 0.070907514257657775, 
              c[ 11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ -0.062044074975450343, 
              c[ 13][ t]], 
            Times[ -0.11423673049785436, 
              c[ 14][ t]], 
            Times[ -0.15591488063143982, 
              c[ 15][ t]], 
            Times[ -0.18675027222298601, 
              c[ 16][ t]], 
            Times[ -0.206748335783172, 
              c[ 17][ t]], 
            Times[ -0.21623620818304484, 
              c[ 18][ t]], 
            Times[ -0.21584055771952015, 
              c[ 19][ t]], 
            Times[ -0.20645618564475843, 
              c[ 20][ t]], 
            Times[ -0.18920668216016426, 
              c[ 21][ t]], 
            Times[ -0.16539866862653771, 
              c[ 22][ t]], 
            Times[ -0.13647135277833605, 
              c[ 23][ t]], 
            Times[ -0.10394325375429328, 
              c[ 24][ t]], 
            Times[ -0.06935801494512607, 
              c[ 25][ t]], 
            Times[ -0.034231213779558949, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.032022748374425904, 
              c[ 28][ t]], 
            Times[ 0.060688263076985105, 
              c[ 29][ t]], 
            Times[ 0.085044480344421705, 
              c[ 30][ t]], 
            Times[ 0.10436044624225685, 
              c[ 31][ t]], 
            Times[ 0.11814190616181255, 
              c[ 32][ t]], 
            Times[ 0.12613778810677614, 
              c[ 33][ t]], 
            Times[ 0.12833762891430928, 
              c[ 34][ t]], 
            Times[ 0.12496032289024853, 
              c[ 35][ t]], 
            Times[ 0.11643488132933186, 
              c[ 36][ t]], 
            Times[ 0.10337416789158609, 
              c[ 37][ t]], 
            Times[ 0.086542809078944891, 
              c[ 38][ t]], 
            Times[ 0.066820663127759972, 
              c[ 39][ t]], 
            Times[ 0.045163358568919301, 
              c[ 40][ t]], 
            Times[ 0.022561481809254869, 
              c[ 41][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 42][ t]], 
            Times[ -0.021580547817547879, 
              c[ 43][ t]], 
            Times[ -0.04131966847794722, 
              c[ 44][ t]], 
            Times[ -0.058468080236789913, 
              c[ 45][ t]], 
            Times[ -0.072413370861974122, 
              c[ 46][ t]], 
            Times[ -0.082699334313268744, 
              c[ 47][ t]], 
            Times[ -0.089038438663606695, 
              c[ 48][ t]], 
            Times[ -0.091317159035181589, 
              c[ 49][ t]], 
            Times[ -0.089594193770366884, 
              c[ 50][ t]], 
            Times[ -0.084091858737850814, 
              c[ 51][ t]], 
            Times[ -0.075181213012062598, 
              c[ 52][ t]], 
            Times[ -0.063361699504227528, 
              c[ 53][ t]], 
            Times[ -0.049236278094138941, 
              c[ 54][ t]], 
            Times[ -0.033483179628681567, 
              c[ 55][ t]], 
            Times[ -0.016825511857749401, 
              c[ 56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ 0.016273855731265604, 
              c[ 58][ t]], 
            Times[ 0.031322974491347078, 
              c[ 59][ t]], 
            Times[ 0.044547108751839919, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-2\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-2\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03348317962868157`\)\ \(c[\(-60\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-59\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-58\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-57\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-56\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-55\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-54\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-53\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-52\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-51\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-50\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-49\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-48\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-47\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-46\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-45\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-44\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-43\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-42\)]\)[t] + 
            0.11643488132933195`\ \(c[\(-41\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-40\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-39\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-38\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-37\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-36\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-35\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-34\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-33\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-31\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-30\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-29\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-28\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-27\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-26\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-25\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-24\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-23\)]\)[t] - 
            0.206748335783172`\ \(c[\(-22\)]\)[t] - 
            0.186750272222986`\ \(c[\(-21\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-20\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-19\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-18\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-17\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-16\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-15\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-14\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-13\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-12\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-11\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-10\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-9\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-8\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-7\)]\)[t] + 
            0.8870637930591837`\ \(c[\(-6\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-5\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-4\)]\)[t] + 
            0.9927051996072067`\ \(c[\(-3\)]\)[t] + 
            1.087729816898572`\ \(c[\(-2\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-1\)]\)[t] + 
            0.9710122092317629`\ \(c[0]\)[t] + 
            0.9354892837886392`\ \(c[1]\)[t] + 
            0.8870637930591838`\ \(c[2]\)[t] + 
            0.8269933431326882`\ \(c[3]\)[t] + 
            0.7568267286406569`\ \(c[4]\)[t] + 
            0.6783560385470634`\ \(c[5]\)[t] + 
            0.5935615337286805`\ \(c[6]\)[t] + 
            0.5045511524271047`\ \(c[7]\)[t] + 
            0.4134966715663442`\ \(c[8]\)[t] + 
            0.32256865202152135`\ \(c[9]\)[t] + 
            0.23387232094715985`\ \(c[10]\)[t] + 
            0.14938649372796362`\ \(c[11]\)[t] + 
            0.07090751425765762`\ \(c[12]\)[t] + 
            3.898171832519376`*^-17\ \(c[13]\)[t] - 
            0.06204407497545034`\ \(c[14]\)[t] - 
            0.11423673049785445`\ \(c[15]\)[t] - 
            0.15591488063143982`\ \(c[16]\)[t] - 
            0.186750272222986`\ \(c[17]\)[t] - 
            0.206748335783172`\ \(c[18]\)[t] - 
            0.21623620818304484`\ \(c[19]\)[t] - 
            0.21584055771952015`\ \(c[20]\)[t] - 
            0.20645618564475843`\ \(c[21]\)[t] - 
            0.18920668216016434`\ \(c[22]\)[t] - 
            0.1653986686265377`\ \(c[23]\)[t] - 
            0.13647135277833605`\ \(c[24]\)[t] - 
            0.1039432537542934`\ \(c[25]\)[t] - 
            0.06935801494512607`\ \(c[26]\)[t] - 
            0.03423121377955895`\ \(c[27]\)[t] - 
            1.8033970416801674`*^-16\ \(c[28]\)[t] + 
            0.032022748374425904`\ \(c[29]\)[t] + 
            0.060688263076985105`\ \(c[30]\)[t] + 
            0.08504448034442161`\ \(c[31]\)[t] + 
            0.10436044624225685`\ \(c[32]\)[t] + 
            0.11814190616181255`\ \(c[33]\)[t] + 
            0.12613778810677612`\ \(c[34]\)[t] + 
            0.12833762891430928`\ \(c[35]\)[t] + 
            0.12496032289024853`\ \(c[36]\)[t] + 
            0.11643488132933186`\ \(c[37]\)[t] + 
            0.10337416789158609`\ \(c[38]\)[t] + 
            0.08654280907894475`\ \(c[39]\)[t] + 
            0.06682066312775997`\ \(c[40]\)[t] + 
            0.0451633585689193`\ \(c[41]\)[t] + 
            0.022561481809254675`\ \(c[42]\)[t] + 
            3.8981718325193755`*^-17\ \(c[43]\)[t] - 
            0.02158054781754788`\ \(c[44]\)[t] - 
            0.04131966847794737`\ \(c[45]\)[t] - 
            0.05846808023678991`\ \(c[46]\)[t] - 
            0.07241337086197412`\ \(c[47]\)[t] - 
            0.08269933431326881`\ \(c[48]\)[t] - 
            0.0890384386636067`\ \(c[49]\)[t] - 
            0.09131715903518159`\ \(c[50]\)[t] - 
            0.08959419377036684`\ \(c[51]\)[t] - 
            0.08409185873785081`\ \(c[52]\)[t] - 
            0.0751812130120626`\ \(c[53]\)[t] - 
            0.0633616995042274`\ \(c[54]\)[t] - 
            0.04923627809413894`\ \(c[55]\)[t] - 
            0.03348317962868157`\ \(c[56]\)[t] - 
            0.016825511857749262`\ \(c[57]\)[t] - 
            3.898171832519376`*^-17\ \(c[58]\)[t] + 
            0.016273855731265604`\ \(c[59]\)[t] + 
            0.0313229744913472`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -2, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -2]][ t]], 
          Plus[ 
            Times[ -0.033483179628681567, 
              c[ -60][ t]], 
            Times[ -0.049236278094139066, 
              c[ -59][ t]], 
            Times[ -0.063361699504227528, 
              c[ -58][ t]], 
            Times[ -0.075181213012062598, 
              c[ -57][ t]], 
            Times[ -0.084091858737850855, 
              c[ -56][ t]], 
            Times[ -0.089594193770366884, 
              c[ -55][ t]], 
            Times[ -0.091317159035181589, 
              c[ -54][ t]], 
            Times[ -0.089038438663606653, 
              c[ -53][ t]], 
            Times[ -0.082699334313268744, 
              c[ -52][ t]], 
            Times[ -0.072413370861974122, 
              c[ -51][ t]], 
            Times[ -0.058468080236789774, 
              c[ -50][ t]], 
            Times[ -0.04131966847794722, 
              c[ -49][ t]], 
            Times[ -0.021580547817547879, 
              c[ -48][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -47][ t]], 
            Times[ 0.022561481809254869, 
              c[ -46][ t]], 
            Times[ 0.045163358568919301, 
              c[ -45][ t]], 
            Times[ 0.066820663127760152, 
              c[ -44][ t]], 
            Times[ 0.086542809078944891, 
              c[ -43][ t]], 
            Times[ 0.10337416789158609, 
              c[ -42][ t]], 
            Times[ 0.11643488132933195, 
              c[ -41][ t]], 
            Times[ 0.12496032289024853, 
              c[ -40][ t]], 
            Times[ 0.12833762891430925, 
              c[ -39][ t]], 
            Times[ 0.12613778810677614, 
              c[ -38][ t]], 
            Times[ 0.11814190616181255, 
              c[ -37][ t]], 
            Times[ 0.10436044624225692, 
              c[ -36][ t]], 
            Times[ 0.085044480344421705, 
              c[ -35][ t]], 
            Times[ 0.060688263076985105, 
              c[ -34][ t]], 
            Times[ 0.032022748374426029, 
              c[ -33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ -0.034231213779558949, 
              c[ -31][ t]], 
            Times[ -0.069358014945125918, 
              c[ -30][ t]], 
            Times[ -0.10394325375429328, 
              c[ -29][ t]], 
            Times[ -0.13647135277833605, 
              c[ -28][ t]], 
            Times[ -0.1653986686265376, 
              c[ -27][ t]], 
            Times[ -0.18920668216016426, 
              c[ -26][ t]], 
            Times[ -0.20645618564475843, 
              c[ -25][ t]], 
            Times[ -0.21584055771952013, 
              c[ -24][ t]], 
            Times[ -0.21623620818304484, 
              c[ -23][ t]], 
            Times[ -0.206748335783172, 
              c[ -22][ t]], 
            Times[ -0.18675027222298601, 
              c[ -21][ t]], 
            Times[ -0.15591488063143974, 
              c[ -20][ t]], 
            Times[ -0.11423673049785436, 
              c[ -19][ t]], 
            Times[ -0.062044074975450343, 
              c[ -18][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -17][ t]], 
            Times[ 0.070907514257657775, 
              c[ -16][ t]], 
            Times[ 0.14938649372796362, 
              c[ -15][ t]], 
            Times[ 0.23387232094715998, 
              c[ -14][ t]], 
            Times[ 0.32256865202152157, 
              c[ -13][ t]], 
            Times[ 0.41349667156634418, 
              c[ -12][ t]], 
            Times[ 0.50455115242710469, 
              c[ -11][ t]], 
            Times[ 0.59356153372868048, 
              c[ -10][ t]], 
            Times[ 0.67835603854706328, 
              c[ -9][ t]], 
            Times[ 0.75682672864065692, 
              c[ -8][ t]], 
            Times[ 0.82699334313268824, 
              c[ -7][ t]], 
            Times[ 0.8870637930591837, 
              c[ -6][ t]], 
            Times[ 0.93548928378863916, 
              c[ -5][ t]], 
            Times[ 0.9710122092317629, 
              c[ -4][ t]], 
            Times[ 0.99270519960720671, 
              c[ -3][ t]], 
            Times[ 1.0877298168985721, 
              c[ -2][ t]], 
            Times[ 0.99270519960720693, 
              c[ -1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 0][ t]], 
            Times[ 0.93548928378863916, 
              c[ 1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 2][ t]], 
            Times[ 0.82699334313268824, 
              c[ 3][ t]], 
            Times[ 0.75682672864065692, 
              c[ 4][ t]], 
            Times[ 0.67835603854706339, 
              c[ 5][ t]], 
            Times[ 0.59356153372868048, 
              c[ 6][ t]], 
            Times[ 0.50455115242710469, 
              c[ 7][ t]], 
            Times[ 0.41349667156634418, 
              c[ 8][ t]], 
            Times[ 0.32256865202152135, 
              c[ 9][ t]], 
            Times[ 0.23387232094715985, 
              c[ 10][ t]], 
            Times[ 0.14938649372796362, 
              c[ 11][ t]], 
            Times[ 0.070907514257657622, 
              c[ 12][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ -0.062044074975450343, 
              c[ 14][ t]], 
            Times[ -0.11423673049785445, 
              c[ 15][ t]], 
            Times[ -0.15591488063143982, 
              c[ 16][ t]], 
            Times[ -0.18675027222298601, 
              c[ 17][ t]], 
            Times[ -0.206748335783172, 
              c[ 18][ t]], 
            Times[ -0.21623620818304484, 
              c[ 19][ t]], 
            Times[ -0.21584055771952015, 
              c[ 20][ t]], 
            Times[ -0.20645618564475843, 
              c[ 21][ t]], 
            Times[ -0.18920668216016434, 
              c[ 22][ t]], 
            Times[ -0.16539866862653771, 
              c[ 23][ t]], 
            Times[ -0.13647135277833605, 
              c[ 24][ t]], 
            Times[ -0.1039432537542934, 
              c[ 25][ t]], 
            Times[ -0.06935801494512607, 
              c[ 26][ t]], 
            Times[ -0.034231213779558949, 
              c[ 27][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 28][ t]], 
            Times[ 0.032022748374425904, 
              c[ 29][ t]], 
            Times[ 0.060688263076985105, 
              c[ 30][ t]], 
            Times[ 0.085044480344421608, 
              c[ 31][ t]], 
            Times[ 0.10436044624225685, 
              c[ 32][ t]], 
            Times[ 0.11814190616181255, 
              c[ 33][ t]], 
            Times[ 0.12613778810677612, 
              c[ 34][ t]], 
            Times[ 0.12833762891430928, 
              c[ 35][ t]], 
            Times[ 0.12496032289024853, 
              c[ 36][ t]], 
            Times[ 0.11643488132933186, 
              c[ 37][ t]], 
            Times[ 0.10337416789158609, 
              c[ 38][ t]], 
            Times[ 0.086542809078944752, 
              c[ 39][ t]], 
            Times[ 0.066820663127759972, 
              c[ 40][ t]], 
            Times[ 0.045163358568919301, 
              c[ 41][ t]], 
            Times[ 0.022561481809254675, 
              c[ 42][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 43][ t]], 
            Times[ -0.021580547817547879, 
              c[ 44][ t]], 
            Times[ -0.041319668477947373, 
              c[ 45][ t]], 
            Times[ -0.058468080236789913, 
              c[ 46][ t]], 
            Times[ -0.072413370861974122, 
              c[ 47][ t]], 
            Times[ -0.082699334313268813, 
              c[ 48][ t]], 
            Times[ -0.089038438663606695, 
              c[ 49][ t]], 
            Times[ -0.091317159035181589, 
              c[ 50][ t]], 
            Times[ -0.089594193770366842, 
              c[ 51][ t]], 
            Times[ -0.084091858737850814, 
              c[ 52][ t]], 
            Times[ -0.075181213012062598, 
              c[ 53][ t]], 
            Times[ -0.063361699504227403, 
              c[ 54][ t]], 
            Times[ -0.049236278094138941, 
              c[ 55][ t]], 
            Times[ -0.033483179628681567, 
              c[ 56][ t]], 
            Times[ -0.016825511857749262, 
              c[ 57][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ 0.016273855731265604, 
              c[ 59][ t]], 
            Times[ 0.031322974491347202, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", \(-1\), 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[\(-1\)]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.016825511857749262`\)\ \(c[\(-60\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-59\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-58\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-57\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-56\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-55\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-54\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-53\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-52\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-51\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-50\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-49\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-48\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-47\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-46\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-45\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-44\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-43\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-42\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-41\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-40\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-39\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-38\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-37\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-36\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-35\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-34\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-33\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-32\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-31\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-30\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-29\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-28\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-27\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-26\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-25\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-24\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-23\)]\)[t] - 
            0.21623620818304481`\ \(c[\(-22\)]\)[t] - 
            0.206748335783172`\ \(c[\(-21\)]\)[t] - 
            0.186750272222986`\ \(c[\(-20\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-19\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-18\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-17\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-15\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-14\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-13\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-12\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-11\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-10\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-9\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-8\)]\)[t] + 
            0.756826728640657`\ \(c[\(-7\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-6\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-5\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-4\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-3\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-2\)]\)[t] + 
            1.021932454224643`\ \(c[\(-1\)]\)[t] + 
            0.9927051996072069`\ \(c[0]\)[t] + 
            0.9710122092317629`\ \(c[1]\)[t] + 
            0.9354892837886392`\ \(c[2]\)[t] + 
            0.8870637930591838`\ \(c[3]\)[t] + 
            0.8269933431326882`\ \(c[4]\)[t] + 
            0.7568267286406569`\ \(c[5]\)[t] + 
            0.6783560385470633`\ \(c[6]\)[t] + 
            0.5935615337286805`\ \(c[7]\)[t] + 
            0.5045511524271047`\ \(c[8]\)[t] + 
            0.4134966715663442`\ \(c[9]\)[t] + 
            0.3225686520215216`\ \(c[10]\)[t] + 
            0.23387232094715998`\ \(c[11]\)[t] + 
            0.14938649372796362`\ \(c[12]\)[t] + 
            0.07090751425765777`\ \(c[13]\)[t] + 
            1.8033970416801674`*^-16\ \(c[14]\)[t] - 
            0.06204407497545034`\ \(c[15]\)[t] - 
            0.11423673049785436`\ \(c[16]\)[t] - 
            0.15591488063143974`\ \(c[17]\)[t] - 
            0.186750272222986`\ \(c[18]\)[t] - 
            0.206748335783172`\ \(c[19]\)[t] - 
            0.21623620818304484`\ \(c[20]\)[t] - 
            0.21584055771952013`\ \(c[21]\)[t] - 
            0.20645618564475843`\ \(c[22]\)[t] - 
            0.18920668216016426`\ \(c[23]\)[t] - 
            0.1653986686265376`\ \(c[24]\)[t] - 
            0.13647135277833605`\ \(c[25]\)[t] - 
            0.10394325375429328`\ \(c[26]\)[t] - 
            0.06935801494512592`\ \(c[27]\)[t] - 
            0.03423121377955895`\ \(c[28]\)[t] - 
            3.898171832519376`*^-17\ \(c[29]\)[t] + 
            0.03202274837442603`\ \(c[30]\)[t] + 
            0.060688263076985105`\ \(c[31]\)[t] + 
            0.0850444803444217`\ \(c[32]\)[t] + 
            0.10436044624225692`\ \(c[33]\)[t] + 
            0.11814190616181255`\ \(c[34]\)[t] + 
            0.12613778810677614`\ \(c[35]\)[t] + 
            0.12833762891430925`\ \(c[36]\)[t] + 
            0.12496032289024853`\ \(c[37]\)[t] + 
            0.11643488132933186`\ \(c[38]\)[t] + 
            0.10337416789158609`\ \(c[39]\)[t] + 
            0.08654280907894489`\ \(c[40]\)[t] + 
            0.06682066312776015`\ \(c[41]\)[t] + 
            0.0451633585689193`\ \(c[42]\)[t] + 
            0.02256148180925487`\ \(c[43]\)[t] + 
            2.274590327822911`*^-16\ \(c[44]\)[t] - 
            0.02158054781754788`\ \(c[45]\)[t] - 
            0.04131966847794722`\ \(c[46]\)[t] - 
            0.058468080236789774`\ \(c[47]\)[t] - 
            0.07241337086197412`\ \(c[48]\)[t] - 
            0.08269933431326874`\ \(c[49]\)[t] - 
            0.08903843866360665`\ \(c[50]\)[t] - 
            0.09131715903518159`\ \(c[51]\)[t] - 
            0.08959419377036688`\ \(c[52]\)[t] - 
            0.08409185873785086`\ \(c[53]\)[t] - 
            0.0751812130120626`\ \(c[54]\)[t] - 
            0.06336169950422753`\ \(c[55]\)[t] - 
            0.049236278094139066`\ \(c[56]\)[t] - 
            0.03348317962868157`\ \(c[57]\)[t] - 
            0.0168255118577494`\ \(c[58]\)[t] - 
            1.8033970416801674`*^-16\ \(c[59]\)[t] + 
            0.016273855731265604`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", -1, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ -1]][ t]], 
          Plus[ 
            Times[ -0.016825511857749262, 
              c[ -60][ t]], 
            Times[ -0.033483179628681567, 
              c[ -59][ t]], 
            Times[ -0.049236278094138941, 
              c[ -58][ t]], 
            Times[ -0.063361699504227403, 
              c[ -57][ t]], 
            Times[ -0.075181213012062598, 
              c[ -56][ t]], 
            Times[ -0.084091858737850814, 
              c[ -55][ t]], 
            Times[ -0.089594193770366842, 
              c[ -54][ t]], 
            Times[ -0.091317159035181589, 
              c[ -53][ t]], 
            Times[ -0.089038438663606695, 
              c[ -52][ t]], 
            Times[ -0.082699334313268813, 
              c[ -51][ t]], 
            Times[ -0.072413370861974122, 
              c[ -50][ t]], 
            Times[ -0.058468080236789913, 
              c[ -49][ t]], 
            Times[ -0.041319668477947373, 
              c[ -48][ t]], 
            Times[ -0.021580547817547879, 
              c[ -47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -46][ t]], 
            Times[ 0.022561481809254675, 
              c[ -45][ t]], 
            Times[ 0.045163358568919301, 
              c[ -44][ t]], 
            Times[ 0.066820663127759972, 
              c[ -43][ t]], 
            Times[ 0.086542809078944752, 
              c[ -42][ t]], 
            Times[ 0.10337416789158609, 
              c[ -41][ t]], 
            Times[ 0.11643488132933186, 
              c[ -40][ t]], 
            Times[ 0.12496032289024853, 
              c[ -39][ t]], 
            Times[ 0.12833762891430928, 
              c[ -38][ t]], 
            Times[ 0.12613778810677612, 
              c[ -37][ t]], 
            Times[ 0.11814190616181255, 
              c[ -36][ t]], 
            Times[ 0.10436044624225685, 
              c[ -35][ t]], 
            Times[ 0.085044480344421608, 
              c[ -34][ t]], 
            Times[ 0.060688263076985105, 
              c[ -33][ t]], 
            Times[ 0.032022748374425904, 
              c[ -32][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -31][ t]], 
            Times[ -0.034231213779558949, 
              c[ -30][ t]], 
            Times[ -0.06935801494512607, 
              c[ -29][ t]], 
            Times[ -0.1039432537542934, 
              c[ -28][ t]], 
            Times[ -0.13647135277833605, 
              c[ -27][ t]], 
            Times[ -0.16539866862653771, 
              c[ -26][ t]], 
            Times[ -0.18920668216016434, 
              c[ -25][ t]], 
            Times[ -0.20645618564475843, 
              c[ -24][ t]], 
            Times[ -0.21584055771952015, 
              c[ -23][ t]], 
            Times[ -0.21623620818304481, 
              c[ -22][ t]], 
            Times[ -0.206748335783172, 
              c[ -21][ t]], 
            Times[ -0.18675027222298601, 
              c[ -20][ t]], 
            Times[ -0.15591488063143982, 
              c[ -19][ t]], 
            Times[ -0.11423673049785445, 
              c[ -18][ t]], 
            Times[ -0.062044074975450343, 
              c[ -17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ 0.070907514257657622, 
              c[ -15][ t]], 
            Times[ 0.14938649372796362, 
              c[ -14][ t]], 
            Times[ 0.23387232094715985, 
              c[ -13][ t]], 
            Times[ 0.32256865202152135, 
              c[ -12][ t]], 
            Times[ 0.41349667156634418, 
              c[ -11][ t]], 
            Times[ 0.50455115242710469, 
              c[ -10][ t]], 
            Times[ 0.59356153372868048, 
              c[ -9][ t]], 
            Times[ 0.67835603854706339, 
              c[ -8][ t]], 
            Times[ 0.75682672864065703, 
              c[ -7][ t]], 
            Times[ 0.82699334313268824, 
              c[ -6][ t]], 
            Times[ 0.88706379305918381, 
              c[ -5][ t]], 
            Times[ 0.93548928378863916, 
              c[ -4][ t]], 
            Times[ 0.9710122092317629, 
              c[ -3][ t]], 
            Times[ 0.99270519960720693, 
              c[ -2][ t]], 
            Times[ 1.0219324542246431, 
              c[ -1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 0][ t]], 
            Times[ 0.9710122092317629, 
              c[ 1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 2][ t]], 
            Times[ 0.88706379305918381, 
              c[ 3][ t]], 
            Times[ 0.82699334313268824, 
              c[ 4][ t]], 
            Times[ 0.75682672864065692, 
              c[ 5][ t]], 
            Times[ 0.67835603854706328, 
              c[ 6][ t]], 
            Times[ 0.59356153372868048, 
              c[ 7][ t]], 
            Times[ 0.50455115242710469, 
              c[ 8][ t]], 
            Times[ 0.41349667156634418, 
              c[ 9][ t]], 
            Times[ 0.32256865202152157, 
              c[ 10][ t]], 
            Times[ 0.23387232094715998, 
              c[ 11][ t]], 
            Times[ 0.14938649372796362, 
              c[ 12][ t]], 
            Times[ 0.070907514257657775, 
              c[ 13][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 14][ t]], 
            Times[ -0.062044074975450343, 
              c[ 15][ t]], 
            Times[ -0.11423673049785436, 
              c[ 16][ t]], 
            Times[ -0.15591488063143974, 
              c[ 17][ t]], 
            Times[ -0.18675027222298601, 
              c[ 18][ t]], 
            Times[ -0.206748335783172, 
              c[ 19][ t]], 
            Times[ -0.21623620818304484, 
              c[ 20][ t]], 
            Times[ -0.21584055771952013, 
              c[ 21][ t]], 
            Times[ -0.20645618564475843, 
              c[ 22][ t]], 
            Times[ -0.18920668216016426, 
              c[ 23][ t]], 
            Times[ -0.1653986686265376, 
              c[ 24][ t]], 
            Times[ -0.13647135277833605, 
              c[ 25][ t]], 
            Times[ -0.10394325375429328, 
              c[ 26][ t]], 
            Times[ -0.069358014945125918, 
              c[ 27][ t]], 
            Times[ -0.034231213779558949, 
              c[ 28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ 0.032022748374426029, 
              c[ 30][ t]], 
            Times[ 0.060688263076985105, 
              c[ 31][ t]], 
            Times[ 0.085044480344421705, 
              c[ 32][ t]], 
            Times[ 0.10436044624225692, 
              c[ 33][ t]], 
            Times[ 0.11814190616181255, 
              c[ 34][ t]], 
            Times[ 0.12613778810677614, 
              c[ 35][ t]], 
            Times[ 0.12833762891430925, 
              c[ 36][ t]], 
            Times[ 0.12496032289024853, 
              c[ 37][ t]], 
            Times[ 0.11643488132933186, 
              c[ 38][ t]], 
            Times[ 0.10337416789158609, 
              c[ 39][ t]], 
            Times[ 0.086542809078944891, 
              c[ 40][ t]], 
            Times[ 0.066820663127760152, 
              c[ 41][ t]], 
            Times[ 0.045163358568919301, 
              c[ 42][ t]], 
            Times[ 0.022561481809254869, 
              c[ 43][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 44][ t]], 
            Times[ -0.021580547817547879, 
              c[ 45][ t]], 
            Times[ -0.04131966847794722, 
              c[ 46][ t]], 
            Times[ -0.058468080236789774, 
              c[ 47][ t]], 
            Times[ -0.072413370861974122, 
              c[ 48][ t]], 
            Times[ -0.082699334313268744, 
              c[ 49][ t]], 
            Times[ -0.089038438663606653, 
              c[ 50][ t]], 
            Times[ -0.091317159035181589, 
              c[ 51][ t]], 
            Times[ -0.089594193770366884, 
              c[ 52][ t]], 
            Times[ -0.084091858737850855, 
              c[ 53][ t]], 
            Times[ -0.075181213012062598, 
              c[ 54][ t]], 
            Times[ -0.063361699504227528, 
              c[ 55][ t]], 
            Times[ -0.049236278094139066, 
              c[ 56][ t]], 
            Times[ -0.033483179628681567, 
              c[ 57][ t]], 
            Times[ -0.016825511857749401, 
              c[ 58][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 59][ t]], 
            Times[ 0.016273855731265604, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "0", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[0]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-59\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-58\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-57\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-56\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-55\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-54\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-53\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-52\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-51\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-50\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-49\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-48\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-47\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-46\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-44\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-43\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-42\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-41\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-40\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-39\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-38\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-37\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-36\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-35\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-34\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-33\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-32\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-29\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-28\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-27\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-26\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-25\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-24\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-23\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-22\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-21\)]\)[t] - 
            0.206748335783172`\ \(c[\(-20\)]\)[t] - 
            0.186750272222986`\ \(c[\(-19\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-18\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-17\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-14\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-13\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-12\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-11\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-10\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-9\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-8\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-7\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-6\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-5\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-4\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-3\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-2\)]\)[t] + 
            0.9927051996072069`\ \(c[\(-1\)]\)[t] + 1.`\ \(c[0]\)[t] + 
            0.9927051996072069`\ \(c[1]\)[t] + 
            0.9710122092317629`\ \(c[2]\)[t] + 
            0.9354892837886392`\ \(c[3]\)[t] + 
            0.8870637930591838`\ \(c[4]\)[t] + 
            0.8269933431326882`\ \(c[5]\)[t] + 
            0.7568267286406569`\ \(c[6]\)[t] + 
            0.6783560385470634`\ \(c[7]\)[t] + 
            0.5935615337286805`\ \(c[8]\)[t] + 
            0.5045511524271047`\ \(c[9]\)[t] + 
            0.4134966715663442`\ \(c[10]\)[t] + 
            0.3225686520215216`\ \(c[11]\)[t] + 
            0.23387232094715985`\ \(c[12]\)[t] + 
            0.14938649372796362`\ \(c[13]\)[t] + 
            0.07090751425765777`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.06204407497545034`\ \(c[16]\)[t] - 
            0.11423673049785436`\ \(c[17]\)[t] - 
            0.15591488063143982`\ \(c[18]\)[t] - 
            0.186750272222986`\ \(c[19]\)[t] - 
            0.206748335783172`\ \(c[20]\)[t] - 
            0.21623620818304484`\ \(c[21]\)[t] - 
            0.21584055771952015`\ \(c[22]\)[t] - 
            0.20645618564475843`\ \(c[23]\)[t] - 
            0.18920668216016426`\ \(c[24]\)[t] - 
            0.1653986686265377`\ \(c[25]\)[t] - 
            0.13647135277833605`\ \(c[26]\)[t] - 
            0.10394325375429328`\ \(c[27]\)[t] - 
            0.06935801494512607`\ \(c[28]\)[t] - 
            0.03423121377955895`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.032022748374425904`\ \(c[31]\)[t] + 
            0.060688263076985105`\ \(c[32]\)[t] + 
            0.0850444803444217`\ \(c[33]\)[t] + 
            0.10436044624225685`\ \(c[34]\)[t] + 
            0.11814190616181255`\ \(c[35]\)[t] + 
            0.12613778810677614`\ \(c[36]\)[t] + 
            0.12833762891430928`\ \(c[37]\)[t] + 
            0.12496032289024853`\ \(c[38]\)[t] + 
            0.11643488132933186`\ \(c[39]\)[t] + 
            0.10337416789158609`\ \(c[40]\)[t] + 
            0.08654280907894489`\ \(c[41]\)[t] + 
            0.06682066312775997`\ \(c[42]\)[t] + 
            0.0451633585689193`\ \(c[43]\)[t] + 
            0.02256148180925487`\ \(c[44]\)[t] + 
            3.8981718325193755`*^-17\ \(c[45]\)[t] - 
            0.02158054781754788`\ \(c[46]\)[t] - 
            0.04131966847794722`\ \(c[47]\)[t] - 
            0.05846808023678991`\ \(c[48]\)[t] - 
            0.07241337086197412`\ \(c[49]\)[t] - 
            0.08269933431326874`\ \(c[50]\)[t] - 
            0.0890384386636067`\ \(c[51]\)[t] - 
            0.09131715903518159`\ \(c[52]\)[t] - 
            0.08959419377036688`\ \(c[53]\)[t] - 
            0.08409185873785081`\ \(c[54]\)[t] - 
            0.0751812130120626`\ \(c[55]\)[t] - 
            0.06336169950422753`\ \(c[56]\)[t] - 
            0.04923627809413894`\ \(c[57]\)[t] - 
            0.03348317962868157`\ \(c[58]\)[t] - 
            0.0168255118577494`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 0, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 0]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.016825511857749401, 
              c[ -59][ t]], 
            Times[ -0.033483179628681567, 
              c[ -58][ t]], 
            Times[ -0.049236278094138941, 
              c[ -57][ t]], 
            Times[ -0.063361699504227528, 
              c[ -56][ t]], 
            Times[ -0.075181213012062598, 
              c[ -55][ t]], 
            Times[ -0.084091858737850814, 
              c[ -54][ t]], 
            Times[ -0.089594193770366884, 
              c[ -53][ t]], 
            Times[ -0.091317159035181589, 
              c[ -52][ t]], 
            Times[ -0.089038438663606695, 
              c[ -51][ t]], 
            Times[ -0.082699334313268744, 
              c[ -50][ t]], 
            Times[ -0.072413370861974122, 
              c[ -49][ t]], 
            Times[ -0.058468080236789913, 
              c[ -48][ t]], 
            Times[ -0.04131966847794722, 
              c[ -47][ t]], 
            Times[ -0.021580547817547879, 
              c[ -46][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ 0.022561481809254869, 
              c[ -44][ t]], 
            Times[ 0.045163358568919301, 
              c[ -43][ t]], 
            Times[ 0.066820663127759972, 
              c[ -42][ t]], 
            Times[ 0.086542809078944891, 
              c[ -41][ t]], 
            Times[ 0.10337416789158609, 
              c[ -40][ t]], 
            Times[ 0.11643488132933186, 
              c[ -39][ t]], 
            Times[ 0.12496032289024853, 
              c[ -38][ t]], 
            Times[ 0.12833762891430928, 
              c[ -37][ t]], 
            Times[ 0.12613778810677614, 
              c[ -36][ t]], 
            Times[ 0.11814190616181255, 
              c[ -35][ t]], 
            Times[ 0.10436044624225685, 
              c[ -34][ t]], 
            Times[ 0.085044480344421705, 
              c[ -33][ t]], 
            Times[ 0.060688263076985105, 
              c[ -32][ t]], 
            Times[ 0.032022748374425904, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.034231213779558949, 
              c[ -29][ t]], 
            Times[ -0.06935801494512607, 
              c[ -28][ t]], 
            Times[ -0.10394325375429328, 
              c[ -27][ t]], 
            Times[ -0.13647135277833605, 
              c[ -26][ t]], 
            Times[ -0.16539866862653771, 
              c[ -25][ t]], 
            Times[ -0.18920668216016426, 
              c[ -24][ t]], 
            Times[ -0.20645618564475843, 
              c[ -23][ t]], 
            Times[ -0.21584055771952015, 
              c[ -22][ t]], 
            Times[ -0.21623620818304484, 
              c[ -21][ t]], 
            Times[ -0.206748335783172, 
              c[ -20][ t]], 
            Times[ -0.18675027222298601, 
              c[ -19][ t]], 
            Times[ -0.15591488063143982, 
              c[ -18][ t]], 
            Times[ -0.11423673049785436, 
              c[ -17][ t]], 
            Times[ -0.062044074975450343, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.070907514257657775, 
              c[ -14][ t]], 
            Times[ 0.14938649372796362, 
              c[ -13][ t]], 
            Times[ 0.23387232094715985, 
              c[ -12][ t]], 
            Times[ 0.32256865202152157, 
              c[ -11][ t]], 
            Times[ 0.41349667156634418, 
              c[ -10][ t]], 
            Times[ 0.50455115242710469, 
              c[ -9][ t]], 
            Times[ 0.59356153372868048, 
              c[ -8][ t]], 
            Times[ 0.67835603854706339, 
              c[ -7][ t]], 
            Times[ 0.75682672864065692, 
              c[ -6][ t]], 
            Times[ 0.82699334313268824, 
              c[ -5][ t]], 
            Times[ 0.88706379305918381, 
              c[ -4][ t]], 
            Times[ 0.93548928378863916, 
              c[ -3][ t]], 
            Times[ 0.9710122092317629, 
              c[ -2][ t]], 
            Times[ 0.99270519960720693, 
              c[ -1][ t]], 
            Times[ 1.0, 
              c[ 0][ t]], 
            Times[ 0.99270519960720693, 
              c[ 1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 2][ t]], 
            Times[ 0.93548928378863916, 
              c[ 3][ t]], 
            Times[ 0.88706379305918381, 
              c[ 4][ t]], 
            Times[ 0.82699334313268824, 
              c[ 5][ t]], 
            Times[ 0.75682672864065692, 
              c[ 6][ t]], 
            Times[ 0.67835603854706339, 
              c[ 7][ t]], 
            Times[ 0.59356153372868048, 
              c[ 8][ t]], 
            Times[ 0.50455115242710469, 
              c[ 9][ t]], 
            Times[ 0.41349667156634418, 
              c[ 10][ t]], 
            Times[ 0.32256865202152157, 
              c[ 11][ t]], 
            Times[ 0.23387232094715985, 
              c[ 12][ t]], 
            Times[ 0.14938649372796362, 
              c[ 13][ t]], 
            Times[ 0.070907514257657775, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.062044074975450343, 
              c[ 16][ t]], 
            Times[ -0.11423673049785436, 
              c[ 17][ t]], 
            Times[ -0.15591488063143982, 
              c[ 18][ t]], 
            Times[ -0.18675027222298601, 
              c[ 19][ t]], 
            Times[ -0.206748335783172, 
              c[ 20][ t]], 
            Times[ -0.21623620818304484, 
              c[ 21][ t]], 
            Times[ -0.21584055771952015, 
              c[ 22][ t]], 
            Times[ -0.20645618564475843, 
              c[ 23][ t]], 
            Times[ -0.18920668216016426, 
              c[ 24][ t]], 
            Times[ -0.16539866862653771, 
              c[ 25][ t]], 
            Times[ -0.13647135277833605, 
              c[ 26][ t]], 
            Times[ -0.10394325375429328, 
              c[ 27][ t]], 
            Times[ -0.06935801494512607, 
              c[ 28][ t]], 
            Times[ -0.034231213779558949, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.032022748374425904, 
              c[ 31][ t]], 
            Times[ 0.060688263076985105, 
              c[ 32][ t]], 
            Times[ 0.085044480344421705, 
              c[ 33][ t]], 
            Times[ 0.10436044624225685, 
              c[ 34][ t]], 
            Times[ 0.11814190616181255, 
              c[ 35][ t]], 
            Times[ 0.12613778810677614, 
              c[ 36][ t]], 
            Times[ 0.12833762891430928, 
              c[ 37][ t]], 
            Times[ 0.12496032289024853, 
              c[ 38][ t]], 
            Times[ 0.11643488132933186, 
              c[ 39][ t]], 
            Times[ 0.10337416789158609, 
              c[ 40][ t]], 
            Times[ 0.086542809078944891, 
              c[ 41][ t]], 
            Times[ 0.066820663127759972, 
              c[ 42][ t]], 
            Times[ 0.045163358568919301, 
              c[ 43][ t]], 
            Times[ 0.022561481809254869, 
              c[ 44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 45][ t]], 
            Times[ -0.021580547817547879, 
              c[ 46][ t]], 
            Times[ -0.04131966847794722, 
              c[ 47][ t]], 
            Times[ -0.058468080236789913, 
              c[ 48][ t]], 
            Times[ -0.072413370861974122, 
              c[ 49][ t]], 
            Times[ -0.082699334313268744, 
              c[ 50][ t]], 
            Times[ -0.089038438663606695, 
              c[ 51][ t]], 
            Times[ -0.091317159035181589, 
              c[ 52][ t]], 
            Times[ -0.089594193770366884, 
              c[ 53][ t]], 
            Times[ -0.084091858737850814, 
              c[ 54][ t]], 
            Times[ -0.075181213012062598, 
              c[ 55][ t]], 
            Times[ -0.063361699504227528, 
              c[ 56][ t]], 
            Times[ -0.049236278094138941, 
              c[ 57][ t]], 
            Times[ -0.033483179628681567, 
              c[ 58][ t]], 
            Times[ -0.016825511857749401, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[1]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.016273855731265604`\ \(c[\(-60\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-59\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-58\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-57\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-56\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-55\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-54\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-53\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-52\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-51\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-50\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-49\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-48\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-47\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-46\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-45\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-44\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-43\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-42\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-41\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-40\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-39\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-38\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-37\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-36\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-35\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-34\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-33\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-32\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-31\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-30\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-28\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-27\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-26\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-25\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-24\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-23\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-22\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-21\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-20\)]\)[t] - 
            0.206748335783172`\ \(c[\(-19\)]\)[t] - 
            0.186750272222986`\ \(c[\(-18\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-17\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-16\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-15\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-14\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-13\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-12\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-11\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-10\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-9\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-8\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-7\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-6\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-5\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-4\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-3\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-2\)]\)[t] + 
            0.9710122092317629`\ \(c[\(-1\)]\)[t] + 
            0.9927051996072069`\ \(c[0]\)[t] + 
            1.021932454224643`\ \(c[1]\)[t] + 
            0.9927051996072069`\ \(c[2]\)[t] + 
            0.9710122092317629`\ \(c[3]\)[t] + 
            0.9354892837886392`\ \(c[4]\)[t] + 
            0.8870637930591838`\ \(c[5]\)[t] + 
            0.8269933431326882`\ \(c[6]\)[t] + 
            0.756826728640657`\ \(c[7]\)[t] + 
            0.6783560385470634`\ \(c[8]\)[t] + 
            0.5935615337286805`\ \(c[9]\)[t] + 
            0.5045511524271047`\ \(c[10]\)[t] + 
            0.4134966715663442`\ \(c[11]\)[t] + 
            0.32256865202152135`\ \(c[12]\)[t] + 
            0.23387232094715985`\ \(c[13]\)[t] + 
            0.14938649372796362`\ \(c[14]\)[t] + 
            0.07090751425765762`\ \(c[15]\)[t] + 
            3.898171832519376`*^-17\ \(c[16]\)[t] - 
            0.06204407497545034`\ \(c[17]\)[t] - 
            0.11423673049785445`\ \(c[18]\)[t] - 
            0.15591488063143982`\ \(c[19]\)[t] - 
            0.186750272222986`\ \(c[20]\)[t] - 
            0.206748335783172`\ \(c[21]\)[t] - 
            0.21623620818304481`\ \(c[22]\)[t] - 
            0.21584055771952015`\ \(c[23]\)[t] - 
            0.20645618564475843`\ \(c[24]\)[t] - 
            0.18920668216016434`\ \(c[25]\)[t] - 
            0.1653986686265377`\ \(c[26]\)[t] - 
            0.13647135277833605`\ \(c[27]\)[t] - 
            0.1039432537542934`\ \(c[28]\)[t] - 
            0.06935801494512607`\ \(c[29]\)[t] - 
            0.03423121377955895`\ \(c[30]\)[t] - 
            1.8033970416801674`*^-16\ \(c[31]\)[t] + 
            0.032022748374425904`\ \(c[32]\)[t] + 
            0.060688263076985105`\ \(c[33]\)[t] + 
            0.08504448034442161`\ \(c[34]\)[t] + 
            0.10436044624225685`\ \(c[35]\)[t] + 
            0.11814190616181255`\ \(c[36]\)[t] + 
            0.12613778810677612`\ \(c[37]\)[t] + 
            0.12833762891430928`\ \(c[38]\)[t] + 
            0.12496032289024853`\ \(c[39]\)[t] + 
            0.11643488132933186`\ \(c[40]\)[t] + 
            0.10337416789158609`\ \(c[41]\)[t] + 
            0.08654280907894475`\ \(c[42]\)[t] + 
            0.06682066312775997`\ \(c[43]\)[t] + 
            0.0451633585689193`\ \(c[44]\)[t] + 
            0.022561481809254675`\ \(c[45]\)[t] + 
            3.8981718325193755`*^-17\ \(c[46]\)[t] - 
            0.02158054781754788`\ \(c[47]\)[t] - 
            0.04131966847794737`\ \(c[48]\)[t] - 
            0.05846808023678991`\ \(c[49]\)[t] - 
            0.07241337086197412`\ \(c[50]\)[t] - 
            0.08269933431326881`\ \(c[51]\)[t] - 
            0.0890384386636067`\ \(c[52]\)[t] - 
            0.09131715903518159`\ \(c[53]\)[t] - 
            0.08959419377036684`\ \(c[54]\)[t] - 
            0.08409185873785081`\ \(c[55]\)[t] - 
            0.0751812130120626`\ \(c[56]\)[t] - 
            0.0633616995042274`\ \(c[57]\)[t] - 
            0.04923627809413894`\ \(c[58]\)[t] - 
            0.03348317962868157`\ \(c[59]\)[t] - 
            0.016825511857749262`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 1, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 1]][ t]], 
          Plus[ 
            Times[ 0.016273855731265604, 
              c[ -60][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -59][ t]], 
            Times[ -0.016825511857749401, 
              c[ -58][ t]], 
            Times[ -0.033483179628681567, 
              c[ -57][ t]], 
            Times[ -0.049236278094139066, 
              c[ -56][ t]], 
            Times[ -0.063361699504227528, 
              c[ -55][ t]], 
            Times[ -0.075181213012062598, 
              c[ -54][ t]], 
            Times[ -0.084091858737850855, 
              c[ -53][ t]], 
            Times[ -0.089594193770366884, 
              c[ -52][ t]], 
            Times[ -0.091317159035181589, 
              c[ -51][ t]], 
            Times[ -0.089038438663606653, 
              c[ -50][ t]], 
            Times[ -0.082699334313268744, 
              c[ -49][ t]], 
            Times[ -0.072413370861974122, 
              c[ -48][ t]], 
            Times[ -0.058468080236789774, 
              c[ -47][ t]], 
            Times[ -0.04131966847794722, 
              c[ -46][ t]], 
            Times[ -0.021580547817547879, 
              c[ -45][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -44][ t]], 
            Times[ 0.022561481809254869, 
              c[ -43][ t]], 
            Times[ 0.045163358568919301, 
              c[ -42][ t]], 
            Times[ 0.066820663127760152, 
              c[ -41][ t]], 
            Times[ 0.086542809078944891, 
              c[ -40][ t]], 
            Times[ 0.10337416789158609, 
              c[ -39][ t]], 
            Times[ 0.11643488132933186, 
              c[ -38][ t]], 
            Times[ 0.12496032289024853, 
              c[ -37][ t]], 
            Times[ 0.12833762891430925, 
              c[ -36][ t]], 
            Times[ 0.12613778810677614, 
              c[ -35][ t]], 
            Times[ 0.11814190616181255, 
              c[ -34][ t]], 
            Times[ 0.10436044624225692, 
              c[ -33][ t]], 
            Times[ 0.085044480344421705, 
              c[ -32][ t]], 
            Times[ 0.060688263076985105, 
              c[ -31][ t]], 
            Times[ 0.032022748374426029, 
              c[ -30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ -0.034231213779558949, 
              c[ -28][ t]], 
            Times[ -0.069358014945125918, 
              c[ -27][ t]], 
            Times[ -0.10394325375429328, 
              c[ -26][ t]], 
            Times[ -0.13647135277833605, 
              c[ -25][ t]], 
            Times[ -0.1653986686265376, 
              c[ -24][ t]], 
            Times[ -0.18920668216016426, 
              c[ -23][ t]], 
            Times[ -0.20645618564475843, 
              c[ -22][ t]], 
            Times[ -0.21584055771952013, 
              c[ -21][ t]], 
            Times[ -0.21623620818304484, 
              c[ -20][ t]], 
            Times[ -0.206748335783172, 
              c[ -19][ t]], 
            Times[ -0.18675027222298601, 
              c[ -18][ t]], 
            Times[ -0.15591488063143974, 
              c[ -17][ t]], 
            Times[ -0.11423673049785436, 
              c[ -16][ t]], 
            Times[ -0.062044074975450343, 
              c[ -15][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -14][ t]], 
            Times[ 0.070907514257657775, 
              c[ -13][ t]], 
            Times[ 0.14938649372796362, 
              c[ -12][ t]], 
            Times[ 0.23387232094715998, 
              c[ -11][ t]], 
            Times[ 0.32256865202152157, 
              c[ -10][ t]], 
            Times[ 0.41349667156634418, 
              c[ -9][ t]], 
            Times[ 0.50455115242710469, 
              c[ -8][ t]], 
            Times[ 0.59356153372868048, 
              c[ -7][ t]], 
            Times[ 0.67835603854706328, 
              c[ -6][ t]], 
            Times[ 0.75682672864065692, 
              c[ -5][ t]], 
            Times[ 0.82699334313268824, 
              c[ -4][ t]], 
            Times[ 0.88706379305918381, 
              c[ -3][ t]], 
            Times[ 0.93548928378863916, 
              c[ -2][ t]], 
            Times[ 0.9710122092317629, 
              c[ -1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 0][ t]], 
            Times[ 1.0219324542246431, 
              c[ 1][ t]], 
            Times[ 0.99270519960720693, 
              c[ 2][ t]], 
            Times[ 0.9710122092317629, 
              c[ 3][ t]], 
            Times[ 0.93548928378863916, 
              c[ 4][ t]], 
            Times[ 0.88706379305918381, 
              c[ 5][ t]], 
            Times[ 0.82699334313268824, 
              c[ 6][ t]], 
            Times[ 0.75682672864065703, 
              c[ 7][ t]], 
            Times[ 0.67835603854706339, 
              c[ 8][ t]], 
            Times[ 0.59356153372868048, 
              c[ 9][ t]], 
            Times[ 0.50455115242710469, 
              c[ 10][ t]], 
            Times[ 0.41349667156634418, 
              c[ 11][ t]], 
            Times[ 0.32256865202152135, 
              c[ 12][ t]], 
            Times[ 0.23387232094715985, 
              c[ 13][ t]], 
            Times[ 0.14938649372796362, 
              c[ 14][ t]], 
            Times[ 0.070907514257657622, 
              c[ 15][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ -0.062044074975450343, 
              c[ 17][ t]], 
            Times[ -0.11423673049785445, 
              c[ 18][ t]], 
            Times[ -0.15591488063143982, 
              c[ 19][ t]], 
            Times[ -0.18675027222298601, 
              c[ 20][ t]], 
            Times[ -0.206748335783172, 
              c[ 21][ t]], 
            Times[ -0.21623620818304481, 
              c[ 22][ t]], 
            Times[ -0.21584055771952015, 
              c[ 23][ t]], 
            Times[ -0.20645618564475843, 
              c[ 24][ t]], 
            Times[ -0.18920668216016434, 
              c[ 25][ t]], 
            Times[ -0.16539866862653771, 
              c[ 26][ t]], 
            Times[ -0.13647135277833605, 
              c[ 27][ t]], 
            Times[ -0.1039432537542934, 
              c[ 28][ t]], 
            Times[ -0.06935801494512607, 
              c[ 29][ t]], 
            Times[ -0.034231213779558949, 
              c[ 30][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 31][ t]], 
            Times[ 0.032022748374425904, 
              c[ 32][ t]], 
            Times[ 0.060688263076985105, 
              c[ 33][ t]], 
            Times[ 0.085044480344421608, 
              c[ 34][ t]], 
            Times[ 0.10436044624225685, 
              c[ 35][ t]], 
            Times[ 0.11814190616181255, 
              c[ 36][ t]], 
            Times[ 0.12613778810677612, 
              c[ 37][ t]], 
            Times[ 0.12833762891430928, 
              c[ 38][ t]], 
            Times[ 0.12496032289024853, 
              c[ 39][ t]], 
            Times[ 0.11643488132933186, 
              c[ 40][ t]], 
            Times[ 0.10337416789158609, 
              c[ 41][ t]], 
            Times[ 0.086542809078944752, 
              c[ 42][ t]], 
            Times[ 0.066820663127759972, 
              c[ 43][ t]], 
            Times[ 0.045163358568919301, 
              c[ 44][ t]], 
            Times[ 0.022561481809254675, 
              c[ 45][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 46][ t]], 
            Times[ -0.021580547817547879, 
              c[ 47][ t]], 
            Times[ -0.041319668477947373, 
              c[ 48][ t]], 
            Times[ -0.058468080236789913, 
              c[ 49][ t]], 
            Times[ -0.072413370861974122, 
              c[ 50][ t]], 
            Times[ -0.082699334313268813, 
              c[ 51][ t]], 
            Times[ -0.089038438663606695, 
              c[ 52][ t]], 
            Times[ -0.091317159035181589, 
              c[ 53][ t]], 
            Times[ -0.089594193770366842, 
              c[ 54][ t]], 
            Times[ -0.084091858737850814, 
              c[ 55][ t]], 
            Times[ -0.075181213012062598, 
              c[ 56][ t]], 
            Times[ -0.063361699504227403, 
              c[ 57][ t]], 
            Times[ -0.049236278094138941, 
              c[ 58][ t]], 
            Times[ -0.033483179628681567, 
              c[ 59][ t]], 
            Times[ -0.016825511857749262, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "2", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[2]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.0313229744913472`\ \(c[\(-60\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-59\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-57\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-56\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-55\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-54\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-53\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-52\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-51\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-50\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-49\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-48\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-47\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-46\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-45\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-44\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-43\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-42\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-41\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-40\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-39\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-38\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-37\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-36\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-35\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-34\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-33\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-32\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-31\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-30\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-29\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-28\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-27\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-26\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-25\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-24\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-23\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-22\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-21\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-20\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-19\)]\)[t] - 
            0.206748335783172`\ \(c[\(-18\)]\)[t] - 
            0.186750272222986`\ \(c[\(-17\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-16\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-15\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-14\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-12\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-11\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-10\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-9\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-8\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-7\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-6\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-5\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-4\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-3\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-2\)]\)[t] + 
            0.9354892837886392`\ \(c[\(-1\)]\)[t] + 
            0.9710122092317629`\ \(c[0]\)[t] + 
            0.9927051996072069`\ \(c[1]\)[t] + 
            1.087729816898572`\ \(c[2]\)[t] + 
            0.9927051996072067`\ \(c[3]\)[t] + 
            0.9710122092317629`\ \(c[4]\)[t] + 
            0.9354892837886392`\ \(c[5]\)[t] + 
            0.8870637930591837`\ \(c[6]\)[t] + 
            0.8269933431326882`\ \(c[7]\)[t] + 
            0.7568267286406569`\ \(c[8]\)[t] + 
            0.6783560385470633`\ \(c[9]\)[t] + 
            0.5935615337286805`\ \(c[10]\)[t] + 
            0.5045511524271047`\ \(c[11]\)[t] + 
            0.4134966715663442`\ \(c[12]\)[t] + 
            0.3225686520215216`\ \(c[13]\)[t] + 
            0.23387232094715998`\ \(c[14]\)[t] + 
            0.14938649372796362`\ \(c[15]\)[t] + 
            0.07090751425765777`\ \(c[16]\)[t] + 
            1.8033970416801674`*^-16\ \(c[17]\)[t] - 
            0.06204407497545034`\ \(c[18]\)[t] - 
            0.11423673049785436`\ \(c[19]\)[t] - 
            0.15591488063143974`\ \(c[20]\)[t] - 
            0.186750272222986`\ \(c[21]\)[t] - 
            0.206748335783172`\ \(c[22]\)[t] - 
            0.21623620818304484`\ \(c[23]\)[t] - 
            0.21584055771952013`\ \(c[24]\)[t] - 
            0.20645618564475843`\ \(c[25]\)[t] - 
            0.18920668216016426`\ \(c[26]\)[t] - 
            0.1653986686265376`\ \(c[27]\)[t] - 
            0.13647135277833605`\ \(c[28]\)[t] - 
            0.10394325375429328`\ \(c[29]\)[t] - 
            0.06935801494512592`\ \(c[30]\)[t] - 
            0.03423121377955895`\ \(c[31]\)[t] - 
            3.898171832519376`*^-17\ \(c[32]\)[t] + 
            0.03202274837442603`\ \(c[33]\)[t] + 
            0.060688263076985105`\ \(c[34]\)[t] + 
            0.0850444803444217`\ \(c[35]\)[t] + 
            0.10436044624225692`\ \(c[36]\)[t] + 
            0.11814190616181255`\ \(c[37]\)[t] + 
            0.12613778810677614`\ \(c[38]\)[t] + 
            0.12833762891430925`\ \(c[39]\)[t] + 
            0.12496032289024853`\ \(c[40]\)[t] + 
            0.11643488132933195`\ \(c[41]\)[t] + 
            0.10337416789158609`\ \(c[42]\)[t] + 
            0.08654280907894489`\ \(c[43]\)[t] + 
            0.06682066312776015`\ \(c[44]\)[t] + 
            0.0451633585689193`\ \(c[45]\)[t] + 
            0.02256148180925487`\ \(c[46]\)[t] + 
            2.274590327822911`*^-16\ \(c[47]\)[t] - 
            0.02158054781754788`\ \(c[48]\)[t] - 
            0.04131966847794722`\ \(c[49]\)[t] - 
            0.058468080236789774`\ \(c[50]\)[t] - 
            0.07241337086197412`\ \(c[51]\)[t] - 
            0.08269933431326874`\ \(c[52]\)[t] - 
            0.08903843866360665`\ \(c[53]\)[t] - 
            0.09131715903518159`\ \(c[54]\)[t] - 
            0.08959419377036688`\ \(c[55]\)[t] - 
            0.08409185873785086`\ \(c[56]\)[t] - 
            0.0751812130120626`\ \(c[57]\)[t] - 
            0.06336169950422753`\ \(c[58]\)[t] - 
            0.049236278094139066`\ \(c[59]\)[t] - 
            0.03348317962868157`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 2, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 2]][ t]], 
          Plus[ 
            Times[ 0.031322974491347202, 
              c[ -60][ t]], 
            Times[ 0.016273855731265604, 
              c[ -59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ -0.016825511857749262, 
              c[ -57][ t]], 
            Times[ -0.033483179628681567, 
              c[ -56][ t]], 
            Times[ -0.049236278094138941, 
              c[ -55][ t]], 
            Times[ -0.063361699504227403, 
              c[ -54][ t]], 
            Times[ -0.075181213012062598, 
              c[ -53][ t]], 
            Times[ -0.084091858737850814, 
              c[ -52][ t]], 
            Times[ -0.089594193770366842, 
              c[ -51][ t]], 
            Times[ -0.091317159035181589, 
              c[ -50][ t]], 
            Times[ -0.089038438663606695, 
              c[ -49][ t]], 
            Times[ -0.082699334313268813, 
              c[ -48][ t]], 
            Times[ -0.072413370861974122, 
              c[ -47][ t]], 
            Times[ -0.058468080236789913, 
              c[ -46][ t]], 
            Times[ -0.041319668477947373, 
              c[ -45][ t]], 
            Times[ -0.021580547817547879, 
              c[ -44][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -43][ t]], 
            Times[ 0.022561481809254675, 
              c[ -42][ t]], 
            Times[ 0.045163358568919301, 
              c[ -41][ t]], 
            Times[ 0.066820663127759972, 
              c[ -40][ t]], 
            Times[ 0.086542809078944752, 
              c[ -39][ t]], 
            Times[ 0.10337416789158609, 
              c[ -38][ t]], 
            Times[ 0.11643488132933186, 
              c[ -37][ t]], 
            Times[ 0.12496032289024853, 
              c[ -36][ t]], 
            Times[ 0.12833762891430928, 
              c[ -35][ t]], 
            Times[ 0.12613778810677612, 
              c[ -34][ t]], 
            Times[ 0.11814190616181255, 
              c[ -33][ t]], 
            Times[ 0.10436044624225685, 
              c[ -32][ t]], 
            Times[ 0.085044480344421608, 
              c[ -31][ t]], 
            Times[ 0.060688263076985105, 
              c[ -30][ t]], 
            Times[ 0.032022748374425904, 
              c[ -29][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -28][ t]], 
            Times[ -0.034231213779558949, 
              c[ -27][ t]], 
            Times[ -0.06935801494512607, 
              c[ -26][ t]], 
            Times[ -0.1039432537542934, 
              c[ -25][ t]], 
            Times[ -0.13647135277833605, 
              c[ -24][ t]], 
            Times[ -0.16539866862653771, 
              c[ -23][ t]], 
            Times[ -0.18920668216016434, 
              c[ -22][ t]], 
            Times[ -0.20645618564475843, 
              c[ -21][ t]], 
            Times[ -0.21584055771952015, 
              c[ -20][ t]], 
            Times[ -0.21623620818304484, 
              c[ -19][ t]], 
            Times[ -0.206748335783172, 
              c[ -18][ t]], 
            Times[ -0.18675027222298601, 
              c[ -17][ t]], 
            Times[ -0.15591488063143982, 
              c[ -16][ t]], 
            Times[ -0.11423673049785445, 
              c[ -15][ t]], 
            Times[ -0.062044074975450343, 
              c[ -14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ 0.070907514257657622, 
              c[ -12][ t]], 
            Times[ 0.14938649372796362, 
              c[ -11][ t]], 
            Times[ 0.23387232094715985, 
              c[ -10][ t]], 
            Times[ 0.32256865202152135, 
              c[ -9][ t]], 
            Times[ 0.41349667156634418, 
              c[ -8][ t]], 
            Times[ 0.50455115242710469, 
              c[ -7][ t]], 
            Times[ 0.59356153372868048, 
              c[ -6][ t]], 
            Times[ 0.67835603854706339, 
              c[ -5][ t]], 
            Times[ 0.75682672864065692, 
              c[ -4][ t]], 
            Times[ 0.82699334313268824, 
              c[ -3][ t]], 
            Times[ 0.88706379305918381, 
              c[ -2][ t]], 
            Times[ 0.93548928378863916, 
              c[ -1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 0][ t]], 
            Times[ 0.99270519960720693, 
              c[ 1][ t]], 
            Times[ 1.0877298168985721, 
              c[ 2][ t]], 
            Times[ 0.99270519960720671, 
              c[ 3][ t]], 
            Times[ 0.9710122092317629, 
              c[ 4][ t]], 
            Times[ 0.93548928378863916, 
              c[ 5][ t]], 
            Times[ 0.8870637930591837, 
              c[ 6][ t]], 
            Times[ 0.82699334313268824, 
              c[ 7][ t]], 
            Times[ 0.75682672864065692, 
              c[ 8][ t]], 
            Times[ 0.67835603854706328, 
              c[ 9][ t]], 
            Times[ 0.59356153372868048, 
              c[ 10][ t]], 
            Times[ 0.50455115242710469, 
              c[ 11][ t]], 
            Times[ 0.41349667156634418, 
              c[ 12][ t]], 
            Times[ 0.32256865202152157, 
              c[ 13][ t]], 
            Times[ 0.23387232094715998, 
              c[ 14][ t]], 
            Times[ 0.14938649372796362, 
              c[ 15][ t]], 
            Times[ 0.070907514257657775, 
              c[ 16][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 17][ t]], 
            Times[ -0.062044074975450343, 
              c[ 18][ t]], 
            Times[ -0.11423673049785436, 
              c[ 19][ t]], 
            Times[ -0.15591488063143974, 
              c[ 20][ t]], 
            Times[ -0.18675027222298601, 
              c[ 21][ t]], 
            Times[ -0.206748335783172, 
              c[ 22][ t]], 
            Times[ -0.21623620818304484, 
              c[ 23][ t]], 
            Times[ -0.21584055771952013, 
              c[ 24][ t]], 
            Times[ -0.20645618564475843, 
              c[ 25][ t]], 
            Times[ -0.18920668216016426, 
              c[ 26][ t]], 
            Times[ -0.1653986686265376, 
              c[ 27][ t]], 
            Times[ -0.13647135277833605, 
              c[ 28][ t]], 
            Times[ -0.10394325375429328, 
              c[ 29][ t]], 
            Times[ -0.069358014945125918, 
              c[ 30][ t]], 
            Times[ -0.034231213779558949, 
              c[ 31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ 0.032022748374426029, 
              c[ 33][ t]], 
            Times[ 0.060688263076985105, 
              c[ 34][ t]], 
            Times[ 0.085044480344421705, 
              c[ 35][ t]], 
            Times[ 0.10436044624225692, 
              c[ 36][ t]], 
            Times[ 0.11814190616181255, 
              c[ 37][ t]], 
            Times[ 0.12613778810677614, 
              c[ 38][ t]], 
            Times[ 0.12833762891430925, 
              c[ 39][ t]], 
            Times[ 0.12496032289024853, 
              c[ 40][ t]], 
            Times[ 0.11643488132933195, 
              c[ 41][ t]], 
            Times[ 0.10337416789158609, 
              c[ 42][ t]], 
            Times[ 0.086542809078944891, 
              c[ 43][ t]], 
            Times[ 0.066820663127760152, 
              c[ 44][ t]], 
            Times[ 0.045163358568919301, 
              c[ 45][ t]], 
            Times[ 0.022561481809254869, 
              c[ 46][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 47][ t]], 
            Times[ -0.021580547817547879, 
              c[ 48][ t]], 
            Times[ -0.04131966847794722, 
              c[ 49][ t]], 
            Times[ -0.058468080236789774, 
              c[ 50][ t]], 
            Times[ -0.072413370861974122, 
              c[ 51][ t]], 
            Times[ -0.082699334313268744, 
              c[ 52][ t]], 
            Times[ -0.089038438663606653, 
              c[ 53][ t]], 
            Times[ -0.091317159035181589, 
              c[ 54][ t]], 
            Times[ -0.089594193770366884, 
              c[ 55][ t]], 
            Times[ -0.084091858737850855, 
              c[ 56][ t]], 
            Times[ -0.075181213012062598, 
              c[ 57][ t]], 
            Times[ -0.063361699504227528, 
              c[ 58][ t]], 
            Times[ -0.049236278094139066, 
              c[ 59][ t]], 
            Times[ -0.033483179628681567, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "3", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[3]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04454710875183992`\ \(c[\(-60\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-59\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-58\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-56\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-55\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-54\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-53\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-52\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-51\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-50\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-49\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-48\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-47\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-46\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-45\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-44\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-43\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-42\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-41\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-40\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-39\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-38\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-37\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-36\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-35\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-34\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-33\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-32\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-31\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-30\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-29\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-26\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-25\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-24\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-23\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-22\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-21\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-20\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-19\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-18\)]\)[t] - 
            0.206748335783172`\ \(c[\(-17\)]\)[t] - 
            0.186750272222986`\ \(c[\(-16\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-15\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-14\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-13\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-11\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-10\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-9\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-8\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-7\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-6\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-5\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-4\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-3\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-2\)]\)[t] + 
            0.8870637930591838`\ \(c[\(-1\)]\)[t] + 
            0.9354892837886392`\ \(c[0]\)[t] + 
            0.9710122092317629`\ \(c[1]\)[t] + 
            0.9927051996072067`\ \(c[2]\)[t] + 
            1.1973920880217872`\ \(c[3]\)[t] + 
            0.9927051996072069`\ \(c[4]\)[t] + 
            0.9710122092317629`\ \(c[5]\)[t] + 
            0.9354892837886392`\ \(c[6]\)[t] + 
            0.8870637930591838`\ \(c[7]\)[t] + 
            0.8269933431326882`\ \(c[8]\)[t] + 
            0.7568267286406569`\ \(c[9]\)[t] + 
            0.6783560385470634`\ \(c[10]\)[t] + 
            0.5935615337286806`\ \(c[11]\)[t] + 
            0.5045511524271047`\ \(c[12]\)[t] + 
            0.4134966715663442`\ \(c[13]\)[t] + 
            0.3225686520215216`\ \(c[14]\)[t] + 
            0.23387232094715985`\ \(c[15]\)[t] + 
            0.14938649372796362`\ \(c[16]\)[t] + 
            0.07090751425765777`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.06204407497545034`\ \(c[19]\)[t] - 
            0.11423673049785436`\ \(c[20]\)[t] - 
            0.15591488063143982`\ \(c[21]\)[t] - 
            0.18675027222298593`\ \(c[22]\)[t] - 
            0.206748335783172`\ \(c[23]\)[t] - 
            0.21623620818304484`\ \(c[24]\)[t] - 
            0.21584055771952015`\ \(c[25]\)[t] - 
            0.20645618564475843`\ \(c[26]\)[t] - 
            0.18920668216016426`\ \(c[27]\)[t] - 
            0.1653986686265377`\ \(c[28]\)[t] - 
            0.13647135277833605`\ \(c[29]\)[t] - 
            0.10394325375429328`\ \(c[30]\)[t] - 
            0.06935801494512607`\ \(c[31]\)[t] - 
            0.03423121377955895`\ \(c[32]\)[t] - 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.032022748374425904`\ \(c[34]\)[t] + 
            0.060688263076985105`\ \(c[35]\)[t] + 
            0.0850444803444217`\ \(c[36]\)[t] + 
            0.10436044624225685`\ \(c[37]\)[t] + 
            0.11814190616181255`\ \(c[38]\)[t] + 
            0.12613778810677614`\ \(c[39]\)[t] + 
            0.12833762891430928`\ \(c[40]\)[t] + 
            0.12496032289024853`\ \(c[41]\)[t] + 
            0.11643488132933186`\ \(c[42]\)[t] + 
            0.10337416789158609`\ \(c[43]\)[t] + 
            0.08654280907894489`\ \(c[44]\)[t] + 
            0.06682066312775997`\ \(c[45]\)[t] + 
            0.0451633585689193`\ \(c[46]\)[t] + 
            0.02256148180925487`\ \(c[47]\)[t] + 
            3.8981718325193755`*^-17\ \(c[48]\)[t] - 
            0.02158054781754788`\ \(c[49]\)[t] - 
            0.04131966847794722`\ \(c[50]\)[t] - 
            0.05846808023678991`\ \(c[51]\)[t] - 
            0.07241337086197412`\ \(c[52]\)[t] - 
            0.08269933431326874`\ \(c[53]\)[t] - 
            0.0890384386636067`\ \(c[54]\)[t] - 
            0.09131715903518159`\ \(c[55]\)[t] - 
            0.08959419377036688`\ \(c[56]\)[t] - 
            0.08409185873785081`\ \(c[57]\)[t] - 
            0.0751812130120626`\ \(c[58]\)[t] - 
            0.06336169950422753`\ \(c[59]\)[t] - 
            0.04923627809413894`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 3, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 3]][ t]], 
          Plus[ 
            Times[ 0.044547108751839919, 
              c[ -60][ t]], 
            Times[ 0.031322974491347078, 
              c[ -59][ t]], 
            Times[ 0.016273855731265604, 
              c[ -58][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ -0.016825511857749401, 
              c[ -56][ t]], 
            Times[ -0.033483179628681567, 
              c[ -55][ t]], 
            Times[ -0.049236278094138941, 
              c[ -54][ t]], 
            Times[ -0.063361699504227528, 
              c[ -53][ t]], 
            Times[ -0.075181213012062598, 
              c[ -52][ t]], 
            Times[ -0.084091858737850814, 
              c[ -51][ t]], 
            Times[ -0.089594193770366884, 
              c[ -50][ t]], 
            Times[ -0.091317159035181589, 
              c[ -49][ t]], 
            Times[ -0.089038438663606695, 
              c[ -48][ t]], 
            Times[ -0.082699334313268744, 
              c[ -47][ t]], 
            Times[ -0.072413370861974122, 
              c[ -46][ t]], 
            Times[ -0.058468080236789913, 
              c[ -45][ t]], 
            Times[ -0.04131966847794722, 
              c[ -44][ t]], 
            Times[ -0.021580547817547879, 
              c[ -43][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -42][ t]], 
            Times[ 0.022561481809254869, 
              c[ -41][ t]], 
            Times[ 0.045163358568919301, 
              c[ -40][ t]], 
            Times[ 0.066820663127759972, 
              c[ -39][ t]], 
            Times[ 0.086542809078944891, 
              c[ -38][ t]], 
            Times[ 0.10337416789158609, 
              c[ -37][ t]], 
            Times[ 0.11643488132933186, 
              c[ -36][ t]], 
            Times[ 0.12496032289024853, 
              c[ -35][ t]], 
            Times[ 0.12833762891430928, 
              c[ -34][ t]], 
            Times[ 0.12613778810677614, 
              c[ -33][ t]], 
            Times[ 0.11814190616181255, 
              c[ -32][ t]], 
            Times[ 0.10436044624225685, 
              c[ -31][ t]], 
            Times[ 0.085044480344421705, 
              c[ -30][ t]], 
            Times[ 0.060688263076985105, 
              c[ -29][ t]], 
            Times[ 0.032022748374425904, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.034231213779558949, 
              c[ -26][ t]], 
            Times[ -0.06935801494512607, 
              c[ -25][ t]], 
            Times[ -0.10394325375429328, 
              c[ -24][ t]], 
            Times[ -0.13647135277833605, 
              c[ -23][ t]], 
            Times[ -0.16539866862653771, 
              c[ -22][ t]], 
            Times[ -0.18920668216016426, 
              c[ -21][ t]], 
            Times[ -0.20645618564475843, 
              c[ -20][ t]], 
            Times[ -0.21584055771952015, 
              c[ -19][ t]], 
            Times[ -0.21623620818304484, 
              c[ -18][ t]], 
            Times[ -0.206748335783172, 
              c[ -17][ t]], 
            Times[ -0.18675027222298601, 
              c[ -16][ t]], 
            Times[ -0.15591488063143982, 
              c[ -15][ t]], 
            Times[ -0.11423673049785436, 
              c[ -14][ t]], 
            Times[ -0.062044074975450343, 
              c[ -13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ 0.070907514257657775, 
              c[ -11][ t]], 
            Times[ 0.14938649372796362, 
              c[ -10][ t]], 
            Times[ 0.23387232094715985, 
              c[ -9][ t]], 
            Times[ 0.32256865202152157, 
              c[ -8][ t]], 
            Times[ 0.41349667156634418, 
              c[ -7][ t]], 
            Times[ 0.50455115242710469, 
              c[ -6][ t]], 
            Times[ 0.59356153372868048, 
              c[ -5][ t]], 
            Times[ 0.67835603854706339, 
              c[ -4][ t]], 
            Times[ 0.75682672864065692, 
              c[ -3][ t]], 
            Times[ 0.82699334313268824, 
              c[ -2][ t]], 
            Times[ 0.88706379305918381, 
              c[ -1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 0][ t]], 
            Times[ 0.9710122092317629, 
              c[ 1][ t]], 
            Times[ 0.99270519960720671, 
              c[ 2][ t]], 
            Times[ 1.1973920880217872, 
              c[ 3][ t]], 
            Times[ 0.99270519960720693, 
              c[ 4][ t]], 
            Times[ 0.9710122092317629, 
              c[ 5][ t]], 
            Times[ 0.93548928378863916, 
              c[ 6][ t]], 
            Times[ 0.88706379305918381, 
              c[ 7][ t]], 
            Times[ 0.82699334313268824, 
              c[ 8][ t]], 
            Times[ 0.75682672864065692, 
              c[ 9][ t]], 
            Times[ 0.67835603854706339, 
              c[ 10][ t]], 
            Times[ 0.59356153372868059, 
              c[ 11][ t]], 
            Times[ 0.50455115242710469, 
              c[ 12][ t]], 
            Times[ 0.41349667156634418, 
              c[ 13][ t]], 
            Times[ 0.32256865202152157, 
              c[ 14][ t]], 
            Times[ 0.23387232094715985, 
              c[ 15][ t]], 
            Times[ 0.14938649372796362, 
              c[ 16][ t]], 
            Times[ 0.070907514257657775, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.062044074975450343, 
              c[ 19][ t]], 
            Times[ -0.11423673049785436, 
              c[ 20][ t]], 
            Times[ -0.15591488063143982, 
              c[ 21][ t]], 
            Times[ -0.18675027222298593, 
              c[ 22][ t]], 
            Times[ -0.206748335783172, 
              c[ 23][ t]], 
            Times[ -0.21623620818304484, 
              c[ 24][ t]], 
            Times[ -0.21584055771952015, 
              c[ 25][ t]], 
            Times[ -0.20645618564475843, 
              c[ 26][ t]], 
            Times[ -0.18920668216016426, 
              c[ 27][ t]], 
            Times[ -0.16539866862653771, 
              c[ 28][ t]], 
            Times[ -0.13647135277833605, 
              c[ 29][ t]], 
            Times[ -0.10394325375429328, 
              c[ 30][ t]], 
            Times[ -0.06935801494512607, 
              c[ 31][ t]], 
            Times[ -0.034231213779558949, 
              c[ 32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.032022748374425904, 
              c[ 34][ t]], 
            Times[ 0.060688263076985105, 
              c[ 35][ t]], 
            Times[ 0.085044480344421705, 
              c[ 36][ t]], 
            Times[ 0.10436044624225685, 
              c[ 37][ t]], 
            Times[ 0.11814190616181255, 
              c[ 38][ t]], 
            Times[ 0.12613778810677614, 
              c[ 39][ t]], 
            Times[ 0.12833762891430928, 
              c[ 40][ t]], 
            Times[ 0.12496032289024853, 
              c[ 41][ t]], 
            Times[ 0.11643488132933186, 
              c[ 42][ t]], 
            Times[ 0.10337416789158609, 
              c[ 43][ t]], 
            Times[ 0.086542809078944891, 
              c[ 44][ t]], 
            Times[ 0.066820663127759972, 
              c[ 45][ t]], 
            Times[ 0.045163358568919301, 
              c[ 46][ t]], 
            Times[ 0.022561481809254869, 
              c[ 47][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 48][ t]], 
            Times[ -0.021580547817547879, 
              c[ 49][ t]], 
            Times[ -0.04131966847794722, 
              c[ 50][ t]], 
            Times[ -0.058468080236789913, 
              c[ 51][ t]], 
            Times[ -0.072413370861974122, 
              c[ 52][ t]], 
            Times[ -0.082699334313268744, 
              c[ 53][ t]], 
            Times[ -0.089038438663606695, 
              c[ 54][ t]], 
            Times[ -0.091317159035181589, 
              c[ 55][ t]], 
            Times[ -0.089594193770366884, 
              c[ 56][ t]], 
            Times[ -0.084091858737850814, 
              c[ 57][ t]], 
            Times[ -0.075181213012062598, 
              c[ 58][ t]], 
            Times[ -0.063361699504227528, 
              c[ 59][ t]], 
            Times[ -0.049236278094138941, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "4", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[4]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.05544148706619893`\ \(c[\(-60\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-59\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-58\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-57\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-56\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-55\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-54\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-53\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-52\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-51\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-50\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-49\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-48\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-47\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-46\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-45\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-44\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-43\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-42\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-41\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-40\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-39\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-38\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-37\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-36\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-35\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-34\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-33\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-32\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-31\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-30\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-29\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-28\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-27\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-25\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-24\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-23\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-22\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-21\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-20\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-19\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-18\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-17\)]\)[t] - 
            0.206748335783172`\ \(c[\(-16\)]\)[t] - 
            0.186750272222986`\ \(c[\(-15\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-14\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-13\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-12\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-11\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-10\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-9\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-8\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-7\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-6\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-5\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-4\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-3\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-2\)]\)[t] + 
            0.8269933431326882`\ \(c[\(-1\)]\)[t] + 
            0.8870637930591838`\ \(c[0]\)[t] + 
            0.9354892837886392`\ \(c[1]\)[t] + 
            0.9710122092317629`\ \(c[2]\)[t] + 
            0.9927051996072069`\ \(c[3]\)[t] + 
            1.3509192675942883`\ \(c[4]\)[t] + 
            0.9927051996072069`\ \(c[5]\)[t] + 
            0.9710122092317629`\ \(c[6]\)[t] + 
            0.935489283788639`\ \(c[7]\)[t] + 
            0.8870637930591838`\ \(c[8]\)[t] + 
            0.8269933431326881`\ \(c[9]\)[t] + 
            0.7568267286406569`\ \(c[10]\)[t] + 
            0.6783560385470634`\ \(c[11]\)[t] + 
            0.5935615337286803`\ \(c[12]\)[t] + 
            0.5045511524271047`\ \(c[13]\)[t] + 
            0.4134966715663442`\ \(c[14]\)[t] + 
            0.32256865202152135`\ \(c[15]\)[t] + 
            0.23387232094715985`\ \(c[16]\)[t] + 
            0.14938649372796362`\ \(c[17]\)[t] + 
            0.07090751425765762`\ \(c[18]\)[t] + 
            3.898171832519376`*^-17\ \(c[19]\)[t] - 
            0.06204407497545034`\ \(c[20]\)[t] - 
            0.11423673049785445`\ \(c[21]\)[t] - 
            0.15591488063143974`\ \(c[22]\)[t] - 
            0.186750272222986`\ \(c[23]\)[t] - 
            0.206748335783172`\ \(c[24]\)[t] - 
            0.21623620818304481`\ \(c[25]\)[t] - 
            0.21584055771952015`\ \(c[26]\)[t] - 
            0.20645618564475843`\ \(c[27]\)[t] - 
            0.18920668216016434`\ \(c[28]\)[t] - 
            0.1653986686265377`\ \(c[29]\)[t] - 
            0.13647135277833605`\ \(c[30]\)[t] - 
            0.1039432537542934`\ \(c[31]\)[t] - 
            0.06935801494512607`\ \(c[32]\)[t] - 
            0.03423121377955895`\ \(c[33]\)[t] - 
            1.8033970416801674`*^-16\ \(c[34]\)[t] + 
            0.032022748374425904`\ \(c[35]\)[t] + 
            0.060688263076985105`\ \(c[36]\)[t] + 
            0.08504448034442161`\ \(c[37]\)[t] + 
            0.10436044624225685`\ \(c[38]\)[t] + 
            0.11814190616181255`\ \(c[39]\)[t] + 
            0.12613778810677612`\ \(c[40]\)[t] + 
            0.12833762891430925`\ \(c[41]\)[t] + 
            0.12496032289024853`\ \(c[42]\)[t] + 
            0.11643488132933186`\ \(c[43]\)[t] + 
            0.10337416789158609`\ \(c[44]\)[t] + 
            0.08654280907894475`\ \(c[45]\)[t] + 
            0.06682066312775997`\ \(c[46]\)[t] + 
            0.0451633585689193`\ \(c[47]\)[t] + 
            0.022561481809254675`\ \(c[48]\)[t] + 
            3.8981718325193755`*^-17\ \(c[49]\)[t] - 
            0.02158054781754788`\ \(c[50]\)[t] - 
            0.04131966847794737`\ \(c[51]\)[t] - 
            0.05846808023678991`\ \(c[52]\)[t] - 
            0.07241337086197412`\ \(c[53]\)[t] - 
            0.08269933431326881`\ \(c[54]\)[t] - 
            0.0890384386636067`\ \(c[55]\)[t] - 
            0.09131715903518159`\ \(c[56]\)[t] - 
            0.08959419377036684`\ \(c[57]\)[t] - 
            0.08409185873785081`\ \(c[58]\)[t] - 
            0.0751812130120626`\ \(c[59]\)[t] - 
            0.0633616995042274`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 4, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 4]][ t]], 
          Plus[ 
            Times[ 0.055441487066198933, 
              c[ -60][ t]], 
            Times[ 0.044547108751839815, 
              c[ -59][ t]], 
            Times[ 0.031322974491347078, 
              c[ -58][ t]], 
            Times[ 0.016273855731265604, 
              c[ -57][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -56][ t]], 
            Times[ -0.016825511857749401, 
              c[ -55][ t]], 
            Times[ -0.033483179628681567, 
              c[ -54][ t]], 
            Times[ -0.049236278094139066, 
              c[ -53][ t]], 
            Times[ -0.063361699504227528, 
              c[ -52][ t]], 
            Times[ -0.075181213012062598, 
              c[ -51][ t]], 
            Times[ -0.084091858737850855, 
              c[ -50][ t]], 
            Times[ -0.089594193770366884, 
              c[ -49][ t]], 
            Times[ -0.091317159035181589, 
              c[ -48][ t]], 
            Times[ -0.089038438663606653, 
              c[ -47][ t]], 
            Times[ -0.082699334313268744, 
              c[ -46][ t]], 
            Times[ -0.072413370861974122, 
              c[ -45][ t]], 
            Times[ -0.058468080236789774, 
              c[ -44][ t]], 
            Times[ -0.04131966847794722, 
              c[ -43][ t]], 
            Times[ -0.021580547817547879, 
              c[ -42][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -41][ t]], 
            Times[ 0.022561481809254869, 
              c[ -40][ t]], 
            Times[ 0.045163358568919301, 
              c[ -39][ t]], 
            Times[ 0.066820663127759972, 
              c[ -38][ t]], 
            Times[ 0.086542809078944891, 
              c[ -37][ t]], 
            Times[ 0.10337416789158609, 
              c[ -36][ t]], 
            Times[ 0.11643488132933186, 
              c[ -35][ t]], 
            Times[ 0.12496032289024853, 
              c[ -34][ t]], 
            Times[ 0.12833762891430925, 
              c[ -33][ t]], 
            Times[ 0.12613778810677614, 
              c[ -32][ t]], 
            Times[ 0.11814190616181255, 
              c[ -31][ t]], 
            Times[ 0.10436044624225692, 
              c[ -30][ t]], 
            Times[ 0.085044480344421705, 
              c[ -29][ t]], 
            Times[ 0.060688263076985105, 
              c[ -28][ t]], 
            Times[ 0.032022748374426029, 
              c[ -27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ -0.034231213779558949, 
              c[ -25][ t]], 
            Times[ -0.069358014945125918, 
              c[ -24][ t]], 
            Times[ -0.10394325375429328, 
              c[ -23][ t]], 
            Times[ -0.13647135277833605, 
              c[ -22][ t]], 
            Times[ -0.1653986686265376, 
              c[ -21][ t]], 
            Times[ -0.18920668216016426, 
              c[ -20][ t]], 
            Times[ -0.20645618564475843, 
              c[ -19][ t]], 
            Times[ -0.21584055771952013, 
              c[ -18][ t]], 
            Times[ -0.21623620818304484, 
              c[ -17][ t]], 
            Times[ -0.206748335783172, 
              c[ -16][ t]], 
            Times[ -0.18675027222298601, 
              c[ -15][ t]], 
            Times[ -0.15591488063143974, 
              c[ -14][ t]], 
            Times[ -0.11423673049785436, 
              c[ -13][ t]], 
            Times[ -0.062044074975450343, 
              c[ -12][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -11][ t]], 
            Times[ 0.070907514257657775, 
              c[ -10][ t]], 
            Times[ 0.14938649372796362, 
              c[ -9][ t]], 
            Times[ 0.23387232094715985, 
              c[ -8][ t]], 
            Times[ 0.32256865202152157, 
              c[ -7][ t]], 
            Times[ 0.41349667156634418, 
              c[ -6][ t]], 
            Times[ 0.50455115242710469, 
              c[ -5][ t]], 
            Times[ 0.59356153372868048, 
              c[ -4][ t]], 
            Times[ 0.67835603854706339, 
              c[ -3][ t]], 
            Times[ 0.75682672864065692, 
              c[ -2][ t]], 
            Times[ 0.82699334313268824, 
              c[ -1][ t]], 
            Times[ 0.88706379305918381, 
              c[ 0][ t]], 
            Times[ 0.93548928378863916, 
              c[ 1][ t]], 
            Times[ 0.9710122092317629, 
              c[ 2][ t]], 
            Times[ 0.99270519960720693, 
              c[ 3][ t]], 
            Times[ 1.3509192675942883, 
              c[ 4][ t]], 
            Times[ 0.99270519960720693, 
              c[ 5][ t]], 
            Times[ 0.9710122092317629, 
              c[ 6][ t]], 
            Times[ 0.93548928378863905, 
              c[ 7][ t]], 
            Times[ 0.88706379305918381, 
              c[ 8][ t]], 
            Times[ 0.82699334313268813, 
              c[ 9][ t]], 
            Times[ 0.75682672864065692, 
              c[ 10][ t]], 
            Times[ 0.67835603854706339, 
              c[ 11][ t]], 
            Times[ 0.59356153372868026, 
              c[ 12][ t]], 
            Times[ 0.50455115242710469, 
              c[ 13][ t]], 
            Times[ 0.41349667156634418, 
              c[ 14][ t]], 
            Times[ 0.32256865202152135, 
              c[ 15][ t]], 
            Times[ 0.23387232094715985, 
              c[ 16][ t]], 
            Times[ 0.14938649372796362, 
              c[ 17][ t]], 
            Times[ 0.070907514257657622, 
              c[ 18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ -0.062044074975450343, 
              c[ 20][ t]], 
            Times[ -0.11423673049785445, 
              c[ 21][ t]], 
            Times[ -0.15591488063143974, 
              c[ 22][ t]], 
            Times[ -0.18675027222298601, 
              c[ 23][ t]], 
            Times[ -0.206748335783172, 
              c[ 24][ t]], 
            Times[ -0.21623620818304481, 
              c[ 25][ t]], 
            Times[ -0.21584055771952015, 
              c[ 26][ t]], 
            Times[ -0.20645618564475843, 
              c[ 27][ t]], 
            Times[ -0.18920668216016434, 
              c[ 28][ t]], 
            Times[ -0.16539866862653771, 
              c[ 29][ t]], 
            Times[ -0.13647135277833605, 
              c[ 30][ t]], 
            Times[ -0.1039432537542934, 
              c[ 31][ t]], 
            Times[ -0.06935801494512607, 
              c[ 32][ t]], 
            Times[ -0.034231213779558949, 
              c[ 33][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 34][ t]], 
            Times[ 0.032022748374425904, 
              c[ 35][ t]], 
            Times[ 0.060688263076985105, 
              c[ 36][ t]], 
            Times[ 0.085044480344421608, 
              c[ 37][ t]], 
            Times[ 0.10436044624225685, 
              c[ 38][ t]], 
            Times[ 0.11814190616181255, 
              c[ 39][ t]], 
            Times[ 0.12613778810677612, 
              c[ 40][ t]], 
            Times[ 0.12833762891430925, 
              c[ 41][ t]], 
            Times[ 0.12496032289024853, 
              c[ 42][ t]], 
            Times[ 0.11643488132933186, 
              c[ 43][ t]], 
            Times[ 0.10337416789158609, 
              c[ 44][ t]], 
            Times[ 0.086542809078944752, 
              c[ 45][ t]], 
            Times[ 0.066820663127759972, 
              c[ 46][ t]], 
            Times[ 0.045163358568919301, 
              c[ 47][ t]], 
            Times[ 0.022561481809254675, 
              c[ 48][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 49][ t]], 
            Times[ -0.021580547817547879, 
              c[ 50][ t]], 
            Times[ -0.041319668477947373, 
              c[ 51][ t]], 
            Times[ -0.058468080236789913, 
              c[ 52][ t]], 
            Times[ -0.072413370861974122, 
              c[ 53][ t]], 
            Times[ -0.082699334313268813, 
              c[ 54][ t]], 
            Times[ -0.089038438663606695, 
              c[ 55][ t]], 
            Times[ -0.091317159035181589, 
              c[ 56][ t]], 
            Times[ -0.089594193770366842, 
              c[ 57][ t]], 
            Times[ -0.084091858737850814, 
              c[ 58][ t]], 
            Times[ -0.075181213012062598, 
              c[ 59][ t]], 
            Times[ -0.063361699504227403, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "5", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[5]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06361487254866832`\ \(c[\(-60\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-59\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-58\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-57\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-56\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-54\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-53\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-52\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-51\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-50\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-49\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-48\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-47\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-46\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-45\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-44\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-43\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-42\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-41\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-40\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-39\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-38\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-37\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-36\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-35\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-34\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-33\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-32\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-31\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-30\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-29\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-28\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-27\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-26\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-25\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-24\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-23\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-22\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-21\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-20\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-19\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-18\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-17\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-16\)]\)[t] - 
            0.206748335783172`\ \(c[\(-15\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-14\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-13\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-12\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-11\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-9\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-8\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-7\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-6\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-5\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-4\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-3\)]\)[t] + 
            0.6783560385470634`\ \(c[\(-2\)]\)[t] + 
            0.7568267286406569`\ \(c[\(-1\)]\)[t] + 
            0.8269933431326882`\ \(c[0]\)[t] + 
            0.8870637930591838`\ \(c[1]\)[t] + 
            0.9354892837886392`\ \(c[2]\)[t] + 
            0.9710122092317629`\ \(c[3]\)[t] + 
            0.9927051996072069`\ \(c[4]\)[t] + 
            1.5483113556160752`\ \(c[5]\)[t] + 
            0.9927051996072067`\ \(c[6]\)[t] + 
            0.9710122092317629`\ \(c[7]\)[t] + 
            0.9354892837886392`\ \(c[8]\)[t] + 
            0.8870637930591837`\ \(c[9]\)[t] + 
            0.8269933431326882`\ \(c[10]\)[t] + 
            0.756826728640657`\ \(c[11]\)[t] + 
            0.6783560385470633`\ \(c[12]\)[t] + 
            0.5935615337286805`\ \(c[13]\)[t] + 
            0.5045511524271047`\ \(c[14]\)[t] + 
            0.41349667156634395`\ \(c[15]\)[t] + 
            0.3225686520215216`\ \(c[16]\)[t] + 
            0.23387232094715985`\ \(c[17]\)[t] + 
            0.14938649372796345`\ \(c[18]\)[t] + 
            0.07090751425765777`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] - 
            0.062044074975450475`\ \(c[21]\)[t] - 
            0.11423673049785436`\ \(c[22]\)[t] - 
            0.15591488063143982`\ \(c[23]\)[t] - 
            0.18675027222298607`\ \(c[24]\)[t] - 
            0.206748335783172`\ \(c[25]\)[t] - 
            0.21623620818304484`\ \(c[26]\)[t] - 
            0.21584055771952013`\ \(c[27]\)[t] - 
            0.20645618564475843`\ \(c[28]\)[t] - 
            0.18920668216016426`\ \(c[29]\)[t] - 
            0.1653986686265376`\ \(c[30]\)[t] - 
            0.13647135277833605`\ \(c[31]\)[t] - 
            0.10394325375429328`\ \(c[32]\)[t] - 
            0.06935801494512592`\ \(c[33]\)[t] - 
            0.03423121377955895`\ \(c[34]\)[t] - 
            3.898171832519376`*^-17\ \(c[35]\)[t] + 
            0.03202274837442603`\ \(c[36]\)[t] + 
            0.060688263076985105`\ \(c[37]\)[t] + 
            0.0850444803444217`\ \(c[38]\)[t] + 
            0.10436044624225692`\ \(c[39]\)[t] + 
            0.11814190616181255`\ \(c[40]\)[t] + 
            0.12613778810677612`\ \(c[41]\)[t] + 
            0.12833762891430925`\ \(c[42]\)[t] + 
            0.12496032289024853`\ \(c[43]\)[t] + 
            0.11643488132933195`\ \(c[44]\)[t] + 
            0.10337416789158609`\ \(c[45]\)[t] + 
            0.08654280907894489`\ \(c[46]\)[t] + 
            0.06682066312776015`\ \(c[47]\)[t] + 
            0.0451633585689193`\ \(c[48]\)[t] + 
            0.02256148180925487`\ \(c[49]\)[t] + 
            2.274590327822911`*^-16\ \(c[50]\)[t] - 
            0.02158054781754788`\ \(c[51]\)[t] - 
            0.04131966847794722`\ \(c[52]\)[t] - 
            0.058468080236789774`\ \(c[53]\)[t] - 
            0.07241337086197412`\ \(c[54]\)[t] - 
            0.08269933431326874`\ \(c[55]\)[t] - 
            0.08903843866360665`\ \(c[56]\)[t] - 
            0.09131715903518159`\ \(c[57]\)[t] - 
            0.08959419377036688`\ \(c[58]\)[t] - 
            0.08409185873785086`\ \(c[59]\)[t] - 
            0.0751812130120626`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 5, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 5]][ t]], 
          Plus[ 
            Times[ 0.063614872548668322, 
              c[ -60][ t]], 
            Times[ 0.055441487066198933, 
              c[ -59][ t]], 
            Times[ 0.044547108751839919, 
              c[ -58][ t]], 
            Times[ 0.031322974491347202, 
              c[ -57][ t]], 
            Times[ 0.016273855731265604, 
              c[ -56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ -0.016825511857749262, 
              c[ -54][ t]], 
            Times[ -0.033483179628681567, 
              c[ -53][ t]], 
            Times[ -0.049236278094138941, 
              c[ -52][ t]], 
            Times[ -0.063361699504227403, 
              c[ -51][ t]], 
            Times[ -0.075181213012062598, 
              c[ -50][ t]], 
            Times[ -0.084091858737850814, 
              c[ -49][ t]], 
            Times[ -0.089594193770366842, 
              c[ -48][ t]], 
            Times[ -0.091317159035181589, 
              c[ -47][ t]], 
            Times[ -0.089038438663606695, 
              c[ -46][ t]], 
            Times[ -0.082699334313268813, 
              c[ -45][ t]], 
            Times[ -0.072413370861974122, 
              c[ -44][ t]], 
            Times[ -0.058468080236789913, 
              c[ -43][ t]], 
            Times[ -0.041319668477947373, 
              c[ -42][ t]], 
            Times[ -0.021580547817547879, 
              c[ -41][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -40][ t]], 
            Times[ 0.022561481809254675, 
              c[ -39][ t]], 
            Times[ 0.045163358568919301, 
              c[ -38][ t]], 
            Times[ 0.066820663127759972, 
              c[ -37][ t]], 
            Times[ 0.086542809078944752, 
              c[ -36][ t]], 
            Times[ 0.10337416789158609, 
              c[ -35][ t]], 
            Times[ 0.11643488132933186, 
              c[ -34][ t]], 
            Times[ 0.12496032289024853, 
              c[ -33][ t]], 
            Times[ 0.12833762891430928, 
              c[ -32][ t]], 
            Times[ 0.12613778810677612, 
              c[ -31][ t]], 
            Times[ 0.11814190616181255, 
              c[ -30][ t]], 
            Times[ 0.10436044624225685, 
              c[ -29][ t]], 
            Times[ 0.085044480344421608, 
              c[ -28][ t]], 
            Times[ 0.060688263076985105, 
              c[ -27][ t]], 
            Times[ 0.032022748374425904, 
              c[ -26][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -25][ t]], 
            Times[ -0.034231213779558949, 
              c[ -24][ t]], 
            Times[ -0.06935801494512607, 
              c[ -23][ t]], 
            Times[ -0.1039432537542934, 
              c[ -22][ t]], 
            Times[ -0.13647135277833605, 
              c[ -21][ t]], 
            Times[ -0.16539866862653771, 
              c[ -20][ t]], 
            Times[ -0.18920668216016426, 
              c[ -19][ t]], 
            Times[ -0.20645618564475843, 
              c[ -18][ t]], 
            Times[ -0.21584055771952015, 
              c[ -17][ t]], 
            Times[ -0.21623620818304484, 
              c[ -16][ t]], 
            Times[ -0.206748335783172, 
              c[ -15][ t]], 
            Times[ -0.18675027222298593, 
              c[ -14][ t]], 
            Times[ -0.15591488063143982, 
              c[ -13][ t]], 
            Times[ -0.11423673049785436, 
              c[ -12][ t]], 
            Times[ -0.062044074975450239, 
              c[ -11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ 0.070907514257657775, 
              c[ -9][ t]], 
            Times[ 0.14938649372796362, 
              c[ -8][ t]], 
            Times[ 0.23387232094715985, 
              c[ -7][ t]], 
            Times[ 0.32256865202152157, 
              c[ -6][ t]], 
            Times[ 0.41349667156634418, 
              c[ -5][ t]], 
            Times[ 0.50455115242710469, 
              c[ -4][ t]], 
            Times[ 0.59356153372868048, 
              c[ -3][ t]], 
            Times[ 0.67835603854706339, 
              c[ -2][ t]], 
            Times[ 0.75682672864065692, 
              c[ -1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 0][ t]], 
            Times[ 0.88706379305918381, 
              c[ 1][ t]], 
            Times[ 0.93548928378863916, 
              c[ 2][ t]], 
            Times[ 0.9710122092317629, 
              c[ 3][ t]], 
            Times[ 0.99270519960720693, 
              c[ 4][ t]], 
            Times[ 1.5483113556160752, 
              c[ 5][ t]], 
            Times[ 0.99270519960720671, 
              c[ 6][ t]], 
            Times[ 0.9710122092317629, 
              c[ 7][ t]], 
            Times[ 0.93548928378863916, 
              c[ 8][ t]], 
            Times[ 0.8870637930591837, 
              c[ 9][ t]], 
            Times[ 0.82699334313268824, 
              c[ 10][ t]], 
            Times[ 0.75682672864065703, 
              c[ 11][ t]], 
            Times[ 0.67835603854706328, 
              c[ 12][ t]], 
            Times[ 0.59356153372868048, 
              c[ 13][ t]], 
            Times[ 0.50455115242710469, 
              c[ 14][ t]], 
            Times[ 0.41349667156634395, 
              c[ 15][ t]], 
            Times[ 0.32256865202152157, 
              c[ 16][ t]], 
            Times[ 0.23387232094715985, 
              c[ 17][ t]], 
            Times[ 0.14938649372796345, 
              c[ 18][ t]], 
            Times[ 0.070907514257657775, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ -0.062044074975450475, 
              c[ 21][ t]], 
            Times[ -0.11423673049785436, 
              c[ 22][ t]], 
            Times[ -0.15591488063143982, 
              c[ 23][ t]], 
            Times[ -0.18675027222298607, 
              c[ 24][ t]], 
            Times[ -0.206748335783172, 
              c[ 25][ t]], 
            Times[ -0.21623620818304484, 
              c[ 26][ t]], 
            Times[ -0.21584055771952013, 
              c[ 27][ t]], 
            Times[ -0.20645618564475843, 
              c[ 28][ t]], 
            Times[ -0.18920668216016426, 
              c[ 29][ t]], 
            Times[ -0.1653986686265376, 
              c[ 30][ t]], 
            Times[ -0.13647135277833605, 
              c[ 31][ t]], 
            Times[ -0.10394325375429328, 
              c[ 32][ t]], 
            Times[ -0.069358014945125918, 
              c[ 33][ t]], 
            Times[ -0.034231213779558949, 
              c[ 34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ 0.032022748374426029, 
              c[ 36][ t]], 
            Times[ 0.060688263076985105, 
              c[ 37][ t]], 
            Times[ 0.085044480344421705, 
              c[ 38][ t]], 
            Times[ 0.10436044624225692, 
              c[ 39][ t]], 
            Times[ 0.11814190616181255, 
              c[ 40][ t]], 
            Times[ 0.12613778810677612, 
              c[ 41][ t]], 
            Times[ 0.12833762891430925, 
              c[ 42][ t]], 
            Times[ 0.12496032289024853, 
              c[ 43][ t]], 
            Times[ 0.11643488132933195, 
              c[ 44][ t]], 
            Times[ 0.10337416789158609, 
              c[ 45][ t]], 
            Times[ 0.086542809078944891, 
              c[ 46][ t]], 
            Times[ 0.066820663127760152, 
              c[ 47][ t]], 
            Times[ 0.045163358568919301, 
              c[ 48][ t]], 
            Times[ 0.022561481809254869, 
              c[ 49][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 50][ t]], 
            Times[ -0.021580547817547879, 
              c[ 51][ t]], 
            Times[ -0.04131966847794722, 
              c[ 52][ t]], 
            Times[ -0.058468080236789774, 
              c[ 53][ t]], 
            Times[ -0.072413370861974122, 
              c[ 54][ t]], 
            Times[ -0.082699334313268744, 
              c[ 55][ t]], 
            Times[ -0.089038438663606653, 
              c[ 56][ t]], 
            Times[ -0.091317159035181589, 
              c[ 57][ t]], 
            Times[ -0.089594193770366884, 
              c[ 58][ t]], 
            Times[ -0.084091858737850855, 
              c[ 59][ t]], 
            Times[ -0.075181213012062598, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "6", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[6]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06880242987642335`\ \(c[\(-60\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-59\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-58\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-57\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-56\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-55\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-53\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-52\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-51\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-50\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-49\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-48\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-47\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-46\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-45\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-44\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-43\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-42\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-41\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-40\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-39\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-38\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-37\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-36\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-35\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-34\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-33\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-32\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-31\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-30\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-29\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-28\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-27\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-26\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-23\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-22\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-21\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-20\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-19\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-18\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-17\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-16\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-15\)]\)[t] - 
            0.206748335783172`\ \(c[\(-14\)]\)[t] - 
            0.186750272222986`\ \(c[\(-13\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-12\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-11\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-10\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-8\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-7\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-6\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-5\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-4\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-3\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-2\)]\)[t] + 
            0.6783560385470633`\ \(c[\(-1\)]\)[t] + 
            0.7568267286406569`\ \(c[0]\)[t] + 
            0.8269933431326882`\ \(c[1]\)[t] + 
            0.8870637930591837`\ \(c[2]\)[t] + 
            0.9354892837886392`\ \(c[3]\)[t] + 
            0.9710122092317629`\ \(c[4]\)[t] + 
            0.9927051996072067`\ \(c[5]\)[t] + 
            1.7895683520871486`\ \(c[6]\)[t] + 
            0.9927051996072069`\ \(c[7]\)[t] + 
            0.9710122092317629`\ \(c[8]\)[t] + 
            0.9354892837886392`\ \(c[9]\)[t] + 
            0.8870637930591838`\ \(c[10]\)[t] + 
            0.8269933431326881`\ \(c[11]\)[t] + 
            0.7568267286406569`\ \(c[12]\)[t] + 
            0.6783560385470634`\ \(c[13]\)[t] + 
            0.5935615337286806`\ \(c[14]\)[t] + 
            0.5045511524271047`\ \(c[15]\)[t] + 
            0.4134966715663442`\ \(c[16]\)[t] + 
            0.3225686520215216`\ \(c[17]\)[t] + 
            0.23387232094715985`\ \(c[18]\)[t] + 
            0.14938649372796362`\ \(c[19]\)[t] + 
            0.07090751425765777`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.06204407497545024`\ \(c[22]\)[t] - 
            0.11423673049785436`\ \(c[23]\)[t] - 
            0.15591488063143982`\ \(c[24]\)[t] - 
            0.18675027222298593`\ \(c[25]\)[t] - 
            0.206748335783172`\ \(c[26]\)[t] - 
            0.21623620818304484`\ \(c[27]\)[t] - 
            0.21584055771952015`\ \(c[28]\)[t] - 
            0.20645618564475843`\ \(c[29]\)[t] - 
            0.18920668216016426`\ \(c[30]\)[t] - 
            0.1653986686265377`\ \(c[31]\)[t] - 
            0.13647135277833605`\ \(c[32]\)[t] - 
            0.10394325375429328`\ \(c[33]\)[t] - 
            0.06935801494512607`\ \(c[34]\)[t] - 
            0.03423121377955895`\ \(c[35]\)[t] - 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.032022748374425904`\ \(c[37]\)[t] + 
            0.060688263076985105`\ \(c[38]\)[t] + 
            0.0850444803444217`\ \(c[39]\)[t] + 
            0.10436044624225685`\ \(c[40]\)[t] + 
            0.11814190616181253`\ \(c[41]\)[t] + 
            0.12613778810677614`\ \(c[42]\)[t] + 
            0.12833762891430928`\ \(c[43]\)[t] + 
            0.12496032289024853`\ \(c[44]\)[t] + 
            0.11643488132933186`\ \(c[45]\)[t] + 
            0.10337416789158609`\ \(c[46]\)[t] + 
            0.08654280907894489`\ \(c[47]\)[t] + 
            0.06682066312775997`\ \(c[48]\)[t] + 
            0.0451633585689193`\ \(c[49]\)[t] + 
            0.02256148180925487`\ \(c[50]\)[t] + 
            3.8981718325193755`*^-17\ \(c[51]\)[t] - 
            0.02158054781754788`\ \(c[52]\)[t] - 
            0.04131966847794722`\ \(c[53]\)[t] - 
            0.05846808023678991`\ \(c[54]\)[t] - 
            0.07241337086197412`\ \(c[55]\)[t] - 
            0.08269933431326874`\ \(c[56]\)[t] - 
            0.0890384386636067`\ \(c[57]\)[t] - 
            0.09131715903518159`\ \(c[58]\)[t] - 
            0.08959419377036688`\ \(c[59]\)[t] - 
            0.08409185873785081`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 6, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 6]][ t]], 
          Plus[ 
            Times[ 0.068802429876423349, 
              c[ -60][ t]], 
            Times[ 0.063614872548668253, 
              c[ -59][ t]], 
            Times[ 0.055441487066198933, 
              c[ -58][ t]], 
            Times[ 0.044547108751839919, 
              c[ -57][ t]], 
            Times[ 0.031322974491347078, 
              c[ -56][ t]], 
            Times[ 0.016273855731265604, 
              c[ -55][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ -0.016825511857749401, 
              c[ -53][ t]], 
            Times[ -0.033483179628681567, 
              c[ -52][ t]], 
            Times[ -0.049236278094138941, 
              c[ -51][ t]], 
            Times[ -0.063361699504227528, 
              c[ -50][ t]], 
            Times[ -0.075181213012062598, 
              c[ -49][ t]], 
            Times[ -0.084091858737850814, 
              c[ -48][ t]], 
            Times[ -0.089594193770366884, 
              c[ -47][ t]], 
            Times[ -0.091317159035181589, 
              c[ -46][ t]], 
            Times[ -0.089038438663606695, 
              c[ -45][ t]], 
            Times[ -0.082699334313268744, 
              c[ -44][ t]], 
            Times[ -0.072413370861974122, 
              c[ -43][ t]], 
            Times[ -0.058468080236789913, 
              c[ -42][ t]], 
            Times[ -0.04131966847794722, 
              c[ -41][ t]], 
            Times[ -0.021580547817547879, 
              c[ -40][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -39][ t]], 
            Times[ 0.022561481809254869, 
              c[ -38][ t]], 
            Times[ 0.045163358568919301, 
              c[ -37][ t]], 
            Times[ 0.066820663127759972, 
              c[ -36][ t]], 
            Times[ 0.086542809078944891, 
              c[ -35][ t]], 
            Times[ 0.10337416789158609, 
              c[ -34][ t]], 
            Times[ 0.11643488132933186, 
              c[ -33][ t]], 
            Times[ 0.12496032289024853, 
              c[ -32][ t]], 
            Times[ 0.12833762891430928, 
              c[ -31][ t]], 
            Times[ 0.12613778810677614, 
              c[ -30][ t]], 
            Times[ 0.11814190616181255, 
              c[ -29][ t]], 
            Times[ 0.10436044624225685, 
              c[ -28][ t]], 
            Times[ 0.085044480344421705, 
              c[ -27][ t]], 
            Times[ 0.060688263076985105, 
              c[ -26][ t]], 
            Times[ 0.032022748374425904, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.034231213779558949, 
              c[ -23][ t]], 
            Times[ -0.06935801494512607, 
              c[ -22][ t]], 
            Times[ -0.10394325375429328, 
              c[ -21][ t]], 
            Times[ -0.13647135277833605, 
              c[ -20][ t]], 
            Times[ -0.16539866862653771, 
              c[ -19][ t]], 
            Times[ -0.18920668216016426, 
              c[ -18][ t]], 
            Times[ -0.20645618564475843, 
              c[ -17][ t]], 
            Times[ -0.21584055771952015, 
              c[ -16][ t]], 
            Times[ -0.21623620818304484, 
              c[ -15][ t]], 
            Times[ -0.206748335783172, 
              c[ -14][ t]], 
            Times[ -0.18675027222298601, 
              c[ -13][ t]], 
            Times[ -0.15591488063143982, 
              c[ -12][ t]], 
            Times[ -0.11423673049785436, 
              c[ -11][ t]], 
            Times[ -0.062044074975450343, 
              c[ -10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ 0.070907514257657775, 
              c[ -8][ t]], 
            Times[ 0.14938649372796362, 
              c[ -7][ t]], 
            Times[ 0.23387232094715985, 
              c[ -6][ t]], 
            Times[ 0.32256865202152157, 
              c[ -5][ t]], 
            Times[ 0.41349667156634418, 
              c[ -4][ t]], 
            Times[ 0.50455115242710469, 
              c[ -3][ t]], 
            Times[ 0.59356153372868048, 
              c[ -2][ t]], 
            Times[ 0.67835603854706328, 
              c[ -1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 0][ t]], 
            Times[ 0.82699334313268824, 
              c[ 1][ t]], 
            Times[ 0.8870637930591837, 
              c[ 2][ t]], 
            Times[ 0.93548928378863916, 
              c[ 3][ t]], 
            Times[ 0.9710122092317629, 
              c[ 4][ t]], 
            Times[ 0.99270519960720671, 
              c[ 5][ t]], 
            Times[ 1.7895683520871486, 
              c[ 6][ t]], 
            Times[ 0.99270519960720693, 
              c[ 7][ t]], 
            Times[ 0.9710122092317629, 
              c[ 8][ t]], 
            Times[ 0.93548928378863916, 
              c[ 9][ t]], 
            Times[ 0.88706379305918381, 
              c[ 10][ t]], 
            Times[ 0.82699334313268813, 
              c[ 11][ t]], 
            Times[ 0.75682672864065692, 
              c[ 12][ t]], 
            Times[ 0.67835603854706339, 
              c[ 13][ t]], 
            Times[ 0.59356153372868059, 
              c[ 14][ t]], 
            Times[ 0.50455115242710469, 
              c[ 15][ t]], 
            Times[ 0.41349667156634418, 
              c[ 16][ t]], 
            Times[ 0.32256865202152157, 
              c[ 17][ t]], 
            Times[ 0.23387232094715985, 
              c[ 18][ t]], 
            Times[ 0.14938649372796362, 
              c[ 19][ t]], 
            Times[ 0.070907514257657775, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.062044074975450239, 
              c[ 22][ t]], 
            Times[ -0.11423673049785436, 
              c[ 23][ t]], 
            Times[ -0.15591488063143982, 
              c[ 24][ t]], 
            Times[ -0.18675027222298593, 
              c[ 25][ t]], 
            Times[ -0.206748335783172, 
              c[ 26][ t]], 
            Times[ -0.21623620818304484, 
              c[ 27][ t]], 
            Times[ -0.21584055771952015, 
              c[ 28][ t]], 
            Times[ -0.20645618564475843, 
              c[ 29][ t]], 
            Times[ -0.18920668216016426, 
              c[ 30][ t]], 
            Times[ -0.16539866862653771, 
              c[ 31][ t]], 
            Times[ -0.13647135277833605, 
              c[ 32][ t]], 
            Times[ -0.10394325375429328, 
              c[ 33][ t]], 
            Times[ -0.06935801494512607, 
              c[ 34][ t]], 
            Times[ -0.034231213779558949, 
              c[ 35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.032022748374425904, 
              c[ 37][ t]], 
            Times[ 0.060688263076985105, 
              c[ 38][ t]], 
            Times[ 0.085044480344421705, 
              c[ 39][ t]], 
            Times[ 0.10436044624225685, 
              c[ 40][ t]], 
            Times[ 0.11814190616181253, 
              c[ 41][ t]], 
            Times[ 0.12613778810677614, 
              c[ 42][ t]], 
            Times[ 0.12833762891430928, 
              c[ 43][ t]], 
            Times[ 0.12496032289024853, 
              c[ 44][ t]], 
            Times[ 0.11643488132933186, 
              c[ 45][ t]], 
            Times[ 0.10337416789158609, 
              c[ 46][ t]], 
            Times[ 0.086542809078944891, 
              c[ 47][ t]], 
            Times[ 0.066820663127759972, 
              c[ 48][ t]], 
            Times[ 0.045163358568919301, 
              c[ 49][ t]], 
            Times[ 0.022561481809254869, 
              c[ 50][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 51][ t]], 
            Times[ -0.021580547817547879, 
              c[ 52][ t]], 
            Times[ -0.04131966847794722, 
              c[ 53][ t]], 
            Times[ -0.058468080236789913, 
              c[ 54][ t]], 
            Times[ -0.072413370861974122, 
              c[ 55][ t]], 
            Times[ -0.082699334313268744, 
              c[ 56][ t]], 
            Times[ -0.089038438663606695, 
              c[ 57][ t]], 
            Times[ -0.091317159035181589, 
              c[ 58][ t]], 
            Times[ -0.089594193770366884, 
              c[ 59][ t]], 
            Times[ -0.084091858737850814, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "7", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[7]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.07087301895267824`\ \(c[\(-60\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-59\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-58\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-57\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-56\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-55\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-54\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-53\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-52\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-51\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-50\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-49\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-48\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-47\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-46\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-45\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-44\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-43\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-42\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-41\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-40\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-39\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-38\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-37\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-36\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-35\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-34\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-33\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-32\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-31\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-30\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-29\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-28\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-27\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-26\)]\)[t] + 
            0.060688263076985`\ \(c[\(-25\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-24\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-22\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-21\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-20\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-19\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-18\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-17\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-16\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-15\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-14\)]\)[t] - 
            0.206748335783172`\ \(c[\(-13\)]\)[t] - 
            0.186750272222986`\ \(c[\(-12\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-11\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-10\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-9\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-7\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-6\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-5\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-4\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-3\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-2\)]\)[t] + 
            0.5935615337286805`\ \(c[\(-1\)]\)[t] + 
            0.6783560385470634`\ \(c[0]\)[t] + 
            0.756826728640657`\ \(c[1]\)[t] + 
            0.8269933431326882`\ \(c[2]\)[t] + 
            0.8870637930591838`\ \(c[3]\)[t] + 
            0.935489283788639`\ \(c[4]\)[t] + 
            0.9710122092317629`\ \(c[5]\)[t] + 
            0.9927051996072069`\ \(c[6]\)[t] + 
            2.0746902570075076`\ \(c[7]\)[t] + 
            0.9927051996072067`\ \(c[8]\)[t] + 
            0.9710122092317629`\ \(c[9]\)[t] + 
            0.9354892837886392`\ \(c[10]\)[t] + 
            0.8870637930591838`\ \(c[11]\)[t] + 
            0.8269933431326881`\ \(c[12]\)[t] + 
            0.7568267286406569`\ \(c[13]\)[t] + 
            0.6783560385470634`\ \(c[14]\)[t] + 
            0.5935615337286803`\ \(c[15]\)[t] + 
            0.5045511524271047`\ \(c[16]\)[t] + 
            0.4134966715663442`\ \(c[17]\)[t] + 
            0.32256865202152135`\ \(c[18]\)[t] + 
            0.23387232094715985`\ \(c[19]\)[t] + 
            0.14938649372796362`\ \(c[20]\)[t] + 
            0.07090751425765762`\ \(c[21]\)[t] + 
            1.8033970416801674`*^-16\ \(c[22]\)[t] - 
            0.06204407497545034`\ \(c[23]\)[t] - 
            0.11423673049785445`\ \(c[24]\)[t] - 
            0.15591488063143974`\ \(c[25]\)[t] - 
            0.186750272222986`\ \(c[26]\)[t] - 
            0.20674833578317206`\ \(c[27]\)[t] - 
            0.21623620818304484`\ \(c[28]\)[t] - 
            0.21584055771952015`\ \(c[29]\)[t] - 
            0.20645618564475834`\ \(c[30]\)[t] - 
            0.18920668216016426`\ \(c[31]\)[t] - 
            0.1653986686265377`\ \(c[32]\)[t] - 
            0.1364713527783359`\ \(c[33]\)[t] - 
            0.10394325375429328`\ \(c[34]\)[t] - 
            0.06935801494512607`\ \(c[35]\)[t] - 
            0.034231213779558796`\ \(c[36]\)[t] - 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.032022748374425904`\ \(c[38]\)[t] + 
            0.06068826307698522`\ \(c[39]\)[t] + 
            0.0850444803444217`\ \(c[40]\)[t] + 
            0.10436044624225685`\ \(c[41]\)[t] + 
            0.1181419061618126`\ \(c[42]\)[t] + 
            0.12613778810677614`\ \(c[43]\)[t] + 
            0.12833762891430928`\ \(c[44]\)[t] + 
            0.12496032289024847`\ \(c[45]\)[t] + 
            0.11643488132933186`\ \(c[46]\)[t] + 
            0.10337416789158609`\ \(c[47]\)[t] + 
            0.08654280907894475`\ \(c[48]\)[t] + 
            0.06682066312775997`\ \(c[49]\)[t] + 
            0.0451633585689193`\ \(c[50]\)[t] + 
            0.022561481809254675`\ \(c[51]\)[t] + 
            3.8981718325193755`*^-17\ \(c[52]\)[t] - 
            0.02158054781754788`\ \(c[53]\)[t] - 
            0.04131966847794737`\ \(c[54]\)[t] - 
            0.05846808023678991`\ \(c[55]\)[t] - 
            0.07241337086197412`\ \(c[56]\)[t] - 
            0.08269933431326881`\ \(c[57]\)[t] - 
            0.0890384386636067`\ \(c[58]\)[t] - 
            0.09131715903518159`\ \(c[59]\)[t] - 
            0.08959419377036684`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 7, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 7]][ t]], 
          Plus[ 
            Times[ 0.070873018952678238, 
              c[ -60][ t]], 
            Times[ 0.068802429876423321, 
              c[ -59][ t]], 
            Times[ 0.063614872548668253, 
              c[ -58][ t]], 
            Times[ 0.055441487066198933, 
              c[ -57][ t]], 
            Times[ 0.044547108751839815, 
              c[ -56][ t]], 
            Times[ 0.031322974491347078, 
              c[ -55][ t]], 
            Times[ 0.016273855731265604, 
              c[ -54][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -53][ t]], 
            Times[ -0.016825511857749401, 
              c[ -52][ t]], 
            Times[ -0.033483179628681567, 
              c[ -51][ t]], 
            Times[ -0.049236278094139066, 
              c[ -50][ t]], 
            Times[ -0.063361699504227528, 
              c[ -49][ t]], 
            Times[ -0.075181213012062598, 
              c[ -48][ t]], 
            Times[ -0.084091858737850855, 
              c[ -47][ t]], 
            Times[ -0.089594193770366884, 
              c[ -46][ t]], 
            Times[ -0.091317159035181589, 
              c[ -45][ t]], 
            Times[ -0.089038438663606653, 
              c[ -44][ t]], 
            Times[ -0.082699334313268744, 
              c[ -43][ t]], 
            Times[ -0.072413370861974122, 
              c[ -42][ t]], 
            Times[ -0.058468080236789774, 
              c[ -41][ t]], 
            Times[ -0.04131966847794722, 
              c[ -40][ t]], 
            Times[ -0.021580547817547879, 
              c[ -39][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -38][ t]], 
            Times[ 0.022561481809254869, 
              c[ -37][ t]], 
            Times[ 0.045163358568919301, 
              c[ -36][ t]], 
            Times[ 0.066820663127759972, 
              c[ -35][ t]], 
            Times[ 0.086542809078944891, 
              c[ -34][ t]], 
            Times[ 0.10337416789158609, 
              c[ -33][ t]], 
            Times[ 0.11643488132933186, 
              c[ -32][ t]], 
            Times[ 0.12496032289024853, 
              c[ -31][ t]], 
            Times[ 0.12833762891430928, 
              c[ -30][ t]], 
            Times[ 0.12613778810677614, 
              c[ -29][ t]], 
            Times[ 0.11814190616181253, 
              c[ -28][ t]], 
            Times[ 0.10436044624225685, 
              c[ -27][ t]], 
            Times[ 0.085044480344421705, 
              c[ -26][ t]], 
            Times[ 0.060688263076985001, 
              c[ -25][ t]], 
            Times[ 0.032022748374425904, 
              c[ -24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.034231213779559094, 
              c[ -22][ t]], 
            Times[ -0.06935801494512607, 
              c[ -21][ t]], 
            Times[ -0.10394325375429328, 
              c[ -20][ t]], 
            Times[ -0.13647135277833605, 
              c[ -19][ t]], 
            Times[ -0.16539866862653771, 
              c[ -18][ t]], 
            Times[ -0.18920668216016426, 
              c[ -17][ t]], 
            Times[ -0.20645618564475843, 
              c[ -16][ t]], 
            Times[ -0.21584055771952015, 
              c[ -15][ t]], 
            Times[ -0.21623620818304484, 
              c[ -14][ t]], 
            Times[ -0.206748335783172, 
              c[ -13][ t]], 
            Times[ -0.18675027222298601, 
              c[ -12][ t]], 
            Times[ -0.15591488063143974, 
              c[ -11][ t]], 
            Times[ -0.11423673049785436, 
              c[ -10][ t]], 
            Times[ -0.062044074975450343, 
              c[ -9][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ 0.070907514257657775, 
              c[ -7][ t]], 
            Times[ 0.14938649372796362, 
              c[ -6][ t]], 
            Times[ 0.23387232094715985, 
              c[ -5][ t]], 
            Times[ 0.32256865202152157, 
              c[ -4][ t]], 
            Times[ 0.41349667156634418, 
              c[ -3][ t]], 
            Times[ 0.50455115242710469, 
              c[ -2][ t]], 
            Times[ 0.59356153372868048, 
              c[ -1][ t]], 
            Times[ 0.67835603854706339, 
              c[ 0][ t]], 
            Times[ 0.75682672864065703, 
              c[ 1][ t]], 
            Times[ 0.82699334313268824, 
              c[ 2][ t]], 
            Times[ 0.88706379305918381, 
              c[ 3][ t]], 
            Times[ 0.93548928378863905, 
              c[ 4][ t]], 
            Times[ 0.9710122092317629, 
              c[ 5][ t]], 
            Times[ 0.99270519960720693, 
              c[ 6][ t]], 
            Times[ 2.0746902570075076, 
              c[ 7][ t]], 
            Times[ 0.99270519960720671, 
              c[ 8][ t]], 
            Times[ 0.9710122092317629, 
              c[ 9][ t]], 
            Times[ 0.93548928378863916, 
              c[ 10][ t]], 
            Times[ 0.88706379305918381, 
              c[ 11][ t]], 
            Times[ 0.82699334313268813, 
              c[ 12][ t]], 
            Times[ 0.75682672864065692, 
              c[ 13][ t]], 
            Times[ 0.67835603854706339, 
              c[ 14][ t]], 
            Times[ 0.59356153372868026, 
              c[ 15][ t]], 
            Times[ 0.50455115242710469, 
              c[ 16][ t]], 
            Times[ 0.41349667156634418, 
              c[ 17][ t]], 
            Times[ 0.32256865202152135, 
              c[ 18][ t]], 
            Times[ 0.23387232094715985, 
              c[ 19][ t]], 
            Times[ 0.14938649372796362, 
              c[ 20][ t]], 
            Times[ 0.070907514257657622, 
              c[ 21][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 22][ t]], 
            Times[ -0.062044074975450343, 
              c[ 23][ t]], 
            Times[ -0.11423673049785445, 
              c[ 24][ t]], 
            Times[ -0.15591488063143974, 
              c[ 25][ t]], 
            Times[ -0.18675027222298601, 
              c[ 26][ t]], 
            Times[ -0.20674833578317206, 
              c[ 27][ t]], 
            Times[ -0.21623620818304484, 
              c[ 28][ t]], 
            Times[ -0.21584055771952015, 
              c[ 29][ t]], 
            Times[ -0.20645618564475834, 
              c[ 30][ t]], 
            Times[ -0.18920668216016426, 
              c[ 31][ t]], 
            Times[ -0.16539866862653771, 
              c[ 32][ t]], 
            Times[ -0.13647135277833591, 
              c[ 33][ t]], 
            Times[ -0.10394325375429328, 
              c[ 34][ t]], 
            Times[ -0.06935801494512607, 
              c[ 35][ t]], 
            Times[ -0.034231213779558796, 
              c[ 36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.032022748374425904, 
              c[ 38][ t]], 
            Times[ 0.060688263076985223, 
              c[ 39][ t]], 
            Times[ 0.085044480344421705, 
              c[ 40][ t]], 
            Times[ 0.10436044624225685, 
              c[ 41][ t]], 
            Times[ 0.1181419061618126, 
              c[ 42][ t]], 
            Times[ 0.12613778810677614, 
              c[ 43][ t]], 
            Times[ 0.12833762891430928, 
              c[ 44][ t]], 
            Times[ 0.12496032289024847, 
              c[ 45][ t]], 
            Times[ 0.11643488132933186, 
              c[ 46][ t]], 
            Times[ 0.10337416789158609, 
              c[ 47][ t]], 
            Times[ 0.086542809078944752, 
              c[ 48][ t]], 
            Times[ 0.066820663127759972, 
              c[ 49][ t]], 
            Times[ 0.045163358568919301, 
              c[ 50][ t]], 
            Times[ 0.022561481809254675, 
              c[ 51][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 52][ t]], 
            Times[ -0.021580547817547879, 
              c[ 53][ t]], 
            Times[ -0.041319668477947373, 
              c[ 54][ t]], 
            Times[ -0.058468080236789913, 
              c[ 55][ t]], 
            Times[ -0.072413370861974122, 
              c[ 56][ t]], 
            Times[ -0.082699334313268813, 
              c[ 57][ t]], 
            Times[ -0.089038438663606695, 
              c[ 58][ t]], 
            Times[ -0.091317159035181589, 
              c[ 59][ t]], 
            Times[ -0.089594193770366842, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "8", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[8]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06983076867396239`\ \(c[\(-60\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-59\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-58\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-57\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-56\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-55\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-54\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-53\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-51\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-50\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-49\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-48\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-47\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-46\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-45\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-44\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-43\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-42\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-41\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-40\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-39\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-38\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-37\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-36\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-35\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-34\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-33\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-32\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-31\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-30\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-29\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-28\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-27\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-26\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-25\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-24\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-23\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-22\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-21\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-20\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-19\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-18\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-17\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-16\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-15\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-14\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-13\)]\)[t] - 
            0.206748335783172`\ \(c[\(-12\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-11\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-10\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-9\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-8\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-6\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-5\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-4\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-3\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-2\)]\)[t] + 
            0.5045511524271047`\ \(c[\(-1\)]\)[t] + 
            0.5935615337286805`\ \(c[0]\)[t] + 
            0.6783560385470634`\ \(c[1]\)[t] + 
            0.7568267286406569`\ \(c[2]\)[t] + 
            0.8269933431326882`\ \(c[3]\)[t] + 
            0.8870637930591838`\ \(c[4]\)[t] + 
            0.9354892837886392`\ \(c[5]\)[t] + 
            0.9710122092317629`\ \(c[6]\)[t] + 
            0.9927051996072067`\ \(c[7]\)[t] + 
            2.403677070377153`\ \(c[8]\)[t] + 
            0.9927051996072067`\ \(c[9]\)[t] + 
            0.9710122092317629`\ \(c[10]\)[t] + 
            0.9354892837886392`\ \(c[11]\)[t] + 
            0.8870637930591837`\ \(c[12]\)[t] + 
            0.8269933431326882`\ \(c[13]\)[t] + 
            0.756826728640657`\ \(c[14]\)[t] + 
            0.6783560385470633`\ \(c[15]\)[t] + 
            0.5935615337286805`\ \(c[16]\)[t] + 
            0.5045511524271047`\ \(c[17]\)[t] + 
            0.41349667156634395`\ \(c[18]\)[t] + 
            0.3225686520215216`\ \(c[19]\)[t] + 
            0.23387232094715985`\ \(c[20]\)[t] + 
            0.14938649372796345`\ \(c[21]\)[t] + 
            0.07090751425765777`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] - 
            0.062044074975450475`\ \(c[24]\)[t] - 
            0.11423673049785436`\ \(c[25]\)[t] - 
            0.15591488063143982`\ \(c[26]\)[t] - 
            0.18675027222298607`\ \(c[27]\)[t] - 
            0.206748335783172`\ \(c[28]\)[t] - 
            0.21623620818304484`\ \(c[29]\)[t] - 
            0.21584055771952013`\ \(c[30]\)[t] - 
            0.20645618564475843`\ \(c[31]\)[t] - 
            0.18920668216016426`\ \(c[32]\)[t] - 
            0.1653986686265376`\ \(c[33]\)[t] - 
            0.13647135277833605`\ \(c[34]\)[t] - 
            0.10394325375429328`\ \(c[35]\)[t] - 
            0.06935801494512592`\ \(c[36]\)[t] - 
            0.03423121377955895`\ \(c[37]\)[t] - 
            3.898171832519376`*^-17\ \(c[38]\)[t] + 
            0.03202274837442603`\ \(c[39]\)[t] + 
            0.060688263076985105`\ \(c[40]\)[t] + 
            0.08504448034442161`\ \(c[41]\)[t] + 
            0.10436044624225692`\ \(c[42]\)[t] + 
            0.11814190616181255`\ \(c[43]\)[t] + 
            0.12613778810677612`\ \(c[44]\)[t] + 
            0.12833762891430925`\ \(c[45]\)[t] + 
            0.12496032289024853`\ \(c[46]\)[t] + 
            0.11643488132933195`\ \(c[47]\)[t] + 
            0.10337416789158609`\ \(c[48]\)[t] + 
            0.08654280907894489`\ \(c[49]\)[t] + 
            0.06682066312776015`\ \(c[50]\)[t] + 
            0.0451633585689193`\ \(c[51]\)[t] + 
            0.02256148180925487`\ \(c[52]\)[t] + 
            2.274590327822911`*^-16\ \(c[53]\)[t] - 
            0.02158054781754788`\ \(c[54]\)[t] - 
            0.04131966847794722`\ \(c[55]\)[t] - 
            0.058468080236789774`\ \(c[56]\)[t] - 
            0.07241337086197412`\ \(c[57]\)[t] - 
            0.08269933431326874`\ \(c[58]\)[t] - 
            0.08903843866360665`\ \(c[59]\)[t] - 
            0.09131715903518159`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 8, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 8]][ t]], 
          Plus[ 
            Times[ 0.069830768673962387, 
              c[ -60][ t]], 
            Times[ 0.070873018952678238, 
              c[ -59][ t]], 
            Times[ 0.068802429876423349, 
              c[ -58][ t]], 
            Times[ 0.063614872548668322, 
              c[ -57][ t]], 
            Times[ 0.055441487066198933, 
              c[ -56][ t]], 
            Times[ 0.044547108751839919, 
              c[ -55][ t]], 
            Times[ 0.031322974491347202, 
              c[ -54][ t]], 
            Times[ 0.016273855731265604, 
              c[ -53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ -0.016825511857749262, 
              c[ -51][ t]], 
            Times[ -0.033483179628681567, 
              c[ -50][ t]], 
            Times[ -0.049236278094138941, 
              c[ -49][ t]], 
            Times[ -0.063361699504227403, 
              c[ -48][ t]], 
            Times[ -0.075181213012062598, 
              c[ -47][ t]], 
            Times[ -0.084091858737850814, 
              c[ -46][ t]], 
            Times[ -0.089594193770366842, 
              c[ -45][ t]], 
            Times[ -0.091317159035181589, 
              c[ -44][ t]], 
            Times[ -0.089038438663606695, 
              c[ -43][ t]], 
            Times[ -0.082699334313268813, 
              c[ -42][ t]], 
            Times[ -0.072413370861974122, 
              c[ -41][ t]], 
            Times[ -0.058468080236789913, 
              c[ -40][ t]], 
            Times[ -0.041319668477947373, 
              c[ -39][ t]], 
            Times[ -0.021580547817547879, 
              c[ -38][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -37][ t]], 
            Times[ 0.022561481809254675, 
              c[ -36][ t]], 
            Times[ 0.045163358568919301, 
              c[ -35][ t]], 
            Times[ 0.066820663127759972, 
              c[ -34][ t]], 
            Times[ 0.086542809078944752, 
              c[ -33][ t]], 
            Times[ 0.10337416789158609, 
              c[ -32][ t]], 
            Times[ 0.11643488132933186, 
              c[ -31][ t]], 
            Times[ 0.12496032289024853, 
              c[ -30][ t]], 
            Times[ 0.12833762891430928, 
              c[ -29][ t]], 
            Times[ 0.12613778810677612, 
              c[ -28][ t]], 
            Times[ 0.11814190616181255, 
              c[ -27][ t]], 
            Times[ 0.10436044624225685, 
              c[ -26][ t]], 
            Times[ 0.085044480344421608, 
              c[ -25][ t]], 
            Times[ 0.060688263076985105, 
              c[ -24][ t]], 
            Times[ 0.032022748374425904, 
              c[ -23][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -22][ t]], 
            Times[ -0.034231213779558949, 
              c[ -21][ t]], 
            Times[ -0.06935801494512607, 
              c[ -20][ t]], 
            Times[ -0.10394325375429328, 
              c[ -19][ t]], 
            Times[ -0.13647135277833605, 
              c[ -18][ t]], 
            Times[ -0.16539866862653771, 
              c[ -17][ t]], 
            Times[ -0.18920668216016426, 
              c[ -16][ t]], 
            Times[ -0.20645618564475843, 
              c[ -15][ t]], 
            Times[ -0.21584055771952015, 
              c[ -14][ t]], 
            Times[ -0.21623620818304484, 
              c[ -13][ t]], 
            Times[ -0.206748335783172, 
              c[ -12][ t]], 
            Times[ -0.18675027222298593, 
              c[ -11][ t]], 
            Times[ -0.15591488063143982, 
              c[ -10][ t]], 
            Times[ -0.11423673049785436, 
              c[ -9][ t]], 
            Times[ -0.062044074975450343, 
              c[ -8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ 0.070907514257657775, 
              c[ -6][ t]], 
            Times[ 0.14938649372796362, 
              c[ -5][ t]], 
            Times[ 0.23387232094715985, 
              c[ -4][ t]], 
            Times[ 0.32256865202152157, 
              c[ -3][ t]], 
            Times[ 0.41349667156634418, 
              c[ -2][ t]], 
            Times[ 0.50455115242710469, 
              c[ -1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 0][ t]], 
            Times[ 0.67835603854706339, 
              c[ 1][ t]], 
            Times[ 0.75682672864065692, 
              c[ 2][ t]], 
            Times[ 0.82699334313268824, 
              c[ 3][ t]], 
            Times[ 0.88706379305918381, 
              c[ 4][ t]], 
            Times[ 0.93548928378863916, 
              c[ 5][ t]], 
            Times[ 0.9710122092317629, 
              c[ 6][ t]], 
            Times[ 0.99270519960720671, 
              c[ 7][ t]], 
            Times[ 2.4036770703771531, 
              c[ 8][ t]], 
            Times[ 0.99270519960720671, 
              c[ 9][ t]], 
            Times[ 0.9710122092317629, 
              c[ 10][ t]], 
            Times[ 0.93548928378863916, 
              c[ 11][ t]], 
            Times[ 0.8870637930591837, 
              c[ 12][ t]], 
            Times[ 0.82699334313268824, 
              c[ 13][ t]], 
            Times[ 0.75682672864065703, 
              c[ 14][ t]], 
            Times[ 0.67835603854706328, 
              c[ 15][ t]], 
            Times[ 0.59356153372868048, 
              c[ 16][ t]], 
            Times[ 0.50455115242710469, 
              c[ 17][ t]], 
            Times[ 0.41349667156634395, 
              c[ 18][ t]], 
            Times[ 0.32256865202152157, 
              c[ 19][ t]], 
            Times[ 0.23387232094715985, 
              c[ 20][ t]], 
            Times[ 0.14938649372796345, 
              c[ 21][ t]], 
            Times[ 0.070907514257657775, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ -0.062044074975450475, 
              c[ 24][ t]], 
            Times[ -0.11423673049785436, 
              c[ 25][ t]], 
            Times[ -0.15591488063143982, 
              c[ 26][ t]], 
            Times[ -0.18675027222298607, 
              c[ 27][ t]], 
            Times[ -0.206748335783172, 
              c[ 28][ t]], 
            Times[ -0.21623620818304484, 
              c[ 29][ t]], 
            Times[ -0.21584055771952013, 
              c[ 30][ t]], 
            Times[ -0.20645618564475843, 
              c[ 31][ t]], 
            Times[ -0.18920668216016426, 
              c[ 32][ t]], 
            Times[ -0.1653986686265376, 
              c[ 33][ t]], 
            Times[ -0.13647135277833605, 
              c[ 34][ t]], 
            Times[ -0.10394325375429328, 
              c[ 35][ t]], 
            Times[ -0.069358014945125918, 
              c[ 36][ t]], 
            Times[ -0.034231213779558949, 
              c[ 37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ 0.032022748374426029, 
              c[ 39][ t]], 
            Times[ 0.060688263076985105, 
              c[ 40][ t]], 
            Times[ 0.085044480344421608, 
              c[ 41][ t]], 
            Times[ 0.10436044624225692, 
              c[ 42][ t]], 
            Times[ 0.11814190616181255, 
              c[ 43][ t]], 
            Times[ 0.12613778810677612, 
              c[ 44][ t]], 
            Times[ 0.12833762891430925, 
              c[ 45][ t]], 
            Times[ 0.12496032289024853, 
              c[ 46][ t]], 
            Times[ 0.11643488132933195, 
              c[ 47][ t]], 
            Times[ 0.10337416789158609, 
              c[ 48][ t]], 
            Times[ 0.086542809078944891, 
              c[ 49][ t]], 
            Times[ 0.066820663127760152, 
              c[ 50][ t]], 
            Times[ 0.045163358568919301, 
              c[ 51][ t]], 
            Times[ 0.022561481809254869, 
              c[ 52][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 53][ t]], 
            Times[ -0.021580547817547879, 
              c[ 54][ t]], 
            Times[ -0.04131966847794722, 
              c[ 55][ t]], 
            Times[ -0.058468080236789774, 
              c[ 56][ t]], 
            Times[ -0.072413370861974122, 
              c[ 57][ t]], 
            Times[ -0.082699334313268744, 
              c[ 58][ t]], 
            Times[ -0.089038438663606653, 
              c[ 59][ t]], 
            Times[ -0.091317159035181589, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "9", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[9]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.06581101988179627`\ \(c[\(-60\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-59\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-58\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-57\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-56\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-55\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-54\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-53\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-52\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-50\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-49\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-48\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-47\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-46\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-45\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-44\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-43\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-42\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-41\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-40\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-39\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-38\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-37\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-36\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-35\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-34\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-33\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-32\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-31\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-30\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-29\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-28\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-27\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-26\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-25\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-24\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-23\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-20\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-19\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-18\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-17\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-16\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-15\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-14\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-13\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-12\)]\)[t] - 
            0.206748335783172`\ \(c[\(-11\)]\)[t] - 
            0.186750272222986`\ \(c[\(-10\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-9\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-8\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-7\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-5\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-4\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-3\)]\)[t] + 
            0.32256865202152135`\ \(c[\(-2\)]\)[t] + 
            0.4134966715663442`\ \(c[\(-1\)]\)[t] + 
            0.5045511524271047`\ \(c[0]\)[t] + 
            0.5935615337286805`\ \(c[1]\)[t] + 
            0.6783560385470633`\ \(c[2]\)[t] + 
            0.7568267286406569`\ \(c[3]\)[t] + 
            0.8269933431326881`\ \(c[4]\)[t] + 
            0.8870637930591837`\ \(c[5]\)[t] + 
            0.9354892837886392`\ \(c[6]\)[t] + 
            0.9710122092317629`\ \(c[7]\)[t] + 
            0.9927051996072067`\ \(c[8]\)[t] + 
            2.7765287921960846`\ \(c[9]\)[t] + 
            0.9927051996072069`\ \(c[10]\)[t] + 
            0.9710122092317629`\ \(c[11]\)[t] + 
            0.9354892837886392`\ \(c[12]\)[t] + 
            0.8870637930591838`\ \(c[13]\)[t] + 
            0.8269933431326881`\ \(c[14]\)[t] + 
            0.7568267286406569`\ \(c[15]\)[t] + 
            0.6783560385470634`\ \(c[16]\)[t] + 
            0.5935615337286806`\ \(c[17]\)[t] + 
            0.5045511524271047`\ \(c[18]\)[t] + 
            0.4134966715663442`\ \(c[19]\)[t] + 
            0.3225686520215216`\ \(c[20]\)[t] + 
            0.23387232094715985`\ \(c[21]\)[t] + 
            0.14938649372796384`\ \(c[22]\)[t] + 
            0.07090751425765777`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.06204407497545024`\ \(c[25]\)[t] - 
            0.11423673049785436`\ \(c[26]\)[t] - 
            0.15591488063143982`\ \(c[27]\)[t] - 
            0.18675027222298593`\ \(c[28]\)[t] - 
            0.206748335783172`\ \(c[29]\)[t] - 
            0.21623620818304484`\ \(c[30]\)[t] - 
            0.21584055771952015`\ \(c[31]\)[t] - 
            0.20645618564475843`\ \(c[32]\)[t] - 
            0.18920668216016426`\ \(c[33]\)[t] - 
            0.1653986686265377`\ \(c[34]\)[t] - 
            0.13647135277833605`\ \(c[35]\)[t] - 
            0.10394325375429328`\ \(c[36]\)[t] - 
            0.06935801494512607`\ \(c[37]\)[t] - 
            0.03423121377955895`\ \(c[38]\)[t] - 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.032022748374425904`\ \(c[40]\)[t] + 
            0.060688263076985`\ \(c[41]\)[t] + 
            0.0850444803444217`\ \(c[42]\)[t] + 
            0.10436044624225685`\ \(c[43]\)[t] + 
            0.11814190616181253`\ \(c[44]\)[t] + 
            0.12613778810677614`\ \(c[45]\)[t] + 
            0.12833762891430928`\ \(c[46]\)[t] + 
            0.12496032289024853`\ \(c[47]\)[t] + 
            0.11643488132933186`\ \(c[48]\)[t] + 
            0.10337416789158609`\ \(c[49]\)[t] + 
            0.08654280907894489`\ \(c[50]\)[t] + 
            0.06682066312775997`\ \(c[51]\)[t] + 
            0.0451633585689193`\ \(c[52]\)[t] + 
            0.02256148180925487`\ \(c[53]\)[t] + 
            3.8981718325193755`*^-17\ \(c[54]\)[t] - 
            0.02158054781754788`\ \(c[55]\)[t] - 
            0.04131966847794722`\ \(c[56]\)[t] - 
            0.05846808023678991`\ \(c[57]\)[t] - 
            0.07241337086197412`\ \(c[58]\)[t] - 
            0.08269933431326874`\ \(c[59]\)[t] - 
            0.0890384386636067`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 9, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 9]][ t]], 
          Plus[ 
            Times[ 0.065811019881796273, 
              c[ -60][ t]], 
            Times[ 0.069830768673962415, 
              c[ -59][ t]], 
            Times[ 0.070873018952678238, 
              c[ -58][ t]], 
            Times[ 0.068802429876423349, 
              c[ -57][ t]], 
            Times[ 0.063614872548668253, 
              c[ -56][ t]], 
            Times[ 0.055441487066198933, 
              c[ -55][ t]], 
            Times[ 0.044547108751839919, 
              c[ -54][ t]], 
            Times[ 0.031322974491347078, 
              c[ -53][ t]], 
            Times[ 0.016273855731265604, 
              c[ -52][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ -0.016825511857749401, 
              c[ -50][ t]], 
            Times[ -0.033483179628681567, 
              c[ -49][ t]], 
            Times[ -0.049236278094138941, 
              c[ -48][ t]], 
            Times[ -0.063361699504227528, 
              c[ -47][ t]], 
            Times[ -0.075181213012062598, 
              c[ -46][ t]], 
            Times[ -0.084091858737850814, 
              c[ -45][ t]], 
            Times[ -0.089594193770366884, 
              c[ -44][ t]], 
            Times[ -0.091317159035181589, 
              c[ -43][ t]], 
            Times[ -0.089038438663606695, 
              c[ -42][ t]], 
            Times[ -0.082699334313268744, 
              c[ -41][ t]], 
            Times[ -0.072413370861974122, 
              c[ -40][ t]], 
            Times[ -0.058468080236789913, 
              c[ -39][ t]], 
            Times[ -0.04131966847794722, 
              c[ -38][ t]], 
            Times[ -0.021580547817547879, 
              c[ -37][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -36][ t]], 
            Times[ 0.022561481809254869, 
              c[ -35][ t]], 
            Times[ 0.045163358568919301, 
              c[ -34][ t]], 
            Times[ 0.066820663127759972, 
              c[ -33][ t]], 
            Times[ 0.086542809078944891, 
              c[ -32][ t]], 
            Times[ 0.10337416789158609, 
              c[ -31][ t]], 
            Times[ 0.11643488132933186, 
              c[ -30][ t]], 
            Times[ 0.12496032289024853, 
              c[ -29][ t]], 
            Times[ 0.12833762891430928, 
              c[ -28][ t]], 
            Times[ 0.12613778810677614, 
              c[ -27][ t]], 
            Times[ 0.11814190616181255, 
              c[ -26][ t]], 
            Times[ 0.10436044624225685, 
              c[ -25][ t]], 
            Times[ 0.085044480344421705, 
              c[ -24][ t]], 
            Times[ 0.060688263076985105, 
              c[ -23][ t]], 
            Times[ 0.032022748374425904, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.034231213779558949, 
              c[ -20][ t]], 
            Times[ -0.06935801494512607, 
              c[ -19][ t]], 
            Times[ -0.10394325375429328, 
              c[ -18][ t]], 
            Times[ -0.13647135277833605, 
              c[ -17][ t]], 
            Times[ -0.16539866862653771, 
              c[ -16][ t]], 
            Times[ -0.18920668216016426, 
              c[ -15][ t]], 
            Times[ -0.20645618564475843, 
              c[ -14][ t]], 
            Times[ -0.21584055771952015, 
              c[ -13][ t]], 
            Times[ -0.21623620818304484, 
              c[ -12][ t]], 
            Times[ -0.206748335783172, 
              c[ -11][ t]], 
            Times[ -0.18675027222298601, 
              c[ -10][ t]], 
            Times[ -0.15591488063143982, 
              c[ -9][ t]], 
            Times[ -0.11423673049785436, 
              c[ -8][ t]], 
            Times[ -0.062044074975450343, 
              c[ -7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ 0.070907514257657775, 
              c[ -5][ t]], 
            Times[ 0.14938649372796362, 
              c[ -4][ t]], 
            Times[ 0.23387232094715985, 
              c[ -3][ t]], 
            Times[ 0.32256865202152135, 
              c[ -2][ t]], 
            Times[ 0.41349667156634418, 
              c[ -1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 0][ t]], 
            Times[ 0.59356153372868048, 
              c[ 1][ t]], 
            Times[ 0.67835603854706328, 
              c[ 2][ t]], 
            Times[ 0.75682672864065692, 
              c[ 3][ t]], 
            Times[ 0.82699334313268813, 
              c[ 4][ t]], 
            Times[ 0.8870637930591837, 
              c[ 5][ t]], 
            Times[ 0.93548928378863916, 
              c[ 6][ t]], 
            Times[ 0.9710122092317629, 
              c[ 7][ t]], 
            Times[ 0.99270519960720671, 
              c[ 8][ t]], 
            Times[ 2.7765287921960846, 
              c[ 9][ t]], 
            Times[ 0.99270519960720693, 
              c[ 10][ t]], 
            Times[ 0.9710122092317629, 
              c[ 11][ t]], 
            Times[ 0.93548928378863916, 
              c[ 12][ t]], 
            Times[ 0.88706379305918381, 
              c[ 13][ t]], 
            Times[ 0.82699334313268813, 
              c[ 14][ t]], 
            Times[ 0.75682672864065692, 
              c[ 15][ t]], 
            Times[ 0.67835603854706339, 
              c[ 16][ t]], 
            Times[ 0.59356153372868059, 
              c[ 17][ t]], 
            Times[ 0.50455115242710469, 
              c[ 18][ t]], 
            Times[ 0.41349667156634418, 
              c[ 19][ t]], 
            Times[ 0.32256865202152157, 
              c[ 20][ t]], 
            Times[ 0.23387232094715985, 
              c[ 21][ t]], 
            Times[ 0.14938649372796384, 
              c[ 22][ t]], 
            Times[ 0.070907514257657775, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.062044074975450239, 
              c[ 25][ t]], 
            Times[ -0.11423673049785436, 
              c[ 26][ t]], 
            Times[ -0.15591488063143982, 
              c[ 27][ t]], 
            Times[ -0.18675027222298593, 
              c[ 28][ t]], 
            Times[ -0.206748335783172, 
              c[ 29][ t]], 
            Times[ -0.21623620818304484, 
              c[ 30][ t]], 
            Times[ -0.21584055771952015, 
              c[ 31][ t]], 
            Times[ -0.20645618564475843, 
              c[ 32][ t]], 
            Times[ -0.18920668216016426, 
              c[ 33][ t]], 
            Times[ -0.16539866862653771, 
              c[ 34][ t]], 
            Times[ -0.13647135277833605, 
              c[ 35][ t]], 
            Times[ -0.10394325375429328, 
              c[ 36][ t]], 
            Times[ -0.06935801494512607, 
              c[ 37][ t]], 
            Times[ -0.034231213779558949, 
              c[ 38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.032022748374425904, 
              c[ 40][ t]], 
            Times[ 0.060688263076985001, 
              c[ 41][ t]], 
            Times[ 0.085044480344421705, 
              c[ 42][ t]], 
            Times[ 0.10436044624225685, 
              c[ 43][ t]], 
            Times[ 0.11814190616181253, 
              c[ 44][ t]], 
            Times[ 0.12613778810677614, 
              c[ 45][ t]], 
            Times[ 0.12833762891430928, 
              c[ 46][ t]], 
            Times[ 0.12496032289024853, 
              c[ 47][ t]], 
            Times[ 0.11643488132933186, 
              c[ 48][ t]], 
            Times[ 0.10337416789158609, 
              c[ 49][ t]], 
            Times[ 0.086542809078944891, 
              c[ 50][ t]], 
            Times[ 0.066820663127759972, 
              c[ 51][ t]], 
            Times[ 0.045163358568919301, 
              c[ 52][ t]], 
            Times[ 0.022561481809254869, 
              c[ 53][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 54][ t]], 
            Times[ -0.021580547817547879, 
              c[ 55][ t]], 
            Times[ -0.04131966847794722, 
              c[ 56][ t]], 
            Times[ -0.058468080236789913, 
              c[ 57][ t]], 
            Times[ -0.072413370861974122, 
              c[ 58][ t]], 
            Times[ -0.082699334313268744, 
              c[ 59][ t]], 
            Times[ -0.089038438663606695, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "10", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[10]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.059070953080906326`\ \(c[\(-60\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-59\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-58\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-57\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-56\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-55\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-54\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-53\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-52\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-51\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-50\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-49\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-48\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-47\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-46\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-45\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-44\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-43\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-42\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-41\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-40\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-39\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-38\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-37\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-36\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-35\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-34\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-33\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-32\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-31\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-30\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-29\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-28\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-27\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-26\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-25\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-24\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-23\)]\)[t] + 
            0.060688263076985`\ \(c[\(-22\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-21\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-19\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-18\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-17\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-16\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-15\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-14\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-13\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-12\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-11\)]\)[t] - 
            0.206748335783172`\ \(c[\(-10\)]\)[t] - 
            0.186750272222986`\ \(c[\(-9\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-8\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-7\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-6\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-4\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-3\)]\)[t] + 
            0.23387232094715985`\ \(c[\(-2\)]\)[t] + 
            0.3225686520215216`\ \(c[\(-1\)]\)[t] + 
            0.4134966715663442`\ \(c[0]\)[t] + 
            0.5045511524271047`\ \(c[1]\)[t] + 
            0.5935615337286805`\ \(c[2]\)[t] + 
            0.6783560385470634`\ \(c[3]\)[t] + 
            0.7568267286406569`\ \(c[4]\)[t] + 
            0.8269933431326882`\ \(c[5]\)[t] + 
            0.8870637930591838`\ \(c[6]\)[t] + 
            0.9354892837886392`\ \(c[7]\)[t] + 
            0.9710122092317629`\ \(c[8]\)[t] + 
            0.9927051996072069`\ \(c[9]\)[t] + 
            3.1932454224643014`\ \(c[10]\)[t] + 
            0.9927051996072069`\ \(c[11]\)[t] + 
            0.9710122092317629`\ \(c[12]\)[t] + 
            0.9354892837886392`\ \(c[13]\)[t] + 
            0.8870637930591838`\ \(c[14]\)[t] + 
            0.8269933431326881`\ \(c[15]\)[t] + 
            0.7568267286406569`\ \(c[16]\)[t] + 
            0.6783560385470634`\ \(c[17]\)[t] + 
            0.5935615337286803`\ \(c[18]\)[t] + 
            0.5045511524271047`\ \(c[19]\)[t] + 
            0.4134966715663442`\ \(c[20]\)[t] + 
            0.32256865202152135`\ \(c[21]\)[t] + 
            0.23387232094715998`\ \(c[22]\)[t] + 
            0.14938649372796362`\ \(c[23]\)[t] + 
            0.07090751425765762`\ \(c[24]\)[t] + 
            1.8033970416801674`*^-16\ \(c[25]\)[t] - 
            0.06204407497545034`\ \(c[26]\)[t] - 
            0.11423673049785445`\ \(c[27]\)[t] - 
            0.15591488063143974`\ \(c[28]\)[t] - 
            0.186750272222986`\ \(c[29]\)[t] - 
            0.20674833578317206`\ \(c[30]\)[t] - 
            0.21623620818304484`\ \(c[31]\)[t] - 
            0.21584055771952015`\ \(c[32]\)[t] - 
            0.20645618564475834`\ \(c[33]\)[t] - 
            0.18920668216016426`\ \(c[34]\)[t] - 
            0.1653986686265377`\ \(c[35]\)[t] - 
            0.1364713527783359`\ \(c[36]\)[t] - 
            0.10394325375429328`\ \(c[37]\)[t] - 
            0.06935801494512607`\ \(c[38]\)[t] - 
            0.034231213779558796`\ \(c[39]\)[t] - 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.032022748374425904`\ \(c[41]\)[t] + 
            0.06068826307698522`\ \(c[42]\)[t] + 
            0.0850444803444217`\ \(c[43]\)[t] + 
            0.10436044624225685`\ \(c[44]\)[t] + 
            0.1181419061618126`\ \(c[45]\)[t] + 
            0.12613778810677614`\ \(c[46]\)[t] + 
            0.12833762891430928`\ \(c[47]\)[t] + 
            0.12496032289024847`\ \(c[48]\)[t] + 
            0.11643488132933186`\ \(c[49]\)[t] + 
            0.10337416789158609`\ \(c[50]\)[t] + 
            0.08654280907894475`\ \(c[51]\)[t] + 
            0.06682066312775997`\ \(c[52]\)[t] + 
            0.0451633585689193`\ \(c[53]\)[t] + 
            0.022561481809254675`\ \(c[54]\)[t] + 
            3.8981718325193755`*^-17\ \(c[55]\)[t] - 
            0.02158054781754788`\ \(c[56]\)[t] - 
            0.04131966847794737`\ \(c[57]\)[t] - 
            0.05846808023678991`\ \(c[58]\)[t] - 
            0.07241337086197412`\ \(c[59]\)[t] - 
            0.08269933431326881`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 10, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 10]][ t]], 
          Plus[ 
            Times[ 0.059070953080906326, 
              c[ -60][ t]], 
            Times[ 0.065811019881796315, 
              c[ -59][ t]], 
            Times[ 0.069830768673962415, 
              c[ -58][ t]], 
            Times[ 0.070873018952678238, 
              c[ -57][ t]], 
            Times[ 0.068802429876423321, 
              c[ -56][ t]], 
            Times[ 0.063614872548668253, 
              c[ -55][ t]], 
            Times[ 0.055441487066198933, 
              c[ -54][ t]], 
            Times[ 0.044547108751839815, 
              c[ -53][ t]], 
            Times[ 0.031322974491347078, 
              c[ -52][ t]], 
            Times[ 0.016273855731265604, 
              c[ -51][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -50][ t]], 
            Times[ -0.016825511857749401, 
              c[ -49][ t]], 
            Times[ -0.033483179628681567, 
              c[ -48][ t]], 
            Times[ -0.049236278094139066, 
              c[ -47][ t]], 
            Times[ -0.063361699504227528, 
              c[ -46][ t]], 
            Times[ -0.075181213012062598, 
              c[ -45][ t]], 
            Times[ -0.084091858737850855, 
              c[ -44][ t]], 
            Times[ -0.089594193770366884, 
              c[ -43][ t]], 
            Times[ -0.091317159035181589, 
              c[ -42][ t]], 
            Times[ -0.089038438663606653, 
              c[ -41][ t]], 
            Times[ -0.082699334313268744, 
              c[ -40][ t]], 
            Times[ -0.072413370861974122, 
              c[ -39][ t]], 
            Times[ -0.058468080236789913, 
              c[ -38][ t]], 
            Times[ -0.04131966847794722, 
              c[ -37][ t]], 
            Times[ -0.021580547817547879, 
              c[ -36][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -35][ t]], 
            Times[ 0.022561481809254869, 
              c[ -34][ t]], 
            Times[ 0.045163358568919301, 
              c[ -33][ t]], 
            Times[ 0.066820663127759972, 
              c[ -32][ t]], 
            Times[ 0.086542809078944891, 
              c[ -31][ t]], 
            Times[ 0.10337416789158609, 
              c[ -30][ t]], 
            Times[ 0.11643488132933186, 
              c[ -29][ t]], 
            Times[ 0.12496032289024853, 
              c[ -28][ t]], 
            Times[ 0.12833762891430928, 
              c[ -27][ t]], 
            Times[ 0.12613778810677614, 
              c[ -26][ t]], 
            Times[ 0.11814190616181253, 
              c[ -25][ t]], 
            Times[ 0.10436044624225685, 
              c[ -24][ t]], 
            Times[ 0.085044480344421705, 
              c[ -23][ t]], 
            Times[ 0.060688263076985001, 
              c[ -22][ t]], 
            Times[ 0.032022748374425904, 
              c[ -21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.034231213779558949, 
              c[ -19][ t]], 
            Times[ -0.06935801494512607, 
              c[ -18][ t]], 
            Times[ -0.10394325375429328, 
              c[ -17][ t]], 
            Times[ -0.13647135277833605, 
              c[ -16][ t]], 
            Times[ -0.16539866862653771, 
              c[ -15][ t]], 
            Times[ -0.18920668216016426, 
              c[ -14][ t]], 
            Times[ -0.20645618564475843, 
              c[ -13][ t]], 
            Times[ -0.21584055771952015, 
              c[ -12][ t]], 
            Times[ -0.21623620818304484, 
              c[ -11][ t]], 
            Times[ -0.206748335783172, 
              c[ -10][ t]], 
            Times[ -0.18675027222298601, 
              c[ -9][ t]], 
            Times[ -0.15591488063143982, 
              c[ -8][ t]], 
            Times[ -0.11423673049785436, 
              c[ -7][ t]], 
            Times[ -0.062044074975450343, 
              c[ -6][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ 0.070907514257657775, 
              c[ -4][ t]], 
            Times[ 0.14938649372796362, 
              c[ -3][ t]], 
            Times[ 0.23387232094715985, 
              c[ -2][ t]], 
            Times[ 0.32256865202152157, 
              c[ -1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 0][ t]], 
            Times[ 0.50455115242710469, 
              c[ 1][ t]], 
            Times[ 0.59356153372868048, 
              c[ 2][ t]], 
            Times[ 0.67835603854706339, 
              c[ 3][ t]], 
            Times[ 0.75682672864065692, 
              c[ 4][ t]], 
            Times[ 0.82699334313268824, 
              c[ 5][ t]], 
            Times[ 0.88706379305918381, 
              c[ 6][ t]], 
            Times[ 0.93548928378863916, 
              c[ 7][ t]], 
            Times[ 0.9710122092317629, 
              c[ 8][ t]], 
            Times[ 0.99270519960720693, 
              c[ 9][ t]], 
            Times[ 3.1932454224643014, 
              c[ 10][ t]], 
            Times[ 0.99270519960720693, 
              c[ 11][ t]], 
            Times[ 0.9710122092317629, 
              c[ 12][ t]], 
            Times[ 0.93548928378863916, 
              c[ 13][ t]], 
            Times[ 0.88706379305918381, 
              c[ 14][ t]], 
            Times[ 0.82699334313268813, 
              c[ 15][ t]], 
            Times[ 0.75682672864065692, 
              c[ 16][ t]], 
            Times[ 0.67835603854706339, 
              c[ 17][ t]], 
            Times[ 0.59356153372868026, 
              c[ 18][ t]], 
            Times[ 0.50455115242710469, 
              c[ 19][ t]], 
            Times[ 0.41349667156634418, 
              c[ 20][ t]], 
            Times[ 0.32256865202152135, 
              c[ 21][ t]], 
            Times[ 0.23387232094715998, 
              c[ 22][ t]], 
            Times[ 0.14938649372796362, 
              c[ 23][ t]], 
            Times[ 0.070907514257657622, 
              c[ 24][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 25][ t]], 
            Times[ -0.062044074975450343, 
              c[ 26][ t]], 
            Times[ -0.11423673049785445, 
              c[ 27][ t]], 
            Times[ -0.15591488063143974, 
              c[ 28][ t]], 
            Times[ -0.18675027222298601, 
              c[ 29][ t]], 
            Times[ -0.20674833578317206, 
              c[ 30][ t]], 
            Times[ -0.21623620818304484, 
              c[ 31][ t]], 
            Times[ -0.21584055771952015, 
              c[ 32][ t]], 
            Times[ -0.20645618564475834, 
              c[ 33][ t]], 
            Times[ -0.18920668216016426, 
              c[ 34][ t]], 
            Times[ -0.16539866862653771, 
              c[ 35][ t]], 
            Times[ -0.13647135277833591, 
              c[ 36][ t]], 
            Times[ -0.10394325375429328, 
              c[ 37][ t]], 
            Times[ -0.06935801494512607, 
              c[ 38][ t]], 
            Times[ -0.034231213779558796, 
              c[ 39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.032022748374425904, 
              c[ 41][ t]], 
            Times[ 0.060688263076985223, 
              c[ 42][ t]], 
            Times[ 0.085044480344421705, 
              c[ 43][ t]], 
            Times[ 0.10436044624225685, 
              c[ 44][ t]], 
            Times[ 0.1181419061618126, 
              c[ 45][ t]], 
            Times[ 0.12613778810677614, 
              c[ 46][ t]], 
            Times[ 0.12833762891430928, 
              c[ 47][ t]], 
            Times[ 0.12496032289024847, 
              c[ 48][ t]], 
            Times[ 0.11643488132933186, 
              c[ 49][ t]], 
            Times[ 0.10337416789158609, 
              c[ 50][ t]], 
            Times[ 0.086542809078944752, 
              c[ 51][ t]], 
            Times[ 0.066820663127759972, 
              c[ 52][ t]], 
            Times[ 0.045163358568919301, 
              c[ 53][ t]], 
            Times[ 0.022561481809254675, 
              c[ 54][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 55][ t]], 
            Times[ -0.021580547817547879, 
              c[ 56][ t]], 
            Times[ -0.041319668477947373, 
              c[ 57][ t]], 
            Times[ -0.058468080236789913, 
              c[ 58][ t]], 
            Times[ -0.072413370861974122, 
              c[ 59][ t]], 
            Times[ -0.082699334313268813, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "11", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[11]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.049975424961080865`\ \(c[\(-60\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-59\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-58\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-57\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-56\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-55\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-54\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-53\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-52\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-51\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-50\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-48\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-47\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-46\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-45\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-44\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-43\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-42\)]\)[t] - 
            0.0913171590351816`\ \(c[\(-41\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-40\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-39\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-38\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-37\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-36\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-35\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-34\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-33\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-32\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-31\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-30\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-29\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-28\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-27\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-26\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-25\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-24\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-23\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-22\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-21\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-20\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-19\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-18\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-17\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-16\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-15\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-14\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-13\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-12\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-11\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-10\)]\)[t] - 
            0.206748335783172`\ \(c[\(-9\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-8\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-7\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-6\)]\)[t] - 
            0.06204407497545024`\ \(c[\(-5\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-3\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-2\)]\)[t] + 
            0.23387232094715998`\ \(c[\(-1\)]\)[t] + 
            0.3225686520215216`\ \(c[0]\)[t] + 
            0.4134966715663442`\ \(c[1]\)[t] + 
            0.5045511524271047`\ \(c[2]\)[t] + 
            0.5935615337286806`\ \(c[3]\)[t] + 
            0.6783560385470634`\ \(c[4]\)[t] + 
            0.756826728640657`\ \(c[5]\)[t] + 
            0.8269933431326881`\ \(c[6]\)[t] + 
            0.8870637930591838`\ \(c[7]\)[t] + 
            0.9354892837886392`\ \(c[8]\)[t] + 
            0.9710122092317629`\ \(c[9]\)[t] + 
            0.9927051996072069`\ \(c[10]\)[t] + 
            3.6538269611818044`\ \(c[11]\)[t] + 
            0.9927051996072067`\ \(c[12]\)[t] + 
            0.9710122092317629`\ \(c[13]\)[t] + 
            0.9354892837886392`\ \(c[14]\)[t] + 
            0.8870637930591838`\ \(c[15]\)[t] + 
            0.8269933431326881`\ \(c[16]\)[t] + 
            0.7568267286406569`\ \(c[17]\)[t] + 
            0.6783560385470632`\ \(c[18]\)[t] + 
            0.5935615337286803`\ \(c[19]\)[t] + 
            0.5045511524271047`\ \(c[20]\)[t] + 
            0.41349667156634395`\ \(c[21]\)[t] + 
            0.3225686520215216`\ \(c[22]\)[t] + 
            0.23387232094715985`\ \(c[23]\)[t] + 
            0.14938649372796345`\ \(c[24]\)[t] + 
            0.07090751425765777`\ \(c[25]\)[t] + 
            3.898171832519376`*^-17\ \(c[26]\)[t] - 
            0.062044074975450475`\ \(c[27]\)[t] - 
            0.11423673049785436`\ \(c[28]\)[t] - 
            0.15591488063143982`\ \(c[29]\)[t] - 
            0.18675027222298607`\ \(c[30]\)[t] - 
            0.206748335783172`\ \(c[31]\)[t] - 
            0.21623620818304484`\ \(c[32]\)[t] - 
            0.21584055771952013`\ \(c[33]\)[t] - 
            0.20645618564475843`\ \(c[34]\)[t] - 
            0.18920668216016426`\ \(c[35]\)[t] - 
            0.1653986686265376`\ \(c[36]\)[t] - 
            0.13647135277833605`\ \(c[37]\)[t] - 
            0.10394325375429328`\ \(c[38]\)[t] - 
            0.06935801494512592`\ \(c[39]\)[t] - 
            0.03423121377955895`\ \(c[40]\)[t] - 
            1.8033970416801674`*^-16\ \(c[41]\)[t] + 
            0.03202274837442603`\ \(c[42]\)[t] + 
            0.060688263076985105`\ \(c[43]\)[t] + 
            0.08504448034442161`\ \(c[44]\)[t] + 
            0.10436044624225692`\ \(c[45]\)[t] + 
            0.11814190616181255`\ \(c[46]\)[t] + 
            0.12613778810677612`\ \(c[47]\)[t] + 
            0.12833762891430925`\ \(c[48]\)[t] + 
            0.12496032289024853`\ \(c[49]\)[t] + 
            0.11643488132933186`\ \(c[50]\)[t] + 
            0.10337416789158595`\ \(c[51]\)[t] + 
            0.08654280907894489`\ \(c[52]\)[t] + 
            0.06682066312775997`\ \(c[53]\)[t] + 
            0.045163358568919114`\ \(c[54]\)[t] + 
            0.02256148180925487`\ \(c[55]\)[t] + 
            3.8981718325193755`*^-17\ \(c[56]\)[t] - 
            0.021580547817548056`\ \(c[57]\)[t] - 
            0.04131966847794722`\ \(c[58]\)[t] - 
            0.05846808023678991`\ \(c[59]\)[t] - 
            0.07241337086197425`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 11, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 11]][ t]], 
          Plus[ 
            Times[ 0.049975424961080865, 
              c[ -60][ t]], 
            Times[ 0.059070953080906402, 
              c[ -59][ t]], 
            Times[ 0.065811019881796273, 
              c[ -58][ t]], 
            Times[ 0.069830768673962415, 
              c[ -57][ t]], 
            Times[ 0.070873018952678238, 
              c[ -56][ t]], 
            Times[ 0.068802429876423349, 
              c[ -55][ t]], 
            Times[ 0.063614872548668253, 
              c[ -54][ t]], 
            Times[ 0.055441487066198857, 
              c[ -53][ t]], 
            Times[ 0.044547108751839919, 
              c[ -52][ t]], 
            Times[ 0.031322974491347078, 
              c[ -51][ t]], 
            Times[ 0.016273855731265469, 
              c[ -50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ -0.016825511857749401, 
              c[ -48][ t]], 
            Times[ -0.033483179628681706, 
              c[ -47][ t]], 
            Times[ -0.049236278094138941, 
              c[ -46][ t]], 
            Times[ -0.063361699504227528, 
              c[ -45][ t]], 
            Times[ -0.075181213012062695, 
              c[ -44][ t]], 
            Times[ -0.084091858737850814, 
              c[ -43][ t]], 
            Times[ -0.089594193770366884, 
              c[ -42][ t]], 
            Times[ -0.091317159035181603, 
              c[ -41][ t]], 
            Times[ -0.089038438663606695, 
              c[ -40][ t]], 
            Times[ -0.082699334313268744, 
              c[ -39][ t]], 
            Times[ -0.072413370861974122, 
              c[ -38][ t]], 
            Times[ -0.058468080236789913, 
              c[ -37][ t]], 
            Times[ -0.04131966847794722, 
              c[ -36][ t]], 
            Times[ -0.021580547817547879, 
              c[ -35][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -34][ t]], 
            Times[ 0.022561481809254869, 
              c[ -33][ t]], 
            Times[ 0.045163358568919301, 
              c[ -32][ t]], 
            Times[ 0.066820663127759972, 
              c[ -31][ t]], 
            Times[ 0.086542809078944891, 
              c[ -30][ t]], 
            Times[ 0.10337416789158609, 
              c[ -29][ t]], 
            Times[ 0.11643488132933186, 
              c[ -28][ t]], 
            Times[ 0.12496032289024853, 
              c[ -27][ t]], 
            Times[ 0.12833762891430928, 
              c[ -26][ t]], 
            Times[ 0.12613778810677612, 
              c[ -25][ t]], 
            Times[ 0.11814190616181255, 
              c[ -24][ t]], 
            Times[ 0.10436044624225685, 
              c[ -23][ t]], 
            Times[ 0.085044480344421608, 
              c[ -22][ t]], 
            Times[ 0.060688263076985105, 
              c[ -21][ t]], 
            Times[ 0.032022748374425904, 
              c[ -20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -19][ t]], 
            Times[ -0.034231213779558949, 
              c[ -18][ t]], 
            Times[ -0.06935801494512607, 
              c[ -17][ t]], 
            Times[ -0.10394325375429328, 
              c[ -16][ t]], 
            Times[ -0.13647135277833605, 
              c[ -15][ t]], 
            Times[ -0.16539866862653771, 
              c[ -14][ t]], 
            Times[ -0.18920668216016426, 
              c[ -13][ t]], 
            Times[ -0.20645618564475843, 
              c[ -12][ t]], 
            Times[ -0.21584055771952015, 
              c[ -11][ t]], 
            Times[ -0.21623620818304484, 
              c[ -10][ t]], 
            Times[ -0.206748335783172, 
              c[ -9][ t]], 
            Times[ -0.18675027222298593, 
              c[ -8][ t]], 
            Times[ -0.15591488063143974, 
              c[ -7][ t]], 
            Times[ -0.11423673049785436, 
              c[ -6][ t]], 
            Times[ -0.062044074975450239, 
              c[ -5][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ 0.070907514257657775, 
              c[ -3][ t]], 
            Times[ 0.14938649372796362, 
              c[ -2][ t]], 
            Times[ 0.23387232094715998, 
              c[ -1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 0][ t]], 
            Times[ 0.41349667156634418, 
              c[ 1][ t]], 
            Times[ 0.50455115242710469, 
              c[ 2][ t]], 
            Times[ 0.59356153372868059, 
              c[ 3][ t]], 
            Times[ 0.67835603854706339, 
              c[ 4][ t]], 
            Times[ 0.75682672864065703, 
              c[ 5][ t]], 
            Times[ 0.82699334313268813, 
              c[ 6][ t]], 
            Times[ 0.88706379305918381, 
              c[ 7][ t]], 
            Times[ 0.93548928378863916, 
              c[ 8][ t]], 
            Times[ 0.9710122092317629, 
              c[ 9][ t]], 
            Times[ 0.99270519960720693, 
              c[ 10][ t]], 
            Times[ 3.6538269611818044, 
              c[ 11][ t]], 
            Times[ 0.99270519960720671, 
              c[ 12][ t]], 
            Times[ 0.9710122092317629, 
              c[ 13][ t]], 
            Times[ 0.93548928378863916, 
              c[ 14][ t]], 
            Times[ 0.88706379305918381, 
              c[ 15][ t]], 
            Times[ 0.82699334313268813, 
              c[ 16][ t]], 
            Times[ 0.75682672864065692, 
              c[ 17][ t]], 
            Times[ 0.67835603854706317, 
              c[ 18][ t]], 
            Times[ 0.59356153372868026, 
              c[ 19][ t]], 
            Times[ 0.50455115242710469, 
              c[ 20][ t]], 
            Times[ 0.41349667156634395, 
              c[ 21][ t]], 
            Times[ 0.32256865202152157, 
              c[ 22][ t]], 
            Times[ 0.23387232094715985, 
              c[ 23][ t]], 
            Times[ 0.14938649372796345, 
              c[ 24][ t]], 
            Times[ 0.070907514257657775, 
              c[ 25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 26][ t]], 
            Times[ -0.062044074975450475, 
              c[ 27][ t]], 
            Times[ -0.11423673049785436, 
              c[ 28][ t]], 
            Times[ -0.15591488063143982, 
              c[ 29][ t]], 
            Times[ -0.18675027222298607, 
              c[ 30][ t]], 
            Times[ -0.206748335783172, 
              c[ 31][ t]], 
            Times[ -0.21623620818304484, 
              c[ 32][ t]], 
            Times[ -0.21584055771952013, 
              c[ 33][ t]], 
            Times[ -0.20645618564475843, 
              c[ 34][ t]], 
            Times[ -0.18920668216016426, 
              c[ 35][ t]], 
            Times[ -0.1653986686265376, 
              c[ 36][ t]], 
            Times[ -0.13647135277833605, 
              c[ 37][ t]], 
            Times[ -0.10394325375429328, 
              c[ 38][ t]], 
            Times[ -0.069358014945125918, 
              c[ 39][ t]], 
            Times[ -0.034231213779558949, 
              c[ 40][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 41][ t]], 
            Times[ 0.032022748374426029, 
              c[ 42][ t]], 
            Times[ 0.060688263076985105, 
              c[ 43][ t]], 
            Times[ 0.085044480344421608, 
              c[ 44][ t]], 
            Times[ 0.10436044624225692, 
              c[ 45][ t]], 
            Times[ 0.11814190616181255, 
              c[ 46][ t]], 
            Times[ 0.12613778810677612, 
              c[ 47][ t]], 
            Times[ 0.12833762891430925, 
              c[ 48][ t]], 
            Times[ 0.12496032289024853, 
              c[ 49][ t]], 
            Times[ 0.11643488132933186, 
              c[ 50][ t]], 
            Times[ 0.10337416789158595, 
              c[ 51][ t]], 
            Times[ 0.086542809078944891, 
              c[ 52][ t]], 
            Times[ 0.066820663127759972, 
              c[ 53][ t]], 
            Times[ 0.045163358568919114, 
              c[ 54][ t]], 
            Times[ 0.022561481809254869, 
              c[ 55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 56][ t]], 
            Times[ -0.021580547817548056, 
              c[ 57][ t]], 
            Times[ -0.04131966847794722, 
              c[ 58][ t]], 
            Times[ -0.058468080236789913, 
              c[ 59][ t]], 
            Times[ -0.072413370861974247, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "12", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[12]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03897872015785999`\ \(c[\(-60\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-59\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-58\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-57\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-56\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-55\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-54\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-53\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-52\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-51\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-50\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-49\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-47\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-46\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-45\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-44\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-43\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-42\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-41\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-40\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-39\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-38\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-37\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-36\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-35\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-34\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-33\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-32\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-31\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-30\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-29\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-28\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-27\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-26\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-25\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-24\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-23\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-22\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-21\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-20\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-17\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-16\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-15\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-14\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-13\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-12\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-11\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-10\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-9\)]\)[t] - 
            0.206748335783172`\ \(c[\(-8\)]\)[t] - 
            0.186750272222986`\ \(c[\(-7\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-6\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-5\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-4\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] + 
            0.07090751425765762`\ \(c[\(-2\)]\)[t] + 
            0.14938649372796362`\ \(c[\(-1\)]\)[t] + 
            0.23387232094715985`\ \(c[0]\)[t] + 
            0.32256865202152135`\ \(c[1]\)[t] + 
            0.4134966715663442`\ \(c[2]\)[t] + 
            0.5045511524271047`\ \(c[3]\)[t] + 
            0.5935615337286803`\ \(c[4]\)[t] + 
            0.6783560385470633`\ \(c[5]\)[t] + 
            0.7568267286406569`\ \(c[6]\)[t] + 
            0.8269933431326881`\ \(c[7]\)[t] + 
            0.8870637930591837`\ \(c[8]\)[t] + 
            0.9354892837886392`\ \(c[9]\)[t] + 
            0.9710122092317629`\ \(c[10]\)[t] + 
            0.9927051996072067`\ \(c[11]\)[t] + 
            4.158273408348594`\ \(c[12]\)[t] + 
            0.9927051996072069`\ \(c[13]\)[t] + 
            0.9710122092317629`\ \(c[14]\)[t] + 
            0.9354892837886392`\ \(c[15]\)[t] + 
            0.8870637930591838`\ \(c[16]\)[t] + 
            0.8269933431326881`\ \(c[17]\)[t] + 
            0.7568267286406569`\ \(c[18]\)[t] + 
            0.6783560385470634`\ \(c[19]\)[t] + 
            0.5935615337286806`\ \(c[20]\)[t] + 
            0.5045511524271047`\ \(c[21]\)[t] + 
            0.4134966715663443`\ \(c[22]\)[t] + 
            0.3225686520215216`\ \(c[23]\)[t] + 
            0.23387232094715985`\ \(c[24]\)[t] + 
            0.14938649372796384`\ \(c[25]\)[t] + 
            0.07090751425765777`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.06204407497545024`\ \(c[28]\)[t] - 
            0.11423673049785436`\ \(c[29]\)[t] - 
            0.15591488063143982`\ \(c[30]\)[t] - 
            0.18675027222298593`\ \(c[31]\)[t] - 
            0.206748335783172`\ \(c[32]\)[t] - 
            0.21623620818304484`\ \(c[33]\)[t] - 
            0.21584055771952015`\ \(c[34]\)[t] - 
            0.20645618564475843`\ \(c[35]\)[t] - 
            0.18920668216016426`\ \(c[36]\)[t] - 
            0.1653986686265377`\ \(c[37]\)[t] - 
            0.13647135277833605`\ \(c[38]\)[t] - 
            0.10394325375429328`\ \(c[39]\)[t] - 
            0.06935801494512607`\ \(c[40]\)[t] - 
            0.034231213779559094`\ \(c[41]\)[t] - 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.032022748374425904`\ \(c[43]\)[t] + 
            0.060688263076985`\ \(c[44]\)[t] + 
            0.0850444803444217`\ \(c[45]\)[t] + 
            0.10436044624225685`\ \(c[46]\)[t] + 
            0.11814190616181253`\ \(c[47]\)[t] + 
            0.12613778810677614`\ \(c[48]\)[t] + 
            0.12833762891430928`\ \(c[49]\)[t] + 
            0.12496032289024853`\ \(c[50]\)[t] + 
            0.11643488132933186`\ \(c[51]\)[t] + 
            0.10337416789158609`\ \(c[52]\)[t] + 
            0.08654280907894489`\ \(c[53]\)[t] + 
            0.06682066312775997`\ \(c[54]\)[t] + 
            0.0451633585689193`\ \(c[55]\)[t] + 
            0.02256148180925487`\ \(c[56]\)[t] + 
            3.8981718325193755`*^-17\ \(c[57]\)[t] - 
            0.02158054781754788`\ \(c[58]\)[t] - 
            0.04131966847794722`\ \(c[59]\)[t] - 
            0.05846808023678991`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 12, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 12]][ t]], 
          Plus[ 
            Times[ 0.03897872015785999, 
              c[ -60][ t]], 
            Times[ 0.049975424961080865, 
              c[ -59][ t]], 
            Times[ 0.059070953080906326, 
              c[ -58][ t]], 
            Times[ 0.065811019881796273, 
              c[ -57][ t]], 
            Times[ 0.069830768673962415, 
              c[ -56][ t]], 
            Times[ 0.070873018952678238, 
              c[ -55][ t]], 
            Times[ 0.068802429876423349, 
              c[ -54][ t]], 
            Times[ 0.063614872548668253, 
              c[ -53][ t]], 
            Times[ 0.055441487066198933, 
              c[ -52][ t]], 
            Times[ 0.044547108751839919, 
              c[ -51][ t]], 
            Times[ 0.031322974491347078, 
              c[ -50][ t]], 
            Times[ 0.016273855731265604, 
              c[ -49][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ -0.016825511857749401, 
              c[ -47][ t]], 
            Times[ -0.033483179628681567, 
              c[ -46][ t]], 
            Times[ -0.049236278094138941, 
              c[ -45][ t]], 
            Times[ -0.063361699504227528, 
              c[ -44][ t]], 
            Times[ -0.075181213012062598, 
              c[ -43][ t]], 
            Times[ -0.084091858737850814, 
              c[ -42][ t]], 
            Times[ -0.089594193770366884, 
              c[ -41][ t]], 
            Times[ -0.091317159035181589, 
              c[ -40][ t]], 
            Times[ -0.089038438663606695, 
              c[ -39][ t]], 
            Times[ -0.082699334313268744, 
              c[ -38][ t]], 
            Times[ -0.072413370861974122, 
              c[ -37][ t]], 
            Times[ -0.058468080236789913, 
              c[ -36][ t]], 
            Times[ -0.04131966847794722, 
              c[ -35][ t]], 
            Times[ -0.021580547817547879, 
              c[ -34][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -33][ t]], 
            Times[ 0.022561481809254869, 
              c[ -32][ t]], 
            Times[ 0.045163358568919301, 
              c[ -31][ t]], 
            Times[ 0.066820663127759972, 
              c[ -30][ t]], 
            Times[ 0.086542809078944891, 
              c[ -29][ t]], 
            Times[ 0.10337416789158609, 
              c[ -28][ t]], 
            Times[ 0.11643488132933186, 
              c[ -27][ t]], 
            Times[ 0.12496032289024853, 
              c[ -26][ t]], 
            Times[ 0.12833762891430928, 
              c[ -25][ t]], 
            Times[ 0.12613778810677614, 
              c[ -24][ t]], 
            Times[ 0.11814190616181255, 
              c[ -23][ t]], 
            Times[ 0.10436044624225685, 
              c[ -22][ t]], 
            Times[ 0.085044480344421705, 
              c[ -21][ t]], 
            Times[ 0.060688263076985105, 
              c[ -20][ t]], 
            Times[ 0.032022748374425904, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.034231213779558949, 
              c[ -17][ t]], 
            Times[ -0.06935801494512607, 
              c[ -16][ t]], 
            Times[ -0.10394325375429328, 
              c[ -15][ t]], 
            Times[ -0.13647135277833605, 
              c[ -14][ t]], 
            Times[ -0.16539866862653771, 
              c[ -13][ t]], 
            Times[ -0.18920668216016426, 
              c[ -12][ t]], 
            Times[ -0.20645618564475843, 
              c[ -11][ t]], 
            Times[ -0.21584055771952015, 
              c[ -10][ t]], 
            Times[ -0.21623620818304484, 
              c[ -9][ t]], 
            Times[ -0.206748335783172, 
              c[ -8][ t]], 
            Times[ -0.18675027222298601, 
              c[ -7][ t]], 
            Times[ -0.15591488063143982, 
              c[ -6][ t]], 
            Times[ -0.11423673049785436, 
              c[ -5][ t]], 
            Times[ -0.062044074975450343, 
              c[ -4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ 0.070907514257657622, 
              c[ -2][ t]], 
            Times[ 0.14938649372796362, 
              c[ -1][ t]], 
            Times[ 0.23387232094715985, 
              c[ 0][ t]], 
            Times[ 0.32256865202152135, 
              c[ 1][ t]], 
            Times[ 0.41349667156634418, 
              c[ 2][ t]], 
            Times[ 0.50455115242710469, 
              c[ 3][ t]], 
            Times[ 0.59356153372868026, 
              c[ 4][ t]], 
            Times[ 0.67835603854706328, 
              c[ 5][ t]], 
            Times[ 0.75682672864065692, 
              c[ 6][ t]], 
            Times[ 0.82699334313268813, 
              c[ 7][ t]], 
            Times[ 0.8870637930591837, 
              c[ 8][ t]], 
            Times[ 0.93548928378863916, 
              c[ 9][ t]], 
            Times[ 0.9710122092317629, 
              c[ 10][ t]], 
            Times[ 0.99270519960720671, 
              c[ 11][ t]], 
            Times[ 4.1582734083485944, 
              c[ 12][ t]], 
            Times[ 0.99270519960720693, 
              c[ 13][ t]], 
            Times[ 0.9710122092317629, 
              c[ 14][ t]], 
            Times[ 0.93548928378863916, 
              c[ 15][ t]], 
            Times[ 0.88706379305918381, 
              c[ 16][ t]], 
            Times[ 0.82699334313268813, 
              c[ 17][ t]], 
            Times[ 0.75682672864065692, 
              c[ 18][ t]], 
            Times[ 0.67835603854706339, 
              c[ 19][ t]], 
            Times[ 0.59356153372868059, 
              c[ 20][ t]], 
            Times[ 0.50455115242710469, 
              c[ 21][ t]], 
            Times[ 0.41349667156634429, 
              c[ 22][ t]], 
            Times[ 0.32256865202152157, 
              c[ 23][ t]], 
            Times[ 0.23387232094715985, 
              c[ 24][ t]], 
            Times[ 0.14938649372796384, 
              c[ 25][ t]], 
            Times[ 0.070907514257657775, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.062044074975450239, 
              c[ 28][ t]], 
            Times[ -0.11423673049785436, 
              c[ 29][ t]], 
            Times[ -0.15591488063143982, 
              c[ 30][ t]], 
            Times[ -0.18675027222298593, 
              c[ 31][ t]], 
            Times[ -0.206748335783172, 
              c[ 32][ t]], 
            Times[ -0.21623620818304484, 
              c[ 33][ t]], 
            Times[ -0.21584055771952015, 
              c[ 34][ t]], 
            Times[ -0.20645618564475843, 
              c[ 35][ t]], 
            Times[ -0.18920668216016426, 
              c[ 36][ t]], 
            Times[ -0.16539866862653771, 
              c[ 37][ t]], 
            Times[ -0.13647135277833605, 
              c[ 38][ t]], 
            Times[ -0.10394325375429328, 
              c[ 39][ t]], 
            Times[ -0.06935801494512607, 
              c[ 40][ t]], 
            Times[ -0.034231213779559094, 
              c[ 41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.032022748374425904, 
              c[ 43][ t]], 
            Times[ 0.060688263076985001, 
              c[ 44][ t]], 
            Times[ 0.085044480344421705, 
              c[ 45][ t]], 
            Times[ 0.10436044624225685, 
              c[ 46][ t]], 
            Times[ 0.11814190616181253, 
              c[ 47][ t]], 
            Times[ 0.12613778810677614, 
              c[ 48][ t]], 
            Times[ 0.12833762891430928, 
              c[ 49][ t]], 
            Times[ 0.12496032289024853, 
              c[ 50][ t]], 
            Times[ 0.11643488132933186, 
              c[ 51][ t]], 
            Times[ 0.10337416789158609, 
              c[ 52][ t]], 
            Times[ 0.086542809078944891, 
              c[ 53][ t]], 
            Times[ 0.066820663127759972, 
              c[ 54][ t]], 
            Times[ 0.045163358568919301, 
              c[ 55][ t]], 
            Times[ 0.022561481809254869, 
              c[ 56][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 57][ t]], 
            Times[ -0.021580547817547879, 
              c[ 58][ t]], 
            Times[ -0.04131966847794722, 
              c[ 59][ t]], 
            Times[ -0.058468080236789913, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "13", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[13]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.026603074225527826`\ \(c[\(-60\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-59\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-58\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-57\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-56\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-55\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-54\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-53\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-52\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-51\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-50\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-49\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-48\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-47\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-46\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-45\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-44\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-43\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-42\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-41\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-40\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-39\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-38\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-37\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-36\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-35\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-34\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-33\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-32\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-31\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-30\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-29\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-28\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-27\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-26\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-25\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-24\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-23\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-22\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-21\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-20\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-19\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-18\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-16\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-15\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-14\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-13\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-12\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-11\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-10\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-9\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-8\)]\)[t] - 
            0.206748335783172`\ \(c[\(-7\)]\)[t] - 
            0.186750272222986`\ \(c[\(-6\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-5\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-4\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-3\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] + 
            0.07090751425765777`\ \(c[\(-1\)]\)[t] + 
            0.14938649372796362`\ \(c[0]\)[t] + 
            0.23387232094715985`\ \(c[1]\)[t] + 
            0.3225686520215216`\ \(c[2]\)[t] + 
            0.4134966715663442`\ \(c[3]\)[t] + 
            0.5045511524271047`\ \(c[4]\)[t] + 
            0.5935615337286805`\ \(c[5]\)[t] + 
            0.6783560385470634`\ \(c[6]\)[t] + 
            0.7568267286406569`\ \(c[7]\)[t] + 
            0.8269933431326882`\ \(c[8]\)[t] + 
            0.8870637930591838`\ \(c[9]\)[t] + 
            0.9354892837886392`\ \(c[10]\)[t] + 
            0.9710122092317629`\ \(c[11]\)[t] + 
            0.9927051996072069`\ \(c[12]\)[t] + 
            4.70658476396467`\ \(c[13]\)[t] + 
            0.9927051996072069`\ \(c[14]\)[t] + 
            0.9710122092317629`\ \(c[15]\)[t] + 
            0.9354892837886392`\ \(c[16]\)[t] + 
            0.8870637930591838`\ \(c[17]\)[t] + 
            0.8269933431326881`\ \(c[18]\)[t] + 
            0.7568267286406569`\ \(c[19]\)[t] + 
            0.6783560385470634`\ \(c[20]\)[t] + 
            0.5935615337286803`\ \(c[21]\)[t] + 
            0.5045511524271049`\ \(c[22]\)[t] + 
            0.4134966715663442`\ \(c[23]\)[t] + 
            0.32256865202152135`\ \(c[24]\)[t] + 
            0.23387232094715998`\ \(c[25]\)[t] + 
            0.14938649372796362`\ \(c[26]\)[t] + 
            0.07090751425765762`\ \(c[27]\)[t] + 
            1.8033970416801674`*^-16\ \(c[28]\)[t] - 
            0.06204407497545034`\ \(c[29]\)[t] - 
            0.11423673049785445`\ \(c[30]\)[t] - 
            0.15591488063143974`\ \(c[31]\)[t] - 
            0.186750272222986`\ \(c[32]\)[t] - 
            0.20674833578317206`\ \(c[33]\)[t] - 
            0.21623620818304484`\ \(c[34]\)[t] - 
            0.21584055771952015`\ \(c[35]\)[t] - 
            0.20645618564475834`\ \(c[36]\)[t] - 
            0.18920668216016426`\ \(c[37]\)[t] - 
            0.1653986686265377`\ \(c[38]\)[t] - 
            0.1364713527783359`\ \(c[39]\)[t] - 
            0.10394325375429328`\ \(c[40]\)[t] - 
            0.06935801494512607`\ \(c[41]\)[t] - 
            0.034231213779558796`\ \(c[42]\)[t] - 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.032022748374425904`\ \(c[44]\)[t] + 
            0.06068826307698522`\ \(c[45]\)[t] + 
            0.0850444803444217`\ \(c[46]\)[t] + 
            0.10436044624225685`\ \(c[47]\)[t] + 
            0.1181419061618126`\ \(c[48]\)[t] + 
            0.12613778810677614`\ \(c[49]\)[t] + 
            0.12833762891430928`\ \(c[50]\)[t] + 
            0.12496032289024847`\ \(c[51]\)[t] + 
            0.11643488132933186`\ \(c[52]\)[t] + 
            0.10337416789158609`\ \(c[53]\)[t] + 
            0.08654280907894475`\ \(c[54]\)[t] + 
            0.06682066312775997`\ \(c[55]\)[t] + 
            0.0451633585689193`\ \(c[56]\)[t] + 
            0.022561481809254675`\ \(c[57]\)[t] + 
            3.8981718325193755`*^-17\ \(c[58]\)[t] - 
            0.02158054781754788`\ \(c[59]\)[t] - 
            0.04131966847794737`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 13, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 13]][ t]], 
          Plus[ 
            Times[ 0.026603074225527826, 
              c[ -60][ t]], 
            Times[ 0.038978720157860088, 
              c[ -59][ t]], 
            Times[ 0.049975424961080865, 
              c[ -58][ t]], 
            Times[ 0.059070953080906326, 
              c[ -57][ t]], 
            Times[ 0.065811019881796315, 
              c[ -56][ t]], 
            Times[ 0.069830768673962415, 
              c[ -55][ t]], 
            Times[ 0.070873018952678238, 
              c[ -54][ t]], 
            Times[ 0.068802429876423321, 
              c[ -53][ t]], 
            Times[ 0.063614872548668253, 
              c[ -52][ t]], 
            Times[ 0.055441487066198933, 
              c[ -51][ t]], 
            Times[ 0.044547108751839815, 
              c[ -50][ t]], 
            Times[ 0.031322974491347078, 
              c[ -49][ t]], 
            Times[ 0.016273855731265604, 
              c[ -48][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -47][ t]], 
            Times[ -0.016825511857749401, 
              c[ -46][ t]], 
            Times[ -0.033483179628681567, 
              c[ -45][ t]], 
            Times[ -0.049236278094139066, 
              c[ -44][ t]], 
            Times[ -0.063361699504227528, 
              c[ -43][ t]], 
            Times[ -0.075181213012062598, 
              c[ -42][ t]], 
            Times[ -0.084091858737850855, 
              c[ -41][ t]], 
            Times[ -0.089594193770366884, 
              c[ -40][ t]], 
            Times[ -0.091317159035181589, 
              c[ -39][ t]], 
            Times[ -0.089038438663606695, 
              c[ -38][ t]], 
            Times[ -0.082699334313268744, 
              c[ -37][ t]], 
            Times[ -0.072413370861974122, 
              c[ -36][ t]], 
            Times[ -0.058468080236789913, 
              c[ -35][ t]], 
            Times[ -0.04131966847794722, 
              c[ -34][ t]], 
            Times[ -0.021580547817547879, 
              c[ -33][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -32][ t]], 
            Times[ 0.022561481809254869, 
              c[ -31][ t]], 
            Times[ 0.045163358568919301, 
              c[ -30][ t]], 
            Times[ 0.066820663127759972, 
              c[ -29][ t]], 
            Times[ 0.086542809078944891, 
              c[ -28][ t]], 
            Times[ 0.10337416789158609, 
              c[ -27][ t]], 
            Times[ 0.11643488132933186, 
              c[ -26][ t]], 
            Times[ 0.12496032289024853, 
              c[ -25][ t]], 
            Times[ 0.12833762891430928, 
              c[ -24][ t]], 
            Times[ 0.12613778810677614, 
              c[ -23][ t]], 
            Times[ 0.11814190616181253, 
              c[ -22][ t]], 
            Times[ 0.10436044624225685, 
              c[ -21][ t]], 
            Times[ 0.085044480344421705, 
              c[ -20][ t]], 
            Times[ 0.060688263076985105, 
              c[ -19][ t]], 
            Times[ 0.032022748374425904, 
              c[ -18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.034231213779558949, 
              c[ -16][ t]], 
            Times[ -0.06935801494512607, 
              c[ -15][ t]], 
            Times[ -0.10394325375429328, 
              c[ -14][ t]], 
            Times[ -0.13647135277833605, 
              c[ -13][ t]], 
            Times[ -0.16539866862653771, 
              c[ -12][ t]], 
            Times[ -0.18920668216016426, 
              c[ -11][ t]], 
            Times[ -0.20645618564475843, 
              c[ -10][ t]], 
            Times[ -0.21584055771952015, 
              c[ -9][ t]], 
            Times[ -0.21623620818304484, 
              c[ -8][ t]], 
            Times[ -0.206748335783172, 
              c[ -7][ t]], 
            Times[ -0.18675027222298601, 
              c[ -6][ t]], 
            Times[ -0.15591488063143982, 
              c[ -5][ t]], 
            Times[ -0.11423673049785436, 
              c[ -4][ t]], 
            Times[ -0.062044074975450343, 
              c[ -3][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ 0.070907514257657775, 
              c[ -1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 0][ t]], 
            Times[ 0.23387232094715985, 
              c[ 1][ t]], 
            Times[ 0.32256865202152157, 
              c[ 2][ t]], 
            Times[ 0.41349667156634418, 
              c[ 3][ t]], 
            Times[ 0.50455115242710469, 
              c[ 4][ t]], 
            Times[ 0.59356153372868048, 
              c[ 5][ t]], 
            Times[ 0.67835603854706339, 
              c[ 6][ t]], 
            Times[ 0.75682672864065692, 
              c[ 7][ t]], 
            Times[ 0.82699334313268824, 
              c[ 8][ t]], 
            Times[ 0.88706379305918381, 
              c[ 9][ t]], 
            Times[ 0.93548928378863916, 
              c[ 10][ t]], 
            Times[ 0.9710122092317629, 
              c[ 11][ t]], 
            Times[ 0.99270519960720693, 
              c[ 12][ t]], 
            Times[ 4.7065847639646696, 
              c[ 13][ t]], 
            Times[ 0.99270519960720693, 
              c[ 14][ t]], 
            Times[ 0.9710122092317629, 
              c[ 15][ t]], 
            Times[ 0.93548928378863916, 
              c[ 16][ t]], 
            Times[ 0.88706379305918381, 
              c[ 17][ t]], 
            Times[ 0.82699334313268813, 
              c[ 18][ t]], 
            Times[ 0.75682672864065692, 
              c[ 19][ t]], 
            Times[ 0.67835603854706339, 
              c[ 20][ t]], 
            Times[ 0.59356153372868026, 
              c[ 21][ t]], 
            Times[ 0.50455115242710491, 
              c[ 22][ t]], 
            Times[ 0.41349667156634418, 
              c[ 23][ t]], 
            Times[ 0.32256865202152135, 
              c[ 24][ t]], 
            Times[ 0.23387232094715998, 
              c[ 25][ t]], 
            Times[ 0.14938649372796362, 
              c[ 26][ t]], 
            Times[ 0.070907514257657622, 
              c[ 27][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 28][ t]], 
            Times[ -0.062044074975450343, 
              c[ 29][ t]], 
            Times[ -0.11423673049785445, 
              c[ 30][ t]], 
            Times[ -0.15591488063143974, 
              c[ 31][ t]], 
            Times[ -0.18675027222298601, 
              c[ 32][ t]], 
            Times[ -0.20674833578317206, 
              c[ 33][ t]], 
            Times[ -0.21623620818304484, 
              c[ 34][ t]], 
            Times[ -0.21584055771952015, 
              c[ 35][ t]], 
            Times[ -0.20645618564475834, 
              c[ 36][ t]], 
            Times[ -0.18920668216016426, 
              c[ 37][ t]], 
            Times[ -0.16539866862653771, 
              c[ 38][ t]], 
            Times[ -0.13647135277833591, 
              c[ 39][ t]], 
            Times[ -0.10394325375429328, 
              c[ 40][ t]], 
            Times[ -0.06935801494512607, 
              c[ 41][ t]], 
            Times[ -0.034231213779558796, 
              c[ 42][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.032022748374425904, 
              c[ 44][ t]], 
            Times[ 0.060688263076985223, 
              c[ 45][ t]], 
            Times[ 0.085044480344421705, 
              c[ 46][ t]], 
            Times[ 0.10436044624225685, 
              c[ 47][ t]], 
            Times[ 0.1181419061618126, 
              c[ 48][ t]], 
            Times[ 0.12613778810677614, 
              c[ 49][ t]], 
            Times[ 0.12833762891430928, 
              c[ 50][ t]], 
            Times[ 0.12496032289024847, 
              c[ 51][ t]], 
            Times[ 0.11643488132933186, 
              c[ 52][ t]], 
            Times[ 0.10337416789158609, 
              c[ 53][ t]], 
            Times[ 0.086542809078944752, 
              c[ 54][ t]], 
            Times[ 0.066820663127759972, 
              c[ 55][ t]], 
            Times[ 0.045163358568919301, 
              c[ 56][ t]], 
            Times[ 0.022561481809254675, 
              c[ 57][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 58][ t]], 
            Times[ -0.021580547817547879, 
              c[ 59][ t]], 
            Times[ -0.041319668477947373, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "14", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[14]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.013414935129827233`\ \(c[\(-60\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-59\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-58\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-57\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-56\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-55\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-54\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-53\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-52\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-51\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-50\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-49\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-48\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-47\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-45\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-44\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-43\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-42\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-41\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-40\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-39\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-38\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-37\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-36\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-35\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-34\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-33\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-32\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-31\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-30\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-29\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-28\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-27\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-26\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-25\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-24\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-23\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-22\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-21\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-20\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-19\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-18\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-17\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-16\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-15\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-14\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-13\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-12\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-11\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-10\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-9\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-8\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-7\)]\)[t] - 
            0.206748335783172`\ \(c[\(-6\)]\)[t] - 
            0.18675027222298593`\ \(c[\(-5\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-4\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-3\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-2\)]\)[t] + 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] + 
            0.07090751425765777`\ \(c[0]\)[t] + 
            0.14938649372796362`\ \(c[1]\)[t] + 
            0.23387232094715998`\ \(c[2]\)[t] + 
            0.3225686520215216`\ \(c[3]\)[t] + 
            0.4134966715663442`\ \(c[4]\)[t] + 
            0.5045511524271047`\ \(c[5]\)[t] + 
            0.5935615337286806`\ \(c[6]\)[t] + 
            0.6783560385470634`\ \(c[7]\)[t] + 
            0.756826728640657`\ \(c[8]\)[t] + 
            0.8269933431326881`\ \(c[9]\)[t] + 
            0.8870637930591838`\ \(c[10]\)[t] + 
            0.9354892837886392`\ \(c[11]\)[t] + 
            0.9710122092317629`\ \(c[12]\)[t] + 
            0.9927051996072069`\ \(c[13]\)[t] + 
            5.298761028030031`\ \(c[14]\)[t] + 
            0.9927051996072067`\ \(c[15]\)[t] + 
            0.9710122092317629`\ \(c[16]\)[t] + 
            0.9354892837886392`\ \(c[17]\)[t] + 
            0.8870637930591838`\ \(c[18]\)[t] + 
            0.8269933431326881`\ \(c[19]\)[t] + 
            0.7568267286406569`\ \(c[20]\)[t] + 
            0.6783560385470632`\ \(c[21]\)[t] + 
            0.5935615337286806`\ \(c[22]\)[t] + 
            0.5045511524271047`\ \(c[23]\)[t] + 
            0.41349667156634395`\ \(c[24]\)[t] + 
            0.3225686520215216`\ \(c[25]\)[t] + 
            0.23387232094715985`\ \(c[26]\)[t] + 
            0.14938649372796345`\ \(c[27]\)[t] + 
            0.07090751425765777`\ \(c[28]\)[t] + 
            3.898171832519376`*^-17\ \(c[29]\)[t] - 
            0.062044074975450475`\ \(c[30]\)[t] - 
            0.11423673049785436`\ \(c[31]\)[t] - 
            0.15591488063143982`\ \(c[32]\)[t] - 
            0.18675027222298607`\ \(c[33]\)[t] - 
            0.206748335783172`\ \(c[34]\)[t] - 
            0.21623620818304484`\ \(c[35]\)[t] - 
            0.21584055771952013`\ \(c[36]\)[t] - 
            0.20645618564475843`\ \(c[37]\)[t] - 
            0.18920668216016426`\ \(c[38]\)[t] - 
            0.1653986686265376`\ \(c[39]\)[t] - 
            0.13647135277833605`\ \(c[40]\)[t] - 
            0.1039432537542934`\ \(c[41]\)[t] - 
            0.06935801494512592`\ \(c[42]\)[t] - 
            0.03423121377955895`\ \(c[43]\)[t] - 
            1.8033970416801674`*^-16\ \(c[44]\)[t] + 
            0.03202274837442603`\ \(c[45]\)[t] + 
            0.060688263076985105`\ \(c[46]\)[t] + 
            0.08504448034442161`\ \(c[47]\)[t] + 
            0.10436044624225692`\ \(c[48]\)[t] + 
            0.11814190616181255`\ \(c[49]\)[t] + 
            0.12613778810677612`\ \(c[50]\)[t] + 
            0.12833762891430925`\ \(c[51]\)[t] + 
            0.12496032289024853`\ \(c[52]\)[t] + 
            0.11643488132933186`\ \(c[53]\)[t] + 
            0.10337416789158595`\ \(c[54]\)[t] + 
            0.08654280907894489`\ \(c[55]\)[t] + 
            0.06682066312775997`\ \(c[56]\)[t] + 
            0.045163358568919114`\ \(c[57]\)[t] + 
            0.02256148180925487`\ \(c[58]\)[t] + 
            3.8981718325193755`*^-17\ \(c[59]\)[t] - 
            0.021580547817548056`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 14, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 14]][ t]], 
          Plus[ 
            Times[ 0.013414935129827233, 
              c[ -60][ t]], 
            Times[ 0.026603074225527937, 
              c[ -59][ t]], 
            Times[ 0.03897872015785999, 
              c[ -58][ t]], 
            Times[ 0.049975424961080865, 
              c[ -57][ t]], 
            Times[ 0.059070953080906402, 
              c[ -56][ t]], 
            Times[ 0.065811019881796273, 
              c[ -55][ t]], 
            Times[ 0.069830768673962415, 
              c[ -54][ t]], 
            Times[ 0.070873018952678238, 
              c[ -53][ t]], 
            Times[ 0.068802429876423349, 
              c[ -52][ t]], 
            Times[ 0.063614872548668253, 
              c[ -51][ t]], 
            Times[ 0.055441487066198857, 
              c[ -50][ t]], 
            Times[ 0.044547108751839919, 
              c[ -49][ t]], 
            Times[ 0.031322974491347078, 
              c[ -48][ t]], 
            Times[ 0.016273855731265469, 
              c[ -47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ -0.016825511857749401, 
              c[ -45][ t]], 
            Times[ -0.033483179628681706, 
              c[ -44][ t]], 
            Times[ -0.049236278094138941, 
              c[ -43][ t]], 
            Times[ -0.063361699504227528, 
              c[ -42][ t]], 
            Times[ -0.075181213012062695, 
              c[ -41][ t]], 
            Times[ -0.084091858737850814, 
              c[ -40][ t]], 
            Times[ -0.089594193770366884, 
              c[ -39][ t]], 
            Times[ -0.091317159035181589, 
              c[ -38][ t]], 
            Times[ -0.089038438663606695, 
              c[ -37][ t]], 
            Times[ -0.082699334313268744, 
              c[ -36][ t]], 
            Times[ -0.072413370861974122, 
              c[ -35][ t]], 
            Times[ -0.058468080236789913, 
              c[ -34][ t]], 
            Times[ -0.04131966847794722, 
              c[ -33][ t]], 
            Times[ -0.021580547817547879, 
              c[ -32][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -31][ t]], 
            Times[ 0.022561481809254869, 
              c[ -30][ t]], 
            Times[ 0.045163358568919301, 
              c[ -29][ t]], 
            Times[ 0.066820663127759972, 
              c[ -28][ t]], 
            Times[ 0.086542809078944891, 
              c[ -27][ t]], 
            Times[ 0.10337416789158609, 
              c[ -26][ t]], 
            Times[ 0.11643488132933186, 
              c[ -25][ t]], 
            Times[ 0.12496032289024853, 
              c[ -24][ t]], 
            Times[ 0.12833762891430928, 
              c[ -23][ t]], 
            Times[ 0.12613778810677612, 
              c[ -22][ t]], 
            Times[ 0.11814190616181255, 
              c[ -21][ t]], 
            Times[ 0.10436044624225685, 
              c[ -20][ t]], 
            Times[ 0.085044480344421705, 
              c[ -19][ t]], 
            Times[ 0.060688263076985105, 
              c[ -18][ t]], 
            Times[ 0.032022748374425904, 
              c[ -17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -16][ t]], 
            Times[ -0.034231213779558949, 
              c[ -15][ t]], 
            Times[ -0.06935801494512607, 
              c[ -14][ t]], 
            Times[ -0.10394325375429328, 
              c[ -13][ t]], 
            Times[ -0.13647135277833605, 
              c[ -12][ t]], 
            Times[ -0.16539866862653771, 
              c[ -11][ t]], 
            Times[ -0.18920668216016426, 
              c[ -10][ t]], 
            Times[ -0.20645618564475843, 
              c[ -9][ t]], 
            Times[ -0.21584055771952015, 
              c[ -8][ t]], 
            Times[ -0.21623620818304484, 
              c[ -7][ t]], 
            Times[ -0.206748335783172, 
              c[ -6][ t]], 
            Times[ -0.18675027222298593, 
              c[ -5][ t]], 
            Times[ -0.15591488063143974, 
              c[ -4][ t]], 
            Times[ -0.11423673049785436, 
              c[ -3][ t]], 
            Times[ -0.062044074975450343, 
              c[ -2][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 0][ t]], 
            Times[ 0.14938649372796362, 
              c[ 1][ t]], 
            Times[ 0.23387232094715998, 
              c[ 2][ t]], 
            Times[ 0.32256865202152157, 
              c[ 3][ t]], 
            Times[ 0.41349667156634418, 
              c[ 4][ t]], 
            Times[ 0.50455115242710469, 
              c[ 5][ t]], 
            Times[ 0.59356153372868059, 
              c[ 6][ t]], 
            Times[ 0.67835603854706339, 
              c[ 7][ t]], 
            Times[ 0.75682672864065703, 
              c[ 8][ t]], 
            Times[ 0.82699334313268813, 
              c[ 9][ t]], 
            Times[ 0.88706379305918381, 
              c[ 10][ t]], 
            Times[ 0.93548928378863916, 
              c[ 11][ t]], 
            Times[ 0.9710122092317629, 
              c[ 12][ t]], 
            Times[ 0.99270519960720693, 
              c[ 13][ t]], 
            Times[ 5.2987610280300306, 
              c[ 14][ t]], 
            Times[ 0.99270519960720671, 
              c[ 15][ t]], 
            Times[ 0.9710122092317629, 
              c[ 16][ t]], 
            Times[ 0.93548928378863916, 
              c[ 17][ t]], 
            Times[ 0.88706379305918381, 
              c[ 18][ t]], 
            Times[ 0.82699334313268813, 
              c[ 19][ t]], 
            Times[ 0.75682672864065692, 
              c[ 20][ t]], 
            Times[ 0.67835603854706317, 
              c[ 21][ t]], 
            Times[ 0.59356153372868059, 
              c[ 22][ t]], 
            Times[ 0.50455115242710469, 
              c[ 23][ t]], 
            Times[ 0.41349667156634395, 
              c[ 24][ t]], 
            Times[ 0.32256865202152157, 
              c[ 25][ t]], 
            Times[ 0.23387232094715985, 
              c[ 26][ t]], 
            Times[ 0.14938649372796345, 
              c[ 27][ t]], 
            Times[ 0.070907514257657775, 
              c[ 28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 29][ t]], 
            Times[ -0.062044074975450475, 
              c[ 30][ t]], 
            Times[ -0.11423673049785436, 
              c[ 31][ t]], 
            Times[ -0.15591488063143982, 
              c[ 32][ t]], 
            Times[ -0.18675027222298607, 
              c[ 33][ t]], 
            Times[ -0.206748335783172, 
              c[ 34][ t]], 
            Times[ -0.21623620818304484, 
              c[ 35][ t]], 
            Times[ -0.21584055771952013, 
              c[ 36][ t]], 
            Times[ -0.20645618564475843, 
              c[ 37][ t]], 
            Times[ -0.18920668216016426, 
              c[ 38][ t]], 
            Times[ -0.1653986686265376, 
              c[ 39][ t]], 
            Times[ -0.13647135277833605, 
              c[ 40][ t]], 
            Times[ -0.1039432537542934, 
              c[ 41][ t]], 
            Times[ -0.069358014945125918, 
              c[ 42][ t]], 
            Times[ -0.034231213779558949, 
              c[ 43][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 44][ t]], 
            Times[ 0.032022748374426029, 
              c[ 45][ t]], 
            Times[ 0.060688263076985105, 
              c[ 46][ t]], 
            Times[ 0.085044480344421608, 
              c[ 47][ t]], 
            Times[ 0.10436044624225692, 
              c[ 48][ t]], 
            Times[ 0.11814190616181255, 
              c[ 49][ t]], 
            Times[ 0.12613778810677612, 
              c[ 50][ t]], 
            Times[ 0.12833762891430925, 
              c[ 51][ t]], 
            Times[ 0.12496032289024853, 
              c[ 52][ t]], 
            Times[ 0.11643488132933186, 
              c[ 53][ t]], 
            Times[ 0.10337416789158595, 
              c[ 54][ t]], 
            Times[ 0.086542809078944891, 
              c[ 55][ t]], 
            Times[ 0.066820663127759972, 
              c[ 56][ t]], 
            Times[ 0.045163358568919114, 
              c[ 57][ t]], 
            Times[ 0.022561481809254869, 
              c[ 58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 59][ t]], 
            Times[ -0.021580547817548056, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "15", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[15]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.898171832519376`*^-17\ \(c[\(-60\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-59\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-58\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-57\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-56\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-55\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-54\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-53\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-52\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-51\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-50\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-49\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-48\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-47\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-46\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-44\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-43\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-42\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-41\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-40\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-39\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-38\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-37\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-36\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-35\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-34\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-33\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-32\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-31\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-30\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-29\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-28\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-27\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-26\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-25\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-24\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-23\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-22\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-21\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-20\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-19\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-18\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-17\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-14\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-13\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-12\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-11\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-10\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-9\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-8\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-7\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-6\)]\)[t] - 
            0.206748335783172`\ \(c[\(-5\)]\)[t] - 
            0.186750272222986`\ \(c[\(-4\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-3\)]\)[t] - 
            0.11423673049785445`\ \(c[\(-2\)]\)[t] - 
            0.06204407497545034`\ \(c[\(-1\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[0]\)[t] + 
            0.07090751425765762`\ \(c[1]\)[t] + 
            0.14938649372796362`\ \(c[2]\)[t] + 
            0.23387232094715985`\ \(c[3]\)[t] + 
            0.32256865202152135`\ \(c[4]\)[t] + 
            0.41349667156634395`\ \(c[5]\)[t] + 
            0.5045511524271047`\ \(c[6]\)[t] + 
            0.5935615337286803`\ \(c[7]\)[t] + 
            0.6783560385470633`\ \(c[8]\)[t] + 
            0.7568267286406569`\ \(c[9]\)[t] + 
            0.8269933431326881`\ \(c[10]\)[t] + 
            0.8870637930591838`\ \(c[11]\)[t] + 
            0.9354892837886392`\ \(c[12]\)[t] + 
            0.9710122092317629`\ \(c[13]\)[t] + 
            0.9927051996072067`\ \(c[14]\)[t] + 
            5.934802200544679`\ \(c[15]\)[t] + 
            0.9927051996072069`\ \(c[16]\)[t] + 
            0.9710122092317629`\ \(c[17]\)[t] + 
            0.9354892837886392`\ \(c[18]\)[t] + 
            0.8870637930591838`\ \(c[19]\)[t] + 
            0.8269933431326881`\ \(c[20]\)[t] + 
            0.7568267286406569`\ \(c[21]\)[t] + 
            0.6783560385470636`\ \(c[22]\)[t] + 
            0.5935615337286806`\ \(c[23]\)[t] + 
            0.5045511524271047`\ \(c[24]\)[t] + 
            0.4134966715663443`\ \(c[25]\)[t] + 
            0.3225686520215216`\ \(c[26]\)[t] + 
            0.23387232094715985`\ \(c[27]\)[t] + 
            0.14938649372796384`\ \(c[28]\)[t] + 
            0.07090751425765777`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.06204407497545024`\ \(c[31]\)[t] - 
            0.11423673049785436`\ \(c[32]\)[t] - 
            0.15591488063143982`\ \(c[33]\)[t] - 
            0.18675027222298593`\ \(c[34]\)[t] - 
            0.206748335783172`\ \(c[35]\)[t] - 
            0.21623620818304484`\ \(c[36]\)[t] - 
            0.21584055771952015`\ \(c[37]\)[t] - 
            0.20645618564475843`\ \(c[38]\)[t] - 
            0.18920668216016426`\ \(c[39]\)[t] - 
            0.1653986686265377`\ \(c[40]\)[t] - 
            0.13647135277833616`\ \(c[41]\)[t] - 
            0.10394325375429328`\ \(c[42]\)[t] - 
            0.06935801494512607`\ \(c[43]\)[t] - 
            0.034231213779559094`\ \(c[44]\)[t] - 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.032022748374425904`\ \(c[46]\)[t] + 
            0.060688263076985`\ \(c[47]\)[t] + 
            0.0850444803444217`\ \(c[48]\)[t] + 
            0.10436044624225685`\ \(c[49]\)[t] + 
            0.11814190616181253`\ \(c[50]\)[t] + 
            0.12613778810677614`\ \(c[51]\)[t] + 
            0.12833762891430928`\ \(c[52]\)[t] + 
            0.12496032289024853`\ \(c[53]\)[t] + 
            0.11643488132933186`\ \(c[54]\)[t] + 
            0.10337416789158609`\ \(c[55]\)[t] + 
            0.08654280907894489`\ \(c[56]\)[t] + 
            0.06682066312775997`\ \(c[57]\)[t] + 
            0.0451633585689193`\ \(c[58]\)[t] + 
            0.02256148180925487`\ \(c[59]\)[t] + 
            3.8981718325193755`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 15, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 15]][ t]], 
          Plus[ 
            Times[ 3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ 0.013414935129827233, 
              c[ -59][ t]], 
            Times[ 0.026603074225527826, 
              c[ -58][ t]], 
            Times[ 0.03897872015785999, 
              c[ -57][ t]], 
            Times[ 0.049975424961080865, 
              c[ -56][ t]], 
            Times[ 0.059070953080906326, 
              c[ -55][ t]], 
            Times[ 0.065811019881796273, 
              c[ -54][ t]], 
            Times[ 0.069830768673962415, 
              c[ -53][ t]], 
            Times[ 0.070873018952678238, 
              c[ -52][ t]], 
            Times[ 0.068802429876423349, 
              c[ -51][ t]], 
            Times[ 0.063614872548668253, 
              c[ -50][ t]], 
            Times[ 0.055441487066198933, 
              c[ -49][ t]], 
            Times[ 0.044547108751839919, 
              c[ -48][ t]], 
            Times[ 0.031322974491347078, 
              c[ -47][ t]], 
            Times[ 0.016273855731265604, 
              c[ -46][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ -0.016825511857749401, 
              c[ -44][ t]], 
            Times[ -0.033483179628681567, 
              c[ -43][ t]], 
            Times[ -0.049236278094138941, 
              c[ -42][ t]], 
            Times[ -0.063361699504227528, 
              c[ -41][ t]], 
            Times[ -0.075181213012062598, 
              c[ -40][ t]], 
            Times[ -0.084091858737850814, 
              c[ -39][ t]], 
            Times[ -0.089594193770366884, 
              c[ -38][ t]], 
            Times[ -0.091317159035181589, 
              c[ -37][ t]], 
            Times[ -0.089038438663606695, 
              c[ -36][ t]], 
            Times[ -0.082699334313268744, 
              c[ -35][ t]], 
            Times[ -0.072413370861974122, 
              c[ -34][ t]], 
            Times[ -0.058468080236789913, 
              c[ -33][ t]], 
            Times[ -0.04131966847794722, 
              c[ -32][ t]], 
            Times[ -0.021580547817547879, 
              c[ -31][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -30][ t]], 
            Times[ 0.022561481809254869, 
              c[ -29][ t]], 
            Times[ 0.045163358568919301, 
              c[ -28][ t]], 
            Times[ 0.066820663127759972, 
              c[ -27][ t]], 
            Times[ 0.086542809078944891, 
              c[ -26][ t]], 
            Times[ 0.10337416789158609, 
              c[ -25][ t]], 
            Times[ 0.11643488132933186, 
              c[ -24][ t]], 
            Times[ 0.12496032289024853, 
              c[ -23][ t]], 
            Times[ 0.12833762891430928, 
              c[ -22][ t]], 
            Times[ 0.12613778810677614, 
              c[ -21][ t]], 
            Times[ 0.11814190616181255, 
              c[ -20][ t]], 
            Times[ 0.10436044624225685, 
              c[ -19][ t]], 
            Times[ 0.085044480344421705, 
              c[ -18][ t]], 
            Times[ 0.060688263076985105, 
              c[ -17][ t]], 
            Times[ 0.032022748374425904, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.034231213779558949, 
              c[ -14][ t]], 
            Times[ -0.06935801494512607, 
              c[ -13][ t]], 
            Times[ -0.10394325375429328, 
              c[ -12][ t]], 
            Times[ -0.13647135277833605, 
              c[ -11][ t]], 
            Times[ -0.16539866862653771, 
              c[ -10][ t]], 
            Times[ -0.18920668216016426, 
              c[ -9][ t]], 
            Times[ -0.20645618564475843, 
              c[ -8][ t]], 
            Times[ -0.21584055771952015, 
              c[ -7][ t]], 
            Times[ -0.21623620818304484, 
              c[ -6][ t]], 
            Times[ -0.206748335783172, 
              c[ -5][ t]], 
            Times[ -0.18675027222298601, 
              c[ -4][ t]], 
            Times[ -0.15591488063143982, 
              c[ -3][ t]], 
            Times[ -0.11423673049785445, 
              c[ -2][ t]], 
            Times[ -0.062044074975450343, 
              c[ -1][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ 0.070907514257657622, 
              c[ 1][ t]], 
            Times[ 0.14938649372796362, 
              c[ 2][ t]], 
            Times[ 0.23387232094715985, 
              c[ 3][ t]], 
            Times[ 0.32256865202152135, 
              c[ 4][ t]], 
            Times[ 0.41349667156634395, 
              c[ 5][ t]], 
            Times[ 0.50455115242710469, 
              c[ 6][ t]], 
            Times[ 0.59356153372868026, 
              c[ 7][ t]], 
            Times[ 0.67835603854706328, 
              c[ 8][ t]], 
            Times[ 0.75682672864065692, 
              c[ 9][ t]], 
            Times[ 0.82699334313268813, 
              c[ 10][ t]], 
            Times[ 0.88706379305918381, 
              c[ 11][ t]], 
            Times[ 0.93548928378863916, 
              c[ 12][ t]], 
            Times[ 0.9710122092317629, 
              c[ 13][ t]], 
            Times[ 0.99270519960720671, 
              c[ 14][ t]], 
            Times[ 5.934802200544679, 
              c[ 15][ t]], 
            Times[ 0.99270519960720693, 
              c[ 16][ t]], 
            Times[ 0.9710122092317629, 
              c[ 17][ t]], 
            Times[ 0.93548928378863916, 
              c[ 18][ t]], 
            Times[ 0.88706379305918381, 
              c[ 19][ t]], 
            Times[ 0.82699334313268813, 
              c[ 20][ t]], 
            Times[ 0.75682672864065692, 
              c[ 21][ t]], 
            Times[ 0.67835603854706361, 
              c[ 22][ t]], 
            Times[ 0.59356153372868059, 
              c[ 23][ t]], 
            Times[ 0.50455115242710469, 
              c[ 24][ t]], 
            Times[ 0.41349667156634429, 
              c[ 25][ t]], 
            Times[ 0.32256865202152157, 
              c[ 26][ t]], 
            Times[ 0.23387232094715985, 
              c[ 27][ t]], 
            Times[ 0.14938649372796384, 
              c[ 28][ t]], 
            Times[ 0.070907514257657775, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.062044074975450239, 
              c[ 31][ t]], 
            Times[ -0.11423673049785436, 
              c[ 32][ t]], 
            Times[ -0.15591488063143982, 
              c[ 33][ t]], 
            Times[ -0.18675027222298593, 
              c[ 34][ t]], 
            Times[ -0.206748335783172, 
              c[ 35][ t]], 
            Times[ -0.21623620818304484, 
              c[ 36][ t]], 
            Times[ -0.21584055771952015, 
              c[ 37][ t]], 
            Times[ -0.20645618564475843, 
              c[ 38][ t]], 
            Times[ -0.18920668216016426, 
              c[ 39][ t]], 
            Times[ -0.16539866862653771, 
              c[ 40][ t]], 
            Times[ -0.13647135277833616, 
              c[ 41][ t]], 
            Times[ -0.10394325375429328, 
              c[ 42][ t]], 
            Times[ -0.06935801494512607, 
              c[ 43][ t]], 
            Times[ -0.034231213779559094, 
              c[ 44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.032022748374425904, 
              c[ 46][ t]], 
            Times[ 0.060688263076985001, 
              c[ 47][ t]], 
            Times[ 0.085044480344421705, 
              c[ 48][ t]], 
            Times[ 0.10436044624225685, 
              c[ 49][ t]], 
            Times[ 0.11814190616181253, 
              c[ 50][ t]], 
            Times[ 0.12613778810677614, 
              c[ 51][ t]], 
            Times[ 0.12833762891430928, 
              c[ 52][ t]], 
            Times[ 0.12496032289024853, 
              c[ 53][ t]], 
            Times[ 0.11643488132933186, 
              c[ 54][ t]], 
            Times[ 0.10337416789158609, 
              c[ 55][ t]], 
            Times[ 0.086542809078944891, 
              c[ 56][ t]], 
            Times[ 0.066820663127759972, 
              c[ 57][ t]], 
            Times[ 0.045163358568919301, 
              c[ 58][ t]], 
            Times[ 0.022561481809254869, 
              c[ 59][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "16", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[16]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.013061910521147383`\)\ \(c[\(-60\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-59\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-58\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-57\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-56\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-55\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-54\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-53\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-52\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-51\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-50\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-49\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-48\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-47\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-46\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-45\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-44\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-43\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-42\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-41\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-40\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-39\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-38\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-37\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-36\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-35\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-34\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-33\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-32\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-31\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-30\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-29\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-28\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-27\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-26\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-25\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-24\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-23\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-22\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-21\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-20\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-19\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-18\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-17\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-16\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-15\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-13\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-12\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-11\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-10\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-9\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-8\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-7\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-6\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-5\)]\)[t] - 
            0.206748335783172`\ \(c[\(-4\)]\)[t] - 
            0.186750272222986`\ \(c[\(-3\)]\)[t] - 
            0.15591488063143982`\ \(c[\(-2\)]\)[t] - 
            0.11423673049785436`\ \(c[\(-1\)]\)[t] - 
            0.06204407497545034`\ \(c[0]\)[t] + 
            3.898171832519376`*^-17\ \(c[1]\)[t] + 
            0.07090751425765777`\ \(c[2]\)[t] + 
            0.14938649372796362`\ \(c[3]\)[t] + 
            0.23387232094715985`\ \(c[4]\)[t] + 
            0.3225686520215216`\ \(c[5]\)[t] + 
            0.4134966715663442`\ \(c[6]\)[t] + 
            0.5045511524271047`\ \(c[7]\)[t] + 
            0.5935615337286805`\ \(c[8]\)[t] + 
            0.6783560385470634`\ \(c[9]\)[t] + 
            0.7568267286406569`\ \(c[10]\)[t] + 
            0.8269933431326881`\ \(c[11]\)[t] + 
            0.8870637930591838`\ \(c[12]\)[t] + 
            0.9354892837886392`\ \(c[13]\)[t] + 
            0.9710122092317629`\ \(c[14]\)[t] + 
            0.9927051996072069`\ \(c[15]\)[t] + 
            6.614708281508612`\ \(c[16]\)[t] + 
            0.9927051996072069`\ \(c[17]\)[t] + 
            0.9710122092317629`\ \(c[18]\)[t] + 
            0.9354892837886392`\ \(c[19]\)[t] + 
            0.8870637930591838`\ \(c[20]\)[t] + 
            0.8269933431326881`\ \(c[21]\)[t] + 
            0.7568267286406571`\ \(c[22]\)[t] + 
            0.6783560385470634`\ \(c[23]\)[t] + 
            0.5935615337286803`\ \(c[24]\)[t] + 
            0.5045511524271049`\ \(c[25]\)[t] + 
            0.4134966715663442`\ \(c[26]\)[t] + 
            0.32256865202152135`\ \(c[27]\)[t] + 
            0.23387232094715998`\ \(c[28]\)[t] + 
            0.14938649372796362`\ \(c[29]\)[t] + 
            0.07090751425765762`\ \(c[30]\)[t] + 
            1.8033970416801674`*^-16\ \(c[31]\)[t] - 
            0.06204407497545034`\ \(c[32]\)[t] - 
            0.11423673049785445`\ \(c[33]\)[t] - 
            0.15591488063143974`\ \(c[34]\)[t] - 
            0.186750272222986`\ \(c[35]\)[t] - 
            0.20674833578317206`\ \(c[36]\)[t] - 
            0.21623620818304484`\ \(c[37]\)[t] - 
            0.21584055771952015`\ \(c[38]\)[t] - 
            0.20645618564475834`\ \(c[39]\)[t] - 
            0.18920668216016426`\ \(c[40]\)[t] - 
            0.1653986686265377`\ \(c[41]\)[t] - 
            0.1364713527783359`\ \(c[42]\)[t] - 
            0.10394325375429328`\ \(c[43]\)[t] - 
            0.06935801494512607`\ \(c[44]\)[t] - 
            0.034231213779558796`\ \(c[45]\)[t] - 
            3.898171832519376`*^-17\ \(c[46]\)[t] + 
            0.032022748374425904`\ \(c[47]\)[t] + 
            0.06068826307698522`\ \(c[48]\)[t] + 
            0.0850444803444217`\ \(c[49]\)[t] + 
            0.10436044624225685`\ \(c[50]\)[t] + 
            0.1181419061618126`\ \(c[51]\)[t] + 
            0.12613778810677614`\ \(c[52]\)[t] + 
            0.12833762891430928`\ \(c[53]\)[t] + 
            0.12496032289024847`\ \(c[54]\)[t] + 
            0.11643488132933186`\ \(c[55]\)[t] + 
            0.10337416789158609`\ \(c[56]\)[t] + 
            0.08654280907894475`\ \(c[57]\)[t] + 
            0.06682066312775997`\ \(c[58]\)[t] + 
            0.0451633585689193`\ \(c[59]\)[t] + 
            0.022561481809254675`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 16, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 16]][ t]], 
          Plus[ 
            Times[ -0.013061910521147383, 
              c[ -60][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -59][ t]], 
            Times[ 0.013414935129827233, 
              c[ -58][ t]], 
            Times[ 0.026603074225527826, 
              c[ -57][ t]], 
            Times[ 0.038978720157860088, 
              c[ -56][ t]], 
            Times[ 0.049975424961080865, 
              c[ -55][ t]], 
            Times[ 0.059070953080906326, 
              c[ -54][ t]], 
            Times[ 0.065811019881796315, 
              c[ -53][ t]], 
            Times[ 0.069830768673962415, 
              c[ -52][ t]], 
            Times[ 0.070873018952678238, 
              c[ -51][ t]], 
            Times[ 0.068802429876423321, 
              c[ -50][ t]], 
            Times[ 0.063614872548668253, 
              c[ -49][ t]], 
            Times[ 0.055441487066198933, 
              c[ -48][ t]], 
            Times[ 0.044547108751839815, 
              c[ -47][ t]], 
            Times[ 0.031322974491347078, 
              c[ -46][ t]], 
            Times[ 0.016273855731265604, 
              c[ -45][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -44][ t]], 
            Times[ -0.016825511857749401, 
              c[ -43][ t]], 
            Times[ -0.033483179628681567, 
              c[ -42][ t]], 
            Times[ -0.049236278094139066, 
              c[ -41][ t]], 
            Times[ -0.063361699504227528, 
              c[ -40][ t]], 
            Times[ -0.075181213012062598, 
              c[ -39][ t]], 
            Times[ -0.084091858737850814, 
              c[ -38][ t]], 
            Times[ -0.089594193770366884, 
              c[ -37][ t]], 
            Times[ -0.091317159035181589, 
              c[ -36][ t]], 
            Times[ -0.089038438663606695, 
              c[ -35][ t]], 
            Times[ -0.082699334313268744, 
              c[ -34][ t]], 
            Times[ -0.072413370861974122, 
              c[ -33][ t]], 
            Times[ -0.058468080236789913, 
              c[ -32][ t]], 
            Times[ -0.04131966847794722, 
              c[ -31][ t]], 
            Times[ -0.021580547817547879, 
              c[ -30][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -29][ t]], 
            Times[ 0.022561481809254869, 
              c[ -28][ t]], 
            Times[ 0.045163358568919301, 
              c[ -27][ t]], 
            Times[ 0.066820663127759972, 
              c[ -26][ t]], 
            Times[ 0.086542809078944891, 
              c[ -25][ t]], 
            Times[ 0.10337416789158609, 
              c[ -24][ t]], 
            Times[ 0.11643488132933186, 
              c[ -23][ t]], 
            Times[ 0.12496032289024853, 
              c[ -22][ t]], 
            Times[ 0.12833762891430928, 
              c[ -21][ t]], 
            Times[ 0.12613778810677614, 
              c[ -20][ t]], 
            Times[ 0.11814190616181255, 
              c[ -19][ t]], 
            Times[ 0.10436044624225685, 
              c[ -18][ t]], 
            Times[ 0.085044480344421705, 
              c[ -17][ t]], 
            Times[ 0.060688263076985105, 
              c[ -16][ t]], 
            Times[ 0.032022748374425904, 
              c[ -15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.034231213779558949, 
              c[ -13][ t]], 
            Times[ -0.06935801494512607, 
              c[ -12][ t]], 
            Times[ -0.10394325375429328, 
              c[ -11][ t]], 
            Times[ -0.13647135277833605, 
              c[ -10][ t]], 
            Times[ -0.16539866862653771, 
              c[ -9][ t]], 
            Times[ -0.18920668216016426, 
              c[ -8][ t]], 
            Times[ -0.20645618564475843, 
              c[ -7][ t]], 
            Times[ -0.21584055771952015, 
              c[ -6][ t]], 
            Times[ -0.21623620818304484, 
              c[ -5][ t]], 
            Times[ -0.206748335783172, 
              c[ -4][ t]], 
            Times[ -0.18675027222298601, 
              c[ -3][ t]], 
            Times[ -0.15591488063143982, 
              c[ -2][ t]], 
            Times[ -0.11423673049785436, 
              c[ -1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 0][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 1][ t]], 
            Times[ 0.070907514257657775, 
              c[ 2][ t]], 
            Times[ 0.14938649372796362, 
              c[ 3][ t]], 
            Times[ 0.23387232094715985, 
              c[ 4][ t]], 
            Times[ 0.32256865202152157, 
              c[ 5][ t]], 
            Times[ 0.41349667156634418, 
              c[ 6][ t]], 
            Times[ 0.50455115242710469, 
              c[ 7][ t]], 
            Times[ 0.59356153372868048, 
              c[ 8][ t]], 
            Times[ 0.67835603854706339, 
              c[ 9][ t]], 
            Times[ 0.75682672864065692, 
              c[ 10][ t]], 
            Times[ 0.82699334313268813, 
              c[ 11][ t]], 
            Times[ 0.88706379305918381, 
              c[ 12][ t]], 
            Times[ 0.93548928378863916, 
              c[ 13][ t]], 
            Times[ 0.9710122092317629, 
              c[ 14][ t]], 
            Times[ 0.99270519960720693, 
              c[ 15][ t]], 
            Times[ 6.6147082815086122, 
              c[ 16][ t]], 
            Times[ 0.99270519960720693, 
              c[ 17][ t]], 
            Times[ 0.9710122092317629, 
              c[ 18][ t]], 
            Times[ 0.93548928378863916, 
              c[ 19][ t]], 
            Times[ 0.88706379305918381, 
              c[ 20][ t]], 
            Times[ 0.82699334313268813, 
              c[ 21][ t]], 
            Times[ 0.75682672864065714, 
              c[ 22][ t]], 
            Times[ 0.67835603854706339, 
              c[ 23][ t]], 
            Times[ 0.59356153372868026, 
              c[ 24][ t]], 
            Times[ 0.50455115242710491, 
              c[ 25][ t]], 
            Times[ 0.41349667156634418, 
              c[ 26][ t]], 
            Times[ 0.32256865202152135, 
              c[ 27][ t]], 
            Times[ 0.23387232094715998, 
              c[ 28][ t]], 
            Times[ 0.14938649372796362, 
              c[ 29][ t]], 
            Times[ 0.070907514257657622, 
              c[ 30][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 31][ t]], 
            Times[ -0.062044074975450343, 
              c[ 32][ t]], 
            Times[ -0.11423673049785445, 
              c[ 33][ t]], 
            Times[ -0.15591488063143974, 
              c[ 34][ t]], 
            Times[ -0.18675027222298601, 
              c[ 35][ t]], 
            Times[ -0.20674833578317206, 
              c[ 36][ t]], 
            Times[ -0.21623620818304484, 
              c[ 37][ t]], 
            Times[ -0.21584055771952015, 
              c[ 38][ t]], 
            Times[ -0.20645618564475834, 
              c[ 39][ t]], 
            Times[ -0.18920668216016426, 
              c[ 40][ t]], 
            Times[ -0.16539866862653771, 
              c[ 41][ t]], 
            Times[ -0.13647135277833591, 
              c[ 42][ t]], 
            Times[ -0.10394325375429328, 
              c[ 43][ t]], 
            Times[ -0.06935801494512607, 
              c[ 44][ t]], 
            Times[ -0.034231213779558796, 
              c[ 45][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ 0.032022748374425904, 
              c[ 47][ t]], 
            Times[ 0.060688263076985223, 
              c[ 48][ t]], 
            Times[ 0.085044480344421705, 
              c[ 49][ t]], 
            Times[ 0.10436044624225685, 
              c[ 50][ t]], 
            Times[ 0.1181419061618126, 
              c[ 51][ t]], 
            Times[ 0.12613778810677614, 
              c[ 52][ t]], 
            Times[ 0.12833762891430928, 
              c[ 53][ t]], 
            Times[ 0.12496032289024847, 
              c[ 54][ t]], 
            Times[ 0.11643488132933186, 
              c[ 55][ t]], 
            Times[ 0.10337416789158609, 
              c[ 56][ t]], 
            Times[ 0.086542809078944752, 
              c[ 57][ t]], 
            Times[ 0.066820663127759972, 
              c[ 58][ t]], 
            Times[ 0.045163358568919301, 
              c[ 59][ t]], 
            Times[ 0.022561481809254675, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "17", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[17]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.025221096343682053`\)\ \(c[\(-60\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-59\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-58\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-57\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-56\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-55\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-54\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-53\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-52\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-51\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-50\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-49\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-48\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-47\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-46\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-45\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-44\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-42\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-41\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-40\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-39\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-38\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-37\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-36\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-35\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-34\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-33\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-32\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-31\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-30\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-29\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-28\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-27\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-26\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-25\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-24\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-23\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-22\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-21\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-20\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-19\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-18\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-17\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-16\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-15\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-14\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-13\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-12\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-11\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-10\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-9\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-8\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-7\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-6\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-5\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-4\)]\)[t] - 
            0.206748335783172`\ \(c[\(-3\)]\)[t] - 
            0.186750272222986`\ \(c[\(-2\)]\)[t] - 
            0.15591488063143974`\ \(c[\(-1\)]\)[t] - 
            0.11423673049785436`\ \(c[0]\)[t] - 
            0.06204407497545034`\ \(c[1]\)[t] + 
            1.8033970416801674`*^-16\ \(c[2]\)[t] + 
            0.07090751425765777`\ \(c[3]\)[t] + 
            0.14938649372796362`\ \(c[4]\)[t] + 
            0.23387232094715985`\ \(c[5]\)[t] + 
            0.3225686520215216`\ \(c[6]\)[t] + 
            0.4134966715663442`\ \(c[7]\)[t] + 
            0.5045511524271047`\ \(c[8]\)[t] + 
            0.5935615337286806`\ \(c[9]\)[t] + 
            0.6783560385470634`\ \(c[10]\)[t] + 
            0.7568267286406569`\ \(c[11]\)[t] + 
            0.8269933431326881`\ \(c[12]\)[t] + 
            0.8870637930591838`\ \(c[13]\)[t] + 
            0.9354892837886392`\ \(c[14]\)[t] + 
            0.9710122092317629`\ \(c[15]\)[t] + 
            0.9927051996072069`\ \(c[16]\)[t] + 
            7.338479270921831`\ \(c[17]\)[t] + 
            0.9927051996072067`\ \(c[18]\)[t] + 
            0.9710122092317629`\ \(c[19]\)[t] + 
            0.9354892837886392`\ \(c[20]\)[t] + 
            0.8870637930591838`\ \(c[21]\)[t] + 
            0.8269933431326881`\ \(c[22]\)[t] + 
            0.7568267286406569`\ \(c[23]\)[t] + 
            0.6783560385470632`\ \(c[24]\)[t] + 
            0.5935615337286806`\ \(c[25]\)[t] + 
            0.5045511524271047`\ \(c[26]\)[t] + 
            0.41349667156634395`\ \(c[27]\)[t] + 
            0.3225686520215216`\ \(c[28]\)[t] + 
            0.23387232094715985`\ \(c[29]\)[t] + 
            0.14938649372796345`\ \(c[30]\)[t] + 
            0.07090751425765777`\ \(c[31]\)[t] + 
            3.898171832519376`*^-17\ \(c[32]\)[t] - 
            0.062044074975450475`\ \(c[33]\)[t] - 
            0.11423673049785436`\ \(c[34]\)[t] - 
            0.15591488063143982`\ \(c[35]\)[t] - 
            0.18675027222298607`\ \(c[36]\)[t] - 
            0.206748335783172`\ \(c[37]\)[t] - 
            0.21623620818304484`\ \(c[38]\)[t] - 
            0.21584055771952013`\ \(c[39]\)[t] - 
            0.20645618564475843`\ \(c[40]\)[t] - 
            0.18920668216016434`\ \(c[41]\)[t] - 
            0.1653986686265376`\ \(c[42]\)[t] - 
            0.13647135277833605`\ \(c[43]\)[t] - 
            0.1039432537542934`\ \(c[44]\)[t] - 
            0.06935801494512592`\ \(c[45]\)[t] - 
            0.03423121377955895`\ \(c[46]\)[t] - 
            1.8033970416801674`*^-16\ \(c[47]\)[t] + 
            0.03202274837442603`\ \(c[48]\)[t] + 
            0.060688263076985105`\ \(c[49]\)[t] + 
            0.08504448034442161`\ \(c[50]\)[t] + 
            0.10436044624225692`\ \(c[51]\)[t] + 
            0.11814190616181255`\ \(c[52]\)[t] + 
            0.12613778810677612`\ \(c[53]\)[t] + 
            0.12833762891430925`\ \(c[54]\)[t] + 
            0.12496032289024853`\ \(c[55]\)[t] + 
            0.11643488132933186`\ \(c[56]\)[t] + 
            0.10337416789158595`\ \(c[57]\)[t] + 
            0.08654280907894489`\ \(c[58]\)[t] + 
            0.06682066312775997`\ \(c[59]\)[t] + 
            0.045163358568919114`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 17, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 17]][ t]], 
          Plus[ 
            Times[ -0.025221096343682053, 
              c[ -60][ t]], 
            Times[ -0.013061910521147276, 
              c[ -59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -58][ t]], 
            Times[ 0.013414935129827233, 
              c[ -57][ t]], 
            Times[ 0.026603074225527937, 
              c[ -56][ t]], 
            Times[ 0.03897872015785999, 
              c[ -55][ t]], 
            Times[ 0.049975424961080865, 
              c[ -54][ t]], 
            Times[ 0.059070953080906402, 
              c[ -53][ t]], 
            Times[ 0.065811019881796273, 
              c[ -52][ t]], 
            Times[ 0.069830768673962415, 
              c[ -51][ t]], 
            Times[ 0.070873018952678238, 
              c[ -50][ t]], 
            Times[ 0.068802429876423349, 
              c[ -49][ t]], 
            Times[ 0.063614872548668253, 
              c[ -48][ t]], 
            Times[ 0.055441487066198857, 
              c[ -47][ t]], 
            Times[ 0.044547108751839919, 
              c[ -46][ t]], 
            Times[ 0.031322974491347078, 
              c[ -45][ t]], 
            Times[ 0.016273855731265469, 
              c[ -44][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ -0.016825511857749401, 
              c[ -42][ t]], 
            Times[ -0.033483179628681706, 
              c[ -41][ t]], 
            Times[ -0.049236278094138941, 
              c[ -40][ t]], 
            Times[ -0.063361699504227528, 
              c[ -39][ t]], 
            Times[ -0.075181213012062598, 
              c[ -38][ t]], 
            Times[ -0.084091858737850814, 
              c[ -37][ t]], 
            Times[ -0.089594193770366884, 
              c[ -36][ t]], 
            Times[ -0.091317159035181589, 
              c[ -35][ t]], 
            Times[ -0.089038438663606695, 
              c[ -34][ t]], 
            Times[ -0.082699334313268744, 
              c[ -33][ t]], 
            Times[ -0.072413370861974122, 
              c[ -32][ t]], 
            Times[ -0.058468080236789913, 
              c[ -31][ t]], 
            Times[ -0.04131966847794722, 
              c[ -30][ t]], 
            Times[ -0.021580547817547879, 
              c[ -29][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -28][ t]], 
            Times[ 0.022561481809254869, 
              c[ -27][ t]], 
            Times[ 0.045163358568919301, 
              c[ -26][ t]], 
            Times[ 0.066820663127759972, 
              c[ -25][ t]], 
            Times[ 0.086542809078944891, 
              c[ -24][ t]], 
            Times[ 0.10337416789158609, 
              c[ -23][ t]], 
            Times[ 0.11643488132933186, 
              c[ -22][ t]], 
            Times[ 0.12496032289024853, 
              c[ -21][ t]], 
            Times[ 0.12833762891430928, 
              c[ -20][ t]], 
            Times[ 0.12613778810677614, 
              c[ -19][ t]], 
            Times[ 0.11814190616181255, 
              c[ -18][ t]], 
            Times[ 0.10436044624225685, 
              c[ -17][ t]], 
            Times[ 0.085044480344421705, 
              c[ -16][ t]], 
            Times[ 0.060688263076985105, 
              c[ -15][ t]], 
            Times[ 0.032022748374425904, 
              c[ -14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -13][ t]], 
            Times[ -0.034231213779558949, 
              c[ -12][ t]], 
            Times[ -0.06935801494512607, 
              c[ -11][ t]], 
            Times[ -0.10394325375429328, 
              c[ -10][ t]], 
            Times[ -0.13647135277833605, 
              c[ -9][ t]], 
            Times[ -0.16539866862653771, 
              c[ -8][ t]], 
            Times[ -0.18920668216016426, 
              c[ -7][ t]], 
            Times[ -0.20645618564475843, 
              c[ -6][ t]], 
            Times[ -0.21584055771952015, 
              c[ -5][ t]], 
            Times[ -0.21623620818304484, 
              c[ -4][ t]], 
            Times[ -0.206748335783172, 
              c[ -3][ t]], 
            Times[ -0.18675027222298601, 
              c[ -2][ t]], 
            Times[ -0.15591488063143974, 
              c[ -1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 0][ t]], 
            Times[ -0.062044074975450343, 
              c[ 1][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 2][ t]], 
            Times[ 0.070907514257657775, 
              c[ 3][ t]], 
            Times[ 0.14938649372796362, 
              c[ 4][ t]], 
            Times[ 0.23387232094715985, 
              c[ 5][ t]], 
            Times[ 0.32256865202152157, 
              c[ 6][ t]], 
            Times[ 0.41349667156634418, 
              c[ 7][ t]], 
            Times[ 0.50455115242710469, 
              c[ 8][ t]], 
            Times[ 0.59356153372868059, 
              c[ 9][ t]], 
            Times[ 0.67835603854706339, 
              c[ 10][ t]], 
            Times[ 0.75682672864065692, 
              c[ 11][ t]], 
            Times[ 0.82699334313268813, 
              c[ 12][ t]], 
            Times[ 0.88706379305918381, 
              c[ 13][ t]], 
            Times[ 0.93548928378863916, 
              c[ 14][ t]], 
            Times[ 0.9710122092317629, 
              c[ 15][ t]], 
            Times[ 0.99270519960720693, 
              c[ 16][ t]], 
            Times[ 7.3384792709218312, 
              c[ 17][ t]], 
            Times[ 0.99270519960720671, 
              c[ 18][ t]], 
            Times[ 0.9710122092317629, 
              c[ 19][ t]], 
            Times[ 0.93548928378863916, 
              c[ 20][ t]], 
            Times[ 0.88706379305918381, 
              c[ 21][ t]], 
            Times[ 0.82699334313268813, 
              c[ 22][ t]], 
            Times[ 0.75682672864065692, 
              c[ 23][ t]], 
            Times[ 0.67835603854706317, 
              c[ 24][ t]], 
            Times[ 0.59356153372868059, 
              c[ 25][ t]], 
            Times[ 0.50455115242710469, 
              c[ 26][ t]], 
            Times[ 0.41349667156634395, 
              c[ 27][ t]], 
            Times[ 0.32256865202152157, 
              c[ 28][ t]], 
            Times[ 0.23387232094715985, 
              c[ 29][ t]], 
            Times[ 0.14938649372796345, 
              c[ 30][ t]], 
            Times[ 0.070907514257657775, 
              c[ 31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 32][ t]], 
            Times[ -0.062044074975450475, 
              c[ 33][ t]], 
            Times[ -0.11423673049785436, 
              c[ 34][ t]], 
            Times[ -0.15591488063143982, 
              c[ 35][ t]], 
            Times[ -0.18675027222298607, 
              c[ 36][ t]], 
            Times[ -0.206748335783172, 
              c[ 37][ t]], 
            Times[ -0.21623620818304484, 
              c[ 38][ t]], 
            Times[ -0.21584055771952013, 
              c[ 39][ t]], 
            Times[ -0.20645618564475843, 
              c[ 40][ t]], 
            Times[ -0.18920668216016434, 
              c[ 41][ t]], 
            Times[ -0.1653986686265376, 
              c[ 42][ t]], 
            Times[ -0.13647135277833605, 
              c[ 43][ t]], 
            Times[ -0.1039432537542934, 
              c[ 44][ t]], 
            Times[ -0.069358014945125918, 
              c[ 45][ t]], 
            Times[ -0.034231213779558949, 
              c[ 46][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 47][ t]], 
            Times[ 0.032022748374426029, 
              c[ 48][ t]], 
            Times[ 0.060688263076985105, 
              c[ 49][ t]], 
            Times[ 0.085044480344421608, 
              c[ 50][ t]], 
            Times[ 0.10436044624225692, 
              c[ 51][ t]], 
            Times[ 0.11814190616181255, 
              c[ 52][ t]], 
            Times[ 0.12613778810677612, 
              c[ 53][ t]], 
            Times[ 0.12833762891430925, 
              c[ 54][ t]], 
            Times[ 0.12496032289024853, 
              c[ 55][ t]], 
            Times[ 0.11643488132933186, 
              c[ 56][ t]], 
            Times[ 0.10337416789158595, 
              c[ 57][ t]], 
            Times[ 0.086542809078944891, 
              c[ 58][ t]], 
            Times[ 0.066820663127759972, 
              c[ 59][ t]], 
            Times[ 0.045163358568919114, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "18", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[18]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03598035706879378`\)\ \(c[\(-60\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-59\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-58\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-57\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-56\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-55\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-54\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-53\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-52\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-51\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-50\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-49\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-48\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-47\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-46\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-45\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-44\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-43\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-41\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-40\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-39\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-38\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-37\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-36\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-35\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-34\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-33\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-32\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-31\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-30\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-29\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-28\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-27\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-26\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-25\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-24\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-23\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-22\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-21\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-20\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-19\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-18\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-17\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-16\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-15\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-14\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-11\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-10\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-9\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-8\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-7\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-6\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-5\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-4\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-3\)]\)[t] - 
            0.206748335783172`\ \(c[\(-2\)]\)[t] - 
            0.186750272222986`\ \(c[\(-1\)]\)[t] - 
            0.15591488063143982`\ \(c[0]\)[t] - 
            0.11423673049785445`\ \(c[1]\)[t] - 
            0.06204407497545034`\ \(c[2]\)[t] + 
            3.898171832519376`*^-17\ \(c[3]\)[t] + 
            0.07090751425765762`\ \(c[4]\)[t] + 
            0.14938649372796345`\ \(c[5]\)[t] + 
            0.23387232094715985`\ \(c[6]\)[t] + 
            0.32256865202152135`\ \(c[7]\)[t] + 
            0.41349667156634395`\ \(c[8]\)[t] + 
            0.5045511524271047`\ \(c[9]\)[t] + 
            0.5935615337286803`\ \(c[10]\)[t] + 
            0.6783560385470632`\ \(c[11]\)[t] + 
            0.7568267286406569`\ \(c[12]\)[t] + 
            0.8269933431326881`\ \(c[13]\)[t] + 
            0.8870637930591838`\ \(c[14]\)[t] + 
            0.9354892837886392`\ \(c[15]\)[t] + 
            0.9710122092317629`\ \(c[16]\)[t] + 
            0.9927051996072067`\ \(c[17]\)[t] + 
            8.106115168784338`\ \(c[18]\)[t] + 
            0.9927051996072069`\ \(c[19]\)[t] + 
            0.9710122092317629`\ \(c[20]\)[t] + 
            0.9354892837886392`\ \(c[21]\)[t] + 
            0.8870637930591839`\ \(c[22]\)[t] + 
            0.8269933431326881`\ \(c[23]\)[t] + 
            0.7568267286406569`\ \(c[24]\)[t] + 
            0.6783560385470636`\ \(c[25]\)[t] + 
            0.5935615337286806`\ \(c[26]\)[t] + 
            0.5045511524271047`\ \(c[27]\)[t] + 
            0.4134966715663443`\ \(c[28]\)[t] + 
            0.3225686520215216`\ \(c[29]\)[t] + 
            0.23387232094715985`\ \(c[30]\)[t] + 
            0.14938649372796384`\ \(c[31]\)[t] + 
            0.07090751425765777`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] - 
            0.06204407497545024`\ \(c[34]\)[t] - 
            0.11423673049785436`\ \(c[35]\)[t] - 
            0.15591488063143982`\ \(c[36]\)[t] - 
            0.18675027222298593`\ \(c[37]\)[t] - 
            0.206748335783172`\ \(c[38]\)[t] - 
            0.21623620818304484`\ \(c[39]\)[t] - 
            0.21584055771952015`\ \(c[40]\)[t] - 
            0.20645618564475848`\ \(c[41]\)[t] - 
            0.18920668216016426`\ \(c[42]\)[t] - 
            0.1653986686265377`\ \(c[43]\)[t] - 
            0.13647135277833616`\ \(c[44]\)[t] - 
            0.10394325375429328`\ \(c[45]\)[t] - 
            0.06935801494512607`\ \(c[46]\)[t] - 
            0.034231213779559094`\ \(c[47]\)[t] - 
            3.898171832519376`*^-17\ \(c[48]\)[t] + 
            0.032022748374425904`\ \(c[49]\)[t] + 
            0.060688263076985`\ \(c[50]\)[t] + 
            0.0850444803444217`\ \(c[51]\)[t] + 
            0.10436044624225685`\ \(c[52]\)[t] + 
            0.11814190616181253`\ \(c[53]\)[t] + 
            0.12613778810677614`\ \(c[54]\)[t] + 
            0.12833762891430928`\ \(c[55]\)[t] + 
            0.12496032289024853`\ \(c[56]\)[t] + 
            0.11643488132933186`\ \(c[57]\)[t] + 
            0.10337416789158609`\ \(c[58]\)[t] + 
            0.08654280907894489`\ \(c[59]\)[t] + 
            0.06682066312775997`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 18, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 18]][ t]], 
          Plus[ 
            Times[ -0.035980357068793781, 
              c[ -60][ t]], 
            Times[ -0.025221096343682053, 
              c[ -59][ t]], 
            Times[ -0.013061910521147383, 
              c[ -58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -57][ t]], 
            Times[ 0.013414935129827233, 
              c[ -56][ t]], 
            Times[ 0.026603074225527826, 
              c[ -55][ t]], 
            Times[ 0.03897872015785999, 
              c[ -54][ t]], 
            Times[ 0.049975424961080865, 
              c[ -53][ t]], 
            Times[ 0.059070953080906326, 
              c[ -52][ t]], 
            Times[ 0.065811019881796273, 
              c[ -51][ t]], 
            Times[ 0.069830768673962415, 
              c[ -50][ t]], 
            Times[ 0.070873018952678238, 
              c[ -49][ t]], 
            Times[ 0.068802429876423349, 
              c[ -48][ t]], 
            Times[ 0.063614872548668253, 
              c[ -47][ t]], 
            Times[ 0.055441487066198933, 
              c[ -46][ t]], 
            Times[ 0.044547108751839919, 
              c[ -45][ t]], 
            Times[ 0.031322974491347078, 
              c[ -44][ t]], 
            Times[ 0.016273855731265604, 
              c[ -43][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ -0.016825511857749401, 
              c[ -41][ t]], 
            Times[ -0.033483179628681567, 
              c[ -40][ t]], 
            Times[ -0.049236278094138941, 
              c[ -39][ t]], 
            Times[ -0.063361699504227528, 
              c[ -38][ t]], 
            Times[ -0.075181213012062598, 
              c[ -37][ t]], 
            Times[ -0.084091858737850814, 
              c[ -36][ t]], 
            Times[ -0.089594193770366884, 
              c[ -35][ t]], 
            Times[ -0.091317159035181589, 
              c[ -34][ t]], 
            Times[ -0.089038438663606695, 
              c[ -33][ t]], 
            Times[ -0.082699334313268744, 
              c[ -32][ t]], 
            Times[ -0.072413370861974122, 
              c[ -31][ t]], 
            Times[ -0.058468080236789913, 
              c[ -30][ t]], 
            Times[ -0.04131966847794722, 
              c[ -29][ t]], 
            Times[ -0.021580547817547879, 
              c[ -28][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -27][ t]], 
            Times[ 0.022561481809254869, 
              c[ -26][ t]], 
            Times[ 0.045163358568919301, 
              c[ -25][ t]], 
            Times[ 0.066820663127759972, 
              c[ -24][ t]], 
            Times[ 0.086542809078944891, 
              c[ -23][ t]], 
            Times[ 0.10337416789158609, 
              c[ -22][ t]], 
            Times[ 0.11643488132933186, 
              c[ -21][ t]], 
            Times[ 0.12496032289024853, 
              c[ -20][ t]], 
            Times[ 0.12833762891430928, 
              c[ -19][ t]], 
            Times[ 0.12613778810677614, 
              c[ -18][ t]], 
            Times[ 0.11814190616181255, 
              c[ -17][ t]], 
            Times[ 0.10436044624225685, 
              c[ -16][ t]], 
            Times[ 0.085044480344421705, 
              c[ -15][ t]], 
            Times[ 0.060688263076985105, 
              c[ -14][ t]], 
            Times[ 0.032022748374425904, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.034231213779558949, 
              c[ -11][ t]], 
            Times[ -0.06935801494512607, 
              c[ -10][ t]], 
            Times[ -0.10394325375429328, 
              c[ -9][ t]], 
            Times[ -0.13647135277833605, 
              c[ -8][ t]], 
            Times[ -0.16539866862653771, 
              c[ -7][ t]], 
            Times[ -0.18920668216016426, 
              c[ -6][ t]], 
            Times[ -0.20645618564475843, 
              c[ -5][ t]], 
            Times[ -0.21584055771952013, 
              c[ -4][ t]], 
            Times[ -0.21623620818304484, 
              c[ -3][ t]], 
            Times[ -0.206748335783172, 
              c[ -2][ t]], 
            Times[ -0.18675027222298601, 
              c[ -1][ t]], 
            Times[ -0.15591488063143982, 
              c[ 0][ t]], 
            Times[ -0.11423673049785445, 
              c[ 1][ t]], 
            Times[ -0.062044074975450343, 
              c[ 2][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ 0.070907514257657622, 
              c[ 4][ t]], 
            Times[ 0.14938649372796345, 
              c[ 5][ t]], 
            Times[ 0.23387232094715985, 
              c[ 6][ t]], 
            Times[ 0.32256865202152135, 
              c[ 7][ t]], 
            Times[ 0.41349667156634395, 
              c[ 8][ t]], 
            Times[ 0.50455115242710469, 
              c[ 9][ t]], 
            Times[ 0.59356153372868026, 
              c[ 10][ t]], 
            Times[ 0.67835603854706317, 
              c[ 11][ t]], 
            Times[ 0.75682672864065692, 
              c[ 12][ t]], 
            Times[ 0.82699334313268813, 
              c[ 13][ t]], 
            Times[ 0.88706379305918381, 
              c[ 14][ t]], 
            Times[ 0.93548928378863916, 
              c[ 15][ t]], 
            Times[ 0.9710122092317629, 
              c[ 16][ t]], 
            Times[ 0.99270519960720671, 
              c[ 17][ t]], 
            Times[ 8.1061151687843385, 
              c[ 18][ t]], 
            Times[ 0.99270519960720693, 
              c[ 19][ t]], 
            Times[ 0.9710122092317629, 
              c[ 20][ t]], 
            Times[ 0.93548928378863916, 
              c[ 21][ t]], 
            Times[ 0.88706379305918392, 
              c[ 22][ t]], 
            Times[ 0.82699334313268813, 
              c[ 23][ t]], 
            Times[ 0.75682672864065692, 
              c[ 24][ t]], 
            Times[ 0.67835603854706361, 
              c[ 25][ t]], 
            Times[ 0.59356153372868059, 
              c[ 26][ t]], 
            Times[ 0.50455115242710469, 
              c[ 27][ t]], 
            Times[ 0.41349667156634429, 
              c[ 28][ t]], 
            Times[ 0.32256865202152157, 
              c[ 29][ t]], 
            Times[ 0.23387232094715985, 
              c[ 30][ t]], 
            Times[ 0.14938649372796384, 
              c[ 31][ t]], 
            Times[ 0.070907514257657775, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ -0.062044074975450239, 
              c[ 34][ t]], 
            Times[ -0.11423673049785436, 
              c[ 35][ t]], 
            Times[ -0.15591488063143982, 
              c[ 36][ t]], 
            Times[ -0.18675027222298593, 
              c[ 37][ t]], 
            Times[ -0.206748335783172, 
              c[ 38][ t]], 
            Times[ -0.21623620818304484, 
              c[ 39][ t]], 
            Times[ -0.21584055771952015, 
              c[ 40][ t]], 
            Times[ -0.20645618564475848, 
              c[ 41][ t]], 
            Times[ -0.18920668216016426, 
              c[ 42][ t]], 
            Times[ -0.16539866862653771, 
              c[ 43][ t]], 
            Times[ -0.13647135277833616, 
              c[ 44][ t]], 
            Times[ -0.10394325375429328, 
              c[ 45][ t]], 
            Times[ -0.06935801494512607, 
              c[ 46][ t]], 
            Times[ -0.034231213779559094, 
              c[ 47][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ 0.032022748374425904, 
              c[ 49][ t]], 
            Times[ 0.060688263076985001, 
              c[ 50][ t]], 
            Times[ 0.085044480344421705, 
              c[ 51][ t]], 
            Times[ 0.10436044624225685, 
              c[ 52][ t]], 
            Times[ 0.11814190616181253, 
              c[ 53][ t]], 
            Times[ 0.12613778810677614, 
              c[ 54][ t]], 
            Times[ 0.12833762891430928, 
              c[ 55][ t]], 
            Times[ 0.12496032289024853, 
              c[ 56][ t]], 
            Times[ 0.11643488132933186, 
              c[ 57][ t]], 
            Times[ 0.10337416789158609, 
              c[ 58][ t]], 
            Times[ 0.086542809078944891, 
              c[ 59][ t]], 
            Times[ 0.066820663127759972, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "19", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[19]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04491462243337642`\)\ \(c[\(-60\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-59\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-58\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-57\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-56\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-55\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-54\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-53\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-52\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-51\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-50\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-49\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-48\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-47\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-46\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-45\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-44\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-43\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-42\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-41\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-40\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-39\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-38\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-37\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-36\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-35\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-34\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-33\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-32\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-31\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-30\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-29\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-28\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-27\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-26\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-25\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-24\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-23\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-22\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-21\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-20\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-19\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-18\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-17\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-16\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-15\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-14\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-13\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-12\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-10\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-9\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-8\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-7\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-6\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-5\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-4\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-3\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-2\)]\)[t] - 
            0.206748335783172`\ \(c[\(-1\)]\)[t] - 
            0.186750272222986`\ \(c[0]\)[t] - 
            0.15591488063143982`\ \(c[1]\)[t] - 
            0.11423673049785436`\ \(c[2]\)[t] - 
            0.06204407497545034`\ \(c[3]\)[t] + 
            3.898171832519376`*^-17\ \(c[4]\)[t] + 
            0.07090751425765777`\ \(c[5]\)[t] + 
            0.14938649372796362`\ \(c[6]\)[t] + 
            0.23387232094715985`\ \(c[7]\)[t] + 
            0.3225686520215216`\ \(c[8]\)[t] + 
            0.4134966715663442`\ \(c[9]\)[t] + 
            0.5045511524271047`\ \(c[10]\)[t] + 
            0.5935615337286803`\ \(c[11]\)[t] + 
            0.6783560385470634`\ \(c[12]\)[t] + 
            0.7568267286406569`\ \(c[13]\)[t] + 
            0.8269933431326881`\ \(c[14]\)[t] + 
            0.8870637930591838`\ \(c[15]\)[t] + 
            0.9354892837886392`\ \(c[16]\)[t] + 
            0.9710122092317629`\ \(c[17]\)[t] + 
            0.9927051996072069`\ \(c[18]\)[t] + 
            8.91761597509613`\ \(c[19]\)[t] + 
            0.9927051996072069`\ \(c[20]\)[t] + 
            0.9710122092317629`\ \(c[21]\)[t] + 
            0.9354892837886394`\ \(c[22]\)[t] + 
            0.8870637930591838`\ \(c[23]\)[t] + 
            0.8269933431326881`\ \(c[24]\)[t] + 
            0.7568267286406571`\ \(c[25]\)[t] + 
            0.6783560385470634`\ \(c[26]\)[t] + 
            0.5935615337286803`\ \(c[27]\)[t] + 
            0.5045511524271049`\ \(c[28]\)[t] + 
            0.4134966715663442`\ \(c[29]\)[t] + 
            0.32256865202152135`\ \(c[30]\)[t] + 
            0.23387232094715998`\ \(c[31]\)[t] + 
            0.14938649372796362`\ \(c[32]\)[t] + 
            0.07090751425765762`\ \(c[33]\)[t] + 
            1.8033970416801674`*^-16\ \(c[34]\)[t] - 
            0.06204407497545034`\ \(c[35]\)[t] - 
            0.11423673049785445`\ \(c[36]\)[t] - 
            0.15591488063143974`\ \(c[37]\)[t] - 
            0.186750272222986`\ \(c[38]\)[t] - 
            0.20674833578317206`\ \(c[39]\)[t] - 
            0.21623620818304484`\ \(c[40]\)[t] - 
            0.21584055771952015`\ \(c[41]\)[t] - 
            0.20645618564475834`\ \(c[42]\)[t] - 
            0.18920668216016426`\ \(c[43]\)[t] - 
            0.1653986686265377`\ \(c[44]\)[t] - 
            0.1364713527783359`\ \(c[45]\)[t] - 
            0.10394325375429328`\ \(c[46]\)[t] - 
            0.06935801494512607`\ \(c[47]\)[t] - 
            0.034231213779558796`\ \(c[48]\)[t] - 
            3.898171832519376`*^-17\ \(c[49]\)[t] + 
            0.032022748374425904`\ \(c[50]\)[t] + 
            0.06068826307698522`\ \(c[51]\)[t] + 
            0.0850444803444217`\ \(c[52]\)[t] + 
            0.10436044624225685`\ \(c[53]\)[t] + 
            0.1181419061618126`\ \(c[54]\)[t] + 
            0.12613778810677614`\ \(c[55]\)[t] + 
            0.12833762891430928`\ \(c[56]\)[t] + 
            0.12496032289024847`\ \(c[57]\)[t] + 
            0.11643488132933186`\ \(c[58]\)[t] + 
            0.10337416789158609`\ \(c[59]\)[t] + 
            0.08654280907894475`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 19, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 19]][ t]], 
          Plus[ 
            Times[ -0.044914622433376419, 
              c[ -60][ t]], 
            Times[ -0.035980357068793781, 
              c[ -59][ t]], 
            Times[ -0.025221096343682053, 
              c[ -58][ t]], 
            Times[ -0.013061910521147383, 
              c[ -57][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -56][ t]], 
            Times[ 0.013414935129827233, 
              c[ -55][ t]], 
            Times[ 0.026603074225527826, 
              c[ -54][ t]], 
            Times[ 0.038978720157860088, 
              c[ -53][ t]], 
            Times[ 0.049975424961080865, 
              c[ -52][ t]], 
            Times[ 0.059070953080906326, 
              c[ -51][ t]], 
            Times[ 0.065811019881796315, 
              c[ -50][ t]], 
            Times[ 0.069830768673962415, 
              c[ -49][ t]], 
            Times[ 0.070873018952678238, 
              c[ -48][ t]], 
            Times[ 0.068802429876423321, 
              c[ -47][ t]], 
            Times[ 0.063614872548668253, 
              c[ -46][ t]], 
            Times[ 0.055441487066198933, 
              c[ -45][ t]], 
            Times[ 0.044547108751839815, 
              c[ -44][ t]], 
            Times[ 0.031322974491347078, 
              c[ -43][ t]], 
            Times[ 0.016273855731265604, 
              c[ -42][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -41][ t]], 
            Times[ -0.016825511857749401, 
              c[ -40][ t]], 
            Times[ -0.033483179628681567, 
              c[ -39][ t]], 
            Times[ -0.049236278094138941, 
              c[ -38][ t]], 
            Times[ -0.063361699504227528, 
              c[ -37][ t]], 
            Times[ -0.075181213012062598, 
              c[ -36][ t]], 
            Times[ -0.084091858737850814, 
              c[ -35][ t]], 
            Times[ -0.089594193770366884, 
              c[ -34][ t]], 
            Times[ -0.091317159035181589, 
              c[ -33][ t]], 
            Times[ -0.089038438663606695, 
              c[ -32][ t]], 
            Times[ -0.082699334313268744, 
              c[ -31][ t]], 
            Times[ -0.072413370861974122, 
              c[ -30][ t]], 
            Times[ -0.058468080236789913, 
              c[ -29][ t]], 
            Times[ -0.04131966847794722, 
              c[ -28][ t]], 
            Times[ -0.021580547817547879, 
              c[ -27][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -26][ t]], 
            Times[ 0.022561481809254869, 
              c[ -25][ t]], 
            Times[ 0.045163358568919301, 
              c[ -24][ t]], 
            Times[ 0.066820663127759972, 
              c[ -23][ t]], 
            Times[ 0.086542809078944891, 
              c[ -22][ t]], 
            Times[ 0.10337416789158609, 
              c[ -21][ t]], 
            Times[ 0.11643488132933186, 
              c[ -20][ t]], 
            Times[ 0.12496032289024853, 
              c[ -19][ t]], 
            Times[ 0.12833762891430928, 
              c[ -18][ t]], 
            Times[ 0.12613778810677614, 
              c[ -17][ t]], 
            Times[ 0.11814190616181255, 
              c[ -16][ t]], 
            Times[ 0.10436044624225685, 
              c[ -15][ t]], 
            Times[ 0.085044480344421705, 
              c[ -14][ t]], 
            Times[ 0.060688263076985105, 
              c[ -13][ t]], 
            Times[ 0.032022748374425904, 
              c[ -12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.034231213779558949, 
              c[ -10][ t]], 
            Times[ -0.06935801494512607, 
              c[ -9][ t]], 
            Times[ -0.10394325375429328, 
              c[ -8][ t]], 
            Times[ -0.13647135277833605, 
              c[ -7][ t]], 
            Times[ -0.16539866862653771, 
              c[ -6][ t]], 
            Times[ -0.18920668216016426, 
              c[ -5][ t]], 
            Times[ -0.20645618564475843, 
              c[ -4][ t]], 
            Times[ -0.21584055771952015, 
              c[ -3][ t]], 
            Times[ -0.21623620818304484, 
              c[ -2][ t]], 
            Times[ -0.206748335783172, 
              c[ -1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 0][ t]], 
            Times[ -0.15591488063143982, 
              c[ 1][ t]], 
            Times[ -0.11423673049785436, 
              c[ 2][ t]], 
            Times[ -0.062044074975450343, 
              c[ 3][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 4][ t]], 
            Times[ 0.070907514257657775, 
              c[ 5][ t]], 
            Times[ 0.14938649372796362, 
              c[ 6][ t]], 
            Times[ 0.23387232094715985, 
              c[ 7][ t]], 
            Times[ 0.32256865202152157, 
              c[ 8][ t]], 
            Times[ 0.41349667156634418, 
              c[ 9][ t]], 
            Times[ 0.50455115242710469, 
              c[ 10][ t]], 
            Times[ 0.59356153372868026, 
              c[ 11][ t]], 
            Times[ 0.67835603854706339, 
              c[ 12][ t]], 
            Times[ 0.75682672864065692, 
              c[ 13][ t]], 
            Times[ 0.82699334313268813, 
              c[ 14][ t]], 
            Times[ 0.88706379305918381, 
              c[ 15][ t]], 
            Times[ 0.93548928378863916, 
              c[ 16][ t]], 
            Times[ 0.9710122092317629, 
              c[ 17][ t]], 
            Times[ 0.99270519960720693, 
              c[ 18][ t]], 
            Times[ 8.9176159750961297, 
              c[ 19][ t]], 
            Times[ 0.99270519960720693, 
              c[ 20][ t]], 
            Times[ 0.9710122092317629, 
              c[ 21][ t]], 
            Times[ 0.93548928378863938, 
              c[ 22][ t]], 
            Times[ 0.88706379305918381, 
              c[ 23][ t]], 
            Times[ 0.82699334313268813, 
              c[ 24][ t]], 
            Times[ 0.75682672864065714, 
              c[ 25][ t]], 
            Times[ 0.67835603854706339, 
              c[ 26][ t]], 
            Times[ 0.59356153372868026, 
              c[ 27][ t]], 
            Times[ 0.50455115242710491, 
              c[ 28][ t]], 
            Times[ 0.41349667156634418, 
              c[ 29][ t]], 
            Times[ 0.32256865202152135, 
              c[ 30][ t]], 
            Times[ 0.23387232094715998, 
              c[ 31][ t]], 
            Times[ 0.14938649372796362, 
              c[ 32][ t]], 
            Times[ 0.070907514257657622, 
              c[ 33][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 34][ t]], 
            Times[ -0.062044074975450343, 
              c[ 35][ t]], 
            Times[ -0.11423673049785445, 
              c[ 36][ t]], 
            Times[ -0.15591488063143974, 
              c[ 37][ t]], 
            Times[ -0.18675027222298601, 
              c[ 38][ t]], 
            Times[ -0.20674833578317206, 
              c[ 39][ t]], 
            Times[ -0.21623620818304484, 
              c[ 40][ t]], 
            Times[ -0.21584055771952015, 
              c[ 41][ t]], 
            Times[ -0.20645618564475834, 
              c[ 42][ t]], 
            Times[ -0.18920668216016426, 
              c[ 43][ t]], 
            Times[ -0.16539866862653771, 
              c[ 44][ t]], 
            Times[ -0.13647135277833591, 
              c[ 45][ t]], 
            Times[ -0.10394325375429328, 
              c[ 46][ t]], 
            Times[ -0.06935801494512607, 
              c[ 47][ t]], 
            Times[ -0.034231213779558796, 
              c[ 48][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ 0.032022748374425904, 
              c[ 50][ t]], 
            Times[ 0.060688263076985223, 
              c[ 51][ t]], 
            Times[ 0.085044480344421705, 
              c[ 52][ t]], 
            Times[ 0.10436044624225685, 
              c[ 53][ t]], 
            Times[ 0.1181419061618126, 
              c[ 54][ t]], 
            Times[ 0.12613778810677614, 
              c[ 55][ t]], 
            Times[ 0.12833762891430928, 
              c[ 56][ t]], 
            Times[ 0.12496032289024847, 
              c[ 57][ t]], 
            Times[ 0.11643488132933186, 
              c[ 58][ t]], 
            Times[ 0.10337416789158609, 
              c[ 59][ t]], 
            Times[ 0.086542809078944752, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "20", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[20]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05168708394579296`\)\ \(c[\(-60\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-59\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-58\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-57\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-56\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-55\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-54\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-53\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-52\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-51\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-50\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-49\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-48\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-47\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-46\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-45\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-44\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-43\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-42\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-41\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-39\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-38\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-37\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-36\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-35\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-34\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-33\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-32\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-31\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-30\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-29\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-28\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-27\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-26\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-25\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-24\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-23\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-22\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-21\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-20\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-19\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-18\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-17\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-16\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-15\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-14\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-13\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-12\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-11\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-10\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-9\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-8\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-7\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-6\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-5\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-4\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-3\)]\)[t] - 
            0.21584055771952015`\ \(c[\(-2\)]\)[t] - 
            0.21623620818304484`\ \(c[\(-1\)]\)[t] - 
            0.206748335783172`\ \(c[0]\)[t] - 
            0.186750272222986`\ \(c[1]\)[t] - 
            0.15591488063143974`\ \(c[2]\)[t] - 
            0.11423673049785436`\ \(c[3]\)[t] - 
            0.06204407497545034`\ \(c[4]\)[t] + 
            3.898171832519376`*^-17\ \(c[5]\)[t] + 
            0.07090751425765777`\ \(c[6]\)[t] + 
            0.14938649372796362`\ \(c[7]\)[t] + 
            0.23387232094715985`\ \(c[8]\)[t] + 
            0.3225686520215216`\ \(c[9]\)[t] + 
            0.4134966715663442`\ \(c[10]\)[t] + 
            0.5045511524271047`\ \(c[11]\)[t] + 
            0.5935615337286806`\ \(c[12]\)[t] + 
            0.6783560385470634`\ \(c[13]\)[t] + 
            0.7568267286406569`\ \(c[14]\)[t] + 
            0.8269933431326881`\ \(c[15]\)[t] + 
            0.8870637930591838`\ \(c[16]\)[t] + 
            0.9354892837886392`\ \(c[17]\)[t] + 
            0.9710122092317629`\ \(c[18]\)[t] + 
            0.9927051996072069`\ \(c[19]\)[t] + 
            9.772981689857206`\ \(c[20]\)[t] + 
            0.9927051996072067`\ \(c[21]\)[t] + 
            0.9710122092317629`\ \(c[22]\)[t] + 
            0.9354892837886392`\ \(c[23]\)[t] + 
            0.8870637930591838`\ \(c[24]\)[t] + 
            0.8269933431326881`\ \(c[25]\)[t] + 
            0.7568267286406569`\ \(c[26]\)[t] + 
            0.6783560385470632`\ \(c[27]\)[t] + 
            0.5935615337286806`\ \(c[28]\)[t] + 
            0.5045511524271047`\ \(c[29]\)[t] + 
            0.41349667156634395`\ \(c[30]\)[t] + 
            0.3225686520215216`\ \(c[31]\)[t] + 
            0.23387232094715985`\ \(c[32]\)[t] + 
            0.14938649372796345`\ \(c[33]\)[t] + 
            0.07090751425765777`\ \(c[34]\)[t] + 
            3.898171832519376`*^-17\ \(c[35]\)[t] - 
            0.062044074975450475`\ \(c[36]\)[t] - 
            0.11423673049785436`\ \(c[37]\)[t] - 
            0.15591488063143982`\ \(c[38]\)[t] - 
            0.18675027222298607`\ \(c[39]\)[t] - 
            0.206748335783172`\ \(c[40]\)[t] - 
            0.21623620818304481`\ \(c[41]\)[t] - 
            0.21584055771952013`\ \(c[42]\)[t] - 
            0.20645618564475843`\ \(c[43]\)[t] - 
            0.18920668216016434`\ \(c[44]\)[t] - 
            0.1653986686265376`\ \(c[45]\)[t] - 
            0.13647135277833605`\ \(c[46]\)[t] - 
            0.1039432537542934`\ \(c[47]\)[t] - 
            0.06935801494512592`\ \(c[48]\)[t] - 
            0.03423121377955895`\ \(c[49]\)[t] - 
            1.8033970416801674`*^-16\ \(c[50]\)[t] + 
            0.03202274837442603`\ \(c[51]\)[t] + 
            0.060688263076985105`\ \(c[52]\)[t] + 
            0.08504448034442161`\ \(c[53]\)[t] + 
            0.10436044624225692`\ \(c[54]\)[t] + 
            0.11814190616181255`\ \(c[55]\)[t] + 
            0.12613778810677612`\ \(c[56]\)[t] + 
            0.12833762891430925`\ \(c[57]\)[t] + 
            0.12496032289024853`\ \(c[58]\)[t] + 
            0.11643488132933186`\ \(c[59]\)[t] + 
            0.10337416789158595`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 20, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 20]][ t]], 
          Plus[ 
            Times[ -0.05168708394579296, 
              c[ -60][ t]], 
            Times[ -0.044914622433376288, 
              c[ -59][ t]], 
            Times[ -0.035980357068793781, 
              c[ -58][ t]], 
            Times[ -0.025221096343682053, 
              c[ -57][ t]], 
            Times[ -0.013061910521147276, 
              c[ -56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -55][ t]], 
            Times[ 0.013414935129827233, 
              c[ -54][ t]], 
            Times[ 0.026603074225527937, 
              c[ -53][ t]], 
            Times[ 0.03897872015785999, 
              c[ -52][ t]], 
            Times[ 0.049975424961080865, 
              c[ -51][ t]], 
            Times[ 0.059070953080906402, 
              c[ -50][ t]], 
            Times[ 0.065811019881796273, 
              c[ -49][ t]], 
            Times[ 0.069830768673962415, 
              c[ -48][ t]], 
            Times[ 0.070873018952678238, 
              c[ -47][ t]], 
            Times[ 0.068802429876423349, 
              c[ -46][ t]], 
            Times[ 0.063614872548668253, 
              c[ -45][ t]], 
            Times[ 0.055441487066198857, 
              c[ -44][ t]], 
            Times[ 0.044547108751839919, 
              c[ -43][ t]], 
            Times[ 0.031322974491347078, 
              c[ -42][ t]], 
            Times[ 0.016273855731265469, 
              c[ -41][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ -0.016825511857749401, 
              c[ -39][ t]], 
            Times[ -0.033483179628681567, 
              c[ -38][ t]], 
            Times[ -0.049236278094138941, 
              c[ -37][ t]], 
            Times[ -0.063361699504227528, 
              c[ -36][ t]], 
            Times[ -0.075181213012062598, 
              c[ -35][ t]], 
            Times[ -0.084091858737850814, 
              c[ -34][ t]], 
            Times[ -0.089594193770366884, 
              c[ -33][ t]], 
            Times[ -0.091317159035181589, 
              c[ -32][ t]], 
            Times[ -0.089038438663606695, 
              c[ -31][ t]], 
            Times[ -0.082699334313268744, 
              c[ -30][ t]], 
            Times[ -0.072413370861974122, 
              c[ -29][ t]], 
            Times[ -0.058468080236789913, 
              c[ -28][ t]], 
            Times[ -0.04131966847794722, 
              c[ -27][ t]], 
            Times[ -0.021580547817547879, 
              c[ -26][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -25][ t]], 
            Times[ 0.022561481809254869, 
              c[ -24][ t]], 
            Times[ 0.045163358568919301, 
              c[ -23][ t]], 
            Times[ 0.066820663127759972, 
              c[ -22][ t]], 
            Times[ 0.086542809078944891, 
              c[ -21][ t]], 
            Times[ 0.10337416789158609, 
              c[ -20][ t]], 
            Times[ 0.11643488132933186, 
              c[ -19][ t]], 
            Times[ 0.12496032289024853, 
              c[ -18][ t]], 
            Times[ 0.12833762891430928, 
              c[ -17][ t]], 
            Times[ 0.12613778810677614, 
              c[ -16][ t]], 
            Times[ 0.11814190616181255, 
              c[ -15][ t]], 
            Times[ 0.10436044624225685, 
              c[ -14][ t]], 
            Times[ 0.085044480344421705, 
              c[ -13][ t]], 
            Times[ 0.060688263076985105, 
              c[ -12][ t]], 
            Times[ 0.032022748374425904, 
              c[ -11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -10][ t]], 
            Times[ -0.034231213779558949, 
              c[ -9][ t]], 
            Times[ -0.06935801494512607, 
              c[ -8][ t]], 
            Times[ -0.10394325375429328, 
              c[ -7][ t]], 
            Times[ -0.13647135277833605, 
              c[ -6][ t]], 
            Times[ -0.16539866862653771, 
              c[ -5][ t]], 
            Times[ -0.18920668216016426, 
              c[ -4][ t]], 
            Times[ -0.20645618564475843, 
              c[ -3][ t]], 
            Times[ -0.21584055771952015, 
              c[ -2][ t]], 
            Times[ -0.21623620818304484, 
              c[ -1][ t]], 
            Times[ -0.206748335783172, 
              c[ 0][ t]], 
            Times[ -0.18675027222298601, 
              c[ 1][ t]], 
            Times[ -0.15591488063143974, 
              c[ 2][ t]], 
            Times[ -0.11423673049785436, 
              c[ 3][ t]], 
            Times[ -0.062044074975450343, 
              c[ 4][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ 0.070907514257657775, 
              c[ 6][ t]], 
            Times[ 0.14938649372796362, 
              c[ 7][ t]], 
            Times[ 0.23387232094715985, 
              c[ 8][ t]], 
            Times[ 0.32256865202152157, 
              c[ 9][ t]], 
            Times[ 0.41349667156634418, 
              c[ 10][ t]], 
            Times[ 0.50455115242710469, 
              c[ 11][ t]], 
            Times[ 0.59356153372868059, 
              c[ 12][ t]], 
            Times[ 0.67835603854706339, 
              c[ 13][ t]], 
            Times[ 0.75682672864065692, 
              c[ 14][ t]], 
            Times[ 0.82699334313268813, 
              c[ 15][ t]], 
            Times[ 0.88706379305918381, 
              c[ 16][ t]], 
            Times[ 0.93548928378863916, 
              c[ 17][ t]], 
            Times[ 0.9710122092317629, 
              c[ 18][ t]], 
            Times[ 0.99270519960720693, 
              c[ 19][ t]], 
            Times[ 9.7729816898572057, 
              c[ 20][ t]], 
            Times[ 0.99270519960720671, 
              c[ 21][ t]], 
            Times[ 0.9710122092317629, 
              c[ 22][ t]], 
            Times[ 0.93548928378863916, 
              c[ 23][ t]], 
            Times[ 0.88706379305918381, 
              c[ 24][ t]], 
            Times[ 0.82699334313268813, 
              c[ 25][ t]], 
            Times[ 0.75682672864065692, 
              c[ 26][ t]], 
            Times[ 0.67835603854706317, 
              c[ 27][ t]], 
            Times[ 0.59356153372868059, 
              c[ 28][ t]], 
            Times[ 0.50455115242710469, 
              c[ 29][ t]], 
            Times[ 0.41349667156634395, 
              c[ 30][ t]], 
            Times[ 0.32256865202152157, 
              c[ 31][ t]], 
            Times[ 0.23387232094715985, 
              c[ 32][ t]], 
            Times[ 0.14938649372796345, 
              c[ 33][ t]], 
            Times[ 0.070907514257657775, 
              c[ 34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 35][ t]], 
            Times[ -0.062044074975450475, 
              c[ 36][ t]], 
            Times[ -0.11423673049785436, 
              c[ 37][ t]], 
            Times[ -0.15591488063143982, 
              c[ 38][ t]], 
            Times[ -0.18675027222298607, 
              c[ 39][ t]], 
            Times[ -0.206748335783172, 
              c[ 40][ t]], 
            Times[ -0.21623620818304481, 
              c[ 41][ t]], 
            Times[ -0.21584055771952013, 
              c[ 42][ t]], 
            Times[ -0.20645618564475843, 
              c[ 43][ t]], 
            Times[ -0.18920668216016434, 
              c[ 44][ t]], 
            Times[ -0.1653986686265376, 
              c[ 45][ t]], 
            Times[ -0.13647135277833605, 
              c[ 46][ t]], 
            Times[ -0.1039432537542934, 
              c[ 47][ t]], 
            Times[ -0.069358014945125918, 
              c[ 48][ t]], 
            Times[ -0.034231213779558949, 
              c[ 49][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 50][ t]], 
            Times[ 0.032022748374426029, 
              c[ 51][ t]], 
            Times[ 0.060688263076985105, 
              c[ 52][ t]], 
            Times[ 0.085044480344421608, 
              c[ 53][ t]], 
            Times[ 0.10436044624225692, 
              c[ 54][ t]], 
            Times[ 0.11814190616181255, 
              c[ 55][ t]], 
            Times[ 0.12613778810677612, 
              c[ 56][ t]], 
            Times[ 0.12833762891430925, 
              c[ 57][ t]], 
            Times[ 0.12496032289024853, 
              c[ 58][ t]], 
            Times[ 0.11643488132933186, 
              c[ 59][ t]], 
            Times[ 0.10337416789158595, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "21", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[21]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.056061239158567186`\)\ \(c[\(-60\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-59\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-58\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-57\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-56\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-55\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-54\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-53\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-52\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-51\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-50\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-49\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-48\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-47\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-46\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-45\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-44\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-43\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-42\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-41\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-40\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-38\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-37\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-36\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-35\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-34\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-33\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-32\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-31\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-30\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-29\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-28\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-27\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-26\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-25\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-24\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-23\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-22\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-21\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-20\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-19\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-18\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-17\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-16\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-15\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-14\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-13\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-12\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-11\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-8\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-7\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-6\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-5\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-4\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-3\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-2\)]\)[t] - 
            0.21584055771952013`\ \(c[\(-1\)]\)[t] - 
            0.21623620818304484`\ \(c[0]\)[t] - 
            0.206748335783172`\ \(c[1]\)[t] - 
            0.186750272222986`\ \(c[2]\)[t] - 
            0.15591488063143982`\ \(c[3]\)[t] - 
            0.11423673049785445`\ \(c[4]\)[t] - 
            0.062044074975450475`\ \(c[5]\)[t] + 
            3.898171832519376`*^-17\ \(c[6]\)[t] + 
            0.07090751425765762`\ \(c[7]\)[t] + 
            0.14938649372796345`\ \(c[8]\)[t] + 
            0.23387232094715985`\ \(c[9]\)[t] + 
            0.32256865202152135`\ \(c[10]\)[t] + 
            0.41349667156634395`\ \(c[11]\)[t] + 
            0.5045511524271047`\ \(c[12]\)[t] + 
            0.5935615337286803`\ \(c[13]\)[t] + 
            0.6783560385470632`\ \(c[14]\)[t] + 
            0.7568267286406569`\ \(c[15]\)[t] + 
            0.8269933431326881`\ \(c[16]\)[t] + 
            0.8870637930591838`\ \(c[17]\)[t] + 
            0.9354892837886392`\ \(c[18]\)[t] + 
            0.9710122092317629`\ \(c[19]\)[t] + 
            0.9927051996072067`\ \(c[20]\)[t] + 
            10.67221231306757`\ \(c[21]\)[t] + 
            0.9927051996072069`\ \(c[22]\)[t] + 
            0.9710122092317629`\ \(c[23]\)[t] + 
            0.9354892837886392`\ \(c[24]\)[t] + 
            0.8870637930591839`\ \(c[25]\)[t] + 
            0.8269933431326881`\ \(c[26]\)[t] + 
            0.7568267286406569`\ \(c[27]\)[t] + 
            0.6783560385470636`\ \(c[28]\)[t] + 
            0.5935615337286806`\ \(c[29]\)[t] + 
            0.5045511524271047`\ \(c[30]\)[t] + 
            0.4134966715663443`\ \(c[31]\)[t] + 
            0.3225686520215216`\ \(c[32]\)[t] + 
            0.23387232094715985`\ \(c[33]\)[t] + 
            0.14938649372796384`\ \(c[34]\)[t] + 
            0.07090751425765777`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] - 
            0.06204407497545024`\ \(c[37]\)[t] - 
            0.11423673049785436`\ \(c[38]\)[t] - 
            0.15591488063143982`\ \(c[39]\)[t] - 
            0.18675027222298593`\ \(c[40]\)[t] - 
            0.2067483357831719`\ \(c[41]\)[t] - 
            0.21623620818304484`\ \(c[42]\)[t] - 
            0.21584055771952015`\ \(c[43]\)[t] - 
            0.20645618564475848`\ \(c[44]\)[t] - 
            0.18920668216016426`\ \(c[45]\)[t] - 
            0.1653986686265377`\ \(c[46]\)[t] - 
            0.13647135277833616`\ \(c[47]\)[t] - 
            0.10394325375429328`\ \(c[48]\)[t] - 
            0.06935801494512607`\ \(c[49]\)[t] - 
            0.034231213779559094`\ \(c[50]\)[t] - 
            3.898171832519376`*^-17\ \(c[51]\)[t] + 
            0.032022748374425904`\ \(c[52]\)[t] + 
            0.060688263076985`\ \(c[53]\)[t] + 
            0.0850444803444217`\ \(c[54]\)[t] + 
            0.10436044624225685`\ \(c[55]\)[t] + 
            0.11814190616181253`\ \(c[56]\)[t] + 
            0.12613778810677614`\ \(c[57]\)[t] + 
            0.12833762891430928`\ \(c[58]\)[t] + 
            0.12496032289024853`\ \(c[59]\)[t] + 
            0.11643488132933186`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 21, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 21]][ t]], 
          Plus[ 
            Times[ -0.056061239158567186, 
              c[ -60][ t]], 
            Times[ -0.05168708394579296, 
              c[ -59][ t]], 
            Times[ -0.044914622433376419, 
              c[ -58][ t]], 
            Times[ -0.035980357068793781, 
              c[ -57][ t]], 
            Times[ -0.025221096343682053, 
              c[ -56][ t]], 
            Times[ -0.013061910521147383, 
              c[ -55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -54][ t]], 
            Times[ 0.013414935129827233, 
              c[ -53][ t]], 
            Times[ 0.026603074225527826, 
              c[ -52][ t]], 
            Times[ 0.03897872015785999, 
              c[ -51][ t]], 
            Times[ 0.049975424961080865, 
              c[ -50][ t]], 
            Times[ 0.059070953080906326, 
              c[ -49][ t]], 
            Times[ 0.065811019881796273, 
              c[ -48][ t]], 
            Times[ 0.069830768673962415, 
              c[ -47][ t]], 
            Times[ 0.070873018952678238, 
              c[ -46][ t]], 
            Times[ 0.068802429876423349, 
              c[ -45][ t]], 
            Times[ 0.063614872548668253, 
              c[ -44][ t]], 
            Times[ 0.055441487066198933, 
              c[ -43][ t]], 
            Times[ 0.044547108751839919, 
              c[ -42][ t]], 
            Times[ 0.031322974491347078, 
              c[ -41][ t]], 
            Times[ 0.016273855731265604, 
              c[ -40][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ -0.016825511857749401, 
              c[ -38][ t]], 
            Times[ -0.033483179628681567, 
              c[ -37][ t]], 
            Times[ -0.049236278094138941, 
              c[ -36][ t]], 
            Times[ -0.063361699504227528, 
              c[ -35][ t]], 
            Times[ -0.075181213012062598, 
              c[ -34][ t]], 
            Times[ -0.084091858737850814, 
              c[ -33][ t]], 
            Times[ -0.089594193770366884, 
              c[ -32][ t]], 
            Times[ -0.091317159035181589, 
              c[ -31][ t]], 
            Times[ -0.089038438663606695, 
              c[ -30][ t]], 
            Times[ -0.082699334313268744, 
              c[ -29][ t]], 
            Times[ -0.072413370861974122, 
              c[ -28][ t]], 
            Times[ -0.058468080236789913, 
              c[ -27][ t]], 
            Times[ -0.04131966847794722, 
              c[ -26][ t]], 
            Times[ -0.021580547817547879, 
              c[ -25][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -24][ t]], 
            Times[ 0.022561481809254869, 
              c[ -23][ t]], 
            Times[ 0.045163358568919301, 
              c[ -22][ t]], 
            Times[ 0.066820663127759972, 
              c[ -21][ t]], 
            Times[ 0.086542809078944891, 
              c[ -20][ t]], 
            Times[ 0.10337416789158609, 
              c[ -19][ t]], 
            Times[ 0.11643488132933186, 
              c[ -18][ t]], 
            Times[ 0.12496032289024853, 
              c[ -17][ t]], 
            Times[ 0.12833762891430928, 
              c[ -16][ t]], 
            Times[ 0.12613778810677614, 
              c[ -15][ t]], 
            Times[ 0.11814190616181255, 
              c[ -14][ t]], 
            Times[ 0.10436044624225685, 
              c[ -13][ t]], 
            Times[ 0.085044480344421705, 
              c[ -12][ t]], 
            Times[ 0.060688263076985105, 
              c[ -11][ t]], 
            Times[ 0.032022748374425904, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.034231213779558949, 
              c[ -8][ t]], 
            Times[ -0.06935801494512607, 
              c[ -7][ t]], 
            Times[ -0.10394325375429328, 
              c[ -6][ t]], 
            Times[ -0.13647135277833605, 
              c[ -5][ t]], 
            Times[ -0.1653986686265376, 
              c[ -4][ t]], 
            Times[ -0.18920668216016426, 
              c[ -3][ t]], 
            Times[ -0.20645618564475843, 
              c[ -2][ t]], 
            Times[ -0.21584055771952013, 
              c[ -1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 0][ t]], 
            Times[ -0.206748335783172, 
              c[ 1][ t]], 
            Times[ -0.18675027222298601, 
              c[ 2][ t]], 
            Times[ -0.15591488063143982, 
              c[ 3][ t]], 
            Times[ -0.11423673049785445, 
              c[ 4][ t]], 
            Times[ -0.062044074975450475, 
              c[ 5][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ 0.070907514257657622, 
              c[ 7][ t]], 
            Times[ 0.14938649372796345, 
              c[ 8][ t]], 
            Times[ 0.23387232094715985, 
              c[ 9][ t]], 
            Times[ 0.32256865202152135, 
              c[ 10][ t]], 
            Times[ 0.41349667156634395, 
              c[ 11][ t]], 
            Times[ 0.50455115242710469, 
              c[ 12][ t]], 
            Times[ 0.59356153372868026, 
              c[ 13][ t]], 
            Times[ 0.67835603854706317, 
              c[ 14][ t]], 
            Times[ 0.75682672864065692, 
              c[ 15][ t]], 
            Times[ 0.82699334313268813, 
              c[ 16][ t]], 
            Times[ 0.88706379305918381, 
              c[ 17][ t]], 
            Times[ 0.93548928378863916, 
              c[ 18][ t]], 
            Times[ 0.9710122092317629, 
              c[ 19][ t]], 
            Times[ 0.99270519960720671, 
              c[ 20][ t]], 
            Times[ 10.67221231306757, 
              c[ 21][ t]], 
            Times[ 0.99270519960720693, 
              c[ 22][ t]], 
            Times[ 0.9710122092317629, 
              c[ 23][ t]], 
            Times[ 0.93548928378863916, 
              c[ 24][ t]], 
            Times[ 0.88706379305918392, 
              c[ 25][ t]], 
            Times[ 0.82699334313268813, 
              c[ 26][ t]], 
            Times[ 0.75682672864065692, 
              c[ 27][ t]], 
            Times[ 0.67835603854706361, 
              c[ 28][ t]], 
            Times[ 0.59356153372868059, 
              c[ 29][ t]], 
            Times[ 0.50455115242710469, 
              c[ 30][ t]], 
            Times[ 0.41349667156634429, 
              c[ 31][ t]], 
            Times[ 0.32256865202152157, 
              c[ 32][ t]], 
            Times[ 0.23387232094715985, 
              c[ 33][ t]], 
            Times[ 0.14938649372796384, 
              c[ 34][ t]], 
            Times[ 0.070907514257657775, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ -0.062044074975450239, 
              c[ 37][ t]], 
            Times[ -0.11423673049785436, 
              c[ 38][ t]], 
            Times[ -0.15591488063143982, 
              c[ 39][ t]], 
            Times[ -0.18675027222298593, 
              c[ 40][ t]], 
            Times[ -0.20674833578317189, 
              c[ 41][ t]], 
            Times[ -0.21623620818304484, 
              c[ 42][ t]], 
            Times[ -0.21584055771952015, 
              c[ 43][ t]], 
            Times[ -0.20645618564475848, 
              c[ 44][ t]], 
            Times[ -0.18920668216016426, 
              c[ 45][ t]], 
            Times[ -0.16539866862653771, 
              c[ 46][ t]], 
            Times[ -0.13647135277833616, 
              c[ 47][ t]], 
            Times[ -0.10394325375429328, 
              c[ 48][ t]], 
            Times[ -0.06935801494512607, 
              c[ 49][ t]], 
            Times[ -0.034231213779559094, 
              c[ 50][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ 0.032022748374425904, 
              c[ 52][ t]], 
            Times[ 0.060688263076985001, 
              c[ 53][ t]], 
            Times[ 0.085044480344421705, 
              c[ 54][ t]], 
            Times[ 0.10436044624225685, 
              c[ 55][ t]], 
            Times[ 0.11814190616181253, 
              c[ 56][ t]], 
            Times[ 0.12613778810677614, 
              c[ 57][ t]], 
            Times[ 0.12833762891430928, 
              c[ 58][ t]], 
            Times[ 0.12496032289024853, 
              c[ 59][ t]], 
            Times[ 0.11643488132933186, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "22", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[22]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.0579084423149932`\)\ \(c[\(-60\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-59\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-58\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-57\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-56\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-55\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-54\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-53\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-52\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-51\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-50\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-49\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-48\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-47\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-46\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-45\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-44\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-43\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-42\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-41\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-40\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-39\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-37\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-36\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-35\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-34\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-33\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-32\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-31\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-30\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-29\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-28\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-27\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-26\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-25\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-24\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-23\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-22\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-21\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-20\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-19\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-18\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-17\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-16\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-15\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-14\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-13\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-12\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-11\)]\)[t] + 
            0.060688263076985`\ \(c[\(-10\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-9\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-8\)]\)[t] - 
            0.034231213779559094`\ \(c[\(-7\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-6\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-5\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-4\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-3\)]\)[t] - 
            0.18920668216016434`\ \(c[\(-2\)]\)[t] - 
            0.20645618564475843`\ \(c[\(-1\)]\)[t] - 
            0.21584055771952015`\ \(c[0]\)[t] - 
            0.21623620818304481`\ \(c[1]\)[t] - 
            0.206748335783172`\ \(c[2]\)[t] - 
            0.18675027222298593`\ \(c[3]\)[t] - 
            0.15591488063143974`\ \(c[4]\)[t] - 
            0.11423673049785436`\ \(c[5]\)[t] - 
            0.06204407497545024`\ \(c[6]\)[t] + 
            1.8033970416801674`*^-16\ \(c[7]\)[t] + 
            0.07090751425765777`\ \(c[8]\)[t] + 
            0.14938649372796384`\ \(c[9]\)[t] + 
            0.23387232094715998`\ \(c[10]\)[t] + 
            0.3225686520215216`\ \(c[11]\)[t] + 
            0.4134966715663443`\ \(c[12]\)[t] + 
            0.5045511524271049`\ \(c[13]\)[t] + 
            0.5935615337286806`\ \(c[14]\)[t] + 
            0.6783560385470636`\ \(c[15]\)[t] + 
            0.7568267286406571`\ \(c[16]\)[t] + 
            0.8269933431326881`\ \(c[17]\)[t] + 
            0.8870637930591839`\ \(c[18]\)[t] + 
            0.9354892837886394`\ \(c[19]\)[t] + 
            0.9710122092317629`\ \(c[20]\)[t] + 
            0.9927051996072069`\ \(c[21]\)[t] + 
            11.615307844727218`\ \(c[22]\)[t] + 
            0.9927051996072067`\ \(c[23]\)[t] + 
            0.9710122092317629`\ \(c[24]\)[t] + 
            0.9354892837886392`\ \(c[25]\)[t] + 
            0.8870637930591838`\ \(c[26]\)[t] + 
            0.826993343132688`\ \(c[27]\)[t] + 
            0.7568267286406569`\ \(c[28]\)[t] + 
            0.6783560385470632`\ \(c[29]\)[t] + 
            0.5935615337286801`\ \(c[30]\)[t] + 
            0.5045511524271047`\ \(c[31]\)[t] + 
            0.41349667156634395`\ \(c[32]\)[t] + 
            0.32256865202152113`\ \(c[33]\)[t] + 
            0.23387232094715985`\ \(c[34]\)[t] + 
            0.14938649372796345`\ \(c[35]\)[t] + 
            0.07090751425765746`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] - 
            0.062044074975450475`\ \(c[38]\)[t] - 
            0.11423673049785459`\ \(c[39]\)[t] - 
            0.15591488063143982`\ \(c[40]\)[t] - 
            0.18675027222298593`\ \(c[41]\)[t] - 
            0.20674833578317206`\ \(c[42]\)[t] - 
            0.21623620818304484`\ \(c[43]\)[t] - 
            0.21584055771952015`\ \(c[44]\)[t] - 
            0.20645618564475834`\ \(c[45]\)[t] - 
            0.18920668216016426`\ \(c[46]\)[t] - 
            0.1653986686265377`\ \(c[47]\)[t] - 
            0.1364713527783359`\ \(c[48]\)[t] - 
            0.10394325375429328`\ \(c[49]\)[t] - 
            0.06935801494512607`\ \(c[50]\)[t] - 
            0.034231213779558796`\ \(c[51]\)[t] - 
            3.898171832519376`*^-17\ \(c[52]\)[t] + 
            0.032022748374425904`\ \(c[53]\)[t] + 
            0.06068826307698522`\ \(c[54]\)[t] + 
            0.0850444803444217`\ \(c[55]\)[t] + 
            0.10436044624225685`\ \(c[56]\)[t] + 
            0.1181419061618126`\ \(c[57]\)[t] + 
            0.12613778810677614`\ \(c[58]\)[t] + 
            0.12833762891430928`\ \(c[59]\)[t] + 
            0.12496032289024847`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 22, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 22]][ t]], 
          Plus[ 
            Times[ -0.057908442314993203, 
              c[ -60][ t]], 
            Times[ -0.05606123915856713, 
              c[ -59][ t]], 
            Times[ -0.05168708394579296, 
              c[ -58][ t]], 
            Times[ -0.044914622433376419, 
              c[ -57][ t]], 
            Times[ -0.035980357068793781, 
              c[ -56][ t]], 
            Times[ -0.025221096343682053, 
              c[ -55][ t]], 
            Times[ -0.013061910521147383, 
              c[ -54][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -53][ t]], 
            Times[ 0.013414935129827233, 
              c[ -52][ t]], 
            Times[ 0.026603074225527826, 
              c[ -51][ t]], 
            Times[ 0.038978720157860088, 
              c[ -50][ t]], 
            Times[ 0.049975424961080865, 
              c[ -49][ t]], 
            Times[ 0.059070953080906326, 
              c[ -48][ t]], 
            Times[ 0.065811019881796315, 
              c[ -47][ t]], 
            Times[ 0.069830768673962415, 
              c[ -46][ t]], 
            Times[ 0.070873018952678238, 
              c[ -45][ t]], 
            Times[ 0.068802429876423321, 
              c[ -44][ t]], 
            Times[ 0.063614872548668253, 
              c[ -43][ t]], 
            Times[ 0.055441487066198933, 
              c[ -42][ t]], 
            Times[ 0.044547108751839815, 
              c[ -41][ t]], 
            Times[ 0.031322974491347078, 
              c[ -40][ t]], 
            Times[ 0.016273855731265604, 
              c[ -39][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ -0.016825511857749401, 
              c[ -37][ t]], 
            Times[ -0.033483179628681567, 
              c[ -36][ t]], 
            Times[ -0.049236278094138941, 
              c[ -35][ t]], 
            Times[ -0.063361699504227528, 
              c[ -34][ t]], 
            Times[ -0.075181213012062598, 
              c[ -33][ t]], 
            Times[ -0.084091858737850814, 
              c[ -32][ t]], 
            Times[ -0.089594193770366884, 
              c[ -31][ t]], 
            Times[ -0.091317159035181589, 
              c[ -30][ t]], 
            Times[ -0.089038438663606695, 
              c[ -29][ t]], 
            Times[ -0.082699334313268744, 
              c[ -28][ t]], 
            Times[ -0.072413370861974122, 
              c[ -27][ t]], 
            Times[ -0.058468080236789913, 
              c[ -26][ t]], 
            Times[ -0.04131966847794722, 
              c[ -25][ t]], 
            Times[ -0.021580547817547879, 
              c[ -24][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -23][ t]], 
            Times[ 0.022561481809254869, 
              c[ -22][ t]], 
            Times[ 0.045163358568919301, 
              c[ -21][ t]], 
            Times[ 0.066820663127759972, 
              c[ -20][ t]], 
            Times[ 0.086542809078944891, 
              c[ -19][ t]], 
            Times[ 0.10337416789158609, 
              c[ -18][ t]], 
            Times[ 0.11643488132933186, 
              c[ -17][ t]], 
            Times[ 0.12496032289024853, 
              c[ -16][ t]], 
            Times[ 0.12833762891430928, 
              c[ -15][ t]], 
            Times[ 0.12613778810677612, 
              c[ -14][ t]], 
            Times[ 0.11814190616181253, 
              c[ -13][ t]], 
            Times[ 0.10436044624225685, 
              c[ -12][ t]], 
            Times[ 0.085044480344421608, 
              c[ -11][ t]], 
            Times[ 0.060688263076985001, 
              c[ -10][ t]], 
            Times[ 0.032022748374425904, 
              c[ -9][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -8][ t]], 
            Times[ -0.034231213779559094, 
              c[ -7][ t]], 
            Times[ -0.06935801494512607, 
              c[ -6][ t]], 
            Times[ -0.1039432537542934, 
              c[ -5][ t]], 
            Times[ -0.13647135277833605, 
              c[ -4][ t]], 
            Times[ -0.16539866862653771, 
              c[ -3][ t]], 
            Times[ -0.18920668216016434, 
              c[ -2][ t]], 
            Times[ -0.20645618564475843, 
              c[ -1][ t]], 
            Times[ -0.21584055771952015, 
              c[ 0][ t]], 
            Times[ -0.21623620818304481, 
              c[ 1][ t]], 
            Times[ -0.206748335783172, 
              c[ 2][ t]], 
            Times[ -0.18675027222298593, 
              c[ 3][ t]], 
            Times[ -0.15591488063143974, 
              c[ 4][ t]], 
            Times[ -0.11423673049785436, 
              c[ 5][ t]], 
            Times[ -0.062044074975450239, 
              c[ 6][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 7][ t]], 
            Times[ 0.070907514257657775, 
              c[ 8][ t]], 
            Times[ 0.14938649372796384, 
              c[ 9][ t]], 
            Times[ 0.23387232094715998, 
              c[ 10][ t]], 
            Times[ 0.32256865202152157, 
              c[ 11][ t]], 
            Times[ 0.41349667156634429, 
              c[ 12][ t]], 
            Times[ 0.50455115242710491, 
              c[ 13][ t]], 
            Times[ 0.59356153372868059, 
              c[ 14][ t]], 
            Times[ 0.67835603854706361, 
              c[ 15][ t]], 
            Times[ 0.75682672864065714, 
              c[ 16][ t]], 
            Times[ 0.82699334313268813, 
              c[ 17][ t]], 
            Times[ 0.88706379305918392, 
              c[ 18][ t]], 
            Times[ 0.93548928378863938, 
              c[ 19][ t]], 
            Times[ 0.9710122092317629, 
              c[ 20][ t]], 
            Times[ 0.99270519960720693, 
              c[ 21][ t]], 
            Times[ 11.615307844727218, 
              c[ 22][ t]], 
            Times[ 0.99270519960720671, 
              c[ 23][ t]], 
            Times[ 0.9710122092317629, 
              c[ 24][ t]], 
            Times[ 0.93548928378863916, 
              c[ 25][ t]], 
            Times[ 0.88706379305918381, 
              c[ 26][ t]], 
            Times[ 0.82699334313268802, 
              c[ 27][ t]], 
            Times[ 0.75682672864065692, 
              c[ 28][ t]], 
            Times[ 0.67835603854706317, 
              c[ 29][ t]], 
            Times[ 0.59356153372868015, 
              c[ 30][ t]], 
            Times[ 0.50455115242710469, 
              c[ 31][ t]], 
            Times[ 0.41349667156634395, 
              c[ 32][ t]], 
            Times[ 0.32256865202152113, 
              c[ 33][ t]], 
            Times[ 0.23387232094715985, 
              c[ 34][ t]], 
            Times[ 0.14938649372796345, 
              c[ 35][ t]], 
            Times[ 0.070907514257657456, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ -0.062044074975450475, 
              c[ 38][ t]], 
            Times[ -0.11423673049785459, 
              c[ 39][ t]], 
            Times[ -0.15591488063143982, 
              c[ 40][ t]], 
            Times[ -0.18675027222298593, 
              c[ 41][ t]], 
            Times[ -0.20674833578317206, 
              c[ 42][ t]], 
            Times[ -0.21623620818304484, 
              c[ 43][ t]], 
            Times[ -0.21584055771952015, 
              c[ 44][ t]], 
            Times[ -0.20645618564475834, 
              c[ 45][ t]], 
            Times[ -0.18920668216016426, 
              c[ 46][ t]], 
            Times[ -0.16539866862653771, 
              c[ 47][ t]], 
            Times[ -0.13647135277833591, 
              c[ 48][ t]], 
            Times[ -0.10394325375429328, 
              c[ 49][ t]], 
            Times[ -0.06935801494512607, 
              c[ 50][ t]], 
            Times[ -0.034231213779558796, 
              c[ 51][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ 0.032022748374425904, 
              c[ 53][ t]], 
            Times[ 0.060688263076985223, 
              c[ 54][ t]], 
            Times[ 0.085044480344421705, 
              c[ 55][ t]], 
            Times[ 0.10436044624225685, 
              c[ 56][ t]], 
            Times[ 0.1181419061618126, 
              c[ 57][ t]], 
            Times[ 0.12613778810677614, 
              c[ 58][ t]], 
            Times[ 0.12833762891430928, 
              c[ 59][ t]], 
            Times[ 0.12496032289024847, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "23", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[23]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.05721075023890897`\)\ \(c[\(-60\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-59\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-58\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-57\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-56\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-55\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-54\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-53\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-52\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-51\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-50\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-49\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-48\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-47\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-46\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-45\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-44\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-43\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-42\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-41\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-40\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-39\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-38\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-36\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-35\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-34\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-33\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-32\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-31\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-30\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-29\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-28\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-27\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-26\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-25\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-24\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-23\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-22\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-21\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-20\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-19\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-18\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-17\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-16\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-15\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-14\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-13\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-12\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-11\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-10\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-9\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-8\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-7\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-6\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-5\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-4\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-3\)]\)[t] - 
            0.1653986686265377`\ \(c[\(-2\)]\)[t] - 
            0.18920668216016426`\ \(c[\(-1\)]\)[t] - 
            0.20645618564475843`\ \(c[0]\)[t] - 
            0.21584055771952015`\ \(c[1]\)[t] - 
            0.21623620818304484`\ \(c[2]\)[t] - 
            0.206748335783172`\ \(c[3]\)[t] - 
            0.186750272222986`\ \(c[4]\)[t] - 
            0.15591488063143982`\ \(c[5]\)[t] - 
            0.11423673049785436`\ \(c[6]\)[t] - 
            0.06204407497545034`\ \(c[7]\)[t] + 
            3.898171832519376`*^-17\ \(c[8]\)[t] + 
            0.07090751425765777`\ \(c[9]\)[t] + 
            0.14938649372796362`\ \(c[10]\)[t] + 
            0.23387232094715985`\ \(c[11]\)[t] + 
            0.3225686520215216`\ \(c[12]\)[t] + 
            0.4134966715663442`\ \(c[13]\)[t] + 
            0.5045511524271047`\ \(c[14]\)[t] + 
            0.5935615337286806`\ \(c[15]\)[t] + 
            0.6783560385470634`\ \(c[16]\)[t] + 
            0.7568267286406569`\ \(c[17]\)[t] + 
            0.8269933431326881`\ \(c[18]\)[t] + 
            0.8870637930591838`\ \(c[19]\)[t] + 
            0.9354892837886392`\ \(c[20]\)[t] + 
            0.9710122092317629`\ \(c[21]\)[t] + 
            0.9927051996072067`\ \(c[22]\)[t] + 
            12.602268284836155`\ \(c[23]\)[t] + 
            0.9927051996072067`\ \(c[24]\)[t] + 
            0.9710122092317629`\ \(c[25]\)[t] + 
            0.9354892837886392`\ \(c[26]\)[t] + 
            0.8870637930591838`\ \(c[27]\)[t] + 
            0.8269933431326881`\ \(c[28]\)[t] + 
            0.7568267286406569`\ \(c[29]\)[t] + 
            0.6783560385470632`\ \(c[30]\)[t] + 
            0.5935615337286806`\ \(c[31]\)[t] + 
            0.5045511524271047`\ \(c[32]\)[t] + 
            0.41349667156634395`\ \(c[33]\)[t] + 
            0.3225686520215216`\ \(c[34]\)[t] + 
            0.23387232094715985`\ \(c[35]\)[t] + 
            0.14938649372796345`\ \(c[36]\)[t] + 
            0.07090751425765777`\ \(c[37]\)[t] + 
            3.898171832519376`*^-17\ \(c[38]\)[t] - 
            0.062044074975450475`\ \(c[39]\)[t] - 
            0.11423673049785436`\ \(c[40]\)[t] - 
            0.15591488063143966`\ \(c[41]\)[t] - 
            0.18675027222298607`\ \(c[42]\)[t] - 
            0.206748335783172`\ \(c[43]\)[t] - 
            0.21623620818304481`\ \(c[44]\)[t] - 
            0.21584055771952013`\ \(c[45]\)[t] - 
            0.20645618564475843`\ \(c[46]\)[t] - 
            0.18920668216016434`\ \(c[47]\)[t] - 
            0.1653986686265376`\ \(c[48]\)[t] - 
            0.13647135277833605`\ \(c[49]\)[t] - 
            0.1039432537542934`\ \(c[50]\)[t] - 
            0.06935801494512592`\ \(c[51]\)[t] - 
            0.03423121377955895`\ \(c[52]\)[t] - 
            1.8033970416801674`*^-16\ \(c[53]\)[t] + 
            0.03202274837442603`\ \(c[54]\)[t] + 
            0.060688263076985105`\ \(c[55]\)[t] + 
            0.08504448034442161`\ \(c[56]\)[t] + 
            0.10436044624225692`\ \(c[57]\)[t] + 
            0.11814190616181255`\ \(c[58]\)[t] + 
            0.12613778810677612`\ \(c[59]\)[t] + 
            0.12833762891430925`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 23, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 23]][ t]], 
          Plus[ 
            Times[ -0.057210750238908967, 
              c[ -60][ t]], 
            Times[ -0.057908442314993203, 
              c[ -59][ t]], 
            Times[ -0.056061239158567186, 
              c[ -58][ t]], 
            Times[ -0.05168708394579296, 
              c[ -57][ t]], 
            Times[ -0.044914622433376288, 
              c[ -56][ t]], 
            Times[ -0.035980357068793781, 
              c[ -55][ t]], 
            Times[ -0.025221096343682053, 
              c[ -54][ t]], 
            Times[ -0.013061910521147276, 
              c[ -53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -52][ t]], 
            Times[ 0.013414935129827233, 
              c[ -51][ t]], 
            Times[ 0.026603074225527937, 
              c[ -50][ t]], 
            Times[ 0.03897872015785999, 
              c[ -49][ t]], 
            Times[ 0.049975424961080865, 
              c[ -48][ t]], 
            Times[ 0.059070953080906402, 
              c[ -47][ t]], 
            Times[ 0.065811019881796273, 
              c[ -46][ t]], 
            Times[ 0.069830768673962415, 
              c[ -45][ t]], 
            Times[ 0.070873018952678238, 
              c[ -44][ t]], 
            Times[ 0.068802429876423349, 
              c[ -43][ t]], 
            Times[ 0.063614872548668253, 
              c[ -42][ t]], 
            Times[ 0.055441487066198857, 
              c[ -41][ t]], 
            Times[ 0.044547108751839919, 
              c[ -40][ t]], 
            Times[ 0.031322974491347078, 
              c[ -39][ t]], 
            Times[ 0.016273855731265604, 
              c[ -38][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ -0.016825511857749401, 
              c[ -36][ t]], 
            Times[ -0.033483179628681567, 
              c[ -35][ t]], 
            Times[ -0.049236278094138941, 
              c[ -34][ t]], 
            Times[ -0.063361699504227528, 
              c[ -33][ t]], 
            Times[ -0.075181213012062598, 
              c[ -32][ t]], 
            Times[ -0.084091858737850814, 
              c[ -31][ t]], 
            Times[ -0.089594193770366884, 
              c[ -30][ t]], 
            Times[ -0.091317159035181589, 
              c[ -29][ t]], 
            Times[ -0.089038438663606695, 
              c[ -28][ t]], 
            Times[ -0.082699334313268744, 
              c[ -27][ t]], 
            Times[ -0.072413370861974122, 
              c[ -26][ t]], 
            Times[ -0.058468080236789913, 
              c[ -25][ t]], 
            Times[ -0.04131966847794722, 
              c[ -24][ t]], 
            Times[ -0.021580547817547879, 
              c[ -23][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -22][ t]], 
            Times[ 0.022561481809254869, 
              c[ -21][ t]], 
            Times[ 0.045163358568919301, 
              c[ -20][ t]], 
            Times[ 0.066820663127759972, 
              c[ -19][ t]], 
            Times[ 0.086542809078944891, 
              c[ -18][ t]], 
            Times[ 0.10337416789158609, 
              c[ -17][ t]], 
            Times[ 0.11643488132933186, 
              c[ -16][ t]], 
            Times[ 0.12496032289024853, 
              c[ -15][ t]], 
            Times[ 0.12833762891430928, 
              c[ -14][ t]], 
            Times[ 0.12613778810677614, 
              c[ -13][ t]], 
            Times[ 0.11814190616181255, 
              c[ -12][ t]], 
            Times[ 0.10436044624225685, 
              c[ -11][ t]], 
            Times[ 0.085044480344421705, 
              c[ -10][ t]], 
            Times[ 0.060688263076985105, 
              c[ -9][ t]], 
            Times[ 0.032022748374425904, 
              c[ -8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -7][ t]], 
            Times[ -0.034231213779558949, 
              c[ -6][ t]], 
            Times[ -0.06935801494512607, 
              c[ -5][ t]], 
            Times[ -0.10394325375429328, 
              c[ -4][ t]], 
            Times[ -0.13647135277833605, 
              c[ -3][ t]], 
            Times[ -0.16539866862653771, 
              c[ -2][ t]], 
            Times[ -0.18920668216016426, 
              c[ -1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 0][ t]], 
            Times[ -0.21584055771952015, 
              c[ 1][ t]], 
            Times[ -0.21623620818304484, 
              c[ 2][ t]], 
            Times[ -0.206748335783172, 
              c[ 3][ t]], 
            Times[ -0.18675027222298601, 
              c[ 4][ t]], 
            Times[ -0.15591488063143982, 
              c[ 5][ t]], 
            Times[ -0.11423673049785436, 
              c[ 6][ t]], 
            Times[ -0.062044074975450343, 
              c[ 7][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ 0.070907514257657775, 
              c[ 9][ t]], 
            Times[ 0.14938649372796362, 
              c[ 10][ t]], 
            Times[ 0.23387232094715985, 
              c[ 11][ t]], 
            Times[ 0.32256865202152157, 
              c[ 12][ t]], 
            Times[ 0.41349667156634418, 
              c[ 13][ t]], 
            Times[ 0.50455115242710469, 
              c[ 14][ t]], 
            Times[ 0.59356153372868059, 
              c[ 15][ t]], 
            Times[ 0.67835603854706339, 
              c[ 16][ t]], 
            Times[ 0.75682672864065692, 
              c[ 17][ t]], 
            Times[ 0.82699334313268813, 
              c[ 18][ t]], 
            Times[ 0.88706379305918381, 
              c[ 19][ t]], 
            Times[ 0.93548928378863916, 
              c[ 20][ t]], 
            Times[ 0.9710122092317629, 
              c[ 21][ t]], 
            Times[ 0.99270519960720671, 
              c[ 22][ t]], 
            Times[ 12.602268284836155, 
              c[ 23][ t]], 
            Times[ 0.99270519960720671, 
              c[ 24][ t]], 
            Times[ 0.9710122092317629, 
              c[ 25][ t]], 
            Times[ 0.93548928378863916, 
              c[ 26][ t]], 
            Times[ 0.88706379305918381, 
              c[ 27][ t]], 
            Times[ 0.82699334313268813, 
              c[ 28][ t]], 
            Times[ 0.75682672864065692, 
              c[ 29][ t]], 
            Times[ 0.67835603854706317, 
              c[ 30][ t]], 
            Times[ 0.59356153372868059, 
              c[ 31][ t]], 
            Times[ 0.50455115242710469, 
              c[ 32][ t]], 
            Times[ 0.41349667156634395, 
              c[ 33][ t]], 
            Times[ 0.32256865202152157, 
              c[ 34][ t]], 
            Times[ 0.23387232094715985, 
              c[ 35][ t]], 
            Times[ 0.14938649372796345, 
              c[ 36][ t]], 
            Times[ 0.070907514257657775, 
              c[ 37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 38][ t]], 
            Times[ -0.062044074975450475, 
              c[ 39][ t]], 
            Times[ -0.11423673049785436, 
              c[ 40][ t]], 
            Times[ -0.15591488063143966, 
              c[ 41][ t]], 
            Times[ -0.18675027222298607, 
              c[ 42][ t]], 
            Times[ -0.206748335783172, 
              c[ 43][ t]], 
            Times[ -0.21623620818304481, 
              c[ 44][ t]], 
            Times[ -0.21584055771952013, 
              c[ 45][ t]], 
            Times[ -0.20645618564475843, 
              c[ 46][ t]], 
            Times[ -0.18920668216016434, 
              c[ 47][ t]], 
            Times[ -0.1653986686265376, 
              c[ 48][ t]], 
            Times[ -0.13647135277833605, 
              c[ 49][ t]], 
            Times[ -0.1039432537542934, 
              c[ 50][ t]], 
            Times[ -0.069358014945125918, 
              c[ 51][ t]], 
            Times[ -0.034231213779558949, 
              c[ 52][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 53][ t]], 
            Times[ 0.032022748374426029, 
              c[ 54][ t]], 
            Times[ 0.060688263076985105, 
              c[ 55][ t]], 
            Times[ 0.085044480344421608, 
              c[ 56][ t]], 
            Times[ 0.10436044624225692, 
              c[ 57][ t]], 
            Times[ 0.11814190616181255, 
              c[ 58][ t]], 
            Times[ 0.12613778810677612, 
              c[ 59][ t]], 
            Times[ 0.12833762891430925, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "24", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[24]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.054059052045761224`\)\ \(c[\(-60\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-59\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-58\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-57\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-56\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-55\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-54\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-53\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-52\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-51\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-50\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-49\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-48\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-47\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-46\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-45\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-44\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-43\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-42\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-41\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-40\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-39\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-38\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-37\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-35\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-34\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-33\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-32\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-31\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-30\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-29\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-28\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-27\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-26\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-25\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-24\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-23\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-22\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-21\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-20\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-19\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-18\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-17\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-16\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-15\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-14\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-13\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-12\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-11\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-10\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-9\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-8\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-5\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-4\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-3\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-2\)]\)[t] - 
            0.1653986686265376`\ \(c[\(-1\)]\)[t] - 
            0.18920668216016426`\ \(c[0]\)[t] - 
            0.20645618564475843`\ \(c[1]\)[t] - 
            0.21584055771952013`\ \(c[2]\)[t] - 
            0.21623620818304484`\ \(c[3]\)[t] - 
            0.206748335783172`\ \(c[4]\)[t] - 
            0.18675027222298607`\ \(c[5]\)[t] - 
            0.15591488063143982`\ \(c[6]\)[t] - 
            0.11423673049785445`\ \(c[7]\)[t] - 
            0.062044074975450475`\ \(c[8]\)[t] + 
            3.898171832519376`*^-17\ \(c[9]\)[t] + 
            0.07090751425765762`\ \(c[10]\)[t] + 
            0.14938649372796345`\ \(c[11]\)[t] + 
            0.23387232094715985`\ \(c[12]\)[t] + 
            0.32256865202152135`\ \(c[13]\)[t] + 
            0.41349667156634395`\ \(c[14]\)[t] + 
            0.5045511524271047`\ \(c[15]\)[t] + 
            0.5935615337286803`\ \(c[16]\)[t] + 
            0.6783560385470632`\ \(c[17]\)[t] + 
            0.7568267286406569`\ \(c[18]\)[t] + 
            0.8269933431326881`\ \(c[19]\)[t] + 
            0.8870637930591838`\ \(c[20]\)[t] + 
            0.9354892837886392`\ \(c[21]\)[t] + 
            0.9710122092317629`\ \(c[22]\)[t] + 
            0.9927051996072067`\ \(c[23]\)[t] + 
            13.633093633394378`\ \(c[24]\)[t] + 
            0.9927051996072069`\ \(c[25]\)[t] + 
            0.9710122092317629`\ \(c[26]\)[t] + 
            0.9354892837886392`\ \(c[27]\)[t] + 
            0.8870637930591839`\ \(c[28]\)[t] + 
            0.8269933431326881`\ \(c[29]\)[t] + 
            0.7568267286406569`\ \(c[30]\)[t] + 
            0.6783560385470636`\ \(c[31]\)[t] + 
            0.5935615337286806`\ \(c[32]\)[t] + 
            0.5045511524271047`\ \(c[33]\)[t] + 
            0.4134966715663443`\ \(c[34]\)[t] + 
            0.3225686520215216`\ \(c[35]\)[t] + 
            0.23387232094715985`\ \(c[36]\)[t] + 
            0.14938649372796384`\ \(c[37]\)[t] + 
            0.07090751425765777`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] - 
            0.06204407497545024`\ \(c[40]\)[t] - 
            0.11423673049785416`\ \(c[41]\)[t] - 
            0.15591488063143982`\ \(c[42]\)[t] - 
            0.18675027222298593`\ \(c[43]\)[t] - 
            0.2067483357831719`\ \(c[44]\)[t] - 
            0.21623620818304484`\ \(c[45]\)[t] - 
            0.21584055771952015`\ \(c[46]\)[t] - 
            0.20645618564475848`\ \(c[47]\)[t] - 
            0.18920668216016426`\ \(c[48]\)[t] - 
            0.1653986686265377`\ \(c[49]\)[t] - 
            0.13647135277833616`\ \(c[50]\)[t] - 
            0.10394325375429328`\ \(c[51]\)[t] - 
            0.06935801494512607`\ \(c[52]\)[t] - 
            0.034231213779559094`\ \(c[53]\)[t] - 
            3.898171832519376`*^-17\ \(c[54]\)[t] + 
            0.032022748374425904`\ \(c[55]\)[t] + 
            0.060688263076985`\ \(c[56]\)[t] + 
            0.0850444803444217`\ \(c[57]\)[t] + 
            0.10436044624225685`\ \(c[58]\)[t] + 
            0.11814190616181253`\ \(c[59]\)[t] + 
            0.12613778810677614`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 24, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 24]][ t]], 
          Plus[ 
            Times[ -0.054059052045761224, 
              c[ -60][ t]], 
            Times[ -0.057210750238908967, 
              c[ -59][ t]], 
            Times[ -0.057908442314993203, 
              c[ -58][ t]], 
            Times[ -0.056061239158567186, 
              c[ -57][ t]], 
            Times[ -0.05168708394579296, 
              c[ -56][ t]], 
            Times[ -0.044914622433376419, 
              c[ -55][ t]], 
            Times[ -0.035980357068793781, 
              c[ -54][ t]], 
            Times[ -0.025221096343682053, 
              c[ -53][ t]], 
            Times[ -0.013061910521147383, 
              c[ -52][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -51][ t]], 
            Times[ 0.013414935129827233, 
              c[ -50][ t]], 
            Times[ 0.026603074225527826, 
              c[ -49][ t]], 
            Times[ 0.03897872015785999, 
              c[ -48][ t]], 
            Times[ 0.049975424961080865, 
              c[ -47][ t]], 
            Times[ 0.059070953080906326, 
              c[ -46][ t]], 
            Times[ 0.065811019881796273, 
              c[ -45][ t]], 
            Times[ 0.069830768673962415, 
              c[ -44][ t]], 
            Times[ 0.070873018952678238, 
              c[ -43][ t]], 
            Times[ 0.068802429876423349, 
              c[ -42][ t]], 
            Times[ 0.063614872548668253, 
              c[ -41][ t]], 
            Times[ 0.055441487066198933, 
              c[ -40][ t]], 
            Times[ 0.044547108751839919, 
              c[ -39][ t]], 
            Times[ 0.031322974491347078, 
              c[ -38][ t]], 
            Times[ 0.016273855731265604, 
              c[ -37][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ -0.016825511857749401, 
              c[ -35][ t]], 
            Times[ -0.033483179628681567, 
              c[ -34][ t]], 
            Times[ -0.049236278094138941, 
              c[ -33][ t]], 
            Times[ -0.063361699504227528, 
              c[ -32][ t]], 
            Times[ -0.075181213012062598, 
              c[ -31][ t]], 
            Times[ -0.084091858737850814, 
              c[ -30][ t]], 
            Times[ -0.089594193770366884, 
              c[ -29][ t]], 
            Times[ -0.091317159035181589, 
              c[ -28][ t]], 
            Times[ -0.089038438663606695, 
              c[ -27][ t]], 
            Times[ -0.082699334313268744, 
              c[ -26][ t]], 
            Times[ -0.072413370861974122, 
              c[ -25][ t]], 
            Times[ -0.058468080236789913, 
              c[ -24][ t]], 
            Times[ -0.04131966847794722, 
              c[ -23][ t]], 
            Times[ -0.021580547817547879, 
              c[ -22][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -21][ t]], 
            Times[ 0.022561481809254869, 
              c[ -20][ t]], 
            Times[ 0.045163358568919301, 
              c[ -19][ t]], 
            Times[ 0.066820663127759972, 
              c[ -18][ t]], 
            Times[ 0.086542809078944891, 
              c[ -17][ t]], 
            Times[ 0.10337416789158609, 
              c[ -16][ t]], 
            Times[ 0.11643488132933186, 
              c[ -15][ t]], 
            Times[ 0.12496032289024853, 
              c[ -14][ t]], 
            Times[ 0.12833762891430928, 
              c[ -13][ t]], 
            Times[ 0.12613778810677614, 
              c[ -12][ t]], 
            Times[ 0.11814190616181255, 
              c[ -11][ t]], 
            Times[ 0.10436044624225685, 
              c[ -10][ t]], 
            Times[ 0.085044480344421705, 
              c[ -9][ t]], 
            Times[ 0.060688263076985105, 
              c[ -8][ t]], 
            Times[ 0.032022748374425904, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.034231213779558949, 
              c[ -5][ t]], 
            Times[ -0.069358014945125918, 
              c[ -4][ t]], 
            Times[ -0.10394325375429328, 
              c[ -3][ t]], 
            Times[ -0.13647135277833605, 
              c[ -2][ t]], 
            Times[ -0.1653986686265376, 
              c[ -1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 0][ t]], 
            Times[ -0.20645618564475843, 
              c[ 1][ t]], 
            Times[ -0.21584055771952013, 
              c[ 2][ t]], 
            Times[ -0.21623620818304484, 
              c[ 3][ t]], 
            Times[ -0.206748335783172, 
              c[ 4][ t]], 
            Times[ -0.18675027222298607, 
              c[ 5][ t]], 
            Times[ -0.15591488063143982, 
              c[ 6][ t]], 
            Times[ -0.11423673049785445, 
              c[ 7][ t]], 
            Times[ -0.062044074975450475, 
              c[ 8][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ 0.070907514257657622, 
              c[ 10][ t]], 
            Times[ 0.14938649372796345, 
              c[ 11][ t]], 
            Times[ 0.23387232094715985, 
              c[ 12][ t]], 
            Times[ 0.32256865202152135, 
              c[ 13][ t]], 
            Times[ 0.41349667156634395, 
              c[ 14][ t]], 
            Times[ 0.50455115242710469, 
              c[ 15][ t]], 
            Times[ 0.59356153372868026, 
              c[ 16][ t]], 
            Times[ 0.67835603854706317, 
              c[ 17][ t]], 
            Times[ 0.75682672864065692, 
              c[ 18][ t]], 
            Times[ 0.82699334313268813, 
              c[ 19][ t]], 
            Times[ 0.88706379305918381, 
              c[ 20][ t]], 
            Times[ 0.93548928378863916, 
              c[ 21][ t]], 
            Times[ 0.9710122092317629, 
              c[ 22][ t]], 
            Times[ 0.99270519960720671, 
              c[ 23][ t]], 
            Times[ 13.633093633394378, 
              c[ 24][ t]], 
            Times[ 0.99270519960720693, 
              c[ 25][ t]], 
            Times[ 0.9710122092317629, 
              c[ 26][ t]], 
            Times[ 0.93548928378863916, 
              c[ 27][ t]], 
            Times[ 0.88706379305918392, 
              c[ 28][ t]], 
            Times[ 0.82699334313268813, 
              c[ 29][ t]], 
            Times[ 0.75682672864065692, 
              c[ 30][ t]], 
            Times[ 0.67835603854706361, 
              c[ 31][ t]], 
            Times[ 0.59356153372868059, 
              c[ 32][ t]], 
            Times[ 0.50455115242710469, 
              c[ 33][ t]], 
            Times[ 0.41349667156634429, 
              c[ 34][ t]], 
            Times[ 0.32256865202152157, 
              c[ 35][ t]], 
            Times[ 0.23387232094715985, 
              c[ 36][ t]], 
            Times[ 0.14938649372796384, 
              c[ 37][ t]], 
            Times[ 0.070907514257657775, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ -0.062044074975450239, 
              c[ 40][ t]], 
            Times[ -0.11423673049785416, 
              c[ 41][ t]], 
            Times[ -0.15591488063143982, 
              c[ 42][ t]], 
            Times[ -0.18675027222298593, 
              c[ 43][ t]], 
            Times[ -0.20674833578317189, 
              c[ 44][ t]], 
            Times[ -0.21623620818304484, 
              c[ 45][ t]], 
            Times[ -0.21584055771952015, 
              c[ 46][ t]], 
            Times[ -0.20645618564475848, 
              c[ 47][ t]], 
            Times[ -0.18920668216016426, 
              c[ 48][ t]], 
            Times[ -0.16539866862653771, 
              c[ 49][ t]], 
            Times[ -0.13647135277833616, 
              c[ 50][ t]], 
            Times[ -0.10394325375429328, 
              c[ 51][ t]], 
            Times[ -0.06935801494512607, 
              c[ 52][ t]], 
            Times[ -0.034231213779559094, 
              c[ 53][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ 0.032022748374425904, 
              c[ 55][ t]], 
            Times[ 0.060688263076985001, 
              c[ 56][ t]], 
            Times[ 0.085044480344421705, 
              c[ 57][ t]], 
            Times[ 0.10436044624225685, 
              c[ 58][ t]], 
            Times[ 0.11814190616181253, 
              c[ 59][ t]], 
            Times[ 0.12613778810677614, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "25", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[25]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04864666724309928`\)\ \(c[\(-60\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-59\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-58\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-57\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-56\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-55\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-54\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-53\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-52\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-51\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-50\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-49\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-48\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-47\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-46\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-45\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-44\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-43\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-42\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-41\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-40\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-39\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-38\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-37\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-36\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-34\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-33\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-32\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-31\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-30\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-29\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-28\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-27\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-26\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-25\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-24\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-23\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-22\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-21\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-20\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-19\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-18\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-17\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-16\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-15\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-14\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-13\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-12\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-11\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-10\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-9\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-8\)]\)[t] + 
            0.060688263076985`\ \(c[\(-7\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-6\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-5\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-4\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-3\)]\)[t] - 
            0.1039432537542934`\ \(c[\(-2\)]\)[t] - 
            0.13647135277833605`\ \(c[\(-1\)]\)[t] - 
            0.1653986686265377`\ \(c[0]\)[t] - 
            0.18920668216016434`\ \(c[1]\)[t] - 
            0.20645618564475843`\ \(c[2]\)[t] - 
            0.21584055771952015`\ \(c[3]\)[t] - 
            0.21623620818304481`\ \(c[4]\)[t] - 
            0.206748335783172`\ \(c[5]\)[t] - 
            0.18675027222298593`\ \(c[6]\)[t] - 
            0.15591488063143974`\ \(c[7]\)[t] - 
            0.11423673049785436`\ \(c[8]\)[t] - 
            0.06204407497545024`\ \(c[9]\)[t] + 
            1.8033970416801674`*^-16\ \(c[10]\)[t] + 
            0.07090751425765777`\ \(c[11]\)[t] + 
            0.14938649372796384`\ \(c[12]\)[t] + 
            0.23387232094715998`\ \(c[13]\)[t] + 
            0.3225686520215216`\ \(c[14]\)[t] + 
            0.4134966715663443`\ \(c[15]\)[t] + 
            0.5045511524271049`\ \(c[16]\)[t] + 
            0.5935615337286806`\ \(c[17]\)[t] + 
            0.6783560385470636`\ \(c[18]\)[t] + 
            0.7568267286406571`\ \(c[19]\)[t] + 
            0.8269933431326881`\ \(c[20]\)[t] + 
            0.8870637930591839`\ \(c[21]\)[t] + 
            0.9354892837886392`\ \(c[22]\)[t] + 
            0.9710122092317629`\ \(c[23]\)[t] + 
            0.9927051996072069`\ \(c[24]\)[t] + 
            14.707783890401883`\ \(c[25]\)[t] + 
            0.9927051996072067`\ \(c[26]\)[t] + 
            0.9710122092317629`\ \(c[27]\)[t] + 
            0.9354892837886392`\ \(c[28]\)[t] + 
            0.8870637930591838`\ \(c[29]\)[t] + 
            0.826993343132688`\ \(c[30]\)[t] + 
            0.7568267286406569`\ \(c[31]\)[t] + 
            0.6783560385470632`\ \(c[32]\)[t] + 
            0.5935615337286801`\ \(c[33]\)[t] + 
            0.5045511524271047`\ \(c[34]\)[t] + 
            0.41349667156634395`\ \(c[35]\)[t] + 
            0.32256865202152113`\ \(c[36]\)[t] + 
            0.23387232094715985`\ \(c[37]\)[t] + 
            0.14938649372796345`\ \(c[38]\)[t] + 
            0.07090751425765746`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] - 
            0.06204407497545024`\ \(c[41]\)[t] - 
            0.11423673049785459`\ \(c[42]\)[t] - 
            0.15591488063143982`\ \(c[43]\)[t] - 
            0.18675027222298593`\ \(c[44]\)[t] - 
            0.20674833578317206`\ \(c[45]\)[t] - 
            0.21623620818304484`\ \(c[46]\)[t] - 
            0.21584055771952015`\ \(c[47]\)[t] - 
            0.20645618564475834`\ \(c[48]\)[t] - 
            0.18920668216016426`\ \(c[49]\)[t] - 
            0.1653986686265377`\ \(c[50]\)[t] - 
            0.1364713527783359`\ \(c[51]\)[t] - 
            0.10394325375429328`\ \(c[52]\)[t] - 
            0.06935801494512607`\ \(c[53]\)[t] - 
            0.034231213779558796`\ \(c[54]\)[t] - 
            3.898171832519376`*^-17\ \(c[55]\)[t] + 
            0.032022748374425904`\ \(c[56]\)[t] + 
            0.06068826307698522`\ \(c[57]\)[t] + 
            0.0850444803444217`\ \(c[58]\)[t] + 
            0.10436044624225685`\ \(c[59]\)[t] + 
            0.1181419061618126`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 25, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 25]][ t]], 
          Plus[ 
            Times[ -0.048646667243099281, 
              c[ -60][ t]], 
            Times[ -0.054059052045761224, 
              c[ -59][ t]], 
            Times[ -0.057210750238908967, 
              c[ -58][ t]], 
            Times[ -0.057908442314993203, 
              c[ -57][ t]], 
            Times[ -0.05606123915856713, 
              c[ -56][ t]], 
            Times[ -0.05168708394579296, 
              c[ -55][ t]], 
            Times[ -0.044914622433376419, 
              c[ -54][ t]], 
            Times[ -0.035980357068793781, 
              c[ -53][ t]], 
            Times[ -0.025221096343682053, 
              c[ -52][ t]], 
            Times[ -0.013061910521147383, 
              c[ -51][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -50][ t]], 
            Times[ 0.013414935129827233, 
              c[ -49][ t]], 
            Times[ 0.026603074225527826, 
              c[ -48][ t]], 
            Times[ 0.038978720157860088, 
              c[ -47][ t]], 
            Times[ 0.049975424961080865, 
              c[ -46][ t]], 
            Times[ 0.059070953080906326, 
              c[ -45][ t]], 
            Times[ 0.065811019881796315, 
              c[ -44][ t]], 
            Times[ 0.069830768673962415, 
              c[ -43][ t]], 
            Times[ 0.070873018952678238, 
              c[ -42][ t]], 
            Times[ 0.068802429876423321, 
              c[ -41][ t]], 
            Times[ 0.063614872548668253, 
              c[ -40][ t]], 
            Times[ 0.055441487066198933, 
              c[ -39][ t]], 
            Times[ 0.044547108751839919, 
              c[ -38][ t]], 
            Times[ 0.031322974491347078, 
              c[ -37][ t]], 
            Times[ 0.016273855731265604, 
              c[ -36][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ -0.016825511857749401, 
              c[ -34][ t]], 
            Times[ -0.033483179628681567, 
              c[ -33][ t]], 
            Times[ -0.049236278094138941, 
              c[ -32][ t]], 
            Times[ -0.063361699504227528, 
              c[ -31][ t]], 
            Times[ -0.075181213012062598, 
              c[ -30][ t]], 
            Times[ -0.084091858737850814, 
              c[ -29][ t]], 
            Times[ -0.089594193770366884, 
              c[ -28][ t]], 
            Times[ -0.091317159035181589, 
              c[ -27][ t]], 
            Times[ -0.089038438663606695, 
              c[ -26][ t]], 
            Times[ -0.082699334313268744, 
              c[ -25][ t]], 
            Times[ -0.072413370861974122, 
              c[ -24][ t]], 
            Times[ -0.058468080236789913, 
              c[ -23][ t]], 
            Times[ -0.04131966847794722, 
              c[ -22][ t]], 
            Times[ -0.021580547817547879, 
              c[ -21][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -20][ t]], 
            Times[ 0.022561481809254869, 
              c[ -19][ t]], 
            Times[ 0.045163358568919301, 
              c[ -18][ t]], 
            Times[ 0.066820663127759972, 
              c[ -17][ t]], 
            Times[ 0.086542809078944891, 
              c[ -16][ t]], 
            Times[ 0.10337416789158609, 
              c[ -15][ t]], 
            Times[ 0.11643488132933186, 
              c[ -14][ t]], 
            Times[ 0.12496032289024853, 
              c[ -13][ t]], 
            Times[ 0.12833762891430928, 
              c[ -12][ t]], 
            Times[ 0.12613778810677612, 
              c[ -11][ t]], 
            Times[ 0.11814190616181253, 
              c[ -10][ t]], 
            Times[ 0.10436044624225685, 
              c[ -9][ t]], 
            Times[ 0.085044480344421608, 
              c[ -8][ t]], 
            Times[ 0.060688263076985001, 
              c[ -7][ t]], 
            Times[ 0.032022748374425904, 
              c[ -6][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -5][ t]], 
            Times[ -0.034231213779558949, 
              c[ -4][ t]], 
            Times[ -0.06935801494512607, 
              c[ -3][ t]], 
            Times[ -0.1039432537542934, 
              c[ -2][ t]], 
            Times[ -0.13647135277833605, 
              c[ -1][ t]], 
            Times[ -0.16539866862653771, 
              c[ 0][ t]], 
            Times[ -0.18920668216016434, 
              c[ 1][ t]], 
            Times[ -0.20645618564475843, 
              c[ 2][ t]], 
            Times[ -0.21584055771952015, 
              c[ 3][ t]], 
            Times[ -0.21623620818304481, 
              c[ 4][ t]], 
            Times[ -0.206748335783172, 
              c[ 5][ t]], 
            Times[ -0.18675027222298593, 
              c[ 6][ t]], 
            Times[ -0.15591488063143974, 
              c[ 7][ t]], 
            Times[ -0.11423673049785436, 
              c[ 8][ t]], 
            Times[ -0.062044074975450239, 
              c[ 9][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 10][ t]], 
            Times[ 0.070907514257657775, 
              c[ 11][ t]], 
            Times[ 0.14938649372796384, 
              c[ 12][ t]], 
            Times[ 0.23387232094715998, 
              c[ 13][ t]], 
            Times[ 0.32256865202152157, 
              c[ 14][ t]], 
            Times[ 0.41349667156634429, 
              c[ 15][ t]], 
            Times[ 0.50455115242710491, 
              c[ 16][ t]], 
            Times[ 0.59356153372868059, 
              c[ 17][ t]], 
            Times[ 0.67835603854706361, 
              c[ 18][ t]], 
            Times[ 0.75682672864065714, 
              c[ 19][ t]], 
            Times[ 0.82699334313268813, 
              c[ 20][ t]], 
            Times[ 0.88706379305918392, 
              c[ 21][ t]], 
            Times[ 0.93548928378863916, 
              c[ 22][ t]], 
            Times[ 0.9710122092317629, 
              c[ 23][ t]], 
            Times[ 0.99270519960720693, 
              c[ 24][ t]], 
            Times[ 14.707783890401883, 
              c[ 25][ t]], 
            Times[ 0.99270519960720671, 
              c[ 26][ t]], 
            Times[ 0.9710122092317629, 
              c[ 27][ t]], 
            Times[ 0.93548928378863916, 
              c[ 28][ t]], 
            Times[ 0.88706379305918381, 
              c[ 29][ t]], 
            Times[ 0.82699334313268802, 
              c[ 30][ t]], 
            Times[ 0.75682672864065692, 
              c[ 31][ t]], 
            Times[ 0.67835603854706317, 
              c[ 32][ t]], 
            Times[ 0.59356153372868015, 
              c[ 33][ t]], 
            Times[ 0.50455115242710469, 
              c[ 34][ t]], 
            Times[ 0.41349667156634395, 
              c[ 35][ t]], 
            Times[ 0.32256865202152113, 
              c[ 36][ t]], 
            Times[ 0.23387232094715985, 
              c[ 37][ t]], 
            Times[ 0.14938649372796345, 
              c[ 38][ t]], 
            Times[ 0.070907514257657456, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ -0.062044074975450239, 
              c[ 41][ t]], 
            Times[ -0.11423673049785459, 
              c[ 42][ t]], 
            Times[ -0.15591488063143982, 
              c[ 43][ t]], 
            Times[ -0.18675027222298593, 
              c[ 44][ t]], 
            Times[ -0.20674833578317206, 
              c[ 45][ t]], 
            Times[ -0.21623620818304484, 
              c[ 46][ t]], 
            Times[ -0.21584055771952015, 
              c[ 47][ t]], 
            Times[ -0.20645618564475834, 
              c[ 48][ t]], 
            Times[ -0.18920668216016426, 
              c[ 49][ t]], 
            Times[ -0.16539866862653771, 
              c[ 50][ t]], 
            Times[ -0.13647135277833591, 
              c[ 51][ t]], 
            Times[ -0.10394325375429328, 
              c[ 52][ t]], 
            Times[ -0.06935801494512607, 
              c[ 53][ t]], 
            Times[ -0.034231213779558796, 
              c[ 54][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ 0.032022748374425904, 
              c[ 56][ t]], 
            Times[ 0.060688263076985223, 
              c[ 57][ t]], 
            Times[ 0.085044480344421705, 
              c[ 58][ t]], 
            Times[ 0.10436044624225685, 
              c[ 59][ t]], 
            Times[ 0.1181419061618126, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "26", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[26]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04125878107252025`\)\ \(c[\(-60\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-59\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-58\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-57\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-56\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-55\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-54\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-53\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-52\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-51\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-50\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-49\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-48\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-47\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-46\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-45\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-44\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-43\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-42\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-41\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-40\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-39\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-38\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-37\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-36\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-35\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-34\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-33\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-32\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-31\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-30\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-29\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-28\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-27\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-26\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-25\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-24\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-23\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-22\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-21\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-20\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-19\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-18\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-17\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-16\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-15\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-14\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-13\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-12\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-11\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-10\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-9\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-8\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-7\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-6\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-5\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-4\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-3\)]\)[t] - 
            0.06935801494512607`\ \(c[\(-2\)]\)[t] - 
            0.10394325375429328`\ \(c[\(-1\)]\)[t] - 
            0.13647135277833605`\ \(c[0]\)[t] - 
            0.1653986686265377`\ \(c[1]\)[t] - 
            0.18920668216016426`\ \(c[2]\)[t] - 
            0.20645618564475843`\ \(c[3]\)[t] - 
            0.21584055771952015`\ \(c[4]\)[t] - 
            0.21623620818304484`\ \(c[5]\)[t] - 
            0.206748335783172`\ \(c[6]\)[t] - 
            0.186750272222986`\ \(c[7]\)[t] - 
            0.15591488063143982`\ \(c[8]\)[t] - 
            0.11423673049785436`\ \(c[9]\)[t] - 
            0.06204407497545034`\ \(c[10]\)[t] + 
            3.898171832519376`*^-17\ \(c[11]\)[t] + 
            0.07090751425765777`\ \(c[12]\)[t] + 
            0.14938649372796362`\ \(c[13]\)[t] + 
            0.23387232094715985`\ \(c[14]\)[t] + 
            0.3225686520215216`\ \(c[15]\)[t] + 
            0.4134966715663442`\ \(c[16]\)[t] + 
            0.5045511524271047`\ \(c[17]\)[t] + 
            0.5935615337286806`\ \(c[18]\)[t] + 
            0.6783560385470634`\ \(c[19]\)[t] + 
            0.7568267286406569`\ \(c[20]\)[t] + 
            0.8269933431326881`\ \(c[21]\)[t] + 
            0.8870637930591838`\ \(c[22]\)[t] + 
            0.9354892837886392`\ \(c[23]\)[t] + 
            0.9710122092317629`\ \(c[24]\)[t] + 
            0.9927051996072067`\ \(c[25]\)[t] + 
            15.826339055858679`\ \(c[26]\)[t] + 
            0.9927051996072067`\ \(c[27]\)[t] + 
            0.9710122092317629`\ \(c[28]\)[t] + 
            0.9354892837886392`\ \(c[29]\)[t] + 
            0.8870637930591838`\ \(c[30]\)[t] + 
            0.8269933431326881`\ \(c[31]\)[t] + 
            0.7568267286406569`\ \(c[32]\)[t] + 
            0.6783560385470632`\ \(c[33]\)[t] + 
            0.5935615337286806`\ \(c[34]\)[t] + 
            0.5045511524271047`\ \(c[35]\)[t] + 
            0.41349667156634395`\ \(c[36]\)[t] + 
            0.3225686520215216`\ \(c[37]\)[t] + 
            0.23387232094715985`\ \(c[38]\)[t] + 
            0.14938649372796345`\ \(c[39]\)[t] + 
            0.07090751425765777`\ \(c[40]\)[t] + 
            3.216976900108398`*^-16\ \(c[41]\)[t] - 
            0.062044074975450475`\ \(c[42]\)[t] - 
            0.11423673049785436`\ \(c[43]\)[t] - 
            0.15591488063143966`\ \(c[44]\)[t] - 
            0.18675027222298607`\ \(c[45]\)[t] - 
            0.206748335783172`\ \(c[46]\)[t] - 
            0.21623620818304481`\ \(c[47]\)[t] - 
            0.21584055771952013`\ \(c[48]\)[t] - 
            0.20645618564475843`\ \(c[49]\)[t] - 
            0.18920668216016434`\ \(c[50]\)[t] - 
            0.1653986686265376`\ \(c[51]\)[t] - 
            0.13647135277833605`\ \(c[52]\)[t] - 
            0.1039432537542934`\ \(c[53]\)[t] - 
            0.06935801494512592`\ \(c[54]\)[t] - 
            0.03423121377955895`\ \(c[55]\)[t] - 
            1.8033970416801674`*^-16\ \(c[56]\)[t] + 
            0.03202274837442603`\ \(c[57]\)[t] + 
            0.060688263076985105`\ \(c[58]\)[t] + 
            0.08504448034442161`\ \(c[59]\)[t] + 
            0.10436044624225692`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 26, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 26]][ t]], 
          Plus[ 
            Times[ -0.041258781072520248, 
              c[ -60][ t]], 
            Times[ -0.048646667243099399, 
              c[ -59][ t]], 
            Times[ -0.054059052045761224, 
              c[ -58][ t]], 
            Times[ -0.057210750238908967, 
              c[ -57][ t]], 
            Times[ -0.057908442314993203, 
              c[ -56][ t]], 
            Times[ -0.056061239158567186, 
              c[ -55][ t]], 
            Times[ -0.05168708394579296, 
              c[ -54][ t]], 
            Times[ -0.044914622433376288, 
              c[ -53][ t]], 
            Times[ -0.035980357068793781, 
              c[ -52][ t]], 
            Times[ -0.025221096343682053, 
              c[ -51][ t]], 
            Times[ -0.013061910521147276, 
              c[ -50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -49][ t]], 
            Times[ 0.013414935129827233, 
              c[ -48][ t]], 
            Times[ 0.026603074225527937, 
              c[ -47][ t]], 
            Times[ 0.03897872015785999, 
              c[ -46][ t]], 
            Times[ 0.049975424961080865, 
              c[ -45][ t]], 
            Times[ 0.059070953080906402, 
              c[ -44][ t]], 
            Times[ 0.065811019881796273, 
              c[ -43][ t]], 
            Times[ 0.069830768673962415, 
              c[ -42][ t]], 
            Times[ 0.070873018952678238, 
              c[ -41][ t]], 
            Times[ 0.068802429876423349, 
              c[ -40][ t]], 
            Times[ 0.063614872548668253, 
              c[ -39][ t]], 
            Times[ 0.055441487066198933, 
              c[ -38][ t]], 
            Times[ 0.044547108751839919, 
              c[ -37][ t]], 
            Times[ 0.031322974491347078, 
              c[ -36][ t]], 
            Times[ 0.016273855731265604, 
              c[ -35][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -34][ t]], 
            Times[ -0.016825511857749401, 
              c[ -33][ t]], 
            Times[ -0.033483179628681567, 
              c[ -32][ t]], 
            Times[ -0.049236278094138941, 
              c[ -31][ t]], 
            Times[ -0.063361699504227528, 
              c[ -30][ t]], 
            Times[ -0.075181213012062598, 
              c[ -29][ t]], 
            Times[ -0.084091858737850814, 
              c[ -28][ t]], 
            Times[ -0.089594193770366884, 
              c[ -27][ t]], 
            Times[ -0.091317159035181589, 
              c[ -26][ t]], 
            Times[ -0.089038438663606695, 
              c[ -25][ t]], 
            Times[ -0.082699334313268744, 
              c[ -24][ t]], 
            Times[ -0.072413370861974122, 
              c[ -23][ t]], 
            Times[ -0.058468080236789913, 
              c[ -22][ t]], 
            Times[ -0.04131966847794722, 
              c[ -21][ t]], 
            Times[ -0.021580547817547879, 
              c[ -20][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -19][ t]], 
            Times[ 0.022561481809254869, 
              c[ -18][ t]], 
            Times[ 0.045163358568919301, 
              c[ -17][ t]], 
            Times[ 0.066820663127759972, 
              c[ -16][ t]], 
            Times[ 0.086542809078944891, 
              c[ -15][ t]], 
            Times[ 0.10337416789158609, 
              c[ -14][ t]], 
            Times[ 0.11643488132933186, 
              c[ -13][ t]], 
            Times[ 0.12496032289024853, 
              c[ -12][ t]], 
            Times[ 0.12833762891430928, 
              c[ -11][ t]], 
            Times[ 0.12613778810677614, 
              c[ -10][ t]], 
            Times[ 0.11814190616181255, 
              c[ -9][ t]], 
            Times[ 0.10436044624225685, 
              c[ -8][ t]], 
            Times[ 0.085044480344421705, 
              c[ -7][ t]], 
            Times[ 0.060688263076985105, 
              c[ -6][ t]], 
            Times[ 0.032022748374425904, 
              c[ -5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -4][ t]], 
            Times[ -0.034231213779558949, 
              c[ -3][ t]], 
            Times[ -0.06935801494512607, 
              c[ -2][ t]], 
            Times[ -0.10394325375429328, 
              c[ -1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 0][ t]], 
            Times[ -0.16539866862653771, 
              c[ 1][ t]], 
            Times[ -0.18920668216016426, 
              c[ 2][ t]], 
            Times[ -0.20645618564475843, 
              c[ 3][ t]], 
            Times[ -0.21584055771952015, 
              c[ 4][ t]], 
            Times[ -0.21623620818304484, 
              c[ 5][ t]], 
            Times[ -0.206748335783172, 
              c[ 6][ t]], 
            Times[ -0.18675027222298601, 
              c[ 7][ t]], 
            Times[ -0.15591488063143982, 
              c[ 8][ t]], 
            Times[ -0.11423673049785436, 
              c[ 9][ t]], 
            Times[ -0.062044074975450343, 
              c[ 10][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 11][ t]], 
            Times[ 0.070907514257657775, 
              c[ 12][ t]], 
            Times[ 0.14938649372796362, 
              c[ 13][ t]], 
            Times[ 0.23387232094715985, 
              c[ 14][ t]], 
            Times[ 0.32256865202152157, 
              c[ 15][ t]], 
            Times[ 0.41349667156634418, 
              c[ 16][ t]], 
            Times[ 0.50455115242710469, 
              c[ 17][ t]], 
            Times[ 0.59356153372868059, 
              c[ 18][ t]], 
            Times[ 0.67835603854706339, 
              c[ 19][ t]], 
            Times[ 0.75682672864065692, 
              c[ 20][ t]], 
            Times[ 0.82699334313268813, 
              c[ 21][ t]], 
            Times[ 0.88706379305918381, 
              c[ 22][ t]], 
            Times[ 0.93548928378863916, 
              c[ 23][ t]], 
            Times[ 0.9710122092317629, 
              c[ 24][ t]], 
            Times[ 0.99270519960720671, 
              c[ 25][ t]], 
            Times[ 15.826339055858679, 
              c[ 26][ t]], 
            Times[ 0.99270519960720671, 
              c[ 27][ t]], 
            Times[ 0.9710122092317629, 
              c[ 28][ t]], 
            Times[ 0.93548928378863916, 
              c[ 29][ t]], 
            Times[ 0.88706379305918381, 
              c[ 30][ t]], 
            Times[ 0.82699334313268813, 
              c[ 31][ t]], 
            Times[ 0.75682672864065692, 
              c[ 32][ t]], 
            Times[ 0.67835603854706317, 
              c[ 33][ t]], 
            Times[ 0.59356153372868059, 
              c[ 34][ t]], 
            Times[ 0.50455115242710469, 
              c[ 35][ t]], 
            Times[ 0.41349667156634395, 
              c[ 36][ t]], 
            Times[ 0.32256865202152157, 
              c[ 37][ t]], 
            Times[ 0.23387232094715985, 
              c[ 38][ t]], 
            Times[ 0.14938649372796345, 
              c[ 39][ t]], 
            Times[ 0.070907514257657775, 
              c[ 40][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 41][ t]], 
            Times[ -0.062044074975450475, 
              c[ 42][ t]], 
            Times[ -0.11423673049785436, 
              c[ 43][ t]], 
            Times[ -0.15591488063143966, 
              c[ 44][ t]], 
            Times[ -0.18675027222298607, 
              c[ 45][ t]], 
            Times[ -0.206748335783172, 
              c[ 46][ t]], 
            Times[ -0.21623620818304481, 
              c[ 47][ t]], 
            Times[ -0.21584055771952013, 
              c[ 48][ t]], 
            Times[ -0.20645618564475843, 
              c[ 49][ t]], 
            Times[ -0.18920668216016434, 
              c[ 50][ t]], 
            Times[ -0.1653986686265376, 
              c[ 51][ t]], 
            Times[ -0.13647135277833605, 
              c[ 52][ t]], 
            Times[ -0.1039432537542934, 
              c[ 53][ t]], 
            Times[ -0.069358014945125918, 
              c[ 54][ t]], 
            Times[ -0.034231213779558949, 
              c[ 55][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 56][ t]], 
            Times[ 0.032022748374426029, 
              c[ 57][ t]], 
            Times[ 0.060688263076985105, 
              c[ 58][ t]], 
            Times[ 0.085044480344421608, 
              c[ 59][ t]], 
            Times[ 0.10436044624225692, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "27", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[27]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03225825116512552`\)\ \(c[\(-60\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-59\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-58\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-57\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-56\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-55\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-54\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-53\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-52\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-51\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-50\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-49\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-48\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-47\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-46\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-45\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-44\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-43\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-42\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-41\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-40\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-39\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-38\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-37\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-36\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-35\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-34\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-32\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-31\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-30\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-29\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-28\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-27\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-26\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-25\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-24\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-23\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-22\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-21\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-20\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-19\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-18\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-17\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-16\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-15\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-14\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-13\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-12\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-11\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-10\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-9\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-8\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-7\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-6\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-5\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-2\)]\)[t] - 
            0.06935801494512592`\ \(c[\(-1\)]\)[t] - 
            0.10394325375429328`\ \(c[0]\)[t] - 
            0.13647135277833605`\ \(c[1]\)[t] - 
            0.1653986686265376`\ \(c[2]\)[t] - 
            0.18920668216016426`\ \(c[3]\)[t] - 
            0.20645618564475843`\ \(c[4]\)[t] - 
            0.21584055771952013`\ \(c[5]\)[t] - 
            0.21623620818304484`\ \(c[6]\)[t] - 
            0.20674833578317206`\ \(c[7]\)[t] - 
            0.18675027222298607`\ \(c[8]\)[t] - 
            0.15591488063143982`\ \(c[9]\)[t] - 
            0.11423673049785445`\ \(c[10]\)[t] - 
            0.062044074975450475`\ \(c[11]\)[t] + 
            3.898171832519376`*^-17\ \(c[12]\)[t] + 
            0.07090751425765762`\ \(c[13]\)[t] + 
            0.14938649372796345`\ \(c[14]\)[t] + 
            0.23387232094715985`\ \(c[15]\)[t] + 
            0.32256865202152135`\ \(c[16]\)[t] + 
            0.41349667156634395`\ \(c[17]\)[t] + 
            0.5045511524271047`\ \(c[18]\)[t] + 
            0.5935615337286803`\ \(c[19]\)[t] + 
            0.6783560385470632`\ \(c[20]\)[t] + 
            0.7568267286406569`\ \(c[21]\)[t] + 
            0.826993343132688`\ \(c[22]\)[t] + 
            0.8870637930591838`\ \(c[23]\)[t] + 
            0.9354892837886392`\ \(c[24]\)[t] + 
            0.9710122092317629`\ \(c[25]\)[t] + 
            0.9927051996072067`\ \(c[26]\)[t] + 
            16.98875912976476`\ \(c[27]\)[t] + 
            0.9927051996072069`\ \(c[28]\)[t] + 
            0.9710122092317629`\ \(c[29]\)[t] + 
            0.9354892837886392`\ \(c[30]\)[t] + 
            0.8870637930591839`\ \(c[31]\)[t] + 
            0.8269933431326881`\ \(c[32]\)[t] + 
            0.7568267286406569`\ \(c[33]\)[t] + 
            0.6783560385470636`\ \(c[34]\)[t] + 
            0.5935615337286806`\ \(c[35]\)[t] + 
            0.5045511524271047`\ \(c[36]\)[t] + 
            0.4134966715663443`\ \(c[37]\)[t] + 
            0.3225686520215216`\ \(c[38]\)[t] + 
            0.23387232094715985`\ \(c[39]\)[t] + 
            0.14938649372796384`\ \(c[40]\)[t] + 
            0.0709075142576581`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] - 
            0.06204407497545024`\ \(c[43]\)[t] - 
            0.11423673049785416`\ \(c[44]\)[t] - 
            0.15591488063143982`\ \(c[45]\)[t] - 
            0.18675027222298593`\ \(c[46]\)[t] - 
            0.2067483357831719`\ \(c[47]\)[t] - 
            0.21623620818304484`\ \(c[48]\)[t] - 
            0.21584055771952015`\ \(c[49]\)[t] - 
            0.20645618564475848`\ \(c[50]\)[t] - 
            0.18920668216016426`\ \(c[51]\)[t] - 
            0.1653986686265377`\ \(c[52]\)[t] - 
            0.13647135277833616`\ \(c[53]\)[t] - 
            0.10394325375429328`\ \(c[54]\)[t] - 
            0.06935801494512607`\ \(c[55]\)[t] - 
            0.034231213779559094`\ \(c[56]\)[t] - 
            3.898171832519376`*^-17\ \(c[57]\)[t] + 
            0.032022748374425904`\ \(c[58]\)[t] + 
            0.060688263076985`\ \(c[59]\)[t] + 
            0.0850444803444217`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 27, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 27]][ t]], 
          Plus[ 
            Times[ -0.032258251165125519, 
              c[ -60][ t]], 
            Times[ -0.041258781072520248, 
              c[ -59][ t]], 
            Times[ -0.048646667243099281, 
              c[ -58][ t]], 
            Times[ -0.054059052045761224, 
              c[ -57][ t]], 
            Times[ -0.057210750238908967, 
              c[ -56][ t]], 
            Times[ -0.057908442314993203, 
              c[ -55][ t]], 
            Times[ -0.056061239158567186, 
              c[ -54][ t]], 
            Times[ -0.05168708394579296, 
              c[ -53][ t]], 
            Times[ -0.044914622433376419, 
              c[ -52][ t]], 
            Times[ -0.035980357068793781, 
              c[ -51][ t]], 
            Times[ -0.025221096343682053, 
              c[ -50][ t]], 
            Times[ -0.013061910521147383, 
              c[ -49][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -48][ t]], 
            Times[ 0.013414935129827233, 
              c[ -47][ t]], 
            Times[ 0.026603074225527826, 
              c[ -46][ t]], 
            Times[ 0.03897872015785999, 
              c[ -45][ t]], 
            Times[ 0.049975424961080865, 
              c[ -44][ t]], 
            Times[ 0.059070953080906326, 
              c[ -43][ t]], 
            Times[ 0.065811019881796273, 
              c[ -42][ t]], 
            Times[ 0.069830768673962415, 
              c[ -41][ t]], 
            Times[ 0.070873018952678238, 
              c[ -40][ t]], 
            Times[ 0.068802429876423349, 
              c[ -39][ t]], 
            Times[ 0.063614872548668253, 
              c[ -38][ t]], 
            Times[ 0.055441487066198933, 
              c[ -37][ t]], 
            Times[ 0.044547108751839919, 
              c[ -36][ t]], 
            Times[ 0.031322974491347078, 
              c[ -35][ t]], 
            Times[ 0.016273855731265604, 
              c[ -34][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ -0.016825511857749401, 
              c[ -32][ t]], 
            Times[ -0.033483179628681567, 
              c[ -31][ t]], 
            Times[ -0.049236278094138941, 
              c[ -30][ t]], 
            Times[ -0.063361699504227528, 
              c[ -29][ t]], 
            Times[ -0.075181213012062598, 
              c[ -28][ t]], 
            Times[ -0.084091858737850814, 
              c[ -27][ t]], 
            Times[ -0.089594193770366884, 
              c[ -26][ t]], 
            Times[ -0.091317159035181589, 
              c[ -25][ t]], 
            Times[ -0.089038438663606695, 
              c[ -24][ t]], 
            Times[ -0.082699334313268744, 
              c[ -23][ t]], 
            Times[ -0.072413370861974122, 
              c[ -22][ t]], 
            Times[ -0.058468080236789913, 
              c[ -21][ t]], 
            Times[ -0.04131966847794722, 
              c[ -20][ t]], 
            Times[ -0.021580547817547879, 
              c[ -19][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -18][ t]], 
            Times[ 0.022561481809254869, 
              c[ -17][ t]], 
            Times[ 0.045163358568919301, 
              c[ -16][ t]], 
            Times[ 0.066820663127759972, 
              c[ -15][ t]], 
            Times[ 0.086542809078944891, 
              c[ -14][ t]], 
            Times[ 0.10337416789158609, 
              c[ -13][ t]], 
            Times[ 0.11643488132933186, 
              c[ -12][ t]], 
            Times[ 0.12496032289024853, 
              c[ -11][ t]], 
            Times[ 0.12833762891430928, 
              c[ -10][ t]], 
            Times[ 0.12613778810677614, 
              c[ -9][ t]], 
            Times[ 0.11814190616181255, 
              c[ -8][ t]], 
            Times[ 0.10436044624225685, 
              c[ -7][ t]], 
            Times[ 0.085044480344421705, 
              c[ -6][ t]], 
            Times[ 0.060688263076985105, 
              c[ -5][ t]], 
            Times[ 0.032022748374426029, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.034231213779558949, 
              c[ -2][ t]], 
            Times[ -0.069358014945125918, 
              c[ -1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 0][ t]], 
            Times[ -0.13647135277833605, 
              c[ 1][ t]], 
            Times[ -0.1653986686265376, 
              c[ 2][ t]], 
            Times[ -0.18920668216016426, 
              c[ 3][ t]], 
            Times[ -0.20645618564475843, 
              c[ 4][ t]], 
            Times[ -0.21584055771952013, 
              c[ 5][ t]], 
            Times[ -0.21623620818304484, 
              c[ 6][ t]], 
            Times[ -0.20674833578317206, 
              c[ 7][ t]], 
            Times[ -0.18675027222298607, 
              c[ 8][ t]], 
            Times[ -0.15591488063143982, 
              c[ 9][ t]], 
            Times[ -0.11423673049785445, 
              c[ 10][ t]], 
            Times[ -0.062044074975450475, 
              c[ 11][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ 0.070907514257657622, 
              c[ 13][ t]], 
            Times[ 0.14938649372796345, 
              c[ 14][ t]], 
            Times[ 0.23387232094715985, 
              c[ 15][ t]], 
            Times[ 0.32256865202152135, 
              c[ 16][ t]], 
            Times[ 0.41349667156634395, 
              c[ 17][ t]], 
            Times[ 0.50455115242710469, 
              c[ 18][ t]], 
            Times[ 0.59356153372868026, 
              c[ 19][ t]], 
            Times[ 0.67835603854706317, 
              c[ 20][ t]], 
            Times[ 0.75682672864065692, 
              c[ 21][ t]], 
            Times[ 0.82699334313268802, 
              c[ 22][ t]], 
            Times[ 0.88706379305918381, 
              c[ 23][ t]], 
            Times[ 0.93548928378863916, 
              c[ 24][ t]], 
            Times[ 0.9710122092317629, 
              c[ 25][ t]], 
            Times[ 0.99270519960720671, 
              c[ 26][ t]], 
            Times[ 16.988759129764759, 
              c[ 27][ t]], 
            Times[ 0.99270519960720693, 
              c[ 28][ t]], 
            Times[ 0.9710122092317629, 
              c[ 29][ t]], 
            Times[ 0.93548928378863916, 
              c[ 30][ t]], 
            Times[ 0.88706379305918392, 
              c[ 31][ t]], 
            Times[ 0.82699334313268813, 
              c[ 32][ t]], 
            Times[ 0.75682672864065692, 
              c[ 33][ t]], 
            Times[ 0.67835603854706361, 
              c[ 34][ t]], 
            Times[ 0.59356153372868059, 
              c[ 35][ t]], 
            Times[ 0.50455115242710469, 
              c[ 36][ t]], 
            Times[ 0.41349667156634429, 
              c[ 37][ t]], 
            Times[ 0.32256865202152157, 
              c[ 38][ t]], 
            Times[ 0.23387232094715985, 
              c[ 39][ t]], 
            Times[ 0.14938649372796384, 
              c[ 40][ t]], 
            Times[ 0.070907514257658094, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ -0.062044074975450239, 
              c[ 43][ t]], 
            Times[ -0.11423673049785416, 
              c[ 44][ t]], 
            Times[ -0.15591488063143982, 
              c[ 45][ t]], 
            Times[ -0.18675027222298593, 
              c[ 46][ t]], 
            Times[ -0.20674833578317189, 
              c[ 47][ t]], 
            Times[ -0.21623620818304484, 
              c[ 48][ t]], 
            Times[ -0.21584055771952015, 
              c[ 49][ t]], 
            Times[ -0.20645618564475848, 
              c[ 50][ t]], 
            Times[ -0.18920668216016426, 
              c[ 51][ t]], 
            Times[ -0.16539866862653771, 
              c[ 52][ t]], 
            Times[ -0.13647135277833616, 
              c[ 53][ t]], 
            Times[ -0.10394325375429328, 
              c[ 54][ t]], 
            Times[ -0.06935801494512607, 
              c[ 55][ t]], 
            Times[ -0.034231213779559094, 
              c[ 56][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ 0.032022748374425904, 
              c[ 58][ t]], 
            Times[ 0.060688263076985001, 
              c[ 59][ t]], 
            Times[ 0.085044480344421705, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "28", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[28]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.022068459300722043`\)\ \(c[\(-60\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-59\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-58\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-57\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-56\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-55\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-54\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-53\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-52\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-51\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-50\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-49\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-48\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-47\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-46\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-45\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-44\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-43\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-42\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-41\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-40\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-39\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-38\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-37\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-36\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-35\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-34\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-33\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-31\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-30\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-29\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-28\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-27\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-26\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-25\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-24\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-23\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-22\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-21\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-20\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-19\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-18\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-17\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-16\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-15\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-14\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-13\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-12\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-11\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-10\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-9\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-8\)]\)[t] + 
            0.11814190616181253`\ \(c[\(-7\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-6\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-5\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-4\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-3\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-2\)]\)[t] - 
            0.03423121377955895`\ \(c[\(-1\)]\)[t] - 
            0.06935801494512607`\ \(c[0]\)[t] - 
            0.1039432537542934`\ \(c[1]\)[t] - 
            0.13647135277833605`\ \(c[2]\)[t] - 
            0.1653986686265377`\ \(c[3]\)[t] - 
            0.18920668216016434`\ \(c[4]\)[t] - 
            0.20645618564475843`\ \(c[5]\)[t] - 
            0.21584055771952015`\ \(c[6]\)[t] - 
            0.21623620818304484`\ \(c[7]\)[t] - 
            0.206748335783172`\ \(c[8]\)[t] - 
            0.18675027222298593`\ \(c[9]\)[t] - 
            0.15591488063143974`\ \(c[10]\)[t] - 
            0.11423673049785436`\ \(c[11]\)[t] - 
            0.06204407497545024`\ \(c[12]\)[t] + 
            1.8033970416801674`*^-16\ \(c[13]\)[t] + 
            0.07090751425765777`\ \(c[14]\)[t] + 
            0.14938649372796384`\ \(c[15]\)[t] + 
            0.23387232094715998`\ \(c[16]\)[t] + 
            0.3225686520215216`\ \(c[17]\)[t] + 
            0.4134966715663443`\ \(c[18]\)[t] + 
            0.5045511524271049`\ \(c[19]\)[t] + 
            0.5935615337286806`\ \(c[20]\)[t] + 
            0.6783560385470636`\ \(c[21]\)[t] + 
            0.7568267286406569`\ \(c[22]\)[t] + 
            0.8269933431326881`\ \(c[23]\)[t] + 
            0.8870637930591839`\ \(c[24]\)[t] + 
            0.9354892837886392`\ \(c[25]\)[t] + 
            0.9710122092317629`\ \(c[26]\)[t] + 
            0.9927051996072069`\ \(c[27]\)[t] + 
            18.195044112120122`\ \(c[28]\)[t] + 
            0.9927051996072067`\ \(c[29]\)[t] + 
            0.9710122092317629`\ \(c[30]\)[t] + 
            0.9354892837886392`\ \(c[31]\)[t] + 
            0.8870637930591838`\ \(c[32]\)[t] + 
            0.826993343132688`\ \(c[33]\)[t] + 
            0.7568267286406569`\ \(c[34]\)[t] + 
            0.6783560385470632`\ \(c[35]\)[t] + 
            0.5935615337286801`\ \(c[36]\)[t] + 
            0.5045511524271047`\ \(c[37]\)[t] + 
            0.41349667156634395`\ \(c[38]\)[t] + 
            0.32256865202152113`\ \(c[39]\)[t] + 
            0.23387232094715985`\ \(c[40]\)[t] + 
            0.14938649372796384`\ \(c[41]\)[t] + 
            0.07090751425765746`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] - 
            0.06204407497545024`\ \(c[44]\)[t] - 
            0.11423673049785459`\ \(c[45]\)[t] - 
            0.15591488063143982`\ \(c[46]\)[t] - 
            0.18675027222298593`\ \(c[47]\)[t] - 
            0.20674833578317206`\ \(c[48]\)[t] - 
            0.21623620818304484`\ \(c[49]\)[t] - 
            0.21584055771952015`\ \(c[50]\)[t] - 
            0.20645618564475834`\ \(c[51]\)[t] - 
            0.18920668216016426`\ \(c[52]\)[t] - 
            0.1653986686265377`\ \(c[53]\)[t] - 
            0.1364713527783359`\ \(c[54]\)[t] - 
            0.10394325375429328`\ \(c[55]\)[t] - 
            0.06935801494512607`\ \(c[56]\)[t] - 
            0.034231213779558796`\ \(c[57]\)[t] - 
            3.898171832519376`*^-17\ \(c[58]\)[t] + 
            0.032022748374425904`\ \(c[59]\)[t] + 
            0.06068826307698522`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 28, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 28]][ t]], 
          Plus[ 
            Times[ -0.022068459300722043, 
              c[ -60][ t]], 
            Times[ -0.032258251165125679, 
              c[ -59][ t]], 
            Times[ -0.041258781072520248, 
              c[ -58][ t]], 
            Times[ -0.048646667243099281, 
              c[ -57][ t]], 
            Times[ -0.054059052045761224, 
              c[ -56][ t]], 
            Times[ -0.057210750238908967, 
              c[ -55][ t]], 
            Times[ -0.057908442314993203, 
              c[ -54][ t]], 
            Times[ -0.05606123915856713, 
              c[ -53][ t]], 
            Times[ -0.05168708394579296, 
              c[ -52][ t]], 
            Times[ -0.044914622433376419, 
              c[ -51][ t]], 
            Times[ -0.035980357068793781, 
              c[ -50][ t]], 
            Times[ -0.025221096343682053, 
              c[ -49][ t]], 
            Times[ -0.013061910521147383, 
              c[ -48][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -47][ t]], 
            Times[ 0.013414935129827233, 
              c[ -46][ t]], 
            Times[ 0.026603074225527826, 
              c[ -45][ t]], 
            Times[ 0.038978720157860088, 
              c[ -44][ t]], 
            Times[ 0.049975424961080865, 
              c[ -43][ t]], 
            Times[ 0.059070953080906326, 
              c[ -42][ t]], 
            Times[ 0.065811019881796315, 
              c[ -41][ t]], 
            Times[ 0.069830768673962415, 
              c[ -40][ t]], 
            Times[ 0.070873018952678238, 
              c[ -39][ t]], 
            Times[ 0.068802429876423349, 
              c[ -38][ t]], 
            Times[ 0.063614872548668253, 
              c[ -37][ t]], 
            Times[ 0.055441487066198933, 
              c[ -36][ t]], 
            Times[ 0.044547108751839919, 
              c[ -35][ t]], 
            Times[ 0.031322974491347078, 
              c[ -34][ t]], 
            Times[ 0.016273855731265604, 
              c[ -33][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ -0.016825511857749401, 
              c[ -31][ t]], 
            Times[ -0.033483179628681567, 
              c[ -30][ t]], 
            Times[ -0.049236278094138941, 
              c[ -29][ t]], 
            Times[ -0.063361699504227528, 
              c[ -28][ t]], 
            Times[ -0.075181213012062598, 
              c[ -27][ t]], 
            Times[ -0.084091858737850814, 
              c[ -26][ t]], 
            Times[ -0.089594193770366884, 
              c[ -25][ t]], 
            Times[ -0.091317159035181589, 
              c[ -24][ t]], 
            Times[ -0.089038438663606695, 
              c[ -23][ t]], 
            Times[ -0.082699334313268744, 
              c[ -22][ t]], 
            Times[ -0.072413370861974122, 
              c[ -21][ t]], 
            Times[ -0.058468080236789913, 
              c[ -20][ t]], 
            Times[ -0.04131966847794722, 
              c[ -19][ t]], 
            Times[ -0.021580547817547879, 
              c[ -18][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -17][ t]], 
            Times[ 0.022561481809254869, 
              c[ -16][ t]], 
            Times[ 0.045163358568919301, 
              c[ -15][ t]], 
            Times[ 0.066820663127759972, 
              c[ -14][ t]], 
            Times[ 0.086542809078944891, 
              c[ -13][ t]], 
            Times[ 0.10337416789158609, 
              c[ -12][ t]], 
            Times[ 0.11643488132933186, 
              c[ -11][ t]], 
            Times[ 0.12496032289024853, 
              c[ -10][ t]], 
            Times[ 0.12833762891430928, 
              c[ -9][ t]], 
            Times[ 0.12613778810677612, 
              c[ -8][ t]], 
            Times[ 0.11814190616181253, 
              c[ -7][ t]], 
            Times[ 0.10436044624225685, 
              c[ -6][ t]], 
            Times[ 0.085044480344421608, 
              c[ -5][ t]], 
            Times[ 0.060688263076985105, 
              c[ -4][ t]], 
            Times[ 0.032022748374425904, 
              c[ -3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -2][ t]], 
            Times[ -0.034231213779558949, 
              c[ -1][ t]], 
            Times[ -0.06935801494512607, 
              c[ 0][ t]], 
            Times[ -0.1039432537542934, 
              c[ 1][ t]], 
            Times[ -0.13647135277833605, 
              c[ 2][ t]], 
            Times[ -0.16539866862653771, 
              c[ 3][ t]], 
            Times[ -0.18920668216016434, 
              c[ 4][ t]], 
            Times[ -0.20645618564475843, 
              c[ 5][ t]], 
            Times[ -0.21584055771952015, 
              c[ 6][ t]], 
            Times[ -0.21623620818304484, 
              c[ 7][ t]], 
            Times[ -0.206748335783172, 
              c[ 8][ t]], 
            Times[ -0.18675027222298593, 
              c[ 9][ t]], 
            Times[ -0.15591488063143974, 
              c[ 10][ t]], 
            Times[ -0.11423673049785436, 
              c[ 11][ t]], 
            Times[ -0.062044074975450239, 
              c[ 12][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 13][ t]], 
            Times[ 0.070907514257657775, 
              c[ 14][ t]], 
            Times[ 0.14938649372796384, 
              c[ 15][ t]], 
            Times[ 0.23387232094715998, 
              c[ 16][ t]], 
            Times[ 0.32256865202152157, 
              c[ 17][ t]], 
            Times[ 0.41349667156634429, 
              c[ 18][ t]], 
            Times[ 0.50455115242710491, 
              c[ 19][ t]], 
            Times[ 0.59356153372868059, 
              c[ 20][ t]], 
            Times[ 0.67835603854706361, 
              c[ 21][ t]], 
            Times[ 0.75682672864065692, 
              c[ 22][ t]], 
            Times[ 0.82699334313268813, 
              c[ 23][ t]], 
            Times[ 0.88706379305918392, 
              c[ 24][ t]], 
            Times[ 0.93548928378863916, 
              c[ 25][ t]], 
            Times[ 0.9710122092317629, 
              c[ 26][ t]], 
            Times[ 0.99270519960720693, 
              c[ 27][ t]], 
            Times[ 18.195044112120122, 
              c[ 28][ t]], 
            Times[ 0.99270519960720671, 
              c[ 29][ t]], 
            Times[ 0.9710122092317629, 
              c[ 30][ t]], 
            Times[ 0.93548928378863916, 
              c[ 31][ t]], 
            Times[ 0.88706379305918381, 
              c[ 32][ t]], 
            Times[ 0.82699334313268802, 
              c[ 33][ t]], 
            Times[ 0.75682672864065692, 
              c[ 34][ t]], 
            Times[ 0.67835603854706317, 
              c[ 35][ t]], 
            Times[ 0.59356153372868015, 
              c[ 36][ t]], 
            Times[ 0.50455115242710469, 
              c[ 37][ t]], 
            Times[ 0.41349667156634395, 
              c[ 38][ t]], 
            Times[ 0.32256865202152113, 
              c[ 39][ t]], 
            Times[ 0.23387232094715985, 
              c[ 40][ t]], 
            Times[ 0.14938649372796384, 
              c[ 41][ t]], 
            Times[ 0.070907514257657456, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ -0.062044074975450239, 
              c[ 44][ t]], 
            Times[ -0.11423673049785459, 
              c[ 45][ t]], 
            Times[ -0.15591488063143982, 
              c[ 46][ t]], 
            Times[ -0.18675027222298593, 
              c[ 47][ t]], 
            Times[ -0.20674833578317206, 
              c[ 48][ t]], 
            Times[ -0.21623620818304484, 
              c[ 49][ t]], 
            Times[ -0.21584055771952015, 
              c[ 50][ t]], 
            Times[ -0.20645618564475834, 
              c[ 51][ t]], 
            Times[ -0.18920668216016426, 
              c[ 52][ t]], 
            Times[ -0.16539866862653771, 
              c[ 53][ t]], 
            Times[ -0.13647135277833591, 
              c[ 54][ t]], 
            Times[ -0.10394325375429328, 
              c[ 55][ t]], 
            Times[ -0.06935801494512607, 
              c[ 56][ t]], 
            Times[ -0.034231213779558796, 
              c[ 57][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ 0.032022748374425904, 
              c[ 59][ t]], 
            Times[ 0.060688263076985223, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "29", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[29]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.011153991006822649`\)\ \(c[\(-60\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-59\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-58\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-57\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-56\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-55\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-54\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-53\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-52\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-51\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-50\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-49\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-48\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-47\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-46\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-45\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-44\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-43\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-42\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-41\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-40\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-39\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-38\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-37\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-36\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-35\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-34\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-33\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-32\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-31\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-30\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-29\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-28\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-27\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-26\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-25\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-24\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-23\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-22\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-21\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-20\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-19\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-18\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-17\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-16\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-15\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-14\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-13\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-12\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-11\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-10\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-9\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-8\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-7\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-6\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-5\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-4\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-3\)]\)[t] + 
            0.032022748374425904`\ \(c[\(-2\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-1\)]\)[t] - 
            0.03423121377955895`\ \(c[0]\)[t] - 
            0.06935801494512607`\ \(c[1]\)[t] - 
            0.10394325375429328`\ \(c[2]\)[t] - 
            0.13647135277833605`\ \(c[3]\)[t] - 
            0.1653986686265377`\ \(c[4]\)[t] - 
            0.18920668216016426`\ \(c[5]\)[t] - 
            0.20645618564475843`\ \(c[6]\)[t] - 
            0.21584055771952015`\ \(c[7]\)[t] - 
            0.21623620818304484`\ \(c[8]\)[t] - 
            0.206748335783172`\ \(c[9]\)[t] - 
            0.186750272222986`\ \(c[10]\)[t] - 
            0.15591488063143982`\ \(c[11]\)[t] - 
            0.11423673049785436`\ \(c[12]\)[t] - 
            0.06204407497545034`\ \(c[13]\)[t] + 
            3.898171832519376`*^-17\ \(c[14]\)[t] + 
            0.07090751425765777`\ \(c[15]\)[t] + 
            0.14938649372796362`\ \(c[16]\)[t] + 
            0.23387232094715985`\ \(c[17]\)[t] + 
            0.3225686520215216`\ \(c[18]\)[t] + 
            0.4134966715663442`\ \(c[19]\)[t] + 
            0.5045511524271047`\ \(c[20]\)[t] + 
            0.5935615337286806`\ \(c[21]\)[t] + 
            0.6783560385470632`\ \(c[22]\)[t] + 
            0.7568267286406569`\ \(c[23]\)[t] + 
            0.8269933431326881`\ \(c[24]\)[t] + 
            0.8870637930591838`\ \(c[25]\)[t] + 
            0.9354892837886392`\ \(c[26]\)[t] + 
            0.9710122092317629`\ \(c[27]\)[t] + 
            0.9927051996072067`\ \(c[28]\)[t] + 
            19.445194002924776`\ \(c[29]\)[t] + 
            0.9927051996072067`\ \(c[30]\)[t] + 
            0.9710122092317629`\ \(c[31]\)[t] + 
            0.9354892837886392`\ \(c[32]\)[t] + 
            0.8870637930591838`\ \(c[33]\)[t] + 
            0.8269933431326881`\ \(c[34]\)[t] + 
            0.7568267286406569`\ \(c[35]\)[t] + 
            0.6783560385470632`\ \(c[36]\)[t] + 
            0.5935615337286806`\ \(c[37]\)[t] + 
            0.5045511524271047`\ \(c[38]\)[t] + 
            0.41349667156634395`\ \(c[39]\)[t] + 
            0.3225686520215216`\ \(c[40]\)[t] + 
            0.23387232094716018`\ \(c[41]\)[t] + 
            0.14938649372796345`\ \(c[42]\)[t] + 
            0.07090751425765777`\ \(c[43]\)[t] + 
            3.216976900108398`*^-16\ \(c[44]\)[t] - 
            0.062044074975450475`\ \(c[45]\)[t] - 
            0.11423673049785436`\ \(c[46]\)[t] - 
            0.15591488063143966`\ \(c[47]\)[t] - 
            0.18675027222298607`\ \(c[48]\)[t] - 
            0.206748335783172`\ \(c[49]\)[t] - 
            0.21623620818304481`\ \(c[50]\)[t] - 
            0.21584055771952013`\ \(c[51]\)[t] - 
            0.20645618564475843`\ \(c[52]\)[t] - 
            0.18920668216016434`\ \(c[53]\)[t] - 
            0.1653986686265376`\ \(c[54]\)[t] - 
            0.13647135277833605`\ \(c[55]\)[t] - 
            0.1039432537542934`\ \(c[56]\)[t] - 
            0.06935801494512592`\ \(c[57]\)[t] - 
            0.03423121377955895`\ \(c[58]\)[t] - 
            1.8033970416801674`*^-16\ \(c[59]\)[t] + 
            0.03202274837442603`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 29, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 29]][ t]], 
          Plus[ 
            Times[ -0.011153991006822649, 
              c[ -60][ t]], 
            Times[ -0.022068459300722043, 
              c[ -59][ t]], 
            Times[ -0.032258251165125519, 
              c[ -58][ t]], 
            Times[ -0.041258781072520248, 
              c[ -57][ t]], 
            Times[ -0.048646667243099399, 
              c[ -56][ t]], 
            Times[ -0.054059052045761224, 
              c[ -55][ t]], 
            Times[ -0.057210750238908967, 
              c[ -54][ t]], 
            Times[ -0.057908442314993203, 
              c[ -53][ t]], 
            Times[ -0.056061239158567186, 
              c[ -52][ t]], 
            Times[ -0.05168708394579296, 
              c[ -51][ t]], 
            Times[ -0.044914622433376288, 
              c[ -50][ t]], 
            Times[ -0.035980357068793781, 
              c[ -49][ t]], 
            Times[ -0.025221096343682053, 
              c[ -48][ t]], 
            Times[ -0.013061910521147276, 
              c[ -47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -46][ t]], 
            Times[ 0.013414935129827233, 
              c[ -45][ t]], 
            Times[ 0.026603074225527937, 
              c[ -44][ t]], 
            Times[ 0.03897872015785999, 
              c[ -43][ t]], 
            Times[ 0.049975424961080865, 
              c[ -42][ t]], 
            Times[ 0.059070953080906402, 
              c[ -41][ t]], 
            Times[ 0.065811019881796273, 
              c[ -40][ t]], 
            Times[ 0.069830768673962415, 
              c[ -39][ t]], 
            Times[ 0.070873018952678238, 
              c[ -38][ t]], 
            Times[ 0.068802429876423349, 
              c[ -37][ t]], 
            Times[ 0.063614872548668253, 
              c[ -36][ t]], 
            Times[ 0.055441487066198933, 
              c[ -35][ t]], 
            Times[ 0.044547108751839919, 
              c[ -34][ t]], 
            Times[ 0.031322974491347078, 
              c[ -33][ t]], 
            Times[ 0.016273855731265604, 
              c[ -32][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -31][ t]], 
            Times[ -0.016825511857749401, 
              c[ -30][ t]], 
            Times[ -0.033483179628681567, 
              c[ -29][ t]], 
            Times[ -0.049236278094138941, 
              c[ -28][ t]], 
            Times[ -0.063361699504227528, 
              c[ -27][ t]], 
            Times[ -0.075181213012062598, 
              c[ -26][ t]], 
            Times[ -0.084091858737850814, 
              c[ -25][ t]], 
            Times[ -0.089594193770366884, 
              c[ -24][ t]], 
            Times[ -0.091317159035181589, 
              c[ -23][ t]], 
            Times[ -0.089038438663606695, 
              c[ -22][ t]], 
            Times[ -0.082699334313268744, 
              c[ -21][ t]], 
            Times[ -0.072413370861974122, 
              c[ -20][ t]], 
            Times[ -0.058468080236789913, 
              c[ -19][ t]], 
            Times[ -0.04131966847794722, 
              c[ -18][ t]], 
            Times[ -0.021580547817547879, 
              c[ -17][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -16][ t]], 
            Times[ 0.022561481809254869, 
              c[ -15][ t]], 
            Times[ 0.045163358568919301, 
              c[ -14][ t]], 
            Times[ 0.066820663127759972, 
              c[ -13][ t]], 
            Times[ 0.086542809078944891, 
              c[ -12][ t]], 
            Times[ 0.10337416789158609, 
              c[ -11][ t]], 
            Times[ 0.11643488132933186, 
              c[ -10][ t]], 
            Times[ 0.12496032289024853, 
              c[ -9][ t]], 
            Times[ 0.12833762891430928, 
              c[ -8][ t]], 
            Times[ 0.12613778810677614, 
              c[ -7][ t]], 
            Times[ 0.11814190616181255, 
              c[ -6][ t]], 
            Times[ 0.10436044624225685, 
              c[ -5][ t]], 
            Times[ 0.085044480344421705, 
              c[ -4][ t]], 
            Times[ 0.060688263076985105, 
              c[ -3][ t]], 
            Times[ 0.032022748374425904, 
              c[ -2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 0][ t]], 
            Times[ -0.06935801494512607, 
              c[ 1][ t]], 
            Times[ -0.10394325375429328, 
              c[ 2][ t]], 
            Times[ -0.13647135277833605, 
              c[ 3][ t]], 
            Times[ -0.16539866862653771, 
              c[ 4][ t]], 
            Times[ -0.18920668216016426, 
              c[ 5][ t]], 
            Times[ -0.20645618564475843, 
              c[ 6][ t]], 
            Times[ -0.21584055771952015, 
              c[ 7][ t]], 
            Times[ -0.21623620818304484, 
              c[ 8][ t]], 
            Times[ -0.206748335783172, 
              c[ 9][ t]], 
            Times[ -0.18675027222298601, 
              c[ 10][ t]], 
            Times[ -0.15591488063143982, 
              c[ 11][ t]], 
            Times[ -0.11423673049785436, 
              c[ 12][ t]], 
            Times[ -0.062044074975450343, 
              c[ 13][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 14][ t]], 
            Times[ 0.070907514257657775, 
              c[ 15][ t]], 
            Times[ 0.14938649372796362, 
              c[ 16][ t]], 
            Times[ 0.23387232094715985, 
              c[ 17][ t]], 
            Times[ 0.32256865202152157, 
              c[ 18][ t]], 
            Times[ 0.41349667156634418, 
              c[ 19][ t]], 
            Times[ 0.50455115242710469, 
              c[ 20][ t]], 
            Times[ 0.59356153372868059, 
              c[ 21][ t]], 
            Times[ 0.67835603854706317, 
              c[ 22][ t]], 
            Times[ 0.75682672864065692, 
              c[ 23][ t]], 
            Times[ 0.82699334313268813, 
              c[ 24][ t]], 
            Times[ 0.88706379305918381, 
              c[ 25][ t]], 
            Times[ 0.93548928378863916, 
              c[ 26][ t]], 
            Times[ 0.9710122092317629, 
              c[ 27][ t]], 
            Times[ 0.99270519960720671, 
              c[ 28][ t]], 
            Times[ 19.445194002924776, 
              c[ 29][ t]], 
            Times[ 0.99270519960720671, 
              c[ 30][ t]], 
            Times[ 0.9710122092317629, 
              c[ 31][ t]], 
            Times[ 0.93548928378863916, 
              c[ 32][ t]], 
            Times[ 0.88706379305918381, 
              c[ 33][ t]], 
            Times[ 0.82699334313268813, 
              c[ 34][ t]], 
            Times[ 0.75682672864065692, 
              c[ 35][ t]], 
            Times[ 0.67835603854706317, 
              c[ 36][ t]], 
            Times[ 0.59356153372868059, 
              c[ 37][ t]], 
            Times[ 0.50455115242710469, 
              c[ 38][ t]], 
            Times[ 0.41349667156634395, 
              c[ 39][ t]], 
            Times[ 0.32256865202152157, 
              c[ 40][ t]], 
            Times[ 0.23387232094716018, 
              c[ 41][ t]], 
            Times[ 0.14938649372796345, 
              c[ 42][ t]], 
            Times[ 0.070907514257657775, 
              c[ 43][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 44][ t]], 
            Times[ -0.062044074975450475, 
              c[ 45][ t]], 
            Times[ -0.11423673049785436, 
              c[ 46][ t]], 
            Times[ -0.15591488063143966, 
              c[ 47][ t]], 
            Times[ -0.18675027222298607, 
              c[ 48][ t]], 
            Times[ -0.206748335783172, 
              c[ 49][ t]], 
            Times[ -0.21623620818304481, 
              c[ 50][ t]], 
            Times[ -0.21584055771952013, 
              c[ 51][ t]], 
            Times[ -0.20645618564475843, 
              c[ 52][ t]], 
            Times[ -0.18920668216016434, 
              c[ 53][ t]], 
            Times[ -0.1653986686265376, 
              c[ 54][ t]], 
            Times[ -0.13647135277833605, 
              c[ 55][ t]], 
            Times[ -0.1039432537542934, 
              c[ 56][ t]], 
            Times[ -0.069358014945125918, 
              c[ 57][ t]], 
            Times[ -0.034231213779558949, 
              c[ 58][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 59][ t]], 
            Times[ 0.032022748374426029, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "30", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[30]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.8981718325193755`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-59\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-58\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-57\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-56\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-55\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-54\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-53\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-52\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-51\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-50\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-49\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-48\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-47\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-46\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-45\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-44\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-43\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-42\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-41\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-40\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-39\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-38\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-37\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-36\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-35\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-34\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-33\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-32\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-31\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-29\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-28\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-27\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-26\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-25\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-24\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-23\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-22\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-21\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-20\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-19\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-18\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-17\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-16\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-15\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-14\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-13\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-12\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-11\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-10\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-9\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-8\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-7\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-6\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-5\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-4\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-3\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-2\)]\)[t] + 
            0.03202274837442603`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.03423121377955895`\ \(c[1]\)[t] - 
            0.06935801494512592`\ \(c[2]\)[t] - 
            0.10394325375429328`\ \(c[3]\)[t] - 
            0.13647135277833605`\ \(c[4]\)[t] - 
            0.1653986686265376`\ \(c[5]\)[t] - 
            0.18920668216016426`\ \(c[6]\)[t] - 
            0.20645618564475834`\ \(c[7]\)[t] - 
            0.21584055771952013`\ \(c[8]\)[t] - 
            0.21623620818304484`\ \(c[9]\)[t] - 
            0.20674833578317206`\ \(c[10]\)[t] - 
            0.18675027222298607`\ \(c[11]\)[t] - 
            0.15591488063143982`\ \(c[12]\)[t] - 
            0.11423673049785445`\ \(c[13]\)[t] - 
            0.062044074975450475`\ \(c[14]\)[t] + 
            3.898171832519376`*^-17\ \(c[15]\)[t] + 
            0.07090751425765762`\ \(c[16]\)[t] + 
            0.14938649372796345`\ \(c[17]\)[t] + 
            0.23387232094715985`\ \(c[18]\)[t] + 
            0.32256865202152135`\ \(c[19]\)[t] + 
            0.41349667156634395`\ \(c[20]\)[t] + 
            0.5045511524271047`\ \(c[21]\)[t] + 
            0.5935615337286801`\ \(c[22]\)[t] + 
            0.6783560385470632`\ \(c[23]\)[t] + 
            0.7568267286406569`\ \(c[24]\)[t] + 
            0.826993343132688`\ \(c[25]\)[t] + 
            0.8870637930591838`\ \(c[26]\)[t] + 
            0.9354892837886392`\ \(c[27]\)[t] + 
            0.9710122092317629`\ \(c[28]\)[t] + 
            0.9927051996072067`\ \(c[29]\)[t] + 
            20.739208802178716`\ \(c[30]\)[t] + 
            0.9927051996072069`\ \(c[31]\)[t] + 
            0.9710122092317629`\ \(c[32]\)[t] + 
            0.9354892837886392`\ \(c[33]\)[t] + 
            0.8870637930591839`\ \(c[34]\)[t] + 
            0.8269933431326881`\ \(c[35]\)[t] + 
            0.7568267286406569`\ \(c[36]\)[t] + 
            0.6783560385470636`\ \(c[37]\)[t] + 
            0.5935615337286806`\ \(c[38]\)[t] + 
            0.5045511524271047`\ \(c[39]\)[t] + 
            0.4134966715663443`\ \(c[40]\)[t] + 
            0.3225686520215219`\ \(c[41]\)[t] + 
            0.23387232094715985`\ \(c[42]\)[t] + 
            0.14938649372796384`\ \(c[43]\)[t] + 
            0.0709075142576581`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] - 
            0.06204407497545024`\ \(c[46]\)[t] - 
            0.11423673049785416`\ \(c[47]\)[t] - 
            0.15591488063143982`\ \(c[48]\)[t] - 
            0.18675027222298593`\ \(c[49]\)[t] - 
            0.2067483357831719`\ \(c[50]\)[t] - 
            0.21623620818304484`\ \(c[51]\)[t] - 
            0.21584055771952015`\ \(c[52]\)[t] - 
            0.20645618564475848`\ \(c[53]\)[t] - 
            0.18920668216016426`\ \(c[54]\)[t] - 
            0.1653986686265377`\ \(c[55]\)[t] - 
            0.13647135277833616`\ \(c[56]\)[t] - 
            0.10394325375429328`\ \(c[57]\)[t] - 
            0.06935801494512607`\ \(c[58]\)[t] - 
            0.034231213779559094`\ \(c[59]\)[t] - 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 30, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 30]][ t]], 
          Plus[ 
            Times[ -3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ -0.011153991006822649, 
              c[ -59][ t]], 
            Times[ -0.022068459300722043, 
              c[ -58][ t]], 
            Times[ -0.032258251165125519, 
              c[ -57][ t]], 
            Times[ -0.041258781072520248, 
              c[ -56][ t]], 
            Times[ -0.048646667243099281, 
              c[ -55][ t]], 
            Times[ -0.054059052045761224, 
              c[ -54][ t]], 
            Times[ -0.057210750238908967, 
              c[ -53][ t]], 
            Times[ -0.057908442314993203, 
              c[ -52][ t]], 
            Times[ -0.056061239158567186, 
              c[ -51][ t]], 
            Times[ -0.05168708394579296, 
              c[ -50][ t]], 
            Times[ -0.044914622433376419, 
              c[ -49][ t]], 
            Times[ -0.035980357068793781, 
              c[ -48][ t]], 
            Times[ -0.025221096343682053, 
              c[ -47][ t]], 
            Times[ -0.013061910521147383, 
              c[ -46][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -45][ t]], 
            Times[ 0.013414935129827233, 
              c[ -44][ t]], 
            Times[ 0.026603074225527826, 
              c[ -43][ t]], 
            Times[ 0.03897872015785999, 
              c[ -42][ t]], 
            Times[ 0.049975424961080865, 
              c[ -41][ t]], 
            Times[ 0.059070953080906326, 
              c[ -40][ t]], 
            Times[ 0.065811019881796273, 
              c[ -39][ t]], 
            Times[ 0.069830768673962415, 
              c[ -38][ t]], 
            Times[ 0.070873018952678238, 
              c[ -37][ t]], 
            Times[ 0.068802429876423349, 
              c[ -36][ t]], 
            Times[ 0.063614872548668253, 
              c[ -35][ t]], 
            Times[ 0.055441487066198933, 
              c[ -34][ t]], 
            Times[ 0.044547108751839919, 
              c[ -33][ t]], 
            Times[ 0.031322974491347078, 
              c[ -32][ t]], 
            Times[ 0.016273855731265604, 
              c[ -31][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ -0.016825511857749401, 
              c[ -29][ t]], 
            Times[ -0.033483179628681567, 
              c[ -28][ t]], 
            Times[ -0.049236278094138941, 
              c[ -27][ t]], 
            Times[ -0.063361699504227528, 
              c[ -26][ t]], 
            Times[ -0.075181213012062598, 
              c[ -25][ t]], 
            Times[ -0.084091858737850814, 
              c[ -24][ t]], 
            Times[ -0.089594193770366884, 
              c[ -23][ t]], 
            Times[ -0.091317159035181589, 
              c[ -22][ t]], 
            Times[ -0.089038438663606695, 
              c[ -21][ t]], 
            Times[ -0.082699334313268744, 
              c[ -20][ t]], 
            Times[ -0.072413370861974122, 
              c[ -19][ t]], 
            Times[ -0.058468080236789913, 
              c[ -18][ t]], 
            Times[ -0.04131966847794722, 
              c[ -17][ t]], 
            Times[ -0.021580547817547879, 
              c[ -16][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -15][ t]], 
            Times[ 0.022561481809254869, 
              c[ -14][ t]], 
            Times[ 0.045163358568919301, 
              c[ -13][ t]], 
            Times[ 0.066820663127759972, 
              c[ -12][ t]], 
            Times[ 0.086542809078944891, 
              c[ -11][ t]], 
            Times[ 0.10337416789158609, 
              c[ -10][ t]], 
            Times[ 0.11643488132933186, 
              c[ -9][ t]], 
            Times[ 0.12496032289024853, 
              c[ -8][ t]], 
            Times[ 0.12833762891430928, 
              c[ -7][ t]], 
            Times[ 0.12613778810677614, 
              c[ -6][ t]], 
            Times[ 0.11814190616181255, 
              c[ -5][ t]], 
            Times[ 0.10436044624225692, 
              c[ -4][ t]], 
            Times[ 0.085044480344421705, 
              c[ -3][ t]], 
            Times[ 0.060688263076985105, 
              c[ -2][ t]], 
            Times[ 0.032022748374426029, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.034231213779558949, 
              c[ 1][ t]], 
            Times[ -0.069358014945125918, 
              c[ 2][ t]], 
            Times[ -0.10394325375429328, 
              c[ 3][ t]], 
            Times[ -0.13647135277833605, 
              c[ 4][ t]], 
            Times[ -0.1653986686265376, 
              c[ 5][ t]], 
            Times[ -0.18920668216016426, 
              c[ 6][ t]], 
            Times[ -0.20645618564475834, 
              c[ 7][ t]], 
            Times[ -0.21584055771952013, 
              c[ 8][ t]], 
            Times[ -0.21623620818304484, 
              c[ 9][ t]], 
            Times[ -0.20674833578317206, 
              c[ 10][ t]], 
            Times[ -0.18675027222298607, 
              c[ 11][ t]], 
            Times[ -0.15591488063143982, 
              c[ 12][ t]], 
            Times[ -0.11423673049785445, 
              c[ 13][ t]], 
            Times[ -0.062044074975450475, 
              c[ 14][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ 0.070907514257657622, 
              c[ 16][ t]], 
            Times[ 0.14938649372796345, 
              c[ 17][ t]], 
            Times[ 0.23387232094715985, 
              c[ 18][ t]], 
            Times[ 0.32256865202152135, 
              c[ 19][ t]], 
            Times[ 0.41349667156634395, 
              c[ 20][ t]], 
            Times[ 0.50455115242710469, 
              c[ 21][ t]], 
            Times[ 0.59356153372868015, 
              c[ 22][ t]], 
            Times[ 0.67835603854706317, 
              c[ 23][ t]], 
            Times[ 0.75682672864065692, 
              c[ 24][ t]], 
            Times[ 0.82699334313268802, 
              c[ 25][ t]], 
            Times[ 0.88706379305918381, 
              c[ 26][ t]], 
            Times[ 0.93548928378863916, 
              c[ 27][ t]], 
            Times[ 0.9710122092317629, 
              c[ 28][ t]], 
            Times[ 0.99270519960720671, 
              c[ 29][ t]], 
            Times[ 20.739208802178716, 
              c[ 30][ t]], 
            Times[ 0.99270519960720693, 
              c[ 31][ t]], 
            Times[ 0.9710122092317629, 
              c[ 32][ t]], 
            Times[ 0.93548928378863916, 
              c[ 33][ t]], 
            Times[ 0.88706379305918392, 
              c[ 34][ t]], 
            Times[ 0.82699334313268813, 
              c[ 35][ t]], 
            Times[ 0.75682672864065692, 
              c[ 36][ t]], 
            Times[ 0.67835603854706361, 
              c[ 37][ t]], 
            Times[ 0.59356153372868059, 
              c[ 38][ t]], 
            Times[ 0.50455115242710469, 
              c[ 39][ t]], 
            Times[ 0.41349667156634429, 
              c[ 40][ t]], 
            Times[ 0.32256865202152191, 
              c[ 41][ t]], 
            Times[ 0.23387232094715985, 
              c[ 42][ t]], 
            Times[ 0.14938649372796384, 
              c[ 43][ t]], 
            Times[ 0.070907514257658094, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ -0.062044074975450239, 
              c[ 46][ t]], 
            Times[ -0.11423673049785416, 
              c[ 47][ t]], 
            Times[ -0.15591488063143982, 
              c[ 48][ t]], 
            Times[ -0.18675027222298593, 
              c[ 49][ t]], 
            Times[ -0.20674833578317189, 
              c[ 50][ t]], 
            Times[ -0.21623620818304484, 
              c[ 51][ t]], 
            Times[ -0.21584055771952015, 
              c[ 52][ t]], 
            Times[ -0.20645618564475848, 
              c[ 53][ t]], 
            Times[ -0.18920668216016426, 
              c[ 54][ t]], 
            Times[ -0.16539866862653771, 
              c[ 55][ t]], 
            Times[ -0.13647135277833616, 
              c[ 56][ t]], 
            Times[ -0.10394325375429328, 
              c[ 57][ t]], 
            Times[ -0.06935801494512607, 
              c[ 58][ t]], 
            Times[ -0.034231213779559094, 
              c[ 59][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "31", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[31]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.010908848347331966`\ \(c[\(-60\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-59\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-58\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-57\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-56\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-55\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-54\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-53\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-52\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-51\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-50\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-49\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-48\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-47\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-46\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-45\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-44\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-43\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-42\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-41\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-40\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-39\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-38\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-37\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-36\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-35\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-34\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-33\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-32\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-31\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-30\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-28\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-27\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-26\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-25\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-24\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-23\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-22\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-21\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-20\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-19\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-18\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-17\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-16\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-15\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-14\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-13\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-12\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-11\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-10\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-9\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-8\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-7\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-6\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-5\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-4\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-3\)]\)[t] + 
            0.08504448034442161`\ \(c[\(-2\)]\)[t] + 
            0.060688263076985105`\ \(c[\(-1\)]\)[t] + 
            0.032022748374425904`\ \(c[0]\)[t] - 
            1.8033970416801674`*^-16\ \(c[1]\)[t] - 
            0.03423121377955895`\ \(c[2]\)[t] - 
            0.06935801494512607`\ \(c[3]\)[t] - 
            0.1039432537542934`\ \(c[4]\)[t] - 
            0.13647135277833605`\ \(c[5]\)[t] - 
            0.1653986686265377`\ \(c[6]\)[t] - 
            0.18920668216016426`\ \(c[7]\)[t] - 
            0.20645618564475843`\ \(c[8]\)[t] - 
            0.21584055771952015`\ \(c[9]\)[t] - 
            0.21623620818304484`\ \(c[10]\)[t] - 
            0.206748335783172`\ \(c[11]\)[t] - 
            0.18675027222298593`\ \(c[12]\)[t] - 
            0.15591488063143974`\ \(c[13]\)[t] - 
            0.11423673049785436`\ \(c[14]\)[t] - 
            0.06204407497545024`\ \(c[15]\)[t] + 
            1.8033970416801674`*^-16\ \(c[16]\)[t] + 
            0.07090751425765777`\ \(c[17]\)[t] + 
            0.14938649372796384`\ \(c[18]\)[t] + 
            0.23387232094715998`\ \(c[19]\)[t] + 
            0.3225686520215216`\ \(c[20]\)[t] + 
            0.4134966715663443`\ \(c[21]\)[t] + 
            0.5045511524271047`\ \(c[22]\)[t] + 
            0.5935615337286806`\ \(c[23]\)[t] + 
            0.6783560385470636`\ \(c[24]\)[t] + 
            0.7568267286406569`\ \(c[25]\)[t] + 
            0.8269933431326881`\ \(c[26]\)[t] + 
            0.8870637930591839`\ \(c[27]\)[t] + 
            0.9354892837886392`\ \(c[28]\)[t] + 
            0.9710122092317629`\ \(c[29]\)[t] + 
            0.9927051996072069`\ \(c[30]\)[t] + 
            22.077088509881936`\ \(c[31]\)[t] + 
            0.9927051996072067`\ \(c[32]\)[t] + 
            0.9710122092317629`\ \(c[33]\)[t] + 
            0.9354892837886392`\ \(c[34]\)[t] + 
            0.8870637930591838`\ \(c[35]\)[t] + 
            0.826993343132688`\ \(c[36]\)[t] + 
            0.7568267286406569`\ \(c[37]\)[t] + 
            0.6783560385470632`\ \(c[38]\)[t] + 
            0.5935615337286801`\ \(c[39]\)[t] + 
            0.5045511524271047`\ \(c[40]\)[t] + 
            0.4134966715663443`\ \(c[41]\)[t] + 
            0.32256865202152113`\ \(c[42]\)[t] + 
            0.23387232094715985`\ \(c[43]\)[t] + 
            0.14938649372796384`\ \(c[44]\)[t] + 
            0.07090751425765746`\ \(c[45]\)[t] + 
            3.898171832519376`*^-17\ \(c[46]\)[t] - 
            0.06204407497545024`\ \(c[47]\)[t] - 
            0.11423673049785459`\ \(c[48]\)[t] - 
            0.15591488063143982`\ \(c[49]\)[t] - 
            0.18675027222298593`\ \(c[50]\)[t] - 
            0.20674833578317206`\ \(c[51]\)[t] - 
            0.21623620818304484`\ \(c[52]\)[t] - 
            0.21584055771952015`\ \(c[53]\)[t] - 
            0.20645618564475834`\ \(c[54]\)[t] - 
            0.18920668216016426`\ \(c[55]\)[t] - 
            0.1653986686265377`\ \(c[56]\)[t] - 
            0.1364713527783359`\ \(c[57]\)[t] - 
            0.10394325375429328`\ \(c[58]\)[t] - 
            0.06935801494512607`\ \(c[59]\)[t] - 
            0.034231213779558796`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 31, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 31]][ t]], 
          Plus[ 
            Times[ 0.010908848347331966, 
              c[ -60][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -59][ t]], 
            Times[ -0.011153991006822649, 
              c[ -58][ t]], 
            Times[ -0.022068459300722043, 
              c[ -57][ t]], 
            Times[ -0.032258251165125679, 
              c[ -56][ t]], 
            Times[ -0.041258781072520248, 
              c[ -55][ t]], 
            Times[ -0.048646667243099281, 
              c[ -54][ t]], 
            Times[ -0.054059052045761224, 
              c[ -53][ t]], 
            Times[ -0.057210750238908967, 
              c[ -52][ t]], 
            Times[ -0.057908442314993203, 
              c[ -51][ t]], 
            Times[ -0.05606123915856713, 
              c[ -50][ t]], 
            Times[ -0.05168708394579296, 
              c[ -49][ t]], 
            Times[ -0.044914622433376419, 
              c[ -48][ t]], 
            Times[ -0.035980357068793781, 
              c[ -47][ t]], 
            Times[ -0.025221096343682053, 
              c[ -46][ t]], 
            Times[ -0.013061910521147383, 
              c[ -45][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -44][ t]], 
            Times[ 0.013414935129827233, 
              c[ -43][ t]], 
            Times[ 0.026603074225527826, 
              c[ -42][ t]], 
            Times[ 0.038978720157860088, 
              c[ -41][ t]], 
            Times[ 0.049975424961080865, 
              c[ -40][ t]], 
            Times[ 0.059070953080906326, 
              c[ -39][ t]], 
            Times[ 0.065811019881796273, 
              c[ -38][ t]], 
            Times[ 0.069830768673962415, 
              c[ -37][ t]], 
            Times[ 0.070873018952678238, 
              c[ -36][ t]], 
            Times[ 0.068802429876423349, 
              c[ -35][ t]], 
            Times[ 0.063614872548668253, 
              c[ -34][ t]], 
            Times[ 0.055441487066198933, 
              c[ -33][ t]], 
            Times[ 0.044547108751839919, 
              c[ -32][ t]], 
            Times[ 0.031322974491347078, 
              c[ -31][ t]], 
            Times[ 0.016273855731265604, 
              c[ -30][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ -0.016825511857749401, 
              c[ -28][ t]], 
            Times[ -0.033483179628681567, 
              c[ -27][ t]], 
            Times[ -0.049236278094138941, 
              c[ -26][ t]], 
            Times[ -0.063361699504227528, 
              c[ -25][ t]], 
            Times[ -0.075181213012062598, 
              c[ -24][ t]], 
            Times[ -0.084091858737850814, 
              c[ -23][ t]], 
            Times[ -0.089594193770366884, 
              c[ -22][ t]], 
            Times[ -0.091317159035181589, 
              c[ -21][ t]], 
            Times[ -0.089038438663606695, 
              c[ -20][ t]], 
            Times[ -0.082699334313268744, 
              c[ -19][ t]], 
            Times[ -0.072413370861974122, 
              c[ -18][ t]], 
            Times[ -0.058468080236789913, 
              c[ -17][ t]], 
            Times[ -0.04131966847794722, 
              c[ -16][ t]], 
            Times[ -0.021580547817547879, 
              c[ -15][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -14][ t]], 
            Times[ 0.022561481809254869, 
              c[ -13][ t]], 
            Times[ 0.045163358568919301, 
              c[ -12][ t]], 
            Times[ 0.066820663127759972, 
              c[ -11][ t]], 
            Times[ 0.086542809078944891, 
              c[ -10][ t]], 
            Times[ 0.10337416789158609, 
              c[ -9][ t]], 
            Times[ 0.11643488132933186, 
              c[ -8][ t]], 
            Times[ 0.12496032289024853, 
              c[ -7][ t]], 
            Times[ 0.12833762891430928, 
              c[ -6][ t]], 
            Times[ 0.12613778810677612, 
              c[ -5][ t]], 
            Times[ 0.11814190616181255, 
              c[ -4][ t]], 
            Times[ 0.10436044624225685, 
              c[ -3][ t]], 
            Times[ 0.085044480344421608, 
              c[ -2][ t]], 
            Times[ 0.060688263076985105, 
              c[ -1][ t]], 
            Times[ 0.032022748374425904, 
              c[ 0][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 1][ t]], 
            Times[ -0.034231213779558949, 
              c[ 2][ t]], 
            Times[ -0.06935801494512607, 
              c[ 3][ t]], 
            Times[ -0.1039432537542934, 
              c[ 4][ t]], 
            Times[ -0.13647135277833605, 
              c[ 5][ t]], 
            Times[ -0.16539866862653771, 
              c[ 6][ t]], 
            Times[ -0.18920668216016426, 
              c[ 7][ t]], 
            Times[ -0.20645618564475843, 
              c[ 8][ t]], 
            Times[ -0.21584055771952015, 
              c[ 9][ t]], 
            Times[ -0.21623620818304484, 
              c[ 10][ t]], 
            Times[ -0.206748335783172, 
              c[ 11][ t]], 
            Times[ -0.18675027222298593, 
              c[ 12][ t]], 
            Times[ -0.15591488063143974, 
              c[ 13][ t]], 
            Times[ -0.11423673049785436, 
              c[ 14][ t]], 
            Times[ -0.062044074975450239, 
              c[ 15][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 16][ t]], 
            Times[ 0.070907514257657775, 
              c[ 17][ t]], 
            Times[ 0.14938649372796384, 
              c[ 18][ t]], 
            Times[ 0.23387232094715998, 
              c[ 19][ t]], 
            Times[ 0.32256865202152157, 
              c[ 20][ t]], 
            Times[ 0.41349667156634429, 
              c[ 21][ t]], 
            Times[ 0.50455115242710469, 
              c[ 22][ t]], 
            Times[ 0.59356153372868059, 
              c[ 23][ t]], 
            Times[ 0.67835603854706361, 
              c[ 24][ t]], 
            Times[ 0.75682672864065692, 
              c[ 25][ t]], 
            Times[ 0.82699334313268813, 
              c[ 26][ t]], 
            Times[ 0.88706379305918392, 
              c[ 27][ t]], 
            Times[ 0.93548928378863916, 
              c[ 28][ t]], 
            Times[ 0.9710122092317629, 
              c[ 29][ t]], 
            Times[ 0.99270519960720693, 
              c[ 30][ t]], 
            Times[ 22.077088509881936, 
              c[ 31][ t]], 
            Times[ 0.99270519960720671, 
              c[ 32][ t]], 
            Times[ 0.9710122092317629, 
              c[ 33][ t]], 
            Times[ 0.93548928378863916, 
              c[ 34][ t]], 
            Times[ 0.88706379305918381, 
              c[ 35][ t]], 
            Times[ 0.82699334313268802, 
              c[ 36][ t]], 
            Times[ 0.75682672864065692, 
              c[ 37][ t]], 
            Times[ 0.67835603854706317, 
              c[ 38][ t]], 
            Times[ 0.59356153372868015, 
              c[ 39][ t]], 
            Times[ 0.50455115242710469, 
              c[ 40][ t]], 
            Times[ 0.41349667156634429, 
              c[ 41][ t]], 
            Times[ 0.32256865202152113, 
              c[ 42][ t]], 
            Times[ 0.23387232094715985, 
              c[ 43][ t]], 
            Times[ 0.14938649372796384, 
              c[ 44][ t]], 
            Times[ 0.070907514257657456, 
              c[ 45][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 46][ t]], 
            Times[ -0.062044074975450239, 
              c[ 47][ t]], 
            Times[ -0.11423673049785459, 
              c[ 48][ t]], 
            Times[ -0.15591488063143982, 
              c[ 49][ t]], 
            Times[ -0.18675027222298593, 
              c[ 50][ t]], 
            Times[ -0.20674833578317206, 
              c[ 51][ t]], 
            Times[ -0.21623620818304484, 
              c[ 52][ t]], 
            Times[ -0.21584055771952015, 
              c[ 53][ t]], 
            Times[ -0.20645618564475834, 
              c[ 54][ t]], 
            Times[ -0.18920668216016426, 
              c[ 55][ t]], 
            Times[ -0.16539866862653771, 
              c[ 56][ t]], 
            Times[ -0.13647135277833591, 
              c[ 57][ t]], 
            Times[ -0.10394325375429328, 
              c[ 58][ t]], 
            Times[ -0.06935801494512607, 
              c[ 59][ t]], 
            Times[ -0.034231213779558796, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "32", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[32]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.021108961070255627`\ \(c[\(-60\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-59\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-58\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-57\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-56\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-55\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-54\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-53\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-52\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-51\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-50\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-49\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-48\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-47\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-46\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-45\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-44\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-43\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-42\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-41\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-40\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-39\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-38\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-37\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-36\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-35\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-34\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-33\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-32\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-31\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-30\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-29\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-28\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-27\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-26\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-25\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-24\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-23\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-22\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-21\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-20\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-19\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-18\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-17\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-16\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-15\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-14\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-13\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-12\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-11\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-10\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-9\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-8\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-7\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-6\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-5\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-4\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-3\)]\)[t] + 
            0.10436044624225685`\ \(c[\(-2\)]\)[t] + 
            0.0850444803444217`\ \(c[\(-1\)]\)[t] + 
            0.060688263076985105`\ \(c[0]\)[t] + 
            0.032022748374425904`\ \(c[1]\)[t] - 
            3.898171832519376`*^-17\ \(c[2]\)[t] - 
            0.03423121377955895`\ \(c[3]\)[t] - 
            0.06935801494512607`\ \(c[4]\)[t] - 
            0.10394325375429328`\ \(c[5]\)[t] - 
            0.13647135277833605`\ \(c[6]\)[t] - 
            0.1653986686265377`\ \(c[7]\)[t] - 
            0.18920668216016426`\ \(c[8]\)[t] - 
            0.20645618564475843`\ \(c[9]\)[t] - 
            0.21584055771952015`\ \(c[10]\)[t] - 
            0.21623620818304484`\ \(c[11]\)[t] - 
            0.206748335783172`\ \(c[12]\)[t] - 
            0.186750272222986`\ \(c[13]\)[t] - 
            0.15591488063143982`\ \(c[14]\)[t] - 
            0.11423673049785436`\ \(c[15]\)[t] - 
            0.06204407497545034`\ \(c[16]\)[t] + 
            3.898171832519376`*^-17\ \(c[17]\)[t] + 
            0.07090751425765777`\ \(c[18]\)[t] + 
            0.14938649372796362`\ \(c[19]\)[t] + 
            0.23387232094715985`\ \(c[20]\)[t] + 
            0.3225686520215216`\ \(c[21]\)[t] + 
            0.41349667156634395`\ \(c[22]\)[t] + 
            0.5045511524271047`\ \(c[23]\)[t] + 
            0.5935615337286806`\ \(c[24]\)[t] + 
            0.6783560385470632`\ \(c[25]\)[t] + 
            0.7568267286406569`\ \(c[26]\)[t] + 
            0.8269933431326881`\ \(c[27]\)[t] + 
            0.8870637930591838`\ \(c[28]\)[t] + 
            0.9354892837886392`\ \(c[29]\)[t] + 
            0.9710122092317629`\ \(c[30]\)[t] + 
            0.9927051996072067`\ \(c[31]\)[t] + 
            23.45883312603445`\ \(c[32]\)[t] + 
            0.9927051996072067`\ \(c[33]\)[t] + 
            0.9710122092317629`\ \(c[34]\)[t] + 
            0.9354892837886392`\ \(c[35]\)[t] + 
            0.8870637930591838`\ \(c[36]\)[t] + 
            0.8269933431326881`\ \(c[37]\)[t] + 
            0.7568267286406569`\ \(c[38]\)[t] + 
            0.6783560385470632`\ \(c[39]\)[t] + 
            0.5935615337286806`\ \(c[40]\)[t] + 
            0.504551152427105`\ \(c[41]\)[t] + 
            0.41349667156634395`\ \(c[42]\)[t] + 
            0.3225686520215216`\ \(c[43]\)[t] + 
            0.23387232094716018`\ \(c[44]\)[t] + 
            0.14938649372796345`\ \(c[45]\)[t] + 
            0.07090751425765777`\ \(c[46]\)[t] + 
            3.216976900108398`*^-16\ \(c[47]\)[t] - 
            0.062044074975450475`\ \(c[48]\)[t] - 
            0.11423673049785436`\ \(c[49]\)[t] - 
            0.15591488063143966`\ \(c[50]\)[t] - 
            0.18675027222298607`\ \(c[51]\)[t] - 
            0.206748335783172`\ \(c[52]\)[t] - 
            0.21623620818304481`\ \(c[53]\)[t] - 
            0.21584055771952013`\ \(c[54]\)[t] - 
            0.20645618564475843`\ \(c[55]\)[t] - 
            0.18920668216016434`\ \(c[56]\)[t] - 
            0.1653986686265376`\ \(c[57]\)[t] - 
            0.13647135277833605`\ \(c[58]\)[t] - 
            0.1039432537542934`\ \(c[59]\)[t] - 
            0.06935801494512592`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 32, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 32]][ t]], 
          Plus[ 
            Times[ 0.021108961070255627, 
              c[ -60][ t]], 
            Times[ 0.010908848347331785, 
              c[ -59][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -58][ t]], 
            Times[ -0.011153991006822649, 
              c[ -57][ t]], 
            Times[ -0.022068459300722043, 
              c[ -56][ t]], 
            Times[ -0.032258251165125519, 
              c[ -55][ t]], 
            Times[ -0.041258781072520248, 
              c[ -54][ t]], 
            Times[ -0.048646667243099399, 
              c[ -53][ t]], 
            Times[ -0.054059052045761224, 
              c[ -52][ t]], 
            Times[ -0.057210750238908967, 
              c[ -51][ t]], 
            Times[ -0.057908442314993203, 
              c[ -50][ t]], 
            Times[ -0.056061239158567186, 
              c[ -49][ t]], 
            Times[ -0.05168708394579296, 
              c[ -48][ t]], 
            Times[ -0.044914622433376288, 
              c[ -47][ t]], 
            Times[ -0.035980357068793781, 
              c[ -46][ t]], 
            Times[ -0.025221096343682053, 
              c[ -45][ t]], 
            Times[ -0.013061910521147276, 
              c[ -44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -43][ t]], 
            Times[ 0.013414935129827233, 
              c[ -42][ t]], 
            Times[ 0.026603074225527937, 
              c[ -41][ t]], 
            Times[ 0.03897872015785999, 
              c[ -40][ t]], 
            Times[ 0.049975424961080865, 
              c[ -39][ t]], 
            Times[ 0.059070953080906326, 
              c[ -38][ t]], 
            Times[ 0.065811019881796273, 
              c[ -37][ t]], 
            Times[ 0.069830768673962415, 
              c[ -36][ t]], 
            Times[ 0.070873018952678238, 
              c[ -35][ t]], 
            Times[ 0.068802429876423349, 
              c[ -34][ t]], 
            Times[ 0.063614872548668253, 
              c[ -33][ t]], 
            Times[ 0.055441487066198933, 
              c[ -32][ t]], 
            Times[ 0.044547108751839919, 
              c[ -31][ t]], 
            Times[ 0.031322974491347078, 
              c[ -30][ t]], 
            Times[ 0.016273855731265604, 
              c[ -29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -28][ t]], 
            Times[ -0.016825511857749401, 
              c[ -27][ t]], 
            Times[ -0.033483179628681567, 
              c[ -26][ t]], 
            Times[ -0.049236278094138941, 
              c[ -25][ t]], 
            Times[ -0.063361699504227528, 
              c[ -24][ t]], 
            Times[ -0.075181213012062598, 
              c[ -23][ t]], 
            Times[ -0.084091858737850814, 
              c[ -22][ t]], 
            Times[ -0.089594193770366884, 
              c[ -21][ t]], 
            Times[ -0.091317159035181589, 
              c[ -20][ t]], 
            Times[ -0.089038438663606695, 
              c[ -19][ t]], 
            Times[ -0.082699334313268744, 
              c[ -18][ t]], 
            Times[ -0.072413370861974122, 
              c[ -17][ t]], 
            Times[ -0.058468080236789913, 
              c[ -16][ t]], 
            Times[ -0.04131966847794722, 
              c[ -15][ t]], 
            Times[ -0.021580547817547879, 
              c[ -14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -13][ t]], 
            Times[ 0.022561481809254869, 
              c[ -12][ t]], 
            Times[ 0.045163358568919301, 
              c[ -11][ t]], 
            Times[ 0.066820663127759972, 
              c[ -10][ t]], 
            Times[ 0.086542809078944891, 
              c[ -9][ t]], 
            Times[ 0.10337416789158609, 
              c[ -8][ t]], 
            Times[ 0.11643488132933186, 
              c[ -7][ t]], 
            Times[ 0.12496032289024853, 
              c[ -6][ t]], 
            Times[ 0.12833762891430928, 
              c[ -5][ t]], 
            Times[ 0.12613778810677614, 
              c[ -4][ t]], 
            Times[ 0.11814190616181255, 
              c[ -3][ t]], 
            Times[ 0.10436044624225685, 
              c[ -2][ t]], 
            Times[ 0.085044480344421705, 
              c[ -1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 0][ t]], 
            Times[ 0.032022748374425904, 
              c[ 1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 2][ t]], 
            Times[ -0.034231213779558949, 
              c[ 3][ t]], 
            Times[ -0.06935801494512607, 
              c[ 4][ t]], 
            Times[ -0.10394325375429328, 
              c[ 5][ t]], 
            Times[ -0.13647135277833605, 
              c[ 6][ t]], 
            Times[ -0.16539866862653771, 
              c[ 7][ t]], 
            Times[ -0.18920668216016426, 
              c[ 8][ t]], 
            Times[ -0.20645618564475843, 
              c[ 9][ t]], 
            Times[ -0.21584055771952015, 
              c[ 10][ t]], 
            Times[ -0.21623620818304484, 
              c[ 11][ t]], 
            Times[ -0.206748335783172, 
              c[ 12][ t]], 
            Times[ -0.18675027222298601, 
              c[ 13][ t]], 
            Times[ -0.15591488063143982, 
              c[ 14][ t]], 
            Times[ -0.11423673049785436, 
              c[ 15][ t]], 
            Times[ -0.062044074975450343, 
              c[ 16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 17][ t]], 
            Times[ 0.070907514257657775, 
              c[ 18][ t]], 
            Times[ 0.14938649372796362, 
              c[ 19][ t]], 
            Times[ 0.23387232094715985, 
              c[ 20][ t]], 
            Times[ 0.32256865202152157, 
              c[ 21][ t]], 
            Times[ 0.41349667156634395, 
              c[ 22][ t]], 
            Times[ 0.50455115242710469, 
              c[ 23][ t]], 
            Times[ 0.59356153372868059, 
              c[ 24][ t]], 
            Times[ 0.67835603854706317, 
              c[ 25][ t]], 
            Times[ 0.75682672864065692, 
              c[ 26][ t]], 
            Times[ 0.82699334313268813, 
              c[ 27][ t]], 
            Times[ 0.88706379305918381, 
              c[ 28][ t]], 
            Times[ 0.93548928378863916, 
              c[ 29][ t]], 
            Times[ 0.9710122092317629, 
              c[ 30][ t]], 
            Times[ 0.99270519960720671, 
              c[ 31][ t]], 
            Times[ 23.458833126034449, 
              c[ 32][ t]], 
            Times[ 0.99270519960720671, 
              c[ 33][ t]], 
            Times[ 0.9710122092317629, 
              c[ 34][ t]], 
            Times[ 0.93548928378863916, 
              c[ 35][ t]], 
            Times[ 0.88706379305918381, 
              c[ 36][ t]], 
            Times[ 0.82699334313268813, 
              c[ 37][ t]], 
            Times[ 0.75682672864065692, 
              c[ 38][ t]], 
            Times[ 0.67835603854706317, 
              c[ 39][ t]], 
            Times[ 0.59356153372868059, 
              c[ 40][ t]], 
            Times[ 0.50455115242710502, 
              c[ 41][ t]], 
            Times[ 0.41349667156634395, 
              c[ 42][ t]], 
            Times[ 0.32256865202152157, 
              c[ 43][ t]], 
            Times[ 0.23387232094716018, 
              c[ 44][ t]], 
            Times[ 0.14938649372796345, 
              c[ 45][ t]], 
            Times[ 0.070907514257657775, 
              c[ 46][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 47][ t]], 
            Times[ -0.062044074975450475, 
              c[ 48][ t]], 
            Times[ -0.11423673049785436, 
              c[ 49][ t]], 
            Times[ -0.15591488063143966, 
              c[ 50][ t]], 
            Times[ -0.18675027222298607, 
              c[ 51][ t]], 
            Times[ -0.206748335783172, 
              c[ 52][ t]], 
            Times[ -0.21623620818304481, 
              c[ 53][ t]], 
            Times[ -0.21584055771952013, 
              c[ 54][ t]], 
            Times[ -0.20645618564475843, 
              c[ 55][ t]], 
            Times[ -0.18920668216016434, 
              c[ 56][ t]], 
            Times[ -0.1653986686265376, 
              c[ 57][ t]], 
            Times[ -0.13647135277833605, 
              c[ 58][ t]], 
            Times[ -0.1039432537542934, 
              c[ 59][ t]], 
            Times[ -0.069358014945125918, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "33", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[33]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.030177073670601236`\ \(c[\(-60\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-59\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-58\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-56\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-55\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-54\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-53\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-52\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-51\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-50\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-49\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-48\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-47\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-46\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-45\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-44\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-43\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-42\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-41\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-40\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-39\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-38\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-37\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-36\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-35\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-34\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-33\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-32\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-31\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-30\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-29\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-28\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-26\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-25\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-24\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-23\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-22\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-21\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-20\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-19\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-18\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-17\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-16\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-15\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-14\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-13\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-12\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-11\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-10\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-9\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-8\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-7\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-6\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-5\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-4\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-3\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-2\)]\)[t] + 
            0.10436044624225692`\ \(c[\(-1\)]\)[t] + 
            0.0850444803444217`\ \(c[0]\)[t] + 
            0.060688263076985105`\ \(c[1]\)[t] + 
            0.03202274837442603`\ \(c[2]\)[t] - 
            3.898171832519376`*^-17\ \(c[3]\)[t] - 
            0.03423121377955895`\ \(c[4]\)[t] - 
            0.06935801494512592`\ \(c[5]\)[t] - 
            0.10394325375429328`\ \(c[6]\)[t] - 
            0.1364713527783359`\ \(c[7]\)[t] - 
            0.1653986686265376`\ \(c[8]\)[t] - 
            0.18920668216016426`\ \(c[9]\)[t] - 
            0.20645618564475834`\ \(c[10]\)[t] - 
            0.21584055771952013`\ \(c[11]\)[t] - 
            0.21623620818304484`\ \(c[12]\)[t] - 
            0.20674833578317206`\ \(c[13]\)[t] - 
            0.18675027222298607`\ \(c[14]\)[t] - 
            0.15591488063143982`\ \(c[15]\)[t] - 
            0.11423673049785445`\ \(c[16]\)[t] - 
            0.062044074975450475`\ \(c[17]\)[t] + 
            3.898171832519376`*^-17\ \(c[18]\)[t] + 
            0.07090751425765762`\ \(c[19]\)[t] + 
            0.14938649372796345`\ \(c[20]\)[t] + 
            0.23387232094715985`\ \(c[21]\)[t] + 
            0.32256865202152113`\ \(c[22]\)[t] + 
            0.41349667156634395`\ \(c[23]\)[t] + 
            0.5045511524271047`\ \(c[24]\)[t] + 
            0.5935615337286801`\ \(c[25]\)[t] + 
            0.6783560385470632`\ \(c[26]\)[t] + 
            0.7568267286406569`\ \(c[27]\)[t] + 
            0.826993343132688`\ \(c[28]\)[t] + 
            0.8870637930591838`\ \(c[29]\)[t] + 
            0.9354892837886392`\ \(c[30]\)[t] + 
            0.9710122092317629`\ \(c[31]\)[t] + 
            0.9927051996072067`\ \(c[32]\)[t] + 
            24.884442650636245`\ \(c[33]\)[t] + 
            0.9927051996072069`\ \(c[34]\)[t] + 
            0.9710122092317629`\ \(c[35]\)[t] + 
            0.9354892837886392`\ \(c[36]\)[t] + 
            0.8870637930591839`\ \(c[37]\)[t] + 
            0.8269933431326881`\ \(c[38]\)[t] + 
            0.7568267286406569`\ \(c[39]\)[t] + 
            0.6783560385470636`\ \(c[40]\)[t] + 
            0.5935615337286809`\ \(c[41]\)[t] + 
            0.5045511524271047`\ \(c[42]\)[t] + 
            0.4134966715663443`\ \(c[43]\)[t] + 
            0.3225686520215219`\ \(c[44]\)[t] + 
            0.23387232094715985`\ \(c[45]\)[t] + 
            0.14938649372796384`\ \(c[46]\)[t] + 
            0.0709075142576581`\ \(c[47]\)[t] + 
            3.898171832519376`*^-17\ \(c[48]\)[t] - 
            0.06204407497545024`\ \(c[49]\)[t] - 
            0.11423673049785416`\ \(c[50]\)[t] - 
            0.15591488063143982`\ \(c[51]\)[t] - 
            0.18675027222298593`\ \(c[52]\)[t] - 
            0.2067483357831719`\ \(c[53]\)[t] - 
            0.21623620818304484`\ \(c[54]\)[t] - 
            0.21584055771952015`\ \(c[55]\)[t] - 
            0.20645618564475848`\ \(c[56]\)[t] - 
            0.18920668216016426`\ \(c[57]\)[t] - 
            0.1653986686265377`\ \(c[58]\)[t] - 
            0.13647135277833616`\ \(c[59]\)[t] - 
            0.10394325375429328`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 33, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 33]][ t]], 
          Plus[ 
            Times[ 0.030177073670601236, 
              c[ -60][ t]], 
            Times[ 0.021108961070255627, 
              c[ -59][ t]], 
            Times[ 0.010908848347331966, 
              c[ -58][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ -0.011153991006822649, 
              c[ -56][ t]], 
            Times[ -0.022068459300722043, 
              c[ -55][ t]], 
            Times[ -0.032258251165125519, 
              c[ -54][ t]], 
            Times[ -0.041258781072520248, 
              c[ -53][ t]], 
            Times[ -0.048646667243099281, 
              c[ -52][ t]], 
            Times[ -0.054059052045761224, 
              c[ -51][ t]], 
            Times[ -0.057210750238908967, 
              c[ -50][ t]], 
            Times[ -0.057908442314993203, 
              c[ -49][ t]], 
            Times[ -0.056061239158567186, 
              c[ -48][ t]], 
            Times[ -0.05168708394579296, 
              c[ -47][ t]], 
            Times[ -0.044914622433376419, 
              c[ -46][ t]], 
            Times[ -0.035980357068793781, 
              c[ -45][ t]], 
            Times[ -0.025221096343682053, 
              c[ -44][ t]], 
            Times[ -0.013061910521147383, 
              c[ -43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -42][ t]], 
            Times[ 0.013414935129827233, 
              c[ -41][ t]], 
            Times[ 0.026603074225527826, 
              c[ -40][ t]], 
            Times[ 0.03897872015785999, 
              c[ -39][ t]], 
            Times[ 0.049975424961080865, 
              c[ -38][ t]], 
            Times[ 0.059070953080906326, 
              c[ -37][ t]], 
            Times[ 0.065811019881796273, 
              c[ -36][ t]], 
            Times[ 0.069830768673962415, 
              c[ -35][ t]], 
            Times[ 0.070873018952678238, 
              c[ -34][ t]], 
            Times[ 0.068802429876423349, 
              c[ -33][ t]], 
            Times[ 0.063614872548668253, 
              c[ -32][ t]], 
            Times[ 0.055441487066198933, 
              c[ -31][ t]], 
            Times[ 0.044547108751839919, 
              c[ -30][ t]], 
            Times[ 0.031322974491347078, 
              c[ -29][ t]], 
            Times[ 0.016273855731265604, 
              c[ -28][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ -0.016825511857749401, 
              c[ -26][ t]], 
            Times[ -0.033483179628681567, 
              c[ -25][ t]], 
            Times[ -0.049236278094138941, 
              c[ -24][ t]], 
            Times[ -0.063361699504227528, 
              c[ -23][ t]], 
            Times[ -0.075181213012062598, 
              c[ -22][ t]], 
            Times[ -0.084091858737850814, 
              c[ -21][ t]], 
            Times[ -0.089594193770366884, 
              c[ -20][ t]], 
            Times[ -0.091317159035181589, 
              c[ -19][ t]], 
            Times[ -0.089038438663606695, 
              c[ -18][ t]], 
            Times[ -0.082699334313268744, 
              c[ -17][ t]], 
            Times[ -0.072413370861974122, 
              c[ -16][ t]], 
            Times[ -0.058468080236789913, 
              c[ -15][ t]], 
            Times[ -0.04131966847794722, 
              c[ -14][ t]], 
            Times[ -0.021580547817547879, 
              c[ -13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -12][ t]], 
            Times[ 0.022561481809254869, 
              c[ -11][ t]], 
            Times[ 0.045163358568919301, 
              c[ -10][ t]], 
            Times[ 0.066820663127759972, 
              c[ -9][ t]], 
            Times[ 0.086542809078944752, 
              c[ -8][ t]], 
            Times[ 0.10337416789158609, 
              c[ -7][ t]], 
            Times[ 0.11643488132933186, 
              c[ -6][ t]], 
            Times[ 0.12496032289024853, 
              c[ -5][ t]], 
            Times[ 0.12833762891430925, 
              c[ -4][ t]], 
            Times[ 0.12613778810677614, 
              c[ -3][ t]], 
            Times[ 0.11814190616181255, 
              c[ -2][ t]], 
            Times[ 0.10436044624225692, 
              c[ -1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 0][ t]], 
            Times[ 0.060688263076985105, 
              c[ 1][ t]], 
            Times[ 0.032022748374426029, 
              c[ 2][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 3][ t]], 
            Times[ -0.034231213779558949, 
              c[ 4][ t]], 
            Times[ -0.069358014945125918, 
              c[ 5][ t]], 
            Times[ -0.10394325375429328, 
              c[ 6][ t]], 
            Times[ -0.13647135277833591, 
              c[ 7][ t]], 
            Times[ -0.1653986686265376, 
              c[ 8][ t]], 
            Times[ -0.18920668216016426, 
              c[ 9][ t]], 
            Times[ -0.20645618564475834, 
              c[ 10][ t]], 
            Times[ -0.21584055771952013, 
              c[ 11][ t]], 
            Times[ -0.21623620818304484, 
              c[ 12][ t]], 
            Times[ -0.20674833578317206, 
              c[ 13][ t]], 
            Times[ -0.18675027222298607, 
              c[ 14][ t]], 
            Times[ -0.15591488063143982, 
              c[ 15][ t]], 
            Times[ -0.11423673049785445, 
              c[ 16][ t]], 
            Times[ -0.062044074975450475, 
              c[ 17][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ 0.070907514257657622, 
              c[ 19][ t]], 
            Times[ 0.14938649372796345, 
              c[ 20][ t]], 
            Times[ 0.23387232094715985, 
              c[ 21][ t]], 
            Times[ 0.32256865202152113, 
              c[ 22][ t]], 
            Times[ 0.41349667156634395, 
              c[ 23][ t]], 
            Times[ 0.50455115242710469, 
              c[ 24][ t]], 
            Times[ 0.59356153372868015, 
              c[ 25][ t]], 
            Times[ 0.67835603854706317, 
              c[ 26][ t]], 
            Times[ 0.75682672864065692, 
              c[ 27][ t]], 
            Times[ 0.82699334313268802, 
              c[ 28][ t]], 
            Times[ 0.88706379305918381, 
              c[ 29][ t]], 
            Times[ 0.93548928378863916, 
              c[ 30][ t]], 
            Times[ 0.9710122092317629, 
              c[ 31][ t]], 
            Times[ 0.99270519960720671, 
              c[ 32][ t]], 
            Times[ 24.884442650636245, 
              c[ 33][ t]], 
            Times[ 0.99270519960720693, 
              c[ 34][ t]], 
            Times[ 0.9710122092317629, 
              c[ 35][ t]], 
            Times[ 0.93548928378863916, 
              c[ 36][ t]], 
            Times[ 0.88706379305918392, 
              c[ 37][ t]], 
            Times[ 0.82699334313268813, 
              c[ 38][ t]], 
            Times[ 0.75682672864065692, 
              c[ 39][ t]], 
            Times[ 0.67835603854706361, 
              c[ 40][ t]], 
            Times[ 0.59356153372868092, 
              c[ 41][ t]], 
            Times[ 0.50455115242710469, 
              c[ 42][ t]], 
            Times[ 0.41349667156634429, 
              c[ 43][ t]], 
            Times[ 0.32256865202152191, 
              c[ 44][ t]], 
            Times[ 0.23387232094715985, 
              c[ 45][ t]], 
            Times[ 0.14938649372796384, 
              c[ 46][ t]], 
            Times[ 0.070907514257658094, 
              c[ 47][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 48][ t]], 
            Times[ -0.062044074975450239, 
              c[ 49][ t]], 
            Times[ -0.11423673049785416, 
              c[ 50][ t]], 
            Times[ -0.15591488063143982, 
              c[ 51][ t]], 
            Times[ -0.18675027222298593, 
              c[ 52][ t]], 
            Times[ -0.20674833578317189, 
              c[ 53][ t]], 
            Times[ -0.21623620818304484, 
              c[ 54][ t]], 
            Times[ -0.21584055771952015, 
              c[ 55][ t]], 
            Times[ -0.20645618564475848, 
              c[ 56][ t]], 
            Times[ -0.18920668216016426, 
              c[ 57][ t]], 
            Times[ -0.16539866862653771, 
              c[ 58][ t]], 
            Times[ -0.13647135277833616, 
              c[ 59][ t]], 
            Times[ -0.10394325375429328, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "34", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[34]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.03774739544932687`\ \(c[\(-60\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-59\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-58\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-57\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-56\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-55\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-54\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-53\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-52\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-51\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-50\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-49\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-48\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-47\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-46\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-45\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-44\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-43\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-42\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-41\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-40\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-39\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-38\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-37\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-36\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-35\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-34\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-33\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-32\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-31\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-30\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-29\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-28\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-27\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-25\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-24\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-23\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-22\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-21\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-20\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-19\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-18\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-17\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-16\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-15\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-14\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-13\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-12\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-11\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-10\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-9\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-8\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-7\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-6\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-5\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-4\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-3\)]\)[t] + 
            0.12613778810677612`\ \(c[\(-2\)]\)[t] + 
            0.11814190616181255`\ \(c[\(-1\)]\)[t] + 
            0.10436044624225685`\ \(c[0]\)[t] + 
            0.08504448034442161`\ \(c[1]\)[t] + 
            0.060688263076985105`\ \(c[2]\)[t] + 
            0.032022748374425904`\ \(c[3]\)[t] - 
            1.8033970416801674`*^-16\ \(c[4]\)[t] - 
            0.03423121377955895`\ \(c[5]\)[t] - 
            0.06935801494512607`\ \(c[6]\)[t] - 
            0.10394325375429328`\ \(c[7]\)[t] - 
            0.13647135277833605`\ \(c[8]\)[t] - 
            0.1653986686265377`\ \(c[9]\)[t] - 
            0.18920668216016426`\ \(c[10]\)[t] - 
            0.20645618564475843`\ \(c[11]\)[t] - 
            0.21584055771952015`\ \(c[12]\)[t] - 
            0.21623620818304484`\ \(c[13]\)[t] - 
            0.206748335783172`\ \(c[14]\)[t] - 
            0.18675027222298593`\ \(c[15]\)[t] - 
            0.15591488063143974`\ \(c[16]\)[t] - 
            0.11423673049785436`\ \(c[17]\)[t] - 
            0.06204407497545024`\ \(c[18]\)[t] + 
            1.8033970416801674`*^-16\ \(c[19]\)[t] + 
            0.07090751425765777`\ \(c[20]\)[t] + 
            0.14938649372796384`\ \(c[21]\)[t] + 
            0.23387232094715985`\ \(c[22]\)[t] + 
            0.3225686520215216`\ \(c[23]\)[t] + 
            0.4134966715663443`\ \(c[24]\)[t] + 
            0.5045511524271047`\ \(c[25]\)[t] + 
            0.5935615337286806`\ \(c[26]\)[t] + 
            0.6783560385470636`\ \(c[27]\)[t] + 
            0.7568267286406569`\ \(c[28]\)[t] + 
            0.8269933431326881`\ \(c[29]\)[t] + 
            0.8870637930591839`\ \(c[30]\)[t] + 
            0.9354892837886392`\ \(c[31]\)[t] + 
            0.9710122092317629`\ \(c[32]\)[t] + 
            0.9927051996072069`\ \(c[33]\)[t] + 
            26.353917083687325`\ \(c[34]\)[t] + 
            0.9927051996072067`\ \(c[35]\)[t] + 
            0.9710122092317629`\ \(c[36]\)[t] + 
            0.9354892837886392`\ \(c[37]\)[t] + 
            0.8870637930591838`\ \(c[38]\)[t] + 
            0.826993343132688`\ \(c[39]\)[t] + 
            0.7568267286406569`\ \(c[40]\)[t] + 
            0.6783560385470636`\ \(c[41]\)[t] + 
            0.5935615337286801`\ \(c[42]\)[t] + 
            0.5045511524271047`\ \(c[43]\)[t] + 
            0.4134966715663443`\ \(c[44]\)[t] + 
            0.32256865202152113`\ \(c[45]\)[t] + 
            0.23387232094715985`\ \(c[46]\)[t] + 
            0.14938649372796384`\ \(c[47]\)[t] + 
            0.07090751425765746`\ \(c[48]\)[t] + 
            3.898171832519376`*^-17\ \(c[49]\)[t] - 
            0.06204407497545024`\ \(c[50]\)[t] - 
            0.11423673049785459`\ \(c[51]\)[t] - 
            0.15591488063143982`\ \(c[52]\)[t] - 
            0.18675027222298593`\ \(c[53]\)[t] - 
            0.20674833578317206`\ \(c[54]\)[t] - 
            0.21623620818304484`\ \(c[55]\)[t] - 
            0.21584055771952015`\ \(c[56]\)[t] - 
            0.20645618564475834`\ \(c[57]\)[t] - 
            0.18920668216016426`\ \(c[58]\)[t] - 
            0.1653986686265377`\ \(c[59]\)[t] - 
            0.1364713527783359`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 34, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 34]][ t]], 
          Plus[ 
            Times[ 0.03774739544932687, 
              c[ -60][ t]], 
            Times[ 0.030177073670601094, 
              c[ -59][ t]], 
            Times[ 0.021108961070255627, 
              c[ -58][ t]], 
            Times[ 0.010908848347331966, 
              c[ -57][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -56][ t]], 
            Times[ -0.011153991006822649, 
              c[ -55][ t]], 
            Times[ -0.022068459300722043, 
              c[ -54][ t]], 
            Times[ -0.032258251165125679, 
              c[ -53][ t]], 
            Times[ -0.041258781072520248, 
              c[ -52][ t]], 
            Times[ -0.048646667243099281, 
              c[ -51][ t]], 
            Times[ -0.054059052045761224, 
              c[ -50][ t]], 
            Times[ -0.057210750238908967, 
              c[ -49][ t]], 
            Times[ -0.057908442314993203, 
              c[ -48][ t]], 
            Times[ -0.05606123915856713, 
              c[ -47][ t]], 
            Times[ -0.05168708394579296, 
              c[ -46][ t]], 
            Times[ -0.044914622433376419, 
              c[ -45][ t]], 
            Times[ -0.035980357068793781, 
              c[ -44][ t]], 
            Times[ -0.025221096343682053, 
              c[ -43][ t]], 
            Times[ -0.013061910521147383, 
              c[ -42][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -41][ t]], 
            Times[ 0.013414935129827233, 
              c[ -40][ t]], 
            Times[ 0.026603074225527826, 
              c[ -39][ t]], 
            Times[ 0.03897872015785999, 
              c[ -38][ t]], 
            Times[ 0.049975424961080865, 
              c[ -37][ t]], 
            Times[ 0.059070953080906326, 
              c[ -36][ t]], 
            Times[ 0.065811019881796273, 
              c[ -35][ t]], 
            Times[ 0.069830768673962415, 
              c[ -34][ t]], 
            Times[ 0.070873018952678238, 
              c[ -33][ t]], 
            Times[ 0.068802429876423349, 
              c[ -32][ t]], 
            Times[ 0.063614872548668253, 
              c[ -31][ t]], 
            Times[ 0.055441487066198933, 
              c[ -30][ t]], 
            Times[ 0.044547108751839919, 
              c[ -29][ t]], 
            Times[ 0.031322974491347078, 
              c[ -28][ t]], 
            Times[ 0.016273855731265604, 
              c[ -27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ -0.016825511857749401, 
              c[ -25][ t]], 
            Times[ -0.033483179628681567, 
              c[ -24][ t]], 
            Times[ -0.049236278094138941, 
              c[ -23][ t]], 
            Times[ -0.063361699504227528, 
              c[ -22][ t]], 
            Times[ -0.075181213012062598, 
              c[ -21][ t]], 
            Times[ -0.084091858737850814, 
              c[ -20][ t]], 
            Times[ -0.089594193770366884, 
              c[ -19][ t]], 
            Times[ -0.091317159035181589, 
              c[ -18][ t]], 
            Times[ -0.089038438663606695, 
              c[ -17][ t]], 
            Times[ -0.082699334313268744, 
              c[ -16][ t]], 
            Times[ -0.072413370861974122, 
              c[ -15][ t]], 
            Times[ -0.058468080236789913, 
              c[ -14][ t]], 
            Times[ -0.04131966847794722, 
              c[ -13][ t]], 
            Times[ -0.021580547817547879, 
              c[ -12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -11][ t]], 
            Times[ 0.022561481809254869, 
              c[ -10][ t]], 
            Times[ 0.045163358568919301, 
              c[ -9][ t]], 
            Times[ 0.066820663127759972, 
              c[ -8][ t]], 
            Times[ 0.086542809078944891, 
              c[ -7][ t]], 
            Times[ 0.10337416789158609, 
              c[ -6][ t]], 
            Times[ 0.11643488132933186, 
              c[ -5][ t]], 
            Times[ 0.12496032289024853, 
              c[ -4][ t]], 
            Times[ 0.12833762891430928, 
              c[ -3][ t]], 
            Times[ 0.12613778810677612, 
              c[ -2][ t]], 
            Times[ 0.11814190616181255, 
              c[ -1][ t]], 
            Times[ 0.10436044624225685, 
              c[ 0][ t]], 
            Times[ 0.085044480344421608, 
              c[ 1][ t]], 
            Times[ 0.060688263076985105, 
              c[ 2][ t]], 
            Times[ 0.032022748374425904, 
              c[ 3][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 4][ t]], 
            Times[ -0.034231213779558949, 
              c[ 5][ t]], 
            Times[ -0.06935801494512607, 
              c[ 6][ t]], 
            Times[ -0.10394325375429328, 
              c[ 7][ t]], 
            Times[ -0.13647135277833605, 
              c[ 8][ t]], 
            Times[ -0.16539866862653771, 
              c[ 9][ t]], 
            Times[ -0.18920668216016426, 
              c[ 10][ t]], 
            Times[ -0.20645618564475843, 
              c[ 11][ t]], 
            Times[ -0.21584055771952015, 
              c[ 12][ t]], 
            Times[ -0.21623620818304484, 
              c[ 13][ t]], 
            Times[ -0.206748335783172, 
              c[ 14][ t]], 
            Times[ -0.18675027222298593, 
              c[ 15][ t]], 
            Times[ -0.15591488063143974, 
              c[ 16][ t]], 
            Times[ -0.11423673049785436, 
              c[ 17][ t]], 
            Times[ -0.062044074975450239, 
              c[ 18][ t]], 
            Times[ 1.8033970416801674*^-16, 
              c[ 19][ t]], 
            Times[ 0.070907514257657775, 
              c[ 20][ t]], 
            Times[ 0.14938649372796384, 
              c[ 21][ t]], 
            Times[ 0.23387232094715985, 
              c[ 22][ t]], 
            Times[ 0.32256865202152157, 
              c[ 23][ t]], 
            Times[ 0.41349667156634429, 
              c[ 24][ t]], 
            Times[ 0.50455115242710469, 
              c[ 25][ t]], 
            Times[ 0.59356153372868059, 
              c[ 26][ t]], 
            Times[ 0.67835603854706361, 
              c[ 27][ t]], 
            Times[ 0.75682672864065692, 
              c[ 28][ t]], 
            Times[ 0.82699334313268813, 
              c[ 29][ t]], 
            Times[ 0.88706379305918392, 
              c[ 30][ t]], 
            Times[ 0.93548928378863916, 
              c[ 31][ t]], 
            Times[ 0.9710122092317629, 
              c[ 32][ t]], 
            Times[ 0.99270519960720693, 
              c[ 33][ t]], 
            Times[ 26.353917083687325, 
              c[ 34][ t]], 
            Times[ 0.99270519960720671, 
              c[ 35][ t]], 
            Times[ 0.9710122092317629, 
              c[ 36][ t]], 
            Times[ 0.93548928378863916, 
              c[ 37][ t]], 
            Times[ 0.88706379305918381, 
              c[ 38][ t]], 
            Times[ 0.82699334313268802, 
              c[ 39][ t]], 
            Times[ 0.75682672864065692, 
              c[ 40][ t]], 
            Times[ 0.67835603854706361, 
              c[ 41][ t]], 
            Times[ 0.59356153372868015, 
              c[ 42][ t]], 
            Times[ 0.50455115242710469, 
              c[ 43][ t]], 
            Times[ 0.41349667156634429, 
              c[ 44][ t]], 
            Times[ 0.32256865202152113, 
              c[ 45][ t]], 
            Times[ 0.23387232094715985, 
              c[ 46][ t]], 
            Times[ 0.14938649372796384, 
              c[ 47][ t]], 
            Times[ 0.070907514257657456, 
              c[ 48][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 49][ t]], 
            Times[ -0.062044074975450239, 
              c[ 50][ t]], 
            Times[ -0.11423673049785459, 
              c[ 51][ t]], 
            Times[ -0.15591488063143982, 
              c[ 52][ t]], 
            Times[ -0.18675027222298593, 
              c[ 53][ t]], 
            Times[ -0.20674833578317206, 
              c[ 54][ t]], 
            Times[ -0.21623620818304484, 
              c[ 55][ t]], 
            Times[ -0.21584055771952015, 
              c[ 56][ t]], 
            Times[ -0.20645618564475834, 
              c[ 57][ t]], 
            Times[ -0.18920668216016426, 
              c[ 58][ t]], 
            Times[ -0.16539866862653771, 
              c[ 59][ t]], 
            Times[ -0.13647135277833591, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "35", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[35]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04352596542803616`\ \(c[\(-60\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-59\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-58\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-57\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-56\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-55\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-54\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-53\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-52\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-51\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-50\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-49\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-48\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-47\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-46\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-45\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-44\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-43\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-42\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-41\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-40\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-39\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-38\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-37\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-36\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-35\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-34\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-33\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-32\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-31\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-30\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-29\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-28\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-27\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-26\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-25\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-24\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-23\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-22\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-21\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-20\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-19\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-18\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-17\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-16\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-15\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-14\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-13\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-12\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-11\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-10\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-9\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-8\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-7\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-6\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-5\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-4\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-3\)]\)[t] + 
            0.12833762891430928`\ \(c[\(-2\)]\)[t] + 
            0.12613778810677614`\ \(c[\(-1\)]\)[t] + 
            0.11814190616181255`\ \(c[0]\)[t] + 
            0.10436044624225685`\ \(c[1]\)[t] + 
            0.0850444803444217`\ \(c[2]\)[t] + 
            0.060688263076985105`\ \(c[3]\)[t] + 
            0.032022748374425904`\ \(c[4]\)[t] - 
            3.898171832519376`*^-17\ \(c[5]\)[t] - 
            0.03423121377955895`\ \(c[6]\)[t] - 
            0.06935801494512607`\ \(c[7]\)[t] - 
            0.10394325375429328`\ \(c[8]\)[t] - 
            0.13647135277833605`\ \(c[9]\)[t] - 
            0.1653986686265377`\ \(c[10]\)[t] - 
            0.18920668216016426`\ \(c[11]\)[t] - 
            0.20645618564475843`\ \(c[12]\)[t] - 
            0.21584055771952015`\ \(c[13]\)[t] - 
            0.21623620818304484`\ \(c[14]\)[t] - 
            0.206748335783172`\ \(c[15]\)[t] - 
            0.186750272222986`\ \(c[16]\)[t] - 
            0.15591488063143982`\ \(c[17]\)[t] - 
            0.11423673049785436`\ \(c[18]\)[t] - 
            0.06204407497545034`\ \(c[19]\)[t] + 
            3.898171832519376`*^-17\ \(c[20]\)[t] + 
            0.07090751425765777`\ \(c[21]\)[t] + 
            0.14938649372796345`\ \(c[22]\)[t] + 
            0.23387232094715985`\ \(c[23]\)[t] + 
            0.3225686520215216`\ \(c[24]\)[t] + 
            0.41349667156634395`\ \(c[25]\)[t] + 
            0.5045511524271047`\ \(c[26]\)[t] + 
            0.5935615337286806`\ \(c[27]\)[t] + 
            0.6783560385470632`\ \(c[28]\)[t] + 
            0.7568267286406569`\ \(c[29]\)[t] + 
            0.8269933431326881`\ \(c[30]\)[t] + 
            0.8870637930591838`\ \(c[31]\)[t] + 
            0.9354892837886392`\ \(c[32]\)[t] + 
            0.9710122092317629`\ \(c[33]\)[t] + 
            0.9927051996072067`\ \(c[34]\)[t] + 
            27.867256425187694`\ \(c[35]\)[t] + 
            0.9927051996072067`\ \(c[36]\)[t] + 
            0.9710122092317629`\ \(c[37]\)[t] + 
            0.9354892837886392`\ \(c[38]\)[t] + 
            0.8870637930591838`\ \(c[39]\)[t] + 
            0.8269933431326881`\ \(c[40]\)[t] + 
            0.7568267286406574`\ \(c[41]\)[t] + 
            0.6783560385470632`\ \(c[42]\)[t] + 
            0.5935615337286806`\ \(c[43]\)[t] + 
            0.504551152427105`\ \(c[44]\)[t] + 
            0.41349667156634395`\ \(c[45]\)[t] + 
            0.3225686520215216`\ \(c[46]\)[t] + 
            0.23387232094716018`\ \(c[47]\)[t] + 
            0.14938649372796345`\ \(c[48]\)[t] + 
            0.07090751425765777`\ \(c[49]\)[t] + 
            3.216976900108398`*^-16\ \(c[50]\)[t] - 
            0.062044074975450475`\ \(c[51]\)[t] - 
            0.11423673049785436`\ \(c[52]\)[t] - 
            0.15591488063143966`\ \(c[53]\)[t] - 
            0.18675027222298607`\ \(c[54]\)[t] - 
            0.206748335783172`\ \(c[55]\)[t] - 
            0.21623620818304481`\ \(c[56]\)[t] - 
            0.21584055771952013`\ \(c[57]\)[t] - 
            0.20645618564475843`\ \(c[58]\)[t] - 
            0.18920668216016434`\ \(c[59]\)[t] - 
            0.1653986686265376`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 35, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 35]][ t]], 
          Plus[ 
            Times[ 0.043525965428036162, 
              c[ -60][ t]], 
            Times[ 0.03774739544932687, 
              c[ -59][ t]], 
            Times[ 0.030177073670601236, 
              c[ -58][ t]], 
            Times[ 0.021108961070255627, 
              c[ -57][ t]], 
            Times[ 0.010908848347331785, 
              c[ -56][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -55][ t]], 
            Times[ -0.011153991006822649, 
              c[ -54][ t]], 
            Times[ -0.022068459300722043, 
              c[ -53][ t]], 
            Times[ -0.032258251165125519, 
              c[ -52][ t]], 
            Times[ -0.041258781072520248, 
              c[ -51][ t]], 
            Times[ -0.048646667243099399, 
              c[ -50][ t]], 
            Times[ -0.054059052045761224, 
              c[ -49][ t]], 
            Times[ -0.057210750238908967, 
              c[ -48][ t]], 
            Times[ -0.057908442314993203, 
              c[ -47][ t]], 
            Times[ -0.056061239158567186, 
              c[ -46][ t]], 
            Times[ -0.05168708394579296, 
              c[ -45][ t]], 
            Times[ -0.044914622433376288, 
              c[ -44][ t]], 
            Times[ -0.035980357068793781, 
              c[ -43][ t]], 
            Times[ -0.025221096343682053, 
              c[ -42][ t]], 
            Times[ -0.013061910521147276, 
              c[ -41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -40][ t]], 
            Times[ 0.013414935129827233, 
              c[ -39][ t]], 
            Times[ 0.026603074225527826, 
              c[ -38][ t]], 
            Times[ 0.03897872015785999, 
              c[ -37][ t]], 
            Times[ 0.049975424961080865, 
              c[ -36][ t]], 
            Times[ 0.059070953080906326, 
              c[ -35][ t]], 
            Times[ 0.065811019881796273, 
              c[ -34][ t]], 
            Times[ 0.069830768673962415, 
              c[ -33][ t]], 
            Times[ 0.070873018952678238, 
              c[ -32][ t]], 
            Times[ 0.068802429876423349, 
              c[ -31][ t]], 
            Times[ 0.063614872548668253, 
              c[ -30][ t]], 
            Times[ 0.055441487066198933, 
              c[ -29][ t]], 
            Times[ 0.044547108751839919, 
              c[ -28][ t]], 
            Times[ 0.031322974491347078, 
              c[ -27][ t]], 
            Times[ 0.016273855731265604, 
              c[ -26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -25][ t]], 
            Times[ -0.016825511857749401, 
              c[ -24][ t]], 
            Times[ -0.033483179628681567, 
              c[ -23][ t]], 
            Times[ -0.049236278094138941, 
              c[ -22][ t]], 
            Times[ -0.063361699504227528, 
              c[ -21][ t]], 
            Times[ -0.075181213012062598, 
              c[ -20][ t]], 
            Times[ -0.084091858737850814, 
              c[ -19][ t]], 
            Times[ -0.089594193770366884, 
              c[ -18][ t]], 
            Times[ -0.091317159035181589, 
              c[ -17][ t]], 
            Times[ -0.089038438663606695, 
              c[ -16][ t]], 
            Times[ -0.082699334313268744, 
              c[ -15][ t]], 
            Times[ -0.072413370861974122, 
              c[ -14][ t]], 
            Times[ -0.058468080236789913, 
              c[ -13][ t]], 
            Times[ -0.04131966847794722, 
              c[ -12][ t]], 
            Times[ -0.021580547817547879, 
              c[ -11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -10][ t]], 
            Times[ 0.022561481809254869, 
              c[ -9][ t]], 
            Times[ 0.045163358568919301, 
              c[ -8][ t]], 
            Times[ 0.066820663127759972, 
              c[ -7][ t]], 
            Times[ 0.086542809078944891, 
              c[ -6][ t]], 
            Times[ 0.10337416789158609, 
              c[ -5][ t]], 
            Times[ 0.11643488132933186, 
              c[ -4][ t]], 
            Times[ 0.12496032289024853, 
              c[ -3][ t]], 
            Times[ 0.12833762891430928, 
              c[ -2][ t]], 
            Times[ 0.12613778810677614, 
              c[ -1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 0][ t]], 
            Times[ 0.10436044624225685, 
              c[ 1][ t]], 
            Times[ 0.085044480344421705, 
              c[ 2][ t]], 
            Times[ 0.060688263076985105, 
              c[ 3][ t]], 
            Times[ 0.032022748374425904, 
              c[ 4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 5][ t]], 
            Times[ -0.034231213779558949, 
              c[ 6][ t]], 
            Times[ -0.06935801494512607, 
              c[ 7][ t]], 
            Times[ -0.10394325375429328, 
              c[ 8][ t]], 
            Times[ -0.13647135277833605, 
              c[ 9][ t]], 
            Times[ -0.16539866862653771, 
              c[ 10][ t]], 
            Times[ -0.18920668216016426, 
              c[ 11][ t]], 
            Times[ -0.20645618564475843, 
              c[ 12][ t]], 
            Times[ -0.21584055771952015, 
              c[ 13][ t]], 
            Times[ -0.21623620818304484, 
              c[ 14][ t]], 
            Times[ -0.206748335783172, 
              c[ 15][ t]], 
            Times[ -0.18675027222298601, 
              c[ 16][ t]], 
            Times[ -0.15591488063143982, 
              c[ 17][ t]], 
            Times[ -0.11423673049785436, 
              c[ 18][ t]], 
            Times[ -0.062044074975450343, 
              c[ 19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 20][ t]], 
            Times[ 0.070907514257657775, 
              c[ 21][ t]], 
            Times[ 0.14938649372796345, 
              c[ 22][ t]], 
            Times[ 0.23387232094715985, 
              c[ 23][ t]], 
            Times[ 0.32256865202152157, 
              c[ 24][ t]], 
            Times[ 0.41349667156634395, 
              c[ 25][ t]], 
            Times[ 0.50455115242710469, 
              c[ 26][ t]], 
            Times[ 0.59356153372868059, 
              c[ 27][ t]], 
            Times[ 0.67835603854706317, 
              c[ 28][ t]], 
            Times[ 0.75682672864065692, 
              c[ 29][ t]], 
            Times[ 0.82699334313268813, 
              c[ 30][ t]], 
            Times[ 0.88706379305918381, 
              c[ 31][ t]], 
            Times[ 0.93548928378863916, 
              c[ 32][ t]], 
            Times[ 0.9710122092317629, 
              c[ 33][ t]], 
            Times[ 0.99270519960720671, 
              c[ 34][ t]], 
            Times[ 27.867256425187694, 
              c[ 35][ t]], 
            Times[ 0.99270519960720671, 
              c[ 36][ t]], 
            Times[ 0.9710122092317629, 
              c[ 37][ t]], 
            Times[ 0.93548928378863916, 
              c[ 38][ t]], 
            Times[ 0.88706379305918381, 
              c[ 39][ t]], 
            Times[ 0.82699334313268813, 
              c[ 40][ t]], 
            Times[ 0.75682672864065736, 
              c[ 41][ t]], 
            Times[ 0.67835603854706317, 
              c[ 42][ t]], 
            Times[ 0.59356153372868059, 
              c[ 43][ t]], 
            Times[ 0.50455115242710502, 
              c[ 44][ t]], 
            Times[ 0.41349667156634395, 
              c[ 45][ t]], 
            Times[ 0.32256865202152157, 
              c[ 46][ t]], 
            Times[ 0.23387232094716018, 
              c[ 47][ t]], 
            Times[ 0.14938649372796345, 
              c[ 48][ t]], 
            Times[ 0.070907514257657775, 
              c[ 49][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 50][ t]], 
            Times[ -0.062044074975450475, 
              c[ 51][ t]], 
            Times[ -0.11423673049785436, 
              c[ 52][ t]], 
            Times[ -0.15591488063143966, 
              c[ 53][ t]], 
            Times[ -0.18675027222298607, 
              c[ 54][ t]], 
            Times[ -0.206748335783172, 
              c[ 55][ t]], 
            Times[ -0.21623620818304481, 
              c[ 56][ t]], 
            Times[ -0.21584055771952013, 
              c[ 57][ t]], 
            Times[ -0.20645618564475843, 
              c[ 58][ t]], 
            Times[ -0.18920668216016434, 
              c[ 59][ t]], 
            Times[ -0.1653986686265376, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "36", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[36]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04730167054004106`\ \(c[\(-60\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-59\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-58\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-57\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-56\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-55\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-53\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-52\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-51\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-50\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-49\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-48\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-47\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-46\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-45\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-44\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-43\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-42\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-41\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-40\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-39\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-38\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-37\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-36\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-35\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-34\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-33\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-32\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-31\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-30\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-29\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-28\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-27\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-26\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-25\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-23\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-22\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-21\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-20\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-19\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-18\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-17\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-16\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-15\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-14\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-13\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-12\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-11\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-10\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-9\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-8\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-7\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-6\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-5\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-4\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-3\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-2\)]\)[t] + 
            0.12833762891430925`\ \(c[\(-1\)]\)[t] + 
            0.12613778810677614`\ \(c[0]\)[t] + 
            0.11814190616181255`\ \(c[1]\)[t] + 
            0.10436044624225692`\ \(c[2]\)[t] + 
            0.0850444803444217`\ \(c[3]\)[t] + 
            0.060688263076985105`\ \(c[4]\)[t] + 
            0.03202274837442603`\ \(c[5]\)[t] - 
            3.898171832519376`*^-17\ \(c[6]\)[t] - 
            0.034231213779558796`\ \(c[7]\)[t] - 
            0.06935801494512592`\ \(c[8]\)[t] - 
            0.10394325375429328`\ \(c[9]\)[t] - 
            0.1364713527783359`\ \(c[10]\)[t] - 
            0.1653986686265376`\ \(c[11]\)[t] - 
            0.18920668216016426`\ \(c[12]\)[t] - 
            0.20645618564475834`\ \(c[13]\)[t] - 
            0.21584055771952013`\ \(c[14]\)[t] - 
            0.21623620818304484`\ \(c[15]\)[t] - 
            0.20674833578317206`\ \(c[16]\)[t] - 
            0.18675027222298607`\ \(c[17]\)[t] - 
            0.15591488063143982`\ \(c[18]\)[t] - 
            0.11423673049785445`\ \(c[19]\)[t] - 
            0.062044074975450475`\ \(c[20]\)[t] + 
            3.898171832519376`*^-17\ \(c[21]\)[t] + 
            0.07090751425765746`\ \(c[22]\)[t] + 
            0.14938649372796345`\ \(c[23]\)[t] + 
            0.23387232094715985`\ \(c[24]\)[t] + 
            0.32256865202152113`\ \(c[25]\)[t] + 
            0.41349667156634395`\ \(c[26]\)[t] + 
            0.5045511524271047`\ \(c[27]\)[t] + 
            0.5935615337286801`\ \(c[28]\)[t] + 
            0.6783560385470632`\ \(c[29]\)[t] + 
            0.7568267286406569`\ \(c[30]\)[t] + 
            0.826993343132688`\ \(c[31]\)[t] + 
            0.8870637930591838`\ \(c[32]\)[t] + 
            0.9354892837886392`\ \(c[33]\)[t] + 
            0.9710122092317629`\ \(c[34]\)[t] + 
            0.9927051996072067`\ \(c[35]\)[t] + 
            29.42446067513735`\ \(c[36]\)[t] + 
            0.9927051996072069`\ \(c[37]\)[t] + 
            0.9710122092317629`\ \(c[38]\)[t] + 
            0.9354892837886392`\ \(c[39]\)[t] + 
            0.8870637930591839`\ \(c[40]\)[t] + 
            0.8269933431326885`\ \(c[41]\)[t] + 
            0.7568267286406569`\ \(c[42]\)[t] + 
            0.6783560385470636`\ \(c[43]\)[t] + 
            0.5935615337286809`\ \(c[44]\)[t] + 
            0.5045511524271047`\ \(c[45]\)[t] + 
            0.4134966715663443`\ \(c[46]\)[t] + 
            0.3225686520215219`\ \(c[47]\)[t] + 
            0.23387232094715985`\ \(c[48]\)[t] + 
            0.14938649372796384`\ \(c[49]\)[t] + 
            0.0709075142576581`\ \(c[50]\)[t] + 
            3.898171832519376`*^-17\ \(c[51]\)[t] - 
            0.06204407497545024`\ \(c[52]\)[t] - 
            0.11423673049785416`\ \(c[53]\)[t] - 
            0.15591488063143982`\ \(c[54]\)[t] - 
            0.18675027222298593`\ \(c[55]\)[t] - 
            0.2067483357831719`\ \(c[56]\)[t] - 
            0.21623620818304484`\ \(c[57]\)[t] - 
            0.21584055771952015`\ \(c[58]\)[t] - 
            0.20645618564475848`\ \(c[59]\)[t] - 
            0.18920668216016426`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 36, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 36]][ t]], 
          Plus[ 
            Times[ 0.047301670540041058, 
              c[ -60][ t]], 
            Times[ 0.043525965428036162, 
              c[ -59][ t]], 
            Times[ 0.03774739544932687, 
              c[ -58][ t]], 
            Times[ 0.030177073670601236, 
              c[ -57][ t]], 
            Times[ 0.021108961070255627, 
              c[ -56][ t]], 
            Times[ 0.010908848347331966, 
              c[ -55][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ -0.011153991006822649, 
              c[ -53][ t]], 
            Times[ -0.022068459300722043, 
              c[ -52][ t]], 
            Times[ -0.032258251165125519, 
              c[ -51][ t]], 
            Times[ -0.041258781072520248, 
              c[ -50][ t]], 
            Times[ -0.048646667243099281, 
              c[ -49][ t]], 
            Times[ -0.054059052045761224, 
              c[ -48][ t]], 
            Times[ -0.057210750238908967, 
              c[ -47][ t]], 
            Times[ -0.057908442314993203, 
              c[ -46][ t]], 
            Times[ -0.056061239158567186, 
              c[ -45][ t]], 
            Times[ -0.05168708394579296, 
              c[ -44][ t]], 
            Times[ -0.044914622433376419, 
              c[ -43][ t]], 
            Times[ -0.035980357068793781, 
              c[ -42][ t]], 
            Times[ -0.025221096343682053, 
              c[ -41][ t]], 
            Times[ -0.013061910521147383, 
              c[ -40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -39][ t]], 
            Times[ 0.013414935129827233, 
              c[ -38][ t]], 
            Times[ 0.026603074225527826, 
              c[ -37][ t]], 
            Times[ 0.03897872015785999, 
              c[ -36][ t]], 
            Times[ 0.049975424961080865, 
              c[ -35][ t]], 
            Times[ 0.059070953080906326, 
              c[ -34][ t]], 
            Times[ 0.065811019881796273, 
              c[ -33][ t]], 
            Times[ 0.069830768673962415, 
              c[ -32][ t]], 
            Times[ 0.070873018952678238, 
              c[ -31][ t]], 
            Times[ 0.068802429876423349, 
              c[ -30][ t]], 
            Times[ 0.063614872548668253, 
              c[ -29][ t]], 
            Times[ 0.055441487066198933, 
              c[ -28][ t]], 
            Times[ 0.044547108751839919, 
              c[ -27][ t]], 
            Times[ 0.031322974491347078, 
              c[ -26][ t]], 
            Times[ 0.016273855731265604, 
              c[ -25][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ -0.016825511857749401, 
              c[ -23][ t]], 
            Times[ -0.033483179628681567, 
              c[ -22][ t]], 
            Times[ -0.049236278094138941, 
              c[ -21][ t]], 
            Times[ -0.063361699504227528, 
              c[ -20][ t]], 
            Times[ -0.075181213012062598, 
              c[ -19][ t]], 
            Times[ -0.084091858737850814, 
              c[ -18][ t]], 
            Times[ -0.089594193770366884, 
              c[ -17][ t]], 
            Times[ -0.091317159035181589, 
              c[ -16][ t]], 
            Times[ -0.089038438663606695, 
              c[ -15][ t]], 
            Times[ -0.082699334313268744, 
              c[ -14][ t]], 
            Times[ -0.072413370861974122, 
              c[ -13][ t]], 
            Times[ -0.058468080236789913, 
              c[ -12][ t]], 
            Times[ -0.04131966847794722, 
              c[ -11][ t]], 
            Times[ -0.021580547817547879, 
              c[ -10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -9][ t]], 
            Times[ 0.022561481809254675, 
              c[ -8][ t]], 
            Times[ 0.045163358568919301, 
              c[ -7][ t]], 
            Times[ 0.066820663127759972, 
              c[ -6][ t]], 
            Times[ 0.086542809078944752, 
              c[ -5][ t]], 
            Times[ 0.10337416789158609, 
              c[ -4][ t]], 
            Times[ 0.11643488132933186, 
              c[ -3][ t]], 
            Times[ 0.12496032289024853, 
              c[ -2][ t]], 
            Times[ 0.12833762891430925, 
              c[ -1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 0][ t]], 
            Times[ 0.11814190616181255, 
              c[ 1][ t]], 
            Times[ 0.10436044624225692, 
              c[ 2][ t]], 
            Times[ 0.085044480344421705, 
              c[ 3][ t]], 
            Times[ 0.060688263076985105, 
              c[ 4][ t]], 
            Times[ 0.032022748374426029, 
              c[ 5][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 6][ t]], 
            Times[ -0.034231213779558796, 
              c[ 7][ t]], 
            Times[ -0.069358014945125918, 
              c[ 8][ t]], 
            Times[ -0.10394325375429328, 
              c[ 9][ t]], 
            Times[ -0.13647135277833591, 
              c[ 10][ t]], 
            Times[ -0.1653986686265376, 
              c[ 11][ t]], 
            Times[ -0.18920668216016426, 
              c[ 12][ t]], 
            Times[ -0.20645618564475834, 
              c[ 13][ t]], 
            Times[ -0.21584055771952013, 
              c[ 14][ t]], 
            Times[ -0.21623620818304484, 
              c[ 15][ t]], 
            Times[ -0.20674833578317206, 
              c[ 16][ t]], 
            Times[ -0.18675027222298607, 
              c[ 17][ t]], 
            Times[ -0.15591488063143982, 
              c[ 18][ t]], 
            Times[ -0.11423673049785445, 
              c[ 19][ t]], 
            Times[ -0.062044074975450475, 
              c[ 20][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ 0.070907514257657456, 
              c[ 22][ t]], 
            Times[ 0.14938649372796345, 
              c[ 23][ t]], 
            Times[ 0.23387232094715985, 
              c[ 24][ t]], 
            Times[ 0.32256865202152113, 
              c[ 25][ t]], 
            Times[ 0.41349667156634395, 
              c[ 26][ t]], 
            Times[ 0.50455115242710469, 
              c[ 27][ t]], 
            Times[ 0.59356153372868015, 
              c[ 28][ t]], 
            Times[ 0.67835603854706317, 
              c[ 29][ t]], 
            Times[ 0.75682672864065692, 
              c[ 30][ t]], 
            Times[ 0.82699334313268802, 
              c[ 31][ t]], 
            Times[ 0.88706379305918381, 
              c[ 32][ t]], 
            Times[ 0.93548928378863916, 
              c[ 33][ t]], 
            Times[ 0.9710122092317629, 
              c[ 34][ t]], 
            Times[ 0.99270519960720671, 
              c[ 35][ t]], 
            Times[ 29.42446067513735, 
              c[ 36][ t]], 
            Times[ 0.99270519960720693, 
              c[ 37][ t]], 
            Times[ 0.9710122092317629, 
              c[ 38][ t]], 
            Times[ 0.93548928378863916, 
              c[ 39][ t]], 
            Times[ 0.88706379305918392, 
              c[ 40][ t]], 
            Times[ 0.82699334313268846, 
              c[ 41][ t]], 
            Times[ 0.75682672864065692, 
              c[ 42][ t]], 
            Times[ 0.67835603854706361, 
              c[ 43][ t]], 
            Times[ 0.59356153372868092, 
              c[ 44][ t]], 
            Times[ 0.50455115242710469, 
              c[ 45][ t]], 
            Times[ 0.41349667156634429, 
              c[ 46][ t]], 
            Times[ 0.32256865202152191, 
              c[ 47][ t]], 
            Times[ 0.23387232094715985, 
              c[ 48][ t]], 
            Times[ 0.14938649372796384, 
              c[ 49][ t]], 
            Times[ 0.070907514257658094, 
              c[ 50][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 51][ t]], 
            Times[ -0.062044074975450239, 
              c[ 52][ t]], 
            Times[ -0.11423673049785416, 
              c[ 53][ t]], 
            Times[ -0.15591488063143982, 
              c[ 54][ t]], 
            Times[ -0.18675027222298593, 
              c[ 55][ t]], 
            Times[ -0.20674833578317189, 
              c[ 56][ t]], 
            Times[ -0.21623620818304484, 
              c[ 57][ t]], 
            Times[ -0.21584055771952015, 
              c[ 58][ t]], 
            Times[ -0.20645618564475848, 
              c[ 59][ t]], 
            Times[ -0.18920668216016426, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "37", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[37]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04895352855494272`\ \(c[\(-60\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-59\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-58\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-57\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-56\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-55\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-54\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-53\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-52\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-51\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-50\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-49\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-48\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-47\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-46\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-45\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-44\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-43\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-42\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-41\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-40\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-39\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-38\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-37\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-36\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-35\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-34\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-33\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-32\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-31\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-30\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-29\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-28\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-27\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-26\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-25\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-24\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-22\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-21\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-20\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-19\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-18\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-17\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-16\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-15\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-14\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-13\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-12\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-11\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-10\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-9\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-8\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-7\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-6\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-5\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-4\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-3\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-2\)]\)[t] + 
            0.12496032289024853`\ \(c[\(-1\)]\)[t] + 
            0.12833762891430928`\ \(c[0]\)[t] + 
            0.12613778810677612`\ \(c[1]\)[t] + 
            0.11814190616181255`\ \(c[2]\)[t] + 
            0.10436044624225685`\ \(c[3]\)[t] + 
            0.08504448034442161`\ \(c[4]\)[t] + 
            0.060688263076985105`\ \(c[5]\)[t] + 
            0.032022748374425904`\ \(c[6]\)[t] - 
            3.898171832519376`*^-17\ \(c[7]\)[t] - 
            0.03423121377955895`\ \(c[8]\)[t] - 
            0.06935801494512607`\ \(c[9]\)[t] - 
            0.10394325375429328`\ \(c[10]\)[t] - 
            0.13647135277833605`\ \(c[11]\)[t] - 
            0.1653986686265377`\ \(c[12]\)[t] - 
            0.18920668216016426`\ \(c[13]\)[t] - 
            0.20645618564475843`\ \(c[14]\)[t] - 
            0.21584055771952015`\ \(c[15]\)[t] - 
            0.21623620818304484`\ \(c[16]\)[t] - 
            0.206748335783172`\ \(c[17]\)[t] - 
            0.18675027222298593`\ \(c[18]\)[t] - 
            0.15591488063143974`\ \(c[19]\)[t] - 
            0.11423673049785436`\ \(c[20]\)[t] - 
            0.06204407497545024`\ \(c[21]\)[t] + 
            3.898171832519376`*^-17\ \(c[22]\)[t] + 
            0.07090751425765777`\ \(c[23]\)[t] + 
            0.14938649372796384`\ \(c[24]\)[t] + 
            0.23387232094715985`\ \(c[25]\)[t] + 
            0.3225686520215216`\ \(c[26]\)[t] + 
            0.4134966715663443`\ \(c[27]\)[t] + 
            0.5045511524271047`\ \(c[28]\)[t] + 
            0.5935615337286806`\ \(c[29]\)[t] + 
            0.6783560385470636`\ \(c[30]\)[t] + 
            0.7568267286406569`\ \(c[31]\)[t] + 
            0.8269933431326881`\ \(c[32]\)[t] + 
            0.8870637930591839`\ \(c[33]\)[t] + 
            0.9354892837886392`\ \(c[34]\)[t] + 
            0.9710122092317629`\ \(c[35]\)[t] + 
            0.9927051996072069`\ \(c[36]\)[t] + 
            31.025529833536286`\ \(c[37]\)[t] + 
            0.9927051996072067`\ \(c[38]\)[t] + 
            0.9710122092317629`\ \(c[39]\)[t] + 
            0.9354892837886392`\ \(c[40]\)[t] + 
            0.8870637930591839`\ \(c[41]\)[t] + 
            0.826993343132688`\ \(c[42]\)[t] + 
            0.7568267286406569`\ \(c[43]\)[t] + 
            0.6783560385470636`\ \(c[44]\)[t] + 
            0.5935615337286801`\ \(c[45]\)[t] + 
            0.5045511524271047`\ \(c[46]\)[t] + 
            0.4134966715663443`\ \(c[47]\)[t] + 
            0.32256865202152113`\ \(c[48]\)[t] + 
            0.23387232094715985`\ \(c[49]\)[t] + 
            0.14938649372796384`\ \(c[50]\)[t] + 
            0.07090751425765746`\ \(c[51]\)[t] + 
            3.898171832519376`*^-17\ \(c[52]\)[t] - 
            0.06204407497545024`\ \(c[53]\)[t] - 
            0.11423673049785459`\ \(c[54]\)[t] - 
            0.15591488063143982`\ \(c[55]\)[t] - 
            0.18675027222298593`\ \(c[56]\)[t] - 
            0.20674833578317206`\ \(c[57]\)[t] - 
            0.21623620818304484`\ \(c[58]\)[t] - 
            0.21584055771952015`\ \(c[59]\)[t] - 
            0.20645618564475834`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 37, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 37]][ t]], 
          Plus[ 
            Times[ 0.04895352855494272, 
              c[ -60][ t]], 
            Times[ 0.047301670540041058, 
              c[ -59][ t]], 
            Times[ 0.043525965428036162, 
              c[ -58][ t]], 
            Times[ 0.03774739544932687, 
              c[ -57][ t]], 
            Times[ 0.030177073670601094, 
              c[ -56][ t]], 
            Times[ 0.021108961070255627, 
              c[ -55][ t]], 
            Times[ 0.010908848347331966, 
              c[ -54][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -53][ t]], 
            Times[ -0.011153991006822649, 
              c[ -52][ t]], 
            Times[ -0.022068459300722043, 
              c[ -51][ t]], 
            Times[ -0.032258251165125679, 
              c[ -50][ t]], 
            Times[ -0.041258781072520248, 
              c[ -49][ t]], 
            Times[ -0.048646667243099281, 
              c[ -48][ t]], 
            Times[ -0.054059052045761224, 
              c[ -47][ t]], 
            Times[ -0.057210750238908967, 
              c[ -46][ t]], 
            Times[ -0.057908442314993203, 
              c[ -45][ t]], 
            Times[ -0.05606123915856713, 
              c[ -44][ t]], 
            Times[ -0.05168708394579296, 
              c[ -43][ t]], 
            Times[ -0.044914622433376419, 
              c[ -42][ t]], 
            Times[ -0.035980357068793781, 
              c[ -41][ t]], 
            Times[ -0.025221096343682053, 
              c[ -40][ t]], 
            Times[ -0.013061910521147383, 
              c[ -39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -38][ t]], 
            Times[ 0.013414935129827233, 
              c[ -37][ t]], 
            Times[ 0.026603074225527826, 
              c[ -36][ t]], 
            Times[ 0.03897872015785999, 
              c[ -35][ t]], 
            Times[ 0.049975424961080865, 
              c[ -34][ t]], 
            Times[ 0.059070953080906326, 
              c[ -33][ t]], 
            Times[ 0.065811019881796273, 
              c[ -32][ t]], 
            Times[ 0.069830768673962415, 
              c[ -31][ t]], 
            Times[ 0.070873018952678238, 
              c[ -30][ t]], 
            Times[ 0.068802429876423349, 
              c[ -29][ t]], 
            Times[ 0.063614872548668253, 
              c[ -28][ t]], 
            Times[ 0.055441487066198933, 
              c[ -27][ t]], 
            Times[ 0.044547108751839919, 
              c[ -26][ t]], 
            Times[ 0.031322974491347078, 
              c[ -25][ t]], 
            Times[ 0.016273855731265604, 
              c[ -24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ -0.016825511857749401, 
              c[ -22][ t]], 
            Times[ -0.033483179628681567, 
              c[ -21][ t]], 
            Times[ -0.049236278094138941, 
              c[ -20][ t]], 
            Times[ -0.063361699504227528, 
              c[ -19][ t]], 
            Times[ -0.075181213012062598, 
              c[ -18][ t]], 
            Times[ -0.084091858737850814, 
              c[ -17][ t]], 
            Times[ -0.089594193770366884, 
              c[ -16][ t]], 
            Times[ -0.091317159035181589, 
              c[ -15][ t]], 
            Times[ -0.089038438663606695, 
              c[ -14][ t]], 
            Times[ -0.082699334313268744, 
              c[ -13][ t]], 
            Times[ -0.072413370861974122, 
              c[ -12][ t]], 
            Times[ -0.058468080236789913, 
              c[ -11][ t]], 
            Times[ -0.04131966847794722, 
              c[ -10][ t]], 
            Times[ -0.021580547817547879, 
              c[ -9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -8][ t]], 
            Times[ 0.022561481809254869, 
              c[ -7][ t]], 
            Times[ 0.045163358568919301, 
              c[ -6][ t]], 
            Times[ 0.066820663127759972, 
              c[ -5][ t]], 
            Times[ 0.086542809078944891, 
              c[ -4][ t]], 
            Times[ 0.10337416789158609, 
              c[ -3][ t]], 
            Times[ 0.11643488132933186, 
              c[ -2][ t]], 
            Times[ 0.12496032289024853, 
              c[ -1][ t]], 
            Times[ 0.12833762891430928, 
              c[ 0][ t]], 
            Times[ 0.12613778810677612, 
              c[ 1][ t]], 
            Times[ 0.11814190616181255, 
              c[ 2][ t]], 
            Times[ 0.10436044624225685, 
              c[ 3][ t]], 
            Times[ 0.085044480344421608, 
              c[ 4][ t]], 
            Times[ 0.060688263076985105, 
              c[ 5][ t]], 
            Times[ 0.032022748374425904, 
              c[ 6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 7][ t]], 
            Times[ -0.034231213779558949, 
              c[ 8][ t]], 
            Times[ -0.06935801494512607, 
              c[ 9][ t]], 
            Times[ -0.10394325375429328, 
              c[ 10][ t]], 
            Times[ -0.13647135277833605, 
              c[ 11][ t]], 
            Times[ -0.16539866862653771, 
              c[ 12][ t]], 
            Times[ -0.18920668216016426, 
              c[ 13][ t]], 
            Times[ -0.20645618564475843, 
              c[ 14][ t]], 
            Times[ -0.21584055771952015, 
              c[ 15][ t]], 
            Times[ -0.21623620818304484, 
              c[ 16][ t]], 
            Times[ -0.206748335783172, 
              c[ 17][ t]], 
            Times[ -0.18675027222298593, 
              c[ 18][ t]], 
            Times[ -0.15591488063143974, 
              c[ 19][ t]], 
            Times[ -0.11423673049785436, 
              c[ 20][ t]], 
            Times[ -0.062044074975450239, 
              c[ 21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ 0.070907514257657775, 
              c[ 23][ t]], 
            Times[ 0.14938649372796384, 
              c[ 24][ t]], 
            Times[ 0.23387232094715985, 
              c[ 25][ t]], 
            Times[ 0.32256865202152157, 
              c[ 26][ t]], 
            Times[ 0.41349667156634429, 
              c[ 27][ t]], 
            Times[ 0.50455115242710469, 
              c[ 28][ t]], 
            Times[ 0.59356153372868059, 
              c[ 29][ t]], 
            Times[ 0.67835603854706361, 
              c[ 30][ t]], 
            Times[ 0.75682672864065692, 
              c[ 31][ t]], 
            Times[ 0.82699334313268813, 
              c[ 32][ t]], 
            Times[ 0.88706379305918392, 
              c[ 33][ t]], 
            Times[ 0.93548928378863916, 
              c[ 34][ t]], 
            Times[ 0.9710122092317629, 
              c[ 35][ t]], 
            Times[ 0.99270519960720693, 
              c[ 36][ t]], 
            Times[ 31.025529833536286, 
              c[ 37][ t]], 
            Times[ 0.99270519960720671, 
              c[ 38][ t]], 
            Times[ 0.9710122092317629, 
              c[ 39][ t]], 
            Times[ 0.93548928378863916, 
              c[ 40][ t]], 
            Times[ 0.88706379305918392, 
              c[ 41][ t]], 
            Times[ 0.82699334313268802, 
              c[ 42][ t]], 
            Times[ 0.75682672864065692, 
              c[ 43][ t]], 
            Times[ 0.67835603854706361, 
              c[ 44][ t]], 
            Times[ 0.59356153372868015, 
              c[ 45][ t]], 
            Times[ 0.50455115242710469, 
              c[ 46][ t]], 
            Times[ 0.41349667156634429, 
              c[ 47][ t]], 
            Times[ 0.32256865202152113, 
              c[ 48][ t]], 
            Times[ 0.23387232094715985, 
              c[ 49][ t]], 
            Times[ 0.14938649372796384, 
              c[ 50][ t]], 
            Times[ 0.070907514257657456, 
              c[ 51][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 52][ t]], 
            Times[ -0.062044074975450239, 
              c[ 53][ t]], 
            Times[ -0.11423673049785459, 
              c[ 54][ t]], 
            Times[ -0.15591488063143982, 
              c[ 55][ t]], 
            Times[ -0.18675027222298593, 
              c[ 56][ t]], 
            Times[ -0.20674833578317206, 
              c[ 57][ t]], 
            Times[ -0.21623620818304484, 
              c[ 58][ t]], 
            Times[ -0.21584055771952015, 
              c[ 59][ t]], 
            Times[ -0.20645618564475834, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "38", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[38]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04845400275336168`\ \(c[\(-60\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-59\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-58\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-57\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-56\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-55\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-54\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-53\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-52\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-51\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-50\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-49\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-48\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-47\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-46\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-45\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-44\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-43\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-42\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-41\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-40\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-39\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-38\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-37\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-36\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-35\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-34\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-33\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-32\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-31\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-30\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-29\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-28\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-27\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-26\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-25\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-24\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-23\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-22\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-21\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-20\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-19\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-18\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-17\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-16\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-15\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-14\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-13\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-12\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-11\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-10\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-9\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-8\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-7\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-6\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-5\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-4\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-3\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-2\)]\)[t] + 
            0.11643488132933186`\ \(c[\(-1\)]\)[t] + 
            0.12496032289024853`\ \(c[0]\)[t] + 
            0.12833762891430928`\ \(c[1]\)[t] + 
            0.12613778810677614`\ \(c[2]\)[t] + 
            0.11814190616181255`\ \(c[3]\)[t] + 
            0.10436044624225685`\ \(c[4]\)[t] + 
            0.0850444803444217`\ \(c[5]\)[t] + 
            0.060688263076985105`\ \(c[6]\)[t] + 
            0.032022748374425904`\ \(c[7]\)[t] - 
            3.898171832519376`*^-17\ \(c[8]\)[t] - 
            0.03423121377955895`\ \(c[9]\)[t] - 
            0.06935801494512607`\ \(c[10]\)[t] - 
            0.10394325375429328`\ \(c[11]\)[t] - 
            0.13647135277833605`\ \(c[12]\)[t] - 
            0.1653986686265377`\ \(c[13]\)[t] - 
            0.18920668216016426`\ \(c[14]\)[t] - 
            0.20645618564475843`\ \(c[15]\)[t] - 
            0.21584055771952015`\ \(c[16]\)[t] - 
            0.21623620818304484`\ \(c[17]\)[t] - 
            0.206748335783172`\ \(c[18]\)[t] - 
            0.186750272222986`\ \(c[19]\)[t] - 
            0.15591488063143982`\ \(c[20]\)[t] - 
            0.11423673049785436`\ \(c[21]\)[t] - 
            0.062044074975450475`\ \(c[22]\)[t] + 
            3.898171832519376`*^-17\ \(c[23]\)[t] + 
            0.07090751425765777`\ \(c[24]\)[t] + 
            0.14938649372796345`\ \(c[25]\)[t] + 
            0.23387232094715985`\ \(c[26]\)[t] + 
            0.3225686520215216`\ \(c[27]\)[t] + 
            0.41349667156634395`\ \(c[28]\)[t] + 
            0.5045511524271047`\ \(c[29]\)[t] + 
            0.5935615337286806`\ \(c[30]\)[t] + 
            0.6783560385470632`\ \(c[31]\)[t] + 
            0.7568267286406569`\ \(c[32]\)[t] + 
            0.8269933431326881`\ \(c[33]\)[t] + 
            0.8870637930591838`\ \(c[34]\)[t] + 
            0.9354892837886392`\ \(c[35]\)[t] + 
            0.9710122092317629`\ \(c[36]\)[t] + 
            0.9927051996072067`\ \(c[37]\)[t] + 
            32.67046390038452`\ \(c[38]\)[t] + 
            0.9927051996072067`\ \(c[39]\)[t] + 
            0.9710122092317629`\ \(c[40]\)[t] + 
            0.9354892837886393`\ \(c[41]\)[t] + 
            0.8870637930591838`\ \(c[42]\)[t] + 
            0.8269933431326881`\ \(c[43]\)[t] + 
            0.7568267286406574`\ \(c[44]\)[t] + 
            0.6783560385470632`\ \(c[45]\)[t] + 
            0.5935615337286806`\ \(c[46]\)[t] + 
            0.504551152427105`\ \(c[47]\)[t] + 
            0.41349667156634395`\ \(c[48]\)[t] + 
            0.3225686520215216`\ \(c[49]\)[t] + 
            0.23387232094716018`\ \(c[50]\)[t] + 
            0.14938649372796345`\ \(c[51]\)[t] + 
            0.07090751425765777`\ \(c[52]\)[t] + 
            3.216976900108398`*^-16\ \(c[53]\)[t] - 
            0.062044074975450475`\ \(c[54]\)[t] - 
            0.11423673049785436`\ \(c[55]\)[t] - 
            0.15591488063143966`\ \(c[56]\)[t] - 
            0.18675027222298607`\ \(c[57]\)[t] - 
            0.206748335783172`\ \(c[58]\)[t] - 
            0.21623620818304481`\ \(c[59]\)[t] - 
            0.21584055771952013`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 38, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 38]][ t]], 
          Plus[ 
            Times[ 0.048454002753361682, 
              c[ -60][ t]], 
            Times[ 0.048953528554942699, 
              c[ -59][ t]], 
            Times[ 0.047301670540041058, 
              c[ -58][ t]], 
            Times[ 0.043525965428036162, 
              c[ -57][ t]], 
            Times[ 0.03774739544932687, 
              c[ -56][ t]], 
            Times[ 0.030177073670601236, 
              c[ -55][ t]], 
            Times[ 0.021108961070255627, 
              c[ -54][ t]], 
            Times[ 0.010908848347331785, 
              c[ -53][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -52][ t]], 
            Times[ -0.011153991006822649, 
              c[ -51][ t]], 
            Times[ -0.022068459300722043, 
              c[ -50][ t]], 
            Times[ -0.032258251165125519, 
              c[ -49][ t]], 
            Times[ -0.041258781072520248, 
              c[ -48][ t]], 
            Times[ -0.048646667243099399, 
              c[ -47][ t]], 
            Times[ -0.054059052045761224, 
              c[ -46][ t]], 
            Times[ -0.057210750238908967, 
              c[ -45][ t]], 
            Times[ -0.057908442314993203, 
              c[ -44][ t]], 
            Times[ -0.056061239158567186, 
              c[ -43][ t]], 
            Times[ -0.05168708394579296, 
              c[ -42][ t]], 
            Times[ -0.044914622433376288, 
              c[ -41][ t]], 
            Times[ -0.035980357068793781, 
              c[ -40][ t]], 
            Times[ -0.025221096343682053, 
              c[ -39][ t]], 
            Times[ -0.013061910521147383, 
              c[ -38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -37][ t]], 
            Times[ 0.013414935129827233, 
              c[ -36][ t]], 
            Times[ 0.026603074225527826, 
              c[ -35][ t]], 
            Times[ 0.03897872015785999, 
              c[ -34][ t]], 
            Times[ 0.049975424961080865, 
              c[ -33][ t]], 
            Times[ 0.059070953080906326, 
              c[ -32][ t]], 
            Times[ 0.065811019881796273, 
              c[ -31][ t]], 
            Times[ 0.069830768673962415, 
              c[ -30][ t]], 
            Times[ 0.070873018952678238, 
              c[ -29][ t]], 
            Times[ 0.068802429876423349, 
              c[ -28][ t]], 
            Times[ 0.063614872548668253, 
              c[ -27][ t]], 
            Times[ 0.055441487066198933, 
              c[ -26][ t]], 
            Times[ 0.044547108751839919, 
              c[ -25][ t]], 
            Times[ 0.031322974491347078, 
              c[ -24][ t]], 
            Times[ 0.016273855731265604, 
              c[ -23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -22][ t]], 
            Times[ -0.016825511857749401, 
              c[ -21][ t]], 
            Times[ -0.033483179628681567, 
              c[ -20][ t]], 
            Times[ -0.049236278094138941, 
              c[ -19][ t]], 
            Times[ -0.063361699504227528, 
              c[ -18][ t]], 
            Times[ -0.075181213012062598, 
              c[ -17][ t]], 
            Times[ -0.084091858737850814, 
              c[ -16][ t]], 
            Times[ -0.089594193770366884, 
              c[ -15][ t]], 
            Times[ -0.091317159035181589, 
              c[ -14][ t]], 
            Times[ -0.089038438663606695, 
              c[ -13][ t]], 
            Times[ -0.082699334313268744, 
              c[ -12][ t]], 
            Times[ -0.072413370861974122, 
              c[ -11][ t]], 
            Times[ -0.058468080236789913, 
              c[ -10][ t]], 
            Times[ -0.04131966847794722, 
              c[ -9][ t]], 
            Times[ -0.021580547817547879, 
              c[ -8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -7][ t]], 
            Times[ 0.022561481809254869, 
              c[ -6][ t]], 
            Times[ 0.045163358568919301, 
              c[ -5][ t]], 
            Times[ 0.066820663127759972, 
              c[ -4][ t]], 
            Times[ 0.086542809078944891, 
              c[ -3][ t]], 
            Times[ 0.10337416789158609, 
              c[ -2][ t]], 
            Times[ 0.11643488132933186, 
              c[ -1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 0][ t]], 
            Times[ 0.12833762891430928, 
              c[ 1][ t]], 
            Times[ 0.12613778810677614, 
              c[ 2][ t]], 
            Times[ 0.11814190616181255, 
              c[ 3][ t]], 
            Times[ 0.10436044624225685, 
              c[ 4][ t]], 
            Times[ 0.085044480344421705, 
              c[ 5][ t]], 
            Times[ 0.060688263076985105, 
              c[ 6][ t]], 
            Times[ 0.032022748374425904, 
              c[ 7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 8][ t]], 
            Times[ -0.034231213779558949, 
              c[ 9][ t]], 
            Times[ -0.06935801494512607, 
              c[ 10][ t]], 
            Times[ -0.10394325375429328, 
              c[ 11][ t]], 
            Times[ -0.13647135277833605, 
              c[ 12][ t]], 
            Times[ -0.16539866862653771, 
              c[ 13][ t]], 
            Times[ -0.18920668216016426, 
              c[ 14][ t]], 
            Times[ -0.20645618564475843, 
              c[ 15][ t]], 
            Times[ -0.21584055771952015, 
              c[ 16][ t]], 
            Times[ -0.21623620818304484, 
              c[ 17][ t]], 
            Times[ -0.206748335783172, 
              c[ 18][ t]], 
            Times[ -0.18675027222298601, 
              c[ 19][ t]], 
            Times[ -0.15591488063143982, 
              c[ 20][ t]], 
            Times[ -0.11423673049785436, 
              c[ 21][ t]], 
            Times[ -0.062044074975450475, 
              c[ 22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 23][ t]], 
            Times[ 0.070907514257657775, 
              c[ 24][ t]], 
            Times[ 0.14938649372796345, 
              c[ 25][ t]], 
            Times[ 0.23387232094715985, 
              c[ 26][ t]], 
            Times[ 0.32256865202152157, 
              c[ 27][ t]], 
            Times[ 0.41349667156634395, 
              c[ 28][ t]], 
            Times[ 0.50455115242710469, 
              c[ 29][ t]], 
            Times[ 0.59356153372868059, 
              c[ 30][ t]], 
            Times[ 0.67835603854706317, 
              c[ 31][ t]], 
            Times[ 0.75682672864065692, 
              c[ 32][ t]], 
            Times[ 0.82699334313268813, 
              c[ 33][ t]], 
            Times[ 0.88706379305918381, 
              c[ 34][ t]], 
            Times[ 0.93548928378863916, 
              c[ 35][ t]], 
            Times[ 0.9710122092317629, 
              c[ 36][ t]], 
            Times[ 0.99270519960720671, 
              c[ 37][ t]], 
            Times[ 32.670463900384519, 
              c[ 38][ t]], 
            Times[ 0.99270519960720671, 
              c[ 39][ t]], 
            Times[ 0.9710122092317629, 
              c[ 40][ t]], 
            Times[ 0.93548928378863927, 
              c[ 41][ t]], 
            Times[ 0.88706379305918381, 
              c[ 42][ t]], 
            Times[ 0.82699334313268813, 
              c[ 43][ t]], 
            Times[ 0.75682672864065736, 
              c[ 44][ t]], 
            Times[ 0.67835603854706317, 
              c[ 45][ t]], 
            Times[ 0.59356153372868059, 
              c[ 46][ t]], 
            Times[ 0.50455115242710502, 
              c[ 47][ t]], 
            Times[ 0.41349667156634395, 
              c[ 48][ t]], 
            Times[ 0.32256865202152157, 
              c[ 49][ t]], 
            Times[ 0.23387232094716018, 
              c[ 50][ t]], 
            Times[ 0.14938649372796345, 
              c[ 51][ t]], 
            Times[ 0.070907514257657775, 
              c[ 52][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 53][ t]], 
            Times[ -0.062044074975450475, 
              c[ 54][ t]], 
            Times[ -0.11423673049785436, 
              c[ 55][ t]], 
            Times[ -0.15591488063143966, 
              c[ 56][ t]], 
            Times[ -0.18675027222298607, 
              c[ 57][ t]], 
            Times[ -0.206748335783172, 
              c[ 58][ t]], 
            Times[ -0.21623620818304481, 
              c[ 59][ t]], 
            Times[ -0.21584055771952013, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "39", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[39]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.045868286584282256`\ \(c[\(-60\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-59\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-58\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-57\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-56\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-55\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-54\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-53\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-52\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-50\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-49\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-48\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-47\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-46\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-45\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-44\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-43\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-42\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-41\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-40\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-39\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-38\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-37\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-36\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-35\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-34\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-33\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-32\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-31\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-30\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-29\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-28\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-27\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-26\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-25\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-24\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-23\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-22\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-20\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-19\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-18\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-17\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-16\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-15\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-14\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-13\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-12\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-11\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-10\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-9\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-8\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-7\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-6\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-5\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-4\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-3\)]\)[t] + 
            0.08654280907894475`\ \(c[\(-2\)]\)[t] + 
            0.10337416789158609`\ \(c[\(-1\)]\)[t] + 
            0.11643488132933186`\ \(c[0]\)[t] + 
            0.12496032289024853`\ \(c[1]\)[t] + 
            0.12833762891430925`\ \(c[2]\)[t] + 
            0.12613778810677614`\ \(c[3]\)[t] + 
            0.11814190616181255`\ \(c[4]\)[t] + 
            0.10436044624225692`\ \(c[5]\)[t] + 
            0.0850444803444217`\ \(c[6]\)[t] + 
            0.06068826307698522`\ \(c[7]\)[t] + 
            0.03202274837442603`\ \(c[8]\)[t] - 
            3.898171832519376`*^-17\ \(c[9]\)[t] - 
            0.034231213779558796`\ \(c[10]\)[t] - 
            0.06935801494512592`\ \(c[11]\)[t] - 
            0.10394325375429328`\ \(c[12]\)[t] - 
            0.1364713527783359`\ \(c[13]\)[t] - 
            0.1653986686265376`\ \(c[14]\)[t] - 
            0.18920668216016426`\ \(c[15]\)[t] - 
            0.20645618564475834`\ \(c[16]\)[t] - 
            0.21584055771952013`\ \(c[17]\)[t] - 
            0.21623620818304484`\ \(c[18]\)[t] - 
            0.20674833578317206`\ \(c[19]\)[t] - 
            0.18675027222298607`\ \(c[20]\)[t] - 
            0.15591488063143982`\ \(c[21]\)[t] - 
            0.11423673049785459`\ \(c[22]\)[t] - 
            0.062044074975450475`\ \(c[23]\)[t] + 
            3.898171832519376`*^-17\ \(c[24]\)[t] + 
            0.07090751425765746`\ \(c[25]\)[t] + 
            0.14938649372796345`\ \(c[26]\)[t] + 
            0.23387232094715985`\ \(c[27]\)[t] + 
            0.32256865202152113`\ \(c[28]\)[t] + 
            0.41349667156634395`\ \(c[29]\)[t] + 
            0.5045511524271047`\ \(c[30]\)[t] + 
            0.5935615337286801`\ \(c[31]\)[t] + 
            0.6783560385470632`\ \(c[32]\)[t] + 
            0.7568267286406569`\ \(c[33]\)[t] + 
            0.826993343132688`\ \(c[34]\)[t] + 
            0.8870637930591838`\ \(c[35]\)[t] + 
            0.9354892837886392`\ \(c[36]\)[t] + 
            0.9710122092317629`\ \(c[37]\)[t] + 
            0.9927051996072067`\ \(c[38]\)[t] + 
            34.35926287568203`\ \(c[39]\)[t] + 
            0.9927051996072069`\ \(c[40]\)[t] + 
            0.9710122092317629`\ \(c[41]\)[t] + 
            0.9354892837886392`\ \(c[42]\)[t] + 
            0.8870637930591839`\ \(c[43]\)[t] + 
            0.8269933431326885`\ \(c[44]\)[t] + 
            0.7568267286406569`\ \(c[45]\)[t] + 
            0.6783560385470636`\ \(c[46]\)[t] + 
            0.5935615337286809`\ \(c[47]\)[t] + 
            0.5045511524271047`\ \(c[48]\)[t] + 
            0.4134966715663443`\ \(c[49]\)[t] + 
            0.3225686520215219`\ \(c[50]\)[t] + 
            0.23387232094715985`\ \(c[51]\)[t] + 
            0.14938649372796384`\ \(c[52]\)[t] + 
            0.0709075142576581`\ \(c[53]\)[t] + 
            3.898171832519376`*^-17\ \(c[54]\)[t] - 
            0.06204407497545024`\ \(c[55]\)[t] - 
            0.11423673049785416`\ \(c[56]\)[t] - 
            0.15591488063143982`\ \(c[57]\)[t] - 
            0.18675027222298593`\ \(c[58]\)[t] - 
            0.2067483357831719`\ \(c[59]\)[t] - 
            0.21623620818304484`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 39, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 39]][ t]], 
          Plus[ 
            Times[ 0.045868286584282256, 
              c[ -60][ t]], 
            Times[ 0.048454002753361682, 
              c[ -59][ t]], 
            Times[ 0.04895352855494272, 
              c[ -58][ t]], 
            Times[ 0.047301670540041058, 
              c[ -57][ t]], 
            Times[ 0.043525965428036162, 
              c[ -56][ t]], 
            Times[ 0.03774739544932687, 
              c[ -55][ t]], 
            Times[ 0.030177073670601236, 
              c[ -54][ t]], 
            Times[ 0.021108961070255627, 
              c[ -53][ t]], 
            Times[ 0.010908848347331966, 
              c[ -52][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ -0.011153991006822649, 
              c[ -50][ t]], 
            Times[ -0.022068459300722043, 
              c[ -49][ t]], 
            Times[ -0.032258251165125519, 
              c[ -48][ t]], 
            Times[ -0.041258781072520248, 
              c[ -47][ t]], 
            Times[ -0.048646667243099281, 
              c[ -46][ t]], 
            Times[ -0.054059052045761224, 
              c[ -45][ t]], 
            Times[ -0.057210750238908967, 
              c[ -44][ t]], 
            Times[ -0.057908442314993203, 
              c[ -43][ t]], 
            Times[ -0.056061239158567186, 
              c[ -42][ t]], 
            Times[ -0.05168708394579296, 
              c[ -41][ t]], 
            Times[ -0.044914622433376419, 
              c[ -40][ t]], 
            Times[ -0.035980357068793781, 
              c[ -39][ t]], 
            Times[ -0.025221096343682053, 
              c[ -38][ t]], 
            Times[ -0.013061910521147383, 
              c[ -37][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -36][ t]], 
            Times[ 0.013414935129827233, 
              c[ -35][ t]], 
            Times[ 0.026603074225527826, 
              c[ -34][ t]], 
            Times[ 0.03897872015785999, 
              c[ -33][ t]], 
            Times[ 0.049975424961080865, 
              c[ -32][ t]], 
            Times[ 0.059070953080906326, 
              c[ -31][ t]], 
            Times[ 0.065811019881796273, 
              c[ -30][ t]], 
            Times[ 0.069830768673962415, 
              c[ -29][ t]], 
            Times[ 0.070873018952678238, 
              c[ -28][ t]], 
            Times[ 0.068802429876423349, 
              c[ -27][ t]], 
            Times[ 0.063614872548668253, 
              c[ -26][ t]], 
            Times[ 0.055441487066198933, 
              c[ -25][ t]], 
            Times[ 0.044547108751839919, 
              c[ -24][ t]], 
            Times[ 0.031322974491347078, 
              c[ -23][ t]], 
            Times[ 0.016273855731265604, 
              c[ -22][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ -0.016825511857749401, 
              c[ -20][ t]], 
            Times[ -0.033483179628681567, 
              c[ -19][ t]], 
            Times[ -0.049236278094138941, 
              c[ -18][ t]], 
            Times[ -0.063361699504227528, 
              c[ -17][ t]], 
            Times[ -0.075181213012062598, 
              c[ -16][ t]], 
            Times[ -0.084091858737850814, 
              c[ -15][ t]], 
            Times[ -0.089594193770366884, 
              c[ -14][ t]], 
            Times[ -0.091317159035181589, 
              c[ -13][ t]], 
            Times[ -0.089038438663606695, 
              c[ -12][ t]], 
            Times[ -0.082699334313268744, 
              c[ -11][ t]], 
            Times[ -0.072413370861974122, 
              c[ -10][ t]], 
            Times[ -0.058468080236789913, 
              c[ -9][ t]], 
            Times[ -0.041319668477947373, 
              c[ -8][ t]], 
            Times[ -0.021580547817547879, 
              c[ -7][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -6][ t]], 
            Times[ 0.022561481809254675, 
              c[ -5][ t]], 
            Times[ 0.045163358568919301, 
              c[ -4][ t]], 
            Times[ 0.066820663127759972, 
              c[ -3][ t]], 
            Times[ 0.086542809078944752, 
              c[ -2][ t]], 
            Times[ 0.10337416789158609, 
              c[ -1][ t]], 
            Times[ 0.11643488132933186, 
              c[ 0][ t]], 
            Times[ 0.12496032289024853, 
              c[ 1][ t]], 
            Times[ 0.12833762891430925, 
              c[ 2][ t]], 
            Times[ 0.12613778810677614, 
              c[ 3][ t]], 
            Times[ 0.11814190616181255, 
              c[ 4][ t]], 
            Times[ 0.10436044624225692, 
              c[ 5][ t]], 
            Times[ 0.085044480344421705, 
              c[ 6][ t]], 
            Times[ 0.060688263076985223, 
              c[ 7][ t]], 
            Times[ 0.032022748374426029, 
              c[ 8][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 9][ t]], 
            Times[ -0.034231213779558796, 
              c[ 10][ t]], 
            Times[ -0.069358014945125918, 
              c[ 11][ t]], 
            Times[ -0.10394325375429328, 
              c[ 12][ t]], 
            Times[ -0.13647135277833591, 
              c[ 13][ t]], 
            Times[ -0.1653986686265376, 
              c[ 14][ t]], 
            Times[ -0.18920668216016426, 
              c[ 15][ t]], 
            Times[ -0.20645618564475834, 
              c[ 16][ t]], 
            Times[ -0.21584055771952013, 
              c[ 17][ t]], 
            Times[ -0.21623620818304484, 
              c[ 18][ t]], 
            Times[ -0.20674833578317206, 
              c[ 19][ t]], 
            Times[ -0.18675027222298607, 
              c[ 20][ t]], 
            Times[ -0.15591488063143982, 
              c[ 21][ t]], 
            Times[ -0.11423673049785459, 
              c[ 22][ t]], 
            Times[ -0.062044074975450475, 
              c[ 23][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ 0.070907514257657456, 
              c[ 25][ t]], 
            Times[ 0.14938649372796345, 
              c[ 26][ t]], 
            Times[ 0.23387232094715985, 
              c[ 27][ t]], 
            Times[ 0.32256865202152113, 
              c[ 28][ t]], 
            Times[ 0.41349667156634395, 
              c[ 29][ t]], 
            Times[ 0.50455115242710469, 
              c[ 30][ t]], 
            Times[ 0.59356153372868015, 
              c[ 31][ t]], 
            Times[ 0.67835603854706317, 
              c[ 32][ t]], 
            Times[ 0.75682672864065692, 
              c[ 33][ t]], 
            Times[ 0.82699334313268802, 
              c[ 34][ t]], 
            Times[ 0.88706379305918381, 
              c[ 35][ t]], 
            Times[ 0.93548928378863916, 
              c[ 36][ t]], 
            Times[ 0.9710122092317629, 
              c[ 37][ t]], 
            Times[ 0.99270519960720671, 
              c[ 38][ t]], 
            Times[ 34.359262875682028, 
              c[ 39][ t]], 
            Times[ 0.99270519960720693, 
              c[ 40][ t]], 
            Times[ 0.9710122092317629, 
              c[ 41][ t]], 
            Times[ 0.93548928378863916, 
              c[ 42][ t]], 
            Times[ 0.88706379305918392, 
              c[ 43][ t]], 
            Times[ 0.82699334313268846, 
              c[ 44][ t]], 
            Times[ 0.75682672864065692, 
              c[ 45][ t]], 
            Times[ 0.67835603854706361, 
              c[ 46][ t]], 
            Times[ 0.59356153372868092, 
              c[ 47][ t]], 
            Times[ 0.50455115242710469, 
              c[ 48][ t]], 
            Times[ 0.41349667156634429, 
              c[ 49][ t]], 
            Times[ 0.32256865202152191, 
              c[ 50][ t]], 
            Times[ 0.23387232094715985, 
              c[ 51][ t]], 
            Times[ 0.14938649372796384, 
              c[ 52][ t]], 
            Times[ 0.070907514257658094, 
              c[ 53][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 54][ t]], 
            Times[ -0.062044074975450239, 
              c[ 55][ t]], 
            Times[ -0.11423673049785416, 
              c[ 56][ t]], 
            Times[ -0.15591488063143982, 
              c[ 57][ t]], 
            Times[ -0.18675027222298593, 
              c[ 58][ t]], 
            Times[ -0.20674833578317189, 
              c[ 59][ t]], 
            Times[ -0.21623620818304484, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "40", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[40]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.04134966715663448`\ \(c[\(-60\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-59\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-58\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-57\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-56\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-55\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-54\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-53\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-52\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-51\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-50\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-49\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-48\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-47\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-46\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-45\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-44\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-43\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-42\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-41\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-40\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-39\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-38\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-37\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-36\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-35\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-34\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-33\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-32\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-31\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-30\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-29\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-28\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-27\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-26\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-25\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-24\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-23\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-22\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-21\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-19\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-18\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-17\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-16\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-15\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-14\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-13\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-12\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-11\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-10\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-9\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-8\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-7\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-6\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-5\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-4\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-3\)]\)[t] + 
            0.06682066312775997`\ \(c[\(-2\)]\)[t] + 
            0.08654280907894489`\ \(c[\(-1\)]\)[t] + 
            0.10337416789158609`\ \(c[0]\)[t] + 
            0.11643488132933186`\ \(c[1]\)[t] + 
            0.12496032289024853`\ \(c[2]\)[t] + 
            0.12833762891430928`\ \(c[3]\)[t] + 
            0.12613778810677612`\ \(c[4]\)[t] + 
            0.11814190616181255`\ \(c[5]\)[t] + 
            0.10436044624225685`\ \(c[6]\)[t] + 
            0.0850444803444217`\ \(c[7]\)[t] + 
            0.060688263076985105`\ \(c[8]\)[t] + 
            0.032022748374425904`\ \(c[9]\)[t] - 
            3.898171832519376`*^-17\ \(c[10]\)[t] - 
            0.03423121377955895`\ \(c[11]\)[t] - 
            0.06935801494512607`\ \(c[12]\)[t] - 
            0.10394325375429328`\ \(c[13]\)[t] - 
            0.13647135277833605`\ \(c[14]\)[t] - 
            0.1653986686265377`\ \(c[15]\)[t] - 
            0.18920668216016426`\ \(c[16]\)[t] - 
            0.20645618564475843`\ \(c[17]\)[t] - 
            0.21584055771952015`\ \(c[18]\)[t] - 
            0.21623620818304484`\ \(c[19]\)[t] - 
            0.206748335783172`\ \(c[20]\)[t] - 
            0.18675027222298593`\ \(c[21]\)[t] - 
            0.15591488063143982`\ \(c[22]\)[t] - 
            0.11423673049785436`\ \(c[23]\)[t] - 
            0.06204407497545024`\ \(c[24]\)[t] + 
            3.898171832519376`*^-17\ \(c[25]\)[t] + 
            0.07090751425765777`\ \(c[26]\)[t] + 
            0.14938649372796384`\ \(c[27]\)[t] + 
            0.23387232094715985`\ \(c[28]\)[t] + 
            0.3225686520215216`\ \(c[29]\)[t] + 
            0.4134966715663443`\ \(c[30]\)[t] + 
            0.5045511524271047`\ \(c[31]\)[t] + 
            0.5935615337286806`\ \(c[32]\)[t] + 
            0.6783560385470636`\ \(c[33]\)[t] + 
            0.7568267286406569`\ \(c[34]\)[t] + 
            0.8269933431326881`\ \(c[35]\)[t] + 
            0.8870637930591839`\ \(c[36]\)[t] + 
            0.9354892837886392`\ \(c[37]\)[t] + 
            0.9710122092317629`\ \(c[38]\)[t] + 
            0.9927051996072069`\ \(c[39]\)[t] + 
            36.09192675942882`\ \(c[40]\)[t] + 
            0.9927051996072069`\ \(c[41]\)[t] + 
            0.9710122092317629`\ \(c[42]\)[t] + 
            0.9354892837886392`\ \(c[43]\)[t] + 
            0.8870637930591839`\ \(c[44]\)[t] + 
            0.826993343132688`\ \(c[45]\)[t] + 
            0.7568267286406569`\ \(c[46]\)[t] + 
            0.6783560385470636`\ \(c[47]\)[t] + 
            0.5935615337286801`\ \(c[48]\)[t] + 
            0.5045511524271047`\ \(c[49]\)[t] + 
            0.4134966715663443`\ \(c[50]\)[t] + 
            0.32256865202152113`\ \(c[51]\)[t] + 
            0.23387232094715985`\ \(c[52]\)[t] + 
            0.14938649372796384`\ \(c[53]\)[t] + 
            0.07090751425765746`\ \(c[54]\)[t] + 
            3.898171832519376`*^-17\ \(c[55]\)[t] - 
            0.06204407497545024`\ \(c[56]\)[t] - 
            0.11423673049785459`\ \(c[57]\)[t] - 
            0.15591488063143982`\ \(c[58]\)[t] - 
            0.18675027222298593`\ \(c[59]\)[t] - 
            0.20674833578317206`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 40, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 40]][ t]], 
          Plus[ 
            Times[ 0.041349667156634483, 
              c[ -60][ t]], 
            Times[ 0.045868286584282311, 
              c[ -59][ t]], 
            Times[ 0.048454002753361682, 
              c[ -58][ t]], 
            Times[ 0.04895352855494272, 
              c[ -57][ t]], 
            Times[ 0.047301670540041058, 
              c[ -56][ t]], 
            Times[ 0.043525965428036162, 
              c[ -55][ t]], 
            Times[ 0.03774739544932687, 
              c[ -54][ t]], 
            Times[ 0.030177073670601094, 
              c[ -53][ t]], 
            Times[ 0.021108961070255627, 
              c[ -52][ t]], 
            Times[ 0.010908848347331966, 
              c[ -51][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -50][ t]], 
            Times[ -0.011153991006822649, 
              c[ -49][ t]], 
            Times[ -0.022068459300722043, 
              c[ -48][ t]], 
            Times[ -0.032258251165125679, 
              c[ -47][ t]], 
            Times[ -0.041258781072520248, 
              c[ -46][ t]], 
            Times[ -0.048646667243099281, 
              c[ -45][ t]], 
            Times[ -0.054059052045761224, 
              c[ -44][ t]], 
            Times[ -0.057210750238908967, 
              c[ -43][ t]], 
            Times[ -0.057908442314993203, 
              c[ -42][ t]], 
            Times[ -0.05606123915856713, 
              c[ -41][ t]], 
            Times[ -0.05168708394579296, 
              c[ -40][ t]], 
            Times[ -0.044914622433376419, 
              c[ -39][ t]], 
            Times[ -0.035980357068793781, 
              c[ -38][ t]], 
            Times[ -0.025221096343682053, 
              c[ -37][ t]], 
            Times[ -0.013061910521147383, 
              c[ -36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -35][ t]], 
            Times[ 0.013414935129827233, 
              c[ -34][ t]], 
            Times[ 0.026603074225527826, 
              c[ -33][ t]], 
            Times[ 0.03897872015785999, 
              c[ -32][ t]], 
            Times[ 0.049975424961080865, 
              c[ -31][ t]], 
            Times[ 0.059070953080906326, 
              c[ -30][ t]], 
            Times[ 0.065811019881796273, 
              c[ -29][ t]], 
            Times[ 0.069830768673962415, 
              c[ -28][ t]], 
            Times[ 0.070873018952678238, 
              c[ -27][ t]], 
            Times[ 0.068802429876423349, 
              c[ -26][ t]], 
            Times[ 0.063614872548668253, 
              c[ -25][ t]], 
            Times[ 0.055441487066198933, 
              c[ -24][ t]], 
            Times[ 0.044547108751839919, 
              c[ -23][ t]], 
            Times[ 0.031322974491347078, 
              c[ -22][ t]], 
            Times[ 0.016273855731265604, 
              c[ -21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ -0.016825511857749401, 
              c[ -19][ t]], 
            Times[ -0.033483179628681567, 
              c[ -18][ t]], 
            Times[ -0.049236278094138941, 
              c[ -17][ t]], 
            Times[ -0.063361699504227528, 
              c[ -16][ t]], 
            Times[ -0.075181213012062598, 
              c[ -15][ t]], 
            Times[ -0.084091858737850814, 
              c[ -14][ t]], 
            Times[ -0.089594193770366884, 
              c[ -13][ t]], 
            Times[ -0.091317159035181589, 
              c[ -12][ t]], 
            Times[ -0.089038438663606695, 
              c[ -11][ t]], 
            Times[ -0.082699334313268744, 
              c[ -10][ t]], 
            Times[ -0.072413370861974122, 
              c[ -9][ t]], 
            Times[ -0.058468080236789913, 
              c[ -8][ t]], 
            Times[ -0.04131966847794722, 
              c[ -7][ t]], 
            Times[ -0.021580547817547879, 
              c[ -6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -5][ t]], 
            Times[ 0.022561481809254869, 
              c[ -4][ t]], 
            Times[ 0.045163358568919301, 
              c[ -3][ t]], 
            Times[ 0.066820663127759972, 
              c[ -2][ t]], 
            Times[ 0.086542809078944891, 
              c[ -1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 0][ t]], 
            Times[ 0.11643488132933186, 
              c[ 1][ t]], 
            Times[ 0.12496032289024853, 
              c[ 2][ t]], 
            Times[ 0.12833762891430928, 
              c[ 3][ t]], 
            Times[ 0.12613778810677612, 
              c[ 4][ t]], 
            Times[ 0.11814190616181255, 
              c[ 5][ t]], 
            Times[ 0.10436044624225685, 
              c[ 6][ t]], 
            Times[ 0.085044480344421705, 
              c[ 7][ t]], 
            Times[ 0.060688263076985105, 
              c[ 8][ t]], 
            Times[ 0.032022748374425904, 
              c[ 9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 10][ t]], 
            Times[ -0.034231213779558949, 
              c[ 11][ t]], 
            Times[ -0.06935801494512607, 
              c[ 12][ t]], 
            Times[ -0.10394325375429328, 
              c[ 13][ t]], 
            Times[ -0.13647135277833605, 
              c[ 14][ t]], 
            Times[ -0.16539866862653771, 
              c[ 15][ t]], 
            Times[ -0.18920668216016426, 
              c[ 16][ t]], 
            Times[ -0.20645618564475843, 
              c[ 17][ t]], 
            Times[ -0.21584055771952015, 
              c[ 18][ t]], 
            Times[ -0.21623620818304484, 
              c[ 19][ t]], 
            Times[ -0.206748335783172, 
              c[ 20][ t]], 
            Times[ -0.18675027222298593, 
              c[ 21][ t]], 
            Times[ -0.15591488063143982, 
              c[ 22][ t]], 
            Times[ -0.11423673049785436, 
              c[ 23][ t]], 
            Times[ -0.062044074975450239, 
              c[ 24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ 0.070907514257657775, 
              c[ 26][ t]], 
            Times[ 0.14938649372796384, 
              c[ 27][ t]], 
            Times[ 0.23387232094715985, 
              c[ 28][ t]], 
            Times[ 0.32256865202152157, 
              c[ 29][ t]], 
            Times[ 0.41349667156634429, 
              c[ 30][ t]], 
            Times[ 0.50455115242710469, 
              c[ 31][ t]], 
            Times[ 0.59356153372868059, 
              c[ 32][ t]], 
            Times[ 0.67835603854706361, 
              c[ 33][ t]], 
            Times[ 0.75682672864065692, 
              c[ 34][ t]], 
            Times[ 0.82699334313268813, 
              c[ 35][ t]], 
            Times[ 0.88706379305918392, 
              c[ 36][ t]], 
            Times[ 0.93548928378863916, 
              c[ 37][ t]], 
            Times[ 0.9710122092317629, 
              c[ 38][ t]], 
            Times[ 0.99270519960720693, 
              c[ 39][ t]], 
            Times[ 36.091926759428823, 
              c[ 40][ t]], 
            Times[ 0.99270519960720693, 
              c[ 41][ t]], 
            Times[ 0.9710122092317629, 
              c[ 42][ t]], 
            Times[ 0.93548928378863916, 
              c[ 43][ t]], 
            Times[ 0.88706379305918392, 
              c[ 44][ t]], 
            Times[ 0.82699334313268802, 
              c[ 45][ t]], 
            Times[ 0.75682672864065692, 
              c[ 46][ t]], 
            Times[ 0.67835603854706361, 
              c[ 47][ t]], 
            Times[ 0.59356153372868015, 
              c[ 48][ t]], 
            Times[ 0.50455115242710469, 
              c[ 49][ t]], 
            Times[ 0.41349667156634429, 
              c[ 50][ t]], 
            Times[ 0.32256865202152113, 
              c[ 51][ t]], 
            Times[ 0.23387232094715985, 
              c[ 52][ t]], 
            Times[ 0.14938649372796384, 
              c[ 53][ t]], 
            Times[ 0.070907514257657456, 
              c[ 54][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 55][ t]], 
            Times[ -0.062044074975450239, 
              c[ 56][ t]], 
            Times[ -0.11423673049785459, 
              c[ 57][ t]], 
            Times[ -0.15591488063143982, 
              c[ 58][ t]], 
            Times[ -0.18675027222298593, 
              c[ 59][ t]], 
            Times[ -0.20674833578317206, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "41", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[41]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.035131239329076656`\ \(c[\(-60\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-59\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-58\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-57\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-56\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-55\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-54\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-53\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-52\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-51\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-50\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-49\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-48\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-47\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-46\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-45\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-44\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-43\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-42\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-41\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-40\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-39\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-38\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-37\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-36\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-35\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-34\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-33\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-32\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-31\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-30\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-29\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-28\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-27\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-26\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-25\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-24\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-23\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-22\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-21\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-20\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-19\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-18\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-17\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-16\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-15\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-14\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-13\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-12\)]\)[t] - 
            0.0913171590351816`\ \(c[\(-11\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-10\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-9\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-8\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-7\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-6\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-5\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-4\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-3\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-2\)]\)[t] + 
            0.06682066312776015`\ \(c[\(-1\)]\)[t] + 
            0.08654280907894489`\ \(c[0]\)[t] + 
            0.10337416789158609`\ \(c[1]\)[t] + 
            0.11643488132933195`\ \(c[2]\)[t] + 
            0.12496032289024853`\ \(c[3]\)[t] + 
            0.12833762891430925`\ \(c[4]\)[t] + 
            0.12613778810677612`\ \(c[5]\)[t] + 
            0.11814190616181253`\ \(c[6]\)[t] + 
            0.10436044624225685`\ \(c[7]\)[t] + 
            0.08504448034442161`\ \(c[8]\)[t] + 
            0.060688263076985`\ \(c[9]\)[t] + 
            0.032022748374425904`\ \(c[10]\)[t] - 
            1.8033970416801674`*^-16\ \(c[11]\)[t] - 
            0.034231213779559094`\ \(c[12]\)[t] - 
            0.06935801494512607`\ \(c[13]\)[t] - 
            0.1039432537542934`\ \(c[14]\)[t] - 
            0.13647135277833616`\ \(c[15]\)[t] - 
            0.1653986686265377`\ \(c[16]\)[t] - 
            0.18920668216016434`\ \(c[17]\)[t] - 
            0.20645618564475848`\ \(c[18]\)[t] - 
            0.21584055771952015`\ \(c[19]\)[t] - 
            0.21623620818304481`\ \(c[20]\)[t] - 
            0.2067483357831719`\ \(c[21]\)[t] - 
            0.18675027222298593`\ \(c[22]\)[t] - 
            0.15591488063143966`\ \(c[23]\)[t] - 
            0.11423673049785416`\ \(c[24]\)[t] - 
            0.06204407497545024`\ \(c[25]\)[t] + 
            3.216976900108398`*^-16\ \(c[26]\)[t] + 
            0.0709075142576581`\ \(c[27]\)[t] + 
            0.14938649372796384`\ \(c[28]\)[t] + 
            0.23387232094716018`\ \(c[29]\)[t] + 
            0.3225686520215219`\ \(c[30]\)[t] + 
            0.4134966715663443`\ \(c[31]\)[t] + 
            0.504551152427105`\ \(c[32]\)[t] + 
            0.5935615337286809`\ \(c[33]\)[t] + 
            0.6783560385470636`\ \(c[34]\)[t] + 
            0.7568267286406574`\ \(c[35]\)[t] + 
            0.8269933431326885`\ \(c[36]\)[t] + 
            0.8870637930591839`\ \(c[37]\)[t] + 
            0.9354892837886393`\ \(c[38]\)[t] + 
            0.9710122092317629`\ \(c[39]\)[t] + 
            0.9927051996072069`\ \(c[40]\)[t] + 
            37.868455551624905`\ \(c[41]\)[t] + 
            0.9927051996072067`\ \(c[42]\)[t] + 
            0.9710122092317629`\ \(c[43]\)[t] + 
            0.9354892837886392`\ \(c[44]\)[t] + 
            0.8870637930591835`\ \(c[45]\)[t] + 
            0.826993343132688`\ \(c[46]\)[t] + 
            0.7568267286406569`\ \(c[47]\)[t] + 
            0.6783560385470627`\ \(c[48]\)[t] + 
            0.5935615337286801`\ \(c[49]\)[t] + 
            0.5045511524271047`\ \(c[50]\)[t] + 
            0.4134966715663436`\ \(c[51]\)[t] + 
            0.32256865202152113`\ \(c[52]\)[t] + 
            0.23387232094715985`\ \(c[53]\)[t] + 
            0.14938649372796314`\ \(c[54]\)[t] + 
            0.07090751425765746`\ \(c[55]\)[t] + 
            3.898171832519376`*^-17\ \(c[56]\)[t] - 
            0.06204407497545072`\ \(c[57]\)[t] - 
            0.11423673049785459`\ \(c[58]\)[t] - 
            0.15591488063143982`\ \(c[59]\)[t] - 
            0.18675027222298618`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 41, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 41]][ t]], 
          Plus[ 
            Times[ 0.035131239329076656, 
              c[ -60][ t]], 
            Times[ 0.041349667156634483, 
              c[ -59][ t]], 
            Times[ 0.045868286584282311, 
              c[ -58][ t]], 
            Times[ 0.048454002753361682, 
              c[ -57][ t]], 
            Times[ 0.048953528554942699, 
              c[ -56][ t]], 
            Times[ 0.047301670540041058, 
              c[ -55][ t]], 
            Times[ 0.043525965428036162, 
              c[ -54][ t]], 
            Times[ 0.03774739544932687, 
              c[ -53][ t]], 
            Times[ 0.030177073670601094, 
              c[ -52][ t]], 
            Times[ 0.021108961070255627, 
              c[ -51][ t]], 
            Times[ 0.010908848347331785, 
              c[ -50][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -49][ t]], 
            Times[ -0.011153991006822649, 
              c[ -48][ t]], 
            Times[ -0.022068459300722043, 
              c[ -47][ t]], 
            Times[ -0.032258251165125679, 
              c[ -46][ t]], 
            Times[ -0.041258781072520248, 
              c[ -45][ t]], 
            Times[ -0.048646667243099399, 
              c[ -44][ t]], 
            Times[ -0.054059052045761224, 
              c[ -43][ t]], 
            Times[ -0.057210750238908967, 
              c[ -42][ t]], 
            Times[ -0.057908442314993203, 
              c[ -41][ t]], 
            Times[ -0.05606123915856713, 
              c[ -40][ t]], 
            Times[ -0.05168708394579296, 
              c[ -39][ t]], 
            Times[ -0.044914622433376288, 
              c[ -38][ t]], 
            Times[ -0.035980357068793781, 
              c[ -37][ t]], 
            Times[ -0.025221096343682053, 
              c[ -36][ t]], 
            Times[ -0.013061910521147276, 
              c[ -35][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -34][ t]], 
            Times[ 0.013414935129827233, 
              c[ -33][ t]], 
            Times[ 0.026603074225527937, 
              c[ -32][ t]], 
            Times[ 0.038978720157860088, 
              c[ -31][ t]], 
            Times[ 0.049975424961080865, 
              c[ -30][ t]], 
            Times[ 0.059070953080906402, 
              c[ -29][ t]], 
            Times[ 0.065811019881796315, 
              c[ -28][ t]], 
            Times[ 0.069830768673962415, 
              c[ -27][ t]], 
            Times[ 0.070873018952678238, 
              c[ -26][ t]], 
            Times[ 0.068802429876423321, 
              c[ -25][ t]], 
            Times[ 0.063614872548668253, 
              c[ -24][ t]], 
            Times[ 0.055441487066198857, 
              c[ -23][ t]], 
            Times[ 0.044547108751839815, 
              c[ -22][ t]], 
            Times[ 0.031322974491347078, 
              c[ -21][ t]], 
            Times[ 0.016273855731265469, 
              c[ -20][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -19][ t]], 
            Times[ -0.016825511857749401, 
              c[ -18][ t]], 
            Times[ -0.033483179628681706, 
              c[ -17][ t]], 
            Times[ -0.049236278094139066, 
              c[ -16][ t]], 
            Times[ -0.063361699504227528, 
              c[ -15][ t]], 
            Times[ -0.075181213012062695, 
              c[ -14][ t]], 
            Times[ -0.084091858737850855, 
              c[ -13][ t]], 
            Times[ -0.089594193770366884, 
              c[ -12][ t]], 
            Times[ -0.091317159035181603, 
              c[ -11][ t]], 
            Times[ -0.089038438663606653, 
              c[ -10][ t]], 
            Times[ -0.082699334313268744, 
              c[ -9][ t]], 
            Times[ -0.072413370861974122, 
              c[ -8][ t]], 
            Times[ -0.058468080236789774, 
              c[ -7][ t]], 
            Times[ -0.04131966847794722, 
              c[ -6][ t]], 
            Times[ -0.021580547817547879, 
              c[ -5][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -4][ t]], 
            Times[ 0.022561481809254869, 
              c[ -3][ t]], 
            Times[ 0.045163358568919301, 
              c[ -2][ t]], 
            Times[ 0.066820663127760152, 
              c[ -1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 0][ t]], 
            Times[ 0.10337416789158609, 
              c[ 1][ t]], 
            Times[ 0.11643488132933195, 
              c[ 2][ t]], 
            Times[ 0.12496032289024853, 
              c[ 3][ t]], 
            Times[ 0.12833762891430925, 
              c[ 4][ t]], 
            Times[ 0.12613778810677612, 
              c[ 5][ t]], 
            Times[ 0.11814190616181253, 
              c[ 6][ t]], 
            Times[ 0.10436044624225685, 
              c[ 7][ t]], 
            Times[ 0.085044480344421608, 
              c[ 8][ t]], 
            Times[ 0.060688263076985001, 
              c[ 9][ t]], 
            Times[ 0.032022748374425904, 
              c[ 10][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 11][ t]], 
            Times[ -0.034231213779559094, 
              c[ 12][ t]], 
            Times[ -0.06935801494512607, 
              c[ 13][ t]], 
            Times[ -0.1039432537542934, 
              c[ 14][ t]], 
            Times[ -0.13647135277833616, 
              c[ 15][ t]], 
            Times[ -0.16539866862653771, 
              c[ 16][ t]], 
            Times[ -0.18920668216016434, 
              c[ 17][ t]], 
            Times[ -0.20645618564475848, 
              c[ 18][ t]], 
            Times[ -0.21584055771952015, 
              c[ 19][ t]], 
            Times[ -0.21623620818304481, 
              c[ 20][ t]], 
            Times[ -0.20674833578317189, 
              c[ 21][ t]], 
            Times[ -0.18675027222298593, 
              c[ 22][ t]], 
            Times[ -0.15591488063143966, 
              c[ 23][ t]], 
            Times[ -0.11423673049785416, 
              c[ 24][ t]], 
            Times[ -0.062044074975450239, 
              c[ 25][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 26][ t]], 
            Times[ 0.070907514257658094, 
              c[ 27][ t]], 
            Times[ 0.14938649372796384, 
              c[ 28][ t]], 
            Times[ 0.23387232094716018, 
              c[ 29][ t]], 
            Times[ 0.32256865202152191, 
              c[ 30][ t]], 
            Times[ 0.41349667156634429, 
              c[ 31][ t]], 
            Times[ 0.50455115242710502, 
              c[ 32][ t]], 
            Times[ 0.59356153372868092, 
              c[ 33][ t]], 
            Times[ 0.67835603854706361, 
              c[ 34][ t]], 
            Times[ 0.75682672864065736, 
              c[ 35][ t]], 
            Times[ 0.82699334313268846, 
              c[ 36][ t]], 
            Times[ 0.88706379305918392, 
              c[ 37][ t]], 
            Times[ 0.93548928378863927, 
              c[ 38][ t]], 
            Times[ 0.9710122092317629, 
              c[ 39][ t]], 
            Times[ 0.99270519960720693, 
              c[ 40][ t]], 
            Times[ 37.868455551624905, 
              c[ 41][ t]], 
            Times[ 0.99270519960720671, 
              c[ 42][ t]], 
            Times[ 0.9710122092317629, 
              c[ 43][ t]], 
            Times[ 0.93548928378863916, 
              c[ 44][ t]], 
            Times[ 0.88706379305918348, 
              c[ 45][ t]], 
            Times[ 0.82699334313268802, 
              c[ 46][ t]], 
            Times[ 0.75682672864065692, 
              c[ 47][ t]], 
            Times[ 0.67835603854706272, 
              c[ 48][ t]], 
            Times[ 0.59356153372868015, 
              c[ 49][ t]], 
            Times[ 0.50455115242710469, 
              c[ 50][ t]], 
            Times[ 0.41349667156634362, 
              c[ 51][ t]], 
            Times[ 0.32256865202152113, 
              c[ 52][ t]], 
            Times[ 0.23387232094715985, 
              c[ 53][ t]], 
            Times[ 0.14938649372796314, 
              c[ 54][ t]], 
            Times[ 0.070907514257657456, 
              c[ 55][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 56][ t]], 
            Times[ -0.062044074975450718, 
              c[ 57][ t]], 
            Times[ -0.11423673049785459, 
              c[ 58][ t]], 
            Times[ -0.15591488063143982, 
              c[ 59][ t]], 
            Times[ -0.18675027222298618, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "42", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[42]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.027514390699665887`\ \(c[\(-60\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-59\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-58\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-57\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-56\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-55\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-54\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-53\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-52\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-51\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-50\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-49\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-47\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-46\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-45\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-44\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-43\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-42\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-41\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-40\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-39\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-38\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-37\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-36\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-35\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-34\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-33\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-32\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-31\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-30\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-29\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-28\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-27\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-26\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-25\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-24\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-23\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-22\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-21\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-20\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-19\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-17\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-16\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-15\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-14\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-13\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-12\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-11\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-10\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-9\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-8\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-7\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-6\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-5\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-4\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-3\)]\)[t] + 
            0.022561481809254675`\ \(c[\(-2\)]\)[t] + 
            0.0451633585689193`\ \(c[\(-1\)]\)[t] + 
            0.06682066312775997`\ \(c[0]\)[t] + 
            0.08654280907894475`\ \(c[1]\)[t] + 
            0.10337416789158609`\ \(c[2]\)[t] + 
            0.11643488132933186`\ \(c[3]\)[t] + 
            0.12496032289024853`\ \(c[4]\)[t] + 
            0.12833762891430925`\ \(c[5]\)[t] + 
            0.12613778810677614`\ \(c[6]\)[t] + 
            0.1181419061618126`\ \(c[7]\)[t] + 
            0.10436044624225692`\ \(c[8]\)[t] + 
            0.0850444803444217`\ \(c[9]\)[t] + 
            0.06068826307698522`\ \(c[10]\)[t] + 
            0.03202274837442603`\ \(c[11]\)[t] - 
            3.898171832519376`*^-17\ \(c[12]\)[t] - 
            0.034231213779558796`\ \(c[13]\)[t] - 
            0.06935801494512592`\ \(c[14]\)[t] - 
            0.10394325375429328`\ \(c[15]\)[t] - 
            0.1364713527783359`\ \(c[16]\)[t] - 
            0.1653986686265376`\ \(c[17]\)[t] - 
            0.18920668216016426`\ \(c[18]\)[t] - 
            0.20645618564475834`\ \(c[19]\)[t] - 
            0.21584055771952013`\ \(c[20]\)[t] - 
            0.21623620818304484`\ \(c[21]\)[t] - 
            0.20674833578317206`\ \(c[22]\)[t] - 
            0.18675027222298607`\ \(c[23]\)[t] - 
            0.15591488063143982`\ \(c[24]\)[t] - 
            0.11423673049785459`\ \(c[25]\)[t] - 
            0.062044074975450475`\ \(c[26]\)[t] + 
            3.898171832519376`*^-17\ \(c[27]\)[t] + 
            0.07090751425765746`\ \(c[28]\)[t] + 
            0.14938649372796345`\ \(c[29]\)[t] + 
            0.23387232094715985`\ \(c[30]\)[t] + 
            0.32256865202152113`\ \(c[31]\)[t] + 
            0.41349667156634395`\ \(c[32]\)[t] + 
            0.5045511524271047`\ \(c[33]\)[t] + 
            0.5935615337286801`\ \(c[34]\)[t] + 
            0.6783560385470632`\ \(c[35]\)[t] + 
            0.7568267286406569`\ \(c[36]\)[t] + 
            0.826993343132688`\ \(c[37]\)[t] + 
            0.8870637930591838`\ \(c[38]\)[t] + 
            0.9354892837886392`\ \(c[39]\)[t] + 
            0.9710122092317629`\ \(c[40]\)[t] + 
            0.9927051996072067`\ \(c[41]\)[t] + 
            39.68884925227028`\ \(c[42]\)[t] + 
            0.9927051996072069`\ \(c[43]\)[t] + 
            0.9710122092317629`\ \(c[44]\)[t] + 
            0.9354892837886392`\ \(c[45]\)[t] + 
            0.8870637930591839`\ \(c[46]\)[t] + 
            0.8269933431326885`\ \(c[47]\)[t] + 
            0.7568267286406569`\ \(c[48]\)[t] + 
            0.6783560385470636`\ \(c[49]\)[t] + 
            0.5935615337286809`\ \(c[50]\)[t] + 
            0.5045511524271047`\ \(c[51]\)[t] + 
            0.4134966715663443`\ \(c[52]\)[t] + 
            0.3225686520215219`\ \(c[53]\)[t] + 
            0.23387232094715985`\ \(c[54]\)[t] + 
            0.14938649372796384`\ \(c[55]\)[t] + 
            0.0709075142576581`\ \(c[56]\)[t] + 
            3.898171832519376`*^-17\ \(c[57]\)[t] - 
            0.06204407497545024`\ \(c[58]\)[t] - 
            0.11423673049785416`\ \(c[59]\)[t] - 
            0.15591488063143982`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 42, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 42]][ t]], 
          Plus[ 
            Times[ 0.027514390699665887, 
              c[ -60][ t]], 
            Times[ 0.035131239329076656, 
              c[ -59][ t]], 
            Times[ 0.041349667156634483, 
              c[ -58][ t]], 
            Times[ 0.045868286584282256, 
              c[ -57][ t]], 
            Times[ 0.048454002753361682, 
              c[ -56][ t]], 
            Times[ 0.04895352855494272, 
              c[ -55][ t]], 
            Times[ 0.047301670540041058, 
              c[ -54][ t]], 
            Times[ 0.043525965428036162, 
              c[ -53][ t]], 
            Times[ 0.03774739544932687, 
              c[ -52][ t]], 
            Times[ 0.030177073670601236, 
              c[ -51][ t]], 
            Times[ 0.021108961070255627, 
              c[ -50][ t]], 
            Times[ 0.010908848347331966, 
              c[ -49][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ -0.011153991006822649, 
              c[ -47][ t]], 
            Times[ -0.022068459300722043, 
              c[ -46][ t]], 
            Times[ -0.032258251165125519, 
              c[ -45][ t]], 
            Times[ -0.041258781072520248, 
              c[ -44][ t]], 
            Times[ -0.048646667243099281, 
              c[ -43][ t]], 
            Times[ -0.054059052045761224, 
              c[ -42][ t]], 
            Times[ -0.057210750238908967, 
              c[ -41][ t]], 
            Times[ -0.057908442314993203, 
              c[ -40][ t]], 
            Times[ -0.056061239158567186, 
              c[ -39][ t]], 
            Times[ -0.05168708394579296, 
              c[ -38][ t]], 
            Times[ -0.044914622433376419, 
              c[ -37][ t]], 
            Times[ -0.035980357068793781, 
              c[ -36][ t]], 
            Times[ -0.025221096343682053, 
              c[ -35][ t]], 
            Times[ -0.013061910521147383, 
              c[ -34][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -33][ t]], 
            Times[ 0.013414935129827233, 
              c[ -32][ t]], 
            Times[ 0.026603074225527826, 
              c[ -31][ t]], 
            Times[ 0.03897872015785999, 
              c[ -30][ t]], 
            Times[ 0.049975424961080865, 
              c[ -29][ t]], 
            Times[ 0.059070953080906326, 
              c[ -28][ t]], 
            Times[ 0.065811019881796273, 
              c[ -27][ t]], 
            Times[ 0.069830768673962415, 
              c[ -26][ t]], 
            Times[ 0.070873018952678238, 
              c[ -25][ t]], 
            Times[ 0.068802429876423349, 
              c[ -24][ t]], 
            Times[ 0.063614872548668253, 
              c[ -23][ t]], 
            Times[ 0.055441487066198933, 
              c[ -22][ t]], 
            Times[ 0.044547108751839919, 
              c[ -21][ t]], 
            Times[ 0.031322974491347078, 
              c[ -20][ t]], 
            Times[ 0.016273855731265604, 
              c[ -19][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ -0.016825511857749401, 
              c[ -17][ t]], 
            Times[ -0.033483179628681567, 
              c[ -16][ t]], 
            Times[ -0.049236278094138941, 
              c[ -15][ t]], 
            Times[ -0.063361699504227528, 
              c[ -14][ t]], 
            Times[ -0.075181213012062598, 
              c[ -13][ t]], 
            Times[ -0.084091858737850814, 
              c[ -12][ t]], 
            Times[ -0.089594193770366884, 
              c[ -11][ t]], 
            Times[ -0.091317159035181589, 
              c[ -10][ t]], 
            Times[ -0.089038438663606695, 
              c[ -9][ t]], 
            Times[ -0.082699334313268813, 
              c[ -8][ t]], 
            Times[ -0.072413370861974122, 
              c[ -7][ t]], 
            Times[ -0.058468080236789913, 
              c[ -6][ t]], 
            Times[ -0.041319668477947373, 
              c[ -5][ t]], 
            Times[ -0.021580547817547879, 
              c[ -4][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -3][ t]], 
            Times[ 0.022561481809254675, 
              c[ -2][ t]], 
            Times[ 0.045163358568919301, 
              c[ -1][ t]], 
            Times[ 0.066820663127759972, 
              c[ 0][ t]], 
            Times[ 0.086542809078944752, 
              c[ 1][ t]], 
            Times[ 0.10337416789158609, 
              c[ 2][ t]], 
            Times[ 0.11643488132933186, 
              c[ 3][ t]], 
            Times[ 0.12496032289024853, 
              c[ 4][ t]], 
            Times[ 0.12833762891430925, 
              c[ 5][ t]], 
            Times[ 0.12613778810677614, 
              c[ 6][ t]], 
            Times[ 0.1181419061618126, 
              c[ 7][ t]], 
            Times[ 0.10436044624225692, 
              c[ 8][ t]], 
            Times[ 0.085044480344421705, 
              c[ 9][ t]], 
            Times[ 0.060688263076985223, 
              c[ 10][ t]], 
            Times[ 0.032022748374426029, 
              c[ 11][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 12][ t]], 
            Times[ -0.034231213779558796, 
              c[ 13][ t]], 
            Times[ -0.069358014945125918, 
              c[ 14][ t]], 
            Times[ -0.10394325375429328, 
              c[ 15][ t]], 
            Times[ -0.13647135277833591, 
              c[ 16][ t]], 
            Times[ -0.1653986686265376, 
              c[ 17][ t]], 
            Times[ -0.18920668216016426, 
              c[ 18][ t]], 
            Times[ -0.20645618564475834, 
              c[ 19][ t]], 
            Times[ -0.21584055771952013, 
              c[ 20][ t]], 
            Times[ -0.21623620818304484, 
              c[ 21][ t]], 
            Times[ -0.20674833578317206, 
              c[ 22][ t]], 
            Times[ -0.18675027222298607, 
              c[ 23][ t]], 
            Times[ -0.15591488063143982, 
              c[ 24][ t]], 
            Times[ -0.11423673049785459, 
              c[ 25][ t]], 
            Times[ -0.062044074975450475, 
              c[ 26][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ 0.070907514257657456, 
              c[ 28][ t]], 
            Times[ 0.14938649372796345, 
              c[ 29][ t]], 
            Times[ 0.23387232094715985, 
              c[ 30][ t]], 
            Times[ 0.32256865202152113, 
              c[ 31][ t]], 
            Times[ 0.41349667156634395, 
              c[ 32][ t]], 
            Times[ 0.50455115242710469, 
              c[ 33][ t]], 
            Times[ 0.59356153372868015, 
              c[ 34][ t]], 
            Times[ 0.67835603854706317, 
              c[ 35][ t]], 
            Times[ 0.75682672864065692, 
              c[ 36][ t]], 
            Times[ 0.82699334313268802, 
              c[ 37][ t]], 
            Times[ 0.88706379305918381, 
              c[ 38][ t]], 
            Times[ 0.93548928378863916, 
              c[ 39][ t]], 
            Times[ 0.9710122092317629, 
              c[ 40][ t]], 
            Times[ 0.99270519960720671, 
              c[ 41][ t]], 
            Times[ 39.68884925227028, 
              c[ 42][ t]], 
            Times[ 0.99270519960720693, 
              c[ 43][ t]], 
            Times[ 0.9710122092317629, 
              c[ 44][ t]], 
            Times[ 0.93548928378863916, 
              c[ 45][ t]], 
            Times[ 0.88706379305918392, 
              c[ 46][ t]], 
            Times[ 0.82699334313268846, 
              c[ 47][ t]], 
            Times[ 0.75682672864065692, 
              c[ 48][ t]], 
            Times[ 0.67835603854706361, 
              c[ 49][ t]], 
            Times[ 0.59356153372868092, 
              c[ 50][ t]], 
            Times[ 0.50455115242710469, 
              c[ 51][ t]], 
            Times[ 0.41349667156634429, 
              c[ 52][ t]], 
            Times[ 0.32256865202152191, 
              c[ 53][ t]], 
            Times[ 0.23387232094715985, 
              c[ 54][ t]], 
            Times[ 0.14938649372796384, 
              c[ 55][ t]], 
            Times[ 0.070907514257658094, 
              c[ 56][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 57][ t]], 
            Times[ -0.062044074975450239, 
              c[ 58][ t]], 
            Times[ -0.11423673049785416, 
              c[ 59][ t]], 
            Times[ -0.15591488063143982, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "43", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[43]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.018854606004500233`\ \(c[\(-60\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-59\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-58\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-57\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-56\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-55\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-54\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-53\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-52\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-51\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-50\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-49\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-48\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-47\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-46\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-45\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-44\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-43\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-42\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-41\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-40\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-39\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-38\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-37\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-36\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-35\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-34\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-33\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-32\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-31\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-30\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-29\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-28\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-27\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-26\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-25\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-24\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-23\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-22\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-21\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-20\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-19\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-18\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-16\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-15\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-14\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-13\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-12\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-11\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-10\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-9\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-8\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-7\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-6\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-5\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-4\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-3\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-2\)]\)[t] + 
            0.02256148180925487`\ \(c[\(-1\)]\)[t] + 
            0.0451633585689193`\ \(c[0]\)[t] + 
            0.06682066312775997`\ \(c[1]\)[t] + 
            0.08654280907894489`\ \(c[2]\)[t] + 
            0.10337416789158609`\ \(c[3]\)[t] + 
            0.11643488132933186`\ \(c[4]\)[t] + 
            0.12496032289024853`\ \(c[5]\)[t] + 
            0.12833762891430928`\ \(c[6]\)[t] + 
            0.12613778810677614`\ \(c[7]\)[t] + 
            0.11814190616181255`\ \(c[8]\)[t] + 
            0.10436044624225685`\ \(c[9]\)[t] + 
            0.0850444803444217`\ \(c[10]\)[t] + 
            0.060688263076985105`\ \(c[11]\)[t] + 
            0.032022748374425904`\ \(c[12]\)[t] - 
            3.898171832519376`*^-17\ \(c[13]\)[t] - 
            0.03423121377955895`\ \(c[14]\)[t] - 
            0.06935801494512607`\ \(c[15]\)[t] - 
            0.10394325375429328`\ \(c[16]\)[t] - 
            0.13647135277833605`\ \(c[17]\)[t] - 
            0.1653986686265377`\ \(c[18]\)[t] - 
            0.18920668216016426`\ \(c[19]\)[t] - 
            0.20645618564475843`\ \(c[20]\)[t] - 
            0.21584055771952015`\ \(c[21]\)[t] - 
            0.21623620818304484`\ \(c[22]\)[t] - 
            0.206748335783172`\ \(c[23]\)[t] - 
            0.18675027222298593`\ \(c[24]\)[t] - 
            0.15591488063143982`\ \(c[25]\)[t] - 
            0.11423673049785436`\ \(c[26]\)[t] - 
            0.06204407497545024`\ \(c[27]\)[t] + 
            3.898171832519376`*^-17\ \(c[28]\)[t] + 
            0.07090751425765777`\ \(c[29]\)[t] + 
            0.14938649372796384`\ \(c[30]\)[t] + 
            0.23387232094715985`\ \(c[31]\)[t] + 
            0.3225686520215216`\ \(c[32]\)[t] + 
            0.4134966715663443`\ \(c[33]\)[t] + 
            0.5045511524271047`\ \(c[34]\)[t] + 
            0.5935615337286806`\ \(c[35]\)[t] + 
            0.6783560385470636`\ \(c[36]\)[t] + 
            0.7568267286406569`\ \(c[37]\)[t] + 
            0.8269933431326881`\ \(c[38]\)[t] + 
            0.8870637930591839`\ \(c[39]\)[t] + 
            0.9354892837886392`\ \(c[40]\)[t] + 
            0.9710122092317629`\ \(c[41]\)[t] + 
            0.9927051996072069`\ \(c[42]\)[t] + 
            41.553107861364936`\ \(c[43]\)[t] + 
            0.9927051996072069`\ \(c[44]\)[t] + 
            0.9710122092317629`\ \(c[45]\)[t] + 
            0.9354892837886392`\ \(c[46]\)[t] + 
            0.8870637930591839`\ \(c[47]\)[t] + 
            0.826993343132688`\ \(c[48]\)[t] + 
            0.7568267286406569`\ \(c[49]\)[t] + 
            0.6783560385470636`\ \(c[50]\)[t] + 
            0.5935615337286801`\ \(c[51]\)[t] + 
            0.5045511524271047`\ \(c[52]\)[t] + 
            0.4134966715663443`\ \(c[53]\)[t] + 
            0.32256865202152113`\ \(c[54]\)[t] + 
            0.23387232094715985`\ \(c[55]\)[t] + 
            0.14938649372796384`\ \(c[56]\)[t] + 
            0.07090751425765746`\ \(c[57]\)[t] + 
            3.898171832519376`*^-17\ \(c[58]\)[t] - 
            0.06204407497545024`\ \(c[59]\)[t] - 
            0.11423673049785459`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 43, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 43]][ t]], 
          Plus[ 
            Times[ 0.018854606004500233, 
              c[ -60][ t]], 
            Times[ 0.027514390699665887, 
              c[ -59][ t]], 
            Times[ 0.035131239329076656, 
              c[ -58][ t]], 
            Times[ 0.041349667156634483, 
              c[ -57][ t]], 
            Times[ 0.045868286584282311, 
              c[ -56][ t]], 
            Times[ 0.048454002753361682, 
              c[ -55][ t]], 
            Times[ 0.04895352855494272, 
              c[ -54][ t]], 
            Times[ 0.047301670540041058, 
              c[ -53][ t]], 
            Times[ 0.043525965428036162, 
              c[ -52][ t]], 
            Times[ 0.03774739544932687, 
              c[ -51][ t]], 
            Times[ 0.030177073670601094, 
              c[ -50][ t]], 
            Times[ 0.021108961070255627, 
              c[ -49][ t]], 
            Times[ 0.010908848347331966, 
              c[ -48][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -47][ t]], 
            Times[ -0.011153991006822649, 
              c[ -46][ t]], 
            Times[ -0.022068459300722043, 
              c[ -45][ t]], 
            Times[ -0.032258251165125679, 
              c[ -44][ t]], 
            Times[ -0.041258781072520248, 
              c[ -43][ t]], 
            Times[ -0.048646667243099281, 
              c[ -42][ t]], 
            Times[ -0.054059052045761224, 
              c[ -41][ t]], 
            Times[ -0.057210750238908967, 
              c[ -40][ t]], 
            Times[ -0.057908442314993203, 
              c[ -39][ t]], 
            Times[ -0.056061239158567186, 
              c[ -38][ t]], 
            Times[ -0.05168708394579296, 
              c[ -37][ t]], 
            Times[ -0.044914622433376419, 
              c[ -36][ t]], 
            Times[ -0.035980357068793781, 
              c[ -35][ t]], 
            Times[ -0.025221096343682053, 
              c[ -34][ t]], 
            Times[ -0.013061910521147383, 
              c[ -33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -32][ t]], 
            Times[ 0.013414935129827233, 
              c[ -31][ t]], 
            Times[ 0.026603074225527826, 
              c[ -30][ t]], 
            Times[ 0.03897872015785999, 
              c[ -29][ t]], 
            Times[ 0.049975424961080865, 
              c[ -28][ t]], 
            Times[ 0.059070953080906326, 
              c[ -27][ t]], 
            Times[ 0.065811019881796273, 
              c[ -26][ t]], 
            Times[ 0.069830768673962415, 
              c[ -25][ t]], 
            Times[ 0.070873018952678238, 
              c[ -24][ t]], 
            Times[ 0.068802429876423349, 
              c[ -23][ t]], 
            Times[ 0.063614872548668253, 
              c[ -22][ t]], 
            Times[ 0.055441487066198933, 
              c[ -21][ t]], 
            Times[ 0.044547108751839919, 
              c[ -20][ t]], 
            Times[ 0.031322974491347078, 
              c[ -19][ t]], 
            Times[ 0.016273855731265604, 
              c[ -18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ -0.016825511857749401, 
              c[ -16][ t]], 
            Times[ -0.033483179628681567, 
              c[ -15][ t]], 
            Times[ -0.049236278094138941, 
              c[ -14][ t]], 
            Times[ -0.063361699504227528, 
              c[ -13][ t]], 
            Times[ -0.075181213012062598, 
              c[ -12][ t]], 
            Times[ -0.084091858737850814, 
              c[ -11][ t]], 
            Times[ -0.089594193770366884, 
              c[ -10][ t]], 
            Times[ -0.091317159035181589, 
              c[ -9][ t]], 
            Times[ -0.089038438663606695, 
              c[ -8][ t]], 
            Times[ -0.082699334313268744, 
              c[ -7][ t]], 
            Times[ -0.072413370861974122, 
              c[ -6][ t]], 
            Times[ -0.058468080236789913, 
              c[ -5][ t]], 
            Times[ -0.04131966847794722, 
              c[ -4][ t]], 
            Times[ -0.021580547817547879, 
              c[ -3][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -2][ t]], 
            Times[ 0.022561481809254869, 
              c[ -1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 0][ t]], 
            Times[ 0.066820663127759972, 
              c[ 1][ t]], 
            Times[ 0.086542809078944891, 
              c[ 2][ t]], 
            Times[ 0.10337416789158609, 
              c[ 3][ t]], 
            Times[ 0.11643488132933186, 
              c[ 4][ t]], 
            Times[ 0.12496032289024853, 
              c[ 5][ t]], 
            Times[ 0.12833762891430928, 
              c[ 6][ t]], 
            Times[ 0.12613778810677614, 
              c[ 7][ t]], 
            Times[ 0.11814190616181255, 
              c[ 8][ t]], 
            Times[ 0.10436044624225685, 
              c[ 9][ t]], 
            Times[ 0.085044480344421705, 
              c[ 10][ t]], 
            Times[ 0.060688263076985105, 
              c[ 11][ t]], 
            Times[ 0.032022748374425904, 
              c[ 12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 13][ t]], 
            Times[ -0.034231213779558949, 
              c[ 14][ t]], 
            Times[ -0.06935801494512607, 
              c[ 15][ t]], 
            Times[ -0.10394325375429328, 
              c[ 16][ t]], 
            Times[ -0.13647135277833605, 
              c[ 17][ t]], 
            Times[ -0.16539866862653771, 
              c[ 18][ t]], 
            Times[ -0.18920668216016426, 
              c[ 19][ t]], 
            Times[ -0.20645618564475843, 
              c[ 20][ t]], 
            Times[ -0.21584055771952015, 
              c[ 21][ t]], 
            Times[ -0.21623620818304484, 
              c[ 22][ t]], 
            Times[ -0.206748335783172, 
              c[ 23][ t]], 
            Times[ -0.18675027222298593, 
              c[ 24][ t]], 
            Times[ -0.15591488063143982, 
              c[ 25][ t]], 
            Times[ -0.11423673049785436, 
              c[ 26][ t]], 
            Times[ -0.062044074975450239, 
              c[ 27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ 0.070907514257657775, 
              c[ 29][ t]], 
            Times[ 0.14938649372796384, 
              c[ 30][ t]], 
            Times[ 0.23387232094715985, 
              c[ 31][ t]], 
            Times[ 0.32256865202152157, 
              c[ 32][ t]], 
            Times[ 0.41349667156634429, 
              c[ 33][ t]], 
            Times[ 0.50455115242710469, 
              c[ 34][ t]], 
            Times[ 0.59356153372868059, 
              c[ 35][ t]], 
            Times[ 0.67835603854706361, 
              c[ 36][ t]], 
            Times[ 0.75682672864065692, 
              c[ 37][ t]], 
            Times[ 0.82699334313268813, 
              c[ 38][ t]], 
            Times[ 0.88706379305918392, 
              c[ 39][ t]], 
            Times[ 0.93548928378863916, 
              c[ 40][ t]], 
            Times[ 0.9710122092317629, 
              c[ 41][ t]], 
            Times[ 0.99270519960720693, 
              c[ 42][ t]], 
            Times[ 41.553107861364936, 
              c[ 43][ t]], 
            Times[ 0.99270519960720693, 
              c[ 44][ t]], 
            Times[ 0.9710122092317629, 
              c[ 45][ t]], 
            Times[ 0.93548928378863916, 
              c[ 46][ t]], 
            Times[ 0.88706379305918392, 
              c[ 47][ t]], 
            Times[ 0.82699334313268802, 
              c[ 48][ t]], 
            Times[ 0.75682672864065692, 
              c[ 49][ t]], 
            Times[ 0.67835603854706361, 
              c[ 50][ t]], 
            Times[ 0.59356153372868015, 
              c[ 51][ t]], 
            Times[ 0.50455115242710469, 
              c[ 52][ t]], 
            Times[ 0.41349667156634429, 
              c[ 53][ t]], 
            Times[ 0.32256865202152113, 
              c[ 54][ t]], 
            Times[ 0.23387232094715985, 
              c[ 55][ t]], 
            Times[ 0.14938649372796384, 
              c[ 56][ t]], 
            Times[ 0.070907514257657456, 
              c[ 57][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 58][ t]], 
            Times[ -0.062044074975450239, 
              c[ 59][ t]], 
            Times[ -0.11423673049785459, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "44", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[44]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(0.009545242303915543`\ \(c[\(-60\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-59\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-58\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-57\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-56\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-55\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-54\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-53\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-52\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-51\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-50\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-49\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-48\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-47\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-46\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-45\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-44\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-43\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-42\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-41\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-40\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-39\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-38\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-37\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-36\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-35\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-34\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-33\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-32\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-31\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-30\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-29\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-28\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-27\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-26\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-25\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-24\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-23\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-22\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-21\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-20\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-19\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-18\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-17\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-16\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-15\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-14\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-13\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-12\)]\)[t] - 
            0.0751812130120627`\ \(c[\(-11\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-10\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-9\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-8\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-7\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-6\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-5\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-4\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-3\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-2\)]\)[t] + 
            2.274590327822911`*^-16\ \(c[\(-1\)]\)[t] + 
            0.02256148180925487`\ \(c[0]\)[t] + 
            0.0451633585689193`\ \(c[1]\)[t] + 
            0.06682066312776015`\ \(c[2]\)[t] + 
            0.08654280907894489`\ \(c[3]\)[t] + 
            0.10337416789158609`\ \(c[4]\)[t] + 
            0.11643488132933195`\ \(c[5]\)[t] + 
            0.12496032289024853`\ \(c[6]\)[t] + 
            0.12833762891430928`\ \(c[7]\)[t] + 
            0.12613778810677612`\ \(c[8]\)[t] + 
            0.11814190616181253`\ \(c[9]\)[t] + 
            0.10436044624225685`\ \(c[10]\)[t] + 
            0.08504448034442161`\ \(c[11]\)[t] + 
            0.060688263076985`\ \(c[12]\)[t] + 
            0.032022748374425904`\ \(c[13]\)[t] - 
            1.8033970416801674`*^-16\ \(c[14]\)[t] - 
            0.034231213779559094`\ \(c[15]\)[t] - 
            0.06935801494512607`\ \(c[16]\)[t] - 
            0.1039432537542934`\ \(c[17]\)[t] - 
            0.13647135277833616`\ \(c[18]\)[t] - 
            0.1653986686265377`\ \(c[19]\)[t] - 
            0.18920668216016434`\ \(c[20]\)[t] - 
            0.20645618564475848`\ \(c[21]\)[t] - 
            0.21584055771952015`\ \(c[22]\)[t] - 
            0.21623620818304481`\ \(c[23]\)[t] - 
            0.2067483357831719`\ \(c[24]\)[t] - 
            0.18675027222298593`\ \(c[25]\)[t] - 
            0.15591488063143966`\ \(c[26]\)[t] - 
            0.11423673049785416`\ \(c[27]\)[t] - 
            0.06204407497545024`\ \(c[28]\)[t] + 
            3.216976900108398`*^-16\ \(c[29]\)[t] + 
            0.0709075142576581`\ \(c[30]\)[t] + 
            0.14938649372796384`\ \(c[31]\)[t] + 
            0.23387232094716018`\ \(c[32]\)[t] + 
            0.3225686520215219`\ \(c[33]\)[t] + 
            0.4134966715663443`\ \(c[34]\)[t] + 
            0.504551152427105`\ \(c[35]\)[t] + 
            0.5935615337286809`\ \(c[36]\)[t] + 
            0.6783560385470636`\ \(c[37]\)[t] + 
            0.7568267286406574`\ \(c[38]\)[t] + 
            0.8269933431326885`\ \(c[39]\)[t] + 
            0.8870637930591839`\ \(c[40]\)[t] + 
            0.9354892837886392`\ \(c[41]\)[t] + 
            0.9710122092317629`\ \(c[42]\)[t] + 
            0.9927051996072069`\ \(c[43]\)[t] + 
            43.46123137890887`\ \(c[44]\)[t] + 
            0.9927051996072067`\ \(c[45]\)[t] + 
            0.9710122092317629`\ \(c[46]\)[t] + 
            0.9354892837886392`\ \(c[47]\)[t] + 
            0.8870637930591835`\ \(c[48]\)[t] + 
            0.826993343132688`\ \(c[49]\)[t] + 
            0.7568267286406569`\ \(c[50]\)[t] + 
            0.6783560385470627`\ \(c[51]\)[t] + 
            0.5935615337286801`\ \(c[52]\)[t] + 
            0.5045511524271047`\ \(c[53]\)[t] + 
            0.4134966715663436`\ \(c[54]\)[t] + 
            0.32256865202152113`\ \(c[55]\)[t] + 
            0.23387232094715985`\ \(c[56]\)[t] + 
            0.14938649372796314`\ \(c[57]\)[t] + 
            0.07090751425765746`\ \(c[58]\)[t] + 
            3.898171832519376`*^-17\ \(c[59]\)[t] - 
            0.06204407497545072`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 44, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 44]][ t]], 
          Plus[ 
            Times[ 0.0095452423039155427, 
              c[ -60][ t]], 
            Times[ 0.018854606004500389, 
              c[ -59][ t]], 
            Times[ 0.027514390699665887, 
              c[ -58][ t]], 
            Times[ 0.035131239329076656, 
              c[ -57][ t]], 
            Times[ 0.041349667156634483, 
              c[ -56][ t]], 
            Times[ 0.045868286584282311, 
              c[ -55][ t]], 
            Times[ 0.048454002753361682, 
              c[ -54][ t]], 
            Times[ 0.048953528554942699, 
              c[ -53][ t]], 
            Times[ 0.047301670540041058, 
              c[ -52][ t]], 
            Times[ 0.043525965428036162, 
              c[ -51][ t]], 
            Times[ 0.03774739544932687, 
              c[ -50][ t]], 
            Times[ 0.030177073670601094, 
              c[ -49][ t]], 
            Times[ 0.021108961070255627, 
              c[ -48][ t]], 
            Times[ 0.010908848347331785, 
              c[ -47][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -46][ t]], 
            Times[ -0.011153991006822649, 
              c[ -45][ t]], 
            Times[ -0.022068459300722043, 
              c[ -44][ t]], 
            Times[ -0.032258251165125679, 
              c[ -43][ t]], 
            Times[ -0.041258781072520248, 
              c[ -42][ t]], 
            Times[ -0.048646667243099399, 
              c[ -41][ t]], 
            Times[ -0.054059052045761224, 
              c[ -40][ t]], 
            Times[ -0.057210750238908967, 
              c[ -39][ t]], 
            Times[ -0.057908442314993203, 
              c[ -38][ t]], 
            Times[ -0.05606123915856713, 
              c[ -37][ t]], 
            Times[ -0.05168708394579296, 
              c[ -36][ t]], 
            Times[ -0.044914622433376288, 
              c[ -35][ t]], 
            Times[ -0.035980357068793781, 
              c[ -34][ t]], 
            Times[ -0.025221096343682053, 
              c[ -33][ t]], 
            Times[ -0.013061910521147276, 
              c[ -32][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -31][ t]], 
            Times[ 0.013414935129827233, 
              c[ -30][ t]], 
            Times[ 0.026603074225527937, 
              c[ -29][ t]], 
            Times[ 0.038978720157860088, 
              c[ -28][ t]], 
            Times[ 0.049975424961080865, 
              c[ -27][ t]], 
            Times[ 0.059070953080906402, 
              c[ -26][ t]], 
            Times[ 0.065811019881796315, 
              c[ -25][ t]], 
            Times[ 0.069830768673962415, 
              c[ -24][ t]], 
            Times[ 0.070873018952678238, 
              c[ -23][ t]], 
            Times[ 0.068802429876423321, 
              c[ -22][ t]], 
            Times[ 0.063614872548668253, 
              c[ -21][ t]], 
            Times[ 0.055441487066198857, 
              c[ -20][ t]], 
            Times[ 0.044547108751839815, 
              c[ -19][ t]], 
            Times[ 0.031322974491347078, 
              c[ -18][ t]], 
            Times[ 0.016273855731265469, 
              c[ -17][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -16][ t]], 
            Times[ -0.016825511857749401, 
              c[ -15][ t]], 
            Times[ -0.033483179628681706, 
              c[ -14][ t]], 
            Times[ -0.049236278094139066, 
              c[ -13][ t]], 
            Times[ -0.063361699504227528, 
              c[ -12][ t]], 
            Times[ -0.075181213012062695, 
              c[ -11][ t]], 
            Times[ -0.084091858737850855, 
              c[ -10][ t]], 
            Times[ -0.089594193770366884, 
              c[ -9][ t]], 
            Times[ -0.091317159035181589, 
              c[ -8][ t]], 
            Times[ -0.089038438663606653, 
              c[ -7][ t]], 
            Times[ -0.082699334313268744, 
              c[ -6][ t]], 
            Times[ -0.072413370861974122, 
              c[ -5][ t]], 
            Times[ -0.058468080236789774, 
              c[ -4][ t]], 
            Times[ -0.04131966847794722, 
              c[ -3][ t]], 
            Times[ -0.021580547817547879, 
              c[ -2][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ -1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 0][ t]], 
            Times[ 0.045163358568919301, 
              c[ 1][ t]], 
            Times[ 0.066820663127760152, 
              c[ 2][ t]], 
            Times[ 0.086542809078944891, 
              c[ 3][ t]], 
            Times[ 0.10337416789158609, 
              c[ 4][ t]], 
            Times[ 0.11643488132933195, 
              c[ 5][ t]], 
            Times[ 0.12496032289024853, 
              c[ 6][ t]], 
            Times[ 0.12833762891430928, 
              c[ 7][ t]], 
            Times[ 0.12613778810677612, 
              c[ 8][ t]], 
            Times[ 0.11814190616181253, 
              c[ 9][ t]], 
            Times[ 0.10436044624225685, 
              c[ 10][ t]], 
            Times[ 0.085044480344421608, 
              c[ 11][ t]], 
            Times[ 0.060688263076985001, 
              c[ 12][ t]], 
            Times[ 0.032022748374425904, 
              c[ 13][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 14][ t]], 
            Times[ -0.034231213779559094, 
              c[ 15][ t]], 
            Times[ -0.06935801494512607, 
              c[ 16][ t]], 
            Times[ -0.1039432537542934, 
              c[ 17][ t]], 
            Times[ -0.13647135277833616, 
              c[ 18][ t]], 
            Times[ -0.16539866862653771, 
              c[ 19][ t]], 
            Times[ -0.18920668216016434, 
              c[ 20][ t]], 
            Times[ -0.20645618564475848, 
              c[ 21][ t]], 
            Times[ -0.21584055771952015, 
              c[ 22][ t]], 
            Times[ -0.21623620818304481, 
              c[ 23][ t]], 
            Times[ -0.20674833578317189, 
              c[ 24][ t]], 
            Times[ -0.18675027222298593, 
              c[ 25][ t]], 
            Times[ -0.15591488063143966, 
              c[ 26][ t]], 
            Times[ -0.11423673049785416, 
              c[ 27][ t]], 
            Times[ -0.062044074975450239, 
              c[ 28][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 29][ t]], 
            Times[ 0.070907514257658094, 
              c[ 30][ t]], 
            Times[ 0.14938649372796384, 
              c[ 31][ t]], 
            Times[ 0.23387232094716018, 
              c[ 32][ t]], 
            Times[ 0.32256865202152191, 
              c[ 33][ t]], 
            Times[ 0.41349667156634429, 
              c[ 34][ t]], 
            Times[ 0.50455115242710502, 
              c[ 35][ t]], 
            Times[ 0.59356153372868092, 
              c[ 36][ t]], 
            Times[ 0.67835603854706361, 
              c[ 37][ t]], 
            Times[ 0.75682672864065736, 
              c[ 38][ t]], 
            Times[ 0.82699334313268846, 
              c[ 39][ t]], 
            Times[ 0.88706379305918392, 
              c[ 40][ t]], 
            Times[ 0.93548928378863916, 
              c[ 41][ t]], 
            Times[ 0.9710122092317629, 
              c[ 42][ t]], 
            Times[ 0.99270519960720693, 
              c[ 43][ t]], 
            Times[ 43.46123137890887, 
              c[ 44][ t]], 
            Times[ 0.99270519960720671, 
              c[ 45][ t]], 
            Times[ 0.9710122092317629, 
              c[ 46][ t]], 
            Times[ 0.93548928378863916, 
              c[ 47][ t]], 
            Times[ 0.88706379305918348, 
              c[ 48][ t]], 
            Times[ 0.82699334313268802, 
              c[ 49][ t]], 
            Times[ 0.75682672864065692, 
              c[ 50][ t]], 
            Times[ 0.67835603854706272, 
              c[ 51][ t]], 
            Times[ 0.59356153372868015, 
              c[ 52][ t]], 
            Times[ 0.50455115242710469, 
              c[ 53][ t]], 
            Times[ 0.41349667156634362, 
              c[ 54][ t]], 
            Times[ 0.32256865202152113, 
              c[ 55][ t]], 
            Times[ 0.23387232094715985, 
              c[ 56][ t]], 
            Times[ 0.14938649372796314, 
              c[ 57][ t]], 
            Times[ 0.070907514257657456, 
              c[ 58][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 59][ t]], 
            Times[ -0.062044074975450718, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "45", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[45]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(3.8981718325193755`*^-17\ \(c[\(-60\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-59\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-58\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-57\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-56\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-55\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-54\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-53\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-52\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-51\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-50\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-49\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-48\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-47\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-46\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-44\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-43\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-42\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-41\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-40\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-39\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-38\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-37\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-36\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-35\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-34\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-33\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-32\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-31\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-30\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-29\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-28\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-27\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-26\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-25\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-24\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-23\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-22\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-21\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-20\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-19\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-18\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-17\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-16\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-14\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-13\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-12\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-11\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-10\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-9\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-8\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-7\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-6\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-5\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-4\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-3\)]\)[t] - 
            0.04131966847794737`\ \(c[\(-2\)]\)[t] - 
            0.02158054781754788`\ \(c[\(-1\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[0]\)[t] + 
            0.022561481809254675`\ \(c[1]\)[t] + 
            0.0451633585689193`\ \(c[2]\)[t] + 
            0.06682066312775997`\ \(c[3]\)[t] + 
            0.08654280907894475`\ \(c[4]\)[t] + 
            0.10337416789158609`\ \(c[5]\)[t] + 
            0.11643488132933186`\ \(c[6]\)[t] + 
            0.12496032289024847`\ \(c[7]\)[t] + 
            0.12833762891430925`\ \(c[8]\)[t] + 
            0.12613778810677614`\ \(c[9]\)[t] + 
            0.1181419061618126`\ \(c[10]\)[t] + 
            0.10436044624225692`\ \(c[11]\)[t] + 
            0.0850444803444217`\ \(c[12]\)[t] + 
            0.06068826307698522`\ \(c[13]\)[t] + 
            0.03202274837442603`\ \(c[14]\)[t] - 
            3.898171832519376`*^-17\ \(c[15]\)[t] - 
            0.034231213779558796`\ \(c[16]\)[t] - 
            0.06935801494512592`\ \(c[17]\)[t] - 
            0.10394325375429328`\ \(c[18]\)[t] - 
            0.1364713527783359`\ \(c[19]\)[t] - 
            0.1653986686265376`\ \(c[20]\)[t] - 
            0.18920668216016426`\ \(c[21]\)[t] - 
            0.20645618564475834`\ \(c[22]\)[t] - 
            0.21584055771952013`\ \(c[23]\)[t] - 
            0.21623620818304484`\ \(c[24]\)[t] - 
            0.20674833578317206`\ \(c[25]\)[t] - 
            0.18675027222298607`\ \(c[26]\)[t] - 
            0.15591488063143982`\ \(c[27]\)[t] - 
            0.11423673049785459`\ \(c[28]\)[t] - 
            0.062044074975450475`\ \(c[29]\)[t] + 
            3.898171832519376`*^-17\ \(c[30]\)[t] + 
            0.07090751425765746`\ \(c[31]\)[t] + 
            0.14938649372796345`\ \(c[32]\)[t] + 
            0.23387232094715985`\ \(c[33]\)[t] + 
            0.32256865202152113`\ \(c[34]\)[t] + 
            0.41349667156634395`\ \(c[35]\)[t] + 
            0.5045511524271047`\ \(c[36]\)[t] + 
            0.5935615337286801`\ \(c[37]\)[t] + 
            0.6783560385470632`\ \(c[38]\)[t] + 
            0.7568267286406569`\ \(c[39]\)[t] + 
            0.826993343132688`\ \(c[40]\)[t] + 
            0.8870637930591835`\ \(c[41]\)[t] + 
            0.9354892837886392`\ \(c[42]\)[t] + 
            0.9710122092317629`\ \(c[43]\)[t] + 
            0.9927051996072067`\ \(c[44]\)[t] + 
            45.41321980490211`\ \(c[45]\)[t] + 
            0.9927051996072069`\ \(c[46]\)[t] + 
            0.9710122092317629`\ \(c[47]\)[t] + 
            0.9354892837886392`\ \(c[48]\)[t] + 
            0.8870637930591839`\ \(c[49]\)[t] + 
            0.8269933431326885`\ \(c[50]\)[t] + 
            0.7568267286406569`\ \(c[51]\)[t] + 
            0.6783560385470636`\ \(c[52]\)[t] + 
            0.5935615337286809`\ \(c[53]\)[t] + 
            0.5045511524271047`\ \(c[54]\)[t] + 
            0.4134966715663443`\ \(c[55]\)[t] + 
            0.3225686520215219`\ \(c[56]\)[t] + 
            0.23387232094715985`\ \(c[57]\)[t] + 
            0.14938649372796384`\ \(c[58]\)[t] + 
            0.0709075142576581`\ \(c[59]\)[t] + 
            3.898171832519376`*^-17\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 45, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 45]][ t]], 
          Plus[ 
            Times[ 3.8981718325193755*^-17, 
              c[ -60][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -59][ t]], 
            Times[ 0.018854606004500233, 
              c[ -58][ t]], 
            Times[ 0.027514390699665887, 
              c[ -57][ t]], 
            Times[ 0.035131239329076656, 
              c[ -56][ t]], 
            Times[ 0.041349667156634483, 
              c[ -55][ t]], 
            Times[ 0.045868286584282256, 
              c[ -54][ t]], 
            Times[ 0.048454002753361682, 
              c[ -53][ t]], 
            Times[ 0.04895352855494272, 
              c[ -52][ t]], 
            Times[ 0.047301670540041058, 
              c[ -51][ t]], 
            Times[ 0.043525965428036162, 
              c[ -50][ t]], 
            Times[ 0.03774739544932687, 
              c[ -49][ t]], 
            Times[ 0.030177073670601236, 
              c[ -48][ t]], 
            Times[ 0.021108961070255627, 
              c[ -47][ t]], 
            Times[ 0.010908848347331966, 
              c[ -46][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ -0.011153991006822649, 
              c[ -44][ t]], 
            Times[ -0.022068459300722043, 
              c[ -43][ t]], 
            Times[ -0.032258251165125519, 
              c[ -42][ t]], 
            Times[ -0.041258781072520248, 
              c[ -41][ t]], 
            Times[ -0.048646667243099281, 
              c[ -40][ t]], 
            Times[ -0.054059052045761224, 
              c[ -39][ t]], 
            Times[ -0.057210750238908967, 
              c[ -38][ t]], 
            Times[ -0.057908442314993203, 
              c[ -37][ t]], 
            Times[ -0.056061239158567186, 
              c[ -36][ t]], 
            Times[ -0.05168708394579296, 
              c[ -35][ t]], 
            Times[ -0.044914622433376419, 
              c[ -34][ t]], 
            Times[ -0.035980357068793781, 
              c[ -33][ t]], 
            Times[ -0.025221096343682053, 
              c[ -32][ t]], 
            Times[ -0.013061910521147383, 
              c[ -31][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -30][ t]], 
            Times[ 0.013414935129827233, 
              c[ -29][ t]], 
            Times[ 0.026603074225527826, 
              c[ -28][ t]], 
            Times[ 0.03897872015785999, 
              c[ -27][ t]], 
            Times[ 0.049975424961080865, 
              c[ -26][ t]], 
            Times[ 0.059070953080906326, 
              c[ -25][ t]], 
            Times[ 0.065811019881796273, 
              c[ -24][ t]], 
            Times[ 0.069830768673962415, 
              c[ -23][ t]], 
            Times[ 0.070873018952678238, 
              c[ -22][ t]], 
            Times[ 0.068802429876423349, 
              c[ -21][ t]], 
            Times[ 0.063614872548668253, 
              c[ -20][ t]], 
            Times[ 0.055441487066198933, 
              c[ -19][ t]], 
            Times[ 0.044547108751839919, 
              c[ -18][ t]], 
            Times[ 0.031322974491347078, 
              c[ -17][ t]], 
            Times[ 0.016273855731265604, 
              c[ -16][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ -0.016825511857749401, 
              c[ -14][ t]], 
            Times[ -0.033483179628681567, 
              c[ -13][ t]], 
            Times[ -0.049236278094138941, 
              c[ -12][ t]], 
            Times[ -0.063361699504227528, 
              c[ -11][ t]], 
            Times[ -0.075181213012062598, 
              c[ -10][ t]], 
            Times[ -0.084091858737850814, 
              c[ -9][ t]], 
            Times[ -0.089594193770366842, 
              c[ -8][ t]], 
            Times[ -0.091317159035181589, 
              c[ -7][ t]], 
            Times[ -0.089038438663606695, 
              c[ -6][ t]], 
            Times[ -0.082699334313268813, 
              c[ -5][ t]], 
            Times[ -0.072413370861974122, 
              c[ -4][ t]], 
            Times[ -0.058468080236789913, 
              c[ -3][ t]], 
            Times[ -0.041319668477947373, 
              c[ -2][ t]], 
            Times[ -0.021580547817547879, 
              c[ -1][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 0][ t]], 
            Times[ 0.022561481809254675, 
              c[ 1][ t]], 
            Times[ 0.045163358568919301, 
              c[ 2][ t]], 
            Times[ 0.066820663127759972, 
              c[ 3][ t]], 
            Times[ 0.086542809078944752, 
              c[ 4][ t]], 
            Times[ 0.10337416789158609, 
              c[ 5][ t]], 
            Times[ 0.11643488132933186, 
              c[ 6][ t]], 
            Times[ 0.12496032289024847, 
              c[ 7][ t]], 
            Times[ 0.12833762891430925, 
              c[ 8][ t]], 
            Times[ 0.12613778810677614, 
              c[ 9][ t]], 
            Times[ 0.1181419061618126, 
              c[ 10][ t]], 
            Times[ 0.10436044624225692, 
              c[ 11][ t]], 
            Times[ 0.085044480344421705, 
              c[ 12][ t]], 
            Times[ 0.060688263076985223, 
              c[ 13][ t]], 
            Times[ 0.032022748374426029, 
              c[ 14][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 15][ t]], 
            Times[ -0.034231213779558796, 
              c[ 16][ t]], 
            Times[ -0.069358014945125918, 
              c[ 17][ t]], 
            Times[ -0.10394325375429328, 
              c[ 18][ t]], 
            Times[ -0.13647135277833591, 
              c[ 19][ t]], 
            Times[ -0.1653986686265376, 
              c[ 20][ t]], 
            Times[ -0.18920668216016426, 
              c[ 21][ t]], 
            Times[ -0.20645618564475834, 
              c[ 22][ t]], 
            Times[ -0.21584055771952013, 
              c[ 23][ t]], 
            Times[ -0.21623620818304484, 
              c[ 24][ t]], 
            Times[ -0.20674833578317206, 
              c[ 25][ t]], 
            Times[ -0.18675027222298607, 
              c[ 26][ t]], 
            Times[ -0.15591488063143982, 
              c[ 27][ t]], 
            Times[ -0.11423673049785459, 
              c[ 28][ t]], 
            Times[ -0.062044074975450475, 
              c[ 29][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ 0.070907514257657456, 
              c[ 31][ t]], 
            Times[ 0.14938649372796345, 
              c[ 32][ t]], 
            Times[ 0.23387232094715985, 
              c[ 33][ t]], 
            Times[ 0.32256865202152113, 
              c[ 34][ t]], 
            Times[ 0.41349667156634395, 
              c[ 35][ t]], 
            Times[ 0.50455115242710469, 
              c[ 36][ t]], 
            Times[ 0.59356153372868015, 
              c[ 37][ t]], 
            Times[ 0.67835603854706317, 
              c[ 38][ t]], 
            Times[ 0.75682672864065692, 
              c[ 39][ t]], 
            Times[ 0.82699334313268802, 
              c[ 40][ t]], 
            Times[ 0.88706379305918348, 
              c[ 41][ t]], 
            Times[ 0.93548928378863916, 
              c[ 42][ t]], 
            Times[ 0.9710122092317629, 
              c[ 43][ t]], 
            Times[ 0.99270519960720671, 
              c[ 44][ t]], 
            Times[ 45.413219804902113, 
              c[ 45][ t]], 
            Times[ 0.99270519960720693, 
              c[ 46][ t]], 
            Times[ 0.9710122092317629, 
              c[ 47][ t]], 
            Times[ 0.93548928378863916, 
              c[ 48][ t]], 
            Times[ 0.88706379305918392, 
              c[ 49][ t]], 
            Times[ 0.82699334313268846, 
              c[ 50][ t]], 
            Times[ 0.75682672864065692, 
              c[ 51][ t]], 
            Times[ 0.67835603854706361, 
              c[ 52][ t]], 
            Times[ 0.59356153372868092, 
              c[ 53][ t]], 
            Times[ 0.50455115242710469, 
              c[ 54][ t]], 
            Times[ 0.41349667156634429, 
              c[ 55][ t]], 
            Times[ 0.32256865202152191, 
              c[ 56][ t]], 
            Times[ 0.23387232094715985, 
              c[ 57][ t]], 
            Times[ 0.14938649372796384, 
              c[ 58][ t]], 
            Times[ 0.070907514257658094, 
              c[ 59][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "46", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[46]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.009365143392520679`\)\ \(c[\(-60\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-59\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-58\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-57\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-56\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-55\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-54\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-53\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-52\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-51\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-50\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-49\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-48\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-47\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-46\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-45\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-44\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-43\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-42\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-41\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-40\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-39\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-38\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-37\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-36\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-35\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-34\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-33\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-32\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-31\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-30\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-29\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-28\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-27\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-26\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-25\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-24\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-23\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-22\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-21\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-20\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-19\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-18\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-17\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-16\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-15\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-14\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-13\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-12\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-11\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-10\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-9\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-8\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-7\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-6\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-5\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-4\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-3\)]\)[t] - 
            0.05846808023678991`\ \(c[\(-2\)]\)[t] - 
            0.04131966847794722`\ \(c[\(-1\)]\)[t] - 
            0.02158054781754788`\ \(c[0]\)[t] + 
            3.8981718325193755`*^-17\ \(c[1]\)[t] + 
            0.02256148180925487`\ \(c[2]\)[t] + 
            0.0451633585689193`\ \(c[3]\)[t] + 
            0.06682066312775997`\ \(c[4]\)[t] + 
            0.08654280907894489`\ \(c[5]\)[t] + 
            0.10337416789158609`\ \(c[6]\)[t] + 
            0.11643488132933186`\ \(c[7]\)[t] + 
            0.12496032289024853`\ \(c[8]\)[t] + 
            0.12833762891430928`\ \(c[9]\)[t] + 
            0.12613778810677614`\ \(c[10]\)[t] + 
            0.11814190616181255`\ \(c[11]\)[t] + 
            0.10436044624225685`\ \(c[12]\)[t] + 
            0.0850444803444217`\ \(c[13]\)[t] + 
            0.060688263076985105`\ \(c[14]\)[t] + 
            0.032022748374425904`\ \(c[15]\)[t] - 
            3.898171832519376`*^-17\ \(c[16]\)[t] - 
            0.03423121377955895`\ \(c[17]\)[t] - 
            0.06935801494512607`\ \(c[18]\)[t] - 
            0.10394325375429328`\ \(c[19]\)[t] - 
            0.13647135277833605`\ \(c[20]\)[t] - 
            0.1653986686265377`\ \(c[21]\)[t] - 
            0.18920668216016426`\ \(c[22]\)[t] - 
            0.20645618564475843`\ \(c[23]\)[t] - 
            0.21584055771952015`\ \(c[24]\)[t] - 
            0.21623620818304484`\ \(c[25]\)[t] - 
            0.206748335783172`\ \(c[26]\)[t] - 
            0.18675027222298593`\ \(c[27]\)[t] - 
            0.15591488063143982`\ \(c[28]\)[t] - 
            0.11423673049785436`\ \(c[29]\)[t] - 
            0.06204407497545024`\ \(c[30]\)[t] + 
            3.898171832519376`*^-17\ \(c[31]\)[t] + 
            0.07090751425765777`\ \(c[32]\)[t] + 
            0.14938649372796384`\ \(c[33]\)[t] + 
            0.23387232094715985`\ \(c[34]\)[t] + 
            0.3225686520215216`\ \(c[35]\)[t] + 
            0.4134966715663443`\ \(c[36]\)[t] + 
            0.5045511524271047`\ \(c[37]\)[t] + 
            0.5935615337286806`\ \(c[38]\)[t] + 
            0.6783560385470636`\ \(c[39]\)[t] + 
            0.7568267286406569`\ \(c[40]\)[t] + 
            0.826993343132688`\ \(c[41]\)[t] + 
            0.8870637930591839`\ \(c[42]\)[t] + 
            0.9354892837886392`\ \(c[43]\)[t] + 
            0.9710122092317629`\ \(c[44]\)[t] + 
            0.9927051996072069`\ \(c[45]\)[t] + 
            47.40907313934462`\ \(c[46]\)[t] + 
            0.9927051996072069`\ \(c[47]\)[t] + 
            0.9710122092317629`\ \(c[48]\)[t] + 
            0.9354892837886392`\ \(c[49]\)[t] + 
            0.8870637930591839`\ \(c[50]\)[t] + 
            0.826993343132688`\ \(c[51]\)[t] + 
            0.7568267286406569`\ \(c[52]\)[t] + 
            0.6783560385470636`\ \(c[53]\)[t] + 
            0.5935615337286801`\ \(c[54]\)[t] + 
            0.5045511524271047`\ \(c[55]\)[t] + 
            0.4134966715663443`\ \(c[56]\)[t] + 
            0.32256865202152113`\ \(c[57]\)[t] + 
            0.23387232094715985`\ \(c[58]\)[t] + 
            0.14938649372796384`\ \(c[59]\)[t] + 
            0.07090751425765746`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 46, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 46]][ t]], 
          Plus[ 
            Times[ -0.0093651433925206785, 
              c[ -60][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -59][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -58][ t]], 
            Times[ 0.018854606004500233, 
              c[ -57][ t]], 
            Times[ 0.027514390699665887, 
              c[ -56][ t]], 
            Times[ 0.035131239329076656, 
              c[ -55][ t]], 
            Times[ 0.041349667156634483, 
              c[ -54][ t]], 
            Times[ 0.045868286584282311, 
              c[ -53][ t]], 
            Times[ 0.048454002753361682, 
              c[ -52][ t]], 
            Times[ 0.04895352855494272, 
              c[ -51][ t]], 
            Times[ 0.047301670540041058, 
              c[ -50][ t]], 
            Times[ 0.043525965428036162, 
              c[ -49][ t]], 
            Times[ 0.03774739544932687, 
              c[ -48][ t]], 
            Times[ 0.030177073670601094, 
              c[ -47][ t]], 
            Times[ 0.021108961070255627, 
              c[ -46][ t]], 
            Times[ 0.010908848347331966, 
              c[ -45][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -44][ t]], 
            Times[ -0.011153991006822649, 
              c[ -43][ t]], 
            Times[ -0.022068459300722043, 
              c[ -42][ t]], 
            Times[ -0.032258251165125679, 
              c[ -41][ t]], 
            Times[ -0.041258781072520248, 
              c[ -40][ t]], 
            Times[ -0.048646667243099281, 
              c[ -39][ t]], 
            Times[ -0.054059052045761224, 
              c[ -38][ t]], 
            Times[ -0.057210750238908967, 
              c[ -37][ t]], 
            Times[ -0.057908442314993203, 
              c[ -36][ t]], 
            Times[ -0.056061239158567186, 
              c[ -35][ t]], 
            Times[ -0.05168708394579296, 
              c[ -34][ t]], 
            Times[ -0.044914622433376419, 
              c[ -33][ t]], 
            Times[ -0.035980357068793781, 
              c[ -32][ t]], 
            Times[ -0.025221096343682053, 
              c[ -31][ t]], 
            Times[ -0.013061910521147383, 
              c[ -30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -29][ t]], 
            Times[ 0.013414935129827233, 
              c[ -28][ t]], 
            Times[ 0.026603074225527826, 
              c[ -27][ t]], 
            Times[ 0.03897872015785999, 
              c[ -26][ t]], 
            Times[ 0.049975424961080865, 
              c[ -25][ t]], 
            Times[ 0.059070953080906326, 
              c[ -24][ t]], 
            Times[ 0.065811019881796273, 
              c[ -23][ t]], 
            Times[ 0.069830768673962415, 
              c[ -22][ t]], 
            Times[ 0.070873018952678238, 
              c[ -21][ t]], 
            Times[ 0.068802429876423349, 
              c[ -20][ t]], 
            Times[ 0.063614872548668253, 
              c[ -19][ t]], 
            Times[ 0.055441487066198933, 
              c[ -18][ t]], 
            Times[ 0.044547108751839919, 
              c[ -17][ t]], 
            Times[ 0.031322974491347078, 
              c[ -16][ t]], 
            Times[ 0.016273855731265604, 
              c[ -15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -14][ t]], 
            Times[ -0.016825511857749401, 
              c[ -13][ t]], 
            Times[ -0.033483179628681567, 
              c[ -12][ t]], 
            Times[ -0.049236278094138941, 
              c[ -11][ t]], 
            Times[ -0.063361699504227528, 
              c[ -10][ t]], 
            Times[ -0.075181213012062598, 
              c[ -9][ t]], 
            Times[ -0.084091858737850814, 
              c[ -8][ t]], 
            Times[ -0.089594193770366884, 
              c[ -7][ t]], 
            Times[ -0.091317159035181589, 
              c[ -6][ t]], 
            Times[ -0.089038438663606695, 
              c[ -5][ t]], 
            Times[ -0.082699334313268744, 
              c[ -4][ t]], 
            Times[ -0.072413370861974122, 
              c[ -3][ t]], 
            Times[ -0.058468080236789913, 
              c[ -2][ t]], 
            Times[ -0.04131966847794722, 
              c[ -1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 0][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 1][ t]], 
            Times[ 0.022561481809254869, 
              c[ 2][ t]], 
            Times[ 0.045163358568919301, 
              c[ 3][ t]], 
            Times[ 0.066820663127759972, 
              c[ 4][ t]], 
            Times[ 0.086542809078944891, 
              c[ 5][ t]], 
            Times[ 0.10337416789158609, 
              c[ 6][ t]], 
            Times[ 0.11643488132933186, 
              c[ 7][ t]], 
            Times[ 0.12496032289024853, 
              c[ 8][ t]], 
            Times[ 0.12833762891430928, 
              c[ 9][ t]], 
            Times[ 0.12613778810677614, 
              c[ 10][ t]], 
            Times[ 0.11814190616181255, 
              c[ 11][ t]], 
            Times[ 0.10436044624225685, 
              c[ 12][ t]], 
            Times[ 0.085044480344421705, 
              c[ 13][ t]], 
            Times[ 0.060688263076985105, 
              c[ 14][ t]], 
            Times[ 0.032022748374425904, 
              c[ 15][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 16][ t]], 
            Times[ -0.034231213779558949, 
              c[ 17][ t]], 
            Times[ -0.06935801494512607, 
              c[ 18][ t]], 
            Times[ -0.10394325375429328, 
              c[ 19][ t]], 
            Times[ -0.13647135277833605, 
              c[ 20][ t]], 
            Times[ -0.16539866862653771, 
              c[ 21][ t]], 
            Times[ -0.18920668216016426, 
              c[ 22][ t]], 
            Times[ -0.20645618564475843, 
              c[ 23][ t]], 
            Times[ -0.21584055771952015, 
              c[ 24][ t]], 
            Times[ -0.21623620818304484, 
              c[ 25][ t]], 
            Times[ -0.206748335783172, 
              c[ 26][ t]], 
            Times[ -0.18675027222298593, 
              c[ 27][ t]], 
            Times[ -0.15591488063143982, 
              c[ 28][ t]], 
            Times[ -0.11423673049785436, 
              c[ 29][ t]], 
            Times[ -0.062044074975450239, 
              c[ 30][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 31][ t]], 
            Times[ 0.070907514257657775, 
              c[ 32][ t]], 
            Times[ 0.14938649372796384, 
              c[ 33][ t]], 
            Times[ 0.23387232094715985, 
              c[ 34][ t]], 
            Times[ 0.32256865202152157, 
              c[ 35][ t]], 
            Times[ 0.41349667156634429, 
              c[ 36][ t]], 
            Times[ 0.50455115242710469, 
              c[ 37][ t]], 
            Times[ 0.59356153372868059, 
              c[ 38][ t]], 
            Times[ 0.67835603854706361, 
              c[ 39][ t]], 
            Times[ 0.75682672864065692, 
              c[ 40][ t]], 
            Times[ 0.82699334313268802, 
              c[ 41][ t]], 
            Times[ 0.88706379305918392, 
              c[ 42][ t]], 
            Times[ 0.93548928378863916, 
              c[ 43][ t]], 
            Times[ 0.9710122092317629, 
              c[ 44][ t]], 
            Times[ 0.99270519960720693, 
              c[ 45][ t]], 
            Times[ 47.409073139344621, 
              c[ 46][ t]], 
            Times[ 0.99270519960720693, 
              c[ 47][ t]], 
            Times[ 0.9710122092317629, 
              c[ 48][ t]], 
            Times[ 0.93548928378863916, 
              c[ 49][ t]], 
            Times[ 0.88706379305918392, 
              c[ 50][ t]], 
            Times[ 0.82699334313268802, 
              c[ 51][ t]], 
            Times[ 0.75682672864065692, 
              c[ 52][ t]], 
            Times[ 0.67835603854706361, 
              c[ 53][ t]], 
            Times[ 0.59356153372868015, 
              c[ 54][ t]], 
            Times[ 0.50455115242710469, 
              c[ 55][ t]], 
            Times[ 0.41349667156634429, 
              c[ 56][ t]], 
            Times[ 0.32256865202152113, 
              c[ 57][ t]], 
            Times[ 0.23387232094715985, 
              c[ 58][ t]], 
            Times[ 0.14938649372796384, 
              c[ 59][ t]], 
            Times[ 0.070907514257657456, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "47", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[47]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.018149760920219783`\)\ \(c[\(-60\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-59\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-58\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-57\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-56\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-55\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-54\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-53\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-52\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-51\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-50\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-49\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-48\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-47\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-46\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-45\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-44\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-43\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-42\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-41\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-40\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-39\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-38\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-37\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-36\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-35\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-34\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-33\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-32\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-31\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-30\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-29\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-28\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-27\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-26\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-25\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-24\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-23\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-22\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-21\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-20\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-19\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-18\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-17\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-16\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-15\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-14\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-13\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-12\)]\)[t] - 
            0.033483179628681706`\ \(c[\(-11\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-10\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-9\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-8\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-7\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-6\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-5\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-4\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-3\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-2\)]\)[t] - 
            0.058468080236789774`\ \(c[\(-1\)]\)[t] - 
            0.04131966847794722`\ \(c[0]\)[t] - 
            0.02158054781754788`\ \(c[1]\)[t] + 
            2.274590327822911`*^-16\ \(c[2]\)[t] + 
            0.02256148180925487`\ \(c[3]\)[t] + 
            0.0451633585689193`\ \(c[4]\)[t] + 
            0.06682066312776015`\ \(c[5]\)[t] + 
            0.08654280907894489`\ \(c[6]\)[t] + 
            0.10337416789158609`\ \(c[7]\)[t] + 
            0.11643488132933195`\ \(c[8]\)[t] + 
            0.12496032289024853`\ \(c[9]\)[t] + 
            0.12833762891430928`\ \(c[10]\)[t] + 
            0.12613778810677612`\ \(c[11]\)[t] + 
            0.11814190616181253`\ \(c[12]\)[t] + 
            0.10436044624225685`\ \(c[13]\)[t] + 
            0.08504448034442161`\ \(c[14]\)[t] + 
            0.060688263076985`\ \(c[15]\)[t] + 
            0.032022748374425904`\ \(c[16]\)[t] - 
            1.8033970416801674`*^-16\ \(c[17]\)[t] - 
            0.034231213779559094`\ \(c[18]\)[t] - 
            0.06935801494512607`\ \(c[19]\)[t] - 
            0.1039432537542934`\ \(c[20]\)[t] - 
            0.13647135277833616`\ \(c[21]\)[t] - 
            0.1653986686265377`\ \(c[22]\)[t] - 
            0.18920668216016434`\ \(c[23]\)[t] - 
            0.20645618564475848`\ \(c[24]\)[t] - 
            0.21584055771952015`\ \(c[25]\)[t] - 
            0.21623620818304481`\ \(c[26]\)[t] - 
            0.2067483357831719`\ \(c[27]\)[t] - 
            0.18675027222298593`\ \(c[28]\)[t] - 
            0.15591488063143966`\ \(c[29]\)[t] - 
            0.11423673049785416`\ \(c[30]\)[t] - 
            0.06204407497545024`\ \(c[31]\)[t] + 
            3.216976900108398`*^-16\ \(c[32]\)[t] + 
            0.0709075142576581`\ \(c[33]\)[t] + 
            0.14938649372796384`\ \(c[34]\)[t] + 
            0.23387232094716018`\ \(c[35]\)[t] + 
            0.3225686520215219`\ \(c[36]\)[t] + 
            0.4134966715663443`\ \(c[37]\)[t] + 
            0.504551152427105`\ \(c[38]\)[t] + 
            0.5935615337286809`\ \(c[39]\)[t] + 
            0.6783560385470636`\ \(c[40]\)[t] + 
            0.7568267286406569`\ \(c[41]\)[t] + 
            0.8269933431326885`\ \(c[42]\)[t] + 
            0.8870637930591839`\ \(c[43]\)[t] + 
            0.9354892837886392`\ \(c[44]\)[t] + 
            0.9710122092317629`\ \(c[45]\)[t] + 
            0.9927051996072069`\ \(c[46]\)[t] + 
            49.448791382236415`\ \(c[47]\)[t] + 
            0.9927051996072067`\ \(c[48]\)[t] + 
            0.9710122092317629`\ \(c[49]\)[t] + 
            0.9354892837886392`\ \(c[50]\)[t] + 
            0.8870637930591835`\ \(c[51]\)[t] + 
            0.826993343132688`\ \(c[52]\)[t] + 
            0.7568267286406569`\ \(c[53]\)[t] + 
            0.6783560385470627`\ \(c[54]\)[t] + 
            0.5935615337286801`\ \(c[55]\)[t] + 
            0.5045511524271047`\ \(c[56]\)[t] + 
            0.4134966715663436`\ \(c[57]\)[t] + 
            0.32256865202152113`\ \(c[58]\)[t] + 
            0.23387232094715985`\ \(c[59]\)[t] + 
            0.14938649372796314`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 47, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 47]][ t]], 
          Plus[ 
            Times[ -0.018149760920219783, 
              c[ -60][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -59][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -58][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -57][ t]], 
            Times[ 0.018854606004500389, 
              c[ -56][ t]], 
            Times[ 0.027514390699665887, 
              c[ -55][ t]], 
            Times[ 0.035131239329076656, 
              c[ -54][ t]], 
            Times[ 0.041349667156634483, 
              c[ -53][ t]], 
            Times[ 0.045868286584282311, 
              c[ -52][ t]], 
            Times[ 0.048454002753361682, 
              c[ -51][ t]], 
            Times[ 0.048953528554942699, 
              c[ -50][ t]], 
            Times[ 0.047301670540041058, 
              c[ -49][ t]], 
            Times[ 0.043525965428036162, 
              c[ -48][ t]], 
            Times[ 0.03774739544932687, 
              c[ -47][ t]], 
            Times[ 0.030177073670601094, 
              c[ -46][ t]], 
            Times[ 0.021108961070255627, 
              c[ -45][ t]], 
            Times[ 0.010908848347331785, 
              c[ -44][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -43][ t]], 
            Times[ -0.011153991006822649, 
              c[ -42][ t]], 
            Times[ -0.022068459300722043, 
              c[ -41][ t]], 
            Times[ -0.032258251165125679, 
              c[ -40][ t]], 
            Times[ -0.041258781072520248, 
              c[ -39][ t]], 
            Times[ -0.048646667243099399, 
              c[ -38][ t]], 
            Times[ -0.054059052045761224, 
              c[ -37][ t]], 
            Times[ -0.057210750238908967, 
              c[ -36][ t]], 
            Times[ -0.057908442314993203, 
              c[ -35][ t]], 
            Times[ -0.05606123915856713, 
              c[ -34][ t]], 
            Times[ -0.05168708394579296, 
              c[ -33][ t]], 
            Times[ -0.044914622433376288, 
              c[ -32][ t]], 
            Times[ -0.035980357068793781, 
              c[ -31][ t]], 
            Times[ -0.025221096343682053, 
              c[ -30][ t]], 
            Times[ -0.013061910521147276, 
              c[ -29][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -28][ t]], 
            Times[ 0.013414935129827233, 
              c[ -27][ t]], 
            Times[ 0.026603074225527937, 
              c[ -26][ t]], 
            Times[ 0.038978720157860088, 
              c[ -25][ t]], 
            Times[ 0.049975424961080865, 
              c[ -24][ t]], 
            Times[ 0.059070953080906402, 
              c[ -23][ t]], 
            Times[ 0.065811019881796315, 
              c[ -22][ t]], 
            Times[ 0.069830768673962415, 
              c[ -21][ t]], 
            Times[ 0.070873018952678238, 
              c[ -20][ t]], 
            Times[ 0.068802429876423321, 
              c[ -19][ t]], 
            Times[ 0.063614872548668253, 
              c[ -18][ t]], 
            Times[ 0.055441487066198857, 
              c[ -17][ t]], 
            Times[ 0.044547108751839815, 
              c[ -16][ t]], 
            Times[ 0.031322974491347078, 
              c[ -15][ t]], 
            Times[ 0.016273855731265469, 
              c[ -14][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -13][ t]], 
            Times[ -0.016825511857749401, 
              c[ -12][ t]], 
            Times[ -0.033483179628681706, 
              c[ -11][ t]], 
            Times[ -0.049236278094139066, 
              c[ -10][ t]], 
            Times[ -0.063361699504227528, 
              c[ -9][ t]], 
            Times[ -0.075181213012062598, 
              c[ -8][ t]], 
            Times[ -0.084091858737850855, 
              c[ -7][ t]], 
            Times[ -0.089594193770366884, 
              c[ -6][ t]], 
            Times[ -0.091317159035181589, 
              c[ -5][ t]], 
            Times[ -0.089038438663606653, 
              c[ -4][ t]], 
            Times[ -0.082699334313268744, 
              c[ -3][ t]], 
            Times[ -0.072413370861974122, 
              c[ -2][ t]], 
            Times[ -0.058468080236789774, 
              c[ -1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 0][ t]], 
            Times[ -0.021580547817547879, 
              c[ 1][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 2][ t]], 
            Times[ 0.022561481809254869, 
              c[ 3][ t]], 
            Times[ 0.045163358568919301, 
              c[ 4][ t]], 
            Times[ 0.066820663127760152, 
              c[ 5][ t]], 
            Times[ 0.086542809078944891, 
              c[ 6][ t]], 
            Times[ 0.10337416789158609, 
              c[ 7][ t]], 
            Times[ 0.11643488132933195, 
              c[ 8][ t]], 
            Times[ 0.12496032289024853, 
              c[ 9][ t]], 
            Times[ 0.12833762891430928, 
              c[ 10][ t]], 
            Times[ 0.12613778810677612, 
              c[ 11][ t]], 
            Times[ 0.11814190616181253, 
              c[ 12][ t]], 
            Times[ 0.10436044624225685, 
              c[ 13][ t]], 
            Times[ 0.085044480344421608, 
              c[ 14][ t]], 
            Times[ 0.060688263076985001, 
              c[ 15][ t]], 
            Times[ 0.032022748374425904, 
              c[ 16][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 17][ t]], 
            Times[ -0.034231213779559094, 
              c[ 18][ t]], 
            Times[ -0.06935801494512607, 
              c[ 19][ t]], 
            Times[ -0.1039432537542934, 
              c[ 20][ t]], 
            Times[ -0.13647135277833616, 
              c[ 21][ t]], 
            Times[ -0.16539866862653771, 
              c[ 22][ t]], 
            Times[ -0.18920668216016434, 
              c[ 23][ t]], 
            Times[ -0.20645618564475848, 
              c[ 24][ t]], 
            Times[ -0.21584055771952015, 
              c[ 25][ t]], 
            Times[ -0.21623620818304481, 
              c[ 26][ t]], 
            Times[ -0.20674833578317189, 
              c[ 27][ t]], 
            Times[ -0.18675027222298593, 
              c[ 28][ t]], 
            Times[ -0.15591488063143966, 
              c[ 29][ t]], 
            Times[ -0.11423673049785416, 
              c[ 30][ t]], 
            Times[ -0.062044074975450239, 
              c[ 31][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 32][ t]], 
            Times[ 0.070907514257658094, 
              c[ 33][ t]], 
            Times[ 0.14938649372796384, 
              c[ 34][ t]], 
            Times[ 0.23387232094716018, 
              c[ 35][ t]], 
            Times[ 0.32256865202152191, 
              c[ 36][ t]], 
            Times[ 0.41349667156634429, 
              c[ 37][ t]], 
            Times[ 0.50455115242710502, 
              c[ 38][ t]], 
            Times[ 0.59356153372868092, 
              c[ 39][ t]], 
            Times[ 0.67835603854706361, 
              c[ 40][ t]], 
            Times[ 0.75682672864065692, 
              c[ 41][ t]], 
            Times[ 0.82699334313268846, 
              c[ 42][ t]], 
            Times[ 0.88706379305918392, 
              c[ 43][ t]], 
            Times[ 0.93548928378863916, 
              c[ 44][ t]], 
            Times[ 0.9710122092317629, 
              c[ 45][ t]], 
            Times[ 0.99270519960720693, 
              c[ 46][ t]], 
            Times[ 49.448791382236415, 
              c[ 47][ t]], 
            Times[ 0.99270519960720671, 
              c[ 48][ t]], 
            Times[ 0.9710122092317629, 
              c[ 49][ t]], 
            Times[ 0.93548928378863916, 
              c[ 50][ t]], 
            Times[ 0.88706379305918348, 
              c[ 51][ t]], 
            Times[ 0.82699334313268802, 
              c[ 52][ t]], 
            Times[ 0.75682672864065692, 
              c[ 53][ t]], 
            Times[ 0.67835603854706272, 
              c[ 54][ t]], 
            Times[ 0.59356153372868015, 
              c[ 55][ t]], 
            Times[ 0.50455115242710469, 
              c[ 56][ t]], 
            Times[ 0.41349667156634362, 
              c[ 57][ t]], 
            Times[ 0.32256865202152113, 
              c[ 58][ t]], 
            Times[ 0.23387232094715985, 
              c[ 59][ t]], 
            Times[ 0.14938649372796314, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "48", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[48]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.02598581343857328`\)\ \(c[\(-60\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-59\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-58\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-57\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-56\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-55\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-54\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-53\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-52\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-51\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-50\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-49\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-48\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-47\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-46\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-45\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-44\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-43\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-42\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-41\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-40\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-39\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-38\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-37\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-36\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-35\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-34\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-33\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-32\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-31\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-30\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-29\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-28\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-27\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-26\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-25\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-24\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-23\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-22\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-21\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-20\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-19\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-18\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-17\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-16\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-15\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-14\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-13\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-12\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-11\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-10\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-9\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-8\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-7\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-6\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-5\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-4\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-3\)]\)[t] - 
            0.08269933431326881`\ \(c[\(-2\)]\)[t] - 
            0.07241337086197412`\ \(c[\(-1\)]\)[t] - 
            0.05846808023678991`\ \(c[0]\)[t] - 
            0.04131966847794737`\ \(c[1]\)[t] - 
            0.02158054781754788`\ \(c[2]\)[t] + 
            3.8981718325193755`*^-17\ \(c[3]\)[t] + 
            0.022561481809254675`\ \(c[4]\)[t] + 
            0.0451633585689193`\ \(c[5]\)[t] + 
            0.06682066312775997`\ \(c[6]\)[t] + 
            0.08654280907894475`\ \(c[7]\)[t] + 
            0.10337416789158609`\ \(c[8]\)[t] + 
            0.11643488132933186`\ \(c[9]\)[t] + 
            0.12496032289024847`\ \(c[10]\)[t] + 
            0.12833762891430925`\ \(c[11]\)[t] + 
            0.12613778810677614`\ \(c[12]\)[t] + 
            0.1181419061618126`\ \(c[13]\)[t] + 
            0.10436044624225692`\ \(c[14]\)[t] + 
            0.0850444803444217`\ \(c[15]\)[t] + 
            0.06068826307698522`\ \(c[16]\)[t] + 
            0.03202274837442603`\ \(c[17]\)[t] - 
            3.898171832519376`*^-17\ \(c[18]\)[t] - 
            0.034231213779558796`\ \(c[19]\)[t] - 
            0.06935801494512592`\ \(c[20]\)[t] - 
            0.10394325375429328`\ \(c[21]\)[t] - 
            0.1364713527783359`\ \(c[22]\)[t] - 
            0.1653986686265376`\ \(c[23]\)[t] - 
            0.18920668216016426`\ \(c[24]\)[t] - 
            0.20645618564475834`\ \(c[25]\)[t] - 
            0.21584055771952013`\ \(c[26]\)[t] - 
            0.21623620818304484`\ \(c[27]\)[t] - 
            0.20674833578317206`\ \(c[28]\)[t] - 
            0.18675027222298607`\ \(c[29]\)[t] - 
            0.15591488063143982`\ \(c[30]\)[t] - 
            0.11423673049785459`\ \(c[31]\)[t] - 
            0.062044074975450475`\ \(c[32]\)[t] + 
            3.898171832519376`*^-17\ \(c[33]\)[t] + 
            0.07090751425765746`\ \(c[34]\)[t] + 
            0.14938649372796345`\ \(c[35]\)[t] + 
            0.23387232094715985`\ \(c[36]\)[t] + 
            0.32256865202152113`\ \(c[37]\)[t] + 
            0.41349667156634395`\ \(c[38]\)[t] + 
            0.5045511524271047`\ \(c[39]\)[t] + 
            0.5935615337286801`\ \(c[40]\)[t] + 
            0.6783560385470627`\ \(c[41]\)[t] + 
            0.7568267286406569`\ \(c[42]\)[t] + 
            0.826993343132688`\ \(c[43]\)[t] + 
            0.8870637930591835`\ \(c[44]\)[t] + 
            0.9354892837886392`\ \(c[45]\)[t] + 
            0.9710122092317629`\ \(c[46]\)[t] + 
            0.9927051996072067`\ \(c[47]\)[t] + 
            51.53237453357751`\ \(c[48]\)[t] + 
            0.9927051996072069`\ \(c[49]\)[t] + 
            0.9710122092317629`\ \(c[50]\)[t] + 
            0.9354892837886392`\ \(c[51]\)[t] + 
            0.8870637930591839`\ \(c[52]\)[t] + 
            0.8269933431326885`\ \(c[53]\)[t] + 
            0.7568267286406569`\ \(c[54]\)[t] + 
            0.6783560385470636`\ \(c[55]\)[t] + 
            0.5935615337286809`\ \(c[56]\)[t] + 
            0.5045511524271047`\ \(c[57]\)[t] + 
            0.4134966715663443`\ \(c[58]\)[t] + 
            0.3225686520215219`\ \(c[59]\)[t] + 
            0.23387232094715985`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 48, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 48]][ t]], 
          Plus[ 
            Times[ -0.025985813438573278, 
              c[ -60][ t]], 
            Times[ -0.018149760920219783, 
              c[ -59][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -58][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -57][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -56][ t]], 
            Times[ 0.018854606004500233, 
              c[ -55][ t]], 
            Times[ 0.027514390699665887, 
              c[ -54][ t]], 
            Times[ 0.035131239329076656, 
              c[ -53][ t]], 
            Times[ 0.041349667156634483, 
              c[ -52][ t]], 
            Times[ 0.045868286584282256, 
              c[ -51][ t]], 
            Times[ 0.048454002753361682, 
              c[ -50][ t]], 
            Times[ 0.04895352855494272, 
              c[ -49][ t]], 
            Times[ 0.047301670540041058, 
              c[ -48][ t]], 
            Times[ 0.043525965428036162, 
              c[ -47][ t]], 
            Times[ 0.03774739544932687, 
              c[ -46][ t]], 
            Times[ 0.030177073670601236, 
              c[ -45][ t]], 
            Times[ 0.021108961070255627, 
              c[ -44][ t]], 
            Times[ 0.010908848347331966, 
              c[ -43][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -42][ t]], 
            Times[ -0.011153991006822649, 
              c[ -41][ t]], 
            Times[ -0.022068459300722043, 
              c[ -40][ t]], 
            Times[ -0.032258251165125519, 
              c[ -39][ t]], 
            Times[ -0.041258781072520248, 
              c[ -38][ t]], 
            Times[ -0.048646667243099281, 
              c[ -37][ t]], 
            Times[ -0.054059052045761224, 
              c[ -36][ t]], 
            Times[ -0.057210750238908967, 
              c[ -35][ t]], 
            Times[ -0.057908442314993203, 
              c[ -34][ t]], 
            Times[ -0.056061239158567186, 
              c[ -33][ t]], 
            Times[ -0.05168708394579296, 
              c[ -32][ t]], 
            Times[ -0.044914622433376419, 
              c[ -31][ t]], 
            Times[ -0.035980357068793781, 
              c[ -30][ t]], 
            Times[ -0.025221096343682053, 
              c[ -29][ t]], 
            Times[ -0.013061910521147383, 
              c[ -28][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -27][ t]], 
            Times[ 0.013414935129827233, 
              c[ -26][ t]], 
            Times[ 0.026603074225527826, 
              c[ -25][ t]], 
            Times[ 0.03897872015785999, 
              c[ -24][ t]], 
            Times[ 0.049975424961080865, 
              c[ -23][ t]], 
            Times[ 0.059070953080906326, 
              c[ -22][ t]], 
            Times[ 0.065811019881796273, 
              c[ -21][ t]], 
            Times[ 0.069830768673962415, 
              c[ -20][ t]], 
            Times[ 0.070873018952678238, 
              c[ -19][ t]], 
            Times[ 0.068802429876423349, 
              c[ -18][ t]], 
            Times[ 0.063614872548668253, 
              c[ -17][ t]], 
            Times[ 0.055441487066198933, 
              c[ -16][ t]], 
            Times[ 0.044547108751839919, 
              c[ -15][ t]], 
            Times[ 0.031322974491347078, 
              c[ -14][ t]], 
            Times[ 0.016273855731265604, 
              c[ -13][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -12][ t]], 
            Times[ -0.016825511857749401, 
              c[ -11][ t]], 
            Times[ -0.033483179628681567, 
              c[ -10][ t]], 
            Times[ -0.049236278094138941, 
              c[ -9][ t]], 
            Times[ -0.063361699504227403, 
              c[ -8][ t]], 
            Times[ -0.075181213012062598, 
              c[ -7][ t]], 
            Times[ -0.084091858737850814, 
              c[ -6][ t]], 
            Times[ -0.089594193770366842, 
              c[ -5][ t]], 
            Times[ -0.091317159035181589, 
              c[ -4][ t]], 
            Times[ -0.089038438663606695, 
              c[ -3][ t]], 
            Times[ -0.082699334313268813, 
              c[ -2][ t]], 
            Times[ -0.072413370861974122, 
              c[ -1][ t]], 
            Times[ -0.058468080236789913, 
              c[ 0][ t]], 
            Times[ -0.041319668477947373, 
              c[ 1][ t]], 
            Times[ -0.021580547817547879, 
              c[ 2][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 3][ t]], 
            Times[ 0.022561481809254675, 
              c[ 4][ t]], 
            Times[ 0.045163358568919301, 
              c[ 5][ t]], 
            Times[ 0.066820663127759972, 
              c[ 6][ t]], 
            Times[ 0.086542809078944752, 
              c[ 7][ t]], 
            Times[ 0.10337416789158609, 
              c[ 8][ t]], 
            Times[ 0.11643488132933186, 
              c[ 9][ t]], 
            Times[ 0.12496032289024847, 
              c[ 10][ t]], 
            Times[ 0.12833762891430925, 
              c[ 11][ t]], 
            Times[ 0.12613778810677614, 
              c[ 12][ t]], 
            Times[ 0.1181419061618126, 
              c[ 13][ t]], 
            Times[ 0.10436044624225692, 
              c[ 14][ t]], 
            Times[ 0.085044480344421705, 
              c[ 15][ t]], 
            Times[ 0.060688263076985223, 
              c[ 16][ t]], 
            Times[ 0.032022748374426029, 
              c[ 17][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 18][ t]], 
            Times[ -0.034231213779558796, 
              c[ 19][ t]], 
            Times[ -0.069358014945125918, 
              c[ 20][ t]], 
            Times[ -0.10394325375429328, 
              c[ 21][ t]], 
            Times[ -0.13647135277833591, 
              c[ 22][ t]], 
            Times[ -0.1653986686265376, 
              c[ 23][ t]], 
            Times[ -0.18920668216016426, 
              c[ 24][ t]], 
            Times[ -0.20645618564475834, 
              c[ 25][ t]], 
            Times[ -0.21584055771952013, 
              c[ 26][ t]], 
            Times[ -0.21623620818304484, 
              c[ 27][ t]], 
            Times[ -0.20674833578317206, 
              c[ 28][ t]], 
            Times[ -0.18675027222298607, 
              c[ 29][ t]], 
            Times[ -0.15591488063143982, 
              c[ 30][ t]], 
            Times[ -0.11423673049785459, 
              c[ 31][ t]], 
            Times[ -0.062044074975450475, 
              c[ 32][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 33][ t]], 
            Times[ 0.070907514257657456, 
              c[ 34][ t]], 
            Times[ 0.14938649372796345, 
              c[ 35][ t]], 
            Times[ 0.23387232094715985, 
              c[ 36][ t]], 
            Times[ 0.32256865202152113, 
              c[ 37][ t]], 
            Times[ 0.41349667156634395, 
              c[ 38][ t]], 
            Times[ 0.50455115242710469, 
              c[ 39][ t]], 
            Times[ 0.59356153372868015, 
              c[ 40][ t]], 
            Times[ 0.67835603854706272, 
              c[ 41][ t]], 
            Times[ 0.75682672864065692, 
              c[ 42][ t]], 
            Times[ 0.82699334313268802, 
              c[ 43][ t]], 
            Times[ 0.88706379305918348, 
              c[ 44][ t]], 
            Times[ 0.93548928378863916, 
              c[ 45][ t]], 
            Times[ 0.9710122092317629, 
              c[ 46][ t]], 
            Times[ 0.99270519960720671, 
              c[ 47][ t]], 
            Times[ 51.53237453357751, 
              c[ 48][ t]], 
            Times[ 0.99270519960720693, 
              c[ 49][ t]], 
            Times[ 0.9710122092317629, 
              c[ 50][ t]], 
            Times[ 0.93548928378863916, 
              c[ 51][ t]], 
            Times[ 0.88706379305918392, 
              c[ 52][ t]], 
            Times[ 0.82699334313268846, 
              c[ 53][ t]], 
            Times[ 0.75682672864065692, 
              c[ 54][ t]], 
            Times[ 0.67835603854706361, 
              c[ 55][ t]], 
            Times[ 0.59356153372868092, 
              c[ 56][ t]], 
            Times[ 0.50455115242710469, 
              c[ 57][ t]], 
            Times[ 0.41349667156634429, 
              c[ 58][ t]], 
            Times[ 0.32256865202152191, 
              c[ 59][ t]], 
            Times[ 0.23387232094715985, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "49", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[49]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.032552799745291155`\)\ \(c[\(-60\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-59\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-58\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-57\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-56\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-55\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-54\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-53\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-52\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-51\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-50\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-49\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-48\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-47\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-46\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-45\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-44\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-43\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-42\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-41\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-40\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-39\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-38\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-37\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-36\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-35\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-34\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-33\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-32\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-31\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-30\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-29\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-28\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-27\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-26\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-25\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-24\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-23\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-22\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-21\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-20\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-19\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-18\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-17\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-16\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-15\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-14\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-13\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-12\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-11\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-10\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-9\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-8\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-7\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-6\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-5\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-4\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-3\)]\)[t] - 
            0.0890384386636067`\ \(c[\(-2\)]\)[t] - 
            0.08269933431326874`\ \(c[\(-1\)]\)[t] - 
            0.07241337086197412`\ \(c[0]\)[t] - 
            0.05846808023678991`\ \(c[1]\)[t] - 
            0.04131966847794722`\ \(c[2]\)[t] - 
            0.02158054781754788`\ \(c[3]\)[t] + 
            3.8981718325193755`*^-17\ \(c[4]\)[t] + 
            0.02256148180925487`\ \(c[5]\)[t] + 
            0.0451633585689193`\ \(c[6]\)[t] + 
            0.06682066312775997`\ \(c[7]\)[t] + 
            0.08654280907894489`\ \(c[8]\)[t] + 
            0.10337416789158609`\ \(c[9]\)[t] + 
            0.11643488132933186`\ \(c[10]\)[t] + 
            0.12496032289024853`\ \(c[11]\)[t] + 
            0.12833762891430928`\ \(c[12]\)[t] + 
            0.12613778810677614`\ \(c[13]\)[t] + 
            0.11814190616181255`\ \(c[14]\)[t] + 
            0.10436044624225685`\ \(c[15]\)[t] + 
            0.0850444803444217`\ \(c[16]\)[t] + 
            0.060688263076985105`\ \(c[17]\)[t] + 
            0.032022748374425904`\ \(c[18]\)[t] - 
            3.898171832519376`*^-17\ \(c[19]\)[t] - 
            0.03423121377955895`\ \(c[20]\)[t] - 
            0.06935801494512607`\ \(c[21]\)[t] - 
            0.10394325375429328`\ \(c[22]\)[t] - 
            0.13647135277833605`\ \(c[23]\)[t] - 
            0.1653986686265377`\ \(c[24]\)[t] - 
            0.18920668216016426`\ \(c[25]\)[t] - 
            0.20645618564475843`\ \(c[26]\)[t] - 
            0.21584055771952015`\ \(c[27]\)[t] - 
            0.21623620818304484`\ \(c[28]\)[t] - 
            0.206748335783172`\ \(c[29]\)[t] - 
            0.18675027222298593`\ \(c[30]\)[t] - 
            0.15591488063143982`\ \(c[31]\)[t] - 
            0.11423673049785436`\ \(c[32]\)[t] - 
            0.06204407497545024`\ \(c[33]\)[t] + 
            3.898171832519376`*^-17\ \(c[34]\)[t] + 
            0.07090751425765777`\ \(c[35]\)[t] + 
            0.14938649372796384`\ \(c[36]\)[t] + 
            0.23387232094715985`\ \(c[37]\)[t] + 
            0.3225686520215216`\ \(c[38]\)[t] + 
            0.4134966715663443`\ \(c[39]\)[t] + 
            0.5045511524271047`\ \(c[40]\)[t] + 
            0.5935615337286801`\ \(c[41]\)[t] + 
            0.6783560385470636`\ \(c[42]\)[t] + 
            0.7568267286406569`\ \(c[43]\)[t] + 
            0.826993343132688`\ \(c[44]\)[t] + 
            0.8870637930591839`\ \(c[45]\)[t] + 
            0.9354892837886392`\ \(c[46]\)[t] + 
            0.9710122092317629`\ \(c[47]\)[t] + 
            0.9927051996072069`\ \(c[48]\)[t] + 
            53.65982259336788`\ \(c[49]\)[t] + 
            0.9927051996072069`\ \(c[50]\)[t] + 
            0.9710122092317629`\ \(c[51]\)[t] + 
            0.9354892837886392`\ \(c[52]\)[t] + 
            0.8870637930591839`\ \(c[53]\)[t] + 
            0.826993343132688`\ \(c[54]\)[t] + 
            0.7568267286406569`\ \(c[55]\)[t] + 
            0.6783560385470636`\ \(c[56]\)[t] + 
            0.5935615337286801`\ \(c[57]\)[t] + 
            0.5045511524271047`\ \(c[58]\)[t] + 
            0.4134966715663443`\ \(c[59]\)[t] + 
            0.32256865202152113`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 49, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 49]][ t]], 
          Plus[ 
            Times[ -0.032552799745291155, 
              c[ -60][ t]], 
            Times[ -0.025985813438573278, 
              c[ -59][ t]], 
            Times[ -0.018149760920219783, 
              c[ -58][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -57][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -56][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -55][ t]], 
            Times[ 0.018854606004500233, 
              c[ -54][ t]], 
            Times[ 0.027514390699665887, 
              c[ -53][ t]], 
            Times[ 0.035131239329076656, 
              c[ -52][ t]], 
            Times[ 0.041349667156634483, 
              c[ -51][ t]], 
            Times[ 0.045868286584282311, 
              c[ -50][ t]], 
            Times[ 0.048454002753361682, 
              c[ -49][ t]], 
            Times[ 0.04895352855494272, 
              c[ -48][ t]], 
            Times[ 0.047301670540041058, 
              c[ -47][ t]], 
            Times[ 0.043525965428036162, 
              c[ -46][ t]], 
            Times[ 0.03774739544932687, 
              c[ -45][ t]], 
            Times[ 0.030177073670601094, 
              c[ -44][ t]], 
            Times[ 0.021108961070255627, 
              c[ -43][ t]], 
            Times[ 0.010908848347331966, 
              c[ -42][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -41][ t]], 
            Times[ -0.011153991006822649, 
              c[ -40][ t]], 
            Times[ -0.022068459300722043, 
              c[ -39][ t]], 
            Times[ -0.032258251165125519, 
              c[ -38][ t]], 
            Times[ -0.041258781072520248, 
              c[ -37][ t]], 
            Times[ -0.048646667243099281, 
              c[ -36][ t]], 
            Times[ -0.054059052045761224, 
              c[ -35][ t]], 
            Times[ -0.057210750238908967, 
              c[ -34][ t]], 
            Times[ -0.057908442314993203, 
              c[ -33][ t]], 
            Times[ -0.056061239158567186, 
              c[ -32][ t]], 
            Times[ -0.05168708394579296, 
              c[ -31][ t]], 
            Times[ -0.044914622433376419, 
              c[ -30][ t]], 
            Times[ -0.035980357068793781, 
              c[ -29][ t]], 
            Times[ -0.025221096343682053, 
              c[ -28][ t]], 
            Times[ -0.013061910521147383, 
              c[ -27][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -26][ t]], 
            Times[ 0.013414935129827233, 
              c[ -25][ t]], 
            Times[ 0.026603074225527826, 
              c[ -24][ t]], 
            Times[ 0.03897872015785999, 
              c[ -23][ t]], 
            Times[ 0.049975424961080865, 
              c[ -22][ t]], 
            Times[ 0.059070953080906326, 
              c[ -21][ t]], 
            Times[ 0.065811019881796273, 
              c[ -20][ t]], 
            Times[ 0.069830768673962415, 
              c[ -19][ t]], 
            Times[ 0.070873018952678238, 
              c[ -18][ t]], 
            Times[ 0.068802429876423349, 
              c[ -17][ t]], 
            Times[ 0.063614872548668253, 
              c[ -16][ t]], 
            Times[ 0.055441487066198933, 
              c[ -15][ t]], 
            Times[ 0.044547108751839919, 
              c[ -14][ t]], 
            Times[ 0.031322974491347078, 
              c[ -13][ t]], 
            Times[ 0.016273855731265604, 
              c[ -12][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -11][ t]], 
            Times[ -0.016825511857749401, 
              c[ -10][ t]], 
            Times[ -0.033483179628681567, 
              c[ -9][ t]], 
            Times[ -0.049236278094138941, 
              c[ -8][ t]], 
            Times[ -0.063361699504227528, 
              c[ -7][ t]], 
            Times[ -0.075181213012062598, 
              c[ -6][ t]], 
            Times[ -0.084091858737850814, 
              c[ -5][ t]], 
            Times[ -0.089594193770366884, 
              c[ -4][ t]], 
            Times[ -0.091317159035181589, 
              c[ -3][ t]], 
            Times[ -0.089038438663606695, 
              c[ -2][ t]], 
            Times[ -0.082699334313268744, 
              c[ -1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 0][ t]], 
            Times[ -0.058468080236789913, 
              c[ 1][ t]], 
            Times[ -0.04131966847794722, 
              c[ 2][ t]], 
            Times[ -0.021580547817547879, 
              c[ 3][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 4][ t]], 
            Times[ 0.022561481809254869, 
              c[ 5][ t]], 
            Times[ 0.045163358568919301, 
              c[ 6][ t]], 
            Times[ 0.066820663127759972, 
              c[ 7][ t]], 
            Times[ 0.086542809078944891, 
              c[ 8][ t]], 
            Times[ 0.10337416789158609, 
              c[ 9][ t]], 
            Times[ 0.11643488132933186, 
              c[ 10][ t]], 
            Times[ 0.12496032289024853, 
              c[ 11][ t]], 
            Times[ 0.12833762891430928, 
              c[ 12][ t]], 
            Times[ 0.12613778810677614, 
              c[ 13][ t]], 
            Times[ 0.11814190616181255, 
              c[ 14][ t]], 
            Times[ 0.10436044624225685, 
              c[ 15][ t]], 
            Times[ 0.085044480344421705, 
              c[ 16][ t]], 
            Times[ 0.060688263076985105, 
              c[ 17][ t]], 
            Times[ 0.032022748374425904, 
              c[ 18][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 19][ t]], 
            Times[ -0.034231213779558949, 
              c[ 20][ t]], 
            Times[ -0.06935801494512607, 
              c[ 21][ t]], 
            Times[ -0.10394325375429328, 
              c[ 22][ t]], 
            Times[ -0.13647135277833605, 
              c[ 23][ t]], 
            Times[ -0.16539866862653771, 
              c[ 24][ t]], 
            Times[ -0.18920668216016426, 
              c[ 25][ t]], 
            Times[ -0.20645618564475843, 
              c[ 26][ t]], 
            Times[ -0.21584055771952015, 
              c[ 27][ t]], 
            Times[ -0.21623620818304484, 
              c[ 28][ t]], 
            Times[ -0.206748335783172, 
              c[ 29][ t]], 
            Times[ -0.18675027222298593, 
              c[ 30][ t]], 
            Times[ -0.15591488063143982, 
              c[ 31][ t]], 
            Times[ -0.11423673049785436, 
              c[ 32][ t]], 
            Times[ -0.062044074975450239, 
              c[ 33][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 34][ t]], 
            Times[ 0.070907514257657775, 
              c[ 35][ t]], 
            Times[ 0.14938649372796384, 
              c[ 36][ t]], 
            Times[ 0.23387232094715985, 
              c[ 37][ t]], 
            Times[ 0.32256865202152157, 
              c[ 38][ t]], 
            Times[ 0.41349667156634429, 
              c[ 39][ t]], 
            Times[ 0.50455115242710469, 
              c[ 40][ t]], 
            Times[ 0.59356153372868015, 
              c[ 41][ t]], 
            Times[ 0.67835603854706361, 
              c[ 42][ t]], 
            Times[ 0.75682672864065692, 
              c[ 43][ t]], 
            Times[ 0.82699334313268802, 
              c[ 44][ t]], 
            Times[ 0.88706379305918392, 
              c[ 45][ t]], 
            Times[ 0.93548928378863916, 
              c[ 46][ t]], 
            Times[ 0.9710122092317629, 
              c[ 47][ t]], 
            Times[ 0.99270519960720693, 
              c[ 48][ t]], 
            Times[ 53.659822593367878, 
              c[ 49][ t]], 
            Times[ 0.99270519960720693, 
              c[ 50][ t]], 
            Times[ 0.9710122092317629, 
              c[ 51][ t]], 
            Times[ 0.93548928378863916, 
              c[ 52][ t]], 
            Times[ 0.88706379305918392, 
              c[ 53][ t]], 
            Times[ 0.82699334313268802, 
              c[ 54][ t]], 
            Times[ 0.75682672864065692, 
              c[ 55][ t]], 
            Times[ 0.67835603854706361, 
              c[ 56][ t]], 
            Times[ 0.59356153372868015, 
              c[ 57][ t]], 
            Times[ 0.50455115242710469, 
              c[ 58][ t]], 
            Times[ 0.41349667156634429, 
              c[ 59][ t]], 
            Times[ 0.32256865202152113, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "50", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[50]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.037590606506031236`\)\ \(c[\(-60\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-59\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-58\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-57\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-56\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-55\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-54\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-53\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-52\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-51\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-50\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-49\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-48\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-47\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-46\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-45\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-44\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-43\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-42\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-41\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-40\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-39\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-38\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-37\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-36\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-35\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-34\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-33\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-32\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-31\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-30\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-29\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-28\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-27\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-26\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-25\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-24\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-23\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-22\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-21\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-20\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-19\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-18\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-17\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-16\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-15\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-14\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-13\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-12\)]\)[t] + 
            0.01627385573126547`\ \(c[\(-11\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-10\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-9\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-8\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-7\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-6\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-5\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-4\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-3\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-2\)]\)[t] - 
            0.08903843866360665`\ \(c[\(-1\)]\)[t] - 
            0.08269933431326874`\ \(c[0]\)[t] - 
            0.07241337086197412`\ \(c[1]\)[t] - 
            0.058468080236789774`\ \(c[2]\)[t] - 
            0.04131966847794722`\ \(c[3]\)[t] - 
            0.02158054781754788`\ \(c[4]\)[t] + 
            2.274590327822911`*^-16\ \(c[5]\)[t] + 
            0.02256148180925487`\ \(c[6]\)[t] + 
            0.0451633585689193`\ \(c[7]\)[t] + 
            0.06682066312776015`\ \(c[8]\)[t] + 
            0.08654280907894489`\ \(c[9]\)[t] + 
            0.10337416789158609`\ \(c[10]\)[t] + 
            0.11643488132933186`\ \(c[11]\)[t] + 
            0.12496032289024853`\ \(c[12]\)[t] + 
            0.12833762891430928`\ \(c[13]\)[t] + 
            0.12613778810677612`\ \(c[14]\)[t] + 
            0.11814190616181253`\ \(c[15]\)[t] + 
            0.10436044624225685`\ \(c[16]\)[t] + 
            0.08504448034442161`\ \(c[17]\)[t] + 
            0.060688263076985`\ \(c[18]\)[t] + 
            0.032022748374425904`\ \(c[19]\)[t] - 
            1.8033970416801674`*^-16\ \(c[20]\)[t] - 
            0.034231213779559094`\ \(c[21]\)[t] - 
            0.06935801494512607`\ \(c[22]\)[t] - 
            0.1039432537542934`\ \(c[23]\)[t] - 
            0.13647135277833616`\ \(c[24]\)[t] - 
            0.1653986686265377`\ \(c[25]\)[t] - 
            0.18920668216016434`\ \(c[26]\)[t] - 
            0.20645618564475848`\ \(c[27]\)[t] - 
            0.21584055771952015`\ \(c[28]\)[t] - 
            0.21623620818304481`\ \(c[29]\)[t] - 
            0.2067483357831719`\ \(c[30]\)[t] - 
            0.18675027222298593`\ \(c[31]\)[t] - 
            0.15591488063143966`\ \(c[32]\)[t] - 
            0.11423673049785416`\ \(c[33]\)[t] - 
            0.06204407497545024`\ \(c[34]\)[t] + 
            3.216976900108398`*^-16\ \(c[35]\)[t] + 
            0.0709075142576581`\ \(c[36]\)[t] + 
            0.14938649372796384`\ \(c[37]\)[t] + 
            0.23387232094716018`\ \(c[38]\)[t] + 
            0.3225686520215219`\ \(c[39]\)[t] + 
            0.4134966715663443`\ \(c[40]\)[t] + 
            0.5045511524271047`\ \(c[41]\)[t] + 
            0.5935615337286809`\ \(c[42]\)[t] + 
            0.6783560385470636`\ \(c[43]\)[t] + 
            0.7568267286406569`\ \(c[44]\)[t] + 
            0.8269933431326885`\ \(c[45]\)[t] + 
            0.8870637930591839`\ \(c[46]\)[t] + 
            0.9354892837886392`\ \(c[47]\)[t] + 
            0.9710122092317629`\ \(c[48]\)[t] + 
            0.9927051996072069`\ \(c[49]\)[t] + 
            55.83113556160753`\ \(c[50]\)[t] + 
            0.9927051996072067`\ \(c[51]\)[t] + 
            0.9710122092317629`\ \(c[52]\)[t] + 
            0.9354892837886392`\ \(c[53]\)[t] + 
            0.8870637930591835`\ \(c[54]\)[t] + 
            0.826993343132688`\ \(c[55]\)[t] + 
            0.7568267286406569`\ \(c[56]\)[t] + 
            0.6783560385470627`\ \(c[57]\)[t] + 
            0.5935615337286801`\ \(c[58]\)[t] + 
            0.5045511524271047`\ \(c[59]\)[t] + 
            0.4134966715663436`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 50, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 50]][ t]], 
          Plus[ 
            Times[ -0.037590606506031236, 
              c[ -60][ t]], 
            Times[ -0.032552799745291051, 
              c[ -59][ t]], 
            Times[ -0.025985813438573278, 
              c[ -58][ t]], 
            Times[ -0.018149760920219783, 
              c[ -57][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -56][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -55][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -54][ t]], 
            Times[ 0.018854606004500389, 
              c[ -53][ t]], 
            Times[ 0.027514390699665887, 
              c[ -52][ t]], 
            Times[ 0.035131239329076656, 
              c[ -51][ t]], 
            Times[ 0.041349667156634483, 
              c[ -50][ t]], 
            Times[ 0.045868286584282311, 
              c[ -49][ t]], 
            Times[ 0.048454002753361682, 
              c[ -48][ t]], 
            Times[ 0.048953528554942699, 
              c[ -47][ t]], 
            Times[ 0.047301670540041058, 
              c[ -46][ t]], 
            Times[ 0.043525965428036162, 
              c[ -45][ t]], 
            Times[ 0.03774739544932687, 
              c[ -44][ t]], 
            Times[ 0.030177073670601094, 
              c[ -43][ t]], 
            Times[ 0.021108961070255627, 
              c[ -42][ t]], 
            Times[ 0.010908848347331785, 
              c[ -41][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -40][ t]], 
            Times[ -0.011153991006822649, 
              c[ -39][ t]], 
            Times[ -0.022068459300722043, 
              c[ -38][ t]], 
            Times[ -0.032258251165125679, 
              c[ -37][ t]], 
            Times[ -0.041258781072520248, 
              c[ -36][ t]], 
            Times[ -0.048646667243099399, 
              c[ -35][ t]], 
            Times[ -0.054059052045761224, 
              c[ -34][ t]], 
            Times[ -0.057210750238908967, 
              c[ -33][ t]], 
            Times[ -0.057908442314993203, 
              c[ -32][ t]], 
            Times[ -0.05606123915856713, 
              c[ -31][ t]], 
            Times[ -0.05168708394579296, 
              c[ -30][ t]], 
            Times[ -0.044914622433376288, 
              c[ -29][ t]], 
            Times[ -0.035980357068793781, 
              c[ -28][ t]], 
            Times[ -0.025221096343682053, 
              c[ -27][ t]], 
            Times[ -0.013061910521147276, 
              c[ -26][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -25][ t]], 
            Times[ 0.013414935129827233, 
              c[ -24][ t]], 
            Times[ 0.026603074225527937, 
              c[ -23][ t]], 
            Times[ 0.038978720157860088, 
              c[ -22][ t]], 
            Times[ 0.049975424961080865, 
              c[ -21][ t]], 
            Times[ 0.059070953080906402, 
              c[ -20][ t]], 
            Times[ 0.065811019881796315, 
              c[ -19][ t]], 
            Times[ 0.069830768673962415, 
              c[ -18][ t]], 
            Times[ 0.070873018952678238, 
              c[ -17][ t]], 
            Times[ 0.068802429876423321, 
              c[ -16][ t]], 
            Times[ 0.063614872548668253, 
              c[ -15][ t]], 
            Times[ 0.055441487066198857, 
              c[ -14][ t]], 
            Times[ 0.044547108751839815, 
              c[ -13][ t]], 
            Times[ 0.031322974491347078, 
              c[ -12][ t]], 
            Times[ 0.016273855731265469, 
              c[ -11][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -10][ t]], 
            Times[ -0.016825511857749401, 
              c[ -9][ t]], 
            Times[ -0.033483179628681567, 
              c[ -8][ t]], 
            Times[ -0.049236278094139066, 
              c[ -7][ t]], 
            Times[ -0.063361699504227528, 
              c[ -6][ t]], 
            Times[ -0.075181213012062598, 
              c[ -5][ t]], 
            Times[ -0.084091858737850855, 
              c[ -4][ t]], 
            Times[ -0.089594193770366884, 
              c[ -3][ t]], 
            Times[ -0.091317159035181589, 
              c[ -2][ t]], 
            Times[ -0.089038438663606653, 
              c[ -1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 0][ t]], 
            Times[ -0.072413370861974122, 
              c[ 1][ t]], 
            Times[ -0.058468080236789774, 
              c[ 2][ t]], 
            Times[ -0.04131966847794722, 
              c[ 3][ t]], 
            Times[ -0.021580547817547879, 
              c[ 4][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 5][ t]], 
            Times[ 0.022561481809254869, 
              c[ 6][ t]], 
            Times[ 0.045163358568919301, 
              c[ 7][ t]], 
            Times[ 0.066820663127760152, 
              c[ 8][ t]], 
            Times[ 0.086542809078944891, 
              c[ 9][ t]], 
            Times[ 0.10337416789158609, 
              c[ 10][ t]], 
            Times[ 0.11643488132933186, 
              c[ 11][ t]], 
            Times[ 0.12496032289024853, 
              c[ 12][ t]], 
            Times[ 0.12833762891430928, 
              c[ 13][ t]], 
            Times[ 0.12613778810677612, 
              c[ 14][ t]], 
            Times[ 0.11814190616181253, 
              c[ 15][ t]], 
            Times[ 0.10436044624225685, 
              c[ 16][ t]], 
            Times[ 0.085044480344421608, 
              c[ 17][ t]], 
            Times[ 0.060688263076985001, 
              c[ 18][ t]], 
            Times[ 0.032022748374425904, 
              c[ 19][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 20][ t]], 
            Times[ -0.034231213779559094, 
              c[ 21][ t]], 
            Times[ -0.06935801494512607, 
              c[ 22][ t]], 
            Times[ -0.1039432537542934, 
              c[ 23][ t]], 
            Times[ -0.13647135277833616, 
              c[ 24][ t]], 
            Times[ -0.16539866862653771, 
              c[ 25][ t]], 
            Times[ -0.18920668216016434, 
              c[ 26][ t]], 
            Times[ -0.20645618564475848, 
              c[ 27][ t]], 
            Times[ -0.21584055771952015, 
              c[ 28][ t]], 
            Times[ -0.21623620818304481, 
              c[ 29][ t]], 
            Times[ -0.20674833578317189, 
              c[ 30][ t]], 
            Times[ -0.18675027222298593, 
              c[ 31][ t]], 
            Times[ -0.15591488063143966, 
              c[ 32][ t]], 
            Times[ -0.11423673049785416, 
              c[ 33][ t]], 
            Times[ -0.062044074975450239, 
              c[ 34][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 35][ t]], 
            Times[ 0.070907514257658094, 
              c[ 36][ t]], 
            Times[ 0.14938649372796384, 
              c[ 37][ t]], 
            Times[ 0.23387232094716018, 
              c[ 38][ t]], 
            Times[ 0.32256865202152191, 
              c[ 39][ t]], 
            Times[ 0.41349667156634429, 
              c[ 40][ t]], 
            Times[ 0.50455115242710469, 
              c[ 41][ t]], 
            Times[ 0.59356153372868092, 
              c[ 42][ t]], 
            Times[ 0.67835603854706361, 
              c[ 43][ t]], 
            Times[ 0.75682672864065692, 
              c[ 44][ t]], 
            Times[ 0.82699334313268846, 
              c[ 45][ t]], 
            Times[ 0.88706379305918392, 
              c[ 46][ t]], 
            Times[ 0.93548928378863916, 
              c[ 47][ t]], 
            Times[ 0.9710122092317629, 
              c[ 48][ t]], 
            Times[ 0.99270519960720693, 
              c[ 49][ t]], 
            Times[ 55.831135561607532, 
              c[ 50][ t]], 
            Times[ 0.99270519960720671, 
              c[ 51][ t]], 
            Times[ 0.9710122092317629, 
              c[ 52][ t]], 
            Times[ 0.93548928378863916, 
              c[ 53][ t]], 
            Times[ 0.88706379305918348, 
              c[ 54][ t]], 
            Times[ 0.82699334313268802, 
              c[ 55][ t]], 
            Times[ 0.75682672864065692, 
              c[ 56][ t]], 
            Times[ 0.67835603854706272, 
              c[ 57][ t]], 
            Times[ 0.59356153372868015, 
              c[ 58][ t]], 
            Times[ 0.50455115242710469, 
              c[ 59][ t]], 
            Times[ 0.41349667156634362, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "51", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[51]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.040909552899494966`\)\ \(c[\(-60\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-59\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-58\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-57\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-56\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-55\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-54\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-53\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-52\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-51\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-50\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-49\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-48\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-47\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-46\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-45\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-44\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-43\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-42\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-41\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-40\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-39\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-38\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-37\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-36\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-35\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-34\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-33\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-32\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-31\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-30\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-29\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-28\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-27\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-26\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-25\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-24\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-23\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-22\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-21\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-20\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-19\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-18\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-17\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-16\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-15\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-14\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-13\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-12\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-11\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-10\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-9\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-8\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-7\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-6\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-5\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-4\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-3\)]\)[t] - 
            0.08959419377036684`\ \(c[\(-2\)]\)[t] - 
            0.09131715903518159`\ \(c[\(-1\)]\)[t] - 
            0.0890384386636067`\ \(c[0]\)[t] - 
            0.08269933431326881`\ \(c[1]\)[t] - 
            0.07241337086197412`\ \(c[2]\)[t] - 
            0.05846808023678991`\ \(c[3]\)[t] - 
            0.04131966847794737`\ \(c[4]\)[t] - 
            0.02158054781754788`\ \(c[5]\)[t] + 
            3.8981718325193755`*^-17\ \(c[6]\)[t] + 
            0.022561481809254675`\ \(c[7]\)[t] + 
            0.0451633585689193`\ \(c[8]\)[t] + 
            0.06682066312775997`\ \(c[9]\)[t] + 
            0.08654280907894475`\ \(c[10]\)[t] + 
            0.10337416789158595`\ \(c[11]\)[t] + 
            0.11643488132933186`\ \(c[12]\)[t] + 
            0.12496032289024847`\ \(c[13]\)[t] + 
            0.12833762891430925`\ \(c[14]\)[t] + 
            0.12613778810677614`\ \(c[15]\)[t] + 
            0.1181419061618126`\ \(c[16]\)[t] + 
            0.10436044624225692`\ \(c[17]\)[t] + 
            0.0850444803444217`\ \(c[18]\)[t] + 
            0.06068826307698522`\ \(c[19]\)[t] + 
            0.03202274837442603`\ \(c[20]\)[t] - 
            3.898171832519376`*^-17\ \(c[21]\)[t] - 
            0.034231213779558796`\ \(c[22]\)[t] - 
            0.06935801494512592`\ \(c[23]\)[t] - 
            0.10394325375429328`\ \(c[24]\)[t] - 
            0.1364713527783359`\ \(c[25]\)[t] - 
            0.1653986686265376`\ \(c[26]\)[t] - 
            0.18920668216016426`\ \(c[27]\)[t] - 
            0.20645618564475834`\ \(c[28]\)[t] - 
            0.21584055771952013`\ \(c[29]\)[t] - 
            0.21623620818304484`\ \(c[30]\)[t] - 
            0.20674833578317206`\ \(c[31]\)[t] - 
            0.18675027222298607`\ \(c[32]\)[t] - 
            0.15591488063143982`\ \(c[33]\)[t] - 
            0.11423673049785459`\ \(c[34]\)[t] - 
            0.062044074975450475`\ \(c[35]\)[t] + 
            3.898171832519376`*^-17\ \(c[36]\)[t] + 
            0.07090751425765746`\ \(c[37]\)[t] + 
            0.14938649372796345`\ \(c[38]\)[t] + 
            0.23387232094715985`\ \(c[39]\)[t] + 
            0.32256865202152113`\ \(c[40]\)[t] + 
            0.4134966715663436`\ \(c[41]\)[t] + 
            0.5045511524271047`\ \(c[42]\)[t] + 
            0.5935615337286801`\ \(c[43]\)[t] + 
            0.6783560385470627`\ \(c[44]\)[t] + 
            0.7568267286406569`\ \(c[45]\)[t] + 
            0.826993343132688`\ \(c[46]\)[t] + 
            0.8870637930591835`\ \(c[47]\)[t] + 
            0.9354892837886392`\ \(c[48]\)[t] + 
            0.9710122092317629`\ \(c[49]\)[t] + 
            0.9927051996072067`\ \(c[50]\)[t] + 
            58.04631343829649`\ \(c[51]\)[t] + 
            0.9927051996072069`\ \(c[52]\)[t] + 
            0.9710122092317629`\ \(c[53]\)[t] + 
            0.9354892837886392`\ \(c[54]\)[t] + 
            0.8870637930591839`\ \(c[55]\)[t] + 
            0.8269933431326885`\ \(c[56]\)[t] + 
            0.7568267286406569`\ \(c[57]\)[t] + 
            0.6783560385470636`\ \(c[58]\)[t] + 
            0.5935615337286809`\ \(c[59]\)[t] + 
            0.5045511524271047`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 51, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 51]][ t]], 
          Plus[ 
            Times[ -0.040909552899494966, 
              c[ -60][ t]], 
            Times[ -0.037590606506031236, 
              c[ -59][ t]], 
            Times[ -0.032552799745291155, 
              c[ -58][ t]], 
            Times[ -0.025985813438573278, 
              c[ -57][ t]], 
            Times[ -0.018149760920219783, 
              c[ -56][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -55][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -54][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -53][ t]], 
            Times[ 0.018854606004500233, 
              c[ -52][ t]], 
            Times[ 0.027514390699665887, 
              c[ -51][ t]], 
            Times[ 0.035131239329076656, 
              c[ -50][ t]], 
            Times[ 0.041349667156634483, 
              c[ -49][ t]], 
            Times[ 0.045868286584282256, 
              c[ -48][ t]], 
            Times[ 0.048454002753361682, 
              c[ -47][ t]], 
            Times[ 0.04895352855494272, 
              c[ -46][ t]], 
            Times[ 0.047301670540041058, 
              c[ -45][ t]], 
            Times[ 0.043525965428036162, 
              c[ -44][ t]], 
            Times[ 0.03774739544932687, 
              c[ -43][ t]], 
            Times[ 0.030177073670601236, 
              c[ -42][ t]], 
            Times[ 0.021108961070255627, 
              c[ -41][ t]], 
            Times[ 0.010908848347331966, 
              c[ -40][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -39][ t]], 
            Times[ -0.011153991006822649, 
              c[ -38][ t]], 
            Times[ -0.022068459300722043, 
              c[ -37][ t]], 
            Times[ -0.032258251165125519, 
              c[ -36][ t]], 
            Times[ -0.041258781072520248, 
              c[ -35][ t]], 
            Times[ -0.048646667243099281, 
              c[ -34][ t]], 
            Times[ -0.054059052045761224, 
              c[ -33][ t]], 
            Times[ -0.057210750238908967, 
              c[ -32][ t]], 
            Times[ -0.057908442314993203, 
              c[ -31][ t]], 
            Times[ -0.056061239158567186, 
              c[ -30][ t]], 
            Times[ -0.05168708394579296, 
              c[ -29][ t]], 
            Times[ -0.044914622433376419, 
              c[ -28][ t]], 
            Times[ -0.035980357068793781, 
              c[ -27][ t]], 
            Times[ -0.025221096343682053, 
              c[ -26][ t]], 
            Times[ -0.013061910521147383, 
              c[ -25][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -24][ t]], 
            Times[ 0.013414935129827233, 
              c[ -23][ t]], 
            Times[ 0.026603074225527826, 
              c[ -22][ t]], 
            Times[ 0.03897872015785999, 
              c[ -21][ t]], 
            Times[ 0.049975424961080865, 
              c[ -20][ t]], 
            Times[ 0.059070953080906326, 
              c[ -19][ t]], 
            Times[ 0.065811019881796273, 
              c[ -18][ t]], 
            Times[ 0.069830768673962415, 
              c[ -17][ t]], 
            Times[ 0.070873018952678238, 
              c[ -16][ t]], 
            Times[ 0.068802429876423349, 
              c[ -15][ t]], 
            Times[ 0.063614872548668253, 
              c[ -14][ t]], 
            Times[ 0.055441487066198933, 
              c[ -13][ t]], 
            Times[ 0.044547108751839919, 
              c[ -12][ t]], 
            Times[ 0.031322974491347078, 
              c[ -11][ t]], 
            Times[ 0.016273855731265604, 
              c[ -10][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -9][ t]], 
            Times[ -0.016825511857749262, 
              c[ -8][ t]], 
            Times[ -0.033483179628681567, 
              c[ -7][ t]], 
            Times[ -0.049236278094138941, 
              c[ -6][ t]], 
            Times[ -0.063361699504227403, 
              c[ -5][ t]], 
            Times[ -0.075181213012062598, 
              c[ -4][ t]], 
            Times[ -0.084091858737850814, 
              c[ -3][ t]], 
            Times[ -0.089594193770366842, 
              c[ -2][ t]], 
            Times[ -0.091317159035181589, 
              c[ -1][ t]], 
            Times[ -0.089038438663606695, 
              c[ 0][ t]], 
            Times[ -0.082699334313268813, 
              c[ 1][ t]], 
            Times[ -0.072413370861974122, 
              c[ 2][ t]], 
            Times[ -0.058468080236789913, 
              c[ 3][ t]], 
            Times[ -0.041319668477947373, 
              c[ 4][ t]], 
            Times[ -0.021580547817547879, 
              c[ 5][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 6][ t]], 
            Times[ 0.022561481809254675, 
              c[ 7][ t]], 
            Times[ 0.045163358568919301, 
              c[ 8][ t]], 
            Times[ 0.066820663127759972, 
              c[ 9][ t]], 
            Times[ 0.086542809078944752, 
              c[ 10][ t]], 
            Times[ 0.10337416789158595, 
              c[ 11][ t]], 
            Times[ 0.11643488132933186, 
              c[ 12][ t]], 
            Times[ 0.12496032289024847, 
              c[ 13][ t]], 
            Times[ 0.12833762891430925, 
              c[ 14][ t]], 
            Times[ 0.12613778810677614, 
              c[ 15][ t]], 
            Times[ 0.1181419061618126, 
              c[ 16][ t]], 
            Times[ 0.10436044624225692, 
              c[ 17][ t]], 
            Times[ 0.085044480344421705, 
              c[ 18][ t]], 
            Times[ 0.060688263076985223, 
              c[ 19][ t]], 
            Times[ 0.032022748374426029, 
              c[ 20][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 21][ t]], 
            Times[ -0.034231213779558796, 
              c[ 22][ t]], 
            Times[ -0.069358014945125918, 
              c[ 23][ t]], 
            Times[ -0.10394325375429328, 
              c[ 24][ t]], 
            Times[ -0.13647135277833591, 
              c[ 25][ t]], 
            Times[ -0.1653986686265376, 
              c[ 26][ t]], 
            Times[ -0.18920668216016426, 
              c[ 27][ t]], 
            Times[ -0.20645618564475834, 
              c[ 28][ t]], 
            Times[ -0.21584055771952013, 
              c[ 29][ t]], 
            Times[ -0.21623620818304484, 
              c[ 30][ t]], 
            Times[ -0.20674833578317206, 
              c[ 31][ t]], 
            Times[ -0.18675027222298607, 
              c[ 32][ t]], 
            Times[ -0.15591488063143982, 
              c[ 33][ t]], 
            Times[ -0.11423673049785459, 
              c[ 34][ t]], 
            Times[ -0.062044074975450475, 
              c[ 35][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 36][ t]], 
            Times[ 0.070907514257657456, 
              c[ 37][ t]], 
            Times[ 0.14938649372796345, 
              c[ 38][ t]], 
            Times[ 0.23387232094715985, 
              c[ 39][ t]], 
            Times[ 0.32256865202152113, 
              c[ 40][ t]], 
            Times[ 0.41349667156634362, 
              c[ 41][ t]], 
            Times[ 0.50455115242710469, 
              c[ 42][ t]], 
            Times[ 0.59356153372868015, 
              c[ 43][ t]], 
            Times[ 0.67835603854706272, 
              c[ 44][ t]], 
            Times[ 0.75682672864065692, 
              c[ 45][ t]], 
            Times[ 0.82699334313268802, 
              c[ 46][ t]], 
            Times[ 0.88706379305918348, 
              c[ 47][ t]], 
            Times[ 0.93548928378863916, 
              c[ 48][ t]], 
            Times[ 0.9710122092317629, 
              c[ 49][ t]], 
            Times[ 0.99270519960720671, 
              c[ 50][ t]], 
            Times[ 58.046313438296487, 
              c[ 51][ t]], 
            Times[ 0.99270519960720693, 
              c[ 52][ t]], 
            Times[ 0.9710122092317629, 
              c[ 53][ t]], 
            Times[ 0.93548928378863916, 
              c[ 54][ t]], 
            Times[ 0.88706379305918392, 
              c[ 55][ t]], 
            Times[ 0.82699334313268846, 
              c[ 56][ t]], 
            Times[ 0.75682672864065692, 
              c[ 57][ t]], 
            Times[ 0.67835603854706361, 
              c[ 58][ t]], 
            Times[ 0.59356153372868092, 
              c[ 59][ t]], 
            Times[ 0.50455115242710469, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "52", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[52]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.04239725240919144`\)\ \(c[\(-60\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-59\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-58\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-57\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-56\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-55\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-54\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-53\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-52\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-51\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-50\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-49\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-48\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-47\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-46\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-45\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-44\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-43\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-42\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-41\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-40\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-39\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-38\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-37\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-36\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-35\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-34\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-33\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-32\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-31\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-30\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-29\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-28\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-27\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-26\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-25\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-24\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-23\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-22\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-21\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-20\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-19\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-18\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-17\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-16\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-15\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-14\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-13\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-12\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-11\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-10\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-9\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-8\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-7\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-6\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-5\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-4\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-3\)]\)[t] - 
            0.08409185873785081`\ \(c[\(-2\)]\)[t] - 
            0.08959419377036688`\ \(c[\(-1\)]\)[t] - 
            0.09131715903518159`\ \(c[0]\)[t] - 
            0.0890384386636067`\ \(c[1]\)[t] - 
            0.08269933431326874`\ \(c[2]\)[t] - 
            0.07241337086197412`\ \(c[3]\)[t] - 
            0.05846808023678991`\ \(c[4]\)[t] - 
            0.04131966847794722`\ \(c[5]\)[t] - 
            0.02158054781754788`\ \(c[6]\)[t] + 
            3.8981718325193755`*^-17\ \(c[7]\)[t] + 
            0.02256148180925487`\ \(c[8]\)[t] + 
            0.0451633585689193`\ \(c[9]\)[t] + 
            0.06682066312775997`\ \(c[10]\)[t] + 
            0.08654280907894489`\ \(c[11]\)[t] + 
            0.10337416789158609`\ \(c[12]\)[t] + 
            0.11643488132933186`\ \(c[13]\)[t] + 
            0.12496032289024853`\ \(c[14]\)[t] + 
            0.12833762891430928`\ \(c[15]\)[t] + 
            0.12613778810677614`\ \(c[16]\)[t] + 
            0.11814190616181255`\ \(c[17]\)[t] + 
            0.10436044624225685`\ \(c[18]\)[t] + 
            0.0850444803444217`\ \(c[19]\)[t] + 
            0.060688263076985105`\ \(c[20]\)[t] + 
            0.032022748374425904`\ \(c[21]\)[t] - 
            3.898171832519376`*^-17\ \(c[22]\)[t] - 
            0.03423121377955895`\ \(c[23]\)[t] - 
            0.06935801494512607`\ \(c[24]\)[t] - 
            0.10394325375429328`\ \(c[25]\)[t] - 
            0.13647135277833605`\ \(c[26]\)[t] - 
            0.1653986686265377`\ \(c[27]\)[t] - 
            0.18920668216016426`\ \(c[28]\)[t] - 
            0.20645618564475843`\ \(c[29]\)[t] - 
            0.21584055771952015`\ \(c[30]\)[t] - 
            0.21623620818304484`\ \(c[31]\)[t] - 
            0.206748335783172`\ \(c[32]\)[t] - 
            0.18675027222298593`\ \(c[33]\)[t] - 
            0.15591488063143982`\ \(c[34]\)[t] - 
            0.11423673049785436`\ \(c[35]\)[t] - 
            0.06204407497545024`\ \(c[36]\)[t] + 
            3.898171832519376`*^-17\ \(c[37]\)[t] + 
            0.07090751425765777`\ \(c[38]\)[t] + 
            0.14938649372796384`\ \(c[39]\)[t] + 
            0.23387232094715985`\ \(c[40]\)[t] + 
            0.32256865202152113`\ \(c[41]\)[t] + 
            0.4134966715663443`\ \(c[42]\)[t] + 
            0.5045511524271047`\ \(c[43]\)[t] + 
            0.5935615337286801`\ \(c[44]\)[t] + 
            0.6783560385470636`\ \(c[45]\)[t] + 
            0.7568267286406569`\ \(c[46]\)[t] + 
            0.826993343132688`\ \(c[47]\)[t] + 
            0.8870637930591839`\ \(c[48]\)[t] + 
            0.9354892837886392`\ \(c[49]\)[t] + 
            0.9710122092317629`\ \(c[50]\)[t] + 
            0.9927051996072069`\ \(c[51]\)[t] + 
            60.305356223434714`\ \(c[52]\)[t] + 
            0.9927051996072069`\ \(c[53]\)[t] + 
            0.9710122092317629`\ \(c[54]\)[t] + 
            0.9354892837886392`\ \(c[55]\)[t] + 
            0.8870637930591839`\ \(c[56]\)[t] + 
            0.826993343132688`\ \(c[57]\)[t] + 
            0.7568267286406569`\ \(c[58]\)[t] + 
            0.6783560385470636`\ \(c[59]\)[t] + 
            0.5935615337286801`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 52, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 52]][ t]], 
          Plus[ 
            Times[ -0.042397252409191441, 
              c[ -60][ t]], 
            Times[ -0.040909552899494925, 
              c[ -59][ t]], 
            Times[ -0.037590606506031236, 
              c[ -58][ t]], 
            Times[ -0.032552799745291155, 
              c[ -57][ t]], 
            Times[ -0.025985813438573278, 
              c[ -56][ t]], 
            Times[ -0.018149760920219783, 
              c[ -55][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -54][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -53][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -52][ t]], 
            Times[ 0.018854606004500233, 
              c[ -51][ t]], 
            Times[ 0.027514390699665887, 
              c[ -50][ t]], 
            Times[ 0.035131239329076656, 
              c[ -49][ t]], 
            Times[ 0.041349667156634483, 
              c[ -48][ t]], 
            Times[ 0.045868286584282311, 
              c[ -47][ t]], 
            Times[ 0.048454002753361682, 
              c[ -46][ t]], 
            Times[ 0.04895352855494272, 
              c[ -45][ t]], 
            Times[ 0.047301670540041058, 
              c[ -44][ t]], 
            Times[ 0.043525965428036162, 
              c[ -43][ t]], 
            Times[ 0.03774739544932687, 
              c[ -42][ t]], 
            Times[ 0.030177073670601094, 
              c[ -41][ t]], 
            Times[ 0.021108961070255627, 
              c[ -40][ t]], 
            Times[ 0.010908848347331966, 
              c[ -39][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -38][ t]], 
            Times[ -0.011153991006822649, 
              c[ -37][ t]], 
            Times[ -0.022068459300722043, 
              c[ -36][ t]], 
            Times[ -0.032258251165125519, 
              c[ -35][ t]], 
            Times[ -0.041258781072520248, 
              c[ -34][ t]], 
            Times[ -0.048646667243099281, 
              c[ -33][ t]], 
            Times[ -0.054059052045761224, 
              c[ -32][ t]], 
            Times[ -0.057210750238908967, 
              c[ -31][ t]], 
            Times[ -0.057908442314993203, 
              c[ -30][ t]], 
            Times[ -0.056061239158567186, 
              c[ -29][ t]], 
            Times[ -0.05168708394579296, 
              c[ -28][ t]], 
            Times[ -0.044914622433376419, 
              c[ -27][ t]], 
            Times[ -0.035980357068793781, 
              c[ -26][ t]], 
            Times[ -0.025221096343682053, 
              c[ -25][ t]], 
            Times[ -0.013061910521147383, 
              c[ -24][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -23][ t]], 
            Times[ 0.013414935129827233, 
              c[ -22][ t]], 
            Times[ 0.026603074225527826, 
              c[ -21][ t]], 
            Times[ 0.03897872015785999, 
              c[ -20][ t]], 
            Times[ 0.049975424961080865, 
              c[ -19][ t]], 
            Times[ 0.059070953080906326, 
              c[ -18][ t]], 
            Times[ 0.065811019881796273, 
              c[ -17][ t]], 
            Times[ 0.069830768673962415, 
              c[ -16][ t]], 
            Times[ 0.070873018952678238, 
              c[ -15][ t]], 
            Times[ 0.068802429876423349, 
              c[ -14][ t]], 
            Times[ 0.063614872548668253, 
              c[ -13][ t]], 
            Times[ 0.055441487066198933, 
              c[ -12][ t]], 
            Times[ 0.044547108751839919, 
              c[ -11][ t]], 
            Times[ 0.031322974491347078, 
              c[ -10][ t]], 
            Times[ 0.016273855731265604, 
              c[ -9][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -8][ t]], 
            Times[ -0.016825511857749401, 
              c[ -7][ t]], 
            Times[ -0.033483179628681567, 
              c[ -6][ t]], 
            Times[ -0.049236278094138941, 
              c[ -5][ t]], 
            Times[ -0.063361699504227528, 
              c[ -4][ t]], 
            Times[ -0.075181213012062598, 
              c[ -3][ t]], 
            Times[ -0.084091858737850814, 
              c[ -2][ t]], 
            Times[ -0.089594193770366884, 
              c[ -1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 0][ t]], 
            Times[ -0.089038438663606695, 
              c[ 1][ t]], 
            Times[ -0.082699334313268744, 
              c[ 2][ t]], 
            Times[ -0.072413370861974122, 
              c[ 3][ t]], 
            Times[ -0.058468080236789913, 
              c[ 4][ t]], 
            Times[ -0.04131966847794722, 
              c[ 5][ t]], 
            Times[ -0.021580547817547879, 
              c[ 6][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 7][ t]], 
            Times[ 0.022561481809254869, 
              c[ 8][ t]], 
            Times[ 0.045163358568919301, 
              c[ 9][ t]], 
            Times[ 0.066820663127759972, 
              c[ 10][ t]], 
            Times[ 0.086542809078944891, 
              c[ 11][ t]], 
            Times[ 0.10337416789158609, 
              c[ 12][ t]], 
            Times[ 0.11643488132933186, 
              c[ 13][ t]], 
            Times[ 0.12496032289024853, 
              c[ 14][ t]], 
            Times[ 0.12833762891430928, 
              c[ 15][ t]], 
            Times[ 0.12613778810677614, 
              c[ 16][ t]], 
            Times[ 0.11814190616181255, 
              c[ 17][ t]], 
            Times[ 0.10436044624225685, 
              c[ 18][ t]], 
            Times[ 0.085044480344421705, 
              c[ 19][ t]], 
            Times[ 0.060688263076985105, 
              c[ 20][ t]], 
            Times[ 0.032022748374425904, 
              c[ 21][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 22][ t]], 
            Times[ -0.034231213779558949, 
              c[ 23][ t]], 
            Times[ -0.06935801494512607, 
              c[ 24][ t]], 
            Times[ -0.10394325375429328, 
              c[ 25][ t]], 
            Times[ -0.13647135277833605, 
              c[ 26][ t]], 
            Times[ -0.16539866862653771, 
              c[ 27][ t]], 
            Times[ -0.18920668216016426, 
              c[ 28][ t]], 
            Times[ -0.20645618564475843, 
              c[ 29][ t]], 
            Times[ -0.21584055771952015, 
              c[ 30][ t]], 
            Times[ -0.21623620818304484, 
              c[ 31][ t]], 
            Times[ -0.206748335783172, 
              c[ 32][ t]], 
            Times[ -0.18675027222298593, 
              c[ 33][ t]], 
            Times[ -0.15591488063143982, 
              c[ 34][ t]], 
            Times[ -0.11423673049785436, 
              c[ 35][ t]], 
            Times[ -0.062044074975450239, 
              c[ 36][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 37][ t]], 
            Times[ 0.070907514257657775, 
              c[ 38][ t]], 
            Times[ 0.14938649372796384, 
              c[ 39][ t]], 
            Times[ 0.23387232094715985, 
              c[ 40][ t]], 
            Times[ 0.32256865202152113, 
              c[ 41][ t]], 
            Times[ 0.41349667156634429, 
              c[ 42][ t]], 
            Times[ 0.50455115242710469, 
              c[ 43][ t]], 
            Times[ 0.59356153372868015, 
              c[ 44][ t]], 
            Times[ 0.67835603854706361, 
              c[ 45][ t]], 
            Times[ 0.75682672864065692, 
              c[ 46][ t]], 
            Times[ 0.82699334313268802, 
              c[ 47][ t]], 
            Times[ 0.88706379305918392, 
              c[ 48][ t]], 
            Times[ 0.93548928378863916, 
              c[ 49][ t]], 
            Times[ 0.9710122092317629, 
              c[ 50][ t]], 
            Times[ 0.99270519960720693, 
              c[ 51][ t]], 
            Times[ 60.305356223434714, 
              c[ 52][ t]], 
            Times[ 0.99270519960720693, 
              c[ 53][ t]], 
            Times[ 0.9710122092317629, 
              c[ 54][ t]], 
            Times[ 0.93548928378863916, 
              c[ 55][ t]], 
            Times[ 0.88706379305918392, 
              c[ 56][ t]], 
            Times[ 0.82699334313268802, 
              c[ 57][ t]], 
            Times[ 0.75682672864065692, 
              c[ 58][ t]], 
            Times[ 0.67835603854706361, 
              c[ 59][ t]], 
            Times[ 0.59356153372868015, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "53", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[53]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.042022055485216314`\)\ \(c[\(-60\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-59\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-58\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-57\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-56\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-55\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-54\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-53\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-52\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-51\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-50\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-49\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-48\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-47\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-46\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-45\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-44\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-43\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-42\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-41\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-40\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-39\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-38\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-37\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-36\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-35\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-34\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-33\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-32\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-31\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-30\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-29\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-28\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-27\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-26\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-25\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-24\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-23\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-22\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-21\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-20\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-19\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-18\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-17\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-16\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-15\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-14\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-13\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-12\)]\)[t] + 
            0.055441487066198857`\ \(c[\(-11\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-10\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-9\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-8\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-7\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-6\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-5\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-4\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-3\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-2\)]\)[t] - 
            0.08409185873785086`\ \(c[\(-1\)]\)[t] - 
            0.08959419377036688`\ \(c[0]\)[t] - 
            0.09131715903518159`\ \(c[1]\)[t] - 
            0.08903843866360665`\ \(c[2]\)[t] - 
            0.08269933431326874`\ \(c[3]\)[t] - 
            0.07241337086197412`\ \(c[4]\)[t] - 
            0.058468080236789774`\ \(c[5]\)[t] - 
            0.04131966847794722`\ \(c[6]\)[t] - 
            0.02158054781754788`\ \(c[7]\)[t] + 
            2.274590327822911`*^-16\ \(c[8]\)[t] + 
            0.02256148180925487`\ \(c[9]\)[t] + 
            0.0451633585689193`\ \(c[10]\)[t] + 
            0.06682066312775997`\ \(c[11]\)[t] + 
            0.08654280907894489`\ \(c[12]\)[t] + 
            0.10337416789158609`\ \(c[13]\)[t] + 
            0.11643488132933186`\ \(c[14]\)[t] + 
            0.12496032289024853`\ \(c[15]\)[t] + 
            0.12833762891430928`\ \(c[16]\)[t] + 
            0.12613778810677612`\ \(c[17]\)[t] + 
            0.11814190616181253`\ \(c[18]\)[t] + 
            0.10436044624225685`\ \(c[19]\)[t] + 
            0.08504448034442161`\ \(c[20]\)[t] + 
            0.060688263076985`\ \(c[21]\)[t] + 
            0.032022748374425904`\ \(c[22]\)[t] - 
            1.8033970416801674`*^-16\ \(c[23]\)[t] - 
            0.034231213779559094`\ \(c[24]\)[t] - 
            0.06935801494512607`\ \(c[25]\)[t] - 
            0.1039432537542934`\ \(c[26]\)[t] - 
            0.13647135277833616`\ \(c[27]\)[t] - 
            0.1653986686265377`\ \(c[28]\)[t] - 
            0.18920668216016434`\ \(c[29]\)[t] - 
            0.20645618564475848`\ \(c[30]\)[t] - 
            0.21584055771952015`\ \(c[31]\)[t] - 
            0.21623620818304481`\ \(c[32]\)[t] - 
            0.2067483357831719`\ \(c[33]\)[t] - 
            0.18675027222298593`\ \(c[34]\)[t] - 
            0.15591488063143966`\ \(c[35]\)[t] - 
            0.11423673049785416`\ \(c[36]\)[t] - 
            0.06204407497545024`\ \(c[37]\)[t] + 
            3.216976900108398`*^-16\ \(c[38]\)[t] + 
            0.0709075142576581`\ \(c[39]\)[t] + 
            0.14938649372796384`\ \(c[40]\)[t] + 
            0.23387232094715985`\ \(c[41]\)[t] + 
            0.3225686520215219`\ \(c[42]\)[t] + 
            0.4134966715663443`\ \(c[43]\)[t] + 
            0.5045511524271047`\ \(c[44]\)[t] + 
            0.5935615337286809`\ \(c[45]\)[t] + 
            0.6783560385470636`\ \(c[46]\)[t] + 
            0.7568267286406569`\ \(c[47]\)[t] + 
            0.8269933431326885`\ \(c[48]\)[t] + 
            0.8870637930591839`\ \(c[49]\)[t] + 
            0.9354892837886392`\ \(c[50]\)[t] + 
            0.9710122092317629`\ \(c[51]\)[t] + 
            0.9927051996072069`\ \(c[52]\)[t] + 
            62.60826391702222`\ \(c[53]\)[t] + 
            0.9927051996072067`\ \(c[54]\)[t] + 
            0.9710122092317629`\ \(c[55]\)[t] + 
            0.9354892837886392`\ \(c[56]\)[t] + 
            0.8870637930591835`\ \(c[57]\)[t] + 
            0.826993343132688`\ \(c[58]\)[t] + 
            0.7568267286406569`\ \(c[59]\)[t] + 
            0.6783560385470627`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 53, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 53]][ t]], 
          Plus[ 
            Times[ -0.042022055485216314, 
              c[ -60][ t]], 
            Times[ -0.042397252409191441, 
              c[ -59][ t]], 
            Times[ -0.040909552899494925, 
              c[ -58][ t]], 
            Times[ -0.037590606506031236, 
              c[ -57][ t]], 
            Times[ -0.032552799745291051, 
              c[ -56][ t]], 
            Times[ -0.025985813438573278, 
              c[ -55][ t]], 
            Times[ -0.018149760920219783, 
              c[ -54][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -53][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -52][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -51][ t]], 
            Times[ 0.018854606004500389, 
              c[ -50][ t]], 
            Times[ 0.027514390699665887, 
              c[ -49][ t]], 
            Times[ 0.035131239329076656, 
              c[ -48][ t]], 
            Times[ 0.041349667156634483, 
              c[ -47][ t]], 
            Times[ 0.045868286584282311, 
              c[ -46][ t]], 
            Times[ 0.048454002753361682, 
              c[ -45][ t]], 
            Times[ 0.048953528554942699, 
              c[ -44][ t]], 
            Times[ 0.047301670540041058, 
              c[ -43][ t]], 
            Times[ 0.043525965428036162, 
              c[ -42][ t]], 
            Times[ 0.03774739544932687, 
              c[ -41][ t]], 
            Times[ 0.030177073670601094, 
              c[ -40][ t]], 
            Times[ 0.021108961070255627, 
              c[ -39][ t]], 
            Times[ 0.010908848347331785, 
              c[ -38][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -37][ t]], 
            Times[ -0.011153991006822649, 
              c[ -36][ t]], 
            Times[ -0.022068459300722043, 
              c[ -35][ t]], 
            Times[ -0.032258251165125679, 
              c[ -34][ t]], 
            Times[ -0.041258781072520248, 
              c[ -33][ t]], 
            Times[ -0.048646667243099399, 
              c[ -32][ t]], 
            Times[ -0.054059052045761224, 
              c[ -31][ t]], 
            Times[ -0.057210750238908967, 
              c[ -30][ t]], 
            Times[ -0.057908442314993203, 
              c[ -29][ t]], 
            Times[ -0.05606123915856713, 
              c[ -28][ t]], 
            Times[ -0.05168708394579296, 
              c[ -27][ t]], 
            Times[ -0.044914622433376288, 
              c[ -26][ t]], 
            Times[ -0.035980357068793781, 
              c[ -25][ t]], 
            Times[ -0.025221096343682053, 
              c[ -24][ t]], 
            Times[ -0.013061910521147276, 
              c[ -23][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -22][ t]], 
            Times[ 0.013414935129827233, 
              c[ -21][ t]], 
            Times[ 0.026603074225527937, 
              c[ -20][ t]], 
            Times[ 0.038978720157860088, 
              c[ -19][ t]], 
            Times[ 0.049975424961080865, 
              c[ -18][ t]], 
            Times[ 0.059070953080906402, 
              c[ -17][ t]], 
            Times[ 0.065811019881796315, 
              c[ -16][ t]], 
            Times[ 0.069830768673962415, 
              c[ -15][ t]], 
            Times[ 0.070873018952678238, 
              c[ -14][ t]], 
            Times[ 0.068802429876423321, 
              c[ -13][ t]], 
            Times[ 0.063614872548668253, 
              c[ -12][ t]], 
            Times[ 0.055441487066198857, 
              c[ -11][ t]], 
            Times[ 0.044547108751839815, 
              c[ -10][ t]], 
            Times[ 0.031322974491347078, 
              c[ -9][ t]], 
            Times[ 0.016273855731265604, 
              c[ -8][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -7][ t]], 
            Times[ -0.016825511857749401, 
              c[ -6][ t]], 
            Times[ -0.033483179628681567, 
              c[ -5][ t]], 
            Times[ -0.049236278094139066, 
              c[ -4][ t]], 
            Times[ -0.063361699504227528, 
              c[ -3][ t]], 
            Times[ -0.075181213012062598, 
              c[ -2][ t]], 
            Times[ -0.084091858737850855, 
              c[ -1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 0][ t]], 
            Times[ -0.091317159035181589, 
              c[ 1][ t]], 
            Times[ -0.089038438663606653, 
              c[ 2][ t]], 
            Times[ -0.082699334313268744, 
              c[ 3][ t]], 
            Times[ -0.072413370861974122, 
              c[ 4][ t]], 
            Times[ -0.058468080236789774, 
              c[ 5][ t]], 
            Times[ -0.04131966847794722, 
              c[ 6][ t]], 
            Times[ -0.021580547817547879, 
              c[ 7][ t]], 
            Times[ 2.2745903278229109*^-16, 
              c[ 8][ t]], 
            Times[ 0.022561481809254869, 
              c[ 9][ t]], 
            Times[ 0.045163358568919301, 
              c[ 10][ t]], 
            Times[ 0.066820663127759972, 
              c[ 11][ t]], 
            Times[ 0.086542809078944891, 
              c[ 12][ t]], 
            Times[ 0.10337416789158609, 
              c[ 13][ t]], 
            Times[ 0.11643488132933186, 
              c[ 14][ t]], 
            Times[ 0.12496032289024853, 
              c[ 15][ t]], 
            Times[ 0.12833762891430928, 
              c[ 16][ t]], 
            Times[ 0.12613778810677612, 
              c[ 17][ t]], 
            Times[ 0.11814190616181253, 
              c[ 18][ t]], 
            Times[ 0.10436044624225685, 
              c[ 19][ t]], 
            Times[ 0.085044480344421608, 
              c[ 20][ t]], 
            Times[ 0.060688263076985001, 
              c[ 21][ t]], 
            Times[ 0.032022748374425904, 
              c[ 22][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 23][ t]], 
            Times[ -0.034231213779559094, 
              c[ 24][ t]], 
            Times[ -0.06935801494512607, 
              c[ 25][ t]], 
            Times[ -0.1039432537542934, 
              c[ 26][ t]], 
            Times[ -0.13647135277833616, 
              c[ 27][ t]], 
            Times[ -0.16539866862653771, 
              c[ 28][ t]], 
            Times[ -0.18920668216016434, 
              c[ 29][ t]], 
            Times[ -0.20645618564475848, 
              c[ 30][ t]], 
            Times[ -0.21584055771952015, 
              c[ 31][ t]], 
            Times[ -0.21623620818304481, 
              c[ 32][ t]], 
            Times[ -0.20674833578317189, 
              c[ 33][ t]], 
            Times[ -0.18675027222298593, 
              c[ 34][ t]], 
            Times[ -0.15591488063143966, 
              c[ 35][ t]], 
            Times[ -0.11423673049785416, 
              c[ 36][ t]], 
            Times[ -0.062044074975450239, 
              c[ 37][ t]], 
            Times[ 3.2169769001083979*^-16, 
              c[ 38][ t]], 
            Times[ 0.070907514257658094, 
              c[ 39][ t]], 
            Times[ 0.14938649372796384, 
              c[ 40][ t]], 
            Times[ 0.23387232094715985, 
              c[ 41][ t]], 
            Times[ 0.32256865202152191, 
              c[ 42][ t]], 
            Times[ 0.41349667156634429, 
              c[ 43][ t]], 
            Times[ 0.50455115242710469, 
              c[ 44][ t]], 
            Times[ 0.59356153372868092, 
              c[ 45][ t]], 
            Times[ 0.67835603854706361, 
              c[ 46][ t]], 
            Times[ 0.75682672864065692, 
              c[ 47][ t]], 
            Times[ 0.82699334313268846, 
              c[ 48][ t]], 
            Times[ 0.88706379305918392, 
              c[ 49][ t]], 
            Times[ 0.93548928378863916, 
              c[ 50][ t]], 
            Times[ 0.9710122092317629, 
              c[ 51][ t]], 
            Times[ 0.99270519960720693, 
              c[ 52][ t]], 
            Times[ 62.608263917022221, 
              c[ 53][ t]], 
            Times[ 0.99270519960720671, 
              c[ 54][ t]], 
            Times[ 0.9710122092317629, 
              c[ 55][ t]], 
            Times[ 0.93548928378863916, 
              c[ 56][ t]], 
            Times[ 0.88706379305918348, 
              c[ 57][ t]], 
            Times[ 0.82699334313268802, 
              c[ 58][ t]], 
            Times[ 0.75682672864065692, 
              c[ 59][ t]], 
            Times[ 0.67835603854706272, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "54", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[54]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.039832985717929335`\)\ \(c[\(-60\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-59\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-58\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-57\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-56\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-55\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-54\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-53\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-52\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-51\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-50\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-49\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-48\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-47\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-46\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-45\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-44\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-43\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-42\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-41\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-40\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-39\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-38\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-37\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-36\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-35\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-34\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-33\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-32\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-31\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-30\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-29\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-28\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-27\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-26\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-25\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-24\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-23\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-22\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-21\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-20\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-19\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-18\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-17\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-16\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-15\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-14\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-13\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-12\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-11\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-10\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-9\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-8\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-7\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-6\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-5\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-4\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-3\)]\)[t] - 
            0.0633616995042274`\ \(c[\(-2\)]\)[t] - 
            0.0751812130120626`\ \(c[\(-1\)]\)[t] - 
            0.08409185873785081`\ \(c[0]\)[t] - 
            0.08959419377036684`\ \(c[1]\)[t] - 
            0.09131715903518159`\ \(c[2]\)[t] - 
            0.0890384386636067`\ \(c[3]\)[t] - 
            0.08269933431326881`\ \(c[4]\)[t] - 
            0.07241337086197412`\ \(c[5]\)[t] - 
            0.05846808023678991`\ \(c[6]\)[t] - 
            0.04131966847794737`\ \(c[7]\)[t] - 
            0.02158054781754788`\ \(c[8]\)[t] + 
            3.8981718325193755`*^-17\ \(c[9]\)[t] + 
            0.022561481809254675`\ \(c[10]\)[t] + 
            0.045163358568919114`\ \(c[11]\)[t] + 
            0.06682066312775997`\ \(c[12]\)[t] + 
            0.08654280907894475`\ \(c[13]\)[t] + 
            0.10337416789158595`\ \(c[14]\)[t] + 
            0.11643488132933186`\ \(c[15]\)[t] + 
            0.12496032289024847`\ \(c[16]\)[t] + 
            0.12833762891430925`\ \(c[17]\)[t] + 
            0.12613778810677614`\ \(c[18]\)[t] + 
            0.1181419061618126`\ \(c[19]\)[t] + 
            0.10436044624225692`\ \(c[20]\)[t] + 
            0.0850444803444217`\ \(c[21]\)[t] + 
            0.06068826307698522`\ \(c[22]\)[t] + 
            0.03202274837442603`\ \(c[23]\)[t] - 
            3.898171832519376`*^-17\ \(c[24]\)[t] - 
            0.034231213779558796`\ \(c[25]\)[t] - 
            0.06935801494512592`\ \(c[26]\)[t] - 
            0.10394325375429328`\ \(c[27]\)[t] - 
            0.1364713527783359`\ \(c[28]\)[t] - 
            0.1653986686265376`\ \(c[29]\)[t] - 
            0.18920668216016426`\ \(c[30]\)[t] - 
            0.20645618564475834`\ \(c[31]\)[t] - 
            0.21584055771952013`\ \(c[32]\)[t] - 
            0.21623620818304484`\ \(c[33]\)[t] - 
            0.20674833578317206`\ \(c[34]\)[t] - 
            0.18675027222298607`\ \(c[35]\)[t] - 
            0.15591488063143982`\ \(c[36]\)[t] - 
            0.11423673049785459`\ \(c[37]\)[t] - 
            0.062044074975450475`\ \(c[38]\)[t] + 
            3.898171832519376`*^-17\ \(c[39]\)[t] + 
            0.07090751425765746`\ \(c[40]\)[t] + 
            0.14938649372796314`\ \(c[41]\)[t] + 
            0.23387232094715985`\ \(c[42]\)[t] + 
            0.32256865202152113`\ \(c[43]\)[t] + 
            0.4134966715663436`\ \(c[44]\)[t] + 
            0.5045511524271047`\ \(c[45]\)[t] + 
            0.5935615337286801`\ \(c[46]\)[t] + 
            0.6783560385470627`\ \(c[47]\)[t] + 
            0.7568267286406569`\ \(c[48]\)[t] + 
            0.826993343132688`\ \(c[49]\)[t] + 
            0.8870637930591835`\ \(c[50]\)[t] + 
            0.9354892837886392`\ \(c[51]\)[t] + 
            0.9710122092317629`\ \(c[52]\)[t] + 
            0.9927051996072067`\ \(c[53]\)[t] + 
            64.95503651905904`\ \(c[54]\)[t] + 
            0.9927051996072069`\ \(c[55]\)[t] + 
            0.9710122092317629`\ \(c[56]\)[t] + 
            0.9354892837886392`\ \(c[57]\)[t] + 
            0.8870637930591839`\ \(c[58]\)[t] + 
            0.8269933431326885`\ \(c[59]\)[t] + 
            0.7568267286406569`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 54, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 54]][ t]], 
          Plus[ 
            Times[ -0.039832985717929335, 
              c[ -60][ t]], 
            Times[ -0.042022055485216314, 
              c[ -59][ t]], 
            Times[ -0.042397252409191441, 
              c[ -58][ t]], 
            Times[ -0.040909552899494966, 
              c[ -57][ t]], 
            Times[ -0.037590606506031236, 
              c[ -56][ t]], 
            Times[ -0.032552799745291155, 
              c[ -55][ t]], 
            Times[ -0.025985813438573278, 
              c[ -54][ t]], 
            Times[ -0.018149760920219783, 
              c[ -53][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -52][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -51][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -50][ t]], 
            Times[ 0.018854606004500233, 
              c[ -49][ t]], 
            Times[ 0.027514390699665887, 
              c[ -48][ t]], 
            Times[ 0.035131239329076656, 
              c[ -47][ t]], 
            Times[ 0.041349667156634483, 
              c[ -46][ t]], 
            Times[ 0.045868286584282256, 
              c[ -45][ t]], 
            Times[ 0.048454002753361682, 
              c[ -44][ t]], 
            Times[ 0.04895352855494272, 
              c[ -43][ t]], 
            Times[ 0.047301670540041058, 
              c[ -42][ t]], 
            Times[ 0.043525965428036162, 
              c[ -41][ t]], 
            Times[ 0.03774739544932687, 
              c[ -40][ t]], 
            Times[ 0.030177073670601236, 
              c[ -39][ t]], 
            Times[ 0.021108961070255627, 
              c[ -38][ t]], 
            Times[ 0.010908848347331966, 
              c[ -37][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -36][ t]], 
            Times[ -0.011153991006822649, 
              c[ -35][ t]], 
            Times[ -0.022068459300722043, 
              c[ -34][ t]], 
            Times[ -0.032258251165125519, 
              c[ -33][ t]], 
            Times[ -0.041258781072520248, 
              c[ -32][ t]], 
            Times[ -0.048646667243099281, 
              c[ -31][ t]], 
            Times[ -0.054059052045761224, 
              c[ -30][ t]], 
            Times[ -0.057210750238908967, 
              c[ -29][ t]], 
            Times[ -0.057908442314993203, 
              c[ -28][ t]], 
            Times[ -0.056061239158567186, 
              c[ -27][ t]], 
            Times[ -0.05168708394579296, 
              c[ -26][ t]], 
            Times[ -0.044914622433376419, 
              c[ -25][ t]], 
            Times[ -0.035980357068793781, 
              c[ -24][ t]], 
            Times[ -0.025221096343682053, 
              c[ -23][ t]], 
            Times[ -0.013061910521147383, 
              c[ -22][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -21][ t]], 
            Times[ 0.013414935129827233, 
              c[ -20][ t]], 
            Times[ 0.026603074225527826, 
              c[ -19][ t]], 
            Times[ 0.03897872015785999, 
              c[ -18][ t]], 
            Times[ 0.049975424961080865, 
              c[ -17][ t]], 
            Times[ 0.059070953080906326, 
              c[ -16][ t]], 
            Times[ 0.065811019881796273, 
              c[ -15][ t]], 
            Times[ 0.069830768673962415, 
              c[ -14][ t]], 
            Times[ 0.070873018952678238, 
              c[ -13][ t]], 
            Times[ 0.068802429876423349, 
              c[ -12][ t]], 
            Times[ 0.063614872548668253, 
              c[ -11][ t]], 
            Times[ 0.055441487066198933, 
              c[ -10][ t]], 
            Times[ 0.044547108751839919, 
              c[ -9][ t]], 
            Times[ 0.031322974491347202, 
              c[ -8][ t]], 
            Times[ 0.016273855731265604, 
              c[ -7][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -6][ t]], 
            Times[ -0.016825511857749262, 
              c[ -5][ t]], 
            Times[ -0.033483179628681567, 
              c[ -4][ t]], 
            Times[ -0.049236278094138941, 
              c[ -3][ t]], 
            Times[ -0.063361699504227403, 
              c[ -2][ t]], 
            Times[ -0.075181213012062598, 
              c[ -1][ t]], 
            Times[ -0.084091858737850814, 
              c[ 0][ t]], 
            Times[ -0.089594193770366842, 
              c[ 1][ t]], 
            Times[ -0.091317159035181589, 
              c[ 2][ t]], 
            Times[ -0.089038438663606695, 
              c[ 3][ t]], 
            Times[ -0.082699334313268813, 
              c[ 4][ t]], 
            Times[ -0.072413370861974122, 
              c[ 5][ t]], 
            Times[ -0.058468080236789913, 
              c[ 6][ t]], 
            Times[ -0.041319668477947373, 
              c[ 7][ t]], 
            Times[ -0.021580547817547879, 
              c[ 8][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 9][ t]], 
            Times[ 0.022561481809254675, 
              c[ 10][ t]], 
            Times[ 0.045163358568919114, 
              c[ 11][ t]], 
            Times[ 0.066820663127759972, 
              c[ 12][ t]], 
            Times[ 0.086542809078944752, 
              c[ 13][ t]], 
            Times[ 0.10337416789158595, 
              c[ 14][ t]], 
            Times[ 0.11643488132933186, 
              c[ 15][ t]], 
            Times[ 0.12496032289024847, 
              c[ 16][ t]], 
            Times[ 0.12833762891430925, 
              c[ 17][ t]], 
            Times[ 0.12613778810677614, 
              c[ 18][ t]], 
            Times[ 0.1181419061618126, 
              c[ 19][ t]], 
            Times[ 0.10436044624225692, 
              c[ 20][ t]], 
            Times[ 0.085044480344421705, 
              c[ 21][ t]], 
            Times[ 0.060688263076985223, 
              c[ 22][ t]], 
            Times[ 0.032022748374426029, 
              c[ 23][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 24][ t]], 
            Times[ -0.034231213779558796, 
              c[ 25][ t]], 
            Times[ -0.069358014945125918, 
              c[ 26][ t]], 
            Times[ -0.10394325375429328, 
              c[ 27][ t]], 
            Times[ -0.13647135277833591, 
              c[ 28][ t]], 
            Times[ -0.1653986686265376, 
              c[ 29][ t]], 
            Times[ -0.18920668216016426, 
              c[ 30][ t]], 
            Times[ -0.20645618564475834, 
              c[ 31][ t]], 
            Times[ -0.21584055771952013, 
              c[ 32][ t]], 
            Times[ -0.21623620818304484, 
              c[ 33][ t]], 
            Times[ -0.20674833578317206, 
              c[ 34][ t]], 
            Times[ -0.18675027222298607, 
              c[ 35][ t]], 
            Times[ -0.15591488063143982, 
              c[ 36][ t]], 
            Times[ -0.11423673049785459, 
              c[ 37][ t]], 
            Times[ -0.062044074975450475, 
              c[ 38][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 39][ t]], 
            Times[ 0.070907514257657456, 
              c[ 40][ t]], 
            Times[ 0.14938649372796314, 
              c[ 41][ t]], 
            Times[ 0.23387232094715985, 
              c[ 42][ t]], 
            Times[ 0.32256865202152113, 
              c[ 43][ t]], 
            Times[ 0.41349667156634362, 
              c[ 44][ t]], 
            Times[ 0.50455115242710469, 
              c[ 45][ t]], 
            Times[ 0.59356153372868015, 
              c[ 46][ t]], 
            Times[ 0.67835603854706272, 
              c[ 47][ t]], 
            Times[ 0.75682672864065692, 
              c[ 48][ t]], 
            Times[ 0.82699334313268802, 
              c[ 49][ t]], 
            Times[ 0.88706379305918348, 
              c[ 50][ t]], 
            Times[ 0.93548928378863916, 
              c[ 51][ t]], 
            Times[ 0.9710122092317629, 
              c[ 52][ t]], 
            Times[ 0.99270519960720671, 
              c[ 53][ t]], 
            Times[ 64.955036519059036, 
              c[ 54][ t]], 
            Times[ 0.99270519960720693, 
              c[ 55][ t]], 
            Times[ 0.9710122092317629, 
              c[ 56][ t]], 
            Times[ 0.93548928378863916, 
              c[ 57][ t]], 
            Times[ 0.88706379305918392, 
              c[ 58][ t]], 
            Times[ 0.82699334313268846, 
              c[ 59][ t]], 
            Times[ 0.75682672864065692, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "55", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[55]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.03595623231011687`\)\ \(c[\(-60\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-59\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-58\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-57\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-56\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-55\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-54\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-53\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-52\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-51\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-50\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-49\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-48\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-47\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-46\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-45\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-44\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-43\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-42\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-41\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-40\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-39\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-38\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-37\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-36\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-35\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-34\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-33\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-32\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-31\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-30\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-29\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-28\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-27\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-26\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-25\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-24\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-23\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-22\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-21\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-20\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-19\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-18\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-17\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-16\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-15\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-14\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-13\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-12\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-11\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-10\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-9\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-8\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-7\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-6\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-5\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-4\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-3\)]\)[t] - 
            0.04923627809413894`\ \(c[\(-2\)]\)[t] - 
            0.06336169950422753`\ \(c[\(-1\)]\)[t] - 
            0.0751812130120626`\ \(c[0]\)[t] - 
            0.08409185873785081`\ \(c[1]\)[t] - 
            0.08959419377036688`\ \(c[2]\)[t] - 
            0.09131715903518159`\ \(c[3]\)[t] - 
            0.0890384386636067`\ \(c[4]\)[t] - 
            0.08269933431326874`\ \(c[5]\)[t] - 
            0.07241337086197412`\ \(c[6]\)[t] - 
            0.05846808023678991`\ \(c[7]\)[t] - 
            0.04131966847794722`\ \(c[8]\)[t] - 
            0.02158054781754788`\ \(c[9]\)[t] + 
            3.8981718325193755`*^-17\ \(c[10]\)[t] + 
            0.02256148180925487`\ \(c[11]\)[t] + 
            0.0451633585689193`\ \(c[12]\)[t] + 
            0.06682066312775997`\ \(c[13]\)[t] + 
            0.08654280907894489`\ \(c[14]\)[t] + 
            0.10337416789158609`\ \(c[15]\)[t] + 
            0.11643488132933186`\ \(c[16]\)[t] + 
            0.12496032289024853`\ \(c[17]\)[t] + 
            0.12833762891430928`\ \(c[18]\)[t] + 
            0.12613778810677614`\ \(c[19]\)[t] + 
            0.11814190616181255`\ \(c[20]\)[t] + 
            0.10436044624225685`\ \(c[21]\)[t] + 
            0.0850444803444217`\ \(c[22]\)[t] + 
            0.060688263076985105`\ \(c[23]\)[t] + 
            0.032022748374425904`\ \(c[24]\)[t] - 
            3.898171832519376`*^-17\ \(c[25]\)[t] - 
            0.03423121377955895`\ \(c[26]\)[t] - 
            0.06935801494512607`\ \(c[27]\)[t] - 
            0.10394325375429328`\ \(c[28]\)[t] - 
            0.13647135277833605`\ \(c[29]\)[t] - 
            0.1653986686265377`\ \(c[30]\)[t] - 
            0.18920668216016426`\ \(c[31]\)[t] - 
            0.20645618564475843`\ \(c[32]\)[t] - 
            0.21584055771952015`\ \(c[33]\)[t] - 
            0.21623620818304484`\ \(c[34]\)[t] - 
            0.206748335783172`\ \(c[35]\)[t] - 
            0.18675027222298593`\ \(c[36]\)[t] - 
            0.15591488063143982`\ \(c[37]\)[t] - 
            0.11423673049785436`\ \(c[38]\)[t] - 
            0.06204407497545024`\ \(c[39]\)[t] + 
            3.898171832519376`*^-17\ \(c[40]\)[t] + 
            0.07090751425765746`\ \(c[41]\)[t] + 
            0.14938649372796384`\ \(c[42]\)[t] + 
            0.23387232094715985`\ \(c[43]\)[t] + 
            0.32256865202152113`\ \(c[44]\)[t] + 
            0.4134966715663443`\ \(c[45]\)[t] + 
            0.5045511524271047`\ \(c[46]\)[t] + 
            0.5935615337286801`\ \(c[47]\)[t] + 
            0.6783560385470636`\ \(c[48]\)[t] + 
            0.7568267286406569`\ \(c[49]\)[t] + 
            0.826993343132688`\ \(c[50]\)[t] + 
            0.8870637930591839`\ \(c[51]\)[t] + 
            0.9354892837886392`\ \(c[52]\)[t] + 
            0.9710122092317629`\ \(c[53]\)[t] + 
            0.9927051996072069`\ \(c[54]\)[t] + 
            67.34567402954512`\ \(c[55]\)[t] + 
            0.9927051996072069`\ \(c[56]\)[t] + 
            0.9710122092317629`\ \(c[57]\)[t] + 
            0.9354892837886392`\ \(c[58]\)[t] + 
            0.8870637930591839`\ \(c[59]\)[t] + 
            0.826993343132688`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 55, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 55]][ t]], 
          Plus[ 
            Times[ -0.035956232310116867, 
              c[ -60][ t]], 
            Times[ -0.039832985717929335, 
              c[ -59][ t]], 
            Times[ -0.042022055485216314, 
              c[ -58][ t]], 
            Times[ -0.042397252409191441, 
              c[ -57][ t]], 
            Times[ -0.040909552899494925, 
              c[ -56][ t]], 
            Times[ -0.037590606506031236, 
              c[ -55][ t]], 
            Times[ -0.032552799745291155, 
              c[ -54][ t]], 
            Times[ -0.025985813438573278, 
              c[ -53][ t]], 
            Times[ -0.018149760920219783, 
              c[ -52][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -51][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -50][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -49][ t]], 
            Times[ 0.018854606004500233, 
              c[ -48][ t]], 
            Times[ 0.027514390699665887, 
              c[ -47][ t]], 
            Times[ 0.035131239329076656, 
              c[ -46][ t]], 
            Times[ 0.041349667156634483, 
              c[ -45][ t]], 
            Times[ 0.045868286584282311, 
              c[ -44][ t]], 
            Times[ 0.048454002753361682, 
              c[ -43][ t]], 
            Times[ 0.04895352855494272, 
              c[ -42][ t]], 
            Times[ 0.047301670540041058, 
              c[ -41][ t]], 
            Times[ 0.043525965428036162, 
              c[ -40][ t]], 
            Times[ 0.03774739544932687, 
              c[ -39][ t]], 
            Times[ 0.030177073670601236, 
              c[ -38][ t]], 
            Times[ 0.021108961070255627, 
              c[ -37][ t]], 
            Times[ 0.010908848347331966, 
              c[ -36][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -35][ t]], 
            Times[ -0.011153991006822649, 
              c[ -34][ t]], 
            Times[ -0.022068459300722043, 
              c[ -33][ t]], 
            Times[ -0.032258251165125519, 
              c[ -32][ t]], 
            Times[ -0.041258781072520248, 
              c[ -31][ t]], 
            Times[ -0.048646667243099281, 
              c[ -30][ t]], 
            Times[ -0.054059052045761224, 
              c[ -29][ t]], 
            Times[ -0.057210750238908967, 
              c[ -28][ t]], 
            Times[ -0.057908442314993203, 
              c[ -27][ t]], 
            Times[ -0.056061239158567186, 
              c[ -26][ t]], 
            Times[ -0.05168708394579296, 
              c[ -25][ t]], 
            Times[ -0.044914622433376419, 
              c[ -24][ t]], 
            Times[ -0.035980357068793781, 
              c[ -23][ t]], 
            Times[ -0.025221096343682053, 
              c[ -22][ t]], 
            Times[ -0.013061910521147383, 
              c[ -21][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -20][ t]], 
            Times[ 0.013414935129827233, 
              c[ -19][ t]], 
            Times[ 0.026603074225527826, 
              c[ -18][ t]], 
            Times[ 0.03897872015785999, 
              c[ -17][ t]], 
            Times[ 0.049975424961080865, 
              c[ -16][ t]], 
            Times[ 0.059070953080906326, 
              c[ -15][ t]], 
            Times[ 0.065811019881796273, 
              c[ -14][ t]], 
            Times[ 0.069830768673962415, 
              c[ -13][ t]], 
            Times[ 0.070873018952678238, 
              c[ -12][ t]], 
            Times[ 0.068802429876423349, 
              c[ -11][ t]], 
            Times[ 0.063614872548668253, 
              c[ -10][ t]], 
            Times[ 0.055441487066198933, 
              c[ -9][ t]], 
            Times[ 0.044547108751839919, 
              c[ -8][ t]], 
            Times[ 0.031322974491347078, 
              c[ -7][ t]], 
            Times[ 0.016273855731265604, 
              c[ -6][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -5][ t]], 
            Times[ -0.016825511857749401, 
              c[ -4][ t]], 
            Times[ -0.033483179628681567, 
              c[ -3][ t]], 
            Times[ -0.049236278094138941, 
              c[ -2][ t]], 
            Times[ -0.063361699504227528, 
              c[ -1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 0][ t]], 
            Times[ -0.084091858737850814, 
              c[ 1][ t]], 
            Times[ -0.089594193770366884, 
              c[ 2][ t]], 
            Times[ -0.091317159035181589, 
              c[ 3][ t]], 
            Times[ -0.089038438663606695, 
              c[ 4][ t]], 
            Times[ -0.082699334313268744, 
              c[ 5][ t]], 
            Times[ -0.072413370861974122, 
              c[ 6][ t]], 
            Times[ -0.058468080236789913, 
              c[ 7][ t]], 
            Times[ -0.04131966847794722, 
              c[ 8][ t]], 
            Times[ -0.021580547817547879, 
              c[ 9][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 10][ t]], 
            Times[ 0.022561481809254869, 
              c[ 11][ t]], 
            Times[ 0.045163358568919301, 
              c[ 12][ t]], 
            Times[ 0.066820663127759972, 
              c[ 13][ t]], 
            Times[ 0.086542809078944891, 
              c[ 14][ t]], 
            Times[ 0.10337416789158609, 
              c[ 15][ t]], 
            Times[ 0.11643488132933186, 
              c[ 16][ t]], 
            Times[ 0.12496032289024853, 
              c[ 17][ t]], 
            Times[ 0.12833762891430928, 
              c[ 18][ t]], 
            Times[ 0.12613778810677614, 
              c[ 19][ t]], 
            Times[ 0.11814190616181255, 
              c[ 20][ t]], 
            Times[ 0.10436044624225685, 
              c[ 21][ t]], 
            Times[ 0.085044480344421705, 
              c[ 22][ t]], 
            Times[ 0.060688263076985105, 
              c[ 23][ t]], 
            Times[ 0.032022748374425904, 
              c[ 24][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 25][ t]], 
            Times[ -0.034231213779558949, 
              c[ 26][ t]], 
            Times[ -0.06935801494512607, 
              c[ 27][ t]], 
            Times[ -0.10394325375429328, 
              c[ 28][ t]], 
            Times[ -0.13647135277833605, 
              c[ 29][ t]], 
            Times[ -0.16539866862653771, 
              c[ 30][ t]], 
            Times[ -0.18920668216016426, 
              c[ 31][ t]], 
            Times[ -0.20645618564475843, 
              c[ 32][ t]], 
            Times[ -0.21584055771952015, 
              c[ 33][ t]], 
            Times[ -0.21623620818304484, 
              c[ 34][ t]], 
            Times[ -0.206748335783172, 
              c[ 35][ t]], 
            Times[ -0.18675027222298593, 
              c[ 36][ t]], 
            Times[ -0.15591488063143982, 
              c[ 37][ t]], 
            Times[ -0.11423673049785436, 
              c[ 38][ t]], 
            Times[ -0.062044074975450239, 
              c[ 39][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 40][ t]], 
            Times[ 0.070907514257657456, 
              c[ 41][ t]], 
            Times[ 0.14938649372796384, 
              c[ 42][ t]], 
            Times[ 0.23387232094715985, 
              c[ 43][ t]], 
            Times[ 0.32256865202152113, 
              c[ 44][ t]], 
            Times[ 0.41349667156634429, 
              c[ 45][ t]], 
            Times[ 0.50455115242710469, 
              c[ 46][ t]], 
            Times[ 0.59356153372868015, 
              c[ 47][ t]], 
            Times[ 0.67835603854706361, 
              c[ 48][ t]], 
            Times[ 0.75682672864065692, 
              c[ 49][ t]], 
            Times[ 0.82699334313268802, 
              c[ 50][ t]], 
            Times[ 0.88706379305918392, 
              c[ 51][ t]], 
            Times[ 0.93548928378863916, 
              c[ 52][ t]], 
            Times[ 0.9710122092317629, 
              c[ 53][ t]], 
            Times[ 0.99270519960720693, 
              c[ 54][ t]], 
            Times[ 67.345674029545123, 
              c[ 55][ t]], 
            Times[ 0.99270519960720693, 
              c[ 56][ t]], 
            Times[ 0.9710122092317629, 
              c[ 57][ t]], 
            Times[ 0.93548928378863916, 
              c[ 58][ t]], 
            Times[ 0.88706379305918392, 
              c[ 59][ t]], 
            Times[ 0.82699334313268802, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "56", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[56]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.030588406657213296`\)\ \(c[\(-60\)]\)[t] - 
            0.035956232310116944`\ \(c[\(-59\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-58\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-57\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-56\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-55\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-54\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-53\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-52\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-51\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-50\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-49\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-48\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-47\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-46\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-45\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-44\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-43\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-42\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-41\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-40\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-39\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-38\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-37\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-36\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-35\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-34\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-33\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-32\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-31\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-30\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-29\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-28\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-27\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-26\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-25\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-24\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-23\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-22\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-21\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-20\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-19\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-18\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-17\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-16\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-15\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-14\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-13\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-12\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-11\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-10\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-9\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-8\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-7\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-6\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-5\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-4\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-3\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-2\)]\)[t] - 
            0.049236278094139066`\ \(c[\(-1\)]\)[t] - 
            0.06336169950422753`\ \(c[0]\)[t] - 
            0.0751812130120626`\ \(c[1]\)[t] - 
            0.08409185873785086`\ \(c[2]\)[t] - 
            0.08959419377036688`\ \(c[3]\)[t] - 
            0.09131715903518159`\ \(c[4]\)[t] - 
            0.08903843866360665`\ \(c[5]\)[t] - 
            0.08269933431326874`\ \(c[6]\)[t] - 
            0.07241337086197412`\ \(c[7]\)[t] - 
            0.058468080236789774`\ \(c[8]\)[t] - 
            0.04131966847794722`\ \(c[9]\)[t] - 
            0.02158054781754788`\ \(c[10]\)[t] + 
            3.8981718325193755`*^-17\ \(c[11]\)[t] + 
            0.02256148180925487`\ \(c[12]\)[t] + 
            0.0451633585689193`\ \(c[13]\)[t] + 
            0.06682066312775997`\ \(c[14]\)[t] + 
            0.08654280907894489`\ \(c[15]\)[t] + 
            0.10337416789158609`\ \(c[16]\)[t] + 
            0.11643488132933186`\ \(c[17]\)[t] + 
            0.12496032289024853`\ \(c[18]\)[t] + 
            0.12833762891430928`\ \(c[19]\)[t] + 
            0.12613778810677612`\ \(c[20]\)[t] + 
            0.11814190616181253`\ \(c[21]\)[t] + 
            0.10436044624225685`\ \(c[22]\)[t] + 
            0.08504448034442161`\ \(c[23]\)[t] + 
            0.060688263076985`\ \(c[24]\)[t] + 
            0.032022748374425904`\ \(c[25]\)[t] - 
            1.8033970416801674`*^-16\ \(c[26]\)[t] - 
            0.034231213779559094`\ \(c[27]\)[t] - 
            0.06935801494512607`\ \(c[28]\)[t] - 
            0.1039432537542934`\ \(c[29]\)[t] - 
            0.13647135277833616`\ \(c[30]\)[t] - 
            0.1653986686265377`\ \(c[31]\)[t] - 
            0.18920668216016434`\ \(c[32]\)[t] - 
            0.20645618564475848`\ \(c[33]\)[t] - 
            0.21584055771952015`\ \(c[34]\)[t] - 
            0.21623620818304481`\ \(c[35]\)[t] - 
            0.2067483357831719`\ \(c[36]\)[t] - 
            0.18675027222298593`\ \(c[37]\)[t] - 
            0.15591488063143966`\ \(c[38]\)[t] - 
            0.11423673049785416`\ \(c[39]\)[t] - 
            0.06204407497545024`\ \(c[40]\)[t] + 
            3.898171832519376`*^-17\ \(c[41]\)[t] + 
            0.0709075142576581`\ \(c[42]\)[t] + 
            0.14938649372796384`\ \(c[43]\)[t] + 
            0.23387232094715985`\ \(c[44]\)[t] + 
            0.3225686520215219`\ \(c[45]\)[t] + 
            0.4134966715663443`\ \(c[46]\)[t] + 
            0.5045511524271047`\ \(c[47]\)[t] + 
            0.5935615337286809`\ \(c[48]\)[t] + 
            0.6783560385470636`\ \(c[49]\)[t] + 
            0.7568267286406569`\ \(c[50]\)[t] + 
            0.8269933431326885`\ \(c[51]\)[t] + 
            0.8870637930591839`\ \(c[52]\)[t] + 
            0.9354892837886392`\ \(c[53]\)[t] + 
            0.9710122092317629`\ \(c[54]\)[t] + 
            0.9927051996072069`\ \(c[55]\)[t] + 
            69.78017644848049`\ \(c[56]\)[t] + 
            0.9927051996072067`\ \(c[57]\)[t] + 
            0.9710122092317629`\ \(c[58]\)[t] + 
            0.9354892837886392`\ \(c[59]\)[t] + 
            0.8870637930591835`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 56, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 56]][ t]], 
          Plus[ 
            Times[ -0.030588406657213296, 
              c[ -60][ t]], 
            Times[ -0.035956232310116944, 
              c[ -59][ t]], 
            Times[ -0.039832985717929335, 
              c[ -58][ t]], 
            Times[ -0.042022055485216314, 
              c[ -57][ t]], 
            Times[ -0.042397252409191441, 
              c[ -56][ t]], 
            Times[ -0.040909552899494925, 
              c[ -55][ t]], 
            Times[ -0.037590606506031236, 
              c[ -54][ t]], 
            Times[ -0.032552799745291051, 
              c[ -53][ t]], 
            Times[ -0.025985813438573278, 
              c[ -52][ t]], 
            Times[ -0.018149760920219783, 
              c[ -51][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -50][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -49][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -48][ t]], 
            Times[ 0.018854606004500389, 
              c[ -47][ t]], 
            Times[ 0.027514390699665887, 
              c[ -46][ t]], 
            Times[ 0.035131239329076656, 
              c[ -45][ t]], 
            Times[ 0.041349667156634483, 
              c[ -44][ t]], 
            Times[ 0.045868286584282311, 
              c[ -43][ t]], 
            Times[ 0.048454002753361682, 
              c[ -42][ t]], 
            Times[ 0.048953528554942699, 
              c[ -41][ t]], 
            Times[ 0.047301670540041058, 
              c[ -40][ t]], 
            Times[ 0.043525965428036162, 
              c[ -39][ t]], 
            Times[ 0.03774739544932687, 
              c[ -38][ t]], 
            Times[ 0.030177073670601094, 
              c[ -37][ t]], 
            Times[ 0.021108961070255627, 
              c[ -36][ t]], 
            Times[ 0.010908848347331785, 
              c[ -35][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -34][ t]], 
            Times[ -0.011153991006822649, 
              c[ -33][ t]], 
            Times[ -0.022068459300722043, 
              c[ -32][ t]], 
            Times[ -0.032258251165125679, 
              c[ -31][ t]], 
            Times[ -0.041258781072520248, 
              c[ -30][ t]], 
            Times[ -0.048646667243099399, 
              c[ -29][ t]], 
            Times[ -0.054059052045761224, 
              c[ -28][ t]], 
            Times[ -0.057210750238908967, 
              c[ -27][ t]], 
            Times[ -0.057908442314993203, 
              c[ -26][ t]], 
            Times[ -0.05606123915856713, 
              c[ -25][ t]], 
            Times[ -0.05168708394579296, 
              c[ -24][ t]], 
            Times[ -0.044914622433376288, 
              c[ -23][ t]], 
            Times[ -0.035980357068793781, 
              c[ -22][ t]], 
            Times[ -0.025221096343682053, 
              c[ -21][ t]], 
            Times[ -0.013061910521147276, 
              c[ -20][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -19][ t]], 
            Times[ 0.013414935129827233, 
              c[ -18][ t]], 
            Times[ 0.026603074225527937, 
              c[ -17][ t]], 
            Times[ 0.038978720157860088, 
              c[ -16][ t]], 
            Times[ 0.049975424961080865, 
              c[ -15][ t]], 
            Times[ 0.059070953080906402, 
              c[ -14][ t]], 
            Times[ 0.065811019881796315, 
              c[ -13][ t]], 
            Times[ 0.069830768673962415, 
              c[ -12][ t]], 
            Times[ 0.070873018952678238, 
              c[ -11][ t]], 
            Times[ 0.068802429876423321, 
              c[ -10][ t]], 
            Times[ 0.063614872548668253, 
              c[ -9][ t]], 
            Times[ 0.055441487066198933, 
              c[ -8][ t]], 
            Times[ 0.044547108751839815, 
              c[ -7][ t]], 
            Times[ 0.031322974491347078, 
              c[ -6][ t]], 
            Times[ 0.016273855731265604, 
              c[ -5][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -4][ t]], 
            Times[ -0.016825511857749401, 
              c[ -3][ t]], 
            Times[ -0.033483179628681567, 
              c[ -2][ t]], 
            Times[ -0.049236278094139066, 
              c[ -1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 0][ t]], 
            Times[ -0.075181213012062598, 
              c[ 1][ t]], 
            Times[ -0.084091858737850855, 
              c[ 2][ t]], 
            Times[ -0.089594193770366884, 
              c[ 3][ t]], 
            Times[ -0.091317159035181589, 
              c[ 4][ t]], 
            Times[ -0.089038438663606653, 
              c[ 5][ t]], 
            Times[ -0.082699334313268744, 
              c[ 6][ t]], 
            Times[ -0.072413370861974122, 
              c[ 7][ t]], 
            Times[ -0.058468080236789774, 
              c[ 8][ t]], 
            Times[ -0.04131966847794722, 
              c[ 9][ t]], 
            Times[ -0.021580547817547879, 
              c[ 10][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 11][ t]], 
            Times[ 0.022561481809254869, 
              c[ 12][ t]], 
            Times[ 0.045163358568919301, 
              c[ 13][ t]], 
            Times[ 0.066820663127759972, 
              c[ 14][ t]], 
            Times[ 0.086542809078944891, 
              c[ 15][ t]], 
            Times[ 0.10337416789158609, 
              c[ 16][ t]], 
            Times[ 0.11643488132933186, 
              c[ 17][ t]], 
            Times[ 0.12496032289024853, 
              c[ 18][ t]], 
            Times[ 0.12833762891430928, 
              c[ 19][ t]], 
            Times[ 0.12613778810677612, 
              c[ 20][ t]], 
            Times[ 0.11814190616181253, 
              c[ 21][ t]], 
            Times[ 0.10436044624225685, 
              c[ 22][ t]], 
            Times[ 0.085044480344421608, 
              c[ 23][ t]], 
            Times[ 0.060688263076985001, 
              c[ 24][ t]], 
            Times[ 0.032022748374425904, 
              c[ 25][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 26][ t]], 
            Times[ -0.034231213779559094, 
              c[ 27][ t]], 
            Times[ -0.06935801494512607, 
              c[ 28][ t]], 
            Times[ -0.1039432537542934, 
              c[ 29][ t]], 
            Times[ -0.13647135277833616, 
              c[ 30][ t]], 
            Times[ -0.16539866862653771, 
              c[ 31][ t]], 
            Times[ -0.18920668216016434, 
              c[ 32][ t]], 
            Times[ -0.20645618564475848, 
              c[ 33][ t]], 
            Times[ -0.21584055771952015, 
              c[ 34][ t]], 
            Times[ -0.21623620818304481, 
              c[ 35][ t]], 
            Times[ -0.20674833578317189, 
              c[ 36][ t]], 
            Times[ -0.18675027222298593, 
              c[ 37][ t]], 
            Times[ -0.15591488063143966, 
              c[ 38][ t]], 
            Times[ -0.11423673049785416, 
              c[ 39][ t]], 
            Times[ -0.062044074975450239, 
              c[ 40][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 41][ t]], 
            Times[ 0.070907514257658094, 
              c[ 42][ t]], 
            Times[ 0.14938649372796384, 
              c[ 43][ t]], 
            Times[ 0.23387232094715985, 
              c[ 44][ t]], 
            Times[ 0.32256865202152191, 
              c[ 45][ t]], 
            Times[ 0.41349667156634429, 
              c[ 46][ t]], 
            Times[ 0.50455115242710469, 
              c[ 47][ t]], 
            Times[ 0.59356153372868092, 
              c[ 48][ t]], 
            Times[ 0.67835603854706361, 
              c[ 49][ t]], 
            Times[ 0.75682672864065692, 
              c[ 50][ t]], 
            Times[ 0.82699334313268846, 
              c[ 51][ t]], 
            Times[ 0.88706379305918392, 
              c[ 52][ t]], 
            Times[ 0.93548928378863916, 
              c[ 53][ t]], 
            Times[ 0.9710122092317629, 
              c[ 54][ t]], 
            Times[ 0.99270519960720693, 
              c[ 55][ t]], 
            Times[ 69.780176448480489, 
              c[ 56][ t]], 
            Times[ 0.99270519960720671, 
              c[ 57][ t]], 
            Times[ 0.9710122092317629, 
              c[ 58][ t]], 
            Times[ 0.93548928378863916, 
              c[ 59][ t]], 
            Times[ 0.88706379305918348, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "57", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[57]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.023986904712529237`\)\ \(c[\(-60\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-59\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-58\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-57\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-56\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-55\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-54\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-53\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-52\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-51\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-50\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-49\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-48\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-47\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-46\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-45\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-44\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-43\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-42\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-41\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-40\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-39\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-38\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-37\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-36\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-35\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-34\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-33\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-32\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-31\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-30\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-29\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-28\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-27\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-26\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-25\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-24\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-23\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-22\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-21\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-20\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-19\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-18\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-17\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-16\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-15\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-14\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-13\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-12\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-11\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-10\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-9\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-8\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-7\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-6\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-5\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-4\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-3\)]\)[t] - 
            0.016825511857749262`\ \(c[\(-2\)]\)[t] - 
            0.03348317962868157`\ \(c[\(-1\)]\)[t] - 
            0.04923627809413894`\ \(c[0]\)[t] - 
            0.0633616995042274`\ \(c[1]\)[t] - 
            0.0751812130120626`\ \(c[2]\)[t] - 
            0.08409185873785081`\ \(c[3]\)[t] - 
            0.08959419377036684`\ \(c[4]\)[t] - 
            0.09131715903518159`\ \(c[5]\)[t] - 
            0.0890384386636067`\ \(c[6]\)[t] - 
            0.08269933431326881`\ \(c[7]\)[t] - 
            0.07241337086197412`\ \(c[8]\)[t] - 
            0.05846808023678991`\ \(c[9]\)[t] - 
            0.04131966847794737`\ \(c[10]\)[t] - 
            0.021580547817548056`\ \(c[11]\)[t] + 
            3.8981718325193755`*^-17\ \(c[12]\)[t] + 
            0.022561481809254675`\ \(c[13]\)[t] + 
            0.045163358568919114`\ \(c[14]\)[t] + 
            0.06682066312775997`\ \(c[15]\)[t] + 
            0.08654280907894475`\ \(c[16]\)[t] + 
            0.10337416789158595`\ \(c[17]\)[t] + 
            0.11643488132933186`\ \(c[18]\)[t] + 
            0.12496032289024847`\ \(c[19]\)[t] + 
            0.12833762891430925`\ \(c[20]\)[t] + 
            0.12613778810677614`\ \(c[21]\)[t] + 
            0.1181419061618126`\ \(c[22]\)[t] + 
            0.10436044624225692`\ \(c[23]\)[t] + 
            0.0850444803444217`\ \(c[24]\)[t] + 
            0.06068826307698522`\ \(c[25]\)[t] + 
            0.03202274837442603`\ \(c[26]\)[t] - 
            3.898171832519376`*^-17\ \(c[27]\)[t] - 
            0.034231213779558796`\ \(c[28]\)[t] - 
            0.06935801494512592`\ \(c[29]\)[t] - 
            0.10394325375429328`\ \(c[30]\)[t] - 
            0.1364713527783359`\ \(c[31]\)[t] - 
            0.1653986686265376`\ \(c[32]\)[t] - 
            0.18920668216016426`\ \(c[33]\)[t] - 
            0.20645618564475834`\ \(c[34]\)[t] - 
            0.21584055771952013`\ \(c[35]\)[t] - 
            0.21623620818304484`\ \(c[36]\)[t] - 
            0.20674833578317206`\ \(c[37]\)[t] - 
            0.18675027222298607`\ \(c[38]\)[t] - 
            0.15591488063143982`\ \(c[39]\)[t] - 
            0.11423673049785459`\ \(c[40]\)[t] - 
            0.06204407497545072`\ \(c[41]\)[t] + 
            3.898171832519376`*^-17\ \(c[42]\)[t] + 
            0.07090751425765746`\ \(c[43]\)[t] + 
            0.14938649372796314`\ \(c[44]\)[t] + 
            0.23387232094715985`\ \(c[45]\)[t] + 
            0.32256865202152113`\ \(c[46]\)[t] + 
            0.4134966715663436`\ \(c[47]\)[t] + 
            0.5045511524271047`\ \(c[48]\)[t] + 
            0.5935615337286801`\ \(c[49]\)[t] + 
            0.6783560385470627`\ \(c[50]\)[t] + 
            0.7568267286406569`\ \(c[51]\)[t] + 
            0.826993343132688`\ \(c[52]\)[t] + 
            0.8870637930591835`\ \(c[53]\)[t] + 
            0.9354892837886392`\ \(c[54]\)[t] + 
            0.9710122092317629`\ \(c[55]\)[t] + 
            0.9927051996072067`\ \(c[56]\)[t] + 
            72.25854377586516`\ \(c[57]\)[t] + 
            0.9927051996072069`\ \(c[58]\)[t] + 
            0.9710122092317629`\ \(c[59]\)[t] + 
            0.9354892837886392`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 57, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 57]][ t]], 
          Plus[ 
            Times[ -0.023986904712529237, 
              c[ -60][ t]], 
            Times[ -0.030588406657213296, 
              c[ -59][ t]], 
            Times[ -0.035956232310116867, 
              c[ -58][ t]], 
            Times[ -0.039832985717929335, 
              c[ -57][ t]], 
            Times[ -0.042022055485216314, 
              c[ -56][ t]], 
            Times[ -0.042397252409191441, 
              c[ -55][ t]], 
            Times[ -0.040909552899494966, 
              c[ -54][ t]], 
            Times[ -0.037590606506031236, 
              c[ -53][ t]], 
            Times[ -0.032552799745291155, 
              c[ -52][ t]], 
            Times[ -0.025985813438573278, 
              c[ -51][ t]], 
            Times[ -0.018149760920219783, 
              c[ -50][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -49][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -48][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -47][ t]], 
            Times[ 0.018854606004500233, 
              c[ -46][ t]], 
            Times[ 0.027514390699665887, 
              c[ -45][ t]], 
            Times[ 0.035131239329076656, 
              c[ -44][ t]], 
            Times[ 0.041349667156634483, 
              c[ -43][ t]], 
            Times[ 0.045868286584282256, 
              c[ -42][ t]], 
            Times[ 0.048454002753361682, 
              c[ -41][ t]], 
            Times[ 0.04895352855494272, 
              c[ -40][ t]], 
            Times[ 0.047301670540041058, 
              c[ -39][ t]], 
            Times[ 0.043525965428036162, 
              c[ -38][ t]], 
            Times[ 0.03774739544932687, 
              c[ -37][ t]], 
            Times[ 0.030177073670601236, 
              c[ -36][ t]], 
            Times[ 0.021108961070255627, 
              c[ -35][ t]], 
            Times[ 0.010908848347331966, 
              c[ -34][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -33][ t]], 
            Times[ -0.011153991006822649, 
              c[ -32][ t]], 
            Times[ -0.022068459300722043, 
              c[ -31][ t]], 
            Times[ -0.032258251165125519, 
              c[ -30][ t]], 
            Times[ -0.041258781072520248, 
              c[ -29][ t]], 
            Times[ -0.048646667243099281, 
              c[ -28][ t]], 
            Times[ -0.054059052045761224, 
              c[ -27][ t]], 
            Times[ -0.057210750238908967, 
              c[ -26][ t]], 
            Times[ -0.057908442314993203, 
              c[ -25][ t]], 
            Times[ -0.056061239158567186, 
              c[ -24][ t]], 
            Times[ -0.05168708394579296, 
              c[ -23][ t]], 
            Times[ -0.044914622433376419, 
              c[ -22][ t]], 
            Times[ -0.035980357068793781, 
              c[ -21][ t]], 
            Times[ -0.025221096343682053, 
              c[ -20][ t]], 
            Times[ -0.013061910521147383, 
              c[ -19][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -18][ t]], 
            Times[ 0.013414935129827233, 
              c[ -17][ t]], 
            Times[ 0.026603074225527826, 
              c[ -16][ t]], 
            Times[ 0.03897872015785999, 
              c[ -15][ t]], 
            Times[ 0.049975424961080865, 
              c[ -14][ t]], 
            Times[ 0.059070953080906326, 
              c[ -13][ t]], 
            Times[ 0.065811019881796273, 
              c[ -12][ t]], 
            Times[ 0.069830768673962415, 
              c[ -11][ t]], 
            Times[ 0.070873018952678238, 
              c[ -10][ t]], 
            Times[ 0.068802429876423349, 
              c[ -9][ t]], 
            Times[ 0.063614872548668322, 
              c[ -8][ t]], 
            Times[ 0.055441487066198933, 
              c[ -7][ t]], 
            Times[ 0.044547108751839919, 
              c[ -6][ t]], 
            Times[ 0.031322974491347202, 
              c[ -5][ t]], 
            Times[ 0.016273855731265604, 
              c[ -4][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -3][ t]], 
            Times[ -0.016825511857749262, 
              c[ -2][ t]], 
            Times[ -0.033483179628681567, 
              c[ -1][ t]], 
            Times[ -0.049236278094138941, 
              c[ 0][ t]], 
            Times[ -0.063361699504227403, 
              c[ 1][ t]], 
            Times[ -0.075181213012062598, 
              c[ 2][ t]], 
            Times[ -0.084091858737850814, 
              c[ 3][ t]], 
            Times[ -0.089594193770366842, 
              c[ 4][ t]], 
            Times[ -0.091317159035181589, 
              c[ 5][ t]], 
            Times[ -0.089038438663606695, 
              c[ 6][ t]], 
            Times[ -0.082699334313268813, 
              c[ 7][ t]], 
            Times[ -0.072413370861974122, 
              c[ 8][ t]], 
            Times[ -0.058468080236789913, 
              c[ 9][ t]], 
            Times[ -0.041319668477947373, 
              c[ 10][ t]], 
            Times[ -0.021580547817548056, 
              c[ 11][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 12][ t]], 
            Times[ 0.022561481809254675, 
              c[ 13][ t]], 
            Times[ 0.045163358568919114, 
              c[ 14][ t]], 
            Times[ 0.066820663127759972, 
              c[ 15][ t]], 
            Times[ 0.086542809078944752, 
              c[ 16][ t]], 
            Times[ 0.10337416789158595, 
              c[ 17][ t]], 
            Times[ 0.11643488132933186, 
              c[ 18][ t]], 
            Times[ 0.12496032289024847, 
              c[ 19][ t]], 
            Times[ 0.12833762891430925, 
              c[ 20][ t]], 
            Times[ 0.12613778810677614, 
              c[ 21][ t]], 
            Times[ 0.1181419061618126, 
              c[ 22][ t]], 
            Times[ 0.10436044624225692, 
              c[ 23][ t]], 
            Times[ 0.085044480344421705, 
              c[ 24][ t]], 
            Times[ 0.060688263076985223, 
              c[ 25][ t]], 
            Times[ 0.032022748374426029, 
              c[ 26][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 27][ t]], 
            Times[ -0.034231213779558796, 
              c[ 28][ t]], 
            Times[ -0.069358014945125918, 
              c[ 29][ t]], 
            Times[ -0.10394325375429328, 
              c[ 30][ t]], 
            Times[ -0.13647135277833591, 
              c[ 31][ t]], 
            Times[ -0.1653986686265376, 
              c[ 32][ t]], 
            Times[ -0.18920668216016426, 
              c[ 33][ t]], 
            Times[ -0.20645618564475834, 
              c[ 34][ t]], 
            Times[ -0.21584055771952013, 
              c[ 35][ t]], 
            Times[ -0.21623620818304484, 
              c[ 36][ t]], 
            Times[ -0.20674833578317206, 
              c[ 37][ t]], 
            Times[ -0.18675027222298607, 
              c[ 38][ t]], 
            Times[ -0.15591488063143982, 
              c[ 39][ t]], 
            Times[ -0.11423673049785459, 
              c[ 40][ t]], 
            Times[ -0.062044074975450718, 
              c[ 41][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 42][ t]], 
            Times[ 0.070907514257657456, 
              c[ 43][ t]], 
            Times[ 0.14938649372796314, 
              c[ 44][ t]], 
            Times[ 0.23387232094715985, 
              c[ 45][ t]], 
            Times[ 0.32256865202152113, 
              c[ 46][ t]], 
            Times[ 0.41349667156634362, 
              c[ 47][ t]], 
            Times[ 0.50455115242710469, 
              c[ 48][ t]], 
            Times[ 0.59356153372868015, 
              c[ 49][ t]], 
            Times[ 0.67835603854706272, 
              c[ 50][ t]], 
            Times[ 0.75682672864065692, 
              c[ 51][ t]], 
            Times[ 0.82699334313268802, 
              c[ 52][ t]], 
            Times[ 0.88706379305918348, 
              c[ 53][ t]], 
            Times[ 0.93548928378863916, 
              c[ 54][ t]], 
            Times[ 0.9710122092317629, 
              c[ 55][ t]], 
            Times[ 0.99270519960720671, 
              c[ 56][ t]], 
            Times[ 72.258543775865164, 
              c[ 57][ t]], 
            Times[ 0.99270519960720693, 
              c[ 58][ t]], 
            Times[ 0.9710122092317629, 
              c[ 59][ t]], 
            Times[ 0.93548928378863916, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "58", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[58]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.01645783405477577`\)\ \(c[\(-60\)]\)[t] - 
            0.02398690471252936`\ \(c[\(-59\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-58\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-57\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-56\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-55\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-54\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-53\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-52\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-51\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-50\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-49\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-48\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-47\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-46\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-45\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-44\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-43\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-42\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-41\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-40\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-39\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-38\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-37\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-36\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-35\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-34\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-33\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-32\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-31\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-30\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-29\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-28\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-27\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-26\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-25\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-24\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-23\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-22\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-21\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-20\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-19\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-18\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-17\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-16\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-15\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-14\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-13\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-12\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-11\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-10\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-9\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-8\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-7\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-6\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-5\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-4\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-3\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[\(-2\)]\)[t] - 
            0.0168255118577494`\ \(c[\(-1\)]\)[t] - 
            0.03348317962868157`\ \(c[0]\)[t] - 
            0.04923627809413894`\ \(c[1]\)[t] - 
            0.06336169950422753`\ \(c[2]\)[t] - 
            0.0751812130120626`\ \(c[3]\)[t] - 
            0.08409185873785081`\ \(c[4]\)[t] - 
            0.08959419377036688`\ \(c[5]\)[t] - 
            0.09131715903518159`\ \(c[6]\)[t] - 
            0.0890384386636067`\ \(c[7]\)[t] - 
            0.08269933431326874`\ \(c[8]\)[t] - 
            0.07241337086197412`\ \(c[9]\)[t] - 
            0.05846808023678991`\ \(c[10]\)[t] - 
            0.04131966847794722`\ \(c[11]\)[t] - 
            0.02158054781754788`\ \(c[12]\)[t] + 
            3.8981718325193755`*^-17\ \(c[13]\)[t] + 
            0.02256148180925487`\ \(c[14]\)[t] + 
            0.0451633585689193`\ \(c[15]\)[t] + 
            0.06682066312775997`\ \(c[16]\)[t] + 
            0.08654280907894489`\ \(c[17]\)[t] + 
            0.10337416789158609`\ \(c[18]\)[t] + 
            0.11643488132933186`\ \(c[19]\)[t] + 
            0.12496032289024853`\ \(c[20]\)[t] + 
            0.12833762891430928`\ \(c[21]\)[t] + 
            0.12613778810677614`\ \(c[22]\)[t] + 
            0.11814190616181255`\ \(c[23]\)[t] + 
            0.10436044624225685`\ \(c[24]\)[t] + 
            0.0850444803444217`\ \(c[25]\)[t] + 
            0.060688263076985105`\ \(c[26]\)[t] + 
            0.032022748374425904`\ \(c[27]\)[t] - 
            3.898171832519376`*^-17\ \(c[28]\)[t] - 
            0.03423121377955895`\ \(c[29]\)[t] - 
            0.06935801494512607`\ \(c[30]\)[t] - 
            0.10394325375429328`\ \(c[31]\)[t] - 
            0.13647135277833605`\ \(c[32]\)[t] - 
            0.1653986686265377`\ \(c[33]\)[t] - 
            0.18920668216016426`\ \(c[34]\)[t] - 
            0.20645618564475843`\ \(c[35]\)[t] - 
            0.21584055771952015`\ \(c[36]\)[t] - 
            0.21623620818304484`\ \(c[37]\)[t] - 
            0.206748335783172`\ \(c[38]\)[t] - 
            0.18675027222298593`\ \(c[39]\)[t] - 
            0.15591488063143982`\ \(c[40]\)[t] - 
            0.11423673049785459`\ \(c[41]\)[t] - 
            0.06204407497545024`\ \(c[42]\)[t] + 
            3.898171832519376`*^-17\ \(c[43]\)[t] + 
            0.07090751425765746`\ \(c[44]\)[t] + 
            0.14938649372796384`\ \(c[45]\)[t] + 
            0.23387232094715985`\ \(c[46]\)[t] + 
            0.32256865202152113`\ \(c[47]\)[t] + 
            0.4134966715663443`\ \(c[48]\)[t] + 
            0.5045511524271047`\ \(c[49]\)[t] + 
            0.5935615337286801`\ \(c[50]\)[t] + 
            0.6783560385470636`\ \(c[51]\)[t] + 
            0.7568267286406569`\ \(c[52]\)[t] + 
            0.826993343132688`\ \(c[53]\)[t] + 
            0.8870637930591839`\ \(c[54]\)[t] + 
            0.9354892837886392`\ \(c[55]\)[t] + 
            0.9710122092317629`\ \(c[56]\)[t] + 
            0.9927051996072069`\ \(c[57]\)[t] + 
            74.7807760116991`\ \(c[58]\)[t] + 
            0.9927051996072069`\ \(c[59]\)[t] + 
            0.9710122092317629`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 58, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 58]][ t]], 
          Plus[ 
            Times[ -0.016457834054775768, 
              c[ -60][ t]], 
            Times[ -0.023986904712529358, 
              c[ -59][ t]], 
            Times[ -0.030588406657213296, 
              c[ -58][ t]], 
            Times[ -0.035956232310116867, 
              c[ -57][ t]], 
            Times[ -0.039832985717929335, 
              c[ -56][ t]], 
            Times[ -0.042022055485216314, 
              c[ -55][ t]], 
            Times[ -0.042397252409191441, 
              c[ -54][ t]], 
            Times[ -0.040909552899494925, 
              c[ -53][ t]], 
            Times[ -0.037590606506031236, 
              c[ -52][ t]], 
            Times[ -0.032552799745291155, 
              c[ -51][ t]], 
            Times[ -0.025985813438573278, 
              c[ -50][ t]], 
            Times[ -0.018149760920219783, 
              c[ -49][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -48][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -47][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -46][ t]], 
            Times[ 0.018854606004500233, 
              c[ -45][ t]], 
            Times[ 0.027514390699665887, 
              c[ -44][ t]], 
            Times[ 0.035131239329076656, 
              c[ -43][ t]], 
            Times[ 0.041349667156634483, 
              c[ -42][ t]], 
            Times[ 0.045868286584282311, 
              c[ -41][ t]], 
            Times[ 0.048454002753361682, 
              c[ -40][ t]], 
            Times[ 0.04895352855494272, 
              c[ -39][ t]], 
            Times[ 0.047301670540041058, 
              c[ -38][ t]], 
            Times[ 0.043525965428036162, 
              c[ -37][ t]], 
            Times[ 0.03774739544932687, 
              c[ -36][ t]], 
            Times[ 0.030177073670601236, 
              c[ -35][ t]], 
            Times[ 0.021108961070255627, 
              c[ -34][ t]], 
            Times[ 0.010908848347331966, 
              c[ -33][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -32][ t]], 
            Times[ -0.011153991006822649, 
              c[ -31][ t]], 
            Times[ -0.022068459300722043, 
              c[ -30][ t]], 
            Times[ -0.032258251165125519, 
              c[ -29][ t]], 
            Times[ -0.041258781072520248, 
              c[ -28][ t]], 
            Times[ -0.048646667243099281, 
              c[ -27][ t]], 
            Times[ -0.054059052045761224, 
              c[ -26][ t]], 
            Times[ -0.057210750238908967, 
              c[ -25][ t]], 
            Times[ -0.057908442314993203, 
              c[ -24][ t]], 
            Times[ -0.056061239158567186, 
              c[ -23][ t]], 
            Times[ -0.05168708394579296, 
              c[ -22][ t]], 
            Times[ -0.044914622433376419, 
              c[ -21][ t]], 
            Times[ -0.035980357068793781, 
              c[ -20][ t]], 
            Times[ -0.025221096343682053, 
              c[ -19][ t]], 
            Times[ -0.013061910521147383, 
              c[ -18][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -17][ t]], 
            Times[ 0.013414935129827233, 
              c[ -16][ t]], 
            Times[ 0.026603074225527826, 
              c[ -15][ t]], 
            Times[ 0.03897872015785999, 
              c[ -14][ t]], 
            Times[ 0.049975424961080865, 
              c[ -13][ t]], 
            Times[ 0.059070953080906326, 
              c[ -12][ t]], 
            Times[ 0.065811019881796273, 
              c[ -11][ t]], 
            Times[ 0.069830768673962415, 
              c[ -10][ t]], 
            Times[ 0.070873018952678238, 
              c[ -9][ t]], 
            Times[ 0.068802429876423349, 
              c[ -8][ t]], 
            Times[ 0.063614872548668253, 
              c[ -7][ t]], 
            Times[ 0.055441487066198933, 
              c[ -6][ t]], 
            Times[ 0.044547108751839919, 
              c[ -5][ t]], 
            Times[ 0.031322974491347078, 
              c[ -4][ t]], 
            Times[ 0.016273855731265604, 
              c[ -3][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ -2][ t]], 
            Times[ -0.016825511857749401, 
              c[ -1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 0][ t]], 
            Times[ -0.049236278094138941, 
              c[ 1][ t]], 
            Times[ -0.063361699504227528, 
              c[ 2][ t]], 
            Times[ -0.075181213012062598, 
              c[ 3][ t]], 
            Times[ -0.084091858737850814, 
              c[ 4][ t]], 
            Times[ -0.089594193770366884, 
              c[ 5][ t]], 
            Times[ -0.091317159035181589, 
              c[ 6][ t]], 
            Times[ -0.089038438663606695, 
              c[ 7][ t]], 
            Times[ -0.082699334313268744, 
              c[ 8][ t]], 
            Times[ -0.072413370861974122, 
              c[ 9][ t]], 
            Times[ -0.058468080236789913, 
              c[ 10][ t]], 
            Times[ -0.04131966847794722, 
              c[ 11][ t]], 
            Times[ -0.021580547817547879, 
              c[ 12][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 13][ t]], 
            Times[ 0.022561481809254869, 
              c[ 14][ t]], 
            Times[ 0.045163358568919301, 
              c[ 15][ t]], 
            Times[ 0.066820663127759972, 
              c[ 16][ t]], 
            Times[ 0.086542809078944891, 
              c[ 17][ t]], 
            Times[ 0.10337416789158609, 
              c[ 18][ t]], 
            Times[ 0.11643488132933186, 
              c[ 19][ t]], 
            Times[ 0.12496032289024853, 
              c[ 20][ t]], 
            Times[ 0.12833762891430928, 
              c[ 21][ t]], 
            Times[ 0.12613778810677614, 
              c[ 22][ t]], 
            Times[ 0.11814190616181255, 
              c[ 23][ t]], 
            Times[ 0.10436044624225685, 
              c[ 24][ t]], 
            Times[ 0.085044480344421705, 
              c[ 25][ t]], 
            Times[ 0.060688263076985105, 
              c[ 26][ t]], 
            Times[ 0.032022748374425904, 
              c[ 27][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 28][ t]], 
            Times[ -0.034231213779558949, 
              c[ 29][ t]], 
            Times[ -0.06935801494512607, 
              c[ 30][ t]], 
            Times[ -0.10394325375429328, 
              c[ 31][ t]], 
            Times[ -0.13647135277833605, 
              c[ 32][ t]], 
            Times[ -0.16539866862653771, 
              c[ 33][ t]], 
            Times[ -0.18920668216016426, 
              c[ 34][ t]], 
            Times[ -0.20645618564475843, 
              c[ 35][ t]], 
            Times[ -0.21584055771952015, 
              c[ 36][ t]], 
            Times[ -0.21623620818304484, 
              c[ 37][ t]], 
            Times[ -0.206748335783172, 
              c[ 38][ t]], 
            Times[ -0.18675027222298593, 
              c[ 39][ t]], 
            Times[ -0.15591488063143982, 
              c[ 40][ t]], 
            Times[ -0.11423673049785459, 
              c[ 41][ t]], 
            Times[ -0.062044074975450239, 
              c[ 42][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 43][ t]], 
            Times[ 0.070907514257657456, 
              c[ 44][ t]], 
            Times[ 0.14938649372796384, 
              c[ 45][ t]], 
            Times[ 0.23387232094715985, 
              c[ 46][ t]], 
            Times[ 0.32256865202152113, 
              c[ 47][ t]], 
            Times[ 0.41349667156634429, 
              c[ 48][ t]], 
            Times[ 0.50455115242710469, 
              c[ 49][ t]], 
            Times[ 0.59356153372868015, 
              c[ 50][ t]], 
            Times[ 0.67835603854706361, 
              c[ 51][ t]], 
            Times[ 0.75682672864065692, 
              c[ 52][ t]], 
            Times[ 0.82699334313268802, 
              c[ 53][ t]], 
            Times[ 0.88706379305918392, 
              c[ 54][ t]], 
            Times[ 0.93548928378863916, 
              c[ 55][ t]], 
            Times[ 0.9710122092317629, 
              c[ 56][ t]], 
            Times[ 0.99270519960720693, 
              c[ 57][ t]], 
            Times[ 74.780776011699103, 
              c[ 58][ t]], 
            Times[ 0.99270519960720693, 
              c[ 59][ t]], 
            Times[ 0.9710122092317629, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "59", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[59]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-0.008342060500900982`\)\ \(c[\(-60\)]\)[t] - 
            0.01645783405477577`\ \(c[\(-59\)]\)[t] - 
            0.02398690471252936`\ \(c[\(-58\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-57\)]\)[t] - 
            0.035956232310116944`\ \(c[\(-56\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-55\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-54\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-53\)]\)[t] - 
            0.040909552899494925`\ \(c[\(-52\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-51\)]\)[t] - 
            0.03255279974529105`\ \(c[\(-50\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-49\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-48\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-47\)]\)[t] + 
            2.005337021455629`*^-16\ \(c[\(-46\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-45\)]\)[t] + 
            0.01885460600450039`\ \(c[\(-44\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-43\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-42\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-41\)]\)[t] + 
            0.04586828658428231`\ \(c[\(-40\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-39\)]\)[t] + 
            0.0489535285549427`\ \(c[\(-38\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-37\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-36\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-35\)]\)[t] + 
            0.030177073670601094`\ \(c[\(-34\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-33\)]\)[t] + 
            0.010908848347331785`\ \(c[\(-32\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-31\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-30\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-29\)]\)[t] - 
            0.03225825116512568`\ \(c[\(-28\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-27\)]\)[t] - 
            0.0486466672430994`\ \(c[\(-26\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-25\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-24\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-23\)]\)[t] - 
            0.05606123915856713`\ \(c[\(-22\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-21\)]\)[t] - 
            0.04491462243337629`\ \(c[\(-20\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-19\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-18\)]\)[t] - 
            0.013061910521147276`\ \(c[\(-17\)]\)[t] + 
            1.5206810699945212`*^-16\ \(c[\(-16\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-15\)]\)[t] + 
            0.026603074225527937`\ \(c[\(-14\)]\)[t] + 
            0.03897872015786009`\ \(c[\(-13\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-12\)]\)[t] + 
            0.0590709530809064`\ \(c[\(-11\)]\)[t] + 
            0.06581101988179631`\ \(c[\(-10\)]\)[t] + 
            0.06983076867396242`\ \(c[\(-9\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-8\)]\)[t] + 
            0.06880242987642332`\ \(c[\(-7\)]\)[t] + 
            0.06361487254866825`\ \(c[\(-6\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-5\)]\)[t] + 
            0.044547108751839815`\ \(c[\(-4\)]\)[t] + 
            0.03132297449134708`\ \(c[\(-3\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-2\)]\)[t] - 
            1.8033970416801674`*^-16\ \(c[\(-1\)]\)[t] - 
            0.0168255118577494`\ \(c[0]\)[t] - 
            0.03348317962868157`\ \(c[1]\)[t] - 
            0.049236278094139066`\ \(c[2]\)[t] - 
            0.06336169950422753`\ \(c[3]\)[t] - 
            0.0751812130120626`\ \(c[4]\)[t] - 
            0.08409185873785086`\ \(c[5]\)[t] - 
            0.08959419377036688`\ \(c[6]\)[t] - 
            0.09131715903518159`\ \(c[7]\)[t] - 
            0.08903843866360665`\ \(c[8]\)[t] - 
            0.08269933431326874`\ \(c[9]\)[t] - 
            0.07241337086197412`\ \(c[10]\)[t] - 
            0.05846808023678991`\ \(c[11]\)[t] - 
            0.04131966847794722`\ \(c[12]\)[t] - 
            0.02158054781754788`\ \(c[13]\)[t] + 
            3.8981718325193755`*^-17\ \(c[14]\)[t] + 
            0.02256148180925487`\ \(c[15]\)[t] + 
            0.0451633585689193`\ \(c[16]\)[t] + 
            0.06682066312775997`\ \(c[17]\)[t] + 
            0.08654280907894489`\ \(c[18]\)[t] + 
            0.10337416789158609`\ \(c[19]\)[t] + 
            0.11643488132933186`\ \(c[20]\)[t] + 
            0.12496032289024853`\ \(c[21]\)[t] + 
            0.12833762891430928`\ \(c[22]\)[t] + 
            0.12613778810677612`\ \(c[23]\)[t] + 
            0.11814190616181253`\ \(c[24]\)[t] + 
            0.10436044624225685`\ \(c[25]\)[t] + 
            0.08504448034442161`\ \(c[26]\)[t] + 
            0.060688263076985`\ \(c[27]\)[t] + 
            0.032022748374425904`\ \(c[28]\)[t] - 
            1.8033970416801674`*^-16\ \(c[29]\)[t] - 
            0.034231213779559094`\ \(c[30]\)[t] - 
            0.06935801494512607`\ \(c[31]\)[t] - 
            0.1039432537542934`\ \(c[32]\)[t] - 
            0.13647135277833616`\ \(c[33]\)[t] - 
            0.1653986686265377`\ \(c[34]\)[t] - 
            0.18920668216016434`\ \(c[35]\)[t] - 
            0.20645618564475848`\ \(c[36]\)[t] - 
            0.21584055771952015`\ \(c[37]\)[t] - 
            0.21623620818304481`\ \(c[38]\)[t] - 
            0.2067483357831719`\ \(c[39]\)[t] - 
            0.18675027222298593`\ \(c[40]\)[t] - 
            0.15591488063143982`\ \(c[41]\)[t] - 
            0.11423673049785416`\ \(c[42]\)[t] - 
            0.06204407497545024`\ \(c[43]\)[t] + 
            3.898171832519376`*^-17\ \(c[44]\)[t] + 
            0.0709075142576581`\ \(c[45]\)[t] + 
            0.14938649372796384`\ \(c[46]\)[t] + 
            0.23387232094715985`\ \(c[47]\)[t] + 
            0.3225686520215219`\ \(c[48]\)[t] + 
            0.4134966715663443`\ \(c[49]\)[t] + 
            0.5045511524271047`\ \(c[50]\)[t] + 
            0.5935615337286809`\ \(c[51]\)[t] + 
            0.6783560385470636`\ \(c[52]\)[t] + 
            0.7568267286406569`\ \(c[53]\)[t] + 
            0.8269933431326885`\ \(c[54]\)[t] + 
            0.8870637930591839`\ \(c[55]\)[t] + 
            0.9354892837886392`\ \(c[56]\)[t] + 
            0.9710122092317629`\ \(c[57]\)[t] + 
            0.9927051996072069`\ \(c[58]\)[t] + 
            77.34687315598232`\ \(c[59]\)[t] + 
            0.9927051996072067`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 59, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 59]][ t]], 
          Plus[ 
            Times[ -0.0083420605009009823, 
              c[ -60][ t]], 
            Times[ -0.016457834054775768, 
              c[ -59][ t]], 
            Times[ -0.023986904712529358, 
              c[ -58][ t]], 
            Times[ -0.030588406657213296, 
              c[ -57][ t]], 
            Times[ -0.035956232310116944, 
              c[ -56][ t]], 
            Times[ -0.039832985717929335, 
              c[ -55][ t]], 
            Times[ -0.042022055485216314, 
              c[ -54][ t]], 
            Times[ -0.042397252409191441, 
              c[ -53][ t]], 
            Times[ -0.040909552899494925, 
              c[ -52][ t]], 
            Times[ -0.037590606506031236, 
              c[ -51][ t]], 
            Times[ -0.032552799745291051, 
              c[ -50][ t]], 
            Times[ -0.025985813438573278, 
              c[ -49][ t]], 
            Times[ -0.018149760920219783, 
              c[ -48][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -47][ t]], 
            Times[ 2.005337021455629*^-16, 
              c[ -46][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -45][ t]], 
            Times[ 0.018854606004500389, 
              c[ -44][ t]], 
            Times[ 0.027514390699665887, 
              c[ -43][ t]], 
            Times[ 0.035131239329076656, 
              c[ -42][ t]], 
            Times[ 0.041349667156634483, 
              c[ -41][ t]], 
            Times[ 0.045868286584282311, 
              c[ -40][ t]], 
            Times[ 0.048454002753361682, 
              c[ -39][ t]], 
            Times[ 0.048953528554942699, 
              c[ -38][ t]], 
            Times[ 0.047301670540041058, 
              c[ -37][ t]], 
            Times[ 0.043525965428036162, 
              c[ -36][ t]], 
            Times[ 0.03774739544932687, 
              c[ -35][ t]], 
            Times[ 0.030177073670601094, 
              c[ -34][ t]], 
            Times[ 0.021108961070255627, 
              c[ -33][ t]], 
            Times[ 0.010908848347331785, 
              c[ -32][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -31][ t]], 
            Times[ -0.011153991006822649, 
              c[ -30][ t]], 
            Times[ -0.022068459300722043, 
              c[ -29][ t]], 
            Times[ -0.032258251165125679, 
              c[ -28][ t]], 
            Times[ -0.041258781072520248, 
              c[ -27][ t]], 
            Times[ -0.048646667243099399, 
              c[ -26][ t]], 
            Times[ -0.054059052045761224, 
              c[ -25][ t]], 
            Times[ -0.057210750238908967, 
              c[ -24][ t]], 
            Times[ -0.057908442314993203, 
              c[ -23][ t]], 
            Times[ -0.05606123915856713, 
              c[ -22][ t]], 
            Times[ -0.05168708394579296, 
              c[ -21][ t]], 
            Times[ -0.044914622433376288, 
              c[ -20][ t]], 
            Times[ -0.035980357068793781, 
              c[ -19][ t]], 
            Times[ -0.025221096343682053, 
              c[ -18][ t]], 
            Times[ -0.013061910521147276, 
              c[ -17][ t]], 
            Times[ 1.5206810699945212*^-16, 
              c[ -16][ t]], 
            Times[ 0.013414935129827233, 
              c[ -15][ t]], 
            Times[ 0.026603074225527937, 
              c[ -14][ t]], 
            Times[ 0.038978720157860088, 
              c[ -13][ t]], 
            Times[ 0.049975424961080865, 
              c[ -12][ t]], 
            Times[ 0.059070953080906402, 
              c[ -11][ t]], 
            Times[ 0.065811019881796315, 
              c[ -10][ t]], 
            Times[ 0.069830768673962415, 
              c[ -9][ t]], 
            Times[ 0.070873018952678238, 
              c[ -8][ t]], 
            Times[ 0.068802429876423321, 
              c[ -7][ t]], 
            Times[ 0.063614872548668253, 
              c[ -6][ t]], 
            Times[ 0.055441487066198933, 
              c[ -5][ t]], 
            Times[ 0.044547108751839815, 
              c[ -4][ t]], 
            Times[ 0.031322974491347078, 
              c[ -3][ t]], 
            Times[ 0.016273855731265604, 
              c[ -2][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ -1][ t]], 
            Times[ -0.016825511857749401, 
              c[ 0][ t]], 
            Times[ -0.033483179628681567, 
              c[ 1][ t]], 
            Times[ -0.049236278094139066, 
              c[ 2][ t]], 
            Times[ -0.063361699504227528, 
              c[ 3][ t]], 
            Times[ -0.075181213012062598, 
              c[ 4][ t]], 
            Times[ -0.084091858737850855, 
              c[ 5][ t]], 
            Times[ -0.089594193770366884, 
              c[ 6][ t]], 
            Times[ -0.091317159035181589, 
              c[ 7][ t]], 
            Times[ -0.089038438663606653, 
              c[ 8][ t]], 
            Times[ -0.082699334313268744, 
              c[ 9][ t]], 
            Times[ -0.072413370861974122, 
              c[ 10][ t]], 
            Times[ -0.058468080236789913, 
              c[ 11][ t]], 
            Times[ -0.04131966847794722, 
              c[ 12][ t]], 
            Times[ -0.021580547817547879, 
              c[ 13][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 14][ t]], 
            Times[ 0.022561481809254869, 
              c[ 15][ t]], 
            Times[ 0.045163358568919301, 
              c[ 16][ t]], 
            Times[ 0.066820663127759972, 
              c[ 17][ t]], 
            Times[ 0.086542809078944891, 
              c[ 18][ t]], 
            Times[ 0.10337416789158609, 
              c[ 19][ t]], 
            Times[ 0.11643488132933186, 
              c[ 20][ t]], 
            Times[ 0.12496032289024853, 
              c[ 21][ t]], 
            Times[ 0.12833762891430928, 
              c[ 22][ t]], 
            Times[ 0.12613778810677612, 
              c[ 23][ t]], 
            Times[ 0.11814190616181253, 
              c[ 24][ t]], 
            Times[ 0.10436044624225685, 
              c[ 25][ t]], 
            Times[ 0.085044480344421608, 
              c[ 26][ t]], 
            Times[ 0.060688263076985001, 
              c[ 27][ t]], 
            Times[ 0.032022748374425904, 
              c[ 28][ t]], 
            Times[ -1.8033970416801674*^-16, 
              c[ 29][ t]], 
            Times[ -0.034231213779559094, 
              c[ 30][ t]], 
            Times[ -0.06935801494512607, 
              c[ 31][ t]], 
            Times[ -0.1039432537542934, 
              c[ 32][ t]], 
            Times[ -0.13647135277833616, 
              c[ 33][ t]], 
            Times[ -0.16539866862653771, 
              c[ 34][ t]], 
            Times[ -0.18920668216016434, 
              c[ 35][ t]], 
            Times[ -0.20645618564475848, 
              c[ 36][ t]], 
            Times[ -0.21584055771952015, 
              c[ 37][ t]], 
            Times[ -0.21623620818304481, 
              c[ 38][ t]], 
            Times[ -0.20674833578317189, 
              c[ 39][ t]], 
            Times[ -0.18675027222298593, 
              c[ 40][ t]], 
            Times[ -0.15591488063143982, 
              c[ 41][ t]], 
            Times[ -0.11423673049785416, 
              c[ 42][ t]], 
            Times[ -0.062044074975450239, 
              c[ 43][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 44][ t]], 
            Times[ 0.070907514257658094, 
              c[ 45][ t]], 
            Times[ 0.14938649372796384, 
              c[ 46][ t]], 
            Times[ 0.23387232094715985, 
              c[ 47][ t]], 
            Times[ 0.32256865202152191, 
              c[ 48][ t]], 
            Times[ 0.41349667156634429, 
              c[ 49][ t]], 
            Times[ 0.50455115242710469, 
              c[ 50][ t]], 
            Times[ 0.59356153372868092, 
              c[ 51][ t]], 
            Times[ 0.67835603854706361, 
              c[ 52][ t]], 
            Times[ 0.75682672864065692, 
              c[ 53][ t]], 
            Times[ 0.82699334313268846, 
              c[ 54][ t]], 
            Times[ 0.88706379305918392, 
              c[ 55][ t]], 
            Times[ 0.93548928378863916, 
              c[ 56][ t]], 
            Times[ 0.9710122092317629, 
              c[ 57][ t]], 
            Times[ 0.99270519960720693, 
              c[ 58][ t]], 
            Times[ 77.346873155982323, 
              c[ 59][ t]], 
            Times[ 0.99270519960720671, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"eq[\"\>", "\[InvisibleSpace]", "60", 
        "\[InvisibleSpace]", "\<\"]=\"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SuperscriptBox[\(c[60]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}], 
          "==", \(\(-3.898171832519376`*^-17\)\ \(c[\(-60\)]\)[t] - 
            0.008342060500900982`\ \(c[\(-59\)]\)[t] - 
            0.01645783405477577`\ \(c[\(-58\)]\)[t] - 
            0.023986904712529237`\ \(c[\(-57\)]\)[t] - 
            0.030588406657213296`\ \(c[\(-56\)]\)[t] - 
            0.03595623231011687`\ \(c[\(-55\)]\)[t] - 
            0.039832985717929335`\ \(c[\(-54\)]\)[t] - 
            0.042022055485216314`\ \(c[\(-53\)]\)[t] - 
            0.04239725240919144`\ \(c[\(-52\)]\)[t] - 
            0.040909552899494966`\ \(c[\(-51\)]\)[t] - 
            0.037590606506031236`\ \(c[\(-50\)]\)[t] - 
            0.032552799745291155`\ \(c[\(-49\)]\)[t] - 
            0.02598581343857328`\ \(c[\(-48\)]\)[t] - 
            0.018149760920219783`\ \(c[\(-47\)]\)[t] - 
            0.009365143392520679`\ \(c[\(-46\)]\)[t] + 
            3.8981718325193755`*^-17\ \(c[\(-45\)]\)[t] + 
            0.009545242303915543`\ \(c[\(-44\)]\)[t] + 
            0.018854606004500233`\ \(c[\(-43\)]\)[t] + 
            0.027514390699665887`\ \(c[\(-42\)]\)[t] + 
            0.035131239329076656`\ \(c[\(-41\)]\)[t] + 
            0.04134966715663448`\ \(c[\(-40\)]\)[t] + 
            0.045868286584282256`\ \(c[\(-39\)]\)[t] + 
            0.04845400275336168`\ \(c[\(-38\)]\)[t] + 
            0.04895352855494272`\ \(c[\(-37\)]\)[t] + 
            0.04730167054004106`\ \(c[\(-36\)]\)[t] + 
            0.04352596542803616`\ \(c[\(-35\)]\)[t] + 
            0.03774739544932687`\ \(c[\(-34\)]\)[t] + 
            0.030177073670601236`\ \(c[\(-33\)]\)[t] + 
            0.021108961070255627`\ \(c[\(-32\)]\)[t] + 
            0.010908848347331966`\ \(c[\(-31\)]\)[t] - 
            3.8981718325193755`*^-17\ \(c[\(-30\)]\)[t] - 
            0.011153991006822649`\ \(c[\(-29\)]\)[t] - 
            0.022068459300722043`\ \(c[\(-28\)]\)[t] - 
            0.03225825116512552`\ \(c[\(-27\)]\)[t] - 
            0.04125878107252025`\ \(c[\(-26\)]\)[t] - 
            0.04864666724309928`\ \(c[\(-25\)]\)[t] - 
            0.054059052045761224`\ \(c[\(-24\)]\)[t] - 
            0.05721075023890897`\ \(c[\(-23\)]\)[t] - 
            0.0579084423149932`\ \(c[\(-22\)]\)[t] - 
            0.056061239158567186`\ \(c[\(-21\)]\)[t] - 
            0.05168708394579296`\ \(c[\(-20\)]\)[t] - 
            0.04491462243337642`\ \(c[\(-19\)]\)[t] - 
            0.03598035706879378`\ \(c[\(-18\)]\)[t] - 
            0.025221096343682053`\ \(c[\(-17\)]\)[t] - 
            0.013061910521147383`\ \(c[\(-16\)]\)[t] + 
            3.898171832519376`*^-17\ \(c[\(-15\)]\)[t] + 
            0.013414935129827233`\ \(c[\(-14\)]\)[t] + 
            0.026603074225527826`\ \(c[\(-13\)]\)[t] + 
            0.03897872015785999`\ \(c[\(-12\)]\)[t] + 
            0.049975424961080865`\ \(c[\(-11\)]\)[t] + 
            0.059070953080906326`\ \(c[\(-10\)]\)[t] + 
            0.06581101988179627`\ \(c[\(-9\)]\)[t] + 
            0.06983076867396239`\ \(c[\(-8\)]\)[t] + 
            0.07087301895267824`\ \(c[\(-7\)]\)[t] + 
            0.06880242987642335`\ \(c[\(-6\)]\)[t] + 
            0.06361487254866832`\ \(c[\(-5\)]\)[t] + 
            0.05544148706619893`\ \(c[\(-4\)]\)[t] + 
            0.04454710875183992`\ \(c[\(-3\)]\)[t] + 
            0.0313229744913472`\ \(c[\(-2\)]\)[t] + 
            0.016273855731265604`\ \(c[\(-1\)]\)[t] - 
            3.898171832519376`*^-17\ \(c[0]\)[t] - 
            0.016825511857749262`\ \(c[1]\)[t] - 
            0.03348317962868157`\ \(c[2]\)[t] - 
            0.04923627809413894`\ \(c[3]\)[t] - 
            0.0633616995042274`\ \(c[4]\)[t] - 
            0.0751812130120626`\ \(c[5]\)[t] - 
            0.08409185873785081`\ \(c[6]\)[t] - 
            0.08959419377036684`\ \(c[7]\)[t] - 
            0.09131715903518159`\ \(c[8]\)[t] - 
            0.0890384386636067`\ \(c[9]\)[t] - 
            0.08269933431326881`\ \(c[10]\)[t] - 
            0.07241337086197425`\ \(c[11]\)[t] - 
            0.05846808023678991`\ \(c[12]\)[t] - 
            0.04131966847794737`\ \(c[13]\)[t] - 
            0.021580547817548056`\ \(c[14]\)[t] + 
            3.8981718325193755`*^-17\ \(c[15]\)[t] + 
            0.022561481809254675`\ \(c[16]\)[t] + 
            0.045163358568919114`\ \(c[17]\)[t] + 
            0.06682066312775997`\ \(c[18]\)[t] + 
            0.08654280907894475`\ \(c[19]\)[t] + 
            0.10337416789158595`\ \(c[20]\)[t] + 
            0.11643488132933186`\ \(c[21]\)[t] + 
            0.12496032289024847`\ \(c[22]\)[t] + 
            0.12833762891430925`\ \(c[23]\)[t] + 
            0.12613778810677614`\ \(c[24]\)[t] + 
            0.1181419061618126`\ \(c[25]\)[t] + 
            0.10436044624225692`\ \(c[26]\)[t] + 
            0.0850444803444217`\ \(c[27]\)[t] + 
            0.06068826307698522`\ \(c[28]\)[t] + 
            0.03202274837442603`\ \(c[29]\)[t] - 
            3.898171832519376`*^-17\ \(c[30]\)[t] - 
            0.034231213779558796`\ \(c[31]\)[t] - 
            0.06935801494512592`\ \(c[32]\)[t] - 
            0.10394325375429328`\ \(c[33]\)[t] - 
            0.1364713527783359`\ \(c[34]\)[t] - 
            0.1653986686265376`\ \(c[35]\)[t] - 
            0.18920668216016426`\ \(c[36]\)[t] - 
            0.20645618564475834`\ \(c[37]\)[t] - 
            0.21584055771952013`\ \(c[38]\)[t] - 
            0.21623620818304484`\ \(c[39]\)[t] - 
            0.20674833578317206`\ \(c[40]\)[t] - 
            0.18675027222298618`\ \(c[41]\)[t] - 
            0.15591488063143982`\ \(c[42]\)[t] - 
            0.11423673049785459`\ \(c[43]\)[t] - 
            0.06204407497545072`\ \(c[44]\)[t] + 
            3.898171832519376`*^-17\ \(c[45]\)[t] + 
            0.07090751425765746`\ \(c[46]\)[t] + 
            0.14938649372796314`\ \(c[47]\)[t] + 
            0.23387232094715985`\ \(c[48]\)[t] + 
            0.32256865202152113`\ \(c[49]\)[t] + 
            0.4134966715663436`\ \(c[50]\)[t] + 
            0.5045511524271047`\ \(c[51]\)[t] + 
            0.5935615337286801`\ \(c[52]\)[t] + 
            0.6783560385470627`\ \(c[53]\)[t] + 
            0.7568267286406569`\ \(c[54]\)[t] + 
            0.826993343132688`\ \(c[55]\)[t] + 
            0.8870637930591835`\ \(c[56]\)[t] + 
            0.9354892837886392`\ \(c[57]\)[t] + 
            0.9710122092317629`\ \(c[58]\)[t] + 
            0.9927051996072067`\ \(c[59]\)[t] + 
            79.95683520871486`\ \(c[60]\)[t]\)}]}],
      SequenceForm[ "eq[", 60, "]=", 
        Equal[ 
          Times[ 
            Complex[ 0, 1], 
            Derivative[ 1][ 
              c[ 60]][ t]], 
          Plus[ 
            Times[ -3.8981718325193761*^-17, 
              c[ -60][ t]], 
            Times[ -0.0083420605009009823, 
              c[ -59][ t]], 
            Times[ -0.016457834054775768, 
              c[ -58][ t]], 
            Times[ -0.023986904712529237, 
              c[ -57][ t]], 
            Times[ -0.030588406657213296, 
              c[ -56][ t]], 
            Times[ -0.035956232310116867, 
              c[ -55][ t]], 
            Times[ -0.039832985717929335, 
              c[ -54][ t]], 
            Times[ -0.042022055485216314, 
              c[ -53][ t]], 
            Times[ -0.042397252409191441, 
              c[ -52][ t]], 
            Times[ -0.040909552899494966, 
              c[ -51][ t]], 
            Times[ -0.037590606506031236, 
              c[ -50][ t]], 
            Times[ -0.032552799745291155, 
              c[ -49][ t]], 
            Times[ -0.025985813438573278, 
              c[ -48][ t]], 
            Times[ -0.018149760920219783, 
              c[ -47][ t]], 
            Times[ -0.0093651433925206785, 
              c[ -46][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ -45][ t]], 
            Times[ 0.0095452423039155427, 
              c[ -44][ t]], 
            Times[ 0.018854606004500233, 
              c[ -43][ t]], 
            Times[ 0.027514390699665887, 
              c[ -42][ t]], 
            Times[ 0.035131239329076656, 
              c[ -41][ t]], 
            Times[ 0.041349667156634483, 
              c[ -40][ t]], 
            Times[ 0.045868286584282256, 
              c[ -39][ t]], 
            Times[ 0.048454002753361682, 
              c[ -38][ t]], 
            Times[ 0.04895352855494272, 
              c[ -37][ t]], 
            Times[ 0.047301670540041058, 
              c[ -36][ t]], 
            Times[ 0.043525965428036162, 
              c[ -35][ t]], 
            Times[ 0.03774739544932687, 
              c[ -34][ t]], 
            Times[ 0.030177073670601236, 
              c[ -33][ t]], 
            Times[ 0.021108961070255627, 
              c[ -32][ t]], 
            Times[ 0.010908848347331966, 
              c[ -31][ t]], 
            Times[ -3.8981718325193755*^-17, 
              c[ -30][ t]], 
            Times[ -0.011153991006822649, 
              c[ -29][ t]], 
            Times[ -0.022068459300722043, 
              c[ -28][ t]], 
            Times[ -0.032258251165125519, 
              c[ -27][ t]], 
            Times[ -0.041258781072520248, 
              c[ -26][ t]], 
            Times[ -0.048646667243099281, 
              c[ -25][ t]], 
            Times[ -0.054059052045761224, 
              c[ -24][ t]], 
            Times[ -0.057210750238908967, 
              c[ -23][ t]], 
            Times[ -0.057908442314993203, 
              c[ -22][ t]], 
            Times[ -0.056061239158567186, 
              c[ -21][ t]], 
            Times[ -0.05168708394579296, 
              c[ -20][ t]], 
            Times[ -0.044914622433376419, 
              c[ -19][ t]], 
            Times[ -0.035980357068793781, 
              c[ -18][ t]], 
            Times[ -0.025221096343682053, 
              c[ -17][ t]], 
            Times[ -0.013061910521147383, 
              c[ -16][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ -15][ t]], 
            Times[ 0.013414935129827233, 
              c[ -14][ t]], 
            Times[ 0.026603074225527826, 
              c[ -13][ t]], 
            Times[ 0.03897872015785999, 
              c[ -12][ t]], 
            Times[ 0.049975424961080865, 
              c[ -11][ t]], 
            Times[ 0.059070953080906326, 
              c[ -10][ t]], 
            Times[ 0.065811019881796273, 
              c[ -9][ t]], 
            Times[ 0.069830768673962387, 
              c[ -8][ t]], 
            Times[ 0.070873018952678238, 
              c[ -7][ t]], 
            Times[ 0.068802429876423349, 
              c[ -6][ t]], 
            Times[ 0.063614872548668322, 
              c[ -5][ t]], 
            Times[ 0.055441487066198933, 
              c[ -4][ t]], 
            Times[ 0.044547108751839919, 
              c[ -3][ t]], 
            Times[ 0.031322974491347202, 
              c[ -2][ t]], 
            Times[ 0.016273855731265604, 
              c[ -1][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 0][ t]], 
            Times[ -0.016825511857749262, 
              c[ 1][ t]], 
            Times[ -0.033483179628681567, 
              c[ 2][ t]], 
            Times[ -0.049236278094138941, 
              c[ 3][ t]], 
            Times[ -0.063361699504227403, 
              c[ 4][ t]], 
            Times[ -0.075181213012062598, 
              c[ 5][ t]], 
            Times[ -0.084091858737850814, 
              c[ 6][ t]], 
            Times[ -0.089594193770366842, 
              c[ 7][ t]], 
            Times[ -0.091317159035181589, 
              c[ 8][ t]], 
            Times[ -0.089038438663606695, 
              c[ 9][ t]], 
            Times[ -0.082699334313268813, 
              c[ 10][ t]], 
            Times[ -0.072413370861974247, 
              c[ 11][ t]], 
            Times[ -0.058468080236789913, 
              c[ 12][ t]], 
            Times[ -0.041319668477947373, 
              c[ 13][ t]], 
            Times[ -0.021580547817548056, 
              c[ 14][ t]], 
            Times[ 3.8981718325193755*^-17, 
              c[ 15][ t]], 
            Times[ 0.022561481809254675, 
              c[ 16][ t]], 
            Times[ 0.045163358568919114, 
              c[ 17][ t]], 
            Times[ 0.066820663127759972, 
              c[ 18][ t]], 
            Times[ 0.086542809078944752, 
              c[ 19][ t]], 
            Times[ 0.10337416789158595, 
              c[ 20][ t]], 
            Times[ 0.11643488132933186, 
              c[ 21][ t]], 
            Times[ 0.12496032289024847, 
              c[ 22][ t]], 
            Times[ 0.12833762891430925, 
              c[ 23][ t]], 
            Times[ 0.12613778810677614, 
              c[ 24][ t]], 
            Times[ 0.1181419061618126, 
              c[ 25][ t]], 
            Times[ 0.10436044624225692, 
              c[ 26][ t]], 
            Times[ 0.085044480344421705, 
              c[ 27][ t]], 
            Times[ 0.060688263076985223, 
              c[ 28][ t]], 
            Times[ 0.032022748374426029, 
              c[ 29][ t]], 
            Times[ -3.8981718325193761*^-17, 
              c[ 30][ t]], 
            Times[ -0.034231213779558796, 
              c[ 31][ t]], 
            Times[ -0.069358014945125918, 
              c[ 32][ t]], 
            Times[ -0.10394325375429328, 
              c[ 33][ t]], 
            Times[ -0.13647135277833591, 
              c[ 34][ t]], 
            Times[ -0.1653986686265376, 
              c[ 35][ t]], 
            Times[ -0.18920668216016426, 
              c[ 36][ t]], 
            Times[ -0.20645618564475834, 
              c[ 37][ t]], 
            Times[ -0.21584055771952013, 
              c[ 38][ t]], 
            Times[ -0.21623620818304484, 
              c[ 39][ t]], 
            Times[ -0.20674833578317206, 
              c[ 40][ t]], 
            Times[ -0.18675027222298618, 
              c[ 41][ t]], 
            Times[ -0.15591488063143982, 
              c[ 42][ t]], 
            Times[ -0.11423673049785459, 
              c[ 43][ t]], 
            Times[ -0.062044074975450718, 
              c[ 44][ t]], 
            Times[ 3.8981718325193761*^-17, 
              c[ 45][ t]], 
            Times[ 0.070907514257657456, 
              c[ 46][ t]], 
            Times[ 0.14938649372796314, 
              c[ 47][ t]], 
            Times[ 0.23387232094715985, 
              c[ 48][ t]], 
            Times[ 0.32256865202152113, 
              c[ 49][ t]], 
            Times[ 0.41349667156634362, 
              c[ 50][ t]], 
            Times[ 0.50455115242710469, 
              c[ 51][ t]], 
            Times[ 0.59356153372868015, 
              c[ 52][ t]], 
            Times[ 0.67835603854706272, 
              c[ 53][ t]], 
            Times[ 0.75682672864065692, 
              c[ 54][ t]], 
            Times[ 0.82699334313268802, 
              c[ 55][ t]], 
            Times[ 0.88706379305918348, 
              c[ 56][ t]], 
            Times[ 0.93548928378863916, 
              c[ 57][ t]], 
            Times[ 0.9710122092317629, 
              c[ 58][ t]], 
            Times[ 0.99270519960720671, 
              c[ 59][ t]], 
            Times[ 79.956835208714864, 
              c[ 60][ t]]]]],
      Editable->False]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Abs[\[Psi][x, t]]^2, {x, \(-15\), 15}, PlotRange \[Rule] {0, 1}, 
          PlotLabel \[Rule] \*"\"\<(|\[Psi][x,t]|\!\(\()\^2\)\), t= \>\"" <> 
              ToString[t], AxesLabel \[Rule] {"\<x\>", "\<\>"}], {t, 0, 
          2.4,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.51"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -52.625 0 ]
[.5 .63053 52.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -113.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
164.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.04262 0 L
.06244 0 L
.08255 0 L
.10458 0 L
.12415 0 L
.14509 0 L
.16639 0 L
.18653 0 L
.20651 0 L
.22495 0 L
.23397 0 L
.24367 0 L
.24923 0 L
.25432 0 L
.25677 0 L
.25744 0 L
.25815 0 L
.25944 0 L
.26075 0 L
.26199 0 L
.2631 0 L
.2643 0 L
.26667 0 L
.26735 0 L
.268 0 L
.26921 0 L
.27036 0 L
.27141 0 L
.27257 0 L
.2738 0 L
.27504 0 L
.27573 0 L
.27636 0 L
.27753 0 L
.27876 0 L
.27942 0 L
.28012 0 L
.28138 0 L
.28215 0 L
.28288 0 L
.28353 0 L
.28424 0 L
.28555 0 L
.28677 0 L
.28748 1e-05 L
.28812 1e-05 L
.28886 1e-05 L
.28956 1e-05 L
.29024 2e-05 L
Mistroke
.29096 3e-05 L
.29226 4e-05 L
.29305 6e-05 L
.2938 8e-05 L
.29447 .0001 L
.2952 .00013 L
.29642 .00021 L
.29711 .00027 L
.29776 .00034 L
.29907 .00053 L
.2998 .00067 L
.30046 .00083 L
.30166 .00122 L
.30295 .00182 L
.30417 .00263 L
.3053 .00365 L
.30648 .00508 L
.30773 .00711 L
.30879 .00939 L
.30995 .0126 L
.31121 .0171 L
.31254 .02336 L
.31381 .03097 L
.31495 .03955 L
.31719 .06187 L
.31961 .09604 L
.3219 .13938 L
.324 .18932 L
.32915 .34492 L
.33198 .43876 L
.33466 .51972 L
.33587 .5505 L
.33716 .57784 L
.33782 .58955 L
.33856 .60028 L
.33987 .61317 L
.34105 .61784 L
.34232 .61527 L
.34352 .60568 L
.34462 .59105 L
.34571 .5714 L
.34688 .54535 L
.34899 .48783 L
.35378 .33228 L
.3584 .1928 L
.36101 .13155 L
.36342 .08811 L
.36612 .05323 L
.36748 .04039 L
.36898 .0293 L
Mistroke
.37029 .02183 L
.3717 .01567 L
.37303 .0113 L
.37424 .00827 L
.37549 .00593 L
.37665 .0043 L
.37793 .00299 L
.37858 .00247 L
.37928 .002 L
.38058 .00134 L
.3818 .00091 L
.38298 .00062 L
.38408 .00043 L
.38534 .00028 L
.38654 .00018 L
.38761 .00012 L
.38878 8e-05 L
.39005 5e-05 L
.39069 4e-05 L
.3914 3e-05 L
.39265 2e-05 L
.39382 1e-05 L
.39493 1e-05 L
.39611 0 L
.39711 0 L
.3982 0 L
.39938 0 L
.40064 0 L
.40183 0 L
.40292 0 L
.40421 0 L
.40486 0 L
.40557 0 L
.40684 0 L
.40802 0 L
.40873 0 L
.40941 0 L
.41069 0 L
.4114 0 L
.41206 0 L
.41278 0 L
.41355 0 L
.41485 0 L
.41559 0 L
.41626 0 L
.41748 0 L
.41813 0 L
.41882 0 L
.42002 0 L
.42114 0 L
Mistroke
.42242 0 L
.42358 0 L
.42477 0 L
.42588 0 L
.42841 0 L
.43353 0 L
.44272 0 L
.45337 0 L
.4635 0 L
.48374 0 L
.50226 0 L
.52206 0 L
.54044 0 L
.56095 0 L
.57956 0 L
.60042 0 L
.61961 0 L
.65815 0 L
.67697 0 L
.69763 0 L
.71713 0 L
.73804 0 L
.74821 0 L
.75927 0 L
.76883 0 L
.77939 0 L
.78429 0 L
.78958 0 L
.79415 0 L
.79915 0 L
.80449 0 L
.8074 0 L
.80879 0 L
.81011 0 L
.81133 0 L
.81265 0 L
.81386 0 L
.81497 0 L
.81617 0 L
.81749 0 L
.81815 0 L
.81887 0 L
.82016 0 L
.82084 0 L
.82149 0 L
.8227 0 L
.824 0 L
.82541 0 L
.82795 0 L
.83028 0 L
Mistroke
.83565 0 L
.84132 0 L
.85091 0 L
.86142 0 L
.88096 0 L
.89191 0 L
.90188 0 L
.92261 0 L
.94177 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`<000002@3oool00`000000oooo0?ooo`070?ooo`<000001P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<05P3oool001/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0R0?ooo`8000002@3oool00`000000oooo0?oo
o`070?ooo`800000903oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0?0?ooo`8000000P3oool2000001D0oooo001a
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2j
0?ooo`00LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0^P3oool00780oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0;X0oooo001b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`2j0?ooo`00LP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0^P3oool00780oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0;X0oooo001c0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2j0?ooo`00L`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02D0oooo0P00002k0?ooo`00L`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0^P3oool007<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0;X0oooo001c
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2j
0?ooo`00L`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0^P3oool007<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0;X0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`2j0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0^P3oool007@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;X0oooo001d0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool09P3oool200000;/0oooo001d0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2j0?ooo`00M03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0^P3oool007@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;X0oooo001d
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2j
0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0^P3oool007@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0;X0oooo001d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`2j0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0^P3oool007@0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0V0?ooo`800000^`3oool007@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0;X0oooo001d0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2j0?ooo`00M03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0^P3oool007@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0;X0oooo001d
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2j
0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0^P3oool007@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`05
0>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo1@0000060?ooo`030000003oool0oooo
0;X0oooo001e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01P3oool0
0`000000oooo0?ooo`2j0?ooo`00M@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00`0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^00L0oooo00<00000
0?ooo`3oool0^P3oool007D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?oo
o`050000003oool0oooo0?ooo`0000003@3oool00`2IVIT08R8R0>k^kP060?ooo`<00000^P3oool0
07D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`050?ooo`030000003oool0oooo0;X0oooo001e0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool01@0A4A40oooo0?ooo`3oool0
4A4A00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00M@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;
0?ooo`050000002k^k/0oooo09VIV@0A4A401P3oool00`000000oooo0?ooo`2j0?ooo`00M@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00M@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0^P3o
ool007D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0;X0oooo001e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`2j0?ooo`00M@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0^P3oool007D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`800000^`3oool007D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0;X0oooo001e0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2j0?ooo`00MP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^P3o
ool007H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0;X0oooo001f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0
oooo0P00002k0?ooo`00MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2j0?ooo`00MP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^P3o
ool007H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo0;X0oooo001f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0
oooo0P00002k0?ooo`00MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00
MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0
oooo001f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@0A4A40oooo
0?ooo`3oool04A4A00/0oooo1@0000060?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000/0
oooo00@0A4A40=gMg@3oool000001`3oool300000;X0oooo001f0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000/0oooo00@0gMgM05EE
E@3oool000001`3oool00`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0307MgM`3<c<`0
000000L0oooo00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A400000007
0?ooo`030000003oool0oooo0;X0oooo001f0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool01@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool01P3oool0
0`000000oooo0?ooo`2j0?ooo`00MP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0^P3oool007H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`800000^`3oool007L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00
M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
^P3oool007L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`800000^`3oool007L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00
M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
^P3oool007L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02T0oooo0P00002k0?ooo`00M`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2j0?ooo`00
M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
^P3oool007L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0;X0oooo001g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3^k^h0<c<c0000000A
4A40c<c<00H0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0
EEEE07MgM`3oool0VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo
00D000000?ooo`3oool0oooo000000060?ooo`<00000^P3oool007L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000
VIVI0?ooo`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@00
0000EEEE0000000A4A40c<c<00H0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0?0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool0
0`1EEED0R8R80?ooo`080?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM
014A4@2IVIT0203oool00`000000oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00l0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@0
0000014A4@H0oooo00<000000?ooo`3oool0^P3oool007L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;X0oooo001g0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2j0?ooo`00N03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0^P3oool007P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;X0oooo
001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool200000;/0oooo001h
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2j
0?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0^P3oool007P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0;X0oooo001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`2j0?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0^P3oool007P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;X0oooo001h0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2j0?ooo`00N03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0^P3oool007P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`800000^`3oool007P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;X0oooo001h
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2j
0?ooo`00N03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0^P3oool007P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0;X0oooo001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`2j0?ooo`00N03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0^P3oool007P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;X0oooo001h0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2j0?ooo`00N03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo0P00002k0?ooo`00N03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0^P3oool007P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;X0oooo001h
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2j
0?ooo`00N03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0^P3oool007P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000
oooo0?ooo`2j0?ooo`00N@3oool01@000000oooo0?ooo`3oool000000180oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<00000
0?ooo`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`0507MgM`2IVIT0
oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P060?ooo`030000
003oool0oooo0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`0000004P3oool01@0A4A40oooo
0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`0000004P3oool01@000000oooo0?ooo`3oool0
000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`060?ooo`<00000^P3oool007T0oooo00D00000
0?ooo`3oool0oooo0000000B0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@3<c<`00000
000000000000c<c<00H0oooo00<000000?ooo`3oool0^P3oool007T0oooo00D000000?ooo`3oool0
oooo0000000B0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/0
4A4A00H0oooo00<000000?ooo`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000H0oooo
00<000000?ooo`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00H0oooo00<000000?oo
o`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`030000003oool0oooo
0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`2j0?oo
o`00N@3oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0^P3oool007T0
oooo00D000000?ooo`3oool0oooo0000000]0?ooo`030000003oool0oooo0;X0oooo001i0?ooo`05
0000003oool0oooo0?ooo`000000;@3oool200000;/0oooo001i0?ooo`050000003oool0oooo0?oo
o`000000;@3oool00`000000oooo0?ooo`2j0?ooo`00N@3oool01@000000oooo0?ooo`3oool00000
02d0oooo00<000000?ooo`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000]0?oo
o`030000003oool0oooo0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`00
0000oooo0?ooo`2j0?ooo`00N@3oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?oo
o`3oool0^P3oool007T0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`030000003oool0oooo
0;X0oooo001i0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`2j0?oo
o`00N@3oool01@000000oooo0?ooo`3oool0000002d0oooo00<000000?ooo`3oool0^P3oool007T0
oooo00D000000?ooo`3oool0oooo0000000]0?ooo`800000^`3oool007T0oooo00D000000?ooo`3o
ool0oooo0000000]0?ooo`030000003oool0oooo0;X0oooo001i0?ooo`040000003oool0oooo0000
02h0oooo00<000000?ooo`3oool0^P3oool007T0oooo00@000000?ooo`3oool00000;P3oool00`00
0000oooo0?ooo`2j0?ooo`00NP3oool00`000000oooo0000000^0?ooo`030000003oool0oooo0;X0
oooo001j0?ooo`030000003oool0000002h0oooo00<000000?ooo`3oool0^P3oool007X0oooo00<0
00000?ooo`000000;P3oool00`000000oooo0?ooo`2j0?ooo`00NP3oool00`000000oooo0000000^
0?ooo`030000003oool0oooo0;X0oooo001j0?ooo`030000003oool0000002h0oooo00<000000?oo
o`3oool0^P3oool007X0oooo00<000000?ooo`000000;P3oool00`000000oooo0?ooo`2j0?ooo`00
NP3oool00`000000oooo0000000^0?ooo`800000^`3oool007X0oooo00<000000?ooo`000000;P3o
ool00`000000oooo0?ooo`2j0?ooo`00NP3oool00`000000oooo0000000^0?ooo`030000003oool0
oooo0;X0oooo001j0?ooo`030000003oool0000002h0oooo00<000000?ooo`3oool0^P3oool007X0
oooo00<000000?ooo`000000;P3oool00`000000oooo0?ooo`2j0?ooo`00NP3oool00`000000oooo
0000000^0?ooo`030000003oool0oooo0;X0oooo001j0?ooo`030000003oool0000002h0oooo00<0
00000?ooo`3oool0^P3oool007/0oooo00<000000?ooo`3oool08`3oool400000003014A4@3oool0
oooo00<0oooo00<000000?ooo`3oool0^P3oool007/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo001k0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool01@3oool300000;X0oooo002S0?ooo`030000003oool0oooo0<80oooo
002S0?ooo`030000003oool0oooo0<80oooo002S0?ooo`030000003oool0oooo0<80oooo002S0?oo
o`030000003oool0oooo0<80oooo002Q0?ooo`80EEEE00<000000?ooo`3oool0`P3oool00?l0oooo
J@3oool00740oooo00<0MgMg06IVIP3oool00`3oool00`000000oooo0?ooo`030?ooo`030;^k^`0c
<c<0oooo00H0oooo0P00000;0?ooo`03014A4@2k^k/0oooo00`0oooo0P0000080?ooo`060000003o
ool0oooo0?ooo`1VIVH0MgMg3@3oool00`0A4A40^k^k0?ooo`2V0?ooo`00L03oool00`3MgMd04A4A
0>k^kP040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`80<c<c3P3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`3^
k^h04A4A0=gMg@0<0?ooo`80<c<cY`3oool00700oooo00<0EEEE09VIV@3oool0103oool00`000000
oooo0?ooo`020?ooo`0509VIV@0A4A4000000000002ZZZX01@3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool200000080oooo00<0R8R80000002ZZZX01@3oool01@2IVIT0000000000014A4@0
^k^k00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0308R8R01VIVH0
oooo00/0oooo00<0R8R80000002ZZZX0303oool01@2IVIT0000000000014A4@0^k^k0140oooo00D0
k^k^03<c<`000000<c<c0>k^kP1o0?ooo`00L03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00H000000:ZZZP1EEED0R8R805EEE@2k^k/40?ooo`030000003oool0oooo0080
oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`20?ooo`030<c<c00000004A4A00D0oooo00D04A4A
0;^k^`3^k^h0MgMg014A4@030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`3^k^h000000?ooo`0;0?ooo`030<c<c00000004A4A00`0oooo00D04A4A0;^k^`3^k^h0MgMg
014A4@020?ooo`H000002@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg07l0oooo001`0?ooo`0303<c
<`3oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01P0c<c<0k^k^09VIV@1EEED0gMgM014A
4@@0oooo00<000000?ooo`3oool00`3oool0103MgMd000000000003<c<`;0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool04`3oool01@0A4A40oooo0?ooo`3oool04A4A07l0oooo001`
0?ooo`0303<c<`3oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01`2k^k/0A4A40<c<c00R
8R80oooo014A4@3<c<`00`3oool00`000000oooo0?ooo`030?ooo`040>k^kP0R8R8000000>k^kP/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`H000002@3oool01@000000
oooo0?ooo`3oool0000007l0oooo001`0?ooo`030000003^k^h0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01`3^k^h000000?ooo`000000k^k^06IVIP28R8P00`3oool00`000000oooo0?ooo`02
0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<02`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`3^k^h000000?ooo`0J0?ooo`030000003o
ool0oooo01<0oooo00D000000?ooo`3oool0oooo0000001o0?ooo`00L03oool00`1EEED0MgMg0?oo
o`040?ooo`030000003oool0oooo0080oooo00@0IVIV09VIV@3oool0<c<c0P2k^k/01@000000oooo
0?ooo`3oool0000000@0oooo0P0000020?ooo`800000203oool00`0A4A40000000000003000000@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0307MgM`1EEED0oooo00<0
oooo1000000A0?ooo`03014A4@000000000000<000004P3oool01@0A4A40oooo0?ooo`3oool04A4A
07l0oooo001`0?ooo`030=gMg@0A4A40k^k^00@0oooo00<000000?ooo`3oool01@3oool00`1VIVH0
MgMg0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`3^k^h04A4A0=gMg@050?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg07l0oooo001a
0?ooo`0307MgM`1VIVH0oooo00<0oooo00<000000?ooo`3oool01@3oool00`2ZZZX0A4A40?ooo`04
0?ooo`8000004`3oool00`000000oooo0?ooo`040?ooo`800000203oool01P000000oooo0?ooo`3o
ool0IVIV07MgM`L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h0O`3oool00;X0oooo00<000000?ooo`3oool0Z`3oool00;L0oooo00@0
00000?ooo`3oool00000[@3oool00;P0oooo0P00002^0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.02961 0 L
.03068 0 L
.0317 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06596 0 L
.06668 0 L
.06797 0 L
.06922 0 L
.07037 0 L
.07101 0 L
.07172 0 L
.073 0 L
Mistroke
.0737 0 L
.07446 0 L
.07517 0 L
.07583 0 L
.0766 0 L
.07741 0 L
.07811 0 L
.07885 0 L
.07955 0 L
.08019 0 L
.08144 0 L
.08213 0 L
.08289 0 L
.08361 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09026 0 L
.09148 0 L
.09274 0 L
.09341 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10086 0 L
.10201 0 L
.10333 0 L
.10458 0 L
.10572 0 L
.10694 0 L
.1081 0 L
.10916 0 L
.11033 0 L
.11162 0 L
.11227 0 L
.11297 0 L
.11422 0 L
.11491 0 L
.11554 0 L
.11624 0 L
.11698 0 L
.11822 0 L
.11892 0 L
Mistroke
.11958 0 L
.12446 0 L
.1256 0 L
.12684 0 L
.12801 0 L
.1291 0 L
.13018 0 L
.13115 0 L
.13228 0 L
.13334 0 L
.1345 0 L
.13573 0 L
.13677 0 L
.13792 0 L
.13916 0 L
.13985 0 L
.14048 0 L
.14171 0 L
.14288 0 L
.15165 0 L
.15281 0 L
.15404 0 L
.15521 0 L
.15626 0 L
.15745 0 L
.15858 0 L
.15979 0 L
.16111 0 L
.16176 0 L
.16248 0 L
.16323 0 L
.16393 0 L
.16518 0 L
.16588 0 L
.16653 0 L
.16777 0 L
.16846 0 L
.1691 0 L
.17035 0 L
.17149 0 L
.17274 0 L
.17388 0 L
.17513 0 L
.17579 0 L
.17649 0 L
.17766 0 L
.17875 0 L
.17995 0 L
.18123 0 L
.18187 0 L
Mistroke
.18255 0 L
.18378 0 L
.1851 0 L
.18585 0 L
.18655 0 L
.18782 0 L
.18898 0 L
.18962 0 L
.19031 0 L
.19159 0 L
.19283 0 L
.19395 0 L
.19525 0 L
.19648 0 L
.19761 0 L
.19866 0 L
.19989 0 L
.20102 0 L
.20223 0 L
.20353 0 L
.20474 0 L
.20589 0 L
.21123 0 L
.21252 0 L
.21374 0 L
.215 0 L
.21569 0 L
.2164 0 L
.21714 0 L
.21781 0 L
.21853 0 L
.21932 0 L
.22 0 L
.22073 0 L
.22203 0 L
.24193 0 L
.24257 0 L
.24327 0 L
.24454 0 L
.2453 0 L
.24601 0 L
.2467 0 L
.24735 0 L
.24863 0 L
.2498 0 L
.25106 0 L
.25176 0 L
.25241 0 L
.25364 0 L
.25434 0 L
Mistroke
.25498 0 L
.2563 0 L
.25703 0 L
.2577 0 L
.25844 0 L
.25913 0 L
.25989 0 L
.26069 0 L
.26138 0 L
.26203 0 L
.26275 0 L
.26351 0 L
.26482 0 L
.26604 0 L
.26674 0 L
.26738 0 L
.26811 0 L
.2688 0 L
.27021 0 L
.27098 0 L
.2717 0 L
.27297 0 L
.27364 0 L
.27437 0 L
.27565 0 L
.27686 0 L
.27796 0 L
.27914 0 L
.28042 0 L
.28161 0 L
.28289 0 L
.28362 0 L
.28431 0 L
.28542 0 L
.28665 0 L
.28793 0 L
.28912 0 L
.29023 0 L
.29125 0 L
.29242 0 L
.29353 0 L
.29473 0 L
.29601 0 L
.2971 0 L
.2983 0 L
.29959 0 L
.30032 0 L
.30098 0 L
.30226 0 L
.30348 0 L
Mistroke
.30473 1e-05 L
.30543 1e-05 L
.30607 1e-05 L
.30726 1e-05 L
.30851 2e-05 L
.30964 3e-05 L
.31069 4e-05 L
.31184 6e-05 L
.31307 8e-05 L
.31439 .00012 L
.31513 .00015 L
.31582 .00018 L
.31708 .00025 L
.31842 .00036 L
.31962 .00049 L
.32074 .00065 L
.32197 .00088 L
.3233 .00122 L
.32445 .0016 L
.32553 .00206 L
.32671 .00269 L
.32797 .00355 L
.3293 .00472 L
.33055 .00613 L
.33168 .00773 L
.33289 .0098 L
.33509 .01484 L
.33711 .02132 L
.33929 .03077 L
.34168 .04486 L
.34418 .06451 L
.3469 .09261 L
.35185 .16319 L
.36114 .34304 L
.36384 .39373 L
.36639 .43394 L
.3678 .45183 L
.36854 .45974 L
.36932 .46689 L
.36998 .47193 L
.37071 .47636 L
.37198 .48128 L
.3733 .48243 L
.37449 .47998 L
.37516 .47721 L
.37588 .47308 L
.37718 .46269 L
.37841 .4498 L
.3797 .43307 L
.38203 .39642 L
Mistroke
.39143 .2124 L
.39391 .16778 L
.39662 .12535 L
.3992 .09179 L
.40155 .06728 L
.40394 .04767 L
.4065 .03201 L
.40887 .02153 L
.4111 .01445 L
.41216 .01185 L
.41328 .00955 L
.4153 .00639 L
.41642 .00507 L
.41746 .00406 L
.41859 .00317 L
.41984 .0024 L
.4211 .0018 L
.42244 .00131 L
.42368 .00097 L
.42484 .00073 L
.42621 .00051 L
.42746 .00037 L
.42883 .00026 L
.42952 .00021 L
.43028 .00017 L
.43158 .00012 L
.43276 8e-05 L
.43341 7e-05 L
.43412 6e-05 L
.4354 4e-05 L
.43661 3e-05 L
.43789 2e-05 L
.43898 1e-05 L
.44018 1e-05 L
.44141 1e-05 L
.44259 0 L
.44364 0 L
.44479 0 L
.44604 0 L
.44674 0 L
.44737 0 L
.4486 0 L
.44976 0 L
.45085 0 L
.452 0 L
.45299 0 L
.45407 0 L
.45523 0 L
.45648 0 L
.45765 0 L
Mistroke
.45873 0 L
.45991 0 L
.46102 0 L
.46223 0 L
.46354 0 L
.46484 0 L
.46549 0 L
.46621 0 L
.46748 0 L
.46865 0 L
.46985 0 L
.47098 0 L
.47201 0 L
.47309 0 L
.47428 0 L
.47537 0 L
.47654 0 L
.47783 0 L
.4785 0 L
.47922 0 L
.48054 0 L
.48182 0 L
.48301 0 L
.48856 0 L
.4986 0 L
.50921 0 L
.51052 0 L
.51174 0 L
.51301 0 L
.51373 0 L
.51441 0 L
.51562 0 L
.51671 0 L
.51918 0 L
.52814 0 L
.53039 0 L
.53152 0 L
.53278 0 L
.53343 0 L
.53413 0 L
.53539 0 L
.53781 0 L
.53849 0 L
.53914 0 L
.54034 0 L
.54164 0 L
.54231 0 L
.54305 0 L
.54428 0 L
.54558 0 L
Mistroke
.54679 0 L
.54791 0 L
.54922 0 L
.54996 0 L
.55064 0 L
.5519 0 L
.55323 0 L
.55396 0 L
.55465 0 L
.5554 0 L
.55622 0 L
.55691 0 L
.55764 0 L
.55894 0 L
.56017 0 L
.56134 0 L
.56199 0 L
.56269 0 L
.56391 0 L
.56508 0 L
.56631 0 L
.56747 0 L
.56853 0 L
.56978 0 L
.57046 0 L
.57111 0 L
.57227 0 L
.57353 0 L
.57424 0 L
.57491 0 L
.57568 0 L
.57638 0 L
.57765 0 L
.57903 0 L
.59861 0 L
.60116 0 L
.60186 0 L
.60261 0 L
.60324 0 L
.60394 0 L
.60519 0 L
.60589 0 L
.60654 0 L
.60773 0 L
.60898 0 L
.60967 0 L
.61042 0 L
.61112 0 L
.61175 0 L
.61246 0 L
Mistroke
.61321 0 L
.61403 0 L
.61479 0 L
.61609 0 L
.61677 0 L
.61751 0 L
.6182 0 L
.61884 0 L
.62008 0 L
.62134 0 L
.62198 0 L
.62269 0 L
.62394 0 L
.62511 0 L
.62577 0 L
.62648 0 L
.62774 0 L
.62844 0 L
.62911 0 L
.62988 0 L
.63058 0 L
.63176 0 L
.63304 0 L
.63423 0 L
.63533 0 L
.63654 0 L
.63723 0 L
.63786 0 L
.63853 0 L
.63924 0 L
.64054 0 L
.64171 0 L
.64296 0 L
.64414 0 L
.64521 0 L
.64648 0 L
.64719 0 L
.64784 0 L
.64905 0 L
.65032 0 L
.65143 0 L
.65261 0 L
.65373 0 L
.65475 0 L
.65595 0 L
.65725 0 L
.65848 0 L
.65961 0 L
.66079 0 L
.66203 0 L
Mistroke
.66309 0 L
.66425 0 L
.6655 0 L
.6662 0 L
.66684 0 L
.66808 0 L
.66925 0 L
.67035 0 L
.67151 0 L
.67251 0 L
.67359 0 L
.67474 0 L
.67583 0 L
.67711 0 L
.67829 0 L
.67956 0 L
.68026 0 L
.68092 0 L
.68219 0 L
.68335 0 L
.68464 0 L
.68529 0 L
.686 0 L
.68677 0 L
.68749 0 L
.68815 0 L
.68886 0 L
.69017 0 L
.6914 0 L
.6925 0 L
.69371 0 L
.69502 0 L
.69573 0 L
.6964 0 L
.6976 0 L
.6989 0 L
.7002 0 L
.70143 0 L
.70211 0 L
.70284 0 L
.70413 0 L
.70536 0 L
.70666 0 L
.70788 0 L
.70899 0 L
.7103 0 L
.71102 0 L
.71171 0 L
.71292 0 L
.71425 0 L
Mistroke
.71494 0 L
.7157 0 L
.71649 0 L
.71724 0 L
.71794 0 L
.71858 0 L
.71933 0 L
.72002 0 L
.72119 0 L
.72244 0 L
.72361 0 L
.72469 0 L
.72595 0 L
.72661 0 L
.72732 0 L
.7285 0 L
.7298 0 L
.73102 0 L
.73233 0 L
.73308 0 L
.73376 0 L
.73444 0 L
.73508 0 L
.73634 0 L
.7375 0 L
.73876 0 L
.73946 0 L
.7401 0 L
.74131 0 L
.74261 0 L
.74381 0 L
.74495 0 L
.74627 0 L
.74749 0 L
.74813 0 L
.74883 0 L
.74957 0 L
.75026 0 L
.75139 0 L
.75259 0 L
.75361 0 L
.75472 0 L
.75593 0 L
.75722 0 L
.75843 0 L
.75954 0 L
.76084 0 L
.7615 0 L
.76222 0 L
.7635 0 L
Mistroke
.7647 0 L
.76542 0 L
.76611 0 L
.76739 0 L
.76811 0 L
.76878 0 L
.76951 0 L
.77029 0 L
.77148 0 L
.77277 0 L
.77399 0 L
.7751 0 L
.77634 0 L
.77704 0 L
.77769 0 L
.77901 0 L
.77975 0 L
.78043 0 L
.78161 0 L
.78273 0 L
.78395 0 L
.78526 0 L
.78591 0 L
.78663 0 L
.78793 0 L
.7892 0 L
.79038 0 L
.79158 0 L
.79272 0 L
.79373 0 L
.79483 0 L
.79603 0 L
.7973 0 L
.79847 0 L
.79957 0 L
.80087 0 L
.80205 0 L
.80332 0 L
.80404 0 L
.8047 0 L
.8058 0 L
.80702 0 L
.80829 0 L
.80948 0 L
.81017 0 L
.81081 0 L
.81148 0 L
.81221 0 L
.81342 0 L
.81472 0 L
Mistroke
.81545 0 L
.81624 0 L
.81698 0 L
.81767 0 L
.81898 0 L
.81963 0 L
.82036 0 L
.82165 0 L
.82285 0 L
.82417 0 L
.82491 0 L
.82557 0 L
.8268 0 L
.82749 0 L
.82812 0 L
.82929 0 L
.83052 0 L
.83163 0 L
.83281 0 L
.83384 0 L
.83495 0 L
.83626 0 L
.83749 0 L
.8387 0 L
.83981 0 L
.84504 0 L
.84629 0 L
.8476 0 L
.84872 0 L
.84995 0 L
.85122 0 L
.85241 0 L
.85306 0 L
.85377 0 L
.85506 0 L
.85581 0 L
.85649 0 L
.85779 0 L
.85846 0 L
.85921 0 L
.85998 0 L
.8607 0 L
.86196 0 L
.86259 0 L
.8633 0 L
.86453 0 L
.8657 0 L
.86636 0 L
.86706 0 L
.86831 0 L
Mistroke
.86897 0 L
.86966 0 L
.87043 0 L
.87114 0 L
.87232 0 L
.87358 0 L
.87423 0 L
.87495 0 L
.87622 0 L
.87742 0 L
.87871 0 L
.87992 0 L
.88103 0 L
.88227 0 L
.88341 0 L
.88467 0 L
.88538 0 L
.88601 0 L
.88718 0 L
.88845 0 L
.88965 0 L
.89075 0 L
.89181 0 L
.89279 0 L
.89388 0 L
.89504 0 L
.89608 0 L
.8972 0 L
.89843 0 L
.89958 0 L
.90083 0 L
.90215 0 L
.90283 0 L
.90357 0 L
.90487 0 L
.9061 0 L
.90741 0 L
.90863 0 L
.90977 0 L
.91046 0 L
.9112 0 L
.912 0 L
.91275 0 L
.9134 0 L
.91409 0 L
.91486 0 L
.91557 0 L
.91686 0 L
.91759 0 L
.91827 0 L
Mistroke
.91952 0 L
.92084 0 L
.9215 0 L
.9222 0 L
.92346 0 L
.92411 0 L
.9248 0 L
.92557 0 L
.92628 0 L
.92754 0 L
.92821 0 L
.92891 0 L
.93021 0 L
.9314 0 L
.93263 0 L
.93378 0 L
.93505 0 L
.93576 0 L
.93641 0 L
.93752 0 L
.93874 0 L
.93989 0 L
.94096 0 L
.94212 0 L
.94334 0 L
.94439 0 L
.94553 0 L
.94677 0 L
.94809 0 L
.94934 0 L
.95048 0 L
.95162 0 L
.95268 0 L
.95384 0 L
.95508 0 L
.95607 0 L
.95715 0 L
.95833 0 L
.95944 0 L
.96049 0 L
.96147 0 L
.96254 0 L
.96369 0 L
.9649 0 L
.96604 0 L
.96707 0 L
.96818 0 L
.96914 0 L
.9702 0 L
.97123 0 L
Mistroke
.97235 0 L
.97338 0 L
.97433 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P0000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool3000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo
00D0k^k^028R8P1gMgL0MgMg03<c<`0F0?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02T0oooo0P0000020?ooo`030000003oool0oooo01<0oooo0P00000H0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00l0oooo0P0000020?ooo`8000005@3oool007P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo001h0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`2j0?ooo`00N@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0^P3oool007T0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0;X0
oooo001j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`2j0?ooo`00NP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0^P3oool007X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0;X0oooo001j0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06@3oool200000;/0oooo001j0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`2j0?ooo`00N`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0^P3oool007/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;X0oooo001k0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`2j0?ooo`00N`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0^P3oool007/0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0;X0
oooo001k0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`2j0?ooo`00O03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0^P3oool007`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0K
0?ooo`800000^`3oool007`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0;X0oooo001l0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`2j0?ooo`00O03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0^P3oool007`0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;X0oooo001l0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2j0?ooo`00O@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0^P3oool007d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;X0
oooo001m0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`2j0?ooo`00O@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo0P00
002k0?ooo`00O@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0^P3oool007d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0;X0oooo001m0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`2j0?ooo`00O@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0^P3oool007d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0;X0oooo001m0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2j0?ooo`00O@3oool00`00
0000oooo0?ooo`0<0?ooo`090000003oool0oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^00D0oooo
0P0R8R840?ooo`D000001P3oool00`000000oooo0?ooo`2j0?ooo`00O@3oool00`000000oooo0?oo
o`0<0?ooo`090000003oool0oooo0?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?oo
o`0509VIV@0R8R80k^k^0?ooo`14A4@01P3oool00`000000oooo0?ooo`2j0?ooo`00O@3oool00`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`0:
0?ooo`0309VIV@0R8R80k^k^00L0oooo00<000000?ooo`3oool0^P3oool007d0oooo00<000000?oo
o`3oool0303oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02`3oool0
0`2IVIT08R8R0>k^kP060?ooo`<00000^P3oool007d0oooo00<000000?ooo`3oool0303oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0303oool00`1gMgL0IVIV0?ooo`05
0?ooo`030000003oool0oooo0;X0oooo001n0?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo014A4@030?ooo`03014A4@3oool0oooo00d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2j0?ooo`00OP3oool00`000000oooo0?ooo`0;0?ooo`090000003oool0oooo
0?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@060?ooo`03
0000003oool0oooo0;X0oooo001n0?ooo`030000003oool0oooo00/0oooo00T000000?ooo`3oool0
oooo0>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2IVIT04A4A0000000R8R80c<c<00H0oooo00<0
00000?ooo`3oool0^P3oool007h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0;X0oooo001n0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`2j0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0^P3oool007h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;X0oooo001n0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool07@3oool200000;/0oooo001n0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2j0?ooo`00OP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0^P3oool007h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;X0
oooo001n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`2j0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0^P3oool007h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0;X0oooo001n0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`2j0?ooo`00OP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0^P3oool007h0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0M0?ooo`800000^`3oool007h0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0;X0oooo001n0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2j0?ooo`00OP3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0^P3oool007l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;X0
oooo001o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0^P3oool007l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0;X0oooo001o0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0^P3oool007l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0N0?ooo`800000^`3oool007l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;X0oooo001o0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2j0?ooo`00O`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0^P3oool007l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0;X0
oooo001o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00D0
k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00@0oooo
00<000000?ooo`3oool0^P3oool007l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001P3oool00`000000oooo
0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`0404A4A03MgMd0oooo000000L0oooo0`00002j0?ooo`00
O`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`040=gMg@1EEED0oooo000000L0oooo00<000000?ooo`3oool0^P3oool007l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`05014A4@3oool0oooo0?oo
o`0A4A40303oool00`1gMgL0c<c<000000070?ooo`030000003oool0oooo0;X0oooo00200?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00`0oooo00<0k^k^04A4A00000001`3oool00`000000oooo0?ooo`2j0?ooo`00P03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00D0k^k^03<c<`000000<c<c0>k^kP0=0?oo
o`0307MgM`000000oooo00H0oooo00<000000?ooo`3oool0^P3oool00800oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;X0oooo00200?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2j0?ooo`00P03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^P3o
ool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0;X0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool20000
0;/0oooo00200?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`2j0?ooo`00P03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0^P3oool00800oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0;X0oooo00200?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`2j0?ooo`00P03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^P3oool00800oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;X0oooo00200?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2j0?ooo`00P03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^P3o
ool00800oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo0;X0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool20000
0;/0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`2j0?ooo`00P@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0^P3oool00840oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0;X0oooo00210?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`2j0?ooo`00P@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0^P3oool00840oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0;X0oooo00210?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2j0?ooo`00P@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0^P3o
ool00840oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`800000^`3oool0
0840oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0;X0oooo00210?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`2j0?ooo`00P@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0^P3oool00840oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0;X0oooo00210?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`2j0?ooo`00P@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0^P3oool00840oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R
8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c0060?ooo`030000003oool0oooo0;X0oooo00210?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00D0oooo0P0R8R840?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801P3oool00`000000oooo0?oo
o`2j0?ooo`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D04A4A
0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool300000;X0oooo
00220?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P060?ooo`030000003oool0oooo0;X0
oooo00220?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D0000005EEE@0000004A4A0<c<c0060?ooo`030000003oool0oooo
0;X0oooo00220?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@0A4A40
oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool0203oool00`000000oooo0?ooo`2j0?oo
o`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI00P0oooo00<000000?ooo`3oool0^P3oool00880
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050>k^kP0c<c<0000003<c
<`3^k^h0303oool0103<c<`0A4A40000000A4A460?ooo`030000003oool0oooo0;X0oooo00220?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2j0?oo
o`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0^P3oool00880oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0;X0oooo00220?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`2j0?ooo`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0240oooo0P00002k0?ooo`00PP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0^P3oool00880oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0;X0oooo00220?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2j0?ooo`00P`3oool01@000000oooo0?oo
o`3oool0000002<0oooo00<000000?ooo`3oool0^P3oool008<0oooo00D000000?ooo`3oool0oooo
0000000S0?ooo`030000003oool0oooo0;X0oooo00230?ooo`050000003oool0oooo0?ooo`000000
8`3oool00`000000oooo0?ooo`2j0?ooo`00P`3oool01@000000oooo0?ooo`3oool0000002<0oooo
00<000000?ooo`3oool0^P3oool008<0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000
003oool0oooo0;X0oooo00230?ooo`050000003oool0oooo0?ooo`0000008`3oool200000;/0oooo
00230?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`2j0?ooo`00P`3o
ool01@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0^P3oool008<0oooo00@0
00000?ooo`3oool00000903oool00`000000oooo0?ooo`2j0?ooo`00P`3oool010000000oooo0?oo
o`00000T0?ooo`030000003oool0oooo0;X0oooo00230?ooo`040000003oool0oooo000002@0oooo
00<000000?ooo`3oool0^P3oool008<0oooo00@000000?ooo`3oool00000903oool00`000000oooo
0?ooo`2j0?ooo`00P`3oool010000000oooo0?ooo`00000T0?ooo`030000003oool0oooo0;X0oooo
00230?ooo`040000003oool0oooo000002@0oooo00<000000?ooo`3oool0^P3oool008<0oooo00@0
00000?ooo`3oool00000903oool200000;/0oooo00230?ooo`040000003oool0oooo000002@0oooo
00<000000?ooo`3oool0^P3oool008<0oooo00<000000?ooo`0000009@3oool00`000000oooo0?oo
o`2j0?ooo`00Q03oool2000002D0oooo00<000000?ooo`3oool0^P3oool008@0oooo0P00000U0?oo
o`030000003oool0oooo0;X0oooo00240?ooo`8000009@3oool00`000000oooo0?ooo`2j0?ooo`00
Q03oool2000002D0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c
0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<000000?ooo`3o
ool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R8R80
VIVI0?ooo`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3o
ool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2j
0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c
<`060?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000
000000000000003<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?oo
o`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@060?ooo`030000003oool0oooo0;X0
oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/00000
00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?oo
o`050:ZZZP0A4A400000014A4@2ZZZX01P3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00
002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00X@3oool40000
0003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool00:<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2j0?ooo`00X`3oool00`000000oooo0?ooo`050?ooo`<00000
^P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool0
0:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:40oooo
0P1EEED00`000000oooo0?ooo`320?ooo`00o`3ooomY0?ooo`00J@3oool00`1gMgL0IVIV0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<0^k^k03<c<`3oool01`3oool2000000/0oooo00<04A4A
0;^k^`3oool0303oool2000000L0oooo00<000000?ooo`3oool00P3oool00`1VIVH0MgMg0?ooo`0<
0?ooo`03014A4@2k^k/0oooo0:d0oooo001X0?ooo`030=gMg@0A4A40k^k^00D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo0P0c<c<>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`3^k^h04A4A0=gMg@0<0?oo
o`80<c<c[P3oool006P0oooo00<0EEEE09VIV@3oool01@3oool01P000000oooo0?ooo`3oool0VIVI
014A4@80000000<0ZZZZ0?ooo`3oool0103oool010000000oooo0?ooo`3oool200000080oooo0P00
00030?ooo`0308R8R0000000ZZZZ00@0oooo00D0VIVI000000000000A4A40;^k^`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`28R8P0IVIV0?ooo`0;0?ooo`0308R8
R0000000ZZZZ00`0oooo00D0VIVI000000000000A4A40;^k^`0@0?ooo`050>k^kP0c<c<0000003<c
<`3^k^h01@3oool2028R8P@0oooo1@00001g0?ooo`00J03oool00`000000oooo0?ooo`050?ooo`0:
0000003oool0oooo0?ooo`000000ZZZZ05EEE@28R8P0EEEE0;^k^`D0oooo00X000000?ooo`3oool0
oooo0>k^kP0R8R80R8R80<c<c0000000c<c<0`3oool00`3<c<`00000014A4@040?ooo`05014A4@2k
^k/0k^k^07MgM`0A4A40103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<0k^k^0000003oool02`3oool00`3<c<`00000014A4@0<0?ooo`06014A4@2k^k/0k^k^07MgM`0A
4A40oooo1P0000090?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0VIVI
028R8P3^k^h0oooo04A4A01g0?ooo`00J03oool00`0c<c<0oooo0?ooo`050?ooo`0:0000003oool0
oooo0?ooo`0c<c<0k^k^09VIV@1EEED0gMgM014A4@D0oooo00<000000?ooo`3oool00P3oool0103M
gMd000000000003<c<`;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool0
1@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0VIVI028R8P3^k^h0N03oool006P0oooo00<0<c<c
0?ooo`3oool01@3oool02`000000oooo0?ooo`3oool0^k^k04A4A03<c<`08R8R0?ooo`0A4A40c<c<
00@0oooo00<000000?ooo`3oool00P3oool0103^k^h08R8R0000003^k^h;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool00`3oool6000000T0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`0309VIV@0R8R80k^k^07L0oooo001X0?ooo`030000003^k^h0oooo00D0oooo00/00000
0?ooo`3oool0oooo0>k^kP000000oooo0000003^k^h0IVIV08R8R0040?ooo`060000003oool0oooo
0?ooo`3^k^h08R8R0P1gMgL00`0c<c<0oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030>k^kP000000oooo01X0oooo00<0
00000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IVIP3oool0
MP3oool006P0oooo00<0EEEE07MgM`3oool01@3oool020000000oooo0?ooo`3oool0IVIV09VIV@3o
ool0<c<c0P2k^k/00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool2
000000P0oooo00<04A4A0000000000000`0000050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`1gMgL0EEEE0?ooo`020?ooo`@000004P3oool00`0A4A40000000000003
00000140oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?ooo`030000003oool0oooo07D0oooo001X
0?ooo`030=gMg@0A4A40k^k^00D0oooo00<000000?ooo`3oool0103oool00`1VIVH0MgMg0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<0k^k^014A4@3MgMd0103oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0180oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k
^k/0oooo09VIV@0A4A40M`3oool006T0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?oo
o`040?ooo`030:ZZZP14A4@0oooo00D0oooo0P00000B0?ooo`030000003oool0oooo00D0oooo0P00
00070?ooo`030000003oool0oooo0080oooo00<0IVIV07MgM`3oool01@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0180oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`0509VI
V@0A4A400000028R8P3<c<`0M`3oool00;80oooo00<000000?ooo`3oool0/`3oool00:l0oooo00@0
00000?ooo`3oool00000]@3oool00;00oooo0P00002f0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.0489 0 L
.05014 0 L
.05083 0 L
.05158 0 L
.05288 0 L
.05404 0 L
.0553 0 L
.05594 0 L
.05663 0 L
.05786 0 L
.05909 0 L
.06026 0 L
.06131 0 L
.06244 0 L
.0637 0 L
.06435 0 L
.06505 0 L
.06632 0 L
.06749 0 L
.06877 0 L
.06949 0 L
.07015 0 L
.07092 0 L
.07165 0 L
.07232 0 L
.07306 0 L
.07376 0 L
.07442 0 L
.07512 0 L
.07587 0 L
.07657 0 L
.07723 0 L
.07847 0 L
.08433 0 L
Mistroke
.08551 0 L
.08676 0 L
.08741 0 L
.08813 0 L
.08938 0 L
.09057 0 L
.09184 0 L
.09305 0 L
.09414 0 L
.09484 0 L
.09549 0 L
.09619 0 L
.09695 0 L
.09825 0 L
.09895 0 L
.09962 0 L
.10087 0 L
.10201 0 L
.10326 0 L
.10458 0 L
.10583 0 L
.10696 0 L
.10818 0 L
.1095 0 L
.11072 0 L
.11185 0 L
.11292 0 L
.11406 0 L
.11539 0 L
.11665 0 L
.11734 0 L
.1181 0 L
.11942 0 L
.12068 0 L
.12132 0 L
.12202 0 L
.12326 0 L
.12442 0 L
.1255 0 L
.12662 0 L
.1276 0 L
.12864 0 L
.12977 0 L
.13081 0 L
.13206 0 L
.13319 0 L
.13443 0 L
.13557 0 L
.13682 0 L
.13745 0 L
Mistroke
.13815 0 L
.13931 0 L
.14056 0 L
.14174 0 L
.14282 0 L
.14411 0 L
.14533 0 L
.14642 0 L
.1476 0 L
.14888 0 L
.14953 0 L
.15024 0 L
.15152 0 L
.15268 0 L
.15385 0 L
.15496 0 L
.15614 0 L
.15741 0 L
.15851 0 L
.15969 0 L
.1608 0 L
.16182 0 L
.16301 0 L
.16431 0 L
.165 0 L
.16564 0 L
.16632 0 L
.16705 0 L
.16777 0 L
.16845 0 L
.16973 0 L
.17039 0 L
.17109 0 L
.17187 0 L
.17259 0 L
.17391 0 L
.17511 0 L
.17577 0 L
.17648 0 L
.17778 0 L
.17898 0 L
.18026 0 L
.18146 0 L
.18255 0 L
.18376 0 L
.18489 0 L
.18613 0 L
.18681 0 L
.18745 0 L
.18812 0 L
Mistroke
.18884 0 L
.19015 0 L
.19135 0 L
.19261 0 L
.20185 0 L
.20302 0 L
.2043 0 L
.20551 0 L
.20663 0 L
.20793 0 L
.20865 0 L
.20931 0 L
.21058 0 L
.21177 0 L
.21245 0 L
.21318 0 L
.21448 0 L
.2152 0 L
.21587 0 L
.21661 0 L
.21741 0 L
.21809 0 L
.21883 0 L
.21952 0 L
.22017 0 L
.22139 0 L
.22269 0 L
.22383 0 L
.22507 0 L
.22628 0 L
.22758 0 L
.22879 0 L
.2299 0 L
.23101 0 L
.23206 0 L
.23337 0 L
.23461 0 L
.23589 0 L
.23658 0 L
.23731 0 L
.23861 0 L
.23984 0 L
.24095 0 L
.24215 0 L
.24331 0 L
.24436 0 L
.24548 0 L
.2467 0 L
.24784 0 L
.24888 0 L
Mistroke
.24987 0 L
.25092 0 L
.25206 0 L
.25327 0 L
.25441 0 L
.25546 0 L
.25668 0 L
.25733 0 L
.25801 0 L
.25927 0 L
.26043 0 L
.26167 0 L
.26282 0 L
.26402 0 L
.26533 0 L
.26647 0 L
.2675 0 L
.2687 0 L
.26982 0 L
.27105 0 L
.27235 0 L
.27347 0 L
.27467 0 L
.27597 0 L
.27718 0 L
.27993 0 L
.28107 0 L
.28228 0 L
.28361 0 L
.28484 0 L
.28598 0 L
.28705 0 L
.28824 0 L
.28949 0 L
.29054 0 L
.29168 0 L
.29272 0 L
.29369 0 L
.29588 0 L
.29822 0 L
.29955 0 L
.3008 0 L
.3021 0 L
.30279 0 L
.30354 0 L
.30485 0 L
.3061 1e-05 L
.30722 1e-05 L
.30844 1e-05 L
.3099 2e-05 L
Mistroke
.31123 2e-05 L
.31265 3e-05 L
.31419 4e-05 L
.31563 5e-05 L
.31694 6e-05 L
.3182 7e-05 L
.31953 .0001 L
.32079 .00012 L
.32193 .00015 L
.32316 .0002 L
.3245 .00025 L
.32688 .00038 L
.32914 .00056 L
.3304 .00069 L
.33179 .00087 L
.33315 .00107 L
.33461 .00135 L
.33597 .00166 L
.33722 .00201 L
.33967 .00291 L
.34216 .00415 L
.34442 .00567 L
.34702 .00799 L
.34948 .01087 L
.35176 .01428 L
.35386 .01818 L
.3586 .03041 L
.36108 .03905 L
.36339 .04871 L
.36866 .07663 L
.37379 .11227 L
.37931 .15903 L
.38944 .25236 L
.39222 .27481 L
.39517 .29528 L
.39796 .31073 L
.39917 .31604 L
.40049 .32078 L
.40175 .32418 L
.40244 .32555 L
.40308 .32651 L
.40423 .32747 L
.40547 .32743 L
.40616 .32693 L
.40691 .32601 L
.40763 .32477 L
.40828 .32332 L
.40953 .31975 L
.41085 .31479 L
.41324 .30276 L
Mistroke
.41548 .28827 L
.42059 .24747 L
.42955 .16479 L
.43911 .08796 L
.44461 .05638 L
.4472 .04384 L
.4496 .0343 L
.452 .02707 L
.45461 .02088 L
.45689 .01587 L
.45934 .01113 L
.46066 .0092 L
.46187 .00791 L
.46308 .007 L
.46423 .00638 L
.4696 .00365 L
.47212 .00227 L
.47339 .00175 L
.4748 .00131 L
.47631 .00097 L
.47773 .00074 L
.47903 .00056 L
.48045 .00041 L
.48172 .0003 L
.48291 .00022 L
.48416 .00017 L
.48486 .00014 L
.48549 .00012 L
.48663 .0001 L
.48787 8e-05 L
.49011 5e-05 L
.49137 3e-05 L
.49208 3e-05 L
.49275 2e-05 L
.49345 2e-05 L
.49409 2e-05 L
.49483 2e-05 L
.49554 1e-05 L
.49794 1e-05 L
.49929 1e-05 L
.50054 1e-05 L
.5018 0 L
.50243 0 L
.50313 0 L
.50439 0 L
.50557 0 L
.50673 0 L
.50778 0 L
.50892 0 L
.51014 0 L
Mistroke
.51144 0 L
.51265 0 L
.51396 0 L
.5147 0 L
.51539 0 L
.51665 0 L
.51781 0 L
.51903 0 L
.51968 0 L
.52036 0 L
.52161 0 L
.52279 0 L
.52384 0 L
.52498 0 L
.52606 0 L
.52719 0 L
.52816 0 L
.52922 0 L
.53046 0 L
.5316 0 L
.53282 0 L
.53351 0 L
.53415 0 L
.53529 0 L
.53651 0 L
.53769 0 L
.53876 0 L
.54815 0 L
.54943 0 L
.55063 0 L
.5513 0 L
.55202 0 L
.55328 0 L
.55449 0 L
.55577 0 L
.55686 0 L
.55806 0 L
.55935 0 L
.56008 0 L
.56074 0 L
.56203 0 L
.56325 0 L
.56456 0 L
.5653 0 L
.56596 0 L
.56675 0 L
.5675 0 L
.56818 0 L
.56893 0 L
.57014 0 L
Mistroke
.57142 0 L
.57262 0 L
.57372 0 L
.57501 0 L
.57573 0 L
.5764 0 L
.5776 0 L
.5789 0 L
.58004 0 L
.58124 0 L
.58255 0 L
.58375 0 L
.58488 0 L
.58592 0 L
.58707 0 L
.5883 0 L
.589 0 L
.58964 0 L
.59035 0 L
.5911 0 L
.59235 0 L
.59307 0 L
.59374 0 L
.59498 0 L
.59612 0 L
.59743 0 L
.59867 0 L
.59998 0 L
.6012 0 L
.60188 0 L
.60261 0 L
.60389 0 L
.60512 0 L
.60641 0 L
.60751 0 L
.60872 0 L
.60946 0 L
.61016 0 L
.61146 0 L
.61219 0 L
.61287 0 L
.61361 0 L
.61439 0 L
.6156 0 L
.61691 0 L
.61766 0 L
.61834 0 L
.61898 0 L
.61968 0 L
.62096 0 L
Mistroke
.62217 0 L
.62335 0 L
.62444 0 L
.62561 0 L
.6269 0 L
.62755 0 L
.62825 0 L
.62951 0 L
.6306 0 L
.63163 0 L
.6327 0 L
.63388 0 L
.63507 0 L
.63635 0 L
.63754 0 L
.63864 0 L
.63993 0 L
.64066 0 L
.64135 0 L
.64207 0 L
.64272 0 L
.64349 0 L
.6442 0 L
.6455 0 L
.64618 0 L
.64691 0 L
.64813 0 L
.64882 0 L
.64947 0 L
.65074 0 L
.65196 0 L
.65304 0 L
.65423 0 L
.65552 0 L
.65624 0 L
.65689 0 L
.65816 0 L
.65935 0 L
.66052 0 L
.66176 0 L
.66284 0 L
.66401 0 L
.66473 0 L
.66539 0 L
.66669 0 L
.66787 0 L
.66912 0 L
.67034 0 L
.67165 0 L
.67289 0 L
Mistroke
.67403 0 L
.67529 0 L
.676 0 L
.67667 0 L
.67737 0 L
.67801 0 L
.67869 0 L
.67944 0 L
.6806 0 L
.68182 0 L
.68296 0 L
.684 0 L
.68524 0 L
.68591 0 L
.68656 0 L
.6877 0 L
.68895 0 L
.69013 0 L
.6912 0 L
.69244 0 L
.6936 0 L
.69461 0 L
.69568 0 L
.69685 0 L
.69792 0 L
.69915 0 L
.69984 0 L
.70048 0 L
.70165 0 L
.7029 0 L
.70401 0 L
.70505 0 L
.70619 0 L
.70743 0 L
.70874 0 L
.70999 0 L
.7112 0 L
.71233 0 L
.71302 0 L
.71367 0 L
.71488 0 L
.71619 0 L
.71693 0 L
.71761 0 L
.71867 0 L
.71981 0 L
.72088 0 L
.72186 0 L
.72301 0 L
.72426 0 L
Mistroke
.72544 0 L
.72653 0 L
.72765 0 L
.7287 0 L
.72995 0 L
.7311 0 L
.73224 0 L
.73344 0 L
.73464 0 L
.73596 0 L
.73719 0 L
.73849 0 L
.73917 0 L
.73992 0 L
.74124 0 L
.74248 0 L
.74318 0 L
.74381 0 L
.74505 0 L
.74622 0 L
.74735 0 L
.74854 0 L
.74957 0 L
.75069 0 L
.752 0 L
.75324 0 L
.75445 0 L
.75556 0 L
.75686 0 L
.7581 0 L
.75879 0 L
.75953 0 L
.76083 0 L
.76207 0 L
.76338 0 L
.76451 0 L
.76575 0 L
.76702 0 L
.76774 0 L
.76839 0 L
.7696 0 L
.77088 0 L
.77155 0 L
.77227 0 L
.77356 0 L
.77436 0 L
.7751 0 L
.77577 0 L
.7765 0 L
.77774 0 L
Mistroke
.77887 0 L
.78017 0 L
.7814 0 L
.78254 0 L
.7836 0 L
.78474 0 L
.78598 0 L
.78722 0 L
.78838 0 L
.78905 0 L
.78976 0 L
.79103 0 L
.79167 0 L
.79236 0 L
.7936 0 L
.79435 0 L
.79507 0 L
.79571 0 L
.7964 0 L
.79771 0 L
.79893 0 L
.79963 0 L
.80027 0 L
.80101 0 L
.80172 0 L
.80239 0 L
.80311 0 L
.80441 0 L
.8052 0 L
.80595 0 L
.80662 0 L
.80735 0 L
.80799 0 L
.80867 0 L
.80991 0 L
.8112 0 L
.81194 0 L
.81261 0 L
.8138 0 L
.8151 0 L
.81632 0 L
.81746 0 L
.81863 0 L
.81987 0 L
.82093 0 L
.82209 0 L
.82334 0 L
.82403 0 L
.82468 0 L
.82594 0 L
Mistroke
.82708 0 L
.82818 0 L
.82934 0 L
.83033 0 L
.83142 0 L
.83259 0 L
.83385 0 L
.83504 0 L
.83612 0 L
.83739 0 L
.8381 0 L
.83875 0 L
.84001 0 L
.84118 0 L
.84184 0 L
.84254 0 L
.84325 0 L
.84402 0 L
.84469 0 L
.8454 0 L
.84669 0 L
.84799 0 L
.84872 0 L
.84939 0 L
.85063 0 L
.85194 0 L
.85312 0 L
.85422 0 L
.85543 0 L
.85673 0 L
.85799 0 L
.85913 0 L
.86045 0 L
.8617 0 L
.86286 0 L
.86392 0 L
.86509 0 L
.86632 0 L
.86757 0 L
.86827 0 L
.86891 0 L
.87014 0 L
.87132 0 L
.87198 0 L
.87268 0 L
.87395 0 L
.87465 0 L
.87531 0 L
.87603 0 L
.87681 0 L
Mistroke
.87745 0 L
.87813 0 L
.87937 0 L
.88012 0 L
.88083 0 L
.88147 0 L
.88217 0 L
.88291 0 L
.88359 0 L
.88431 0 L
.88511 0 L
.88641 0 L
.88714 0 L
.88782 0 L
.88911 0 L
.8898 0 L
.89052 0 L
.89122 0 L
.89187 0 L
.89309 0 L
.8943 0 L
.89541 0 L
.89663 0 L
.89792 0 L
.89914 0 L
.89983 0 L
.90047 0 L
.90164 0 L
.90288 0 L
.90399 0 L
.90504 0 L
.90618 0 L
.90741 0 L
.90864 0 L
.90934 0 L
.90999 0 L
.91131 0 L
.91205 0 L
.91271 0 L
.91391 0 L
.91522 0 L
.91644 0 L
.91758 0 L
.91863 0 L
.91977 0 L
.92084 0 L
.92182 0 L
.92297 0 L
.92421 0 L
.92539 0 L
Mistroke
.92649 0 L
.92772 0 L
.92888 0 L
.92993 0 L
.93105 0 L
.93229 0 L
.93359 0 L
.9348 0 L
.93591 0 L
.93714 0 L
.93779 0 L
.93848 0 L
.93963 0 L
.9409 0 L
.94202 0 L
.94324 0 L
.94438 0 L
.94543 0 L
.94672 0 L
.94792 0 L
.94924 0 L
.94992 0 L
.95065 0 L
.95135 0 L
.95199 0 L
.95325 0 L
.95439 0 L
.95561 0 L
.95676 0 L
.95781 0 L
.95886 0 L
.95986 0 L
.96102 0 L
.9621 0 L
.96328 0 L
.96453 0 L
.96564 0 L
.96684 0 L
.96798 0 L
.96901 0 L
.97016 0 L
.97142 0 L
.97274 0 L
.97396 0 L
.97513 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0`0000090?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<000001`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<05P3oool001/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`8000008`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`8000005@3oool007d0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;X0oooo001n0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2j0?oo
o`00OP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0^P3oool007l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0;X0oooo001o0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2j0?ooo`00P03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0^P3oool00800oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0;X0oooo00200?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0303oool200000;/0oooo00210?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2j0?ooo`00P@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0^P3oool00840oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;X0oooo00220?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2j0?oo
o`00PP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0^P3oool00880oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0;X0oooo00220?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`2j0?ooo`00PP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0^P3oool00880oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0>0?ooo`800000^`3oool008<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0;X0oooo00230?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2j0?ooo`00P`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0^P3oool008<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0;X0oooo00230?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2j0?oo
o`00P`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0^P3oool008<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0;X0oooo00240?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`2j0?ooo`00Q03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00l0oooo0P00002k0?ooo`00Q03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0^P3oool008@0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0;X0oooo00240?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2j0?ooo`00Q@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0^P3oool008D0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0;X0oooo00250?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2j0?oo
o`00Q@3oool00`000000oooo0?ooo`080?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01000
0000oooo028R8P0R8R840?ooo`D000001P3oool00`000000oooo0?ooo`2j0?ooo`00Q@3oool00`00
0000oooo0?ooo`080?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool010000000oooo028R8P0R
8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01P3oool00`000000oooo0?ooo`2j0?ooo`00Q@3o
ool00`000000oooo0?ooo`080?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool00`000000oooo
0?ooo`060?ooo`0309VIV@0R8R80k^k^00L0oooo00<000000?ooo`3oool0^P3oool008D0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
1`3oool00`2IVIT08R8R0>k^kP060?ooo`<00000^P3oool008D0oooo00<000000?ooo`3oool0203o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`1gMgL0IVIV
0?ooo`050?ooo`030000003oool0oooo0;X0oooo00250?ooo`030000003oool0oooo00P0oooo00D0
4A4A0?ooo`3oool0oooo014A4@020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2j0?ooo`00Q@3oool00`000000oooo0?ooo`080?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL00P3oool00`000000oooo0?ooo`060?ooo`050000002k^k/0oooo09VIV@0A
4A401P3oool00`000000oooo0?ooo`2j0?ooo`00QP3oool00`000000oooo0?ooo`070?ooo`050>k^
kP0c<c<0000003<c<`3^k^h00P3oool00`000000oooo0?ooo`060?ooo`0509VIV@0A4A400000028R
8P3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00QP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0^P3oool008H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0;X0oooo00260?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2j0?ooo`00QP3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0^P3oool0
08H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`800000^`3oool008H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;X0
oooo00260?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`2j0?ooo`00QP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0^P3oool008H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0;X0oooo00260?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`2j0?ooo`00Q`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0^P3oool008L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;X0oooo00270?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2j0?ooo`00Q`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo0P00002k0?ooo`00Q`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0^P3oool008L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;X0
oooo00270?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`2j0?ooo`00R03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0^P3oool008P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0;X0oooo00280?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`2j0?ooo`00R03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0^P3oool008P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0;X0oooo00280?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2j0?ooo`00R03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo0P00002k0?ooo`00R@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0^P3oool008T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0;X0
oooo00290?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`2j0?ooo`00R@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0^P3oool008T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0;X0oooo00290?ooo`030000003oool0oooo00@0oooo00D0k^k^03<c
<`00000000000>k^kP050?ooo`808R8R1P3oool200000003014A4@3oool0oooo00@0oooo00<00000
0?ooo`3oool0^P3oool008T0oooo00<000000?ooo`3oool0103oool01@1gMgL0VIVI0?ooo`000000
MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0^P3oool0
08X0oooo00<000000?ooo`3oool00`3oool01@0A4A40oooo0?ooo`0000004A4A00/0oooo1@000006
0?ooo`030000003oool0oooo0;X0oooo002:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P00000;0?ooo`0404A4A03MgMd0oooo000000L0oooo0`00002j0?ooo`00RP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000002`3oool0103MgMd0EEEE0?ooo`000007
0?ooo`030000003oool0oooo0;X0oooo002:0?ooo`030000003oool0oooo00<0oooo00D04A4A0?oo
o`3oool00000014A4@0<0?ooo`0307MgM`3<c<`0000000L0oooo00<000000?ooo`3oool0^P3oool0
08X0oooo00<000000?ooo`3oool00`3oool01@1gMgL0VIVI0?ooo`000000MgMg00`0oooo00<0k^k^
04A4A00000001`3oool00`000000oooo0?ooo`2j0?ooo`00RP3oool00`000000oooo0?ooo`030?oo
o`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`060?ooo`030000003oool0
oooo0;X0oooo002:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`2j0?ooo`00RP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0^P3oool008X0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0;X0oooo002:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`2j0?ooo`00RP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01H0oooo0P00002k0?ooo`00RP3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0^P3oool008X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo002;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2j0?ooo`00R`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0^P3o
ool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0;X0oooo002;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`2j0?ooo`00R`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0^P3oool008/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo002<0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`2j0?ooo`00S03oool01@000000oooo0?ooo`3o
ool0000001X0oooo0P00002k0?ooo`00S03oool01@000000oooo0?ooo`3oool0000001X0oooo00<0
00000?ooo`3oool0^P3oool008`0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003o
ool0oooo0;X0oooo002=0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0^P3o
ool008d0oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`2j0?ooo`00S@3oool30000
01/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050>k^kP0c<c<00000014A4@3<c<`01P3oool0
0`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R84
0?ooo`0505EEE@1gMgL0oooo09VIV@0R8R801P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool0
1@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000
^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000002IVIT0oooo09VIV@0R
8R801P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0
oooo00D0000005EEE@0000004A4A0<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05
014A4@3oool0oooo0?ooo`0A4A402`3oool00`1EEED0R8R80?ooo`080?ooo`030000003oool0oooo
0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool00`3MgMd04A4A09VIV@080?oo
o`030000003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool0103<
c<`0A4A40000000A4A460?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0
c<c<028R8P0000008R8R0<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P060?ooo`03
0000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D000000?ooo`3o
ool0oooo0000000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01P3oool300000;X0oooo002@0?oo
o`050000003oool0oooo0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00H0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05014A4@2k
^k/0oooo0;^k^`0A4A401P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0^k^k000000060?ooo`030000003oool0oooo0;X0
oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ
00H0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:40oooo100000000`0A4A40oooo0?ooo`030?ooo`03
0000003oool0oooo0;X0oooo002S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
^P3oool00:<0oooo00<000000?ooo`3oool01@3oool300000;X0oooo002S0?ooo`030000003oool0
oooo0<80oooo002S0?ooo`030000003oool0oooo0<80oooo002S0?ooo`030000003oool0oooo0<80
oooo002S0?ooo`030000003oool0oooo0<80oooo002Q0?ooo`80EEEE00<000000?ooo`3oool0`P3o
ool00?l0ooooJ@3oool006T0oooo00<0MgMg06IVIP3oool0103oool00`000000oooo0?ooo`020?oo
o`030;^k^`0c<c<0oooo00L0oooo0P00000;0?ooo`03014A4@2k^k/0oooo00`0oooo0P0000070?oo
o`030000003oool0oooo0080oooo00<0IVIV07MgM`3oool0303oool00`0A4A40^k^k0?ooo`2]0?oo
o`00J03oool00`3MgMd04A4A0>k^kP050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`80<c<c3P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<0k^k^014A4@3MgMd0303oool203<c<jh0oooo001X0?ooo`0305EE
E@2IVIT0oooo00D0oooo00H000000?ooo`3oool0oooo09VIV@0A4A42000000030:ZZZP3oool0oooo
00@0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000`3oool00`28R8P000000:ZZZP04
0?ooo`0509VIV@000000000004A4A02k^k/0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<0R8R806IVIP3oool02`3oool00`28R8P000000:ZZZP0<0?ooo`0509VIV@00
0000000004A4A02k^k/0403oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80
000000<04A4A0?ooo`3oool0M@3oool006P0oooo00<000000?ooo`3oool01@3oool02P000000oooo
0?ooo`3oool000000:ZZZP1EEED0R8R805EEE@2k^k/50?ooo`0:0000003oool0oooo0?ooo`3^k^h0
8R8R08R8R03<c<`000000<c<c0<0oooo00<0c<c<0000000A4A40103oool01@0A4A40^k^k0>k^kP1g
MgL04A4A00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030>k^kP00
0000oooo00/0oooo00<0c<c<0000000A4A40303oool01P0A4A40^k^k0>k^kP1gMgL04A4A0?ooo`H0
00002@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo
07H0oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00X000000?ooo`3oool0oooo03<c<`3^k^h0
VIVI05EEE@3MgMd04A4A1@3oool00`000000oooo0?ooo`020?ooo`040=gMg@00000000000<c<c0/0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`05014A4@3oool0oooo0?oo
o`0A4A402`3oool5000007L0oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00/000000?ooo`3o
ool0oooo0;^k^`14A4@0c<c<028R8P3oool04A4A0<c<c0040?ooo`030000003oool0oooo0080oooo
00@0k^k^028R8P000000k^k^2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0
oooo1P0000090?ooo`050000003oool0oooo0?ooo`0000002`3oool01014A4@0gMgM0?ooo`00001h
0?ooo`00J03oool00`000000k^k^0?ooo`050?ooo`0;0000003oool0oooo0?ooo`3^k^h000000?oo
o`000000k^k^06IVIP28R8P0103oool01P000000oooo0?ooo`3oool0k^k^028R8P80MgMg00<0<c<c
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`3^k^h000000?ooo`0J0?ooo`030000003oool0oooo0180oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040=gMg@1EEED0oooo000007P0oooo001X0?ooo`0305EEE@1g
MgL0oooo00D0oooo00P000000?ooo`3oool0oooo06IVIP2IVIT0oooo03<c<`80^k^k00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo0P0000080?ooo`03014A4@000000
000000<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0MgMg
05EEE@3oool00P3oool400000180oooo00<04A4A0000000000000`00000A0?ooo`05014A4@3oool0
oooo0?ooo`0A4A40303oool00`1gMgL0c<c<0000001h0?ooo`00J03oool00`3MgMd04A4A0>k^kP05
0?ooo`030000003oool0oooo00@0oooo00<0IVIV07MgM`3oool01@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`030>k^kP0A4A40gMgM00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A40000001h0?ooo`00J@3oool0
0`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0ZZZZ04A4A03oool01@3oool2
00000180oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool00P3oool0
0`1VIVH0MgMg0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00d0oooo00<0MgMg0000003oool0M`3oool00;80oooo00<00000
0?ooo`3oool0/`3oool00:l0oooo00@000000?ooo`3oool00000]@3oool00;00oooo0P00002f0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04452 0 L
.04521 0 L
.04637 0 L
.04765 0 L
.04879 0 L
.05001 0 L
.05116 0 L
.05221 0 L
.05343 0 L
.05473 0 L
.05541 0 L
.05615 0 L
.05747 0 L
.0587 0 L
.0594 0 L
.06003 0 L
.06127 0 L
.06244 0 L
.06373 0 L
.0649 0 L
.06616 0 L
.06687 0 L
.06752 0 L
.06862 0 L
.06982 0 L
.07107 0 L
.07225 0 L
.07291 0 L
.07363 0 L
.07495 0 L
.07623 0 L
Mistroke
.07742 0 L
.07814 0 L
.07883 0 L
.08011 0 L
.08078 0 L
.08148 0 L
.08226 0 L
.08297 0 L
.08366 0 L
.08432 0 L
.08555 0 L
.08687 0 L
.08762 0 L
.0883 0 L
.08945 0 L
.09072 0 L
.09204 0 L
.09328 0 L
.09394 0 L
.09466 0 L
.09542 0 L
.09612 0 L
.09738 0 L
.09808 0 L
.09872 0 L
.09947 0 L
.10017 0 L
.10093 0 L
.10174 0 L
.10244 0 L
.10309 0 L
.1038 0 L
.10458 0 L
.10584 0 L
.10653 0 L
.10717 0 L
.10834 0 L
.10958 0 L
.11023 0 L
.11094 0 L
.11219 0 L
.1129 0 L
.11365 0 L
.11437 0 L
.11501 0 L
.1162 0 L
.11745 0 L
.11811 0 L
.11883 0 L
.1201 0 L
Mistroke
.1213 0 L
.12258 0 L
.1238 0 L
.12491 0 L
.12605 0 L
.12727 0 L
.12832 0 L
.12946 0 L
.13015 0 L
.1308 0 L
.13206 0 L
.13321 0 L
.13442 0 L
.13549 0 L
.1365 0 L
.13767 0 L
.13873 0 L
.1399 0 L
.14117 0 L
.14236 0 L
.14346 0 L
.14464 0 L
.14588 0 L
.14694 0 L
.14809 0 L
.14935 0 L
.15005 0 L
.15068 0 L
.15194 0 L
.15309 0 L
.15418 0 L
.15533 0 L
.15648 0 L
.15774 0 L
.15884 0 L
.16001 0 L
.16112 0 L
.16213 0 L
.16341 0 L
.16412 0 L
.16476 0 L
.16602 0 L
.1672 0 L
.16787 0 L
.16858 0 L
.16985 0 L
.17055 0 L
.17121 0 L
.17194 0 L
.17271 0 L
Mistroke
.174 0 L
.17473 0 L
.17541 0 L
.17665 0 L
.17796 0 L
.17914 0 L
.18024 0 L
.18144 0 L
.18274 0 L
.18343 0 L
.18407 0 L
.18528 0 L
.18657 0 L
.18724 0 L
.18798 0 L
.18921 0 L
.19051 0 L
.19172 0 L
.19284 0 L
.19353 0 L
.19427 0 L
.19493 0 L
.19562 0 L
.19694 0 L
.19816 0 L
.19883 0 L
.19956 0 L
.20087 0 L
.20163 0 L
.20243 0 L
.20312 0 L
.20387 0 L
.20452 0 L
.20522 0 L
.2065 0 L
.20775 0 L
.2089 0 L
.21014 0 L
.21085 0 L
.21151 0 L
.2122 0 L
.21294 0 L
.21362 0 L
.21427 0 L
.21544 0 L
.21667 0 L
.21784 0 L
.2189 0 L
.22015 0 L
.22086 0 L
Mistroke
.22151 0 L
.22268 0 L
.22395 0 L
.22522 0 L
.22642 0 L
.22759 0 L
.22866 0 L
.22983 0 L
.23111 0 L
.23176 0 L
.23245 0 L
.23371 0 L
.23482 0 L
.23602 0 L
.23729 0 L
.23846 0 L
.23956 0 L
.24056 0 L
.24172 0 L
.24281 0 L
.244 0 L
.24532 0 L
.24598 0 L
.24669 0 L
.24797 0 L
.24925 0 L
.25046 0 L
.25155 0 L
.25273 0 L
.2534 0 L
.25413 0 L
.25544 0 L
.25615 0 L
.2568 0 L
.25759 0 L
.25831 0 L
.25951 0 L
.26083 0 L
.26212 0 L
.26277 0 L
.26348 0 L
.26413 0 L
.26483 0 L
.2661 0 L
.26736 0 L
.26852 0 L
.26917 0 L
.26986 0 L
.27061 0 L
.27132 0 L
Mistroke
.27204 0 L
.27272 0 L
.27398 0 L
.27519 0 L
.27646 0 L
.27755 0 L
.27875 0 L
.28004 0 L
.28076 0 L
.28142 0 L
.28269 0 L
.2839 0 L
.28498 0 L
.28598 0 L
.28702 0 L
.28816 0 L
.28931 0 L
.29055 0 L
.29169 0 L
.29274 0 L
.29398 0 L
.29532 0 L
.29776 0 L
.30248 1e-05 L
.30374 1e-05 L
.30492 1e-05 L
.30615 1e-05 L
.30681 1e-05 L
.30751 1e-05 L
.30993 2e-05 L
.31214 3e-05 L
.31466 4e-05 L
.31599 5e-05 L
.3174 6e-05 L
.31876 7e-05 L
.31999 8e-05 L
.32123 9e-05 L
.3224 .00011 L
.32464 .00016 L
.32701 .00022 L
.33125 .00036 L
.33362 .00047 L
.33582 .00061 L
.33823 .00081 L
.34082 .0011 L
.34339 .00148 L
.34612 .00198 L
.35102 .00325 L
.35374 .00423 L
.3563 .00539 L
Mistroke
.35909 .00702 L
.36211 .00928 L
.36749 .01457 L
.37262 .02144 L
.37722 .0302 L
.38224 .04231 L
.39255 .07638 L
.4019 .119 L
.41281 .16492 L
.4176 .19617 L
.41891 .20506 L
.41964 .20924 L
.42032 .21255 L
.42096 .21497 L
.42165 .21686 L
.42286 .21834 L
.42398 .21802 L
.42521 .21666 L
.4265 .21542 L
.42772 .21567 L
.42884 .21796 L
.42988 .22211 L
.43101 .22873 L
.43221 .23726 L
.43339 .24587 L
.43465 .25334 L
.43584 .25692 L
.43693 .25615 L
.4382 .24984 L
.43892 .24394 L
.43958 .23734 L
.44079 .22381 L
.44209 .21005 L
.44339 .20097 L
.44457 .1994 L
.44577 .2053 L
.4469 .21695 L
.44813 .2332 L
.44943 .2494 L
.45019 .25577 L
.45087 .25856 L
.45155 .25788 L
.4522 .25377 L
.45466 .21004 L
.45602 .17595 L
.4573 .147 L
.45803 .13481 L
.45882 .1263 L
.45954 .12332 L
.4602 .1246 L
Mistroke
.46151 .13697 L
.46217 .14683 L
.4629 .15912 L
.46409 .17903 L
.46533 .19532 L
.46598 .20059 L
.4667 .2033 L
.46795 .20032 L
.46913 .18965 L
.4704 .17268 L
.47268 .13807 L
.47402 .12003 L
.47546 .10399 L
.47809 .08253 L
.48043 .06758 L
.483 .0533 L
.48542 .04271 L
.48768 .03559 L
.49262 .02369 L
.49481 .01891 L
.49689 .01526 L
.49929 .01214 L
.50148 .00977 L
.50409 .00718 L
.50536 .0061 L
.50653 .00528 L
.50873 .00418 L
.50989 .00376 L
.51111 .00336 L
.51347 .00261 L
.51599 .00188 L
.51745 .00158 L
.51877 .00139 L
.52009 .00124 L
.52135 .00113 L
.52563 .0007 L
.52798 .0005 L
.53017 .00036 L
.53254 .00024 L
.5338 .00019 L
.53451 .00017 L
.53515 .00015 L
.53628 .00014 L
.53751 .00012 L
.53975 .0001 L
.54231 7e-05 L
.543 6e-05 L
.54374 5e-05 L
.54507 4e-05 L
.5463 4e-05 L
Mistroke
.54745 4e-05 L
.54871 4e-05 L
.54942 3e-05 L
.55007 3e-05 L
.55118 2e-05 L
.55237 2e-05 L
.55367 1e-05 L
.55487 1e-05 L
.55599 1e-05 L
.55704 1e-05 L
.55818 1e-05 L
.55942 1e-05 L
.56074 0 L
.56197 0 L
.56267 0 L
.56331 0 L
.56405 0 L
.56475 0 L
.56543 0 L
.56615 0 L
.56744 0 L
.56811 0 L
.56883 0 L
.56962 0 L
.57036 0 L
.57165 0 L
.57233 0 L
.57305 0 L
.57375 0 L
.57438 0 L
.5756 0 L
.57679 0 L
.57807 0 L
.57928 0 L
.58039 0 L
.58166 0 L
.58286 0 L
.58394 0 L
.58511 0 L
.58638 0 L
.58702 0 L
.58773 0 L
.58898 0 L
.59015 0 L
.59127 0 L
.59244 0 L
.59344 0 L
.59454 0 L
.59572 0 L
.59698 0 L
Mistroke
.59817 0 L
.59925 0 L
.60055 0 L
.6012 0 L
.60191 0 L
.60318 0 L
.60436 0 L
.60508 0 L
.60576 0 L
.60703 0 L
.60774 0 L
.6084 0 L
.60913 0 L
.6099 0 L
.61108 0 L
.61235 0 L
.61356 0 L
.61466 0 L
.61589 0 L
.61659 0 L
.61723 0 L
.6179 0 L
.61863 0 L
.61993 0 L
.62112 0 L
.62223 0 L
.62345 0 L
.62477 0 L
.62542 0 L
.62614 0 L
.62744 0 L
.62873 0 L
.62989 0 L
.63108 0 L
.6322 0 L
.63338 0 L
.63466 0 L
.63578 0 L
.63697 0 L
.63798 0 L
.63909 0 L
.63976 0 L
.64048 0 L
.6418 0 L
.64309 0 L
.64428 0 L
.64556 0 L
.64629 0 L
.64698 0 L
.64765 0 L
Mistroke
.64835 0 L
.64913 0 L
.64984 0 L
.65103 0 L
.65216 0 L
.65346 0 L
.65463 0 L
.65594 0 L
.65667 0 L
.65735 0 L
.65858 0 L
.65987 0 L
.66109 0 L
.66241 0 L
.66357 0 L
.66481 0 L
.66604 0 L
.66715 0 L
.66827 0 L
.66932 0 L
.67056 0 L
.67186 0 L
.67297 0 L
.67419 0 L
.67551 0 L
.67625 0 L
.67692 0 L
.67823 0 L
.67946 0 L
.68051 0 L
.68168 0 L
.68289 0 L
.68403 0 L
.68509 0 L
.68606 0 L
.68711 0 L
.68824 0 L
.68945 0 L
.69058 0 L
.69127 0 L
.69192 0 L
.69313 0 L
.69429 0 L
.69536 0 L
.69654 0 L
.69778 0 L
.69899 0 L
.69968 0 L
.70032 0 L
.70149 0 L
Mistroke
.70273 0 L
.70384 0 L
.70488 0 L
.70602 0 L
.70725 0 L
.70848 0 L
.70918 0 L
.70983 0 L
.71114 0 L
.71188 0 L
.71254 0 L
.71374 0 L
.71504 0 L
.71627 0 L
.7174 0 L
.71846 0 L
.71959 0 L
.72066 0 L
.72164 0 L
.72278 0 L
.72403 0 L
.72521 0 L
.7263 0 L
.72754 0 L
.7287 0 L
.72974 0 L
.73087 0 L
.7321 0 L
.7334 0 L
.73461 0 L
.73573 0 L
.73696 0 L
.7376 0 L
.73828 0 L
.73943 0 L
.7407 0 L
.74183 0 L
.74304 0 L
.74418 0 L
.74523 0 L
.74645 0 L
.7476 0 L
.74885 0 L
.74955 0 L
.75018 0 L
.75147 0 L
.7522 0 L
.75287 0 L
.75409 0 L
.7554 0 L
Mistroke
.75654 0 L
.75759 0 L
.75864 0 L
.75964 0 L
.7608 0 L
.76188 0 L
.76306 0 L
.76431 0 L
.76542 0 L
.76662 0 L
.76775 0 L
.76879 0 L
.76994 0 L
.7712 0 L
.77251 0 L
.77374 0 L
.77501 0 L
.77565 0 L
.77636 0 L
.77762 0 L
.77877 0 L
.77947 0 L
.78013 0 L
.78089 0 L
.78159 0 L
.78286 0 L
.78352 0 L
.78424 0 L
.78552 0 L
.78625 0 L
.78692 0 L
.78814 0 L
.78944 0 L
.7906 0 L
.79169 0 L
.79288 0 L
.79416 0 L
.7954 0 L
.79655 0 L
.79781 0 L
.79845 0 L
.79915 0 L
.80026 0 L
.80142 0 L
.8027 0 L
.80388 0 L
.80493 0 L
.80606 0 L
.80729 0 L
.80845 0 L
Mistroke
.8096 0 L
.81069 0 L
.81167 0 L
.81273 0 L
.81397 0 L
.81509 0 L
.81639 0 L
.81763 0 L
.81876 0 L
.81981 0 L
.82096 0 L
.8222 0 L
.82291 0 L
.82356 0 L
.82485 0 L
.82601 0 L
.82724 0 L
.82788 0 L
.82857 0 L
.82981 0 L
.83056 0 L
.83127 0 L
.83197 0 L
.83261 0 L
.83382 0 L
.83447 0 L
.83516 0 L
.83647 0 L
.83713 0 L
.83786 0 L
.83917 0 L
.84038 0 L
.8415 0 L
.8427 0 L
.84344 0 L
.84412 0 L
.84487 0 L
.84566 0 L
.84634 0 L
.84698 0 L
.84773 0 L
.84844 0 L
.84976 0 L
.85096 0 L
.85226 0 L
.85299 0 L
.85366 0 L
.85481 0 L
.85602 0 L
.85708 0 L
Mistroke
.85824 0 L
.8595 0 L
.8602 0 L
.86086 0 L
.86213 0 L
.8633 0 L
.86454 0 L
.86585 0 L
.86698 0 L
.86821 0 L
.8689 0 L
.86954 0 L
.87027 0 L
.87097 0 L
.8722 0 L
.8729 0 L
.87354 0 L
.8747 0 L
.87595 0 L
.87713 0 L
.87822 0 L
.87928 0 L
.88041 0 L
.88148 0 L
.88246 0 L
.88351 0 L
.88466 0 L
.8859 0 L
.88708 0 L
.88831 0 L
.88961 0 L
.89073 0 L
.89196 0 L
.89318 0 L
.89431 0 L
.895 0 L
.89566 0 L
.89688 0 L
.89808 0 L
.89939 0 L
.90006 0 L
.90078 0 L
.90206 0 L
.90316 0 L
.90434 0 L
.90545 0 L
.90647 0 L
.90766 0 L
.90896 0 L
.91019 0 L
Mistroke
.91132 0 L
.91264 0 L
.91338 0 L
.91406 0 L
.91528 0 L
.91598 0 L
.91663 0 L
.91776 0 L
.91896 0 L
.92025 0 L
.92143 0 L
.9221 0 L
.92281 0 L
.92408 0 L
.92479 0 L
.92545 0 L
.92617 0 L
.92696 0 L
.92762 0 L
.92835 0 L
.92904 0 L
.92969 0 L
.93088 0 L
.93218 0 L
.93347 0 L
.93417 0 L
.93482 0 L
.936 0 L
.93726 0 L
.93796 0 L
.93873 0 L
.93946 0 L
.94013 0 L
.9414 0 L
.94204 0 L
.94275 0 L
.94403 0 L
.94521 0 L
.94651 0 L
.94716 0 L
.94788 0 L
.94908 0 L
.95037 0 L
.95159 0 L
.9527 0 L
.95385 0 L
.95493 0 L
.95605 0 L
.95729 0 L
.95854 0 L
Mistroke
.95924 0 L
.95988 0 L
.9611 0 L
.96227 0 L
.96335 0 L
.96451 0 L
.9656 0 L
.96659 0 L
.96776 0 L
.96902 0 L
.97021 0 L
.9713 0 L
.97251 0 L
.97363 0 L
.97487 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo1@0000050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0100000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<0
5P3oool001/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0:03oool3000002d0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`8000005@3o
ool00840oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2j0?ooo`00PP3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0;X0oooo00230?ooo`030000003oool0oooo02@0
oooo0P00002l0?ooo`00P`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool000000;`0oooo
00240?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000_03oool008D0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0000002l0?ooo`00QP3oool00`000000oooo0?ooo`0O0?oo
o`040000003oool0oooo00000;`0oooo00260?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P00002k0?ooo`00QP3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?oo
o`000000_03oool008L0oooo00<000000?ooo`3oool07@3oool01@000000oooo0?ooo`3oool00000
0;`0oooo00270?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0000002l0?oo
o`00Q`3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000000_03oool008L0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;X0
oooo00280?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2j0?ooo`00R03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0^P3oool008P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0;X0oooo00290?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool00`3oool200000;/0oooo00290?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2j0?ooo`00R@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool008X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;X0oooo002:0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00RP3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3oool008X0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;X0
oooo002;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2j0?ooo`00R`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0^P3oool008/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`04
0?ooo`800000^`3oool008/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0;X0oooo002<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2j0?ooo`00S03oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0^P3oool008`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;X0oooo002<0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00S03oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3oool008d0
oooo00P000000?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPD0oooo0P0R8R840?ooo`D000001P3o
ool00`000000oooo0?ooo`2j0?ooo`00S@3oool020000000oooo0?ooo`1gMgL0VIVI0?ooo`2IVIT0
MgMg1@3oool2028R8P@0oooo00D0VIVI028R8P3^k^h0000004A4A0060?ooo`030000003oool0oooo
0;X0oooo002=0?ooo`040000003oool0oooo014A4@<0oooo00<04A4A0?ooo`3oool0203oool01@00
0000oooo09VIV@0R8R80000000L0oooo00<000000?ooo`3oool0^P3oool008d0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo09VIV@000000k^k^
1P3oool300000;X0oooo002>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203o
ool01P000000oooo0?ooo`3oool0000006IVIPH0oooo00<000000?ooo`3oool0^P3oool008h0oooo
00<000000?ooo`0A4A400`3oool00`0A4A40oooo0?ooo`070?ooo`8000000`3oool2000000H0oooo
00<000000?ooo`3oool0^P3oool008h0oooo00L000000?ooo`1gMgL0VIVI0?ooo`2IVIT0MgMg00T0
oooo0`000000102k^k/0oooo0000000A4A460?ooo`030000003oool0oooo0;X0oooo002?0?ooo`06
0000003^k^h0<c<c0000000c<c<0k^k^2@3oool20000000509VIV@0A4A4000000000003<c<`01P3o
ool00`000000oooo0?ooo`2j0?ooo`00S`3oool00`000000oooo0?ooo`0<0?ooo`8000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo002?0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0;X0oooo002?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo002@0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`800000^`3oool00900oooo00<000000?ooo`3oool02`3oool01@000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool0^P3oool00940oooo00<000000?ooo`3oool02P3oool0
1@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0^P3oool00940oooo00<00000
0?ooo`3oool02P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0^P3o
ool00940oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool0^P3oool00940oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool0^P3oool00940oooo00<000000?ooo`3oool02P3oool0
1@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0^P3oool00940oooo00<00000
0?ooo`3oool02P3oool01@000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool0^P3o
ool00940oooo00<000000?ooo`3oool02P3oool01@000000oooo0000003oool0000000P0oooo00<0
00000?ooo`3oool0^P3oool00980oooo00<000000?ooo`3oool02@3oool01@000000oooo0000003o
ool0000000P0oooo0P00002k0?ooo`00TP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00800000203oool00`000000oooo0?ooo`2j0?ooo`00TP3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00800000203oool00`000000oooo0?ooo`2j0?ooo`00TP3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`2j0?oo
o`00TP3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`2j0?ooo`00TP3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2j0?oo
o`00TP3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0;X0oooo002C0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`000000oooo0000000=0?ooo`030000003oool0oooo0;X0oooo002C0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`000000oooo0000000=0?ooo`030000003oool0oooo0;X0
oooo002C0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo0000000=0?ooo`03
0000003oool0oooo0;X0oooo002C0?ooo`<000000`3oool01@000000oooo0000003oool0000000d0
oooo0P00002k0?ooo`00UP3oool020000000oooo0?ooo`000000oooo0000003oool000003@3oool0
0`000000oooo0?ooo`2j0?ooo`00UP3oool020000000oooo0?ooo`000000oooo0000003oool00000
3@3oool00`000000oooo0?ooo`2j0?ooo`00UP3oool020000000oooo0?ooo`000000oooo0000003o
ool000003@3oool00`000000oooo0?ooo`2j0?ooo`00UP3oool020000000oooo0?ooo`000000oooo
0000003oool000003@3oool00`000000oooo0?ooo`2j0?ooo`00UP3oool020000000oooo0?ooo`00
0000oooo0000003oool000003@3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01`3^k^h0<c<c
0000000c<c<0k^k^0?ooo`0000000P3oool01@0000008R8R0000003oool0000000@0oooo0P000000
0`0A4A40oooo0?ooo`040?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0707MgM`2IVIT0oooo
09VIV@1gMgL0oooo000000020?ooo`050000000R8R8000000?ooo`0000001@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A40
0P3oool00`000000oooo000000020?ooo`8000000P3oool5000000H0oooo00<000000?ooo`3oool0
^P3oool00900oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo
0P0000020?ooo`0404A4A03MgMd0oooo000000L0oooo0`00002j0?ooo`00T03oool01@000000oooo
0?ooo`3oool000000080oooo0P0000030?ooo`8000000P3oool0103MgMd0EEEE0?ooo`0000070?oo
o`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A400P3oool20000
00<0oooo0P0000030?ooo`0307MgM`3<c<`0000000L0oooo00<000000?ooo`3oool0^P3oool00900
oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`050000003oool0oooo0?ooo`000000103oool0
0`3^k^h0A4A4000000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<00000
03<c<`3^k^h03@3oool00`1gMgL000000?ooo`060?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002@0?oo
o`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`0000004A4A0<c<
c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3o
ool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3oool0000000H0
oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3o
ool0VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000003oool0oooo0?oo
o`0000002`3oool01@000000EEEE0000000A4A40c<c<00H0oooo00<000000?ooo`3oool0^P3oool0
0900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00P0oooo00<00000
0?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40
VIVI00P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0<
0?ooo`040<c<c014A4@00000014A4@H0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R
103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<000000?ooo`3oool0^P3oool00900oooo
00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R
00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`060?ooo`<00000^P3o
ool00900oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c000000000000000003<c<`0
1P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo
00D04A4A0;^k^`3oool0^k^k014A4@060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000H0oooo00<000000?oo
o`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000
014A4@2ZZZX01P3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00X@3oool400000003014A4@3oool0oooo
00<0oooo00<000000?ooo`3oool0^P3oool00:<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2j0?ooo`00X`3oool00`000000oooo0?ooo`050?ooo`<00000^P3oool00:<0oooo00<0
00000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?oo
o`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:40oooo0P1EEED00`000000oooo
0?ooo`320?ooo`00o`3ooomY0?ooo`00J@3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0
oooo0080oooo00<0^k^k03<c<`3oool01`3oool2000000/0oooo00<04A4A0;^k^`3oool0303oool2
000000L0oooo00<000000?ooo`3oool00P3oool00`1VIVH0MgMg0?ooo`0<0?ooo`03014A4@2k^k/0
oooo0:d0oooo001X0?ooo`030=gMg@0A4A40k^k^00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo0P0c<c<>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`3^k^h04A4A0=gMg@0<0?ooo`80<c<c[P3oool006P0
oooo00<0EEEE09VIV@3oool01@3oool01P000000oooo0?ooo`3oool0VIVI014A4@80000000<0ZZZZ
0?ooo`3oool0103oool010000000oooo0?ooo`3oool200000080oooo0P0000030?ooo`0308R8R000
0000ZZZZ00@0oooo00D0VIVI000000000000A4A40;^k^`040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool00`28R8P0IVIV0?ooo`0;0?ooo`0308R8R0000000ZZZZ00`0oooo
00D0VIVI000000000000A4A40;^k^`0@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R
8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c01g0?ooo`00J03oool00`000000oooo0?ooo`050?oo
o`0:0000003oool0oooo0?ooo`000000ZZZZ05EEE@28R8P0EEEE0;^k^`D0oooo00X000000?ooo`3o
ool0oooo0>k^kP0R8R80R8R80<c<c0000000c<c<0`3oool00`3<c<`00000014A4@040?ooo`05014A
4@2k^k/0k^k^07MgM`0A4A40103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo00<0k^k^0000003oool02`3oool00`3<c<`00000014A4@0<0?ooo`06014A4@2k^k/0k^k^07Mg
M`0A4A40oooo1P0000090?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0
EEEE07MgM`3oool0VIVI028R8P1g0?ooo`00J03oool00`0c<c<0oooo0?ooo`050?ooo`0:0000003o
ool0oooo0?ooo`0c<c<0k^k^09VIV@1EEED0gMgM014A4@D0oooo00<000000?ooo`3oool00P3oool0
103MgMd000000000003<c<`;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3o
ool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo0000001g0?ooo`00
J03oool00`0c<c<0oooo0?ooo`050?ooo`0;0000003oool0oooo0?ooo`2k^k/0A4A40<c<c00R8R80
oooo014A4@3<c<`0103oool00`000000oooo0?ooo`020?ooo`040>k^kP0R8R8000000>k^kP/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`H000002@3oool01@000000oooo
0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P1g0?ooo`00J03oool00`000000
k^k^0?ooo`050?ooo`0;0000003oool0oooo0?ooo`3^k^h000000?ooo`000000k^k^06IVIP28R8P0
103oool01P000000oooo0?ooo`3oool0k^k^028R8P80MgMg00<0<c<c0?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`3^
k^h000000?ooo`0J0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`050000001EEED00000014A4@3<c<`0M`3oool006P0oooo00<0EEEE07MgM`3oool01@3oool0
20000000oooo0?ooo`3oool0IVIV09VIV@3oool0<c<c0P2k^k/00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000000P3oool2000000P0oooo00<04A4A0000000000000`0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`1gMgL0EEEE0?ooo`020?oo
o`@000004P3oool00`0A4A4000000000000300000140oooo00D04A4A0?ooo`3oool0oooo014A4@0;
0?ooo`0305EEE@28R8P0oooo07T0oooo001X0?ooo`030=gMg@0A4A40k^k^00D0oooo00<000000?oo
o`3oool0103oool00`1VIVH0MgMg0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0k^k^014A
4@3MgMd0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI07T0oooo001Y0?ooo`0307MgM`1VIVH0oooo
00@0oooo00<000000?ooo`3oool0103oool00`2ZZZX0A4A40?ooo`050?ooo`8000004P3oool00`00
0000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`0306IVIP1gMgL0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`050>k^kP0c<c<00000
03<c<`3^k^h0303oool0103<c<`0A4A40000000A4A5g0?ooo`00/P3oool00`000000oooo0?ooo`2c
0?ooo`00[`3oool010000000oooo0?ooo`00002e0?ooo`00/03oool200000;H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04583 0 L
.04652 0 L
.04727 0 L
.04797 0 L
.04921 0 L
.04987 0 L
.05056 0 L
.05184 0 L
.05302 0 L
.05414 0 L
.05536 0 L
.05606 0 L
.0567 0 L
.05795 0 L
.05899 0 L
.06014 0 L
.06133 0 L
.06244 0 L
.06311 0 L
.06382 0 L
.06508 0 L
.06573 0 L
.06644 0 L
.06721 0 L
.06793 0 L
.0686 0 L
.06932 0 L
.07064 0 L
.07193 0 L
Mistroke
.07312 0 L
.07439 0 L
.07558 0 L
.07666 0 L
.07782 0 L
.07908 0 L
.07972 0 L
.08042 0 L
.08157 0 L
.08282 0 L
.08358 0 L
.08428 0 L
.08494 0 L
.08566 0 L
.08692 0 L
.08761 0 L
.08826 0 L
.08897 0 L
.08972 0 L
.09036 0 L
.09106 0 L
.09182 0 L
.09262 0 L
.09338 0 L
.09408 0 L
.09474 0 L
.09544 0 L
.09614 0 L
.09691 0 L
.09758 0 L
.09829 0 L
.09958 0 L
.10023 0 L
.10093 0 L
.1022 0 L
.10343 0 L
.10458 0 L
.10575 0 L
.10699 0 L
.10805 0 L
.1092 0 L
.11045 0 L
.11115 0 L
.11179 0 L
.11304 0 L
.11419 0 L
.11527 0 L
.11642 0 L
.11757 0 L
.11883 0 L
Mistroke
.11993 0 L
.1211 0 L
.12221 0 L
.12322 0 L
.12449 0 L
.1252 0 L
.12584 0 L
.12709 0 L
.12827 0 L
.12894 0 L
.12965 0 L
.13092 0 L
.13162 0 L
.13228 0 L
.13301 0 L
.13378 0 L
.13507 0 L
.1358 0 L
.13648 0 L
.13772 0 L
.13903 0 L
.1402 0 L
.1413 0 L
.14251 0 L
.14381 0 L
.14507 0 L
.14621 0 L
.14753 0 L
.14878 0 L
.14993 0 L
.15099 0 L
.15215 0 L
.15339 0 L
.15465 0 L
.15582 0 L
.15653 0 L
.15721 0 L
.15848 0 L
.15913 0 L
.15982 0 L
.16106 0 L
.16182 0 L
.16254 0 L
.16318 0 L
.16387 0 L
.16519 0 L
.16642 0 L
.16713 0 L
.16778 0 L
.16852 0 L
Mistroke
.16922 0 L
.16991 0 L
.17063 0 L
.17193 0 L
.17265 0 L
.17333 0 L
.17407 0 L
.17487 0 L
.17616 0 L
.17689 0 L
.17757 0 L
.17882 0 L
.17946 0 L
.18015 0 L
.18145 0 L
.18268 0 L
.18386 0 L
.18497 0 L
.18621 0 L
.18734 0 L
.18856 0 L
.18925 0 L
.18989 0 L
.19094 0 L
.19211 0 L
.19333 0 L
.19447 0 L
.19575 0 L
.19639 0 L
.19709 0 L
.19833 0 L
.19949 0 L
.2002 0 L
.20086 0 L
.20211 0 L
.20275 0 L
.20344 0 L
.2042 0 L
.2049 0 L
.20559 0 L
.20624 0 L
.20746 0 L
.20875 0 L
.20948 0 L
.21016 0 L
.21137 0 L
.21251 0 L
.21382 0 L
.21501 0 L
.21564 0 L
Mistroke
.21634 0 L
.21707 0 L
.21775 0 L
.21905 0 L
.22027 0 L
.22096 0 L
.22171 0 L
.22302 0 L
.22376 0 L
.22455 0 L
.22522 0 L
.22596 0 L
.2271 0 L
.22832 0 L
.22902 0 L
.22965 0 L
.23089 0 L
.23217 0 L
.2329 0 L
.23356 0 L
.23486 0 L
.23608 0 L
.23711 0 L
.23822 0 L
.23945 0 L
.24058 0 L
.24175 0 L
.24302 0 L
.24423 0 L
.24534 0 L
.24653 0 L
.24782 0 L
.24903 0 L
.25014 0 L
.25138 0 L
.25208 0 L
.25273 0 L
.2534 0 L
.25413 0 L
.25482 0 L
.25545 0 L
.25677 0 L
.25744 0 L
.25817 0 L
.25945 0 L
.26065 0 L
.26621 0 L
.26745 0 L
.26861 0 L
.26926 0 L
Mistroke
.26995 0 L
.27117 0 L
.27188 0 L
.27264 0 L
.27328 0 L
.27398 0 L
.27463 0 L
.27533 0 L
.27659 0 L
.27786 0 L
.27853 0 L
.27924 0 L
.28055 0 L
.28175 0 L
.28286 0 L
.28402 0 L
.28529 0 L
.28646 0 L
.28758 0 L
.28863 0 L
.28978 0 L
.291 0 L
.29527 1e-05 L
.29644 1e-05 L
.29771 1e-05 L
.29888 1e-05 L
.29999 1e-05 L
.30123 1e-05 L
.30237 1e-05 L
.30362 1e-05 L
.30433 1e-05 L
.30499 1e-05 L
.30757 3e-05 L
.30899 3e-05 L
.30968 3e-05 L
.31032 4e-05 L
.31156 4e-05 L
.31221 4e-05 L
.3129 4e-05 L
.31412 4e-05 L
.31523 4e-05 L
.31591 4e-05 L
.31656 4e-05 L
.31724 4e-05 L
.31798 5e-05 L
.31862 5e-05 L
.3193 6e-05 L
.32053 7e-05 L
.32196 .0001 L
.32329 .00012 L
Mistroke
.32634 .00019 L
.32758 .00021 L
.32894 .00023 L
.33022 .00024 L
.33141 .00025 L
.33256 .00026 L
.33365 .00027 L
.33491 .00029 L
.33605 .00031 L
.33731 .00035 L
.33795 .00038 L
.33866 .00042 L
.3399 .0005 L
.34106 .0006 L
.34388 .0009 L
.34649 .00118 L
.34892 .00139 L
.35014 .00147 L
.35149 .00154 L
.35277 .00159 L
.35411 .00164 L
.35481 .00168 L
.35558 .00174 L
.35628 .00181 L
.35693 .0019 L
.35822 .00213 L
.3594 .00244 L
.36075 .0029 L
.36203 .00345 L
.36436 .00465 L
.36683 .00599 L
.36789 .00649 L
.36903 .00692 L
.37028 .00722 L
.37145 .00733 L
.3726 .00729 L
.37368 .00717 L
.37466 .00707 L
.37572 .00705 L
.377 .00729 L
.37815 .00789 L
.37879 .00841 L
.37948 .00914 L
.38073 .01092 L
.38315 .0158 L
.38538 .02091 L
.38655 .02327 L
.38781 .02511 L
.38846 .02572 L
.38918 .02608 L
Mistroke
.39045 .0259 L
.39164 .02491 L
.39292 .02329 L
.39403 .02184 L
.39525 .02071 L
.39598 .02047 L
.39665 .02067 L
.39737 .02139 L
.39813 .02281 L
.39885 .02477 L
.39952 .02719 L
.40078 .03313 L
.40323 .04841 L
.40457 .05728 L
.40582 .06461 L
.40691 .06949 L
.40809 .07248 L
.40939 .0726 L
.41058 .06975 L
.41166 .06509 L
.41284 .0586 L
.41394 .05224 L
.41497 .04714 L
.41628 .04353 L
.41747 .04443 L
.41874 .0509 L
.41946 .0572 L
.42012 .0646 L
.42243 .09971 L
.42369 .1216 L
.42489 .14058 L
.42604 .15472 L
.42728 .16325 L
.42842 .16353 L
.42946 .1572 L
.43044 .14604 L
.43153 .12928 L
.43372 .09065 L
.43497 .07294 L
.43612 .06405 L
.43676 .06307 L
.43745 .06561 L
.43871 .08024 L
.43988 .10492 L
.44114 .14062 L
.44339 .21558 L
.44462 .25267 L
.44592 .28107 L
.4466 .28963 L
.44734 .29311 L
Mistroke
.44865 .28304 L
.44989 .25505 L
.45059 .2327 L
.45122 .20921 L
.45246 .15855 L
.45362 .11315 L
.45472 .07832 L
.4559 .05776 L
.45708 .05909 L
.45838 .08775 L
.4595 .13244 L
.46071 .19462 L
.46289 .31354 L
.46415 .36772 L
.46529 .40023 L
.4666 .41545 L
.46785 .40953 L
.469 .39043 L
.47006 .3653 L
.47246 .30049 L
.47488 .24575 L
.47626 .22337 L
.47754 .20756 L
.4789 .19483 L
.48014 .18535 L
.48293 .1664 L
.48811 .13252 L
.49375 .10245 L
.49633 .08915 L
.49775 .08265 L
.49908 .07753 L
.50033 .07375 L
.50168 .07061 L
.50403 .06622 L
.52361 .02612 L
.52897 .01453 L
.52971 .01307 L
.53052 .0117 L
.53123 .01072 L
.53198 .0099 L
.53266 .00937 L
.5334 .00896 L
.53472 .00856 L
.54508 .00574 L
.5549 .00351 L
.56006 .00247 L
.56131 .00225 L
.56265 .00208 L
.56412 .00194 L
.56548 .0018 L
Mistroke
.56817 .00144 L
.5695 .00127 L
.57072 .00115 L
.57182 .00107 L
.573 .00101 L
.57547 .00087 L
.58461 .00044 L
.58583 .00039 L
.58715 .00034 L
.5884 .0003 L
.58956 .00028 L
.59407 .00022 L
.5952 .00019 L
.59639 .00016 L
.5977 .00015 L
.59889 .00014 L
.6002 .00013 L
.60095 .00013 L
.60164 .00013 L
.60289 .00011 L
.60422 9e-05 L
.60537 8e-05 L
.60661 7e-05 L
.60779 7e-05 L
.60887 7e-05 L
.60985 7e-05 L
.61093 6e-05 L
.61205 5e-05 L
.6131 4e-05 L
.61432 4e-05 L
.61548 3e-05 L
.61652 3e-05 L
.61765 3e-05 L
.61888 3e-05 L
.62019 3e-05 L
.62141 2e-05 L
.62255 2e-05 L
.62379 1e-05 L
.62445 1e-05 L
.62515 1e-05 L
.62589 2e-05 L
.6266 2e-05 L
.62791 1e-05 L
.62914 1e-05 L
.6303 1e-05 L
.63151 1e-05 L
.63215 1e-05 L
.63284 1e-05 L
.63354 1e-05 L
.63429 1e-05 L
Mistroke
.63492 1e-05 L
.63561 1e-05 L
.63625 1e-05 L
.63694 0 L
.63817 0 L
.63892 0 L
.63973 0 L
.6405 0 L
.64121 0 L
.6419 0 L
.64255 0 L
.64323 0 L
.64397 0 L
.64513 0 L
.64636 0 L
.64707 0 L
.64771 0 L
.64896 0 L
.65013 0 L
.6514 0 L
.6526 0 L
.6537 0 L
.65497 0 L
.65568 0 L
.65635 0 L
.65706 0 L
.65771 0 L
.65845 0 L
.65916 0 L
.6604 0 L
.66155 0 L
.66281 0 L
.66344 0 L
.66414 0 L
.66534 0 L
.66663 0 L
.66736 0 L
.66803 0 L
.66933 0 L
.67056 0 L
.67188 0 L
.67302 0 L
.67427 0 L
.67548 0 L
.67662 0 L
.67781 0 L
.6791 0 L
.68029 0 L
.68142 0 L
.68244 0 L
Mistroke
.68354 0 L
.68483 0 L
.68604 0 L
.68673 0 L
.68736 0 L
.68811 0 L
.6888 0 L
.69009 0 L
.69078 0 L
.69152 0 L
.69229 0 L
.69302 0 L
.69367 0 L
.69438 0 L
.69559 0 L
.69628 0 L
.69692 0 L
.69758 0 L
.6983 0 L
.6996 0 L
.70078 0 L
.70207 0 L
.70329 0 L
.70441 0 L
.7057 0 L
.70635 0 L
.70707 0 L
.70833 0 L
.7095 0 L
.71022 0 L
.71089 0 L
.71216 0 L
.71286 0 L
.71352 0 L
.71424 0 L
.715 0 L
.71618 0 L
.71745 0 L
.71864 0 L
.71974 0 L
.72096 0 L
.72164 0 L
.72229 0 L
.72357 0 L
.7243 0 L
.72496 0 L
.72614 0 L
.72739 0 L
.72848 0 L
.72968 0 L
Mistroke
.73083 0 L
.73192 0 L
.7329 0 L
.73397 0 L
.73513 0 L
.73636 0 L
.737 0 L
.7377 0 L
.73894 0 L
.74009 0 L
.74133 0 L
.7425 0 L
.74358 0 L
.74485 0 L
.74605 0 L
.74715 0 L
.7483 0 L
.74956 0 L
.75073 0 L
.75198 0 L
.75269 0 L
.75336 0 L
.75453 0 L
.75565 0 L
.75665 0 L
.75775 0 L
.75893 0 L
.76019 0 L
.76139 0 L
.76247 0 L
.76376 0 L
.76442 0 L
.76513 0 L
.76642 0 L
.76758 0 L
.76829 0 L
.76897 0 L
.76968 0 L
.77045 0 L
.77112 0 L
.77184 0 L
.77312 0 L
.7743 0 L
.77558 0 L
.77678 0 L
.77789 0 L
.77911 0 L
.77981 0 L
.78045 0 L
.78176 0 L
Mistroke
.78248 0 L
.78315 0 L
.78439 0 L
.78504 0 L
.78574 0 L
.78648 0 L
.78718 0 L
.78848 0 L
.7897 0 L
.79084 0 L
.79208 0 L
.7934 0 L
.7941 0 L
.79484 0 L
.79565 0 L
.7964 0 L
.79711 0 L
.79786 0 L
.79858 0 L
.79923 0 L
.80052 0 L
.80174 0 L
.80307 0 L
.80381 0 L
.8045 0 L
.80566 0 L
.8069 0 L
.80808 0 L
.80915 0 L
.81035 0 L
.81165 0 L
.81231 0 L
.81302 0 L
.81428 0 L
.81498 0 L
.81563 0 L
.81633 0 L
.81708 0 L
.81834 0 L
.81905 0 L
.81972 0 L
.82096 0 L
.8221 0 L
.82341 0 L
.82465 0 L
.82579 0 L
.82702 0 L
.82817 0 L
.82923 0 L
.83041 0 L
Mistroke
.8317 0 L
.83235 0 L
.83304 0 L
.83429 0 L
.83498 0 L
.83562 0 L
.83632 0 L
.83705 0 L
.8383 0 L
.839 0 L
.83966 0 L
.84087 0 L
.84201 0 L
.84333 0 L
.84454 0 L
.8457 0 L
.84675 0 L
.84797 0 L
.84911 0 L
.85017 0 L
.85115 0 L
.85222 0 L
.85335 0 L
.85449 0 L
.85572 0 L
.85678 0 L
.85793 0 L
.85863 0 L
.85928 0 L
.86056 0 L
.86172 0 L
.86296 0 L
.86409 0 L
.86534 0 L
.86664 0 L
.86785 0 L
.86899 0 L
.87002 0 L
.87121 0 L
.87234 0 L
.87356 0 L
.87486 0 L
.87597 0 L
.87719 0 L
.8785 0 L
.87923 0 L
.8799 0 L
.88121 0 L
.88244 0 L
.8836 0 L
Mistroke
.88482 0 L
.88546 0 L
.88616 0 L
.88739 0 L
.88855 0 L
.8898 0 L
.89097 0 L
.89204 0 L
.89315 0 L
.89418 0 L
.89531 0 L
.89651 0 L
.89754 0 L
.89852 0 L
.89958 0 L
.90073 0 L
.90196 0 L
.90266 0 L
.9033 0 L
.90449 0 L
.90575 0 L
.90699 0 L
.90816 0 L
.90922 0 L
.91035 0 L
.91159 0 L
.91229 0 L
.91294 0 L
.91427 0 L
.91501 0 L
.91568 0 L
.91689 0 L
.9182 0 L
.91944 0 L
.92059 0 L
.92164 0 L
.92278 0 L
.92376 0 L
.92483 0 L
.92602 0 L
.92727 0 L
.92843 0 L
.92951 0 L
.93075 0 L
.93191 0 L
.93312 0 L
.93376 0 L
.93445 0 L
.93567 0 L
.93682 0 L
Mistroke
.93786 0 L
.939 0 L
.9402 0 L
.94149 0 L
.94271 0 L
.9438 0 L
.9451 0 L
.94582 0 L
.94649 0 L
.94772 0 L
.94902 0 L
.95015 0 L
.95135 0 L
.95249 0 L
.95353 0 L
.95475 0 L
.95544 0 L
.95608 0 L
.95724 0 L
.95848 0 L
.95957 0 L
.96057 0 L
.96167 0 L
.96283 0 L
.96384 0 L
.96478 0 L
.96581 0 L
.9669 0 L
.96811 0 L
.96941 0 L
.97064 0 L
.97177 0 L
.9728 0 L
.97392 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001000
00030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`H000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<0
5P3oool001/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00@0oooo1@00000T0?ooo`030000003oool0oooo00T0oooo1000000P0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0?0?ooo`8000000P3o
ool2000001D0oooo00260?ooo`8000008`3oool00`000000oooo0?ooo`060?ooo`<00000/@3oool0
08L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0;40oooo00280?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2a0?ooo`00R03oool00`000000oooo0?ooo`02000001h0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2a0?ooo`00R@3oool010000000oooo00000000000N0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool008T0oooo0P0000000`3oool000000000
000M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/`3oool008d0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;<0oooo002=0?oo
o`030000003oool0oooo01/0oooo0P0000040?ooo`030000003oool0oooo0;@0oooo002=0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2d0?ooo`00
S@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
]@3oool008h0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0]@3oool008h0oooo00<000000?ooo`3oool00P00000H0?ooo`050000003o
ool0oooo0?ooo`000000^03oool008h0oooo00<000000?ooo`3oool00P00000H0?ooo`050000003o
ool0oooo0?ooo`000000^03oool008h0oooo00<000000?ooo`3oool00P00000H0?ooo`040000003o
ool0oooo00000;T0oooo002>0?ooo`060000003oool0oooo0000003oool000005`3oool010000000
oooo0?ooo`00002i0?ooo`00SP3oool01P000000oooo0?ooo`000000oooo000000X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0000002j0?ooo`00SP3oool01P000000oooo0?ooo`000000
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`<00000^P3o
ool008h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool200000;/0oooo002?0?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool20000
0;/0oooo002?0?ooo`8000000P3oool010000000oooo0?ooo`3oool2000000@0oooo0P00000<0?oo
o`800000^`3oool009<0oooo00@000000?ooo`3oool0oooo0P0000040?ooo`800000303oool00`00
0000oooo0?ooo`2j0?ooo`00T`3oool010000000oooo0?ooo`3oool2000000@0oooo0P00000<0?oo
o`030000003oool0oooo0;X0oooo002C0?ooo`040000003oool0oooo0?ooo`800000103oool20000
00/0oooo0P00002l0?ooo`00U03oool00`000000oooo0?ooo`02000000@0oooo0P00000;0?ooo`80
0000_03oool009@0oooo00<000000?ooo`3oool00P0000040?ooo`8000002`3oool200000;`0oooo
002D0?ooo`030000003oool0oooo00800000103oool2000000/0oooo0`00002k0?ooo`00U03oool0
1P000000oooo0?ooo`000000oooo000000<0oooo0P00000;0?ooo`800000_03oool009@0oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`8000002P3oool00`000000oooo0000002l0?ooo`00
U03oool01P000000oooo0?ooo`000000oooo000000<0oooo0P00000:0?ooo`030000003oool00000
0;`0oooo002D0?ooo`060000003oool0oooo0000003oool000000`3oool2000000X0oooo00<00000
0?ooo`000000_03oool009@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`8000002P3o
ool00`000000oooo0000002l0?ooo`00U03oool00`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000080?ooo`040000003oool0oooo00000;`0oooo002@0?ooo`070>k^
kP0c<c<0000003<c<`000000oooo000000020?ooo`060000000R8R808R8R0?ooo`000000oooo1P00
00030?ooo`040000003oool0oooo00000;`0oooo002@0?ooo`0707MgM`2IVIT0oooo09VIV@000000
oooo000000020?ooo`0<0000000R8R808R8R0?ooo`000000oooo0000002IVIT08R8R0>k^kP3oool0
A4A40`3oool010000000oooo0?ooo`00002l0?ooo`00T03oool01`0A4A40oooo0?ooo`3oool00000
0?ooo`0000000P3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo09VIV@0R8R80k^k^
00@0oooo00@000000?ooo`3oool00000_03oool00900oooo00L000000?ooo`3oool0oooo0000003o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00<0VIVI028R8P3^
k^h00`3oool00`000000oooo0?ooo`0300000;X0oooo002@0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`0507MgM`1V
IVH0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01`0A4A40oooo0?oo
o`3oool000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0707MgM`2IVIT0
oooo09VIV@000000oooo000000020?ooo`060000003oool0oooo0?ooo`000000oooo0P000000102k
^k/0oooo09VIV@0A4A420?ooo`050000003oool0oooo0?ooo`000000_03oool00900oooo00L0k^k^
03<c<`000000<c<c0000003oool000000080oooo00`000000?ooo`3oool0oooo0000003oool00000
09VIV@0A4A400000028R8P3<c<`20?ooo`050000003oool0oooo0?ooo`000000_03oool009@0oooo
00<000000?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3oool01@00
0000oooo0?ooo`3oool000000;`0oooo002D0?ooo`030000003oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000L0oooo00D000000?ooo`3oool0oooo0000002l0?ooo`00U03o
ool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`05
0000003oool0oooo0?ooo`000000_03oool009D0oooo0P0000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^P3oool0
09D0oooo0P0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003o
ool0oooo0080oooo0P00002k0?ooo`00U@3oool200000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`00U@3o
ool200000080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`2j0?ooo`00U@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;X0
oooo002I0?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0^P3oool009T0oooo00L000000?ooo`3oool0oooo0000003oool0
000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`00V@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0;X0oooo002I0?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool009X0oooo00H000000?ooo`3oool00000
0?ooo`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool009X0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
0P00002k0?ooo`00VP3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2j
0?ooo`00VP3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00
VP3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo000000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00VP3oool0
0`000000oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00VP3oool00`000000
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool200000;/0oooo002J0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;X0oooo002J
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0;X0oooo002J0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;X0oooo002J0?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0;X0oooo002J0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h01@3oool00`0000008R8R000000020?ooo`030000003oool0oooo00800000
00<04A4A0?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00D0oooo00<00000028R8P0000000P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@050?ooo`03
0000003oool000000080oooo1P0000060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo000000020?ooo`0500000014A4@0gMgM0?oo
o`0000001`3oool300000;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo000000020?ooo`050000003MgMd0EEEE0?ooo`0000001`3oool00`000000oooo0?ooo`2j
0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool04A4A00D0oooo00<000000?ooo`0000000P3oool0
1@000000oooo07MgM`3<c<`0000000L0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg
09VIV@3oool0VIVI07MgM`050?ooo`030000003oool0000000<0oooo00@000000>k^kP14A4@00000
1`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo
00<000000?ooo`0000000`3oool010000000oooo07MgM`0000070?ooo`030000003oool0oooo0;X0
oooo002J0?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`2j0?ooo`00VP3oool00`000000oooo000000030?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0^P3oool009/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0;X0oooo002K0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`2j0?ooo`00V`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000L0oooo0P00002k0?ooo`00V`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0^P3oool009/0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0;X0
oooo002K0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`2j0?ooo`00V`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0^P3oool009/0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0;X0oooo002P0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0^P3oool00:00oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`2j0?ooo`00X03oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0;X0
oooo002P0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0^P3oool00:00oooo
00@000000?ooo`3oool000001`3oool200000;/0oooo002P0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0^P3oool00:00oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`2j0?ooo`00X03oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0;X0
oooo002P0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0^P3oool00:00oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`2j0?ooo`00X03oool010000000oooo
0?ooo`0000070?ooo`030000003oool0oooo0;X0oooo002P0?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool0^P3oool00:00oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`2j0?ooo`00X03oool00`000000oooo000000080?ooo`800000^`3oool00:00oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`2j0?ooo`00X03oool00`000000oooo000000080?oo
o`030000003oool0oooo0;X0oooo002P0?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool0^P3oool00:00oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2j0?ooo`00X03o
ool00`000000oooo000000080?ooo`030000003oool0oooo0;X0oooo002P0?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R103oool01@000000<c<c0000000A4A40c<c<00H0oooo00<000000?ooo`3oool0^P3o
ool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@000000MgMg0000
002IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo
014A4@0;0?ooo`050000003oool000000?ooo`0000001P3oool300000;X0oooo002@0?ooo`050000
003oool0oooo0?ooo`0000002`3oool01@000000VIVI0000002IVIT08R8R00H0oooo00<000000?oo
o`3oool0^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000001EEED00000
014A4@3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool0
4A4A00/0oooo00<0000008R8R0000000203oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<00000014A4@000000203oool00`000000oooo0?ooo`2j
0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D000000<c<c00000000000014A
4@060?ooo`030000003oool0oooo0;X0oooo002P0?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool0^P3oool00:00oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2j0?oo
o`00X03oool00`000000oooo000000080?ooo`030000003oool0oooo0;X0oooo002P0?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool0^P3oool00:00oooo0P0000090?ooo`800000^`3o
ool00:00oooo0P0000090?ooo`030000003oool0oooo0;X0oooo002Q0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0^P3oool00:40oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`2j0?ooo`00X@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000
^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000
000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<c00R8R800000028R8P3<c<`01P3oool00`000000
oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05
028R8P2IVIT0oooo09VIV@0R8R801P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40
oooo0?ooo`3oool04A4A00/0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo0;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2I
VIT0<c<c00H0oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
c<c<00000000000000000<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3o
ool0oooo0?ooo`0A4A402`3oool01@0A4A40^k^k0?ooo`2k^k/04A4A00H0oooo00<000000?ooo`3o
ool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`050000002k^k/0oooo0;^k
^`0000001P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^
00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP060?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002Q0?oo
o`@0000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00X`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo002S0?ooo`030000003oool0oooo00D0oooo
0`00002j0?ooo`00X`3oool00`000000oooo0?ooo`320?ooo`00X`3oool00`000000oooo0?ooo`32
0?ooo`00X`3oool00`000000oooo0?ooo`320?ooo`00X`3oool00`000000oooo0?ooo`320?ooo`00
X@3oool205EEE@030000003oool0oooo0<80oooo003o0?ooofT0oooo001Y0?ooo`0307MgM`1VIVH0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`2k^k/0<c<c0?ooo`070?ooo`8000002`3oool0
0`0A4A40^k^k0?ooo`0<0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`0306IVIP1gMgL0
oooo00`0oooo00<04A4A0;^k^`3oool0[@3oool006P0oooo00<0gMgM014A4@3^k^h01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool203<c
<`h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030>k^kP0A4A40gMgM
00`0oooo0P0c<c>^0?ooo`00J03oool00`1EEED0VIVI0?ooo`050?ooo`060000003oool0oooo0?oo
o`2IVIT04A4A0P0000000`2ZZZX0oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000P3o
ool2000000<0oooo00<0R8R80000002ZZZX0103oool01@2IVIT0000000000014A4@0^k^k00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`0308R8R01VIVH0oooo00/0oooo
00<0R8R80000002ZZZX0303oool01@2IVIT0000000000014A4@0^k^k0100oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<07L0oooo001X0?oo
o`030000003oool0oooo00D0oooo00X000000?ooo`3oool0oooo0000002ZZZX0EEEE08R8R01EEED0
^k^k1@3oool02P000000oooo0?ooo`3oool0k^k^028R8P28R8P0c<c<0000003<c<`30?ooo`030<c<
c00000004A4A00@0oooo00D04A4A0;^k^`3^k^h0MgMg014A4@040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`3^k^h000000?ooo`0;0?ooo`030<c<c00000004A4A00`0
oooo00H04A4A0;^k^`3^k^h0MgMg014A4@3oool6000000T0oooo00D0MgMg09VIV@3oool0VIVI07Mg
M`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R07L0oooo001X0?ooo`0303<c<`3o
ool0oooo00D0oooo00X000000?ooo`3oool0oooo03<c<`3^k^h0VIVI05EEE@3MgMd04A4A1@3oool0
0`000000oooo0?ooo`020?ooo`040=gMg@00000000000<c<c0/0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0B0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo
0?ooo`3oool0000007L0oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00/000000?ooo`3oool0
oooo0;^k^`14A4@0c<c<028R8P3oool04A4A0<c<c0040?ooo`030000003oool0oooo0080oooo00@0
k^k^028R8P000000k^k^2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo
1P0000090?ooo`050000003oool0oooo0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c
07L0oooo001X0?ooo`030000003^k^h0oooo00D0oooo00/000000?ooo`3oool0oooo0>k^kP000000
oooo0000003^k^h0IVIV08R8R0040?ooo`060000003oool0oooo0?ooo`3^k^h08R8R0P1gMgL00`0c
<c<0oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030>k^kP000000oooo01X0oooo00<000000?ooo`3oool04P3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c01g0?ooo`00J03oool0
0`1EEED0MgMg0?ooo`050?ooo`080000003oool0oooo0?ooo`1VIVH0VIVI0?ooo`0c<c<20;^k^`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`800000203oool00`0A
4A40000000000003000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`0307MgM`1EEED0oooo0080oooo1000000B0?ooo`03014A4@000000000000<000004@3oool01@0A
4A40oooo0?ooo`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@1g0?ooo`00J03oool0
0`3MgMd04A4A0>k^kP050?ooo`030000003oool0oooo00@0oooo00<0IVIV07MgM`3oool01@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030>k^kP0A4A40gMgM00@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0B0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?oo
o`2k^k/0000007L0oooo001Y0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?ooo`3oool0103o
ool00`2ZZZX0A4A40?ooo`050?ooo`8000004P3oool00`000000oooo0?ooo`050?ooo`8000001`3o
ool00`000000oooo0?ooo`020?ooo`0306IVIP1gMgL0oooo00D0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0B0?ooo`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A
0000000A4A40ZZZZ07L0oooo002b0?ooo`030000003oool0oooo0;<0oooo002_0?ooo`040000003o
ool0oooo00000;D0oooo002`0?ooo`800000]P3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -55.625 0 ]
[.5 .63053 55.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -116.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
170.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 0 L
.02952 0 L
.03068 0 L
.03178 0 L
.03279 0 L
.03399 0 L
.03527 0 L
.03635 0 L
.03754 0 L
.0388 0 L
.03951 0 L
.04016 0 L
.04142 0 L
.04262 0 L
.04387 0 L
.045 0 L
.0463 0 L
.04753 0 L
.0486 0 L
.04973 0 L
.05096 0 L
.0521 0 L
.05333 0 L
.05465 0 L
.05589 0 L
.05703 0 L
.05772 0 L
.05836 0 L
.05906 0 L
.05981 0 L
.06106 0 L
.06178 0 L
.06244 0 L
.06374 0 L
.06444 0 L
.06511 0 L
.06642 0 L
.0676 0 L
.06884 0 L
.06954 0 L
.07019 0 L
.07084 0 L
.07157 0 L
.07231 0 L
.07302 0 L
.07428 0 L
.07544 0 L
.07668 0 L
.07738 0 L
Mistroke
.07803 0 L
.07923 0 L
.0803 0 L
.08155 0 L
.08272 0 L
.08399 0 L
.08471 0 L
.08539 0 L
.0861 0 L
.08674 0 L
.08749 0 L
.0882 0 L
.08945 0 L
.09061 0 L
.09188 0 L
.09252 0 L
.09323 0 L
.09395 0 L
.0947 0 L
.09535 0 L
.09605 0 L
.0968 0 L
.0975 0 L
.09833 0 L
.09909 0 L
.09975 0 L
.10044 0 L
.10121 0 L
.10191 0 L
.10318 0 L
.10386 0 L
.10458 0 L
.10588 0 L
.10708 0 L
.10838 0 L
.10912 0 L
.10981 0 L
.11107 0 L
.11176 0 L
.1124 0 L
.11353 0 L
.11477 0 L
.11588 0 L
.11693 0 L
.11814 0 L
.11924 0 L
.12044 0 L
.12155 0 L
.12277 0 L
.12407 0 L
Mistroke
.12536 0 L
.12654 0 L
.12782 0 L
.12854 0 L
.1292 0 L
.1304 0 L
.13167 0 L
.1329 0 L
.13402 0 L
.13534 0 L
.136 0 L
.13673 0 L
.13752 0 L
.13825 0 L
.13898 0 L
.13966 0 L
.1403 0 L
.141 0 L
.14222 0 L
.14292 0 L
.14366 0 L
.14497 0 L
.14609 0 L
.14731 0 L
.14861 0 L
.14983 0 L
.15098 0 L
.15203 0 L
.15324 0 L
.15438 0 L
.15564 0 L
.15628 0 L
.15697 0 L
.15821 0 L
.15936 0 L
.16006 0 L
.16072 0 L
.16197 0 L
.16272 0 L
.16343 0 L
.16407 0 L
.16476 0 L
.16608 0 L
.16729 0 L
.1686 0 L
.16926 0 L
.16998 0 L
.17119 0 L
.17248 0 L
.17371 0 L
Mistroke
.17482 0 L
.1755 0 L
.17622 0 L
.17752 0 L
.17825 0 L
.17903 0 L
.17977 0 L
.18045 0 L
.18175 0 L
.18298 0 L
.18367 0 L
.18432 0 L
.18502 0 L
.18577 0 L
.18701 0 L
.18772 0 L
.18838 0 L
.18907 0 L
.1897 0 L
.19044 0 L
.19113 0 L
.19234 0 L
.19366 0 L
.19481 0 L
.19605 0 L
.19737 0 L
.19862 0 L
.19933 0 L
.20009 0 L
.20074 0 L
.20145 0 L
.20218 0 L
.20288 0 L
.20368 0 L
.20441 0 L
.2051 0 L
.20574 0 L
.20649 0 L
.20718 0 L
.20834 0 L
.20958 0 L
.21075 0 L
.21184 0 L
.2131 0 L
.21376 0 L
.21447 0 L
.21578 0 L
.21697 0 L
.21822 0 L
.21954 0 L
Mistroke
.22023 0 L
.22099 0 L
.22167 0 L
.22231 0 L
.22359 0 L
.22474 0 L
.22538 0 L
.22608 0 L
.22734 0 L
.22857 0 L
.22968 0 L
.23091 0 L
.2322 0 L
.23333 0 L
.23438 0 L
.23553 0 L
.23676 0 L
.23746 0 L
.23811 0 L
.23882 0 L
.23956 0 L
.24082 0 L
.24154 0 L
.24221 0 L
.24343 0 L
.24459 0 L
.24523 0 L
.24593 0 L
.24715 0 L
.24844 0 L
.24966 0 L
.25036 0 L
.25099 0 L
.25174 0 L
.25244 0 L
.25374 0 L
.25443 0 L
.25517 0 L
.25595 0 L
.25668 0 L
.25734 0 L
.25806 0 L
.25927 0 L
.25997 0 L
.26061 0 L
.26128 0 L
.26201 0 L
.26331 0 L
.2645 0 L
.2658 0 L
Mistroke
.26703 0 L
.26817 1e-05 L
.26945 1e-05 L
.2701 1e-05 L
.27081 1e-05 L
.27207 1e-05 L
.27324 1e-05 L
.27396 1e-05 L
.27463 1e-05 L
.2759 0 L
.2766 1e-05 L
.27726 1e-05 L
.27797 1e-05 L
.27874 0 L
.27991 0 L
.28118 0 L
.28237 0 L
.28347 0 L
.28469 0 L
.28537 1e-05 L
.28602 1e-05 L
.28869 2e-05 L
.29332 4e-05 L
.29443 5e-05 L
.2956 5e-05 L
.29659 6e-05 L
.29769 5e-05 L
.29894 5e-05 L
.30011 4e-05 L
.30148 3e-05 L
.30273 2e-05 L
.30378 1e-05 L
.30493 1e-05 L
.30615 0 L
.3073 0 L
.30795 0 L
.30864 0 L
.30987 2e-05 L
.31119 4e-05 L
.31194 7e-05 L
.31264 9e-05 L
.31526 .0002 L
.31765 .00029 L
.31877 .00032 L
.31998 .00036 L
.32112 .00038 L
.32218 .00039 L
.32329 .00038 L
.32453 .00036 L
.32581 .0003 L
Mistroke
.32702 .00022 L
.32831 .00013 L
.329 9e-05 L
.32972 5e-05 L
.33042 2e-05 L
.33106 1e-05 L
.3323 1e-05 L
.33349 7e-05 L
.33478 .00019 L
.336 .00035 L
.33713 .00055 L
.33982 .0012 L
.34238 .00187 L
.34306 .00201 L
.34379 .00213 L
.34458 .00222 L
.34532 .00226 L
.3466 .00222 L
.34733 .00214 L
.34801 .00203 L
.35269 .0007 L
.35397 .00034 L
.35461 .00019 L
.35532 7e-05 L
.35657 1e-05 L
.35773 .00018 L
.35891 .00063 L
.36003 .00132 L
.36103 .00217 L
.36212 .00329 L
.36455 .00617 L
.36681 .0087 L
.36801 .00969 L
.3693 .01036 L
.37003 .01051 L
.37073 .01048 L
.37203 .00995 L
.3727 .00943 L
.3734 .00872 L
.37468 .00705 L
.37606 .0049 L
.37756 .00257 L
.37824 .00166 L
.37895 .00087 L
.38024 9e-05 L
.38144 .00028 L
.38276 .00168 L
.38394 .00403 L
.3852 .00764 L
.38747 .01648 L
Mistroke
.39004 .0279 L
.39145 .03338 L
.39276 .0371 L
.39388 .03871 L
.39509 .03854 L
.39574 .03757 L
.39643 .03589 L
.39766 .03138 L
.40022 .01787 L
.40162 .01013 L
.40231 .0068 L
.40295 .0042 L
.4037 .00184 L
.40452 .0004 L
.40521 .00022 L
.40595 .00118 L
.40663 .00322 L
.40727 .00617 L
.40798 .01056 L
.40873 .01659 L
.41132 .0457 L
.41413 .08314 L
.41542 .0975 L
.41614 .10378 L
.41679 .10809 L
.41806 .11217 L
.41925 .11031 L
.42043 .10307 L
.42166 .0902 L
.42387 .05794 L
.4251 .03832 L
.42644 .01917 L
.4277 .006 L
.42886 .00037 L
.43001 .0026 L
.43128 .01513 L
.43192 .02549 L
.4326 .03949 L
.43384 .07134 L
.43601 .13932 L
.43716 .17571 L
.43838 .21005 L
.43912 .2271 L
.43979 .23939 L
.4411 .25317 L
.44174 .25456 L
.44244 .252 L
.44369 .23684 L
.44493 .21008 L
.44623 .17177 L
Mistroke
.44856 .09104 L
.44968 .05437 L
.45074 .02582 L
.45197 .00483 L
.45308 .0004 L
.45413 .01119 L
.45511 .03473 L
.45617 .0748 L
.45731 .13099 L
.4595 .26041 L
.46066 .32612 L
.46187 .38375 L
.46252 .40745 L
.46323 .42683 L
.46447 .44325 L
.46573 .43782 L
.46691 .41602 L
.47196 .25432 L
.47334 .21727 L
.47481 .18693 L
.47606 .16789 L
.47676 .15954 L
.47743 .15299 L
.47872 .14335 L
.47991 .13706 L
.48118 .13191 L
.48256 .12723 L
.48508 .11956 L
.48627 .11633 L
.48736 .11383 L
.48852 .11191 L
.48977 .11084 L
.49087 .11076 L
.49204 .11138 L
.49326 .11245 L
.49441 .11338 L
.49566 .1138 L
.49637 .11357 L
.49701 .11299 L
.49815 .11101 L
.49921 .10808 L
.50037 .10376 L
.5016 .09825 L
.50368 .08809 L
.50595 .07811 L
.50719 .07394 L
.50834 .07111 L
.50956 .06932 L
.51085 .0688 L
.51207 .06956 L
Mistroke
.51321 .07127 L
.51423 .07344 L
.51534 .07619 L
.51667 .07946 L
.5179 .08185 L
.51919 .08293 L
.51988 .0827 L
.52061 .08174 L
.52191 .07809 L
.52314 .07246 L
.52546 .05802 L
.52766 .04368 L
.52887 .03726 L
.53001 .03266 L
.53097 .0299 L
.53201 .02796 L
.53316 .02678 L
.53422 .02625 L
.53536 .02595 L
.53643 .0257 L
.53886 .02495 L
.54007 .02459 L
.54122 .02434 L
.54186 .02424 L
.54255 .02415 L
.54375 .02399 L
.54498 .02375 L
.5461 .02343 L
.54863 .02243 L
.5532 .02084 L
.5636 .01602 L
.57451 .01155 L
.58463 .00843 L
.5946 .00589 L
.60363 .00398 L
.60845 .0031 L
.61366 .00238 L
.61917 .00178 L
.62167 .00157 L
.62305 .00143 L
.62436 .00131 L
.62693 .00115 L
.62928 .00103 L
.6315 .00091 L
.63387 .00077 L
.6351 .00072 L
.63647 .00068 L
.63887 .00061 L
.64171 .0005 L
.64295 .00046 L
Mistroke
.6436 .00044 L
.64431 .00042 L
.64563 .0004 L
.64685 .00038 L
.64954 .00032 L
.65517 .00022 L
.65792 .00019 L
.65927 .00016 L
.66052 .00015 L
.66165 .00013 L
.66285 .00013 L
.66537 .00011 L
.66769 9e-05 L
.66892 8e-05 L
.67022 7e-05 L
.67147 7e-05 L
.67261 6e-05 L
.67375 6e-05 L
.67482 5e-05 L
.67606 5e-05 L
.67737 4e-05 L
.67805 4e-05 L
.6788 3e-05 L
.68012 3e-05 L
.68133 3e-05 L
.68262 3e-05 L
.68385 2e-05 L
.68496 2e-05 L
.6861 2e-05 L
.68731 1e-05 L
.68834 1e-05 L
.68947 1e-05 L
.69069 1e-05 L
.692 1e-05 L
.69323 1e-05 L
.69437 1e-05 L
.69551 1e-05 L
.69676 1e-05 L
.69785 1e-05 L
.69902 1e-05 L
.70017 1e-05 L
.70125 0 L
.70231 0 L
.70328 0 L
.70444 0 L
.70568 0 L
.70685 0 L
.70793 0 L
.70918 0 L
.70984 0 L
Mistroke
.71055 0 L
.71173 0 L
.71303 0 L
.71368 0 L
.71437 0 L
.71559 0 L
.71691 0 L
.71765 0 L
.71835 0 L
.71959 0 L
.72076 0 L
.72141 0 L
.72211 0 L
.72334 0 L
.72449 0 L
.72556 0 L
.72674 0 L
.72801 0 L
.72864 0 L
.72933 0 L
.73059 0 L
.73183 0 L
.73295 0 L
.7341 0 L
.73517 0 L
.73631 0 L
.73755 0 L
.73863 0 L
.73977 0 L
.74074 0 L
.74181 0 L
.74312 0 L
.74433 0 L
.74496 0 L
.74565 0 L
.74638 0 L
.74706 0 L
.74823 0 L
.74946 0 L
.7501 0 L
.7508 0 L
.75203 0 L
.75326 0 L
.75437 0 L
.75565 0 L
.75686 0 L
.75798 0 L
.75901 0 L
.76023 0 L
.76135 0 L
Mistroke
.76255 0 L
.76385 0 L
.76505 0 L
.76619 0 L
.76683 0 L
.76751 0 L
.76874 0 L
.77006 0 L
.77081 0 L
.77151 0 L
.77283 0 L
.77349 0 L
.77421 0 L
.77549 0 L
.77669 0 L
.77741 0 L
.7781 0 L
.77938 0 L
.78006 0 L
.78077 0 L
.78155 0 L
.78227 0 L
.78347 0 L
.78479 0 L
.78603 0 L
.78719 0 L
.78831 0 L
.78936 0 L
.79058 0 L
.79168 0 L
.79291 0 L
.79422 0 L
.79533 0 L
.79655 0 L
.79786 0 L
.7986 0 L
.79927 0 L
.80057 0 L
.80181 0 L
.80286 0 L
.80401 0 L
.80522 0 L
.80636 0 L
.80742 0 L
.80841 0 L
.80944 0 L
.81057 0 L
.81173 0 L
.81297 0 L
.81412 0 L
Mistroke
.81516 0 L
.81638 0 L
.81707 0 L
.81771 0 L
.81887 0 L
.82011 0 L
.82132 0 L
.82264 0 L
.8238 0 L
.82504 0 L
.82627 0 L
.82738 0 L
.82849 0 L
.82955 0 L
.83078 0 L
.83209 0 L
.8332 0 L
.83442 0 L
.83574 0 L
.83647 0 L
.83714 0 L
.83845 0 L
.83968 0 L
.84074 0 L
.8419 0 L
.84311 0 L
.84425 0 L
.84531 0 L
.84628 0 L
.84733 0 L
.84846 0 L
.84961 0 L
.85068 0 L
.85196 0 L
.85311 0 L
.85432 0 L
.85563 0 L
.85686 0 L
.858 0 L
.85926 0 L
.86045 0 L
.86152 0 L
.86269 0 L
.86395 0 L
.86459 0 L
.8653 0 L
.86655 0 L
.86772 0 L
.86883 0 L
.87 0 L
Mistroke
.87101 0 L
.87209 0 L
.87325 0 L
.87434 0 L
.87563 0 L
.8768 0 L
.87809 0 L
.87879 0 L
.87945 0 L
.88061 0 L
.8819 0 L
.88255 0 L
.88326 0 L
.88456 0 L
.88533 0 L
.88605 0 L
.88671 0 L
.88742 0 L
.88873 0 L
.88997 0 L
.89107 0 L
.89228 0 L
.89359 0 L
.89431 0 L
.89498 0 L
.89617 0 L
.89746 0 L
.89809 0 L
.89878 0 L
.90002 0 L
.90132 0 L
.90206 0 L
.90275 0 L
.90389 0 L
.90513 0 L
.90643 0 L
.90764 0 L
.90833 0 L
.90909 0 L
.90979 0 L
.91045 0 L
.91169 0 L
.913 0 L
.91367 0 L
.9144 0 L
.91572 0 L
.91652 0 L
.91728 0 L
.91802 0 L
.91871 0 L
Mistroke
.91999 0 L
.92114 0 L
.92179 0 L
.92248 0 L
.92371 0 L
.92478 0 L
.92594 0 L
.92719 0 L
.92835 0 L
.929 0 L
.92971 0 L
.931 0 L
.93226 0 L
.93342 0 L
.93467 0 L
.93538 0 L
.93605 0 L
.93675 0 L
.93739 0 L
.93809 0 L
.93884 0 L
.94005 0 L
.94119 0 L
.94221 0 L
.94332 0 L
.94453 0 L
.94581 0 L
.94699 0 L
.9481 0 L
.94921 0 L
.95027 0 L
.95122 0 L
.95225 0 L
.95335 0 L
.95454 0 L
.95566 0 L
.9567 0 L
.95781 0 L
.95903 0 L
.96028 0 L
.9616 0 L
.96291 0 L
.96364 0 L
.96431 0 L
.96561 0 L
.96682 0 L
.96794 0 L
.96913 0 L
.97033 0 L
.97164 0 L
Mistroke
.97277 0 L
.97399 0 L
.97514 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000003oool0103oool2000000D0oooo0P0000000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool:000000T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<05P3oool001/0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00D0oooo0P0000050?ooo`8000003@3oool00`000000oooo0?ooo`0I0?ooo`8000004P3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool20000
0080oooo0P00000E0?ooo`00P`3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000050?ooo`8000001@3oool2000000d0oooo00<000000?ooo`3oool05P3oool300000:40
oooo00290?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`8000001@3oool20000
00d0oooo00<000000?ooo`3oool04P3oool400000:@0oooo00290?ooo`070000003oool0oooo0?oo
o`000000oooo000000050?ooo`8000001@3oool2000000d0oooo00<000000?ooo`3oool03`3oool3
00000:P0oooo00290?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`8000001@3o
ool2000000d0oooo00<000000?ooo`3oool03@3oool200000:/0oooo00290?ooo`070000003oool0
oooo0?ooo`000000oooo000000050?ooo`8000001@3oool2000000d0oooo00<000000?ooo`3oool0
2P3oool300000:d0oooo002:0?ooo`060000003oool0oooo0000003oool000001@3oool2000000D0
oooo0P00000=0?ooo`030000003oool0oooo00L0oooo0`00002`0?ooo`00RP3oool00`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`8000003@3oool00`000000oooo
0?ooo`060?ooo`800000/P3oool008X0oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000001@3oool2000000d0oooo0P0000070?ooo`030000003oool0oooo0;40
oooo002;0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool2000000d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2a0?ooo`00
R`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;40
oooo002@0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`80
00003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002@0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002@0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`8000003@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0;80oooo002@0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`8000003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80
oooo002@0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`80
00003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002@0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00T03oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<0?ooo`80
00001P3oool00`000000oooo0?ooo`2b0?ooo`00T@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0;80oooo002A0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo008000000P3oool00`000000
oooo0?ooo`2c0?ooo`00T@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3o
ool0/`3oool00940oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo000000020?ooo`030000003oool000000;D0
oooo002A0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000000P3oool00`000000oooo0000002e0?ooo`00
T@3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool000000080oooo0P00002f0?ooo`00T@3oool00`000000oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000^`3oool00940oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool200000;/0oooo002A0?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002k0?ooo`00
T@3oool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0;X0oooo002A0?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0^P3oool00940oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2j0?ooo`00TP3oool2000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0^P3oool00980oooo0P0000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`2j0?ooo`00TP3oool2000000@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`070?ooo`@00000_03oool00900oooo00D0k^k^03<c<`000000
<c<c0>k^kP030?ooo`040000003oool08R8R00000080oooo00<000000?ooo`000000100000020?oo
o`030000003oool0oooo00800000_03oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?oo
o`040000003oool08R8R00000080oooo00T000000?ooo`2IVIT08R8R0>k^kP3oool0A4A40?ooo`00
0000103oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool04A4A00<0
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`2IVIT08R8R0>k^kP80oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool02@000000oooo0?ooo`3oool0VIVI028R
8P3^k^h0oooo000000040?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool0101gMgL0IVIV0?oo
o`0000040?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A40
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool010000000
oooo0?ooo`0000020?ooo`080000003oool000000;^k^`3oool0VIVI014A4@0000050?ooo`030000
003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool010000000oooo
0?ooo`0000020?ooo`080000003oool0VIVI014A4@0000008R8R0<c<c00000050?ooo`030000003o
ool0oooo0;X0oooo002H0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;X0oooo002H0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0;X0oooo002H0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;X0oooo002H0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0;X0oooo002H0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`800000^`3oool009P0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3o
ool009P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0^P3oool009P0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3o
ool009P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0^P3oool009P0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3o
ool009P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0^P3oool009P0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3o
ool009P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0^P3oool009P0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00002k0?ooo`00V03oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2j0?ooo`00V03oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2j0?ooo`00V03oool0
0`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2j0?ooo`00V03oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00V03oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00V03oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j
0?ooo`00V03oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`2j0?ooo`00V03oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00V03oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00V03oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool200000;/0oooo002I0?oo
o`800000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0^P3oool0
09T0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j
0?ooo`00V@3oool2000000@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo0;X0oooo002I0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool0^P3oool009T0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00@0oooo0P000000
1@0R8R80oooo0?ooo`3oool000000080oooo0P0000000`0A4A40oooo0?ooo`040?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0103oool200000005028R8P3o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A40103oool2000000@0oooo1P0000060?ooo`030000
003oool0oooo0;X0oooo002@0?ooo`050000003oool0oooo0?ooo`000000103oool2000000@0oooo
00D0000004A4A03MgMd0oooo000000070?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0
oooo000000040?ooo`800000103oool01@000000gMgM05EEE@3oool0000000L0oooo00<000000?oo
o`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@040?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`1gMgL0c<c<000000070?ooo`030000003oool0oooo0;X0oooo002@0?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL02P3oool01@000000oooo0>k^kP14A4@0000000L0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0:0?ooo`050000003o
ool0oooo07MgM`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00W`3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool0^P3oool009l0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo0;X0oooo002O0?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`2j0?ooo`00W`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool0^P3oool009l0oooo00D000000?ooo`3oool0oooo000000070?ooo`800000
^`3oool009l0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0;X0oooo
002O0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00W`3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0^P3oool009l0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0;X0oooo002O0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2j0?ooo`00W`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0;X0oooo002O0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0^P3oool009l0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`2j0?ooo`00W`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0;X0oooo
002O0?ooo`040000003oool0oooo000000P0oooo0P00002k0?ooo`00W`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0;X0oooo002O0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0^P3oool009l0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`2j0?ooo`00W`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0;X0oooo
002O0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0^P3oool009l0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`2j0?ooo`00W`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0;X0oooo002O0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0^P3oool009l0oooo00@000000?ooo`3oool00000203oool200000;/0oooo
002O0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0^P3oool009l0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`2j0?ooo`00W`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo0;X0oooo002O0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0^P3oool009l0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`2j0?ooo`00W`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P<0oooo00H000000>k^kP0c<c<0
0000014A4@3<c<`60?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL01@3oool2028R8P<0oooo00H0000005EEE@1gMgL0000009VIV@0R8R860?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402P3oool2000000040?ooo`00
0000oooo000000H0oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000X0oooo
0P000000102IVIT0000009VIV@0R8R860?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000
003oool0oooo0?ooo`0000002P3oool20000000405EEE@0000004A4A0<c<c0H0oooo00<000000?oo
o`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0:0?ooo`030000001EEED00000
00T0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`0:0?oo
o`040000003MgMd0000009VIV@P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c
<`000000<c<c0>k^kP0:0?ooo`060000003oool0000004A4A00000004A4A1P3oool00`000000oooo
0?ooo`2j0?ooo`00W`3oool00`000000oooo000000090?ooo`030000003oool0oooo0;X0oooo002O
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0^P3oool00:00oooo0P0000090?oo
o`030000003oool0oooo0;X0oooo002P0?ooo`8000002@3oool00`000000oooo0?ooo`2j0?ooo`00
X03oool2000000T0oooo0P00002k0?ooo`00X03oool2000000T0oooo00<000000?ooo`3oool0^P3o
ool00:00oooo0P0000090?ooo`030000003oool0oooo0;X0oooo002P0?ooo`8000002@3oool00`00
0000oooo0?ooo`2j0?ooo`00X03oool2000000T0oooo00<000000?ooo`3oool0^P3oool00:00oooo
0P0000090?ooo`030000003oool0oooo0;X0oooo002P0?ooo`8000002@3oool00`000000oooo0?oo
o`2j0?ooo`00X03oool2000000T0oooo00<000000?ooo`3oool0^P3oool00:00oooo0P0000090?oo
o`030000003oool0oooo0;X0oooo002P0?ooo`8000002@3oool200000;/0oooo002P0?ooo`800000
2@3oool00`000000oooo0?ooo`2j0?ooo`00X03oool2000000T0oooo00<000000?ooo`3oool0^P3o
ool00:00oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0c<c<028R8P00
00008R8R0<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL01@3oool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P060?ooo`030000003oool0
oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`0503<c<`2IVIT0oooo09VIV@0c<c<01P3oool300000;X0oooo002@0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00H0oooo00<000000?ooo`3o
ool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`05014A4@2k^k/0oooo0;^k
^`0A4A401P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00/0oooo00D000000;^k^`3oool0^k^k000000060?ooo`030000003oool0oooo0;X0oooo002@0?oo
o`050>k^kP0c<c<0000003<c<`3^k^h02`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00H0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:40oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0
oooo0;X0oooo002S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0^P3oool00:<0
oooo00<000000?ooo`3oool01@3oool300000;X0oooo002S0?ooo`030000003oool0oooo0<80oooo
002S0?ooo`030000003oool0oooo0<80oooo002S0?ooo`030000003oool0oooo0<80oooo002S0?oo
o`030000003oool0oooo0<80oooo002Q0?ooo`80EEEE00<000000?ooo`3oool0`P3oool00?l0oooo
J@3oool006d0oooo00<0MgMg06IVIP3oool00`3oool00`000000oooo0?ooo`030?ooo`030;^k^`0c
<c<0oooo00H0oooo0P00000;0?ooo`03014A4@2k^k/0oooo00`0oooo0P0000080?ooo`060000003o
ool0oooo0?ooo`1VIVH0MgMg3P3oool00`0A4A40^k^k0?ooo`2Y0?ooo`00K03oool00`3MgMd04A4A
0>k^kP040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`80<c<c3P3oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`3^
k^h04A4A0=gMg@0=0?ooo`80<c<cZP3oool006`0oooo00<0EEEE09VIV@3oool0103oool00`000000
oooo0?ooo`020?ooo`0509VIV@0A4A4000000000002ZZZX01@3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool200000080oooo00<0R8R80000002ZZZX01@3oool01@2IVIT0000000000014A4@0
^k^k00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`0308R8R01VIVH0
oooo00`0oooo00<0R8R80000002ZZZX0303oool01@2IVIT0000000000014A4@0^k^k0140oooo1000
00000`0A4A40oooo0?ooo`020?ooo`808R8RO03oool006`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`060000002ZZZX0EEEE08R8R01EEED0^k^k103oool00`000000oooo
0?ooo`020?ooo`060>k^kP0R8R80R8R80<c<c0000000c<c<0P3oool00`3<c<`00000014A4@050?oo
o`05014A4@2k^k/0k^k^07MgM`0A4A400`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00<0k^k^0000003oool0303oool00`3<c<`00000014A4@0<0?ooo`06014A4@2k^k/0
k^k^07MgM`0A4A40oooo1P00000<0?ooo`030000003oool0oooo00@0oooo0P0R8R9l0?ooo`00K03o
ool00`0c<c<0oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00H0<c<c0>k^kP2IVIT0EEEE
0=gMg@0A4A440?ooo`030000003oool0oooo00<0oooo00@0gMgM000000000000c<c<2`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0PP3oool006`0
oooo00<0<c<c0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`070;^k^`14A4@0c<c<028R
8P3oool04A4A0<c<c0030?ooo`030000003oool0oooo00<0oooo00@0k^k^028R8P000000k^k^2`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo1P00000<0?ooo`030000003o
ool0oooo0880oooo001/0?ooo`030000003^k^h0oooo00@0oooo00<000000?ooo`3oool00P3oool0
1`3^k^h000000?ooo`000000k^k^06IVIP28R8P00`3oool00`000000oooo0?ooo`020?ooo`050>k^
kP0R8R80MgMg07MgM`0c<c<02`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`3^k^h000000?ooo`0K0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0PP3oool006`0oooo00<0EEEE07MgM`3oool0103oool00`000000oooo
0?ooo`020?ooo`0406IVIP2IVIT0oooo03<c<`80^k^k00D000000?ooo`3oool0oooo000000040?oo
o`8000000P3oool2000000P0oooo00<04A4A0000000000000`0000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool00`1gMgL0EEEE0?ooo`030?ooo`@000004P3oool00`0A
4A40000000000003000001@0oooo00<000000?ooo`3oool0PP3oool006`0oooo00<0gMgM014A4@3^
k^h0103oool00`000000oooo0?ooo`050?ooo`0306IVIP1gMgL0oooo00@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3o
ool0oooo0>k^kP0A4A40gMgM00D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0880oooo001]0?ooo`0307MgM`1VIVH0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`2ZZZX0A4A40?ooo`040?ooo`8000004`3oool00`000000oooo0?ooo`040?oo
o`800000203oool01P000000oooo0?ooo`3oool0IVIV07MgM`L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0C0?ooo`80EEEE00<000000?ooo`3oool0PP3oool00;H0oooo00<00000
0?ooo`3oool0[`3oool00;<0oooo00@000000?ooo`3oool00000/@3oool00;@0oooo0P00002b0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04583 0 L
.04652 0 L
.04727 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 0 L
.05186 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06453 0 L
.06529 0 L
.06657 0 L
.06729 0 L
.06797 0 L
.06922 0 L
.0704 0 L
.07105 0 L
.07176 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07513 0 L
.07583 0 L
.07659 0 L
.0773 0 L
.07804 0 L
.07885 0 L
.07956 0 L
.08021 0 L
.08091 0 L
.08167 0 L
.08237 0 L
.08301 0 L
.08427 0 L
.08544 0 L
.08669 0 L
.08787 0 L
.08896 0 L
.09016 0 L
.09148 0 L
.09214 0 L
.09285 0 L
.09413 0 L
.09483 0 L
.09548 0 L
.09619 0 L
.09695 0 L
.09821 0 L
.09893 0 L
.09961 0 L
.10084 0 L
.10201 0 L
.10265 0 L
.10335 0 L
.10458 0 L
.10579 0 L
.10691 0 L
.10813 0 L
.10942 0 L
.11054 0 L
.11159 0 L
.11273 0 L
.11396 0 L
.11467 0 L
.11531 0 L
.11659 0 L
.11775 0 L
.11897 0 L
.12029 0 L
Mistroke
.12152 0 L
.12223 0 L
.12288 0 L
.12362 0 L
.12433 0 L
.12501 0 L
.12565 0 L
.12685 0 L
.12814 0 L
.12881 0 L
.12954 0 L
.13076 0 L
.13206 0 L
.13326 0 L
.13437 0 L
.13505 0 L
.13579 0 L
.13645 0 L
.13714 0 L
.13845 0 L
.13966 0 L
.14096 0 L
.14169 0 L
.14236 0 L
.1431 0 L
.14389 0 L
.14464 0 L
.14533 0 L
.14657 0 L
.14722 0 L
.14791 0 L
.14906 0 L
.15034 0 L
.15147 0 L
.15269 0 L
.15384 0 L
.15488 0 L
.15618 0 L
.15739 0 L
.15871 0 L
.15945 0 L
.16012 0 L
.16135 0 L
.16204 0 L
.16268 0 L
.16385 0 L
.16509 0 L
.16623 0 L
.16728 0 L
.16848 0 L
Mistroke
.16962 0 L
.17068 0 L
.17165 0 L
.17272 0 L
.17385 0 L
.17499 0 L
.17621 0 L
.17737 0 L
.17842 0 L
.17966 0 L
.18031 0 L
.181 0 L
.18228 0 L
.18346 0 L
.1847 0 L
.1854 0 L
.18606 0 L
.18675 0 L
.18739 0 L
.18813 0 L
.18881 0 L
.19002 0 L
.19134 0 L
.1925 0 L
.19374 0 L
.19505 0 L
.19579 0 L
.19646 0 L
.1971 0 L
.19779 0 L
.19902 0 L
.19973 0 L
.20038 0 L
.20115 0 L
.20187 0 L
.2026 0 L
.20341 0 L
.20411 0 L
.20486 0 L
.20609 0 L
.20725 0 L
.20789 0 L
.20859 0 L
.20982 0 L
.21099 0 L
.21223 0 L
.2134 0 L
.21446 0 L
.21513 0 L
.21583 0 L
Mistroke
.21708 0 L
.21778 0 L
.21843 0 L
.21914 0 L
.21991 0 L
.22057 0 L
.22128 0 L
.22259 1e-05 L
.22503 1e-05 L
.22617 1e-05 L
.22724 1e-05 L
.22835 1e-05 L
.22956 1e-05 L
.2308 1e-05 L
.23211 1e-05 L
.23334 1e-05 L
.23445 1e-05 L
.23514 1e-05 L
.23577 1e-05 L
.23645 1e-05 L
.2372 1e-05 L
.23847 1e-05 L
.23916 1e-05 L
.23981 2e-05 L
.24097 2e-05 L
.24221 2e-05 L
.24286 2e-05 L
.24357 2e-05 L
.24483 2e-05 L
.24551 2e-05 L
.24623 2e-05 L
.24755 2e-05 L
.24821 2e-05 L
.2489 2e-05 L
.25013 3e-05 L
.25247 4e-05 L
.25497 4e-05 L
.25569 5e-05 L
.25638 5e-05 L
.25766 6e-05 L
.26016 8e-05 L
.26149 9e-05 L
.26215 9e-05 L
.26289 .0001 L
.26368 .0001 L
.26443 .0001 L
.26585 .0001 L
.26825 .00011 L
.26957 .00012 L
.27082 .00012 L
Mistroke
.27152 .00012 L
.27229 .00012 L
.27299 .00012 L
.27363 .00012 L
.27489 .00012 L
.27553 .00013 L
.27623 .00013 L
.27752 .00014 L
.2787 .00016 L
.28134 .00021 L
.2861 .00033 L
.28831 .00042 L
.28952 .00046 L
.29066 .0005 L
.29188 .00052 L
.29253 .00053 L
.29324 .00054 L
.29448 .00055 L
.29562 .00056 L
.2967 .00056 L
.29771 .00057 L
.29882 .00057 L
.30001 .00056 L
.30107 .00054 L
.30221 .00053 L
.30346 .00051 L
.30463 .00052 L
.30532 .00053 L
.30598 .00055 L
.30722 .00062 L
.30853 .00072 L
.30996 .00086 L
.31251 .00119 L
.31488 .0016 L
.31765 .00216 L
.31901 .0024 L
.32026 .00258 L
.32096 .00266 L
.3217 .00271 L
.32244 .00275 L
.32326 .00276 L
.32394 .00276 L
.32467 .00273 L
.32598 .00266 L
.32858 .00239 L
.32995 .00221 L
.3314 .00201 L
.33267 .00188 L
.33339 .00183 L
.33407 .00182 L
Mistroke
.33525 .0019 L
.33653 .00214 L
.33776 .00252 L
.3391 .00312 L
.34154 .0046 L
.34613 .00823 L
.34737 .00919 L
.34868 .01005 L
.34937 .0104 L
.35012 .01071 L
.35144 .01097 L
.35269 .0109 L
.35339 .01073 L
.35402 .01049 L
.35526 .00985 L
.35644 .00908 L
.35861 .00744 L
.3598 .00655 L
.36092 .00582 L
.36212 .00524 L
.36276 .00506 L
.36345 .005 L
.36467 .00528 L
.36579 .00606 L
.36708 .00766 L
.36781 .00891 L
.36849 .01027 L
.37104 .01699 L
.37398 .02635 L
.37536 .03059 L
.37665 .03409 L
.37777 .03654 L
.37898 .03835 L
.37967 .03892 L
.38033 .03912 L
.38156 .03855 L
.38285 .03662 L
.38404 .03372 L
.38676 .02462 L
.38794 .02041 L
.38923 .0164 L
.39044 .01356 L
.39156 .01209 L
.39257 .01193 L
.39367 .01318 L
.39483 .01624 L
.39591 .02078 L
.39718 .02813 L
.39837 .03694 L
.40062 .05691 L
Mistroke
.40302 .07935 L
.40438 .0904 L
.40566 .09843 L
.40686 .10329 L
.40816 .10517 L
.40884 .1047 L
.40954 .10311 L
.41081 .09762 L
.41199 .08972 L
.41309 .08039 L
.41558 .05516 L
.41698 .0411 L
.41767 .035 L
.41831 .03015 L
.4195 .02368 L
.42079 .02159 L
.42208 .02566 L
.42281 .03093 L
.42349 .03785 L
.42487 .05738 L
.42635 .0856 L
.42889 .14456 L
.43127 .19953 L
.43259 .22388 L
.43333 .23437 L
.43402 .24152 L
.43522 .2476 L
.4365 .24406 L
.43718 .23787 L
.43792 .22807 L
.43924 .203 L
.44224 .12441 L
.44358 .08848 L
.445 .05628 L
.44621 .03666 L
.4469 .02954 L
.44755 .02584 L
.4488 .0273 L
.4495 .03324 L
.45015 .04188 L
.45084 .05448 L
.45159 .07193 L
.45296 .11246 L
.45544 .20395 L
.4568 .25564 L
.45808 .29877 L
.45933 .33105 L
.46004 .34357 L
.46068 .35096 L
.46183 .3538 L
Mistroke
.46305 .34278 L
.46418 .3209 L
.46525 .29269 L
.46766 .21509 L
.47009 .14232 L
.47131 .1137 L
.47266 .08964 L
.47337 .08012 L
.47412 .0719 L
.47484 .06587 L
.47549 .06163 L
.47677 .05627 L
.47741 .05473 L
.47811 .05371 L
.47941 .05322 L
.48059 .05379 L
.48124 .05435 L
.48195 .05507 L
.48324 .05646 L
.48444 .05768 L
.48572 .05873 L
.48681 .05932 L
.48801 .05958 L
.48925 .05934 L
.49042 .0586 L
.49148 .05753 L
.49263 .05597 L
.49503 .05185 L
.49635 .04949 L
.49759 .04752 L
.49877 .04607 L
.50004 .04518 L
.50119 .04516 L
.50225 .04593 L
.50325 .04744 L
.50435 .05001 L
.50549 .05375 L
.50656 .05815 L
.51158 .08476 L
.51296 .091 L
.51365 .09351 L
.51442 .09566 L
.51507 .09692 L
.51577 .09766 L
.51704 .09731 L
.51824 .09498 L
.51956 .09039 L
.52094 .08368 L
.52221 .07612 L
.52465 .05983 L
Mistroke
.52695 .04497 L
.52805 .03896 L
.52921 .03378 L
.53049 .0297 L
.53166 .02746 L
.53271 .02654 L
.5337 .0264 L
.53478 .02676 L
.53593 .02739 L
.53717 .028 L
.53786 .02823 L
.53851 .02836 L
.53969 .02842 L
.54095 .02838 L
.54207 .02839 L
.54312 .02853 L
.54427 .02885 L
.54552 .02928 L
.54677 .02965 L
.54791 .02981 L
.54922 .02974 L
.55047 .02949 L
.55154 .02923 L
.55267 .02901 L
.55392 .02889 L
.55507 .0289 L
.55631 .02894 L
.55701 .02894 L
.55764 .02891 L
.55888 .02874 L
.56005 .02845 L
.56553 .02742 L
.58662 .02253 L
.62483 .01024 L
.63497 .00758 L
.64451 .00557 L
.65552 .00381 L
.66549 .00257 L
.67526 .00167 L
.67764 .00147 L
.68018 .00129 L
.68164 .00121 L
.68297 .00115 L
.68558 .00102 L
.68779 .00089 L
.69013 .00079 L
.69135 .00076 L
.69269 .00072 L
.69507 .00063 L
.70406 .0004 L
Mistroke
.70898 .00031 L
.71028 .0003 L
.71166 .00028 L
.71416 .00023 L
.71535 .00021 L
.71647 .0002 L
.71748 .00019 L
.71858 .00019 L
.7198 .00018 L
.7211 .00017 L
.72341 .00014 L
.72471 .00013 L
.72589 .00012 L
.72716 .00011 L
.72783 .00011 L
.72855 .00011 L
.72983 .0001 L
.73101 9e-05 L
.73223 8e-05 L
.73335 7e-05 L
.73404 7e-05 L
.73477 7e-05 L
.73557 7e-05 L
.73631 7e-05 L
.73695 6e-05 L
.73763 6e-05 L
.73908 5e-05 L
.74048 5e-05 L
.7418 4e-05 L
.74299 4e-05 L
.74428 4e-05 L
.75364 2e-05 L
.75633 2e-05 L
.75697 1e-05 L
.75766 1e-05 L
.7589 1e-05 L
.7601 1e-05 L
.7612 1e-05 L
.76249 1e-05 L
.76371 1e-05 L
.76504 1e-05 L
.76629 1e-05 L
.76759 1e-05 L
.76828 1e-05 L
.76902 1e-05 L
.76982 1e-05 L
.77058 1e-05 L
.77127 1e-05 L
.77201 1e-05 L
.7727 1e-05 L
Mistroke
.77344 0 L
.77413 0 L
.77476 0 L
.77599 0 L
.7773 0 L
.77846 0 L
.77969 0 L
.78034 0 L
.78103 0 L
.78228 0 L
.78305 0 L
.78377 0 L
.78442 0 L
.78512 0 L
.7863 0 L
.78757 0 L
.78876 0 L
.78986 0 L
.79113 0 L
.79185 0 L
.79253 0 L
.79375 0 L
.79506 0 L
.79577 0 L
.79643 0 L
.79715 0 L
.79791 0 L
.79857 0 L
.79929 0 L
.80058 0 L
.80183 0 L
.80297 0 L
.80361 0 L
.80431 0 L
.80559 0 L
.80677 0 L
.80804 0 L
.80924 0 L
.81034 0 L
.81149 0 L
.81274 0 L
.81403 0 L
.81474 0 L
.81539 0 L
.81658 0 L
.81769 0 L
.81869 0 L
.81978 0 L
.82096 0 L
.82221 0 L
Mistroke
.82328 0 L
.82446 0 L
.82576 0 L
.82696 0 L
.82828 0 L
.82895 0 L
.82968 0 L
.83084 0 L
.83207 0 L
.83271 0 L
.83341 0 L
.83464 0 L
.83584 0 L
.83712 0 L
.83833 0 L
.83943 0 L
.84054 0 L
.84174 0 L
.84288 0 L
.84393 0 L
.84513 0 L
.84642 0 L
.84754 0 L
.84876 0 L
.8495 0 L
.85018 0 L
.85084 0 L
.85154 0 L
.85222 0 L
.85287 0 L
.85408 0 L
.85539 0 L
.85605 0 L
.85677 0 L
.85805 0 L
.85924 0 L
.85997 0 L
.86066 0 L
.86194 0 L
.86266 0 L
.86333 0 L
.86406 0 L
.86483 0 L
.86597 0 L
.86722 0 L
.86851 0 L
.86972 0 L
.87086 0 L
.87189 0 L
.87308 0 L
Mistroke
.8742 0 L
.87543 0 L
.87673 0 L
.87783 0 L
.87905 0 L
.88036 0 L
.8811 0 L
.88177 0 L
.88307 0 L
.88431 0 L
.88546 0 L
.8865 0 L
.88763 0 L
.88885 0 L
.88998 0 L
.89101 0 L
.89201 0 L
.89305 0 L
.89419 0 L
.89541 0 L
.89656 0 L
.8976 0 L
.89883 0 L
.89948 0 L
.90016 0 L
.90142 0 L
.90259 0 L
.90373 0 L
.90498 0 L
.90628 0 L
.90749 0 L
.90863 0 L
.90967 0 L
.91086 0 L
.91198 0 L
.91321 0 L
.91451 0 L
.91562 0 L
.91684 0 L
.91815 0 L
.91887 0 L
.91956 0 L
.9202 0 L
.92089 0 L
.9221 0 L
.92315 0 L
.92429 0 L
.92553 0 L
.9267 0 L
.92795 0 L
Mistroke
.92926 0 L
.93037 0 L
.9316 0 L
.93275 0 L
.9338 0 L
.93493 0 L
.93615 0 L
.93729 0 L
.93833 0 L
.93933 0 L
.94039 0 L
.94153 0 L
.94278 0 L
.94396 0 L
.94505 0 L
.9461 0 L
.94724 0 L
.94831 0 L
.9493 0 L
.95049 0 L
.95174 0 L
.95279 0 L
.95394 0 L
.95517 0 L
.9565 0 L
.95774 0 L
.95888 0 L
.95995 0 L
.96109 0 L
.96207 0 L
.96314 0 L
.96429 0 L
.96553 0 L
.9666 0 L
.96777 0 L
.96888 0 L
.96991 0 L
.971 0 L
.97217 0 L
.97325 0 L
.97427 0 L
.97519 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`/000002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool:00000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3o
ool01@3^k^h08R8R07MgM`1gMgL0<c<c01H0oooo000K0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`@000009`3oool00`000000oooo0?oo
o`0U0?ooo`H000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool03`3oool200000080oooo0P00000E0?ooo`00O03oool500000080oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0R0?ooo`<00000U@3oool008<0oooo00<000000?oo
o`3oool0103oool2000001l0oooo00<000000?ooo`3oool07`3oool3000009P0oooo00240?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`0L0?ooo`<0
0000V`3oool008@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000O0?ooo`030000
003oool0oooo01T0oooo0`00002N0?ooo`00Q@3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo1@00002Q0?ooo`00
Q@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool2000000L0
oooo1000002V0?ooo`00Q@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00`3oool2000000L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0000000L00000ZP3oool008H0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000H0oooo0P00000>0?ooo`8000001`3oool00`000000oooo
0?ooo`2a0?ooo`00QP3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool2000000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2a0?ooo`00QP3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000006
0?ooo`8000003P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002<0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool2000000h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00S03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000H0oooo0P00000>0?ooo`8000001P3oool00`000000oooo0?ooo`2b0?ooo`00
S@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<000000?ooo`000000
3@3oool3000000H0oooo00<000000?ooo`3oool0/P3oool008d0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`3oool2000000<0oooo
00D000000?ooo`000000oooo000000050?ooo`030000003oool0oooo0;80oooo002=0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0
oooo0`0000020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`2c0?oo
o`00S@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000070?ooo`030000003oool00000008000000P3oool00`000000oooo000000040?oo
o`030000003oool0oooo0;<0oooo002=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool30000
00@0oooo00<000000?ooo`3oool0/`3oool008d0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool0/`3oool008h0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0oooo0;<0oooo002>0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2c0?oo
o`00SP3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool0/`3oool008h0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0;<0oooo002>0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000060?ooo`030000003oool0oooo00D0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`2d0?ooo`00SP3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0]03oool008h0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0;@0oooo
002>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00060?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool000000;H0oooo002>
0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`00002f0?ooo`00SP3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
]@3oool008l0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0oooo002?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0^P3oool009D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
^P3oool009D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00H0k^k^03<c<`000000<c<c
0>k^kP0000040?ooo`040000000R8R80oooo00000080oooo1@0000060?ooo`030000003oool0oooo
0;X0oooo002@0?ooo`0607MgM`2IVIT0oooo09VIV@1gMgL00000103oool0100000008R8R0?ooo`00
00020?ooo`0509VIV@0R8R8000000?ooo`14A4@01P3oool00`000000oooo0?ooo`2j0?ooo`00T03o
ool01P0A4A40oooo0?ooo`3oool04A4A000000@0oooo00@000000?ooo`3oool000000`3oool00`2I
VIT000000>k^kP070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`040000003oool0oooo0?oo
o`800000103oool010000000oooo0?ooo`0000040?ooo`030000000R8R80k^k^00H0oooo0`00002j
0?ooo`00T03oool010000000oooo0?ooo`3oool2000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000MgMg06IVIP060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`06014A4@3oool0
oooo0?ooo`0A4A400000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool0^P3oool00900oooo00H0MgMg09VIV@3oool0VIVI07MgM`0000040?oo
o`040000003oool0oooo00000080oooo00D000000;^k^`000000VIVI014A4@060?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`060>k^kP0c<c<0000003<c<`3^k^h00000103oool010000000oooo
0?ooo`0000020?ooo`0509VIV@0A4A400000028R8P3<c<`01P3oool00`000000oooo0?ooo`2j0?oo
o`00U@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2j0?ooo`00U@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2j0?oo
o`00U@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2j0?ooo`00U@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2j0?oo
o`00U@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool01P3oool200000;/0oooo002E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;X0oooo002E0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0^P3oool009D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2j0?oo
o`00U@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo0;X0oooo002E0?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0^P3oool009H0oooo00@00000
0?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
^P3oool009H0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool0^P3oool009H0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo0;X0oooo002F0?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool000002@3oool200000;/0oooo002F0?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`2j0?ooo`00UP3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
^P3oool009H0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo0;X0oooo002F0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`2j0?ooo`00UP3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0^P3oool009H0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0;X0oooo002F
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`2j0?ooo`00UP3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool009L0oooo00<000000?ooo`000000103oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0;X0oooo002G0?ooo`8000001@3oool010000000oooo
0?ooo`0000090?ooo`800000^`3oool009L0oooo0P0000050?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool009L0oooo0P0000050?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool009L0oooo0P0000050?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool009L0oooo0P0000050?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool009L0oooo0P0000050?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP020?ooo`80
000000<0oooo028R8P0R8R800P3oool00`000000oooo0?ooo`0300000003014A4@3oool0oooo00@0
oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`020?ooo`80
000000<0oooo028R8P0R8R800P3oool01P000000oooo0?ooo`000000oooo000000L0oooo00<00000
0?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@020?ooo`8000001@3oool0
0`000000oooo00000004000000H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00H000000?ooo`14A4@000000?oo
o`0000070?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo000000090?ooo`060000
003oool0gMgM0000003oool000001`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40
oooo0?ooo`3oool04A4A00T0oooo00H000000?ooo`3oool000000<c<c00000070?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02@3oool01P000000oooo0000
003^k^h0A4A4000000L0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000
<c<c0>k^kP090?ooo`060000003oool000000?ooo`1gMgL000001`3oool00`000000oooo0?ooo`2j
0?ooo`00WP3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0;X0oooo002N0?ooo`03
0000003oool0000000X0oooo00<000000?ooo`3oool0^P3oool009h0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`2j0?ooo`00WP3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo0;X0oooo002N0?ooo`030000003oool0000000X0oooo0P00002k0?ooo`00WP3oool00`00
0000oooo0000000:0?ooo`030000003oool0oooo0;X0oooo002N0?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool0^P3oool009h0oooo00<000000?ooo`0000002P3oool00`000000oooo
0?ooo`2j0?ooo`00WP3oool00`000000oooo0000000:0?ooo`030000003oool0oooo0;X0oooo002N
0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0^P3oool009h0oooo00<000000?oo
o`0000002P3oool00`000000oooo0?ooo`2j0?ooo`00WP3oool00`000000oooo0000000:0?ooo`03
0000003oool0oooo0;X0oooo002N0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
^P3oool009h0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`2j0?ooo`00WP3oool0
0`000000oooo0000000:0?ooo`800000^`3oool009h0oooo00<000000?ooo`0000002P3oool00`00
0000oooo0?ooo`2j0?ooo`00W`3oool2000000X0oooo00<000000?ooo`3oool0^P3oool009l0oooo
0P00000:0?ooo`030000003oool0oooo0;X0oooo002O0?ooo`8000002P3oool00`000000oooo0?oo
o`2j0?ooo`00W`3oool2000000X0oooo00<000000?ooo`3oool0^P3oool009l0oooo0P00000:0?oo
o`030000003oool0oooo0;X0oooo002O0?ooo`8000002P3oool00`000000oooo0?ooo`2j0?ooo`00
W`3oool2000000X0oooo00<000000?ooo`3oool0^P3oool009l0oooo0P00000:0?ooo`800000^`3o
ool009l0oooo0P00000:0?ooo`030000003oool0oooo0;X0oooo002O0?ooo`8000002P3oool00`00
0000oooo0?ooo`2j0?ooo`00W`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;X0
oooo002O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c
<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3^k^h0<c<c0000000A4A40c<c<00H0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103o
ool01@1EEED0MgMg0?ooo`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0
4A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool300000;X0
oooo002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000VIVI0?ooo`2IVIT08R8R
00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050000001EEED00000014A4@3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A
4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool0203oool00`000000oooo0?ooo`2j
0?ooo`00T03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00<0gMgM014A4@2IVIT0203oool0
0`000000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo00@0c<c<
04A4A00000004A4A1P3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`050<c<
c00R8R800000028R8P3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo09VIV@0R8R801P3oool00`00
0000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00H0oooo0`00002j0?ooo`00T03oool0
1@000000oooo0?ooo`3oool0000000/0oooo00D0c<c<00000000000000000<c<c0060?ooo`030000
003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@0A4A40^k^k
0?ooo`2k^k/04A4A00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0;0?ooo`050000002k^k/0oooo0;^k^`0000001P3oool00`000000oooo0?ooo`2j0?oo
o`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00/0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP06
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002Q0?ooo`@0000000<04A4A0?ooo`3oool00`3oool00`00
0000oooo0?ooo`2j0?ooo`00X`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;X0
oooo002S0?ooo`030000003oool0oooo00D0oooo0`00002j0?ooo`00X`3oool00`000000oooo0?oo
o`320?ooo`00X`3oool00`000000oooo0?ooo`320?ooo`00X`3oool00`000000oooo0?ooo`320?oo
o`00X`3oool00`000000oooo0?ooo`320?ooo`00X@3oool205EEE@030000003oool0oooo0<80oooo
003o0?ooofT0oooo001Y0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`2k^k/0<c<c0?ooo`070?ooo`8000002`3oool00`0A4A40^k^k0?ooo`0<0?ooo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`0306IVIP1gMgL0oooo00`0oooo00<04A4A0;^k^`3oool0[@3oool0
06P0oooo00<0gMgM014A4@3^k^h01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02P3oool203<c<`h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030>k^kP0A4A40gMgM00`0oooo0P0c<c>^0?ooo`00J03oool00`1EEED0
VIVI0?ooo`050?ooo`060000003oool0oooo0?ooo`2IVIT04A4A0P0000000`2ZZZX0oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`8000000P3oool2000000<0oooo00<0R8R80000002ZZZX0103o
ool01@2IVIT0000000000014A4@0^k^k00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`0308R8R01VIVH0oooo00/0oooo00<0R8R80000002ZZZX0303oool01@2IVIT00000
00000014A4@0^k^k0140oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R103oool5000007L0
oooo001X0?ooo`030000003oool0oooo00D0oooo00X000000?ooo`3oool0oooo0000002ZZZX0EEEE
08R8R01EEED0^k^k1@3oool02P000000oooo0?ooo`3oool0k^k^028R8P28R8P0c<c<0000003<c<`3
0?ooo`030<c<c00000004A4A00@0oooo00D04A4A0;^k^`3^k^h0MgMg014A4@040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`3^k^h000000?ooo`0;0?ooo`030<c<c000
00004A4A00`0oooo00H04A4A0;^k^`3^k^h0MgMg014A4@3oool6000000`0oooo00<000000?ooo`3o
ool0103oool2028R8P@0oooo00D0VIVI028R8P3^k^h0oooo04A4A01g0?ooo`00J03oool00`0c<c<0
oooo0?ooo`050?ooo`0:0000003oool0oooo0?ooo`0c<c<0k^k^09VIV@1EEED0gMgM014A4@D0oooo
00<000000?ooo`3oool00P3oool0103MgMd000000000003<c<`;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`0309VIV@0R8R80k^k^07P0
oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00/000000?ooo`3oool0oooo0;^k^`14A4@0c<c<
028R8P3oool04A4A0<c<c0040?ooo`030000003oool0oooo0080oooo00@0k^k^028R8P000000k^k^
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo1P00000<0?ooo`030000
003oool0oooo00`0oooo00<0VIVI028R8P3^k^h0M`3oool006P0oooo00<000000>k^kP3oool01@3o
ool02`000000oooo0?ooo`3oool0k^k^0000003oool000000>k^kP1VIVH0R8R800@0oooo00H00000
0?ooo`3oool0oooo0>k^kP0R8R8207MgM`0303<c<`3oool0oooo00T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0k^k^0000003oool0
6P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<0MgMg06IVIP3oool0
MP3oool006P0oooo00<0EEEE07MgM`3oool01@3oool020000000oooo0?ooo`3oool0IVIV09VIV@3o
ool0<c<c0P2k^k/00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool2
000000P0oooo00<04A4A0000000000000`0000050?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`1gMgL0EEEE0?ooo`020?ooo`@000004P3oool00`0A4A40000000000003
000001@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1e0?ooo`00J03oool00`3M
gMd04A4A0>k^kP050?ooo`030000003oool0oooo00@0oooo00<0IVIV07MgM`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030>k^kP0A4A40gMgM00@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo00D000000;^k^`3oool0VIVI014A4@1g
0?ooo`00J@3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0ZZZZ04A4
A03oool01@3oool200000180oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?oo
o`3oool00P3oool00`1VIVH0MgMg0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04`3oool205EEE@030000003oool0oooo00X0oooo00D0VIVI014A4@0000008R8R0<c<c01g
0?ooo`00/P3oool00`000000oooo0?ooo`2c0?ooo`00[`3oool010000000oooo0?ooo`00002e0?oo
o`00/03oool200000;H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03056 0 L
.03162 0 L
.03279 0 L
.03397 0 L
.03524 0 L
.03642 0 L
.0375 0 L
.03875 0 L
.03946 0 L
.04012 0 L
.04133 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04663 0 L
.04733 0 L
.04797 0 L
.04921 0 L
.05038 0 L
.05164 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06311 0 L
.06381 0 L
.06458 0 L
.06529 0 L
.06657 0 L
.0673 0 L
.06797 0 L
.06923 0 L
.06991 0 L
.07057 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07583 0 L
.07659 0 L
.07728 0 L
.07804 0 L
.07885 0 L
.0801 0 L
.0808 0 L
.08144 0 L
.08219 0 L
.0829 0 L
.08427 0 L
.08544 0 L
.08673 0 L
.08737 0 L
.08807 0 L
.08933 0 L
.09052 0 L
.09177 0 L
.09294 0 L
.09401 0 L
.09527 0 L
.09597 0 L
.09663 0 L
.09779 0 L
.09906 0 L
.09972 0 L
.10046 0 L
.10117 0 L
.10193 0 L
.10265 0 L
.1033 0 L
.10458 0 L
.10575 0 L
.10686 0 L
.10807 0 L
.10938 0 L
.11067 0 L
.11138 0 L
.11204 0 L
.1132 0 L
.11448 0 L
.11567 0 L
.1168 0 L
.11781 0 L
.11891 0 L
.1201 0 L
.12137 0 L
.12245 0 L
Mistroke
.12364 0 L
.1243 0 L
.12502 0 L
.12634 0 L
.12762 0 L
.12881 0 L
.12953 0 L
.13022 0 L
.13149 0 L
.13221 0 L
.13289 0 L
.13359 0 L
.13436 0 L
.13557 0 L
.13687 0 L
.13918 0 L
.14037 0 L
.14166 0 L
.14239 0 L
.14307 0 L
.14371 0 L
.14439 0 L
.14572 0 L
.14696 0 L
.14826 0 L
.14895 0 L
.14968 0 L
.151 0 L
.15225 0 L
.15337 0 L
.15458 0 L
.15592 0 L
.15666 0 L
.15736 0 L
.15871 0 L
.15996 0 L
.16125 0 L
.16199 0 L
.16267 1e-05 L
.16565 1e-05 L
.16691 1e-05 L
.16826 1e-05 L
.16955 1e-05 L
.17072 1e-05 L
.1721 1e-05 L
.17356 1e-05 L
.17612 1e-05 L
.17727 1e-05 L
.17835 1e-05 L
.17959 1e-05 L
Mistroke
.18073 1e-05 L
.18334 2e-05 L
.18577 2e-05 L
.19038 2e-05 L
.19546 3e-05 L
.20041 4e-05 L
.20314 5e-05 L
.20574 6e-05 L
.20811 6e-05 L
.21071 7e-05 L
.21526 9e-05 L
.21749 .0001 L
.21988 .00012 L
.22418 .00015 L
.23445 .00024 L
.23986 .0003 L
.24282 .00033 L
.24426 .00035 L
.24558 .00037 L
.24799 .00043 L
.25058 .0005 L
.25608 .00069 L
.26575 .0011 L
.27051 .00128 L
.27285 .00134 L
.27499 .00141 L
.27724 .0015 L
.27966 .00165 L
.28218 .00184 L
.28482 .00211 L
.28749 .00247 L
.28997 .00287 L
.2956 .00376 L
.29808 .0041 L
.30042 .00435 L
.30172 .00445 L
.30312 .00452 L
.3044 .00457 L
.30558 .00461 L
.30683 .00466 L
.30802 .00472 L
.30908 .0048 L
.31025 .00491 L
.31151 .00506 L
.31285 .00528 L
.31412 .00556 L
.31527 .00589 L
.31751 .00678 L
.31994 .00811 L
.32433 .01121 L
Mistroke
.32704 .01323 L
.32956 .01492 L
.33094 .01566 L
.3322 .01617 L
.33291 .01638 L
.33359 .01653 L
.33431 .01663 L
.33509 .01667 L
.33627 .01662 L
.33758 .01643 L
.33823 .0163 L
.33894 .01614 L
.34022 .01582 L
.34143 .01554 L
.3427 .01531 L
.34378 .0152 L
.34497 .01523 L
.34561 .01533 L
.34629 .01551 L
.34751 .01607 L
.34883 .01703 L
.34957 .01776 L
.35027 .01856 L
.35268 .02218 L
.35526 .02722 L
.35974 .03693 L
.3621 .04141 L
.36329 .04321 L
.36461 .0447 L
.36533 .04527 L
.36611 .04566 L
.36685 .04582 L
.36753 .04579 L
.36885 .04528 L
.36951 .04482 L
.37023 .04417 L
.37281 .04112 L
.37423 .03931 L
.37492 .03849 L
.37557 .03782 L
.37687 .03685 L
.37755 .03661 L
.37828 .03663 L
.37945 .03735 L
.38075 .03932 L
.38195 .04242 L
.38324 .04719 L
.38446 .05305 L
.38557 .05947 L
.39034 .09338 L
Mistroke
.39159 .10222 L
.39295 .11073 L
.39424 .11726 L
.39542 .12159 L
.39653 .12393 L
.39775 .12436 L
.39902 .12235 L
.40021 .11827 L
.40131 .11282 L
.40231 .10669 L
.40456 .09049 L
.40703 .07275 L
.40828 .0655 L
.409 .06219 L
.40966 .05982 L
.41037 .05805 L
.41115 .05715 L
.41182 .0573 L
.41254 .05843 L
.41381 .06302 L
.41453 .06706 L
.4152 .07174 L
.41776 .09655 L
.42008 .1255 L
.42256 .15703 L
.42387 .1716 L
.4246 .17849 L
.42529 .18411 L
.4266 .19195 L
.42779 .19539 L
.42891 .19509 L
.43014 .19074 L
.43143 .18166 L
.43215 .17471 L
.4328 .16736 L
.43527 .13259 L
.43755 .09667 L
.43875 .07939 L
.44001 .06431 L
.44112 .05485 L
.44234 .04949 L
.44345 .04969 L
.44448 .05442 L
.44577 .06643 L
.4465 .07597 L
.44718 .08634 L
.44974 .13534 L
.45221 .18679 L
.45342 .20866 L
.45452 .22465 L
Mistroke
.45572 .23611 L
.457 .24041 L
.45768 .23907 L
.45841 .23476 L
.4591 .22802 L
.45974 .21958 L
.46114 .19472 L
.46242 .16648 L
.46528 .09705 L
.4676 .04939 L
.46891 .02961 L
.47014 .01631 L
.47144 .00722 L
.47262 .00255 L
.47328 .00112 L
.47399 .00027 L
.47529 .0001 L
.47639 .00078 L
.47761 .00191 L
.48007 .00423 L
.48117 .00506 L
.48236 .00579 L
.4845 .00674 L
.48724 .00759 L
.48858 .00802 L
.48979 .00853 L
.49108 .00927 L
.49178 .00982 L
.49245 .01045 L
.49384 .01221 L
.49536 .01491 L
.49656 .0177 L
.49787 .02146 L
.50054 .03109 L
.50532 .05242 L
.50781 .06319 L
.50912 .06806 L
.51052 .07228 L
.51122 .07391 L
.51187 .07514 L
.51309 .07655 L
.51423 .07677 L
.51547 .07575 L
.51659 .07373 L
.51782 .07037 L
.5191 .06576 L
.5203 .06063 L
.52475 .03868 L
.52605 .03273 L
.52746 .02718 L
Mistroke
.52879 .02307 L
.53002 .02036 L
.53113 .01879 L
.53236 .01792 L
.53363 .01773 L
.53483 .01799 L
.53999 .0198 L
.54563 .02134 L
.55548 .02324 L
.56584 .02468 L
.57041 .02548 L
.57536 .0261 L
.57763 .02637 L
.57888 .02651 L
.58004 .02663 L
.58103 .02671 L
.58209 .02677 L
.58327 .0268 L
.58435 .02681 L
.58566 .02682 L
.58687 .02682 L
.58758 .02682 L
.58821 .02682 L
.58894 .02683 L
.58963 .02682 L
.59088 .02681 L
.59204 .02678 L
.5933 .02672 L
.59464 .02663 L
.59915 .02633 L
.60034 .02626 L
.60163 .02617 L
.60398 .02594 L
.60669 .0256 L
.60916 .02528 L
.61398 .02452 L
.61968 .02331 L
.62494 .02207 L
.66428 .0117 L
.68404 .00729 L
.70211 .0043 L
.71206 .00308 L
.72152 .0022 L
.7315 .00151 L
.73711 .00121 L
.7424 .00098 L
.74735 .0008 L
.75271 .00063 L
.76207 .00041 L
.76738 .00032 L
Mistroke
.77299 .00025 L
.77778 .0002 L
.78304 .00015 L
.78555 .00013 L
.78828 .00012 L
.79324 9e-05 L
.79766 7e-05 L
.80254 6e-05 L
.80781 4e-05 L
.8105 4e-05 L
.81192 3e-05 L
.8134 3e-05 L
.81611 3e-05 L
.81859 2e-05 L
.82092 2e-05 L
.82215 2e-05 L
.82346 2e-05 L
.82479 2e-05 L
.82603 2e-05 L
.82846 1e-05 L
.833 1e-05 L
.83785 1e-05 L
.83918 1e-05 L
.83993 1e-05 L
.84061 1e-05 L
.84319 1e-05 L
.85209 0 L
.85332 0 L
.85465 0 L
.8559 0 L
.85706 0 L
.86156 0 L
.86636 0 L
.86763 0 L
.86834 0 L
.86898 0 L
.87016 0 L
.87143 0 L
.87259 0 L
.87367 0 L
.8747 0 L
.87579 0 L
.87697 0 L
.87807 0 L
.87928 0 L
.88058 0 L
.88189 0 L
.8831 0 L
.8838 0 L
.88443 0 L
Mistroke
.88517 0 L
.88586 0 L
.88715 0 L
.8878 0 L
.88852 0 L
.8893 0 L
.89002 0 L
.89068 0 L
.8914 0 L
.89269 0 L
.8939 0 L
.89499 0 L
.89619 0 L
.89748 0 L
.89818 0 L
.89885 0 L
.90004 0 L
.90132 0 L
.90257 0 L
.90371 0 L
.90502 0 L
.90626 0 L
.90741 0 L
.90847 0 L
.90964 0 L
.91087 0 L
.91211 0 L
.9128 0 L
.91344 0 L
.91469 0 L
.91585 0 L
.9165 0 L
.91719 0 L
.91796 0 L
.91866 0 L
.91932 0 L
.92003 0 L
.92133 0 L
.92265 0 L
.92388 0 L
.92458 0 L
.92523 0 L
.92598 0 L
.92667 0 L
.92735 0 L
.92806 0 L
.92878 0 L
.92957 0 L
.93025 0 L
.93099 0 L
Mistroke
.93168 0 L
.93231 0 L
.93353 0 L
.93467 0 L
.93591 0 L
.93661 0 L
.93724 0 L
.93852 0 L
.93924 0 L
.9399 0 L
.94113 0 L
.94242 0 L
.9435 0 L
.94468 0 L
.94579 0 L
.94682 0 L
.94784 0 L
.94876 0 L
.94983 0 L
.95083 0 L
.95194 0 L
.9531 0 L
.95409 0 L
.95518 0 L
.95635 0 L
.95761 0 L
.95878 0 L
.95987 0 L
.96089 0 L
.96197 0 L
.96306 0 L
.96426 0 L
.96529 0 L
.9664 0 L
.96745 0 L
.96841 0 L
.9694 0 L
.97032 0 L
.97133 0 L
.9724 0 L
.97342 0 L
.97439 0 L
.97525 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool:000000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
0002000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo3`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3o
ool01@3^k^h08R8R07MgM`1gMgL0<c<c01H0oooo000K0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool08@3oool6000000H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`03000000<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`@000009@3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo0P0000020?ooo`8000005@3o
ool007D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo
0000003oool0<P3oool3000008H0oooo001f0?ooo`800000:P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0000002l0oooo100000290?ooo`00M`3oool7000002@0oooo00<000000?ooo`3o
ool01@3oool2000002/0oooo1000002=0?ooo`00O@3oool2000002<0oooo00<000000?ooo`3oool0
1@3oool2000000P0oooo1@00000J0?ooo`@00000T@3oool007h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`050?ooo`800000203oool00`000000oooo0?ooo`020?ooo`H000003`3o
ool5000009D0oooo001o0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3oool2
000000L0oooo00<000000?ooo`3oool02@3oool?000009X0oooo001o0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0;80oooo00200?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool2000000H0
oooo00<000000?ooo`3oool0/P3oool00840oooo00<000000?ooo`3oool00P3oool2000001X0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo
00210?ooo`070000003oool0oooo0?ooo`000000oooo0000000J0?ooo`030000003oool0oooo00H0
oooo0P0000050?ooo`030000003oool0oooo0;<0oooo00210?ooo`8000000P3oool00`000000oooo
0000000I0?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo0;<0oooo
00220?ooo`<000000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo0P00
00050?ooo`030000003oool0oooo0;<0oooo00280?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool0/`3oool008P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`2d0?oo
o`00R03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`2d0?ooo`00
R03oool00`000000oooo0?ooo`050?ooo`8000001`3oool2000000H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo000000030?ooo`030000003oool0oooo0;@0oooo00280?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00L0oooo0`0000030?ooo`030000003oool0oooo0;@0oooo00280?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000001`3oool00`000000oooo000000050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`2d0?ooo`00R@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000L0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`070?ooo`060000003oool0oooo0000003oool00000]`3oool008T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000070?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool01`3oool01P000000oooo0?ooo`000000oooo00000;L0oooo00290?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`00002g0?ooo`00R@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000H0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0;X0oooo00290?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`0000001P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0^P3oool008X0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0;X0oooo002:0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`2j0?ooo`00RP3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo0P00002k
0?ooo`00RP3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^P3o
ool008X0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;X0oooo
002:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^P3oool008X0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2j0?ooo`00R`3oool00`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0;X0oooo002;0?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2j0?ooo`00R`3oool00`000000oooo000000020?ooo`05
0>k^kP0c<c<000000000003^k^h00P3oool00`000000oooo0?ooo`02028R8P040000003oool0oooo
0?ooo`D000001P3oool00`000000oooo0?ooo`2j0?ooo`00R`3oool00`000000oooo000000020?oo
o`0507MgM`2IVIT0oooo0000001gMgL00P3oool00`000000oooo0?ooo`02028R8P090000003oool0
oooo0?ooo`0000008R8R0>k^kP3oool0A4A400H0oooo00<000000?ooo`3oool0^P3oool008/0oooo
0P0000030?ooo`05014A4@3oool0oooo0000000A4A400P3oool00`000000oooo0?ooo`020?ooo`08
0000003oool0oooo0?ooo`000000VIVI028R8P3^k^h70?ooo`030000003oool0oooo0;X0oooo002<
0?ooo`050000003oool0oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3o
ool02@000000oooo0?ooo`3oool000000?ooo`2IVIT08R8R0>k^kP060?ooo`<00000^P3oool00900
oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`0307MgM`1VIVH0oooo00D0oooo00<000000?ooo`3oool0^P3oool00900
oooo00D04A4A0?ooo`3oool00000014A4@020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^P3oool0
0900oooo00D0MgMg09VIV@3oool0000007MgM`020?ooo`030000003oool0oooo0080oooo00T00000
0?ooo`3oool0oooo0000002k^k/0oooo09VIV@0A4A401P3oool00`000000oooo0?ooo`2j0?ooo`00
T03oool01@3^k^h0<c<c000000000000k^k^0080oooo00<000000?ooo`3oool00P3oool02@000000
oooo0?ooo`3oool00000014A4@0000008R8R0<c<c0060?ooo`030000003oool0oooo0;X0oooo002C
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000X0oooo
00<000000?ooo`3oool0^P3oool009@0oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0^P3oool009@0oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0^P3oool009@0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool0^P3oool009@0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3o
ool0000000X0oooo0P00002k0?ooo`00U03oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2j0?ooo`00U03oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2j0?ooo`00
U03oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool0^P3oool009@0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0;X0oooo002D0?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`2j0?ooo`00U03oool00`000000oooo00000006
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0^P3oool009@0oooo00<00000
0?ooo`0000001P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0;X0oooo002D
0?ooo`030000003oool0000000H0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`2j0?ooo`00U03oool00`000000oooo000000060?ooo`030000003oool0000000/0oooo0P00002k
0?ooo`00U03oool00`000000oooo000000060?ooo`030000003oool0000000/0oooo00<000000?oo
o`3oool0^P3oool009D0oooo0P0000060?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool0^P3oool009D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo0;X0oooo002M0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0^P3o
ool009d0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`2j0?ooo`00W@3oool00`00
0000oooo0000000;0?ooo`030000003oool0oooo0;X0oooo002M0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool0^P3oool009d0oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`2j0?ooo`00W@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo0;X0oooo002M
0?ooo`030000003oool0000000/0oooo0P00002k0?ooo`00W@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo0;X0oooo002M0?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool0^P3oool009d0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`2j0?ooo`00W@3o
ool00`000000oooo0000000;0?ooo`030000003oool0oooo0;X0oooo002N0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R0P3oool010000000oooo0?ooo`3oool200000003014A4@3oool0oooo00@0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R0P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0^P3o
ool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001P3oool00`000000oooo0?oo
o`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool00000
1`3oool300000;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE
0?ooo`0000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A
4A40303oool00`1gMgL0c<c<000000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000070?ooo`030000003oool0oooo0;X0
oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`060?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0
oooo00D0k^k^03<c<`0000004A4A0<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P06
0?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool0
1@000000oooo0?ooo`3oool0000000H0oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3o
ool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A4A40c<c<00H0
oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`03
05EEE@28R8P0oooo00P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI00P0oooo00<000000?ooo`3oool0^P3oool00900oooo
00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@H0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool2
00000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c
<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103o
ool01@0R8R80VIVI0?ooo`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0
4A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3o
ool0VIVI03<c<`060?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?oo
o`050<c<c000000000000000003<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A
4A40oooo0?ooo`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@060?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?oo
o`2k^k/0000000H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c
0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01P3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`03
0000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
X@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool00:<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2j0?ooo`00X`3oool00`000000oooo0?ooo`05
0?ooo`<00000^P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3o
ool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3o
ool00:40oooo0P1EEED00`000000oooo0?ooo`320?ooo`00o`3ooomY0?ooo`00J@3oool00`1gMgL0
IVIV0?ooo`040?ooo`030000003oool0oooo0080oooo00<0^k^k03<c<`3oool01`3oool2000000/0
oooo00<04A4A0;^k^`3oool0303oool2000000L0oooo00<000000?ooo`3oool00P3oool00`1VIVH0
MgMg0?ooo`0<0?ooo`03014A4@2k^k/0oooo0:d0oooo001X0?ooo`030=gMg@0A4A40k^k^00D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo
0P0c<c<>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`3^k^h04A4A
0=gMg@0<0?ooo`80<c<c[P3oool006P0oooo00<0EEEE09VIV@3oool01@3oool01P000000oooo0?oo
o`3oool0VIVI014A4@80000000<0ZZZZ0?ooo`3oool0103oool010000000oooo0?ooo`3oool20000
0080oooo0P0000030?ooo`0308R8R0000000ZZZZ00@0oooo00D0VIVI000000000000A4A40;^k^`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`28R8P0IVIV0?ooo`0;
0?ooo`0308R8R0000000ZZZZ00`0oooo00D0VIVI000000000000A4A40;^k^`0A0?ooo`@0000000<0
4A4A0?ooo`3oool00P3oool2028R8PH0oooo0P0000000`0A4A40oooo0?ooo`1e0?ooo`00J03oool0
0`000000oooo0?ooo`050?ooo`0:0000003oool0oooo0?ooo`000000ZZZZ05EEE@28R8P0EEEE0;^k
^`D0oooo00X000000?ooo`3oool0oooo0>k^kP0R8R80R8R80<c<c0000000c<c<0`3oool00`3<c<`0
0000014A4@040?ooo`05014A4@2k^k/0k^k^07MgM`0A4A40103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<0k^k^0000003oool02`3oool00`3<c<`00000014A4@0<0?oo
o`06014A4@2k^k/0k^k^07MgM`0A4A40oooo1P00000<0?ooo`030000003oool0oooo00@0oooo0P0R
8R870?ooo`030000003oool0oooo07H0oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00X00000
0?ooo`3oool0oooo03<c<`3^k^h0VIVI05EEE@3MgMd04A4A1@3oool00`000000oooo0?ooo`020?oo
o`040=gMg@00000000000<c<c0/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00X0oooo1@00001g0?ooo`00J03oool00`0c<c<0oooo0?ooo`050?oo
o`0;0000003oool0oooo0?ooo`2k^k/0A4A40<c<c00R8R80oooo014A4@3<c<`0103oool00`000000
oooo0?ooo`020?ooo`040>k^kP0R8R8000000>k^kP/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`030?ooo`H00000303oool00`000000oooo0?ooo`0:0?ooo`0404A4A03MgMd0oooo
000007P0oooo001X0?ooo`030000003^k^h0oooo00D0oooo00/000000?ooo`3oool0oooo0>k^kP00
0000oooo0000003^k^h0IVIV08R8R0040?ooo`060000003oool0oooo0?ooo`3^k^h08R8R0P1gMgL0
0`0c<c<0oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030>k^kP000000oooo01X0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0:0?ooo`040=gMg@1EEED0oooo000007P0oooo001X0?ooo`0305EEE@1gMgL0
oooo00D0oooo00P000000?ooo`3oool0oooo06IVIP2IVIT0oooo03<c<`80^k^k00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool200000080oooo0P0000080?ooo`03014A4@0000000000
00<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0MgMg05EE
E@3oool00P3oool400000180oooo00<04A4A0000000000000`00000D0?ooo`030000003oool0oooo
00/0oooo00<0MgMg0<c<c0000000N03oool006P0oooo00<0gMgM014A4@3^k^h01@3oool00`000000
oooo0?ooo`040?ooo`0306IVIP1gMgL0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`3^k^h0
4A4A0=gMg@040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0;0?ooo`030>k^kP14A4@0000007P0oooo001Y0?ooo`0307MgM`1VIVH0oooo00@0oooo
00<000000?ooo`3oool0103oool00`2ZZZX0A4A40?ooo`050?ooo`8000004P3oool00`000000oooo
0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`0306IVIP1gMgL0oooo00D0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`80EEEE00<000000?ooo`3oool0
303oool00`1gMgL000000?ooo`1g0?ooo`00/P3oool00`000000oooo0?ooo`2c0?ooo`00[`3oool0
10000000oooo0?ooo`00002e0?ooo`00/03oool200000;H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.03279 0 L
.03405 0 L
.03477 0 L
.03543 0 L
.03665 0 L
.03793 0 L
.03908 0 L
.04016 0 L
.04144 0 L
.04262 0 L
.04384 0 L
.04501 0 L
.04624 0 L
.04693 0 L
.04758 0 L
.04827 0 L
.04892 0 L
.05014 0 L
.05146 0 L
.0522 0 L
.05288 0 L
.05395 0 L
.0551 0 L
.05636 0 L
.05753 0 L
.05885 0 L
.0601 0 L
.06122 0 L
.06244 0 L
.0637 0 L
.0644 0 L
.06505 0 L
.06624 0 L
.06749 0 L
.06815 0 L
.06887 0 L
.07015 0 L
.07093 0 L
.07167 0 L
.07233 0 L
.07306 0 L
.07376 0 L
.07442 0 L
.07512 0 L
.07587 0 L
.07657 0 L
.07723 0 L
.07847 0 L
.07917 0 L
Mistroke
.07992 0 L
.08127 0 L
.0821 0 L
.08288 0 L
.08358 0 L
.08433 0 L
.08551 0 L
.08678 0 L
.08751 0 L
.08817 0 L
.08947 0 L
.09011 0 L
.0908 0 L
.09155 0 L
.09225 0 L
.0935 0 L
.09422 0 L
.09488 0 L
.09607 0 L
.09732 0 L
.09839 0 L
.09955 0 L
.10081 0 L
.10152 0 L
.10216 0 L
.1034 0 L
.10458 0 L
.10574 0 L
.10698 1e-05 L
.10806 1e-05 L
.10922 1e-05 L
.10994 1e-05 L
.11059 1e-05 L
.11189 1e-05 L
.11315 1e-05 L
.11433 1e-05 L
.11547 1e-05 L
.1167 1e-05 L
.11795 1e-05 L
.11866 1e-05 L
.11932 1e-05 L
.11997 1e-05 L
.12067 1e-05 L
.12141 1e-05 L
.12209 1e-05 L
.1234 1e-05 L
.12463 1e-05 L
.12681 2e-05 L
.12788 2e-05 L
.12887 2e-05 L
Mistroke
.13001 2e-05 L
.13125 2e-05 L
.1323 2e-05 L
.13342 2e-05 L
.13407 2e-05 L
.13477 2e-05 L
.13604 3e-05 L
.13718 3e-05 L
.13842 3e-05 L
.1396 3e-05 L
.14086 3e-05 L
.14202 3e-05 L
.1431 3e-05 L
.14818 5e-05 L
.14925 5e-05 L
.15039 5e-05 L
.15165 5e-05 L
.1528 5e-05 L
.15535 6e-05 L
.15777 7e-05 L
.15902 7e-05 L
.16033 8e-05 L
.16102 8e-05 L
.16177 8e-05 L
.16309 9e-05 L
.16761 .00011 L
.16876 .00011 L
.16984 .00011 L
.17081 .00012 L
.17186 .00012 L
.17428 .00014 L
.17687 .00016 L
.17812 .00016 L
.17931 .00017 L
.18037 .00018 L
.18153 .00019 L
.18389 .00021 L
.18643 .00024 L
.18883 .00026 L
.19101 .00028 L
.19363 .00033 L
.19641 .00037 L
.20142 .00045 L
.20664 .00057 L
.21227 .0007 L
.22247 .00105 L
.23282 .00152 L
.24246 .00198 L
.24773 .00229 L
.25003 .00244 L
Mistroke
.25252 .00266 L
.25526 .00297 L
.25785 .00329 L
.26355 .00426 L
.28337 .00857 L
.28819 .00953 L
.29085 .01011 L
.29338 .01082 L
.29635 .01196 L
.29907 .01317 L
.3044 .0159 L
.30933 .01856 L
.31398 .0204 L
.31934 .02201 L
.3217 .02259 L
.32299 .02294 L
.3242 .02334 L
.32525 .02378 L
.32639 .02439 L
.32879 .02618 L
.33101 .02849 L
.33303 .03122 L
.33538 .03524 L
.33793 .04071 L
.34258 .05223 L
.34491 .05765 L
.34743 .06257 L
.34858 .0644 L
.3498 .06595 L
.35084 .06694 L
.35197 .06763 L
.35267 .06784 L
.35334 .0679 L
.35457 .06765 L
.35526 .06732 L
.3559 .06692 L
.35735 .06578 L
.35993 .06345 L
.36119 .06246 L
.36235 .06177 L
.36355 .06134 L
.36469 .06127 L
.36589 .06165 L
.3672 .06267 L
.36791 .06351 L
.36855 .06445 L
.36998 .06724 L
.3713 .07061 L
.37255 .07438 L
.3777 .09306 L
Mistroke
.38043 .10241 L
.38193 .10674 L
.38335 .11005 L
.38462 .11217 L
.38534 .11296 L
.386 .11341 L
.38717 .11349 L
.38841 .11258 L
.38957 .11083 L
.39066 .10849 L
.39313 .10131 L
.39556 .09327 L
.39688 .08916 L
.39811 .08589 L
.39881 .08437 L
.39944 .08325 L
.40015 .08237 L
.4009 .08189 L
.40222 .0824 L
.40346 .08467 L
.40453 .08811 L
.4057 .09352 L
.40808 .10903 L
.41233 .14439 L
.41473 .16167 L
.41542 .16553 L
.41607 .16858 L
.4173 .17247 L
.41845 .17367 L
.41952 .17243 L
.42069 .16836 L
.42194 .16097 L
.42649 .11332 L
.42898 .08223 L
.43129 .05666 L
.4326 .04493 L
.4338 .03644 L
.43444 .03283 L
.43513 .02965 L
.43586 .02713 L
.43655 .02552 L
.43777 .02446 L
.43906 .02559 L
.44016 .02812 L
.44138 .03219 L
.44586 .05197 L
.44822 .06161 L
.45075 .07013 L
.45317 .07684 L
.45431 .07943 L
Mistroke
.45536 .08132 L
.45642 .08259 L
.45757 .08298 L
.45858 .08227 L
.45965 .08027 L
.46085 .07635 L
.46215 .07022 L
.46448 .0552 L
.46721 .03553 L
.46855 .02683 L
.46979 .02 L
.47089 .01502 L
.47211 .01073 L
.47334 .00753 L
.47464 .00512 L
.47574 .00367 L
.47692 .00255 L
.47804 .00178 L
.47906 .00125 L
.48028 .0008 L
.48158 .0005 L
.48281 .00041 L
.48392 .00052 L
.48523 .00091 L
.48597 .00128 L
.48665 .00173 L
.48791 .00286 L
.48923 .00452 L
.49051 .00659 L
.49187 .00937 L
.49433 .01578 L
.49994 .03448 L
.50249 .04283 L
.50389 .04688 L
.5052 .05021 L
.50643 .05279 L
.50708 .05392 L
.50776 .05492 L
.50897 .05617 L
.51008 .05669 L
.51139 .05648 L
.51213 .05596 L
.5128 .05524 L
.51411 .05319 L
.51535 .05053 L
.51812 .04261 L
.52112 .03246 L
.52374 .02384 L
.52619 .01702 L
.52743 .01431 L
Mistroke
.52875 .01204 L
.52951 .01107 L
.53023 .01036 L
.53087 .0099 L
.53157 .00956 L
.53284 .00934 L
.53399 .00946 L
.53463 .0096 L
.53532 .00979 L
.53658 .01015 L
.539 .01069 L
.54123 .01105 L
.56163 .01523 L
.58069 .01966 L
.599 .02278 L
.60427 .02346 L
.60687 .02373 L
.60927 .02404 L
.61039 .02416 L
.61144 .02424 L
.61254 .0243 L
.61375 .02434 L
.6149 .02437 L
.6161 .02441 L
.61742 .02449 L
.61864 .02457 L
.61987 .02466 L
.62052 .0247 L
.6212 .02473 L
.62247 .02477 L
.62363 .02477 L
.62475 .02477 L
.62579 .02476 L
.62694 .02478 L
.62817 .02481 L
.62948 .02486 L
.63016 .02488 L
.6309 .0249 L
.63161 .0249 L
.63224 .02489 L
.63349 .02485 L
.6347 .02479 L
.636 .02471 L
.63836 .02459 L
.63952 .02455 L
.64077 .02449 L
.64194 .02441 L
.64301 .02431 L
.64536 .02402 L
.64793 .02369 L
Mistroke
.65672 .02247 L
.67583 .01892 L
.69659 .01416 L
.716 .01004 L
.7374 .00621 L
.74716 .00486 L
.75768 .00363 L
.76753 .0027 L
.7767 .00201 L
.78628 .00146 L
.79676 .00102 L
.80697 .00071 L
.81264 .00056 L
.81786 .00046 L
.82275 .00038 L
.82812 .0003 L
.83352 .00024 L
.83923 .00019 L
.84426 .00015 L
.84965 .00012 L
.85939 8e-05 L
.86194 7e-05 L
.86334 7e-05 L
.86466 6e-05 L
.86589 6e-05 L
.86722 6e-05 L
.86953 5e-05 L
.87491 4e-05 L
.87633 4e-05 L
.87785 4e-05 L
.87926 3e-05 L
.88059 3e-05 L
.88184 3e-05 L
.88255 3e-05 L
.88321 3e-05 L
.88444 3e-05 L
.88559 2e-05 L
.88685 2e-05 L
.88825 2e-05 L
.88894 2e-05 L
.88969 2e-05 L
.89041 2e-05 L
.89107 2e-05 L
.89224 2e-05 L
.89349 2e-05 L
.89465 2e-05 L
.89571 1e-05 L
.90069 1e-05 L
.90557 1e-05 L
.90675 1e-05 L
Mistroke
.90802 1e-05 L
.90875 1e-05 L
.90941 1e-05 L
.91072 1e-05 L
.91189 1e-05 L
.91298 1e-05 L
.91416 0 L
.91545 0 L
.91657 0 L
.91763 0 L
.91874 0 L
.91994 0 L
.92112 0 L
.92241 0 L
.92362 0 L
.92474 0 L
.92605 0 L
.92677 0 L
.92743 0 L
.9286 0 L
.92988 0 L
.93055 0 L
.93127 0 L
.93196 0 L
.9326 0 L
.93333 0 L
.93412 0 L
.93485 0 L
.93551 0 L
.93681 0 L
.93754 0 L
.93821 0 L
.93944 0 L
.94076 0 L
.94184 0 L
.94283 0 L
.94383 0 L
.94476 0 L
.94584 0 L
.94702 0 L
.94915 0 L
.95014 0 L
.9512 0 L
.95236 0 L
.95345 0 L
.95802 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo300000020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo300000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`050>k^kP0R8R80MgMg07MgM`0c<c<05P3oool001/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0H0?ooo`<000004P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;`3oool00`000000oooo
0?ooo`0B0?ooo`P000004`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo
0P0000020?ooo`8000005@3oool006T0oooo1000000f0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000203oool400000340oooo1`00001h0?ooo`00K@3oool3000003<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000070?ooo`8000000P3oool5000002T0oooo1000001o
0?ooo`00L03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`060?ooo`H00000803oool3000008<0oooo001a0?ooo`<0
0000;P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0303oool5000001H0oooo1@0000260?ooo`00M03oool3000002/0oooo00<000000?ooo`3oool0
1@3oool2000000H0oooo00<000000?ooo`3oool04P3oool7000000T0oooo1P00002;0?ooo`00MP3o
ool200000200oooo0P0000070?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000003o
ool0oooo01P0oooo2P00002A0?ooo`00N03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool0]03oool0
07P0oooo00<000000?ooo`3oool0703oool00`000000oooo000000070?ooo`030000003oool0oooo
00L0oooo0P0000040?ooo`030000003oool0oooo0;@0oooo001i0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0]03oool007X0oooo00<000000?ooo`3oool06P3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2e0?ooo`00NP3oool00`000000oooo0?ooo`0J0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool01`3oool2000000<0oooo00<000000?ooo`3oool0]@3oool007X0oooo
00<000000?ooo`3oool06P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0
oooo0P0000030?ooo`030000003oool0oooo0;D0oooo001k0?ooo`030000003oool0oooo01T0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`2e0?ooo`00N`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`050000
003oool000000?ooo`000000^03oool007/0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0000000200000;P0oooo001l0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^P3o
ool007d0oooo00@000000?ooo`3oool0oooo0`00000B0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`800000^`3oool007d0oooo10000002
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0^P3oool007h0oooo0P0000040?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0^P3oool008@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`2j
0?ooo`00Q03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`2j0?ooo`00Q03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`2j0?ooo`00
Q@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool2000000`0oooo00<000000?ooo`3oool0^P3oool008D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0^P3o
ool008D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0^P3oool008H0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0180oooo0P00002k0?ooo`00QP3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`2j0?ooo`00Q`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;X0oooo00270?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0^P3oool008L0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2j
0?ooo`00R03oool00`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`2j0?ooo`00R03oool3000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;X0oooo002?0?ooo`070000
003^k^h0<c<c0000000c<c<0k^k^000000040?ooo`808R8R103oool5000000H0oooo00<000000?oo
o`3oool0^P3oool008l0oooo00L0000007MgM`2IVIT0oooo09VIV@1gMgL0000000@0oooo0P0R8R84
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@01P3oool00`000000oooo0?ooo`2j0?ooo`00S`3oool0
0`0000004A4A0?ooo`020?ooo`03014A4@000000oooo00X0oooo00<0VIVI028R8P3^k^h01`3oool0
0`000000oooo0?ooo`2j0?ooo`00S`3oool2000000<0oooo0P00000<0?ooo`0309VIV@0R8R80k^k^
00H0oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000h0oooo00<0MgMg06IV
IP3oool01@3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000
VIVI0?ooo`2IVIT0000000/0oooo00D000000;^k^`3oool0VIVI014A4@060?ooo`030000003oool0
oooo0;X0oooo002@0?ooo`050000000c<c<0000003<c<`0000002`3oool01@2IVIT04A4A0000000R
8R80c<c<00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D000000?ooo`3oool0oooo0000
000F0?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000005P3o
ool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000001H0oooo00<0
00000?ooo`3oool0^P3oool00900oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?oo
o`2j0?ooo`00T@3oool00`000000oooo0000000G0?ooo`800000^`3oool00940oooo00<000000?oo
o`0000005`3oool00`000000oooo0?ooo`2j0?ooo`00T@3oool00`000000oooo0000000G0?ooo`03
0000003oool0oooo0;X0oooo002A0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool0
^P3oool00980oooo0P00000G0?ooo`030000003oool0oooo0;X0oooo002B0?ooo`8000005`3oool0
0`000000oooo0?ooo`2j0?ooo`00TP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00
Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00T03oool0
1@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3oool0103o
ool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R
8R870?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A
0?ooo`3oool0oooo014A4@0;0?ooo`D000001P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool0
1@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gMg@3oool000001`3oool300000;X0oooo
002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool0103MgMd0EEEE0?ooo`0000070?ooo`03
0000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`1gMgL0
c<c<000000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0303oool00`3^k^h0A4A4000000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?ooo`060?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`80
0000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?oo
o`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8P@0oooo00D0k^k^03<c<`00
00004A4A0<c<c0060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0VIVI028R8P060?ooo`030000003oool0
oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01@000000oooo0?ooo`3o
ool0000000H0oooo0`00002j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
000009VIV@3oool0VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A4A40c<c<00H0oooo00<000000?ooo`3o
ool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`0305EEE@28R8P0oooo00P0
oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`03
0=gMg@0A4A40VIVI00P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000
<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@H0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<00H0oooo00<000000?ooo`3oool0^P3o
ool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?oo
o`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo
014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`2j0?ooo`00
T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`060?oo
o`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050<c<c00000000000
0000003<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@0A4A40oooo0?ooo`3oool0
4A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@060?ooo`030000003oool0oooo0;X0oooo002@
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2k^k/0000000H0oooo
00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZ
ZP0A4A400000014A4@2ZZZX01P3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00X@3oool400000003014A
4@3oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool00:<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2j0?ooo`00X`3oool00`000000oooo0?ooo`050?ooo`<00000^P3oool0
0:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo
00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:40oooo0P1EEED0
0`000000oooo0?ooo`320?ooo`00o`3ooomY0?ooo`00J@3oool00`1gMgL0IVIV0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<0^k^k03<c<`3oool01`3oool2000000/0oooo00<04A4A0;^k^`3o
ool0303oool2000000L0oooo00<000000?ooo`3oool00P3oool00`1VIVH0MgMg0?ooo`0<0?ooo`03
014A4@2k^k/0oooo0:d0oooo001X0?ooo`030=gMg@0A4A40k^k^00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo0P0c<c<>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`3^k^h04A4A0=gMg@0<0?ooo`80<c<c
[P3oool006P0oooo00<0EEEE09VIV@3oool01@3oool01P000000oooo0?ooo`3oool0VIVI014A4@80
000000<0ZZZZ0?ooo`3oool0103oool010000000oooo0?ooo`3oool200000080oooo0P0000030?oo
o`0308R8R0000000ZZZZ00@0oooo00D0VIVI000000000000A4A40;^k^`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool00`28R8P0IVIV0?ooo`0;0?ooo`0308R8R0000000
ZZZZ00`0oooo00D0VIVI000000000000A4A40;^k^`0A0?ooo`@0000000<04A4A0?ooo`3oool00P3o
ool2028R8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c01g0?ooo`00J03oool00`000000oooo0?oo
o`050?ooo`0:0000003oool0oooo0?ooo`000000ZZZZ05EEE@28R8P0EEEE0;^k^`D0oooo00X00000
0?ooo`3oool0oooo0>k^kP0R8R80R8R80<c<c0000000c<c<0`3oool00`3<c<`00000014A4@040?oo
o`05014A4@2k^k/0k^k^07MgM`0A4A40103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<0k^k^0000003oool02`3oool00`3<c<`00000014A4@0<0?ooo`06014A4@2k^k/0
k^k^07MgM`0A4A40oooo1P00000<0?ooo`030000003oool0oooo00@0oooo0P0R8R840?ooo`0505EE
E@1gMgL0oooo09VIV@0R8R80M`3oool006P0oooo00<0<c<c0?ooo`3oool01@3oool02P000000oooo
0?ooo`3oool0<c<c0>k^kP2IVIT0EEEE0=gMg@0A4A450?ooo`030000003oool0oooo0080oooo00@0
gMgM000000000000c<c<2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000007L0oooo001X0?ooo`0303<c
<`3oool0oooo00D0oooo00/000000?ooo`3oool0oooo0;^k^`14A4@0c<c<028R8P3oool04A4A0<c<
c0040?ooo`030000003oool0oooo0080oooo00@0k^k^028R8P000000k^k^2`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00<0oooo1P00000<0?ooo`030000003oool0oooo00X0oooo
00D0000009VIV@3oool0VIVI028R8P1g0?ooo`00J03oool00`000000k^k^0?ooo`050?ooo`0;0000
003oool0oooo0?ooo`3^k^h000000?ooo`000000k^k^06IVIP28R8P0103oool01P000000oooo0?oo
o`3oool0k^k^028R8P80MgMg00<0<c<c0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`3^k^h000000?ooo`0J0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool01@000000EEEE0000000A4A40c<c<
07L0oooo001X0?ooo`0305EEE@1gMgL0oooo00D0oooo00P000000?ooo`3oool0oooo06IVIP2IVIT0
oooo03<c<`80^k^k00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo
0P0000080?ooo`03014A4@000000000000<000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<0MgMg05EEE@3oool00P3oool400000180oooo00<04A4A000000000000
0`00000D0?ooo`030000003oool0oooo00X0oooo00<0EEEE08R8R03oool0N@3oool006P0oooo00<0
gMgM014A4@3^k^h01@3oool00`000000oooo0?ooo`040?ooo`0306IVIP1gMgL0oooo00D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`3^k^h04A4A0=gMg@040?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030=gMg@0A4A40VIVI07T0oooo001Y
0?ooo`0307MgM`1VIVH0oooo00@0oooo00<000000?ooo`3oool0103oool00`2ZZZX0A4A40?ooo`05
0?ooo`8000004P3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?ooo`02
0?ooo`0306IVIP1gMgL0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`80EEEE00<000000?ooo`3oool02`3oool0103<c<`0A4A40000000A4A5g0?ooo`00/P3oool0
0`000000oooo0?ooo`2c0?ooo`00[`3oool010000000oooo0?ooo`00002e0?ooo`00/03oool20000
0;H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 2e-05 m
.02499 2e-05 L
.02605 1e-05 L
.02729 1e-05 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 1e-05 L
.03279 1e-05 L
.03395 1e-05 L
.0352 1e-05 L
.03638 1e-05 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 1e-05 L
.04262 1e-05 L
.04327 1e-05 L
.04396 1e-05 L
.04519 1e-05 L
.04588 1e-05 L
.04652 1e-05 L
.04722 0 L
.04797 0 L
.04862 0 L
.04933 0 L
.05061 1e-05 L
.05175 1e-05 L
.05302 2e-05 L
.05424 1e-05 L
.05539 1e-05 L
.05671 0 L
.05791 0 L
.05898 0 L
.06009 1e-05 L
.06122 1e-05 L
.06244 2e-05 L
.06315 2e-05 L
.0638 2e-05 L
.06509 1e-05 L
.06625 1e-05 L
.06748 1e-05 L
.06812 1e-05 L
.06881 1e-05 L
.07005 2e-05 L
.0708 2e-05 L
.07152 2e-05 L
.07217 2e-05 L
.07287 2e-05 L
Mistroke
.07415 2e-05 L
.07531 2e-05 L
.07595 2e-05 L
.07664 1e-05 L
.0779 2e-05 L
.07908 2e-05 L
.08033 3e-05 L
.0814 3e-05 L
.08257 3e-05 L
.08328 3e-05 L
.08405 3e-05 L
.08473 3e-05 L
.08545 3e-05 L
.0861 2e-05 L
.08681 3e-05 L
.08807 3e-05 L
.08953 4e-05 L
.09036 4e-05 L
.09111 4e-05 L
.09177 5e-05 L
.0925 4e-05 L
.09326 4e-05 L
.09396 4e-05 L
.09462 4e-05 L
.09535 4e-05 L
.09665 4e-05 L
.09793 5e-05 L
.0991 5e-05 L
.10037 6e-05 L
.10109 6e-05 L
.10176 6e-05 L
.10247 6e-05 L
.10312 6e-05 L
.10382 6e-05 L
.10458 6e-05 L
.10575 6e-05 L
.10686 6e-05 L
.10817 7e-05 L
.10938 8e-05 L
.11056 8e-05 L
.11186 9e-05 L
.11252 9e-05 L
.11322 9e-05 L
.11448 9e-05 L
.11566 9e-05 L
.11694 .0001 L
.11808 .0001 L
.11928 .00011 L
.12036 .00012 L
.12155 .00012 L
Mistroke
.12263 .00012 L
.12364 .00013 L
.12492 .00013 L
.12565 .00013 L
.12632 .00014 L
.12886 .00016 L
.13006 .00017 L
.13118 .00018 L
.13247 .00018 L
.13364 .00019 L
.13495 .0002 L
.13561 .0002 L
.13633 .00021 L
.13881 .00025 L
.1417 .00027 L
.143 .00028 L
.14439 .0003 L
.14563 .00032 L
.147 .00034 L
.14941 .00038 L
.15485 .00046 L
.16476 .00065 L
.1738 .00085 L
.18332 .00109 L
.18815 .00125 L
.19342 .00146 L
.19822 .00171 L
.20268 .00199 L
.21277 .00286 L
.21842 .00349 L
.22354 .00419 L
.24436 .00816 L
.2535 .00974 L
.25834 .0104 L
.26101 .01079 L
.26355 .01123 L
.26596 .01172 L
.2686 .01239 L
.27099 .01317 L
.27321 .01407 L
.27759 .0164 L
.28225 .01971 L
.30203 .03729 L
.32206 .05696 L
.32755 .06333 L
.33031 .06568 L
.33107 .06617 L
.33187 .06663 L
.33263 .06698 L
.33333 .06725 L
Mistroke
.33398 .06743 L
.33467 .06758 L
.33536 .06767 L
.33612 .06772 L
.33677 .06771 L
.33748 .06767 L
.33875 .0675 L
.34007 .06724 L
.34133 .06696 L
.34246 .0667 L
.34369 .06647 L
.34499 .06631 L
.34621 .0663 L
.3474 .06648 L
.3485 .06685 L
.34969 .06753 L
.351 .06866 L
.35236 .07032 L
.35364 .07237 L
.35597 .0774 L
.35809 .08344 L
.36287 .10113 L
.36803 .12157 L
.36944 .12609 L
.37021 .12819 L
.37094 .1299 L
.37222 .13219 L
.3729 .133 L
.37363 .13355 L
.37487 .13368 L
.37557 .13329 L
.37622 .13264 L
.37754 .13047 L
.37828 .12879 L
.37895 .12698 L
.38383 .10827 L
.38633 .0975 L
.38867 .08874 L
.38995 .08489 L
.39111 .08205 L
.39241 .07971 L
.39312 .07878 L
.3938 .07812 L
.39491 .0775 L
.39608 .07738 L
.3972 .07768 L
.3982 .07821 L
.40054 .07983 L
.40181 .08061 L
.403 .08107 L
Mistroke
.40428 .08112 L
.40496 .08092 L
.40568 .08053 L
.40697 .07933 L
.40815 .07769 L
.40952 .07514 L
.41101 .07169 L
.41371 .06403 L
.41892 .04675 L
.4238 .03059 L
.42601 .02409 L
.42833 .01836 L
.42955 .01601 L
.43019 .015 L
.43088 .01411 L
.43209 .01309 L
.43321 .01284 L
.43391 .01306 L
.43456 .01352 L
.43527 .01433 L
.43602 .01554 L
.43727 .01836 L
.43866 .02253 L
.4436 .04291 L
.44489 .04821 L
.44629 .05327 L
.44761 .05706 L
.44884 .05955 L
.44952 .06046 L
.45026 .06108 L
.45105 .06128 L
.45178 .06106 L
.45307 .05978 L
.4538 .05858 L
.45446 .05721 L
.45682 .0506 L
.45941 .0413 L
.46462 .02233 L
.46714 .0154 L
.46857 .01245 L
.46989 .01032 L
.47104 .00889 L
.47231 .00774 L
.47294 .00731 L
.47363 .00694 L
.47487 .00651 L
.47606 .00635 L
.47737 .00642 L
.4786 .00666 L
.47974 .00702 L
Mistroke
.4819 .00791 L
.48419 .00904 L
.48691 .01065 L
.48834 .01171 L
.48985 .01308 L
.49263 .01639 L
.49518 .02025 L
.50039 .02898 L
.50285 .03268 L
.50513 .03547 L
.50626 .03654 L
.50747 .03739 L
.50867 .0379 L
.50936 .03802 L
.51 .03801 L
.51116 .0377 L
.51222 .03705 L
.51339 .03595 L
.51461 .03437 L
.51713 .02998 L
.51947 .02496 L
.5222 .01877 L
.52478 .01345 L
.52701 .0098 L
.52826 .00827 L
.52942 .00722 L
.5304 .0066 L
.53147 .00617 L
.53259 .00596 L
.53364 .00593 L
.53487 .00601 L
.53603 .00615 L
.53821 .0064 L
.54311 .00681 L
.55346 .00768 L
.55853 .00812 L
.56319 .00857 L
.57193 .00974 L
.58137 .01118 L
.60108 .01492 L
.62207 .01915 L
.63118 .02072 L
.6362 .02144 L
.64094 .02199 L
.64654 .0225 L
.65164 .02285 L
.65642 .02308 L
.65773 .02313 L
.65912 .02318 L
.66042 .02321 L
Mistroke
.66162 .02324 L
.66282 .02325 L
.66413 .02327 L
.66529 .02327 L
.66653 .02327 L
.66774 .02326 L
.66888 .02325 L
.66991 .02323 L
.67102 .02321 L
.67358 .02313 L
.67628 .02301 L
.68113 .02273 L
.68985 .02202 L
.69943 .02094 L
.70962 .01942 L
.71892 .0178 L
.73983 .01383 L
.76051 .00997 L
.77965 .00694 L
.79822 .00457 L
.80771 .00362 L
.81795 .00277 L
.8281 .00208 L
.83741 .00158 L
.84631 .0012 L
.85568 .00089 L
.86521 .00066 L
.8754 .00046 L
.88502 .00033 L
.89376 .00024 L
.8986 .0002 L
.90373 .00016 L
.91293 .00012 L
.92283 8e-05 L
.92412 7e-05 L
.92484 7e-05 L
.9255 6e-05 L
.92628 6e-05 L
.92701 6e-05 L
.92769 7e-05 L
.92841 7e-05 L
.92906 7e-05 L
.92976 6e-05 L
.93049 6e-05 L
.93118 6e-05 L
.9324 5e-05 L
.93308 5e-05 L
.93372 4e-05 L
.93504 4e-05 L
.93628 4e-05 L
Mistroke
.93742 5e-05 L
.93862 5e-05 L
.93991 4e-05 L
.94112 4e-05 L
.94246 3e-05 L
.94313 3e-05 L
.94387 3e-05 L
.94508 3e-05 L
.9462 3e-05 L
.9473 3e-05 L
.94834 3e-05 L
.94956 3e-05 L
.95067 3e-05 L
.95195 2e-05 L
.95315 2e-05 L
.95436 2e-05 L
.955 2e-05 L
.95569 2e-05 L
.95641 2e-05 L
.95709 2e-05 L
.95837 3e-05 L
.95956 2e-05 L
.96067 2e-05 L
.96188 1e-05 L
.96318 1e-05 L
.96391 1e-05 L
.96459 1e-05 L
.96532 1e-05 L
.96611 2e-05 L
.96681 2e-05 L
.96746 2e-05 L
.96814 2e-05 L
.96888 2e-05 L
.96954 1e-05 L
.97027 1e-05 L
.97158 0 L
.97286 0 L
.97404 1e-05 L
.97506 1e-05 L
.97619 2e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`006@3oool400000005014A4@3oool0oooo0?ooo`14A4@00P0000000`0c
<c<0gMgM0?ooo`0R0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kRP0oooo
00D0A4A4000000000000<c<c0=gMg@1G0?ooo`0504A4A0000000000003<c<`3MgMd09`3oool40000
0008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hT0?ooo`@0000000D04A4A0?ooo`3oool0
oooo04A4A0020000000303<c<`3MgMd0oooo02D0oooo000K0?ooo`030000003oool0oooo00H0oooo
00<0MgMg03<c<`3oool0903oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0:`3oool00`1gMgL0<c<c0?ooo`1I0?ooo`0307MgM`0c<c<0oooo02P0oooo00<000000?ooo`3o
ool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02H0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0U0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A407`3oool6000000L0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0V0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool01P3oool00`1g
MgL0<c<c0?ooo`0T0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`0307MgM`0c<c<0oooo05T0oooo00<0MgMg03<c<`3oool0:03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo02D0oooo000K0?ooo`030000003oool0oooo00<0oooo00D00000028R8P000000<c<c0<c<
c00U0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000X0?ooo`050000
000R8R80000003<c<`3<c<`0E`3oool01@0000008R8R0000000c<c<0c<c<02T0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000002H0oooo00<000000?ooo`3oool00`3oool0
1@0000008R8R0000000c<c<0c<c<02H0oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40:03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3o
ool01@0A4A40oooo0?ooo`3oool04A4A02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0X0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg02P0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool001T0oooo
0P1EEED00`000000oooo0?ooo`030?ooo`@00000903oool205EEE@030000003oool0oooo0080oooo
00D0k^k^03<c<`000000<c<c0>k^kP0X0?ooo`@00000F03oool4000002P0oooo0P1EEED00`000000
oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c<`3^k^h0903oool205EEE@030000003oool0oooo
00<0oooo1000000W0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooom>0?ooo`8000000P3o
ool2000001D0oooo003o0?ooodh0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`E0?ooo`00o`3o
oom?0?ooo`040=gMg@00000000000<c<c1H0oooo000D0?ooool00000<000000;0?ooo`040>k^kP0R
8R8000000>k^kQH0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0000000<000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo3`0000080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo00D0
k^k^028R8P1gMgL0MgMg03<c<`0F0?ooo`006`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00`0oooo0`00000N0?ooo`030000003oool0oooo02D0oooo0`0000050?ooo`030000003o
ool0oooo00H0oooo2@00000N0?ooo`030000003oool0oooo01l0oooo2P0000040?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool03`3oool200000080oooo0P00000E0?ooo`00G@3oool7
000003h0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00D0oooo0P00
00080?ooo`L00000<`3oool6000006/0oooo001S0?ooo`D00000;P3oool2000000T0oooo00<00000
0?ooo`3oool00`3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?
0?ooo`@00000:P3oool500000740oooo001X0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool04`3oool600000240oooo0`00001f0?ooo`00J@3oool2000002X0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`060?ooo`8000001P3oool00`000000oooo0?ooo`0I0?oo
o`H000004P3oool9000007T0oooo001[0?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`070?ooo`8000001P3oool00`000000oooo0?ooo`0O0?oo
oa800000PP3oool006`0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2d0?oo
o`00K@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0]@3oool006h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000000<0oooo00<000000?ooo`3oool0
]@3oool006l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02@3oool01@000000oooo0000003oool000000;P0oooo
001`0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000^@3oool00740oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2j0?ooo`00LP3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0;X0oooo001c0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0^P3oool0
07@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000`0oooo00<000000?ooo`3oool0^P3oool007D0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0^P3oool007H0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`8000003@3oool00`000000
oooo0?ooo`2j0?ooo`00M`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0303oool200000;/0oooo001h0?ooo`030000003oool0oooo00<000004`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0;X0oooo001i0?ooo`<000000P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0^P3oool0
07l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0;X0oooo001o0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`2j0?ooo`00O`3oool00`000000oooo0?ooo`080?ooo`@0000000<0oooo0000003oool0
6P3oool00`000000oooo0?ooo`2j0?ooo`00P03oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00800000703oool00`000000oooo0?ooo`2j0?ooo`00P03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0^P3oool00800oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0;X0oooo00200?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool07`3oool200000;/0oooo00210?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2j0?ooo`00P@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0^P3o
ool00840oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0;X0oooo00210?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`2j0?ooo`00PP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0^P3oool00880oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0;X0oooo00220?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D00000
1P3oool00`000000oooo0?ooo`2j0?ooo`00P`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R103oool01@2IVIT08R8R0>k^kP3oool0A4A4
00H0oooo00<000000?ooo`3oool0^P3oool008<0oooo00D000000?ooo`3oool0oooo000000080?oo
o`05014A4@3oool0oooo0?ooo`0A4A40303oool00`2IVIT08R8R0>k^kP070?ooo`030000003oool0
oooo0;X0oooo00230?ooo`040000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`0309VIV@0R8R80k^k^00H0oooo0`00002j0?ooo`00Q03oool00`000000oooo00000009
0?ooo`050000003oool0oooo0?ooo`0000003P3oool00`1gMgL0IVIV0?ooo`050?ooo`030000003o
ool0oooo0;X0oooo00240?ooo`<000002@3oool01@0A4A40oooo0?ooo`3oool04A4A00l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00Q@3oool00`000000oooo0?ooo`08
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@000000^k^k0?ooo`2IVIT04A4A00H0oooo
00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`0509VI
V@0A4A400000028R8P3<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo
0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j
0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0
oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0
oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[
0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3o
ool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0
oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<0
00000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`00
0000oooo0?ooo`2j0?ooo`00T03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R860?oo
o`80000000<04A4A0?ooo`3oool0103oool00`000000oooo0?ooo`2j0?ooo`00T03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R870?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001P3oool00`00
0000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00@0A4A40=gM
g@3oool000001`3oool300000;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool0
103MgMd0EEEE0?ooo`0000070?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0
oooo0?ooo`0A4A40303oool00`1gMgL0c<c<000000070?ooo`030000003oool0oooo0;X0oooo002@
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`3^k^h0A4A4000000070?ooo`030000003o
ool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h03@3oool00`1gMgL000000?oo
o`060?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000
003oool0oooo0;X0oooo002[0?ooo`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool200000;/0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002@0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3o
ool2028R8P@0oooo00D0k^k^03<c<`0000004A4A0<c<c0060?ooo`030000003oool0oooo0;X0oooo
002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00D0EEEE07MgM`3oool0
VIVI028R8P060?ooo`030000003oool0oooo0;X0oooo002@0?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool01@000000oooo0?ooo`3oool0000000H0oooo0`00002j0?ooo`00T03oool01@000000
oooo0?ooo`3oool0000000/0oooo00D0000009VIV@3oool0VIVI028R8P060?ooo`030000003oool0
oooo0;X0oooo002@0?ooo`050000003oool0oooo0?ooo`0000002`3oool01@000000EEEE0000000A
4A40c<c<00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D04A4A0?ooo`3oool0oooo014A
4@0;0?ooo`0305EEE@28R8P0oooo00P0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg
09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI00P0oooo00<000000?ooo`3oool0^P3o
ool00900oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`040<c<c014A4@00000014A4@H0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003o
ool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`800000^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0
^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00900oooo
00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`08R8R0000000R8R80c<c<
00H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00H0oooo00<000000?ooo`3oool0^P3oool0
0900oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`2j0?ooo`00T03oool01@000000oooo0?ooo`3oool0000000/0oooo00D0
<c<c09VIV@3oool0VIVI03<c<`060?ooo`<00000^P3oool00900oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`050<c<c000000000000000003<c<`01P3oool00`000000oooo0?ooo`2j0?ooo`00
T03oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00D04A4A0;^k^`3oool0^k^k014A4@060?oo
o`030000003oool0oooo0;X0oooo002@0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@00
0000^k^k0?ooo`2k^k/0000000H0oooo00<000000?ooo`3oool0^P3oool00900oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX01P3oool00`000000oooo0?oo
o`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?oo
o`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3o
ool200000;/0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo
0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo
002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?oo
o`030000003oool0oooo0;X0oooo002[0?ooo`030000003oool0oooo0;X0oooo002[0?ooo`800000
^`3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool0
0:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo
00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<00000
0?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3oool0^P3oool00:/0oooo00<000000?ooo`3o
ool0^P3oool00:/0oooo0P00002k0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool0
0`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000
oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?ooo`2j0?ooo`00Z`3oool00`000000oooo0?oo
o`2j0?ooo`00X@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0^P3oool0
0:<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2j0?ooo`00X`3oool00`000000
oooo0?ooo`050?ooo`<00000^P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<0
00000?ooo`3oool0`P3oool00:<0oooo00<000000?ooo`3oool0`P3oool00:<0oooo00<000000?oo
o`3oool0`P3oool00:40oooo0P1EEED00`000000oooo0?ooo`320?ooo`00o`3ooomY0?ooo`00J@3o
ool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo0080oooo00<0^k^k03<c<`3oool01`3o
ool2000000/0oooo00<04A4A0;^k^`3oool0303oool2000000L0oooo00<000000?ooo`3oool00P3o
ool00`1VIVH0MgMg0?ooo`0<0?ooo`03014A4@2k^k/0oooo0:d0oooo001X0?ooo`030=gMg@0A4A40
k^k^00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo0P0c<c<>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`3^k^h04A4A0=gMg@0<0?ooo`80<c<c[P3oool006P0oooo00<0EEEE09VIV@3oool01@3oool01P00
0000oooo0?ooo`3oool0VIVI014A4@80000000<0ZZZZ0?ooo`3oool0103oool010000000oooo0?oo
o`3oool200000080oooo0P0000030?ooo`0308R8R0000000ZZZZ00@0oooo00D0VIVI000000000000
A4A40;^k^`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`28R8P0
IVIV0?ooo`0;0?ooo`0308R8R0000000ZZZZ00`0oooo00D0VIVI000000000000A4A40;^k^`0A0?oo
o`@0000000<04A4A0?ooo`3oool00P3oool2028R8P@0oooo00D0c<c<028R8P0000008R8R0<c<c01g
0?ooo`00J03oool00`000000oooo0?ooo`050?ooo`0:0000003oool0oooo0?ooo`000000ZZZZ05EE
E@28R8P0EEEE0;^k^`D0oooo00X000000?ooo`3oool0oooo0>k^kP0R8R80R8R80<c<c0000000c<c<
0`3oool00`3<c<`00000014A4@040?ooo`05014A4@2k^k/0k^k^07MgM`0A4A40103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0k^k^0000003oool02`3oool00`3<c<`0
0000014A4@0<0?ooo`06014A4@2k^k/0k^k^07MgM`0A4A40oooo1P00000<0?ooo`030000003oool0
oooo00@0oooo0P0R8R840?ooo`05028R8P2IVIT0oooo09VIV@0R8R80M`3oool006P0oooo00<0<c<c
0?ooo`3oool01@3oool02P000000oooo0?ooo`3oool0<c<c0>k^kP2IVIT0EEEE0=gMg@0A4A450?oo
o`030000003oool0oooo0080oooo00@0gMgM000000000000c<c<2`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3o
ool0000007L0oooo001X0?ooo`0303<c<`3oool0oooo00D0oooo00/000000?ooo`3oool0oooo0;^k
^`14A4@0c<c<028R8P3oool04A4A0<c<c0040?ooo`030000003oool0oooo0080oooo00@0k^k^028R
8P000000k^k^2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo1P00000<
0?ooo`030000003oool0oooo00X0oooo00D0<c<c09VIV@3oool0VIVI03<c<`1g0?ooo`00J03oool0
0`000000k^k^0?ooo`050?ooo`0;0000003oool0oooo0?ooo`3^k^h000000?ooo`000000k^k^06IV
IP28R8P0103oool01P000000oooo0?ooo`3oool0k^k^028R8P80MgMg00<0<c<c0?ooo`3oool02@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`3^k^h000000?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3o
ool01@3<c<`00000000000000000c<c<07L0oooo001X0?ooo`0305EEE@1gMgL0oooo00D0oooo00P0
00000?ooo`3oool0oooo06IVIP2IVIT0oooo03<c<`80^k^k00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`3oool200000080oooo0P0000080?ooo`03014A4@000000000000<000001@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0MgMg05EEE@3oool00P3oool4
00000180oooo00<04A4A0000000000000`00000D0?ooo`030000003oool0oooo00X0oooo00D04A4A
0;^k^`3oool0^k^k014A4@1g0?ooo`00J03oool00`3MgMd04A4A0>k^kP050?ooo`030000003oool0
oooo00@0oooo00<0IVIV07MgM`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030>k^kP0A4A40
gMgM00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00X0oooo00D000000;^k^`3oool0^k^k0000001g0?ooo`00J@3oool00`1gMgL0IVIV0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<0ZZZZ04A4A03oool01@3oool200000180oooo00<00000
0?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`1VIVH0MgMg0?ooo`05
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool205EEE@030000003oool0
oooo00X0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP1g0?ooo`00/P3oool00`000000oooo0?ooo`2c
0?ooo`00[`3oool010000000oooo0?ooo`00002e0?ooo`00/03oool200000;H0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -55.625 0 ]
[.5 .63053 55.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -116.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
170.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 3e-05 m
.02605 .00011 L
.02729 .00018 L
.02846 .00022 L
.02954 .00021 L
.03072 .00016 L
.03179 9e-05 L
.03279 4e-05 L
.03397 1e-05 L
.03527 3e-05 L
.03653 9e-05 L
.03719 .00013 L
.0379 .00016 L
.03916 .0002 L
.04036 .00018 L
.04153 .00012 L
.04262 6e-05 L
.04386 1e-05 L
.04456 0 L
.04521 1e-05 L
.0464 5e-05 L
.04765 .00012 L
.04878 .00017 L
.04983 .00019 L
.05098 .00017 L
.05221 .00011 L
.05353 4e-05 L
.05427 2e-05 L
.05496 0 L
.05622 2e-05 L
.05686 5e-05 L
.05757 9e-05 L
.05878 .00015 L
.06008 .00019 L
.06131 .00019 L
.06244 .00014 L
.06371 8e-05 L
.0649 3e-05 L
.06556 2e-05 L
.06627 3e-05 L
.06752 7e-05 L
.06861 .00014 L
.06977 .0002 L
.07105 .00023 L
.07225 .00021 L
.07297 .00018 L
.07366 .00014 L
.07496 8e-05 L
.07567 7e-05 L
.07633 6e-05 L
Mistroke
.07705 8e-05 L
.07783 .00011 L
.07913 .00019 L
.07984 .00023 L
.08051 .00026 L
.08168 .00028 L
.08297 .00026 L
.08368 .00023 L
.08433 .0002 L
.08508 .00016 L
.08578 .00014 L
.08653 .00013 L
.08734 .00014 L
.08805 .00017 L
.08881 .00021 L
.09007 .00029 L
.09073 .00033 L
.09143 .00036 L
.0922 .00037 L
.09292 .00036 L
.09358 .00034 L
.09431 .00031 L
.09495 .00028 L
.09564 .00025 L
.09689 .00023 L
.09764 .00024 L
.09833 .00026 L
.09963 .00034 L
.10088 .00042 L
.10204 .00047 L
.10325 .00048 L
.10389 .00046 L
.10458 .00044 L
.1059 .00038 L
.10714 .00036 L
.10843 .00039 L
.10911 .00042 L
.10985 .00046 L
.11109 .00054 L
.1124 .0006 L
.11352 .00061 L
.11474 .00059 L
.11542 .00056 L
.11616 .00054 L
.11686 .00052 L
.1175 .00052 L
.11826 .00052 L
.11905 .00055 L
.11972 .00058 L
.12046 .00063 L
Mistroke
.12179 .00071 L
.12254 .00074 L
.12322 .00076 L
.12454 .00075 L
.12579 .00072 L
.12706 .00069 L
.12821 .00069 L
.12885 .0007 L
.12954 .00072 L
.13078 .00078 L
.13196 .00085 L
.1332 .00091 L
.13425 .00093 L
.13541 .00092 L
.13612 .00091 L
.13679 .0009 L
.13803 .00089 L
.13873 .0009 L
.13938 .00091 L
.14009 .00094 L
.14084 .00098 L
.14591 .0012 L
.15529 .00163 L
.15786 .00173 L
.15854 .00175 L
.15926 .00179 L
.16056 .00187 L
.16177 .00197 L
.16287 .00209 L
.16539 .00236 L
.18368 .00431 L
.2045 .00669 L
.21363 .0078 L
.21848 .00858 L
.22368 .00949 L
.22873 .01073 L
.23334 .01215 L
.23798 .01397 L
.24238 .01624 L
.25185 .02273 L
.26217 .03196 L
.2675 .03669 L
.27252 .04033 L
.27472 .04161 L
.27703 .04265 L
.27824 .04307 L
.27956 .04345 L
.28189 .04398 L
.28714 .04496 L
.28853 .0452 L
Mistroke
.29003 .04549 L
.29133 .04579 L
.29276 .04623 L
.2941 .04675 L
.29552 .04745 L
.29806 .04906 L
.30288 .05329 L
.30537 .05618 L
.30808 .05993 L
.31301 .06772 L
.32228 .08271 L
.32752 .08906 L
.33311 .09442 L
.34316 .10519 L
.34574 .1086 L
.34816 .11133 L
.34937 .11239 L
.35068 .11322 L
.35142 .11354 L
.35212 .11372 L
.35344 .11371 L
.35414 .11349 L
.35488 .11307 L
.35551 .11257 L
.35621 .11183 L
.35696 .11083 L
.35777 .10951 L
.35923 .10644 L
.36201 .09849 L
.36456 .08937 L
.36961 .06898 L
.37239 .058 L
.37501 .0489 L
.37745 .04209 L
.37874 .03925 L
.3801 .03679 L
.38125 .03515 L
.38251 .03379 L
.38366 .03295 L
.38473 .0325 L
.3859 .03237 L
.38717 .03265 L
.38838 .03333 L
.38949 .03428 L
.3906 .03551 L
.3916 .03685 L
.39385 .04041 L
.39633 .04484 L
.39895 .04943 L
.40119 .05273 L
Mistroke
.40246 .05415 L
.40364 .05507 L
.40494 .05553 L
.40612 .05539 L
.40677 .05506 L
.40748 .05449 L
.40877 .0529 L
.40943 .0518 L
.41017 .05039 L
.41165 .04693 L
.41431 .0392 L
.4191 .02368 L
.42182 .01605 L
.42314 .01303 L
.42434 .01079 L
.42557 .00902 L
.42673 .00781 L
.42795 .00701 L
.42864 .00676 L
.42927 .00663 L
.43047 .00667 L
.43179 .00707 L
.43245 .0074 L
.43317 .00784 L
.43445 .00886 L
.43564 .01005 L
.43694 .01165 L
.4393 .01547 L
.44159 .02046 L
.44372 .0262 L
.44623 .03394 L
.44893 .04243 L
.45017 .04593 L
.45149 .04905 L
.4526 .0511 L
.45383 .05252 L
.45511 .05291 L
.45582 .05259 L
.45648 .05193 L
.45774 .04966 L
.45894 .04632 L
.46035 .04105 L
.46165 .03522 L
.46458 .02081 L
.46573 .01565 L
.46697 .01079 L
.46815 .00712 L
.46924 .00458 L
.47051 .00266 L
.47122 .00203 L
Mistroke
.47186 .00169 L
.4731 .00159 L
.47426 .002 L
.47536 .00272 L
.47652 .00372 L
.47861 .00587 L
.48332 .01127 L
.48806 .01606 L
.49072 .018 L
.49315 .01933 L
.49602 .02052 L
.49873 .0214 L
.49994 .02171 L
.50123 .02199 L
.5019 .0221 L
.50264 .02221 L
.50394 .02233 L
.50516 .02237 L
.50629 .02232 L
.50754 .02217 L
.50823 .02204 L
.50886 .02188 L
.51014 .02146 L
.51153 .02083 L
.51283 .02005 L
.51404 .01918 L
.51854 .01477 L
.5233 .00914 L
.52577 .00657 L
.52713 .00543 L
.52843 .00459 L
.52963 .00404 L
.53094 .00368 L
.53213 .00354 L
.53323 .00353 L
.53392 .00357 L
.53466 .00363 L
.53601 .00376 L
.53852 .00399 L
.54415 .00446 L
.56375 .00569 L
.58522 .00722 L
.5951 .00803 L
.60568 .00912 L
.62476 .01165 L
.64462 .01524 L
.65508 .01726 L
.66619 .0192 L
.67605 .02049 L
.68167 .02103 L
Mistroke
.68436 .02129 L
.68693 .02147 L
.69175 .02174 L
.69388 .02185 L
.69507 .0219 L
.69616 .02192 L
.69742 .02194 L
.69862 .02194 L
.69972 .02194 L
.7009 .02194 L
.70222 .02194 L
.70288 .02194 L
.7036 .02194 L
.70489 .02193 L
.70609 .02191 L
.70735 .02188 L
.70869 .02184 L
.71109 .02175 L
.71389 .02168 L
.71527 .02163 L
.71653 .02158 L
.71879 .02147 L
.72123 .02133 L
.72392 .02118 L
.72642 .02102 L
.73074 .02065 L
.73546 .02022 L
.74497 .01914 L
.78399 .01324 L
.80389 .01006 L
.82547 .00698 L
.84625 .00467 L
.86543 .00303 L
.87446 .00242 L
.88417 .00187 L
.89483 .00141 L
.9048 .00105 L
.90602 .00106 L
.90733 .00105 L
.90857 .00102 L
.9097 .00096 L
.91103 .00087 L
.91176 .00082 L
.91244 .00079 L
.91362 .00076 L
.91492 .00076 L
.91567 .00077 L
.91637 .00078 L
.91769 .0008 L
.91842 .00079 L
Mistroke
.91911 .00077 L
.91985 .00073 L
.92065 .00069 L
.92186 .00061 L
.92317 .00055 L
.92392 .00053 L
.92461 .00053 L
.92527 .00054 L
.92596 .00056 L
.9272 .00059 L
.92837 .00061 L
.92901 .0006 L
.92971 .00058 L
.93093 .00052 L
.9321 .00045 L
.93334 .00039 L
.9344 .00036 L
.93556 .00038 L
.93626 .0004 L
.93693 .00042 L
.93818 .00046 L
.93887 .00047 L
.93952 .00047 L
.94023 .00045 L
.94098 .00041 L
.94236 .00033 L
.94365 .00027 L
.94481 .00024 L
.94606 .00026 L
.94697 .00029 L
.94781 .00033 L
.94877 .00036 L
.94968 .00037 L
.95052 .00036 L
.9513 .00033 L
.95215 .00028 L
.95306 .00022 L
.95396 .00018 L
.95494 .00015 L
.95586 .00015 L
.9567 .00017 L
.95771 .00022 L
.95879 .00027 L
.9598 .0003 L
.96072 .00029 L
.96166 .00026 L
.96268 .00021 L
.96355 .00015 L
.96451 .0001 L
.96556 8e-05 L
Mistroke
.96667 9e-05 L
.9677 .00014 L
.96865 .00019 L
.96963 .00023 L
.97056 .00025 L
.97139 .00024 L
.97229 .00021 L
.97619 3e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05oooooa3o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo1?l00006ooooo`03o`000?oooooooooo00Kooooo1?l00006ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo000000co00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Fooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00;ooooo1?l0000Wooooo`03o`000?oooooooooo01Oooooo0ol0
0009ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0
0003oooooa3o00004oooool00ol0003oooooooooo`0/ooooo`go00009?ooool00ol0003ooooooooo
o`0?ooooo`;o00000_ooool2o`0001Gooooo001Dooooo`Ko0000>_ooool2o`000003ooooool0003o
000000Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool7o`0003Gooooo1_l0001Nooooo`00F_ooool3o`0003Oooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo1_l0000Yooooo`Ko0000I?oo
ool005gooooo0_l0000dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool2o`0002?ooooo2?l0
000Kooooo`Ko0000J_ooool005oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool4o`0000;ooooo0_l0000]
ooooo`Go00003oooool7o`00073ooooo001Pooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo1?l0000coooo
o`oo0000Moooool0067ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2jooooo`00
H_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;[ooooo001Sooooo`;o00008_oo
ool3o`0000Sooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo
0_l0002kooooo`00IOooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0^_ooool006Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo0;[ooooo001Wooooo`Co00006oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo0;[ooooo001[ooooo`?o00006?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
0;[ooooo001]ooooo`;o00005_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo0;[ooooo001_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l0000<oooo
o`;o00003?ooool00ol0003oooooooooo`2jooooo`00L?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Kooooo0ol0000Kooooo`03o`000?oooooooooo0;[ooooo001aooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2jooooo`00LOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Cooooo0_l0002kooooo`00L_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0^_ooool0
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0;[ooooo001booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2jooooo`00Loooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0^_ooool007Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0;[ooooo001eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`2jooooo`00M_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0^_ooool007Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;[ooooo001gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09_ooool2o`000;_ooooo001hooooo`;o00001ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;[ooooo001jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2jooooo`00Noooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0^_ooool007co
oooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo0;[ooooo001looooo`05
o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`2jooooo`00OOooool4o`0002[o
oooo00?o0000ooooooooool0^_ooool007kooooo0_l0000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^ooo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo
002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`00
0;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3o`000;[ooooo
002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2joooo
o`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oo
oooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2jooooo`00
T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo
002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00
Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034ooooo`00oooooomY
ooooo`00KOooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o^[Zjoc8b
<_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Sooooo00Ko0000oooo
ooooooooooooofIVI_mgMgL>ooooo`03o`000?nj^[[ooooo0:Wooooo001/ooooo`03omgMgOl@413o
k^k^00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooonk^
k_l@413ogMgM00gooooo0_lb<S:Zooooo`00K?ooool00omEEEGoV9RHooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@05ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj
^[X00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ofIVI_oo
ool03?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04?ooool5o`00
00Gooooo0_lQ8B5looooo`00K?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4ooooo`03o`000?oooooooooo00;ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^ko
MgMgoa0@4003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00oo^k^ko
0000ooooo`0<ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6
o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4QO?ooool006cooooo00?o<S8b
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@
1?ooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Cooooo`03oiRHV?lQ8B7ok^k^08Cooooo001/ooooo`03oc8b
<_oooooooooo00Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@
4?o<c<`00oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`03ooooo`Ko00002oooool00onHV9So8B4Qonk^kP23
ooooo`00K?ooool00ol0003ok^k^ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`00
0?oooooo0000oooooomVIVKoQhN700?ooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMg
Molb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03onk^k_l0003ooooo01_ooooo00?o0000ooooooooool05Oooool00omgMgOoIVIV
ooooo`22ooooo`00K?ooool00omEEEGoMgMgooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co
IVIVoiRHV?oooooo<S8b0_nj^[X01Ol0003ooooooooooooooooo000000Cooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000Booooo`03oa0@4?l0003o000000?o
00005Oooool00ol0003oooooooooo`21ooooo`00K?ooool00ooMgMgo410@onk^kP04ooooo`03o`00
0?oooooooooo00Gooooo00?oIVIVohN7Qoooool01?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01ol0003oooooooooooooooook^k^oa0@
4?oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00Go0000okZj
^_ooooooV9RHoa0@4023ooooo`00KOooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?oZJVYodA4A?ooool01?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`00
00Sooooo00Ko0000ooooooooooooooooofIVI_mgMgL7ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool01OnHV9So410@o`000?lQ8B7oc<c<08?ooooo002fooooo`03o`000?oo
oooooooo0:oooooo002cooooo`04o`000?ooooooooooo`000;7ooooo002dooooo`;o0000/_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00108 m
.02499 .00069 L
.02605 .00037 L
.02729 .00017 L
.02846 .00022 L
.02954 .00046 L
.03053 .00078 L
.03162 .00111 L
.03279 .00131 L
.03396 .00128 L
.03506 .00104 L
.03636 .0006 L
.03756 .00023 L
.0388 4e-05 L
.0395 6e-05 L
.04015 .00016 L
.04135 .0005 L
.04262 .00093 L
.04327 .00112 L
.04396 .00125 L
.04519 .00128 L
.04588 .00116 L
.04652 .00099 L
.04797 .00049 L
.04925 .00012 L
.05041 0 L
.05105 4e-05 L
.05175 .00018 L
.05302 .00057 L
.05424 .00099 L
.05539 .00125 L
.05659 .00127 L
.05723 .00117 L
.05791 .001 L
.05904 .00062 L
.0601 .00028 L
.06133 5e-05 L
.06244 7e-05 L
.06372 .00036 L
.06443 .00059 L
.06509 .00082 L
.06629 .00116 L
.06756 .0013 L
.06822 .00125 L
.06893 .00113 L
.07022 .00075 L
.07096 .00051 L
.07174 .0003 L
.07248 .00016 L
.07315 .00011 L
Mistroke
.0739 .00015 L
.0746 .00027 L
.07536 .00047 L
.07617 .00073 L
.0769 .00096 L
.07767 .00116 L
.07832 .00127 L
.07904 .00132 L
.07975 .00128 L
.08039 .00118 L
.08113 .001 L
.08183 .0008 L
.08306 .00045 L
.08377 .00031 L
.08443 .00025 L
.0856 .0003 L
.08686 .00057 L
.08812 .00095 L
.08881 .00115 L
.08945 .00129 L
.0906 .00142 L
.09187 .00132 L
.09294 .00109 L
.09409 .00078 L
.09475 .00063 L
.09545 .00051 L
.09621 .00046 L
.09692 .00049 L
.09819 .00072 L
.09891 .00093 L
.09959 .00114 L
.10082 .00149 L
.102 .00168 L
.10264 .00169 L
.10335 .00164 L
.10458 .00141 L
.10571 .00114 L
.10691 .00092 L
.10822 .00088 L
.10942 .00107 L
.11054 .0014 L
.11159 .00175 L
.11274 .00208 L
.11396 .00225 L
.11466 .00224 L
.1153 .00217 L
.11601 .00205 L
.11676 .00188 L
.11801 .00163 L
.11872 .00155 L
Mistroke
.11939 .00154 L
.12064 .00171 L
.12177 .00205 L
.12311 .00254 L
.12433 .00292 L
.12562 .0031 L
.12633 .00309 L
.127 .00301 L
.12819 .00279 L
.12948 .00255 L
.13016 .00249 L
.1309 .00249 L
.13168 .00259 L
.13241 .00277 L
.13371 .00322 L
.13443 .0035 L
.1351 .00373 L
.13642 .00405 L
.13711 .00411 L
.13785 .0041 L
.13909 .00393 L
.1398 .00379 L
.14045 .00367 L
.14166 .00354 L
.14297 .00363 L
.14412 .00391 L
.14533 .00432 L
.14657 .00474 L
.14726 .00491 L
.14791 .00502 L
.14909 .00505 L
.15034 .0049 L
.15138 .00471 L
.1525 .00453 L
.15373 .00449 L
.15488 .00464 L
.15619 .00497 L
.15762 .0054 L
.15827 .00557 L
.15897 .00569 L
.16022 .00577 L
.16153 .00565 L
.16277 .00544 L
.16389 .00529 L
.16509 .00524 L
.16624 .00536 L
.16731 .00559 L
.16859 .00594 L
.16975 .00624 L
.17097 .00644 L
Mistroke
.17212 .00649 L
.17334 .00642 L
.17466 .0063 L
.17572 .00626 L
.17688 .00633 L
.1781 .00657 L
.17924 .00691 L
.18346 .00812 L
.18586 .00831 L
.18655 .00836 L
.1872 .00844 L
.18842 .0087 L
.18912 .00892 L
.18977 .00917 L
.19122 .00987 L
.19383 .01116 L
.2037 .01554 L
.22222 .02615 L
.2313 .03158 L
.2363 .03392 L
.23749 .03461 L
.23876 .03528 L
.23993 .03578 L
.24103 .03615 L
.2423 .03646 L
.24371 .03675 L
.24662 .03751 L
.25172 .0391 L
.25402 .03944 L
.25528 .0396 L
.25648 .03982 L
.25716 .03998 L
.25789 .04019 L
.25918 .04066 L
.26169 .04176 L
.26418 .0429 L
.2668 .04421 L
.26905 .04574 L
.27152 .04805 L
.27686 .05452 L
.28187 .06247 L
.29072 .0807 L
.29539 .09042 L
.29795 .0951 L
.30037 .09853 L
.30173 .10003 L
.3032 .10132 L
.30454 .10223 L
.30576 .10282 L
.30693 .10316 L
Mistroke
.3082 .10324 L
.30884 .10316 L
.30953 .10299 L
.31077 .10243 L
.31204 .10157 L
.31342 .10036 L
.31594 .09768 L
.32065 .09169 L
.33918 .06592 L
.3494 .05223 L
.35898 .04241 L
.3638 .03866 L
.36627 .03707 L
.36898 .03573 L
.37043 .03521 L
.37113 .03501 L
.37178 .03486 L
.37253 .03473 L
.37321 .03466 L
.37394 .03462 L
.37473 .03464 L
.37537 .03469 L
.37607 .03479 L
.37679 .03493 L
.37748 .0351 L
.38 .03596 L
.38242 .0369 L
.38375 .03734 L
.38499 .03763 L
.38564 .03773 L
.38633 .03779 L
.38711 .03778 L
.38782 .0377 L
.38909 .03738 L
.38973 .03713 L
.39043 .03678 L
.39173 .03595 L
.3929 .03498 L
.39555 .03218 L
.40032 .0261 L
.40489 .02102 L
.40747 .01898 L
.40985 .01759 L
.41456 .01555 L
.41887 .01381 L
.42001 .01342 L
.42125 .01309 L
.42243 .01295 L
.42353 .013 L
.4248 .01334 L
Mistroke
.42595 .01397 L
.42659 .01446 L
.42728 .01511 L
.42854 .0166 L
.43083 .02036 L
.43326 .02545 L
.43553 .03066 L
.4376 .03507 L
.43877 .03715 L
.44005 .03887 L
.44075 .03954 L
.4414 .03995 L
.44268 .04014 L
.44378 .03963 L
.44499 .03834 L
.44625 .03625 L
.44743 .03368 L
.45259 .01917 L
.45531 .01237 L
.45684 .00958 L
.45756 .00856 L
.45822 .00779 L
.45948 .00675 L
.46014 .0064 L
.46085 .00616 L
.46202 .00601 L
.46332 .00608 L
.4645 .00625 L
.46577 .00647 L
.46806 .00679 L
.46939 .00693 L
.47009 .00701 L
.47084 .00712 L
.47155 .00724 L
.4722 .00739 L
.47347 .00779 L
.47469 .00834 L
.47602 .00914 L
.47841 .01111 L
.48311 .01586 L
.48567 .01808 L
.48692 .01894 L
.48806 .01957 L
.48904 .02002 L
.4901 .0204 L
.49122 .0207 L
.49229 .02089 L
.49345 .021 L
.49469 .02099 L
.49575 .02089 L
Mistroke
.49692 .02066 L
.4982 .02026 L
.4994 .01975 L
.50211 .01815 L
.50704 .01445 L
.51631 .00786 L
.52151 .00455 L
.52406 .00324 L
.52641 .00233 L
.52773 .00196 L
.5284 .00181 L
.52912 .00168 L
.52984 .00158 L
.53052 .00151 L
.53132 .00146 L
.53206 .00144 L
.53332 .00145 L
.53403 .00147 L
.53469 .00149 L
.53718 .00163 L
.57642 .00405 L
.61415 .00668 L
.6351 .0083 L
.64428 .00911 L
.65433 .01022 L
.67316 .01291 L
.69299 .01636 L
.70307 .01798 L
.71258 .01925 L
.71785 .01979 L
.72062 .02004 L
.72213 .02018 L
.72355 .02031 L
.72484 .0204 L
.72602 .02047 L
.72733 .02052 L
.72874 .02056 L
.73125 .02065 L
.73353 .02075 L
.73471 .02079 L
.73599 .02082 L
.73719 .02082 L
.7383 .02081 L
.73958 .02078 L
.74077 .02077 L
.74202 .02077 L
.74268 .02077 L
.74339 .02078 L
.74456 .0208 L
.74584 .02081 L
Mistroke
.74705 .02079 L
.74817 .02075 L
.74918 .02071 L
.75029 .02065 L
.75253 .02054 L
.77326 .01924 L
.79263 .01751 L
.81349 .01489 L
.83316 .0119 L
.85466 .00877 L
.8646 .0075 L
.87521 .00632 L
.87641 .00607 L
.87768 .00595 L
.87835 .00594 L
.87908 .00597 L
.88036 .00606 L
.88157 .0061 L
.88287 .00602 L
.8841 .00579 L
.88522 .00549 L
.8863 .00518 L
.88745 .00491 L
.88872 .00476 L
.88989 .00477 L
.89108 .00489 L
.89221 .00501 L
.89322 .00506 L
.89431 .00499 L
.91392 .00314 L
.91516 .00335 L
.91648 .00342 L
.91716 .00337 L
.91792 .00324 L
.91861 .00306 L
.91925 .00286 L
.9205 .00247 L
.92168 .0022 L
.92233 .00213 L
.92305 .00212 L
.9243 .00225 L
.92506 .0024 L
.92575 .00254 L
.92655 .00269 L
.92731 .00277 L
.92801 .00278 L
.92865 .00272 L
.92936 .0026 L
.93011 .00241 L
.93132 .00204 L
Mistroke
.93263 .00168 L
.93338 .00156 L
.93406 .00151 L
.93475 .00154 L
.9354 .00161 L
.93667 .00187 L
.93787 .00212 L
.93911 .00226 L
.93978 .00225 L
.94049 .00217 L
.94169 .00189 L
.94295 .00151 L
.94403 .00122 L
.94521 .00105 L
.94593 .00104 L
.94661 .00111 L
.94788 .00136 L
.9486 .00153 L
.94936 .0017 L
.95002 .00181 L
.95074 .00187 L
.95201 .00179 L
.9532 .00152 L
.95448 .00113 L
.95516 .00094 L
.95588 .00077 L
.95716 .00066 L
.95835 .00078 L
.95957 .00106 L
.96069 .00135 L
.96177 .00155 L
.96295 .00159 L
.96406 .00142 L
.96508 .00114 L
.96619 .00079 L
.96737 .00048 L
.96867 .00037 L
.96989 .00051 L
.97054 .00066 L
.97125 .00087 L
.97254 .00123 L
.9738 .00142 L
.97496 .00136 L
.97619 .00108 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003ooooo
ooooo`02o`000003ooooool0003o000000;ooooo4?l00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?oooolGo`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo3Ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000001;ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_ooooo00?o0000oooooooo
ool08_ooool<o`0002oooooo00?o0000ooooooooool08Oooool5o`0000Oooooo00?o0000oooooooo
ool00oooool2o`0001Kooooo2Ol00009ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02_ooool=o`0001Kooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00
Boooool4o`0004oooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00Co0000oooooooooooo
oooo0_l0000Qooooo`co0000=Oooool5o`00053ooooo001>ooooo`?o0000@Oooool4o`0000Oooooo
00?o0000ooooooooool01?ooool2o`0000Gooooo00Co0000oooooooooooo0000;oooool5o`0002[o
oooo1_l0001Eooooo`00DOooool2o`0003gooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000003Gooooo
1Ol0000Iooooo`co0000Foooool005?ooooo0_l0000jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`Ko0000>ooooolIo`0006Oooooo001E
ooooo`;o0000=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooo`00002looooo`00Eoooool2o`0003Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0^_ooool005Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2jooooo`00
F_ooool2o`0002oooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000oo
oooo0_l0002kooooo`00G?ooool2o`0002Gooooo2Ol0000<ooooo`04o`000?ooooooooooo`0000oo
oooo00?o0000ooooooooool0^_ooool005kooooo1Ol0000Nooooo`;o00001Oooool2o`0000oooooo
0_l0000@ooooo`03o`000?oooooooooo0;[ooooo001Sooooo`;o00006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0;[ooooo001Tooooo`;o00006Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo0;[ooooo001Vooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`2jooooo`00I_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0^_ooool006Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;[ooooo001Xooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2jooooo`00JOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo0_l0002kooooo`00JOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0^_ooool006[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0;[o
oooo001Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2jooooo`00Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0^_ooool006_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo0;[ooooo001/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2jooooo`00K?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0^_ooool006gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0;[ooooo001]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0<oooool2o`000;_ooooo001^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2jooooo`00Koooool01Ol0
003ooooooooooooooooo000003Oooooo00?o0000ooooooooool0^_ooool006oooooo1Ol0000goooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000^_ooool0093ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0
^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002k
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000^_ooool0093ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00
Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o
0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0093ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool3
o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003ooooo
ooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0002jooooo`00
T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo0ol0002jooooo`00Xoooool00ol0003o
ooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003ooooooooo
o`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00XOooool00omEEEGoIVIVo`000034oooo
o`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Oooooo
00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<ooooo`03o`000?nj^[[ooooo0:gooooo
001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<ooooo`;o<S8b[_ooool006Sooooo00?oEEEE
oiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool0
1?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0@ooooo`Go00001Oooool2ob4Q8@Cooooo1Ol0001gooooo`00J?ooool00ol0
003oooooooooo`05ooooo`0:o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGo
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06
oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01gooooo`00J?ooool00olb<S;ooooooooo
o`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000
ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool04oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^07Sooooo001X
ooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooo
oooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo1_l0000;ooooo`03oiRHV?lQ8B7o
k^k^00gooooo00?oV9RHob4Q8Oo^k^h0Moooool006Sooooo00?o0000onk^k_ooool01Oooool02ol0
003oooooooooooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^k_l0003ooooo01[ooooo00?o0000oooo
ooooool05Oooool00omgMgOoIVIVooooo`0=ooooo`03ogMgMomVIVKooooo07Kooooo001Xooooo`03
oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o410@o`000?l000000ol0000Eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0MOooool006Sooooo00?ogMgMoa0@4?o^k^h01Ooo
ool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_oo
ool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_ooooooV9RHoa0@401gooooo`00
JOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool0
1Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool00omVIVKoMgMgooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01goooo
o`00/_ooool00ol0003oooooooooo`2cooooo`00[oooool01?l0003oooooooooool0002eooooo`00
/?ooool2o`000;Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0 0.618034 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .12361 -18 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .24721 -18 -4.5 ]
[.4875 .24721 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -18 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-15)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-10)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-5)] .34127 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(5)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(10)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .12361 m
.50625 .12361 L
s
[(0.2)] .4875 .12361 1 0 Mshowa
.5 .24721 m
.50625 .24721 L
s
[(0.4)] .4875 .24721 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.6)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(0.8)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0309 m
.50375 .0309 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .58713 m
.50375 .58713 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(H) show
69.000 13.438 moveto
(\\310) show
75.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.438 moveto
(@) show
87.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.438 moveto
(D) show
111.000 13.438 moveto
(\\310) show
117.000 13.438 moveto
(L) show
123.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
128.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
140.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
146.250 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
158.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
176.250 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0046 m
.02499 .00489 L
.02605 .00454 L
.02729 .00354 L
.02846 .00231 L
.02946 .00134 L
.03053 .00068 L
.0317 .00057 L
.03279 .00106 L
.03395 .00205 L
.0352 .00325 L
.03638 .00412 L
.03746 .00441 L
.03873 .00403 L
.03944 .00351 L
.04011 .0029 L
.04141 .00157 L
.04262 .00059 L
.04386 .00019 L
.04452 .00028 L
.04521 .00061 L
.04637 .00156 L
.04765 .00284 L
.04879 .0038 L
.05001 .00427 L
.05116 .00403 L
.05221 .00328 L
.05343 .00204 L
.05473 .00077 L
.05541 .0003 L
.05615 3e-05 L
.05747 .00028 L
.0587 .00127 L
.06003 .00274 L
.06129 .00397 L
.06244 .00455 L
.06373 .00433 L
.0649 .0034 L
.06616 .00201 L
.06682 .00129 L
.06752 .00066 L
.06879 .00011 L
.06995 .00044 L
.07105 .00139 L
.07225 .00285 L
.0729 .00366 L
.07362 .00441 L
.07492 .00515 L
.0757 .00512 L
.07642 .00476 L
Mistroke
.07708 .00419 L
.07779 .00342 L
.07846 .00261 L
.07919 .00177 L
.08051 .00072 L
.08179 .00063 L
.08297 .00145 L
.08539 .00446 L
.08609 .00518 L
.08675 .00566 L
.08799 .00582 L
.0887 .00549 L
.08935 .00494 L
.09083 .00323 L
.09212 .00187 L
.09277 .00143 L
.09349 .00123 L
.09419 .00135 L
.09492 .00179 L
.09624 .00321 L
.09699 .00417 L
.09778 .00513 L
.09853 .00586 L
.09921 .00628 L
.10053 .00629 L
.10178 .00542 L
.10248 .00467 L
.10312 .00393 L
.10382 .00316 L
.10458 .00248 L
.10584 .00195 L
.10703 .00228 L
.10819 .00327 L
.10927 .0045 L
.11053 .00583 L
.11171 .00656 L
.11294 .00654 L
.11359 .00621 L
.1143 .00565 L
.11549 .00446 L
.11661 .00339 L
.11777 .00269 L
.11904 .00266 L
.12014 .00327 L
.12114 .00419 L
.1222 .0053 L
.12338 .00632 L
.12467 .00685 L
.12537 .00681 L
.12603 .00657 L
Mistroke
.12721 .00576 L
.12847 .00464 L
.12918 .00408 L
.12995 .00362 L
.13068 .0034 L
.13136 .00342 L
.13264 .00401 L
.13335 .0046 L
.134 .00523 L
.13521 .00645 L
.13648 .00744 L
.13715 .00772 L
.13788 .00781 L
.13917 .00743 L
.14038 .00663 L
.14169 .00571 L
.14292 .00517 L
.14404 .00522 L
.14522 .00589 L
.14632 .00698 L
.14764 .00851 L
.14885 .00974 L
.15005 .01046 L
.15131 .01054 L
.15257 .01003 L
.15329 .00961 L
.15396 .00922 L
.15515 .00876 L
.15628 .00883 L
.1573 .00942 L
.1584 .01057 L
.15958 .01217 L
.16084 .01386 L
.16204 .01505 L
.16313 .01557 L
.16442 .01548 L
.16564 .01496 L
.16695 .01439 L
.1677 .01427 L
.16839 .01436 L
.16911 .01471 L
.1698 .01528 L
.17108 .01686 L
.17247 .01892 L
.17323 .01997 L
.17394 .02078 L
.17513 .02164 L
.17644 .02179 L
.17754 .02143 L
.17873 .02089 L
Mistroke
.1794 .02066 L
.18012 .02056 L
.18144 .02096 L
.18272 .02209 L
.1839 .02359 L
.18515 .02523 L
.18633 .02647 L
.18739 .02708 L
.18855 .02715 L
.18981 .02667 L
.19051 .02628 L
.19115 .02594 L
.19239 .02551 L
.19356 .0256 L
.19466 .0262 L
.19583 .02725 L
.19683 .02831 L
.19791 .02934 L
.19907 .03008 L
.20015 .0303 L
.20144 .02999 L
.20262 .02936 L
.20389 .02866 L
.20454 .02841 L
.20525 .02829 L
.20651 .02853 L
.20769 .02924 L
.20909 .03043 L
.20985 .03109 L
.21057 .03162 L
.21183 .03224 L
.21249 .03235 L
.21321 .03233 L
.21451 .03197 L
.21573 .03148 L
.21684 .03119 L
.21803 .03122 L
.21935 .03181 L
.22001 .03231 L
.22074 .03298 L
.22324 .03549 L
.22453 .03643 L
.22574 .03693 L
.22641 .03707 L
.22714 .03716 L
.22841 .03728 L
.22915 .03744 L
.22993 .03774 L
.2306 .03815 L
.23133 .03877 L
Mistroke
.23274 .04043 L
.23405 .04238 L
.24431 .05372 L
.25361 .06824 L
.25878 .07719 L
.26106 .08167 L
.26235 .08363 L
.26357 .08503 L
.26599 .08724 L
.26857 .09016 L
.26995 .09212 L
.2714 .09416 L
.27265 .09557 L
.27335 .09615 L
.274 .09653 L
.27521 .09684 L
.2763 .09675 L
.27757 .09638 L
.27876 .09597 L
.28125 .09533 L
.2819 .09518 L
.28261 .09499 L
.28388 .09445 L
.28503 .09359 L
.28608 .09245 L
.28732 .09065 L
.2885 .08861 L
.29276 .08067 L
.30238 .06211 L
.30695 .05475 L
.30956 .05172 L
.31201 .04911 L
.31326 .04792 L
.31458 .04684 L
.3157 .04613 L
.31694 .04559 L
.31763 .04541 L
.31827 .04531 L
.319 .04526 L
.31969 .04528 L
.32092 .04541 L
.32161 .04553 L
.32225 .04565 L
.33112 .04873 L
.33234 .04938 L
.33368 .05001 L
.33494 .05045 L
.33611 .05067 L
.33726 .0507 L
.33831 .05056 L
Mistroke
.33952 .05021 L
.34066 .04973 L
.34308 .04828 L
.34531 .04642 L
.34775 .04367 L
.35033 .03998 L
.35939 .02606 L
.36185 .02288 L
.36448 .01992 L
.36696 .01773 L
.36923 .01629 L
.37061 .01566 L
.37188 .01524 L
.37255 .01508 L
.37328 .01495 L
.37405 .01487 L
.37477 .01485 L
.37609 .01495 L
.3773 .01522 L
.37793 .01542 L
.37862 .01571 L
.38002 .01649 L
.38134 .01746 L
.38256 .01857 L
.38531 .02174 L
.3903 .02885 L
.39264 .03207 L
.39484 .03454 L
.39594 .03548 L
.39712 .03621 L
.39844 .03663 L
.39964 .03661 L
.40093 .03616 L
.40165 .0357 L
.40231 .03518 L
.40358 .03385 L
.40478 .03228 L
.41039 .02279 L
.41277 .01883 L
.41529 .01541 L
.41661 .01402 L
.41805 .01281 L
.41937 .012 L
.42059 .01145 L
.42186 .01104 L
.4232 .01074 L
.42561 .0103 L
.42687 .01003 L
.42821 .00965 L
.42969 .00913 L
Mistroke
.43107 .00854 L
.43234 .00797 L
.43373 .00739 L
.43503 .00694 L
.43625 .0067 L
.43745 .00668 L
.43854 .0069 L
.4398 .00748 L
.44099 .00836 L
.44526 .01422 L
.44984 .02269 L
.45119 .02479 L
.45247 .02633 L
.45361 .02723 L
.45486 .0276 L
.45605 .02733 L
.4573 .02634 L
.45837 .02494 L
.45956 .02286 L
.46425 .01164 L
.46671 .00636 L
.46795 .00444 L
.46866 .00361 L
.46931 .00302 L
.47001 .00257 L
.47065 .00233 L
.47139 .00222 L
.47208 .00227 L
.4733 .00269 L
.47399 .00308 L
.47462 .00352 L
.47705 .00569 L
.47962 .00848 L
.48385 .01321 L
.48619 .01546 L
.48841 .01709 L
.48966 .01774 L
.49036 .01802 L
.49102 .01823 L
.49217 .01846 L
.49341 .01853 L
.49467 .01843 L
.49586 .01819 L
.49693 .01787 L
.49808 .01742 L
.50753 .01071 L
.51273 .00672 L
.51765 .00385 L
.52044 .00262 L
.5219 .00209 L
Mistroke
.52346 .00162 L
.52477 .00129 L
.52621 .00101 L
.52752 .00082 L
.52876 .0007 L
.53002 .00062 L
.53066 .00059 L
.53136 .00057 L
.53259 .00055 L
.53374 .00056 L
.53444 .00056 L
.5351 .00057 L
.53634 .00059 L
.53912 .00064 L
.54833 .00081 L
.55337 .00091 L
.55808 .00102 L
.56318 .00119 L
.56878 .0014 L
.57863 .00184 L
.61748 .00423 L
.65879 .00727 L
.66879 .00798 L
.67944 .0088 L
.69857 .01081 L
.73685 .01626 L
.74717 .01779 L
.7526 .01841 L
.75403 .01868 L
.75482 .01881 L
.75556 .01891 L
.75625 .01898 L
.75701 .01902 L
.75832 .01904 L
.75959 .01901 L
.76023 .019 L
.76093 .019 L
.76218 .01904 L
.76334 .01916 L
.76482 .01938 L
.76622 .0196 L
.76747 .01975 L
.76818 .01979 L
.76885 .0198 L
.77003 .01976 L
.7711 .01967 L
.77235 .01956 L
.7735 .01951 L
.77474 .01954 L
.77539 .0196 L
Mistroke
.77608 .01969 L
.77734 .01988 L
.77851 .02004 L
.77973 .02013 L
.78037 .02014 L
.78105 .02011 L
.7822 .01998 L
.78347 .01979 L
.78459 .01962 L
.7858 .01951 L
.78694 .0195 L
.78798 .01957 L
.78922 .01972 L
.7899 .01981 L
.79055 .01988 L
.7918 .01994 L
.79293 .01988 L
.79413 .01971 L
.79542 .01943 L
.7961 .01927 L
.79683 .01912 L
.79814 .01894 L
.7993 .01891 L
.80035 .01898 L
.80159 .01914 L
.80278 .01929 L
.80399 .01936 L
.80512 .0193 L
.80636 .01908 L
.80768 .01873 L
.80882 .01842 L
.81006 .01816 L
.81123 .01807 L
.8123 .01812 L
.81327 .01825 L
.81433 .01843 L
.81544 .01859 L
.81648 .01864 L
.81774 .0185 L
.81838 .01835 L
.81909 .01814 L
.82034 .01768 L
.8215 .01729 L
.82216 .01712 L
.82285 .01701 L
.82355 .01696 L
.82431 .017 L
.82497 .01709 L
.82568 .01723 L
.82695 .01751 L
Mistroke
.82824 .01768 L
.82896 .01767 L
.82963 .01759 L
.83085 .01724 L
.83215 .01669 L
.83323 .01621 L
.8344 .01582 L
.83567 .01565 L
.83686 .01577 L
.8381 .01609 L
.83925 .01641 L
.84051 .01661 L
.84115 .01661 L
.84185 .0165 L
.84302 .01611 L
.84428 .01549 L
.84538 .01493 L
.84657 .01447 L
.84774 .01429 L
.84882 .01439 L
.84997 .01471 L
.85119 .01512 L
.85233 .01539 L
.85341 .01541 L
.85438 .0152 L
.85543 .01474 L
.85664 .01405 L
.85778 .01341 L
.8591 .0129 L
.86031 .01279 L
.86144 .01299 L
.8625 .01334 L
.86364 .01375 L
.86488 .01401 L
.86559 .01401 L
.86624 .0139 L
.86752 .01339 L
.86868 .0127 L
.86991 .01193 L
.87055 .0116 L
.87124 .01134 L
.87247 .01116 L
.87323 .01125 L
.87394 .01144 L
.87458 .01168 L
.87528 .01196 L
.87658 .01242 L
.8778 .01258 L
.8785 .01249 L
.87914 .0123 L
Mistroke
.87984 .01197 L
.88058 .01152 L
.88188 .01064 L
.88259 .0102 L
.88327 .00987 L
.88407 .00961 L
.88479 .00953 L
.88547 .0096 L
.88621 .0098 L
.88753 .01037 L
.88876 .01091 L
.89005 .01119 L
.89073 .01115 L
.89147 .01095 L
.89277 .01024 L
.894 .00934 L
.89521 .00851 L
.89631 .00801 L
.89757 .00791 L
.89822 .00805 L
.89892 .00832 L
.90018 .00898 L
.90136 .00957 L
.90242 .00984 L
.90354 .00974 L
.90479 .00915 L
.90593 .00828 L
.90716 .00729 L
.90846 .00651 L
.90913 .00631 L
.90988 .00629 L
.91119 .00672 L
.91253 .00754 L
.91379 .00831 L
.91493 .00869 L
.91617 .00855 L
.91732 .0079 L
.91854 .00685 L
.9196 .0059 L
.92075 .00511 L
.92144 .00486 L
.92208 .00481 L
.92333 .00521 L
.92447 .00599 L
.92567 .00694 L
.92673 .00758 L
.92787 .00779 L
.92894 .00745 L
.92991 .00673 L
.93107 .00558 L
Mistroke
.93232 .00436 L
.93349 .00364 L
.93457 .00353 L
.93569 .00401 L
.93686 .00497 L
.93816 .00614 L
.93938 .00687 L
.94055 .00693 L
.94181 .00621 L
.94253 .00553 L
.94321 .00479 L
.94448 .00343 L
.94559 .00263 L
.94677 .00244 L
.94777 .00285 L
.94888 .00376 L
.95006 .00494 L
.95134 .00592 L
.95255 .00621 L
.95365 .00579 L
.95493 .00465 L
.95629 .00313 L
.95757 .00199 L
.95874 .00159 L
.95946 .00171 L
.96011 .00205 L
.96084 .00262 L
.9616 .00336 L
.9629 .00463 L
.96363 .00516 L
.96429 .00545 L
.96557 .00534 L
.96679 .0045 L
.9679 .00334 L
.96911 .00205 L
.96975 .00152 L
.97045 .00113 L
.97118 .00098 L
.97186 .00111 L
.97309 .00186 L
.9744 .00313 L
.97619 .0046 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`0Rooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00GoA4A4o`000?l0003o<S8bomgMg@1Gooooo`05odA4A?l0003o0000oc8b<_oMgMd09oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo02Gooooo000Kooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool09?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0:oooool00omgMgOo<S8booooo`1Iooooo`03ogMgMolb<S;ooooo02Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Uooooo`004?ooool6o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Hooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41007oooool6o`0000Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Vooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool001_ooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`0Tooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[
ooooo`03ogMgMolb<S;ooooo05Wooooo00?oMgMgoc8b<_ooool0:?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo02Gooooo000Kooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Uooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Xooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0Eoooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100:?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001Wooooo
00?oEEEEofIVI_l000001Oooool4o`0002Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^02Sooooo1?l0001Hooooo`Co0000:?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool00omEEEGoIVIVo`000005ooooo`Co00009oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooC_ooool2o`0000;ooooo0_l0000Eooooo`00oooooom>
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM5Oooool00?ooooooCoooool01?oMgMgo0000oa0@
4?o<c<`Fooooo`005?ooooooo`00033o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hFooooo`006ooo
ool6o`000003ooooool0003o000000ko000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
0004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo0ol0
0002ooooo`03o`000?oooooooooo00Kooooo6?l00005ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`;o000000Goooooo`000?l0003o0000
ooooo`03o`000004ooooool0003o0000o`0001;ooooo00Co8B4QogMgMomgMgOo<S8b5_ooool001_o
oooo0_l0000:ooooo`03o`000?oooooooooo00;o00000_ooool2o`000005ooooool0003o0000o`00
0?ooool00ol000000ooooooo0000o`000006o`0000[ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Iooooo`?o00001oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00;o00009_ooool8o`0002gooooo00?o0000ooooooooool06?ooool3o`000003ooooool0003o
000000;o000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;ooooo00?o
0000ooooooooool03oooool2o`0000;ooooo0_l0000Eooooo`00?Oooool00ol0003oooooooooo`05
o`0004kooooo1Ol000000ooooooo0000ooooo`06ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`00033ooooo3Ol0000dooooo`So000000?oooooo`000?l000000_ooool00ol0003ooooooooo
o`0iooooo`00A?ooool00ol0003oooooo`00001;ooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0m
ooooo`Ko00008oooool00ol0003oooooooooo`08o`0000;ooooo00?o0000ooooooooool0A?ooool0
04Gooooo0ol0000kooooo`Go00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`0004Gooooo1Ol0000Foooo
o`co0000D?ooool004Sooooo00Co0000ooooool0003o0000=_ooool2o`0000?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool4
o`0004[ooooo5ol000000ooooooo0000o`00001Hooooo`00BOooool00ol0003oooooo`00000eoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0^_ooool004cooooo1?l0000`oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`?o00003?ooool00ol0003oooooooooo`2jooooo`00Coooool5o`0002cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`2jooooo`00Doooool4o`0002Sooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0000Looooo`;o0000^oooool005Oooooo0ol0000Uooooo`03o`00
0?oooooooooo00Wooooo0ol0000Mooooo`03o`000?oooooooooo0;[ooooo001Iooooo`;o00008ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;[ooooo001Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2jooooo`00G?ooool00ol0
003oooooooooo`0Dooooo`Go00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
0;[ooooo001Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool5o`0002ko
oooo00?o0000ooooooooool0^_ooool005kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo0;[ooooo001Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`2jooooo`00Goooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0^_ooool005oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0iooooo`;o0000^oooool005oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0;[ooooo001Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2jooooo`00H?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0^_oo
ool0067ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo001Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`00Hoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0^_ooool006?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo0;[ooooo001Tooooo`;o00001Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo0;[ooooo001Uooooo`03o`000?oooooooooo00;ooooo0_l0000o
ooooo`;o0000^oooool006Kooooo1Ol00010ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oo
oooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;[ooooo002@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[
ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_o
oooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o
0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooo
ooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0
003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooo
ooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooo
oooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2jooooo`00
T?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0;[o
oooo002@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000^_ooool0093ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0^_ooool0
093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_oo
ool00:_ooooo0_l0002kooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool00ol0003oooooooooo`2jooooo`00Zoooool2o`000;_ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`;o0000^oooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0^_ooool0093ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0^_ooool0093ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`000;[ooooo002@ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0^_ooool0093o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2jooooo`00T?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000
^oooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00
Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`2jooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0;[ooooo002@ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0002jooooo`00T?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0;[ooooo002@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0^_ooool0093ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`2jooooo`00T?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0;[ooooo002[oooo
o`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`00
0?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`;o0000^oooool0
0:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo
00?o0000ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo00?o0000oooooooo
ool0^_ooool00:_ooooo00?o0000ooooooooool0^_ooool00:_ooooo0_l0002kooooo`00Zoooool0
0ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003o
ooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003ooooooooo
o`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2joooo
o`00Zoooool00ol0003oooooooooo`2jooooo`00Zoooool00ol0003oooooooooo`2jooooo`00Zooo
ool2o`000;_ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo
0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Qoooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2jooooo`00Xoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0;[ooooo002Sooooo`03o`000?oooooooooo00Gooooo
0ol0002jooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32
ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00Xoooool00ol0003oooooooooo`32ooooo`00
XOooool00omEEEGoIVIVo`000034ooooo`00oooooomYooooo`00JOooool00omgMgOoIVIVooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool2o`0000_ooooo00?o0000
okZj^_ooool03?ooool2o`0000Oooooo00?o0000ooooooooool00_ooool00omVIVKoMgMgooooo`0<
ooooo`03o`000?nj^[[ooooo0:gooooo001Xooooo`03omgMgOl@413ok^k^00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@0<oooo
o`;o<S8b[_ooool006Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003oooooooooooooooooV9RH
oa0@40;o000000?oZJVYooooooooool01?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00on7QhOoIVIVooooo`0;ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`Go00001Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`1eooooo`00J?ooool00ol0003oooooooooo`05ooooo`0:o`00
0?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PGooooo00[o0000oooooooooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
k^k^o`000?ooool02oooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413o
oooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool0M_ooool006Sooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8b
onk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?oV9RHob4Q8Oo^
k^h03?ooool5o`0007Oooooo001Xooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooo
oooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
1_l0000;ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoA4A4omgMgOoooooo0000N?ooool006Sooooo
00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`000?oooooo0000oooooomV
IVKoQhN700Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03onk^
k_l0003ooooo01[ooooo00?o0000ooooooooool05Oooool00omgMgOoIVIVooooo`0:ooooo`04omgM
gOmEEEGoooooo`0007Sooooo001Xooooo`03oeEEEOmgMgOooooo00Gooooo00So0000oooooooooooo
ooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoeEEEOooool00_ooool4o`0001;ooooo00?o
410@o`000?l000000ol0000Eooooo`03o`000?oooooooooo00[ooooo00?oMgMgolc<c?l00000N?oo
ool006Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOo
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00oo^k^ko410@omgMg@04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool04_ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
k^k^odA4A?l00000N?ooool006Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04
ooooo`03ojVYZOm4A4Cooooo00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00=ooooo`03ogMgMol0
003ooooo07Oooooo002booooo`03o`000?oooooooooo0;?ooooo002_ooooo`04o`000?oooooooooo
o`000;Gooooo002`ooooo`;o0000]_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.8522, -0.080387, \
0.130126, 0.00668404}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The plots of the wave packet in Cell ",
  ButtonBox["6.51",
    ButtonData:>"Cell 6.51",
    ButtonStyle->"Hyperlink"],
  " display several interesting effects. First, we can clearly see that \
dispersion causes the packet to spread, just as in the discussion of freely \
propagating packets in Sec. ",
  ButtonBox["5.1.2",
    ButtonData:>{"Chapter5.nb", "c:7"},
    ButtonStyle->"Hyperlink"],
  ".  Second, during the reflection, there is a complex interference pattern \
produced as the reflected packet travels back through the incident packet.  \
Third, a fair fraction of the wave packet is transmitted through the barrier, \
which runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " to 1. A classical particle with energy 12.5 would have been reflected \
from this barrier, which has potential 15. This is the well-known phenomenon \
of ",
  StyleBox["quantum tunneling",
    FontSlant->"Italic"],
  " through a classically forbidden region. "
}], "Text",
  CellTags->"i:16"],

Cell[TextData[{
  "\tOne can also see something else in this simulation: with a speed of 5 in \
our scaled units, the center of a freely propagating wave packet would have \
made it to position ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\(-5\) + 5  \[Tau] = 7\)\)]],
  " in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  ". However, the center of the packet in our simulation has actually made it \
",
  StyleBox["farther",
    FontSlant->"Italic"],
  " than this: the animation clearly shows that the center of the packet is \
roughly at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 9\)]],
  "  at time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2.4\)]],
  ". Adding a potential barrier that creates a classically forbidden region \
has actually ",
  StyleBox["increased",
    FontSlant->"Italic"],
  " the average group velocity of the transmitted part of the packet.  Note \
that the width of the potential barrier was ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", which is just the observed increase in position compared to free \
propagation.  It is as if the wave packet were ",
  "instantaneously transported ",
  "across the forbidden zone. "
}], "Text"],

Cell[TextData[{
  "\tThis phenomenon is referred to in the literature  as ",
  StyleBox["superluminal pulse propagation. ",
    FontSlant->"Italic"],
  "Actually, this  is something of a misnomer. A detailed analysis of the \
pulse propagation shows that it does not violate the tenets of special \
relativity, because the ",
  "wave packet",
  " has components that rapidly disperse (the leading edge of the packet is \
far in advance of the pulse center.).  These forward components already \
signal the arrival of the packet, and they are causal, always travelling at \
speeds less than or equal to that of light. "
}], "Text",
  CellTags->"i:15"],

Cell[TextData[{
  "\tSuperluminal propagation can also occur in classical systems, such as \
light travelling in a dispersive medium.  Although this phenomenon is \
well-known, it has recently received renewed attention [see, for example,  ",
  ButtonBox["Winful (2003)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell["\<\
\t The reader is invited to vary the parameters in this simulation \
in order to further study these phenomena. Questions that one might ask are: \
how does the mean group velocity of the transmitted packet vary with barrier \
height and width, and as a function of the initial packet speed and width? \
What fraction of the packet is transmitted as a function of these parameters? \
How is the dispersion of the packet affected by the barrier? (Caution: The \
simulation runs rather slowly on older machines, due to the large number of \
modes that must be kept.)\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.1", "Subsubtitle",
  CellTags->"c:12"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  "  Use the Galerkin method to solve for the potential in the grounded \
charge-filled enclosure of Fig. ",
  ButtonBox["6.4",
    ButtonData:>"Fig. 6.4",
    ButtonStyle->"Hyperlink"],
  ". The potential satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = \ \(-x\)\)]],
  ", and is zero on the walls. Plot the resulting potential as a contour \
plot, and find the place where the potential is minimum. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000UB000`400?l00000o`00003oooooool]
ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`002?oooooo0?oooa`0oooo2Ooo
ool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703oool9ooooo`002?oooooo0?oooa`0
oooo2Oooool000Sooooo203oool00`30`<00P8200<30`00F0?ooo`030<30`03oool0oooo01L0oooo
00<0`<300820P030`<00g@3oool9ooooo`002?ooool70?ooo`030820P0000000@41001L0oooo00<0
00000<30`03oool0603oool00`10@40000000820P03L0?ooo`Wooooo0008ooooo`H0oooo00<0@410
00000010@400603oool00`30`<0000000<30`00I0?ooo`030410@0000000@4100=/0oooo2Oooool0
00Sooooo1@3oool01020P800000000000020P80I0?ooo`0300000020P800oooo01P0oooo00@0P820
000000000000P820B@3oool00`20P80000000820P00F0?ooo`030820P03oool0oooo01L0oooo00<0
P820000000000000F`3oool9ooooo`002?ooool50?ooo`030410@0000000P82001X0oooo00<0P820
0000003oool06@3oool00`20P80000000410@0180?ooo`030<30`0000000@41001L0oooo00<0P820
0410@03oool0603oool00`10@40000000410@01J0?ooo`Wooooo0008ooooo`@0oooo00<0P8200000
0010@4002`3oool00`30`<00P82000000002000000030410@020P800oooo00L0oooo00<0P8200410
@00000002@3oool00`20P800@41000000002000000030820P030`<00oooo00X0oooo00<0@4100000
0020P800AP3oool00`20P80000000410@00I0?ooo`80@4106@3oool00`20P80000000410@01I0?oo
o`Wooooo0008ooooo`@0oooo0P0000000`30`<00oooo0?ooo`070?ooo`030<30`020P800000000H0
000000<0@4100<30`03oool01@3oool3000000L0oooo00<0`<300410@00000001P0000000`20P800
`<300?ooo`080?ooo`030<30`0000000000004D0oooo00@0P820000000000000`<306@3oool00`30
`<0000000820P00I0?ooo`030410@0000000P82005P0oooo2Oooool000Sooooo0`3oool00`20P800
00000000000:0?ooo`040410@000000000000410@0<0oooo00@0`<30000000000000@4101P3oool3
000000L0oooo00@0@410000000000000`<300`3oool01010@400000000000010@40:0?ooo`800000
00<0P8200?ooo`3oool0@@3oool01030`<00000000000020P80K0?ooo`8000002P3oool01030`<00
P8200820P030`<0<0?ooo`80000000<0`<300?ooo`3oool0E@3oool9ooooo`002?ooool30?ooo`03
0820P0000000P82000T0oooo00@0P82000000000000000001@3oool01020P8000000000000000005
0?ooo`<000001P3oool3000000030820P03oool0oooo00<0oooo0`0000000`20P800oooo0?ooo`07
0?ooo`030820P0000000P82004<0oooo00<0P8200000000000003P3oool3000000T0oooo00@0P820
0000000000000000203oool00`20P800000000000004000000030820P03oool0oooo00P0oooo00<0
P82000000020P800E`3oool9ooooo`002?ooool30?ooo`80000000<0P8200?ooo`3oool01`3oool0
1010@400000000000030`<060?ooo`040410@000000000000<30`0`0oooo00@0`<30000000000000
@4101P3oool01030`<00000000000010@4090?ooo`030820P0000000000004<0oooo0P0000000`20
P800oooo0?ooo`0<0?ooo`<000002@3oool01020P80000000000000000070?ooo`030820P0000000
000000H0000000<0P8200?ooo`3oool01`3oool00`30`<0000000000001G0?ooo`Wooooo0008oooo
o`<0oooo0P0000000`20P800oooo0?ooo`060?ooo`040<30`00000000000000000L0oooo00@0P820
000000000000@410303oool01010@400000000000020P8070?ooo`<0000000<0`<300?ooo`3oool0
1P3oool00`20P8000000000000120?ooo`030820P0000000000000l0oooo0`0000090?ooo`040820
P00000000000000000H0oooo00D0`<3000000000000000000<30`0020?ooo`050<30`00000000000
00000030`<002@3oool3000005H0oooo2Oooool000Sooooo0P3oool3000000T0oooo00<0P8200000
000000002@3oool3000000`0oooo0`0000090?ooo`80000000<0P8200?ooo`3oool01`3oool30000
0440oooo00<0@41000000020P8003`3oool3000000T0oooo00@0`<300820P020P800P8201P3oool2
000000030410@03oool0oooo00@0oooo00<0@4100000000000002@3oool01020P800000000000030
`<1E0?ooo`Wooooo0008ooooo`80oooo0`0000090?ooo`030410@0000000@41000T0oooo00@0@410
000000000000`<302P3oool01030`<00000000000010@4090?ooo`030410@0000000@41000T0oooo
0`0000110?ooo`80000000<0P8200?ooo`3oool03@3oool300000180oooo00<0P820000000000000
203oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000P820E@3oool9ooooo`00
2?ooool20?ooo`<000002@3oool2000000030820P03oool0oooo00L0oooo00@0P820000000000000
P8202P3oool01020P800000000000020P8090?ooo`030820P0000000000000T0oooo0`0000110?oo
o`80000000<0P8200?ooo`3oool03@3oool300000180oooo0`0000080?ooo`<00000203oool01020
P800000000000020P81E0?ooo`Wooooo0008ooooo`80oooo0`0000090?ooo`80000000<0P8200?oo
o`3oool01`3oool01020P800000000000020P80:0?ooo`040820P000000000000820P0T0oooo00<0
P8200000000000002@3oool300000400oooo00<0P820000000000000403oool300000180oooo0P00
00000`20P800oooo0?ooo`060?ooo`030820P0000000000000T0oooo0`00001E0?ooo`Wooooo0008
ooooo`80oooo0`0000090?ooo`80000000<0P8200?ooo`3oool01`3oool01020P800000000000020
P80:0?ooo`040820P000000000000820P0T0oooo00<0P8200000000000002@3oool300000400oooo
00<0P820000000000000403oool300000140oooo00@0P820000000000000`<30203oool01030`<00
000000000020P8080?ooo`<00000E@3oool9ooooo`002?ooool20?ooo`<000002@3oool200000003
0820P03oool0oooo00L0oooo00@0P820000000000000P8202P3oool01020P800000000000020P809
0?ooo`030820P0000000000000T0oooo0`0000100?ooo`030820P000000000000100oooo0`00000A
0?ooo`<000002P3oool3000000P0oooo0`00001E0?ooo`Wooooo0008ooooo`80oooo00@0P8200000
00000000`<30203oool2000000030820P03oool0oooo00L0oooo00@0P820000000000000P8202P3o
ool01020P800000000000020P8090?ooo`030820P0000000000000P0oooo00@0`<30000000000000
P820@03oool00`20P80000000000000@0?ooo`<000004@3oool3000000X0oooo0`0000080?ooo`<0
0000E@3oool9ooooo`002?ooool30?ooo`80000000<0P8200?ooo`3oool01P3oool2000000030820
P03oool0oooo00L0oooo00@0P820000000000000P8202P3oool01020P800000000000020P8090?oo
o`030820P0000000000000P0oooo00<0P820000000000000@@3oool00`20P80000000000000@0?oo
o`<000004@3oool3000000X0oooo0`0000080?ooo`<00000E@3oool9ooooo`002?ooool30?ooo`80
000000<0P8200?ooo`3oool01P3oool00`10@40000000410@0090?ooo`040410@000000000000<30
`0X0oooo00@0`<30000000000000@4102@3oool00`10@40000000410@0080?ooo`030820P0000000
00000440oooo00<0P820000000000000403oool300000140oooo0`00000:0?ooo`<00000203oool3
000005D0oooo2Oooool000Sooooo0`3oool00`20P80000000410@0080?ooo`030820P00000000000
00T0oooo0`00000<0?ooo`<000002@3oool2000000030820P03oool0oooo00H0oooo00<0@4100000
0020P800@@3oool01030`<00000000000030`<0?0?ooo`<000004@3oool3000000X0oooo0`000007
0?ooo`040<30`000000000000410@5D0oooo2Oooool000Sooooo0`3oool00`30`<00000000000008
0?ooo`040<30`00000000000000000L0oooo00@0P820000000000000@410303oool01010@4000000
00000020P8070?ooo`<0000000<0`<300?ooo`3oool01P3oool2000000030<30`03oool0oooo0400
oooo0P0000000`20P800oooo0?ooo`0=0?ooo`<000004@3oool3000000X0oooo0`0000070?ooo`04
0820P000000000000820P5D0oooo2Oooool000Sooooo103oool2000000030820P03oool0oooo00H0
oooo0`0000070?ooo`040820P000000000000820P0`0oooo00@0P820000000000000P8201`3oool3
000000P0oooo00<0P820000000000000@`3oool2000000030820P03oool0oooo00d0oooo0`00000B
0?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P8000000000000080?ooo`040820P0000000
00000820P5D0oooo2Oooool000Sooooo103oool00`20P80000000410@0080?ooo`040820P0000000
00000410@0D0oooo00@0`<3000000000000000003P3oool3000000030<30`03oool0oooo00<0oooo
00@0@410000000000000P820203oool00`10@40000000820P0130?ooo`030820P0000000@41000l0
oooo0`00000B0?ooo`80000000<0P8200?ooo`3oool01P3oool00`20P8000000000000080?ooo`03
0410@0000000000005H0oooo2Oooool000Sooooo1@3oool00`10@40000000820P0080?ooo`040410
@000000000000410@0<0oooo00@0`<30000000000000@410403oool01010@400000000000030`<03
0?ooo`040410@000000000000410@0P0oooo00<0P82000000010@400A03oool00`30`<0000000000
000?0?ooo`<000004P3oool00`10@4000000000000080?ooo`80000000<0@4100?ooo`3oool01P3o
ool2000000030820P03oool0oooo05@0oooo2Oooool000Sooooo1@3oool01030`<00000000000020
P8070?ooo`030<30`020P800000000H0000000<0@4100<30`03oool03`3oool00`30`<00@4100000
0006000000030820P030`<00oooo00H0oooo00@0P820000000000000`<30A@3oool00`10@4000000
0000000:0?ooo`0400000020P800`<300?ooo`<000004P3oool01030`<00000000000030`<060?oo
o`040<30`000000000000<30`0L0oooo00<0P82000000010@400E`3oool9ooooo`002?ooool60?oo
o`040<30`000000000000<30`0P0oooo00<0`<300410@00000000`0000000`20P800oooo0?ooo`0B
0?ooo`030820P000000000000080000000<0@4100<30`03oool01`3oool01030`<00000000000030
`<160?ooo`040<30`000000000000820P0T0oooo1`00000C0?ooo`040410@000000000000820P0@0
oooo00@0P820000000000000@410203oool2000000030<30`03oool0oooo05D0oooo2Oooool000So
oooo203oool200000380oooo0P0000190?ooo`030820P0000000000000T0oooo1`00000D0?ooo`<0
000000@0P8200?ooo`3oool0P8200`0000080?ooo`030820P0000000P82005P0oooo2Oooool000So
oooo203oool00`30`<00P8200<30`00`0?ooo`030<30`020P800`<3004T0oooo00@0`<3000000000
0000P820203oool00`30`<00P82000000004000001@0oooo00<0P8200000000000001P0000000`20
P800oooo0?ooo`060?ooo`80000000<0`<300?ooo`3oool0EP3oool9ooooo`002?oooon90?ooo`03
0410@0000000`<3000X0oooo00@0`<300820P020P800P8205@3oool00`30`<00P820000000030000
00030820P030`<00oooo00H0oooo00@0`<30000000000000`<30F@3oool9ooooo`002?oooon:0?oo
o`030410@0000000`<300300oooo00@0`<30000000000000`<30FP3oool9ooooo`002?oooooo0?oo
oa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703oool9ooooo`002?oo
oooo0?oooa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008oooooaP0ooooR@00001j0?oo
o`Wooooo0008oooooaP0ooooRP0000000`20P800oooo0?ooo`1f0?ooo`Wooooo0008oooooaL0oooo
00@0`<30000000000000@410Q020P803000000030<30`03oool0oooo07H0oooo2Oooool000Sooooo
5`3oool00`10@400000000000002000000030<30`03oool0oooo07l0oooo00@0`<30000000000000
P820N@3oool9ooooo`002?oooolH0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0
OP3oool00`20P80000000410@01j0?ooo`Wooooo0008oooooaX0oooo00H0@4100000000000000000
0410@030`<1n0?ooo`80000000<0P8200?ooo`3oool0N03oool9ooooo`002?oooolL0?ooo`@00000
O@3oool00`20P80000000000001k0?ooo`Wooooo0008oooooa`0oooo00<0`<300000000000000P00
00000`10@400oooo0?ooo`1i0?ooo`030820P0000000@41007/0oooo2Oooool000Sooooo7P3oool0
1P10@4000000000000000000@4100<30`7T0oooo0P0000000`20P800oooo0?ooo`1i0?ooo`Wooooo
0008oooooal0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`1e0?ooo`<00000O03o
ool9ooooo`002?oooolQ0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0LP3oool0
1020P800000000000020P81l0?ooo`Wooooo0008ooooob80oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`1a0?ooo`030820P0000000000007d0oooo2Oooool000Sooooo8`3oool00`30
`<00000000000002000000030820P03oool0oooo0700oooo0`00001m0?ooo`Wooooo0008ooooobD0
oooo00D0P82000000000000000000410@01`0?ooo`040820P000000000000820P7d0oooo2Oooool0
00Sooooo9`3oool01@10@4000000000000000000@41006h0oooo0`00001n0?ooo`Wooooo0008oooo
obP0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`1Y0?ooo`030<30`00000000000
07l0oooo2Oooool000Sooooo:@3oool00`20P800000000000002000006/0oooo00<0P82000000000
0000O`3oool9ooooo`002?ooool[0?ooo`050410@0000000000000000020P800J@3oool200000003
0820P03oool0oooo07d0oooo2Oooool000Sooooo;03oool00`30`<00000000000002000000030<30
`03oool0oooo06@0oooo00<0`<30000000000000P03oool9ooooo`002?ooool]0?ooo`030<30`010
@40000000080000000<0@4100?ooo`3oool0H`3oool00`10@40000000410@0200?ooo`Wooooo0008
ooooobl0oooo00H0P8200410@000000000000410@020P81R0?ooo`040820P000000000000<30`800
oooo2Oooool000Sooooo<@3oool4000000030820P03oool0oooo05l0oooo0`0000210?ooo`Wooooo
0008oooooc80oooo00D0@41000000000000000000410@01O0?ooo`040<30`000000000000820P840
oooo2Oooool000Sooooo<`3oool01P20P8000000000000000000@4100<30`5d0oooo00@0@4100000
00000000`<30P@3oool9ooooo`002?oooole0?ooo`060820P0000000000000000020P800`<30F`3o
ool2000000030410@03oool0oooo0800oooo2Oooool000Sooooo=P3oool00`30`<00@41000000002
000000030<30`03oool0oooo05L0oooo00@0P820000000000000P820PP3oool9ooooo`002?oooolh
0?ooo`@0000000<0P8200?ooo`3oool0EP3oool3000008<0oooo2Oooool000Sooooo>03oool00`30
`<00P82000000002000000030820P03oool0oooo05@0oooo00@0`<30000000000000P820P`3oool9
ooooo`002?oooolj0?ooo`030<30`010@40000000080000000<0P8200?ooo`3oool0DP3oool00`20
P80000000410@0240?ooo`Wooooo0008oooooc`0oooo00D0P82000000000000000000410@01C0?oo
o`80000000<0P8200?ooo`3oool0PP3oool9ooooo`002?oooolm0?ooo`030820P000000000000080
0000D@3oool00`20P8000000000000250?ooo`Wooooo0008oooooch0oooo00H0P8200410@0000000
00000410@020P81?0?ooo`030410@0000000@41008D0oooo2Oooool000Sooooo@03oool01@20P800
0000000000000000@41004h0oooo0P0000000`30`<00oooo0?ooo`230?ooo`Wooooo0008oooood40
oooo00<0`<300410@00000000P0000000`30`<00oooo0?ooo`190?ooo`<00000QP3oool9ooooo`00
2?oooom30?ooo`030820P000000000000080000000<0`<300?ooo`3oool0AP3oool01020P8000000
00000020P8260?ooo`Wooooo0008ooooodD0oooo100000180?ooo`030820P0000000000008L0oooo
2Oooool000SoooooA@3oool00`30`<00@41000000002000000030<30`03oool0oooo04@0oooo0`00
00270?ooo`Wooooo0008ooooodL0oooo00D0P8200410@000000000000410@0140?ooo`040820P000
000000000820P8L0oooo2Oooool000SoooooB@3oool01@10@4000000000000000000@4100480oooo
0`0000280?ooo`Wooooo0008ooooodX0oooo00H0`<3000000000000000000410@030`<0o0?ooo`03
0<30`0000000000008T0oooo2Oooool000SoooooC03oool4000003l0oooo00<0P820000000000000
R@3oool9ooooo`002?oooom=0?ooo`050820P0000000000000000020P800?@3oool2000000030820
P03oool0oooo08L0oooo2Oooool000SoooooCP3oool01P30`<000000000000000000@4100<30`3X0
oooo00<0P820000000000000RP3oool9ooooo`002?oooom@0?ooo`050410@0000000000000000020
P800>@3oool00`10@40000000820P02:0?ooo`Wooooo0008oooooe80oooo00@0@410000000000000
@410=`3oool01020P800000000000030`<2:0?ooo`Wooooo0008oooooe<0oooo00D0P82000000000
000000000820P00e0?ooo`<00000R`3oool9ooooo`002?oooomD0?ooo`050410@000000000000000
0020P800<`3oool01030`<00000000000020P82;0?ooo`Wooooo0008oooooeD0oooo00D0`<300000
0000000000000410@00b0?ooo`040410@000000000000<30`8/0oooo2Oooool000SoooooE`3oool0
1@30`<000000000000000000P82002l0oooo00@0`<30000000000000@410S03oool9ooooo`002?oo
oomI0?ooo`050410@0000000000000000030`<00;@3oool01020P800000000000030`<2<0?ooo`Wo
oooo0008oooooeX0oooo100000000`20P800oooo0?ooo`0Z0?ooo`<00000S@3oool9ooooo`002?oo
oomK0?ooo`050820P0000000000000000030`<00:P3oool01030`<00000000000020P82=0?ooo`Wo
oooo0008oooooed0oooo00D0@41000000000000000000<30`00X0?ooo`030410@0000000@41008h0
oooo2Oooool000SoooooGP3oool01@30`<000000000000000000@41002L0oooo0P0000000`30`<00
oooo0?ooo`2<0?ooo`Wooooo0008oooooel0oooo00H0`<300820P000000000000410@030`<0T0?oo
o`030820P0000000000008l0oooo2Oooool000SoooooH@3oool01020P800000000000000000T0?oo
o`80000000<0P8200?ooo`3oool0S@3oool9ooooo`002?oooomR0?ooo`050<30`000000000000000
0010@4008P3oool2000000030<30`03oool0oooo08d0oooo2Oooool000SoooooI03oool01@10@400
000000000010@400`<3001l0oooo0`00002@0?ooo`Wooooo0008ooooofD0oooo00D0P8200410@000
000000000820P00M0?ooo`040820P000000000000820P900oooo2Oooool000SoooooI`3oool01@20
P8000000000000000000P82001/0oooo0`00002A0?ooo`Wooooo0008ooooofP0oooo00D0P8200000
0000000000000820P00J0?ooo`80000000<0P8200?ooo`3oool0S`3oool9ooooo`002?oooomY0?oo
o`050<30`0000000000000000020P800603oool01020P800000000000020P82A0?ooo`Wooooo0008
ooooof/0oooo00D0P820000000000000@4100820P00F0?ooo`<00000TP3oool9ooooo`002?oooom/
0?ooo`050<30`010@400000000000010@400503oool00`30`<0000000000002C0?ooo`Wooooo0008
ooooofh0oooo00D0P82000000000000000000<30`00B0?ooo`030410@0000000@41009<0oooo2Ooo
ool000SoooooL03oool3000000030820P03oool0oooo00l0oooo0P0000000`20P800oooo0?ooo`2A
0?ooo`Wooooo0008ooooog00oooo00D0`<300410@000000000000820P00?0?ooo`030820P0000000
000009@0oooo2Oooool000SoooooLP3oool01@20P8000000000000000000`<3000d0oooo00<0@410
00000020P800U03oool9ooooo`002?oooomc0?ooo`050<30`020P800000000000010@4002`3oool0
1020P800000000000030`<2D0?ooo`Wooooo0008ooooogD0oooo00D0`<30000000000000@4100820
P0080?ooo`040<30`000000000000410@0P0oooo00<0@41000000030`<00=`3oool20820P4<0oooo
00@0`<30000000000000`<302P3oool9ooooo`002?oooomg0?ooo`<0000000<0P8200?ooo`3oool0
1@3oool01020P800000000000020P8070?ooo`80000000<0P8200?ooo`3oool0=P3oool00`20P800
00000820P0140?ooo`8000002P3oool9ooooo`002?oooomg0?ooo`050<30`010@400000000000010
@4001P3oool00`10@4000000000000070?ooo`030410@0000000@41003X0oooo00<0P82000000030
`<00@`3oool00`30`<0000000410@0090?ooo`Wooooo0008ooooogT0oooo00D0P8200410@0000000
00000<30`0030?ooo`040<30`000000000000410@0H0oooo00@0P820000000000000`<30>`3oool2
0410@4@0oooo00<0@41000000020P800203oool9ooooo`002?oooomk0?ooo`070410@00000000000
0820P030`<00oooo0820P002000000030<30`03oool0oooo00<0oooo00<0`<300000000000002`3o
ool50820P0P0oooo0`20P80R0?ooo`030820P0000000oooo01h0oooo0`20P80S0?ooo`80000000<0
P8200?ooo`3oool01@3oool9ooooo`002?ooooml0?ooo`050<30`0000000000000000020P8000`00
00060?ooo`030410@0000000P82000T0oooo00<0@4100000000000001@0000000`10@400oooo0?oo
o`040?ooo`040820P000000000000<30`1D0oooo0`0000070?ooo`040820P00000000000000001@0
oooo0`0000090?ooo`80000000<0`<300?ooo`3oool02`3oool=000000P0oooo00@0P82000000000
0000`<301P3oool9ooooo`002?oooomn0?ooo`D000001`3oool2000000T0oooo00<0P82000000000
0000200000060?ooo`80000000<0P8200?ooo`3oool04`3oool3000000L0oooo00@0P82000000000
00000000503oool3000000T0oooo00<0P82000000020P8003@3oool=000000T0oooo0P0000000`20
P800oooo0?ooo`040?ooo`Wooooo0008ooooogl0oooo00@0P820000000000000@4101P3oool00`20
P8000000000000080?ooo`050<30`0000000000000000020P800103oool01010@400000000000030
`<050?ooo`030820P0000000@41001D0oooo0`0000070?ooo`040820P00000000000000001@0oooo
0`0000090?ooo`030<30`0000000@41000d0oooo0P0000000`10@400P8200820P0080820P0T0oooo
0`0000060?ooo`Wooooo0008oooooh00oooo00<0P82000000030`<001P3oool00`10@40000000820
P0080?ooo`030820P0000000000000L0oooo00<0@4100000000000001P3oool00`10@40000000<30
`00D0?ooo`<000001`3oool01030`<00P8200820P020P80D0?ooo`<000002P3oool00`10@4000000
0<30`00<0?ooo`80000000<0P8200?ooo`3oool04@3oool01020P800000000000030`<050?ooo`Wo
oooo0008ooooohT0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`040<30`000000000000820P0D0
oooo00<0`<3000000010@400503oool3000001l0oooo0`00000:0?ooo`030<30`0000000@41000`0
oooo00<0P82000000010@4004`3oool01020P800000000000020P8050?ooo`Wooooo0008ooooohT0
oooo0P0000000`20P800oooo0?ooo`0A0?ooo`<000001P3oool2000001@0oooo0`00000O0?ooo`<0
00002`3oool2000000`0oooo00<0P8200000000000004`3oool01020P800000000000020P8050?oo
o`Wooooo0008ooooohP0oooo0`00000D0?ooo`<000001P3oool00`20P80000000820P00:0?ooo`T0
P8200`0000030820P1`0oooo0`00000;0?ooo`030820P0000000000000`0oooo0`0000000`30`<00
oooo0?ooo`0@0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`<00000503oool3000000H0oooo
00<0`<300000000000002P3oool?000001`0oooo0`00000;0?ooo`040<30`000000000000820P0/0
oooo00D0`<3000000000000000000<30`00A0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`<0
00004`3oool00`10@4000000000000080?ooo`030410@0000000000000T0oooo0`0000060820P0<0
00000`20P80L0?ooo`<00000303oool00`10@40000000000000<0?ooo`050<30`000000000000000
0030`<00403oool3000000D0oooo2Oooool000SoooooR03oool300000180oooo00@0@41000000000
0000@410203oool01030`<00000000000020P8090?ooo`030410@0000000P82000D0oooo0`00000O
0?ooo`<00000303oool01030`<00000000000020P80=0?ooo`040410@000000000000820P0l0oooo
0`0000050?ooo`Wooooo0008ooooohP0oooo0`00000@0?ooo`030820P00000000000008000002P3o
ool3000000T0oooo00<0P8200000000000001@3oool3000001l0oooo0`00000=0?ooo`<000003P3o
ool4000000h0oooo0`0000050?ooo`Wooooo0008ooooohP0oooo0`00000=0?ooo`H0000000<0@410
0<30`03oool02@3oool01020P800000000000030`<090?ooo`030410@0000000P82000@0oooo0`00
000O0?ooo`<000003P3oool2000000030<30`03oool0oooo00/0oooo00D0`<300410@00000000000
0410@00=0?ooo`<000001@3oool9ooooo`002?oooon80?ooo`040820P000000000000<30`0`0oooo
1@0000000`20P800`<300?ooo`0;0?ooo`80000000<0@4100?ooo`3oool0203oool2000000040820
P03oool0oooo0?ooo`<000007`3oool3000000h0oooo00<0P82000000010@4003`3oool01010@400
000000000010@40;0?ooo`040<30`000000000000410@0D0oooo2Oooool000SoooooR@3oool20000
00030820P03oool0oooo00d0oooo00D0`<300820P000000000000<30`00<0?ooo`80000000<0`<30
0?ooo`3oool01`3oool01030`<00000000000020P8020?ooo`<000007`3oool3000000l0oooo0P00
00000`30`<00oooo0?ooo`0=0?ooo`040820P000000000000410@0X0oooo00@0P820000000000000
P8201@3oool9ooooo`002?oooon90?ooo`030410@0000000P8200140oooo00@0`<30000000000000
`<302`3oool00`20P80000000410@00:0?ooo`050410@000000000000<30`03oool00`00000O0?oo
o`<000003`3oool00`20P80000000410@00@0?ooo`030820P0000000000000X0oooo00@0P8200000
00000000`<301@3oool9ooooo`002?oooon90?ooo`030820P000000000000180oooo0P0000000`20
P800oooo0?ooo`0:0?ooo`8000002`3oool2000000030820P03oool00000008000007`3oool30000
0100oooo0P00000A0?ooo`80000000<0P8200?ooo`3oool01`3oool3000000H0oooo2Oooool000So
ooooR@3oool00`30`<0000000000000B0?ooo`030820P0000000000000`0oooo00<0@41000000030
`<002P3oool01020P800000000000030`<03000001l0oooo0`00000@0?ooo`030410@0000000P820
0100oooo0P0000000`20P800oooo0?ooo`070?ooo`80000000<0@4100?ooo`3oool0103oool9oooo
o`002?oooon:0?ooo`030410@0000000P82000L0oooo00<0`<300820P020P8001`3oool00`20P800
00000000000<0?ooo`030<30`0000000@41000/0oooo00<0P82000000010@4000`00000J0?ooo`05
0820P0000000P8200<30`03oool00`00000@0?ooo`040<30`000000000000<30`0D0oooo0P20P800
0`30`<00oooo0?ooo`050?ooo`80000000<0P8200?ooo`3oool01P3oool01020P800000000000030
`<060?ooo`Wooooo0008ooooohX0oooo00<0`<300000000000001`3oool01020P800000000000020
P8050?ooo`040<30`000000000000410@0d0oooo00<0@41000000020P8002`3oool00`10@4000000
00000002000001X0oooo00<0P8200000000000001@00000A0?ooo`030410@0000000@41000D0oooo
0P0000000`10@400oooo0?ooo`040?ooo`040410@000000000000<30`0P0oooo0P0000000`20P800
oooo0?ooo`050?ooo`Wooooo0008oooooh/0oooo00@0P820000000000000`<301P3oool01010@400
00000000000000030820P0@0000000<0`<300?ooo`3oool02`3oool01030`<00000000000030`<0;
0?ooo`@000006P3oool00`30`<0000000000000500000140oooo00@0`<30000000000000`<30103o
ool01@30`<000000000000000000@4100080P82000D0@41000000000000000000410@0080?ooo`03
0410@0000000P82000P0oooo2Oooool000SoooooS03oool2000000030820P03oool0oooo00D0oooo
2@0000000`20P800oooo0?ooo`0=0?ooo`80000000<0P8200?ooo`3oool02@3oool01020P8000000
00000000000M0?ooo`D000004P3oool2000000030820P03oool0oooo00<0oooo00<0P82000000000
00001`0000090?ooo`8000002@3oool9ooooo`002?oooon<0?ooo`040<30`000000000000<30`0H0
oooo00<0`<300820P010@400100000000`10@400P8200?ooo`0?0?ooo`030410@0000000000000`0
oooo0`20P80N0?ooo`040<30`020P800P8200820P180oooo00<0P8200000000000001P3oool20820
P0D0000000<0P8200<30`03oool01`3oool00`10@40000000<30`0090?ooo`Wooooo0008ooooohh0
oooo00<0@41000000030`<007P3oool01030`<00P8200820P030`<130?ooo`80P82000<0`<300?oo
o`3oool04P3oool01030`<00000000000030`<0:0?ooo`Wooooo0008ooooool0oooo703oool9oooo
o`002?oooooo0?oooa`0oooo2Oooool000Soooooo`3ooolL0?ooo`Wooooo0008ooooool0oooo703o
ool9ooooo`002?oooooo0?oooa`0oooo2Oooool00?oooooo;Oooool00?oooooo;Oooool00?oooooo
;Oooool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{100.062, 49.9375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.4 Exercise (1).", "Caption",
  CellTags->"Fig. 6.4"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A grounded toroidal conducting shell has a shape given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2/2\  + \ \((r - R)\)\^2 = a\^2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], z)\)\)]],
  " are cylindrical coordinates, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(R = 1\ meter\), " ", ",", " ", Cell["a=0.75 meter"]}], 
        TraditionalForm]]],
  ". Plot this shell using a ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The shell is filled with a uniform charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]/\[Epsilon]\_o\), "=", 
          RowBox[{"10", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Find and plot the contours of constant electrostatic potential in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, z)\)\)]],
  "plane. At what ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the potential maximum, and what is its value, to three significant \
figures?  (Hint: Solve Poisson's equation in cylindrical coordinates.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " A hemispherical shell of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " sits in the base of a cylindrical tube of the same radius (see Fig. ",
  ButtonBox["6.5",
    ButtonData:>"Fig. 6.5",
    ButtonStyle->"Hyperlink"],
  "). The top of the tube at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  " is flat, and the sides of the tube  are insulated. The interior of the \
tube is filled with material of some uniform thermal diffusivity. The \
hemisphere is held at fixed temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  ", and the top end of the tube is held at fixed temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  ". Use the Galerkin method to find the form of ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, z)\)]],
  " in equilibrium within the tube, for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1.5\)]],
  ". (Hint: Try basis functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(n\ m\)\)(r, 
          z) = \((r\^\(\(n\)\(\ \)\)\  - A(z)\ )\)\ \((a\^2\  - \ r\^2\  - \ 
              z\^2)\) \((L - z)\)\ z\^m\)]],
  ", and find the form of ",
  Cell[BoxData[
      \(TraditionalForm\`A(z)\)]],
  " required to match the von Neumann  boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ".)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W0001RB000`400?l00000o`00003ooooooonX
ooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonX
ooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonXooooo`00oooooonX
ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0oooo
T`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:oooo
ool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo
000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooDP3oool40820
P0D0oooo0P20P83o0?ooocH0oooo2oooool000[oooooD@3oool6000000<0oooo1@00003o0?oooc@0
oooo2oooool000[oooooD03oool00`20P800000000000005000000030?ooo`20P800000000@00000
00<0P8200?ooo`3oool0o`3ooola0?ooo`_ooooo000:oooooe00oooo100000030?ooo`D0000000@0
P8200?ooo`3oool0P820o`3ooolc0?ooo`_ooooo000:oooooe00oooo0`0000000`30`<00oooo0?oo
o`030?ooo`040410@000000000000820P?l0oooo=P3oool;ooooo`002_oooom@0?ooo`<000001P3o
ool01020P800000000000020P83o0?ooocH0oooo2oooool000[oooooD03oool3000000H0oooo00@0
P820000000000000P820o`3ooolf0?ooo`_ooooo000:oooooe00oooo00@0`<30000000000000`<30
1@3oool01020P800000000000020P83o0?ooocH0oooo2oooool000[oooooDP3oool2000000D0oooo
00@0P820000000000000P820o`3ooolf0?ooo`_ooooo000:oooooe<0oooo0P0000040?ooo`040820
P000000000000820P?l0oooo=P3oool;ooooo`002_oooomE0?ooo`D0P8200P0000000`20P800oooo
0?ooo`3o0?oooc@0oooo2oooool000[oooooF@3oool3000000030820P03oool0oooo0?l0oooo=03o
ool;ooooo`002_oooomI0?ooo`040820P000000000000820P?l0oooo=P3oool;ooooo`002_oooom@
0?ooo`040<30`000000000000<30`0D0oooo00@0P820000000000000P820o`3ooolf0?ooo`_ooooo
000:oooooe00oooo00@0P820000000000000P8201@3oool01020P800000000000020P83o0?ooocH0
oooo2oooool000[oooooD03oool01020P800000000000020P8050?ooo`030820P000000000000?l0
oooo=`3oool;ooooo`002_oooomA0?ooo`030820P0000000@41000@0oooo00@0P820000000000000
P820o`3ooolg0?ooo`_ooooo000:oooooe@0oooo1@0000000`20P800oooo0?ooo`3o0?ooocL0oooo
2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oo
oi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooobT0oooo0`20P83o0?ooofL0oooo
2oooool000[ooooo9`3oool500000?l0ooooI`3oool;ooooo`002_oooolT0?ooo`030820P0000000
000000D00000o`3ooomW0?ooo`_ooooo000:ooooob<0oooo2@00003o0?ooofL0oooo2oooool000[o
oooo7P3oool20820P0030410@0000000000000X00000o`3ooomV0?ooo`_ooooo000:oooooa`0oooo
4@00003o0?ooofH0oooo2oooool000[ooooo6P3ooolC000000030820P03oool0oooo0?l0ooooH`3o
ool;ooooo`002_oooolE0?ooo`80P82000<0@4100000000000004`0000000`20P800oooo0?ooo`3o
0?ooof<0oooo2oooool000[ooooo4`3ooolJ000000030820P03oool0oooo0?l0ooooH`3oool;oooo
o`002_oooolA0?ooo`030820P0000000000001T0000000<0P8200?ooo`3oool0o`3ooomS0?ooo`_o
oooo000:ooooo`d0oooo0P20P80O00000?l0ooooI@3oool;ooooo`002_ooool:0?ooo`030820P000
0000000009T00000k03oool;ooooo`002_ooool80?oooih00000k03oool;ooooo`002_ooool90?oo
o`@0P820V@00003/0?ooo`_ooooo000:ooooo`h0ooooV000003/0?ooo`_ooooo000:oooooa00oooo
7P00003o0?ooofD0oooo2oooool000[ooooo4@3oool01030`<00P8200820P010@40I00000?l0oooo
I@3oool;ooooo`002_oooolG0?oooaH0000000<0P8200?ooo`3oool0o`3ooomS0?ooo`_ooooo000:
oooooaT0oooo500000000`20P800oooo0?ooo`3o0?ooof<0oooo2oooool000[ooooo6P3oool00`30
`<00P8200820P00@000000030<30`03oool0oooo0?l0ooooH`3oool;ooooo`002_oooolO0?ooo`h0
0000o`3ooomV0?ooo`_ooooo000:ooooob00oooo00<0P8200000000000002P00003o0?ooofH0oooo
2oooool000[ooooo8`3oool20820P0L00000o`3ooomW0?ooo`_ooooo000:ooooobL0oooo00<0P820
0000000000000P00003o0?ooofL0oooo2oooool000[ooooo:P3oool00`000000oooo0?ooo`3o0?oo
ofH0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oo
oooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;oooo
o`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3o
ool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0
ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:
ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_o
oooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC
0?ooo`_ooooo000:ooooool0oooo?`3oool60820P2T0oooo00<0`<300?ooo`3oool08P3oool;oooo
o`002_oooooo0?ooocl0oooo1P00000Y0?ooo`030000003oool0oooo0280oooo2oooool000[ooooo
o`3ooolo0?ooo`H00000:@3oool2000002<0oooo2oooool000[ooooo0`3oool60820P?l0oooo=P3o
ool6000002P0oooo00@0P820000000000000P8208P3oool;ooooo`002_ooool30?ooo`H00000o`3o
oolf0?ooo`H00000:03oool400000280oooo2oooool000[ooooo0`3oool600000?l0oooo=P3oool6
000002P0oooo1000000R0?ooo`_ooooo000:ooooo`T00000o`3ooolf0?ooo`H000009`3oool60000
0240oooo2oooool000[ooooo2@00003o0?ooocH0oooo1P00000W0?ooo`H000008@3oool;ooooo`00
2_ooool900000?l0oooo=P3oool6000002H0oooo00<0P820000000000000100000000`20P800oooo
0?ooo`0N0?ooo`_ooooo000:ooooo`T00000o`3ooole0?ooo`L000009P3oool00`20P80000000000
0004000000030820P03oool0oooo01h0oooo2oooool000[ooooo2@00003o0?ooocD0oooo1`00000V
0?ooo`030410@0000000000000@0000000<0@4100?ooo`3oool07P3oool;ooooo`002_ooool:0000
0?l0oooo=03oool7000002H0oooo2000000P0?ooo`_ooooo000:ooooo`X00000o`3ooold0?ooo`L0
00009P3oool9000001l0oooo2oooool000[ooooo2P00003o0?oooc@0oooo1`00000U0?ooo`X00000
7`3oool;ooooo`002_ooool:00000?l0oooo=03oool7000002D0oooo2`00000N0?ooo`_ooooo000:
ooooo`X00000o`3ooold0?ooo`L00000903oool<000001h0oooo2oooool000[ooooo2P00003o0?oo
oc@0oooo1`00000T0?ooo``0000000<0`<300?ooo`3oool06`3oool;ooooo`002_ooool:00000?l0
oooo=03oool7000002<0oooo00<0P8200000000000002P0000000`20P800oooo0?ooo`0K0?ooo`_o
oooo000:ooooo`X00000o`3ooold0?ooo`L000008`3oool00`20P80000000000000:000000030820
P03oool0oooo01/0oooo2oooool000[ooooo2P00003o0?oooc<0oooo2000000S0?ooo`030410@000
0000000000X0000000<0@4100?ooo`3oool06`3oool;ooooo`002_ooool:00000?l0oooo<`3oool8
000002<0oooo3P00000M0?ooo`_ooooo000:ooooo`X0000000<0P8200?ooo`3oool0o`3oool`0?oo
o`P000008P3oool?000001d0oooo2oooool000[ooooo2P0000000`20P800oooo0?ooo`3o0?oooc00
oooo2000000R0?ooo`l0000000<0P8200?ooo`3oool06P3oool;ooooo`002_ooool:000000030820
P03oool0oooo0?l0oooo<03oool800000240oooo4@00000L0?ooo`_ooooo000:ooooo`X0000000<0
P8200?ooo`3oool0o`3oool_0?ooo`030820P0000000000000H000008@3ooolB000001/0oooo2ooo
ool000[ooooo2`00003o0?oooc40oooo00<0P8200000000000001P00000P0?ooo`030<30`0000000
00000100000000<0`<300?ooo`3oool0603oool;ooooo`002_ooool;00000?l0oooo<@3oool00`20
P80000000000000600000200oooo00<0P820000000000000400000000`20P800oooo0?ooo`0H0?oo
o`_ooooo000:ooooo`/00000o`3ooola0?ooo`030820P0000000000000H00000803oool00`20P800
00000000000@000000030820P03oool0oooo01P0oooo2oooool000[ooooo2`00003o0?oooc40oooo
00<0P8200000000000001P00000P0?oooa@000006P3oool;ooooo`002_ooool<00000?l0oooo<03o
ool900000200oooo5000000J0?ooo`_ooooo000:ooooo``00000o`3oool`0?ooo`T000007`3ooolE
000001X0oooo2oooool000[ooooo3000003o0?oooc00oooo2@00000O0?oooaH000006@3oool;oooo
o`002_ooool<000000030820P03oool0oooo0?l0oooo;@3oool9000001h0oooo00<0P82000000000
00005000000I0?ooo`_ooooo000:ooooo`d00000o`3oool^0?ooo`X000007P3ooolH000001P0oooo
2oooool000[ooooo1P0000000`3oool000000000000400000?l0oooo;P3oool:000001h0oooo6000
000H0?ooo`_ooooo000:ooooo`H0000000<0oooo000000000000100000000`20P800oooo0?ooo`3o
0?ooobX0oooo00<0P8200000000000002000000M0?ooo`030820P0000000000001H0000000<0P820
0?ooo`3oool05@3oool;ooooo`002_ooool6000000030?ooo`000000000000D00000o`3oool/0?oo
o`/00000803ooolD000001X0oooo2oooool000[ooooo1P0000000`3oool0P8200000000500000?l0
oooo;03oool;00000280oooo4000000L0?ooo`_ooooo000:ooooo`H0000000<0oooo0820P0000000
1@0000000`30`<00oooo0?ooo`3o0?ooobP0oooo00<0`<300000000000002@00000V0?ooo`<0P820
0`0000000`20P800`<300?ooo`0O0?ooo`_ooooo000:ooooo`H0000000<0oooo0820P00000001@00
00000`20P800oooo0?ooo`3o0?ooobP0oooo00<0P8200000000000002@00000Y0?ooo`<000008P3o
ool;ooooo`002_ooool600000080oooo1P0000000`20P800oooo0?ooo`3o0?ooobP0oooo00<0P820
0000000000002@00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000080oooo1P0000000`10
@400oooo0?ooo`3o0?ooobP0oooo00<0@4100000000000002@00000Y0?ooo`<000008P3oool;oooo
o`002_ooool600000080oooo1`00003o0?ooobX0oooo3000000Y0?ooo`<000008P3oool;ooooo`00
2_ooool6000000<0oooo1P00003o0?ooobX0oooo3000000Y0?ooo`<000008P3oool;ooooo`002_oo
ool6000000<0oooo1P0000000`20P800oooo0?ooo`3o0?ooobH0oooo00<0P8200000000000002P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000<0oooo1`00003o0?ooobP0oooo3@00000Y
0?ooo`<000008P3oool;ooooo`002_ooool6000000@0oooo1P00003o0?ooobP0oooo3@00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000000@0oooo1P0000000`20P800oooo0?ooo`3o0?ooob@0
oooo1`0000000`3oool0000000000004000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
103oool700000?l0oooo9P3oool7000000030?ooo`000000000000@00000:@3oool300000280oooo
2oooool000[ooooo1P0000040?ooo`030820P0000000000000@00000o`3ooolU0?ooo`030820P000
0000000000@000000P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000103oool0
0`20P800000000000004000000030820P03oool0oooo0?l0oooo8P3oool00`10@400000000000004
00000080oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000@0oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`3o0?ooob80oooo1P0000000`20P800oooo0?ooo`060000
02T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000001@3oool700000?l0oooo903oool600000003
0820P03oool0oooo00H00000:@3oool300000280oooo2oooool000[ooooo1P0000050?ooo`L00000
o`3ooolS0?ooo`L000000`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000001P3o
ool700000?l0oooo8P3oool7000000<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000000L0oooo1P00003o0?ooob40oooo1`0000040?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P0000070?ooo`L00000o`3ooolP0?ooo`L00000103oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H000001`3oool00`20P80000000000000400000?l0oooo7`3oool00`30`<00
000000000004000000030820P03oool0oooo0080oooo1P00000Y0?ooo`<000008P3oool;ooooo`00
2_ooool6000000P0oooo1P0000000`20P800oooo0?ooo`3o0?oooa`0oooo00<0P820000000000000
100000050?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P0000080?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool0o`3ooolL0?ooo`L000001@3oool6000002T0oooo0`00
000R0?ooo`_ooooo000:ooooo`H00000203oool00`20P80000000000000400000?l0oooo7P3oool6
000000030820P03oool0oooo00<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
00T0oooo1P00003o0?oooad0oooo1`0000060?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P0000090?ooo`L00000o`3ooolL0?ooo`L000001P3oool6000002T0oooo0`00000R0?ooo`_o
oooo000:ooooo`H000002P3oool6000000030820P03oool0oooo0?l0oooo603oool7000000030820
P03oool0oooo00@0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000/0oooo1P00
003o0?oooaT0oooo00<0P8200000000000001@0000070?ooo`H00000:@3oool300000280oooo2ooo
ool000[ooooo1P00000;0?ooo`H0000000<0P8200?ooo`3oool0o`3ooolF0?ooo`030820P0000000
000000@00000203oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000002`3oool00`20
P800000000000003000000030410@03oool0oooo0?l0oooo5P3oool6000000030410@03oool0oooo
00H0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000`0oooo1P00003o0?oooaP0
oooo1P0000000`20P800oooo0?ooo`060?ooo`H00000:@3oool300000280oooo2oooool000[ooooo
1P00000<0?ooo`L00000o`3ooolF0?ooo`L000002@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000003@3oool6000000030820P03oool0oooo0?l0oooo4P3oool00`20P80000000000
0004000000030820P03oool0oooo00L0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000000h0oooo1P00003o0?oooa@0oooo1`00000:0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00000>0?ooo`H0000000<0P8200?ooo`3oool0o`3oool@0?ooo`L000002`3oool60000
02T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000003P3oool00`20P80000000000000300000003
0410@03oool0oooo0?l0oooo3`3oool00`30`<00000000000004000000030410@03oool0oooo00T0
oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000000l0oooo1P00003o0?oooa40oooo
1`0000000`20P800oooo0?ooo`090?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00
000?0?ooo`L00000o`3oool@0?ooo`L00000303oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000403oool600000?l0oooo3`3oool8000000`0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool600000100oooo00<0P820000000000000100000000`30`<00oooo0?ooo`3o0?oo
o`X0oooo2000000=0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000A0?ooo`H0
000000<0P8200?ooo`3oool0o`3oool90?ooo`030820P0000000000000D000003P3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H000004@3oool00`20P80000000000000400000?l0oooo
2`3oool00`20P800000000000005000000h0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_oo
ool600000140oooo00<0P8200000000000001@00003o0?ooo`T0oooo00<0P8200000000000001@00
00000`20P800oooo0?ooo`0<0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000B
0?ooo`P00000o`3oool80?ooo`P000003`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H000004P3oool8000000030820P03oool0oooo0?l0oooo103oool9000000l0oooo1P00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000001<0oooo00<0P820000000000000100000000`10@400
oooo0?ooo`3o0?ooo`<0oooo00<0P8200000000000001@0000000`20P800oooo0?ooo`0>0?ooo`H0
0000:@3oool300000280oooo2oooool000[ooooo1P00000D0?ooo`L00000o`3oool50?ooo`P00000
4@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000503oool00`20P80000000000
000500000?l0oooo0`3oool800000180oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000001D0oooo2000003o0?ooo`40oooo00<0P8200000000000001@0000000`10@400oooo0?ooo`0@
0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000F0?ooo`P00000o`3oool80000
01<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000001H0oooo200000000`20P800
oooo0?ooo`3l0?ooo`P000004`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
5`3oool00`10@400000000000004000000030410@03oool0oooo0?/0oooo00<0@410000000000000
1@00000D0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000G0?ooo`030820P000
0000000000H00000n`3oool8000001D0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
000001P0oooo2@00003j0?ooo`L000005P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H000006@3oool8000000030<30`03oool0oooo0?D0oooo00<0`<300000000000001@0000000`20
P800oooo0?ooo`0D0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000J0?ooo`P0
0000m`3oool7000001P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000001X0oooo
00<0P8200000000000001P00003f0?ooo`L00000603oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000006`3oool8000000030820P03oool0oooo0?40oooo00<0P8200000000000001@00
00000`30`<00oooo0?ooo`0F0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000L
0?ooo`P0000000<0P8200?ooo`3oool0k`3oool00`20P800000000000006000001T0oooo1P00000Y
0?ooo`<000008P3oool;ooooo`002_ooool6000001d0oooo2000003a0?ooo`030820P00000000000
00D000006P3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000007P3oool700000003
0820P03oool0oooo0>`0oooo0P20P806000000030410@03oool0oooo01T0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool6000001h0oooo00<0P8200000000000001P00003/0?ooo`030820
P0000000000000H0000000<0P8200?ooo`3oool06@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H000007`3oool8000000030820P03oool0oooo0>T0oooo2@00000L0?ooo`H00000:@3o
ool300000280oooo2oooool000[ooooo1P00000P0?ooo`L0000000<0P8200?ooo`3oool0j@3oool8
000001d0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000200oooo00<0P8200000
000000001P0000000`20P800oooo0?ooo`3U0?ooo`030820P0000000000000H0000000<0P8200?oo
o`3oool06`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H000008@3oool00`20P800
000000000006000000030820P03oool0oooo0><0oooo2@00000O0?ooo`H00000:@3oool300000280
oooo2oooool000[ooooo1P00000R0?ooo`P0000000<0P8200?ooo`3oool0hP3oool00`20P8000000
0000000600000200oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000280oooo00<0
P8200000000000001P0000000`20P800oooo0?ooo`3P0?ooo`030820P0000000000000H000008@3o
ool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000903oool00`20P800000000000006
00000>40oooo200000000`20P800oooo0?ooo`0O0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00000U0?ooo`P0000000<0P8200?ooo`3oool0g@3oool900000280oooo1P00000Y0?oo
o`<000008P3oool;ooooo`002_ooool6000002H0oooo200000000`20P800oooo0?ooo`3K0?ooo`03
0410@0000000000000D0000000<0P8200?ooo`3oool08@3oool6000002T0oooo0`00000R0?ooo`_o
oooo000:ooooo`H000009`3oool900000=/0oooo200000000`20P800oooo0?ooo`0R0?ooo`H00000
:@3oool300000280oooo2oooool000[ooooo1P00000W0?ooo`030820P0000000000000H00000fP3o
ool9000002D0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000002P0oooo00<0P820
0000000000001@0000000`10@400oooo0?ooo`1h0?ooo`030820P0000000000000D0P820EP3oool0
0`10@400000000000006000000030820P03oool0oooo02<0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool6000002X0oooo2000001g0?ooo`<000001P3oool2000000030820P03oool0oooo
0540oooo2@00000W0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000Z0?ooo`03
0820P0000000000000H00000M@3oool01020P800000000000020P8070?ooo`800000DP3oool90000
02P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000002/0oooo2@0000000`30`<00
oooo0?ooo`1a0?ooo`<000002@3oool200000500oooo00<0@4100000000000001P0000000`30`<00
oooo0?ooo`0V0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000/0?ooo`X00000
L@3oool3000000X0oooo00<0P820000000000000C@3oool:000002X0oooo1P00000Y0?ooo`<00000
8P3oool;ooooo`002_ooool6000002d0oooo2P00001`0?ooo`<000002P3oool00`20P80000000000
001<0?ooo`030820P0000000000000L00000:`3oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000;@3oool00`30`<00P82000000007000000030410@03oool0oooo06`0oooo0`000000
0`20P800oooo0?ooo`080?ooo`040820P00000000000000004X0oooo00<0P8200000000000001P00
00000`20P800oooo0?ooo`0Z0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00000`
0?ooo`T00000K@3oool3000000/0oooo00@0P8200000000000000000B@3oool9000002h0oooo1P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool600000300oooo00<0P8200000000000001`00001/
0?ooo`<000002`3oool01020P80000000000000000180?ooo`030820P0000000000000H0000000<0
P8200?ooo`3oool0;03oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000<P3oool0
0`20P800000000000006000000030820P03oool0oooo05H0oooo00<0P8200410@000000010000000
0`10@400P8200?ooo`080?ooo`<000002`3oool01020P80000000000000000160?ooo`80P8202000
00000`20P800oooo0?ooo`0]0?ooo`H00000:@3oool3000000X0oooo00<0`<300820P00000004P00
00000`20P800oooo0?ooo`0;ooooo`002_ooool6000003@0oooo2@00001J0?ooo`<00000303oool3
000000/0oooo100000150?ooo`030820P0000000000000L00000<@3oool6000002T0oooo0`00000=
0?ooo`040820P00000000000000000X0oooo1@0000020?ooo`_ooooo000:ooooo`H00000=03oool0
0`20P800000000000006000000030820P03oool0oooo05L0oooo0`00000=0?ooo`8000002`3oool3
000004H0oooo2@00000b0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P820303o
ool00`20P8000000000000020?ooo`_ooooo000:ooooo`H00000=@3oool9000005T0oooo0`00000=
0?ooo`8000002`3oool3000004@0oooo2P00000c0?ooo`H00000:@3oool3000000d0oooo00@0P820
000000000000P8203@3oool2000000030820P03ooooooooo00[ooooo000:ooooo`H00000=P3oool0
0`20P800@41000000007000000030<30`03oool0oooo05@0oooo0`00000>0?ooo`8000002@3oool3
000000030820P03oool0oooo0400oooo00<0`<300000000000002000000d0?ooo`H00000:@3oool3
000000d0oooo00@0P820000000000000P8203P3oool20820P0030?oooooooooooooo00Wooooo000:
ooooo`H00000>03oool:000005D0oooo0`00000>0?ooo`030820P0000000000000L0oooo0`000013
0?ooo`/0000000<0P8200?ooo`3oool0<P3oool6000002T0oooo0`00000=0?ooo`040820P0000000
00000820P0l0oooo00<000000?ooooooool02_ooool000[ooooo1P00000i0?ooo`X00000E03oool3
000000l0oooo0P0000000`20P800oooo0?ooo`030?ooo`040820P000000000000820P480oooo2`00
000f0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_oo
ool6000003X0oooo00<0@4100000000000001`0000000`20P800oooo0?ooo`1@0?ooo`<00000403o
ool60820P00300000010@400P8200480oooo00<0P8200410@0000000200000000`10@400oooo0?oo
o`0e0?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_oo
ool6000003`0oooo2P0000000`20P800oooo0?ooo`1>0?ooo`<00000FP3oool;000003T0oooo1P00
000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo000:ooooo`H00000?@3o
ool:00000500oooo0`00001I0?ooo`030820P0000000000000P00000>P3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00000m0?ooo`030<30`020
P800000000T0000000<0P8200?ooo`3oool0B`3oool3000005L0oooo0P20P809000000030820P030
`<00oooo03T0oooo1P00000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo
000:ooooo`H00000@03oool;000004`0oooo0`00001F0?ooo`/00000?@3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P0000100?ooo`030820P000
0000000000T00000B`3oool3000005D0oooo2`00000n0?ooo`H00000:@3oool3000000d0oooo00@0
P820000000000000P8204@3oool;ooooo`002_ooool600000480oooo00<0P8200000000000002000
00000`10@400P8200?ooo`170?ooo`<00000DP3oool00`20P800@41000000009000000030820P03o
ool0oooo03d0oooo1P00000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo
000:ooooo`H00000@`3oool00`20P80000000000000:000000030820P03oool0oooo04@0oooo0`00
001@0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0?`3oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P0000150?ooo``00000AP3o
ool300000500oooo300000120?ooo`H00000:@3oool3000000d0oooo00@0P820000000000000P820
4@3oool;ooooo`002_ooool6000004H0oooo00<0P8200000000000002P0000000`20P800oooo0?oo
o`110?ooo`<00000C@3oool00`20P800000000000009000000030820P03oool0oooo0480oooo1P00
000Y0?ooo`<000003@3oool01020P800000000000020P80A0?ooo`_ooooo000:ooooo`H00000B@3o
ool<00000480oooo0`00001;0?ooo`d00000AP3oool6000002T0oooo0`00000=0?ooo`040820P000
000000000820P140oooo2oooool000[ooooo1P00001:0?ooo``0000000<0P8200?ooo`3oool0?P3o
ool3000004T0oooo00<0P8200000000000002P0000000`20P800oooo0?ooo`150?ooo`H00000:@3o
ool3000000d0oooo00@0P820000000000000P8204@3oool;ooooo`002_ooool6000004/0oooo0P20
P80;00000080P820=03oool00`000000oooo0?ooo`060?ooo`<00000203oool00`20P800oooo0?oo
o`0k0?ooo`030<30`020P800000000X0000000<0@4100820P03oool0B03oool6000002T0oooo0`00
000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00001>0?ooo`h00000<P3o
ool00`000000P8200?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`0j0?ooo`h00000B`3o
ool6000002T0oooo0`00000=0?ooo`040820P000000000000820P140oooo2oooool000[ooooo1P00
001@0?ooo`d00000<@3oool00`000000P8200?ooo`060?ooo`<00000203oool00`000000oooo0?oo
o`0h0?ooo`030820P0000000000000/00000C@3oool6000002T0oooo0`00000=0?ooo`040820P000
000000000820P140oooo2oooool000[ooooo1P00001@0?ooo`030<30`020P800000000`000000P20
P80]0?ooo`8000000P20P8050?ooo`<000001@3oool20820P0800000=`3oool00`30`<00P8200000
000=000000030820P03oool0oooo04/0oooo1P00000Y0?ooo`<000003@3oool01010@40000000000
0010@40A0?ooo`_ooooo000:ooooo`H00000D`3oool00`20P80000000000000=000002/0oooo5@00
000f0?ooo`l00000D03oool6000002T0oooo0`00000<0?ooo`H00000403oool;ooooo`002_ooool6
000005<0oooo00<0P8200000000000003P00000Z0?oooaD00000=03oool00`20P80000000000000=
00000540oooo1P00000Y0?ooo`<000002P3oool00`20P800000000000006000000030820P03oool0
oooo00`0oooo2oooool000[ooooo1P00001E0?ooo`80P8203`0000000`10@400P8200?ooo`1Z0?oo
o`80P8203P0000000`10@400P8200?ooo`1B0?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P00001I0?oooa400000I`3oool00`20P80000000000000>000005H0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool6000005X0oooo4P0000000`20P800oooo0?ooo`1P0?oooa400000
00<0P8200?ooo`3oool0E@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000G03o
oolC000005h0oooo4P00001I0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001N
0?ooo`80P820400000020820P0030<30`03oool0oooo0580oooo00<0`<300820P020P8004@000002
0820P0030<30`03oool0oooo05P0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
0640oooo5000001?0?ooo`030820P0000000000001<00000GP3oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H00000I03ooolD000004T0oooo00<0P8200000000000004`0000000`20P800
oooo0?ooo`1N0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001V0?ooo`80P820
4`0000030820P3d0oooo0`20P8000`10@40000000000000C000000030820P03oool0oooo0640oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000006X0oooo5`00000f0?oooaX0000000<0
P8200?ooo`3oool0I03oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000K03oool0
0`20P80000000000000I000000030820P03oool0oooo02P0oooo7000001Y0?ooo`H00000:@3oool3
00000280oooo2oooool000[ooooo1P00001^0?ooo`80P8208000000O0820P1X000000`20P81/0?oo
o`H00000:@3oool300000280oooo2oooool000[ooooo1P00001c0?oooe<00000LP3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H00000MP3oool00`20P80000000000001:000007D0oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6000007T0oooo00@0`<300820P020P800@410
@`00001h0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00001o0?ooo`030820P000
0000000003T00000O@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000Q@3oool0
0`20P80000000000000]000008<0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
08X0oooo1@20P8000`10@40000000000000>00000100P820R03oool6000002T0oooo0`00000R0?oo
o`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo
1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3o
ool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool3
00000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;oooo
o`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000
o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00
000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R
0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[o
oooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo
>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3o
ool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;
ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H0
0000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo
1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00
000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool0
00[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000
:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3o
ool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:oooo
o`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0
oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo
0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2ooo
ool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool60000
0?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H0
0000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<00000
8P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:
ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?oo
ocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0
oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo
2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<000008P3oool;ooooo`002_ooool6
00000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?oo
o`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Y0?ooo`<0
00008P3oool;ooooo`002_ooool600000?l0oooo>@3oool6000002T0oooo0`00000R0?ooo`_ooooo
000:ooooo`H00000o`3oooli0?ooo`H00000:@3oool300000280oooo2oooool000[ooooo1P00003o
0?ooocT0oooo1P00000P0?ooo`80P820400000020820P1X0oooo2oooool000[ooooo1P00003o0?oo
ocT0oooo1P00000N0?oooaP0000000<0P8200?ooo`3oool05@3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000001d0oooo00<0P8200000000000005P0000000`20P800oooo0?ooo`0E0?ooo`_o
oooo000:ooooo`H00000o`3oooli0?ooo`H000007P3ooolH000001P0oooo2oooool000[ooooo1P00
003o0?ooocT0oooo1P00000N0?oooaP00000603oool;ooooo`002_ooool600000?l0oooo>@3oool6
000001l0oooo5P00000I0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000007`3ooolF0000
01T0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000P0?oooa@000006P3oool;ooooo`00
2_ooool600000?l0oooo>@3oool600000200oooo5000000J0?ooo`_ooooo000:ooooo`H00000o`3o
ooli0?ooo`H00000803oool00`10@40000000000000@000000030410@03oool0oooo01P0oooo2ooo
ool000[ooooo1P00003o0?ooocT0oooo1P00000P0?ooo`030820P000000000000100000000<0P820
0?ooo`3oool0603oool;ooooo`002_ooool600000?l0oooo>@3oool600000200oooo00<0P8200000
00000000400000000`20P800oooo0?ooo`0H0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H0
00008@3ooolB000001/0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000Q0?oooa400000
00<0P8200?ooo`3oool06@3oool;ooooo`002_ooool600000?l0oooo>@3oool600000280oooo4000
000L0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000008P3oool@000001`0oooo2oooool0
00[ooooo1P00003o0?ooocT0oooo1P00000R0?ooo`030820P0000000000000`000007@3oool;oooo
o`002_ooool600000?l0oooo>@3oool6000002<0oooo3P00000M0?ooo`_ooooo000:ooooo`H00000
o`3oooli0?ooo`H000008`3oool=000000030820P03oool0oooo01/0oooo2oooool000[ooooo1P00
003o0?ooocT0oooo1P00000S0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool06`3o
ool;ooooo`002_ooool600000?l0oooo>@3oool6000002@0oooo300000000`20P800oooo0?ooo`0K
0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000903oool<000001h0oooo2oooool000[o
oooo1P00003o0?ooocT0oooo1P00000T0?ooo`030820P0000000000000T000007P3oool;ooooo`00
2_ooool600000?l0oooo>@3oool6000002D0oooo2P00000O0?ooo`_ooooo000:ooooo`H00000o`3o
ooli0?ooo`H000009@3oool:000001l0oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000V
0?ooo`P0000000<0P8200?ooo`3oool07@3oool;ooooo`002_ooool600000?l0oooo>@3oool60000
02H0oooo2000000P0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H000009P3oool00`20P800
000000000004000000030820P03oool0oooo01h0oooo2oooool000[ooooo1P00003o0?ooocT0oooo
1P00000V0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool07P3oool;ooooo`002_oo
ool600000?l0oooo>@3oool6000002L0oooo1P00000Q0?ooo`_ooooo000:ooooo`H00000o`3oooli
0?ooo`H000009`3oool600000240oooo2oooool000[ooooo1P00003o0?ooocT0oooo1P00000W0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool07`3oool;ooooo`002_ooool600000?l0
oooo>@3oool6000002P0oooo1000000R0?ooo`_ooooo000:ooooo`H00000o`3oooli0?ooo`H00000
:03oool400000280oooo2oooool000[oooooo`000015000002T0oooo0P00000S0?ooo`_ooooo000:
ooooool00000A@00000Y0?ooo`0300000020P800oooo0280oooo2oooool000[oooooo`0000150000
02T0oooo00<0P8200?ooo`3oool08P3oool;ooooo`002_oooooo000004D00000CP3oool;ooooo`00
2_oooooo000004D00000CP3oool;ooooo`002_oooooo000004D00000CP3oool;ooooo`002_oooooo
000004D00000CP3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_o
oooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC
0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool000[ooooo
o`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo2oooool0
00[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`002_oooooo0?oooi<0oooo
2oooool000[oooooo`3ooonC0?ooo`_ooooo000:oooookL0oooo00<0P8200000000000002000003@
0?ooo`_ooooo000:oooookX0oooo00D0`<3000000000000000000410@03C0?ooo`_ooooo000:oooo
ok/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800
oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo
000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`000000
0`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?oo
o`_ooooo000:oooook/0oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooooj80oooo
2@0000000`20P800oooo0?ooo`0=0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;ooooo`002_oo
oonT0?ooo`H000004@3oool3000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3
000000030820P03oool0oooo0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:oooo
ojD0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;oooo
o`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool0403oool3000000030820P03oool0oooo0=40
oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo0100oooo0`0000000`20P800oooo
0?ooo`3A0?ooo`_ooooo000:ooooojD0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0
P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool0403oool3
000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo
0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:ooooojD0oooo0`0000000`20P800
oooo0?ooo`0@0?ooo`<0000000<0P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<00000
00<0P8200?ooo`3oool0403oool3000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3o
ool3000000030820P03oool0oooo0100oooo0`0000000`20P800oooo0?ooo`3A0?ooo`_ooooo000:
ooooojD0oooo0`0000000`20P800oooo0?ooo`0<0?ooo`040820P03oool0oooo0?ooo`<0000000<0
P8200?ooo`3oool0d@3oool;ooooo`002_oooonU0?ooo`<0000000<0P8200?ooo`3oool03@3oool6
000000030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo
00l0oooo00D0P82000000000000000000820P03C0?ooo`_ooooo000:ooooojD0oooo0`0000000`20
P800oooo0?ooo`0C0?ooo`030820P03oool0oooo0=40oooo2oooool000[oooooY@3oool300000003
0820P03oool0oooo0>L0oooo2oooool000[oooooY@3oool3000000030820P03oool0oooo0>L0oooo
2oooool000[oooooY@3oool3000000030820P03oool0oooo0>L0oooo2oooool000[oooooW03oool0
0`000000oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool01P3oool00`20P800oooo0?ooo`3N
0?ooo`_ooooo000:oooooi`0oooo00<000000?ooo`3oool01P3oool3000000030820P03oool0oooo
00H0oooo00<0P8200?ooo`3oool0gP3oool;ooooo`002_oooonL0?ooo`8000001`3oool300000003
0820P03oool0oooo00D0oooo00<000000820P03oool0g`3oool;ooooo`002_oooonL0?ooo`800000
00<0P8200?ooo`3oool0103oool3000000030820P03oool0oooo00@0oooo0P0000000`20P800oooo
0?ooo`3N0?ooo`_ooooo000:oooooi`0oooo100000050?ooo`<0000000<0P8200?ooo`3oool00`3o
ool3000000030820P03oool0oooo0=h0oooo2oooool000[oooooW03ooolE000000030820P03oool0
oooo0=h0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo000:ooooool0ooooT`3oool;ooooo`00
2_oooooo0?oooi<0oooo2oooool000[oooooo`3ooonC0?ooo`_ooooo003oooooojSooooo003ooooo
ojSooooo003oooooojSooooo003oooooojSooooo003oooooojSooooo003oooooojSooooo003ooooo
ojSooooo003oooooojSooooo003oooooojSooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{141.125, 131},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.5 Exercise (3).", "Caption",
  CellTags->"Fig. 6.5"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  "  A triaxial ellipsoid has a shape given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 + z\^2/c\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\  = \ 2, \ 
      b = 3, \ \ \(\(and\ c\)\(=\)\(4\)\(\ \)\)\)]],
  ". The ellipsoid surface is at potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ". The ellipsoid  is filled with  a uniform negative charge of density ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Rho]\_o\)\)]],
  ".  Using the Galerkin method find the electrostatic potential inside the \
ellipsoid as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  ". (Hint: the solution is a simple polynomial function of ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, z\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Use the Galerkin method to solve the following heat equation problem in \
1-D with inhomogeneous conductivity,  on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1/2\)]],
  ". Choose your own modes, and test to make sure you have kept enough modes. \
Plot the result as an animation:"
}], "Text"],

Cell[TextData[{
  "\t\t  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{\((4  x + 1)\), " ", 
                FractionBox["\[PartialD]", \(\[PartialD]x\),
                  MultilineFunction->None], \(T(x, t)\)}], ")"}]}], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]t\),
              MultilineFunction->None], \(T(x, t)\)}]}], TraditionalForm]]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  "\nwith\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t)\  = \ 0, T(1, t) = 1, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \ x\^6\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  "  Solve the time-dependent (dimensionless) Schr\[ODoubleDot]dinger \
equation for the wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " of a particle in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ", subject to boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](\(\[PlusMinus]a\), t) = 0\)]],
  " and initial condition  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 0) = \(\[Psi]\_o\)(x)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            FractionBox[\(\[PartialD]\(\[Psi](x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None]}], "=", 
          RowBox[{\(\(V(x)\)\ \(\[Psi](x, t)\)\), "-", 
            RowBox[{\(1\/2\), 
              
              FractionBox[\(\[PartialD]\^2\( \[Psi](x, 
                    t)\)\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Take ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = x\^4/4\)]],
  ", use trigonometric functions for the modes in the Galerkin method, and \
work out the matrix elements of ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(n\ m\)\)]],
  ", analytically for general ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ".  (Note: Check to make sure the integrals for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(n\ n\)\)]],
  " are evaluated properly.) Take ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x)\  = \ 
        exp[\(-2\) \((x - 1)\)\^2]\)]],
  ", and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(a\  = \ 4\)\)\)]],
  ". Keep as many basis functions as necessary to obtain a converged answer. \
Plot the solution in time increments of 0.1 for ",
  Cell[BoxData[
      \(TraditionalForm\`0\  < t < 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " Use the Galerkin method to solve for the dynamics of the string with the \
moving boundary condition, described in scaled coordinates by  Eq. ",
  ButtonBox["(5.2.64)",
    ButtonData:>{"Chapter5.nb", "(5.2.64)"},
    ButtonStyle->"Hyperlink"],
  ". Again take the case ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(L\_o = 1\ m\),
            "TraditionalForm"], ",", 
          FormBox[\(c = 300\ m/sec\),
            "TraditionalForm"], ",", 
          RowBox[{"and", 
            RowBox[{
              FormBox[\(v = 2\ m/sec\),
                "TraditionalForm"], "."}]}]}], TraditionalForm]]],
  "   For basis functions, use ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ n\ \[Pi]\ x\&_\)]],
  ".   Plot ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\&_ = 1/2, t)\)]],
  " and listen to the sound the string makes using the ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.45\ sec\)]],
  ". Compare the plot and the sound to the WKB solution, Eq. ",
  ButtonBox["(5.2.65)",
    ButtonData:>{"Chapter5.nb", "(5.2.65)"},
    ButtonStyle->"Hyperlink"],
  ".  (Hint: You will need to increase ",
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to around 5000. )"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Redo the problem , and make an animation of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ", for a case where the WKB solution fails :",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{\(L\_o\), "=", 
              RowBox[{"1", " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]}],
            "TraditionalForm"], ",", 
          FormBox[
            RowBox[{"c", "=", 
              RowBox[{"300", " ", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], "/", 
                  StyleBox["s",
                    FontSlant->"Plain"]}]}]}],
            "TraditionalForm"], ",", 
          RowBox[{"and", 
            FormBox[
              RowBox[{"v", "=", 
                RowBox[{"200", " ", 
                  RowBox[{
                    StyleBox["m",
                      FontSlant->"Plain"], "/", 
                    StyleBox["s",
                      FontSlant->"Plain"]}]}]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  "  . Plot the solution over the time interval ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"0.0045", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Evaluate the energy variation of the string dynamics found in part (b), \
and use this to determine the force on the moving boundary vs. time."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A large sheet of cloth has an elliptical  shape given by ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"2", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"b", "=", 
          RowBox[{"1", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".  The edge of the sheet is fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ", and the propagation speed of waves on the sheet is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"3", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Initially the sheet is flat and stationary, ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 0) = \(\(z\& . \)(x, y, 0) = 0\)\)]],
  ". However, thanks to the acceleration of gravity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ", the sheet begins to sag. The equation of motion for the sheet is the \
damped wave equation,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\^2\/\[PartialD]t\^2 + \ \[Gamma] \
\[PartialD]\/\[PartialD]t)\) \(z(x, y, 
            t)\) = \(c\^2\)\ [\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2] \(z(x, y, t)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 10\ sec\^\(-1\)\)]],
  " due to air drag on the sheet.\n\tSolve for the dynamics of the sheet  \
using the Galerkin method, and plot the resulting motion as a series of ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics objects,   for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"1", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".\t"
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A circular wading pool of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  "m has nonuniform depth, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h(r, \[Theta])\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(h\_o\)(
        1 + 2 \( r\^\(\(2\)\(\ \)\)\) \(cos(
                2  \[Theta])\)/\((3\ a\^2)\)\ )\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`h\_o = 5\ cm\)]],
  " and coordinates are measured from the center of the pool.   \n\tAssuming \
potential flow, the horizontal fluid displacement vector can be expressed as  \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Eta]",
            FontWeight->"Bold"], "=", \(\[Del]\(\[Phi](r, \[Theta], t)\)\)}], 
        TraditionalForm]]],
  ",  with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfying the PDE"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
              MultilineFunction->None], "\[Phi]"}], 
          "=", \(\[Del]\(\(\[CenterDot]\)\(\(c\^2\)(r, \[Theta])\)\)\), 
          RowBox[{"\[Del]", 
            RowBox[{"\[Phi]", 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox[\(r, \[Theta], t\),
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\)(r, \[Theta])\  = \ 
        g\ \(h(r, \[Theta])\)\)]],
  " is the square of the wave speed. The wave height is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r, \[Theta], t)\), " ", "=", 
          RowBox[{
            RowBox[{\(-\[Del]\), "\[CenterDot]", 
              RowBox[{"[", 
                RowBox[{\(h(r, \[Theta])\), " ", 
                  StyleBox["\[Eta]",
                    FontWeight->"Bold"]}], "]"}]}], Cell[""]}]}], 
        TraditionalForm]]],
  ".  The boundary conditions are ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["\[Eta]",
                FontWeight->"Bold"], "\[CenterDot]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}], \( | \_\(r = a\)\)}], "=", "0"}], 
        TraditionalForm]]],
  ". [See Eqs. ",
  ButtonBox["(4.2.50)",
    ButtonData:>{"Chapter4.nb", "(4.2.50)"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(4.4.38)",
    ButtonData:>{"Chapter4.nb", "(4.4.38)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.4.39)",
    ButtonData:>{"Chapter4.nb", "(4.4.39)"},
    ButtonStyle->"Hyperlink"],
  " and the surrounding discussion.]"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " We will use the Galerkin method to solve this problem. First, we must \
choose basis functions.  Show that functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(m\ n\)\)(
          r, \[Theta]) = \(\(\(r\^n\)(
            1 - b\_n\ r\^2)\) \(cos\)\(\ \)\(m\)\(\ \)\(\[Theta]\)\(\ \
\)\)\)]],
  " match the von Neumann  boundary conditions required at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "is chosen properly. (Why don't we need ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ m\ \[Theta]\)]],
  " basis functions?)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " must also be satisfied: the solution and its derivatives must be finite. \
By examining the form of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " in cylindrical coordinates, show that this leads to the requirement on \
the basis functions  that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(r \[Rule] \ 0\)\((\[PartialD]v\_\(m\ n\)\/\
\[PartialD]r - \(m\^2\/r\) v\_\(m\ n\))\) = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:37", "(6.1.37)"}],

Cell[TextData[{
  "Show that this equation implies that we must choose ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in the range  ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ m\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Initially, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], 
          0) = \(-\(\(J\_0\)(\(j\_\(1\ 1\)\) r/a)\)\)/10\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\& . \)(r, \[Theta], 0) = 0\)]],
  ". Find the wave motion and plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r, \[Theta], t)\), Cell[""]}], TraditionalForm]]],
  "for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"3", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 Grid Methods", "Subtitle",
  CellTags->{"i:17", "c:13"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.2.1 Time-Dependent Problems", "Subsubtitle",
  CellTags->"c:14"],

Cell[CellGroupData[{

Cell["FTCS Method for the Heat Equation", "Section",
  CellTags->{"i:18", "c:15"}],

Cell[TextData[{
  "In Chapters ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ", we showed how  boundary- and initial-value ODE problems can be solved \
using grid methods, wherein the linear ODE is converted into a difference \
equation by discretizing the independent variable.  In this section, we apply \
analogous methods to partial differential equations. "
}], "Text"],

Cell[TextData[{
  "\tAs a first example of a grid method in the solution of a PDE, consider \
the heat equation in a slab running from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, 
            t)\) = \[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) \(T(x, t)\) + 
          S(x, t)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.1)"],

Cell[TextData[{
  "We solve for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " subject to the initial condition that ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = \(T\_o\)(x)\)]],
  " and the Dirichlet boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = \(T\_1\)(t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(L, t) = \(T\_2\)(t)\)]],
  ". To solve this problem, we discretize both space and time, according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), "=", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", "  ", \(n = 0\), ",", 
          "1", ",", "2", ",", "...", ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(j = 0\), ",", 
          "1", ",", "2", ",", "...", ",", "M"}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "is the stepsize in time, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/M\)}], TraditionalForm]]],
  " is the stepsize in space.  We will solve Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(x, t)\)\(\ \)\)\)]],
  "only on this grid of points.  It is useful to introduce the notation ",
  Cell[BoxData[
      \(TraditionalForm\`T(x\_j, t\_n) = T\_j\%n\)]],
  " (subscripts refer to the spatial grid point, and superscripts refer to \
the time grid point)."
}], "Text"],

Cell[TextData[{
  "\t We must now discretize the space and time derivatives in Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  ". There are many ways to do so, some better than others. To start with, we \
will discuss the FTCS method, where we use a forward-difference method for \
the time derivative and a centered-difference method for the space derivative \
(hence the name: forward time, centered space). That is, for the time \
derivative, we write"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(\[PartialD]T\/\[PartialD]t\) \((x\_j, t\_n)\)\), 
            "\[Rule]", 
            FractionBox[\(T(x\_j, t\_\(n + 1\)) - T(x\_j, t\_n)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]]}], "=", 
          FractionBox[\(T\_j\%\(n + 1\) - T\_j\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]], " "}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.3)"],

Cell["and for the space derivative, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(\[PartialD]\^2 T\/\[PartialD]x\^2\) \((x\_j, t\_n)\)\), 
            "\[Rule]", 
            
            FractionBox[\(T(x\_\(j + 1\), t\_n) - 2 \( T(x\_j, t\_n)\) + 
                T(x\_\(j - 1\), t\_n)\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]]}], "=", 
          FractionBox[\(T\_\(j + 1\)\%n - 2  T\_j\%n + T\_\(j - 1\)\%n\), 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]], " "}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.4)"],

Cell[TextData[{
  "(See Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  " for a discussion of finite-difference derivatives.) Substituting these \
expressions into Eq. ",
  ButtonBox["(6.2.1)",
    ButtonData:>"(6.2.1)",
    ButtonStyle->"Hyperlink"],
  ", we collect all terms on the ",
  "right-hand",
  " side except for the term involving ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n + 1\)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%\(n + 1\)\), "=", 
          RowBox[{\(T\_j\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.5)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " is a recursion relation that bears a distinct resemblance to Euler's \
method. If, at the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "'th time step, we know ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " on the spatial grid, then we can use Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " to determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " at the ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  "'st ",
  "time step",
  " at each spatial gridpoint. The programming of this method in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "is nearly as simple as for Euler's method. We refer to ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " as the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", and write the recursion relation as"
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(T[j_, n_]\  := \ \(T[j, n]\  = \ 
        T[j, n - 1] + \[CapitalDelta]t\ S[j, 
              n - 1]\  + \ \(\(\[Chi]\ \
\[CapitalDelta]t\)\/\[CapitalDelta]x\^2\) \((T[j + 1, n - 1]\  - 
                2  T[j, n - 1] + T[j - 1, n - 1])\)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.52"],

Cell[TextData[{
  "Note the use of the double equality, in order to force ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to remember previously evaluated values of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", just as was done in Euler's method. \n\tHowever, Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  " works ",
  StyleBox["only for the interior points",
    FontSlant->"Italic"],
  ". We cannot use it to determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\%n\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`T\_M\%n\)]],
  ", because the equation would require ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(-1\)\%n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(M + 1\)\%n\)]],
  ", which are outside the range of the grid. Fortunately, these \
boundary-values can be specified by the boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\%n = \(T\_1\)(t\_n)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_M\%n = \(T\_2\)(t\_n)\)]],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(T[0, n_]\  := \ T1[t] /. t \[Rule] n\ \[CapitalDelta]t;\)\), "\n", 
    \(M = 10; 
    T[M, n_]\  := \ T2[t] /. t \[Rule] n\ \[CapitalDelta]t\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.53"],

Cell["\<\
In grid methods, we determine the unknown function at the boundary \
points of the grid using the boundary conditions, and use the \
finite-differenced differential equation only at the interior points.\
\>", \
"Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["\<\
In order to start the recursion, we must also specify the initial \
condition:\
\>", "Text"],

Cell[BoxData[
    \(T[j_, 0]\  := \ T0[x] /. x \[Rule] \ j\ \[CapitalDelta]x\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.54"],

Cell[TextData[{
  "To use this method, all we need do is choose ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", and specify the source function ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", the initial and boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T0",
            FontFamily->"Courier",
            FontWeight->"Bold"], ",", 
          StyleBox["T1",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["T2",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "respectively, ",
  " and the width ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the system and the thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ".  We do so below for a specific case:"
}], "Text"],

Cell[BoxData[
    \(\(\(L = 1; \ \[Chi]\  = \ 1/4; \[CapitalDelta]t\  = \ 
      0.01; \[CapitalDelta]x\  = \ L/M; 
    S[j_, n_]\  = \ 0;\[IndentingNewLine]\[IndentingNewLine]
    \(T0[x_]\  = \ \(x\^2\) \((1 - x)\);\)\[IndentingNewLine]
    T1[t_]\  = \ t/\((1 + 3  t)\); T2[t_]\  = \ 0;\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.55"],

Cell[TextData[{
  "We now make a table of plots of the solution, evaluated at different \
times, as shown in Cell ",
  ButtonBox["6.56",
    ButtonData:>"Cell 6.56",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        ListPlot[Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}], 
          PlotJoined \[Rule] True, PlotRange \[Rule] {0,  .4}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
              ToString[\[CapitalDelta]t\ n]], {n, 0, 200, 10}];\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.56"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.11905 .01391 L
.21429 .04944 L
.30952 .09734 L
.40476 .14833 L
.5 .19314 L
.59524 .22249 L
.69048 .22713 L
.78571 .19777 L
.88095 .12515 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00;ooooo1ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`09oooo
o`Oo00009oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`0@ooooo`Oo0000ooooool6ooooo`03o`000?oooooooooo023o
oooo000Vooooo`03o`000?oooooooooo01Oooooo1Ol0003oooooo`03o`000?oooooooooo027ooooo
000Vooooo`;o00007Oooool3o`000?cooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000
ooooooooool07oooool3o`000?Sooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000oooo
ooooool08_ooool2o`000?Gooooo00?o0000ooooooooool08oooool002Kooooo00?o0000oooooooo
ool09?ooool3o`000?7ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
9oooool3o`000>kooooo00?o0000ooooooooool09?ooool002Kooooo0_l0000[ooooo`;o0000jooo
ool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`0/ooooo`?o0000ioooool0
0ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`0_ooooo`;o0000i?ooool00ol0
003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0aooooo`?o0000h?ooool00ol0003o
ooooooooo`0Xooooo`009_ooool2o`0003Gooooo0ol0003Mooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo03Oooooo0_l0003Jooooo`03o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo03Wooooo0_l0003Gooooo`03o`000?oooooooooo02[ooooo000Voooo
o`03o`000?oooooooooo03_ooooo0_l0003Dooooo`03o`000?oooooooooo02_ooooo000Vooooo`03
o`000?oooooooooo03gooooo0_l0003Booooo`03o`000?oooooooooo02_ooooo000Vooooo`;o0000
@?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`000?oo
oooooooo043ooooo0_l0003=ooooo`03o`000?oooooooooo02gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`12ooooo`;o0000b_ooool00ol0003o
ooooooooo`0^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
04Cooooo0_l00038ooooo`03o`000?oooooooooo02kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`16ooooo`;o0000aOooool00ol0003oooooooooo`0_ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00018ooooo`;o0000`_ooool00ol0003oooooooooo`0`ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`;o0000_oooool00ol0003o
ooooooooo`0aooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`2looooo`03o`000?oooooooooo037ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`;o0000^oooool00ol0003oooooooooo`0booooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`00053ooooo0_l0002hooooo`03o`000?oooooooooo03?ooooo000Vooooo`03o`000?oooooo
oooo057ooooo0_l0002eooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo
05?ooooo0_l0002booooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Go
oooo0_l0002`ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Oooooo
0_l0002]ooooo`03o`000?oooooooooo03Kooooo000Vooooo`;o0000F_ooool2o`000:[ooooo00?o
0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool0Foooool2o`000:Oooooo00?o0000
ooooooooool0>?ooool002Kooooo00?o0000ooooooooool0GOooool2o`000:Gooooo00?o0000oooo
ooooool0>?ooool002Kooooo00?o0000ooooooooool0Goooool2o`000:;ooooo00?o0000oooooooo
ool0>Oooool002Kooooo00?o0000ooooooooool0HOooool2o`0009oooooo00?o0000ooooooooool0
>_ooool002Kooooo0_l0001Tooooo`03o`000?oooooooooo09[ooooo0_l0000mooooo`009_ooool0
0ol0003oooooooooo`1Tooooo`;o0000VOooool00ol0003oooooooooo`0mooooo`009_ooool00ol0
003oooooooooo`1Vooooo`;o0000U_ooool00ol0003oooooooooo`0nooooo`009_ooool00ol0003o
ooooooooo`1Xooooo`;o0000T_ooool2o`00047ooooo000Vooooo`;o0000Joooool2o`0008oooooo
00?o0000ooooooooool0@Oooool002Kooooo00?o0000ooooooooool0K?ooool2o`0008cooooo00?o
0000ooooooooool0@_ooool002Kooooo00?o0000ooooooooool0K_ooool2o`0008Sooooo0_l00015
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1`ooooo`;o0000QOooool00ol0003oooooooooo`15
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L_ooool2o`0008;ooooo00?o0000ooooooooool0A_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0001d
ooooo`;o0000O_ooool2o`0004Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Kooooo0_l0001kooooo`03o`000?oooooo
oooo04Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07Sooooo0_l0001hooooo`03o`000?oooooooooo04[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07[ooooo0_l0001eooooo`03o`000?oooooooooo04_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo0_l0001a
ooooo`;o0000C_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo
000000Oooooo0_l0001oooooo`?o0000KOooool00ol0003oooooooooo`1>ooooo`009_ooool00ol0
003oooooooooo`21ooooo`;o0000J_ooool00ol0003oooooooooo`1?ooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000I_ooool2o`0005;ooooo000Vooooo`03o`000?oooooooooo08Gooooo
0_l0001Sooooo`03o`000?oooooooooo05;ooooo000Vooooo`;o0000R?ooool2o`00063ooooo00?o
0000ooooooooool0Doooool002Kooooo00?o0000ooooooooool0ROooool2o`0005cooooo0_l0001F
ooooo`009_ooool00ol0003oooooooooo`2;ooooo`;o0000FOooool00ol0003oooooooooo`1Foooo
o`009_ooool00ol0003oooooooooo`2=ooooo`?o0000EOooool00ol0003oooooooooo`1Gooooo`00
9_ooool00ol0003oooooooooo`2@ooooo`?o0000Coooool3o`0005[ooooo000Vooooo`;o0000U?oo
ool3o`0004Wooooo0ol0001Mooooo`009_ooool00ol0003oooooooooo`2Fooooo`?o0000@oooool3
o`00063ooooo000Vooooo`03o`000?oooooooooo09Wooooo1?l0000looooo`?o0000Hoooool002Ko
oooo00?o0000ooooooooool0WOooool3o`0003Gooooo1?l0001Vooooo`009_ooool00ol0003ooooo
ooooo`2Pooooo`?o0000;oooool3o`0006[ooooo000Vooooo`;o0000Y?ooool3o`0002Wooooo0ol0
001]ooooo`009_ooool00ol0003oooooooooo`2Vooooo`?o00008oooool3o`00073ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2Yoooooa7o00003ooo
ool3o`0007?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;[ooooo3ol0
001fooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00W?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOooool009cooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<ZKooooo
002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08kooooo002Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?o
c<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool0
1?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006
oooooomgMgOoV9RHoooooonHV9SoMgMgS_ooool009Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
402>ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^
ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0S?oo
ool009Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@08kooooo002Aooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0S_ooool0097ooooo1ol00004ooooo`;o00004oooool00ol0003o
ooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11885 m
.11905 .09012 L
.21429 .09029 L
.30952 .10881 L
.40476 .13415 L
.5 .15547 L
.59524 .16361 L
.69048 .15207 L
.78571 .11826 L
.88095 .06489 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000Boooo
o`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0<oooool2o`0000;ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool08oooool002Kooooo
00?o0000ooooooooool0oooooolHooooo`;o00009_ooool002Kooooo0_l0003ooooooaSooooo00?o
0000ooooooooool09_ooool002Kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooo
oooo02Oooooo000Vooooo`03o`000?oooooooooo0?oooooo5?ooool2o`0002[ooooo000Vooooo`03
o`000?oooooooooo0?oooooo4oooool00ol0003oooooooooo`0Zooooo`009_ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l0000]ooooo`009_ooool2o`000?oooooo4Oooool00ol0003ooooooooo
o`0]ooooo`009_ooool00ol0003oooooooooo`3oooooo`kooooo0_l0000`ooooo`009_ooool00ol0
003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0<?ooool002Kooooo00?o0000oooooooo
ool0ooooool;ooooo`;o0000<oooool002Kooooo0_l0003oooooo`_ooooo00?o0000ooooooooool0
<oooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo03Cooooo000V
ooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003Oooooo000Vooooo`03o`000?oooooooooo
0?oooooo1_ooool00ol0003oooooooooo`0gooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0_l0000jooooo`009_ooool2o`000?oooooo1?ooool00ol0003oooooooooo`0jooooo`009_oo
ool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0o_ooool2o`0003oooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0o?ooool2o`00047ooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo047ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000?Wooooo0_l00014ooooo`000oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3gooooo`;o0000A_ooool000?ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?Gooooo0_l00018ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0loooool2o`0004[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o00006OoooolSo`000;Oooooo00?o
0000ooooooooool0B_ooool002Kooooo00?o0000ooooooooool05Oooool3o`0002?ooooo1Ol0002`
ooooo`;o0000COooool002Kooooo00?o0000ooooooooool04Oooool4o`0002_ooooo1_l0002Xoooo
o`;o0000Coooool002Kooooo00?o0000ooooooooool03Oooool4o`0003Gooooo1_l0002Pooooo`;o
0000DOooool002Kooooo00?o0000ooooooooool02_ooool3o`0003oooooo1Ol0002Iooooo`;o0000
Doooool002Kooooo0_l00007ooooo`Co0000Aoooool5o`0009?ooooo00?o0000ooooooooool0Dooo
ool002Kooooo00?o0000ooooooooool00_ooool4o`00053ooooo0ol0002>ooooo`;o0000E_ooool0
02Kooooo00?o0000ooooool000000_l0001Gooooo`Co0000R?ooool2o`0005Sooooo000Vooooo`;o
0000G_ooool4o`0008;ooooo0_l0001Jooooo`009_ooool00ol0003oooooooooo`1Qooooo`?o0000
O?ooool3o`0005cooooo000Vooooo`;o0000IOooool4o`0007Gooooo0ol0001Oooooo`009_ooool0
0ol0003oooooooooo`1Xooooo`Co0000K_ooool3o`0006;ooooo000Vooooo`03o`000?oooooooooo
06cooooo0ol0001Xooooo`?o0000IOooool002Kooooo00?o0000ooooooooool0Koooool4o`00067o
oooo0ol0001Xooooo`009_ooool2o`0007Cooooo1Ol0001Iooooo`?o0000Joooool002Kooooo00?o
0000ooooooooool0N?ooool5o`00057ooooo0ol0001^ooooo`009_ooool00ol0003oooooooooo`1m
ooooo`Go0000BOooool3o`00077ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo08;ooooo1Ol00011
ooooo`?o0000M?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Oooooo1Ol0000gooooo`Go0000Moooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002<
ooooo`Oo0000:Oooool7o`0007cooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo2_l0000Hooooo`Oo0000Poooool0
00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0WOooool9o`0000Sooooo1ol0002:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Vooooo`So0000TOooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEE
ofIVI_l000001oooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo08;ooooo002<
ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@
4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`24ooooo`00ROooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0Q?ooool008Wooooo1ol00005ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000026ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19314 m
.11905 .15245 L
.21429 .1323 L
.30952 .12681 L
.40476 .1286 L
.5 .13012 L
.59524 .12503 L
.69048 .10922 L
.78571 .08148 L
.88095 .04363 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`?o00000oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5Oooool2o`0002Wooooo000Vooooo`;o0000oooooolDooooo`;o0000:ooo
ool002Kooooo00?o0000ooooooooool0ooooool@ooooo`?o0000;Oooool002Kooooo00?o0000oooo
ooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000ooooooooool0ooooool<ooooo`;o
0000<_ooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`;o0000=?ooool002Kooooo0_l0
003oooooo`Wooooo0_l0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Gooooo0ol0000h
ooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0_l0000kooooo`009_ooool00ol0003o
ooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool2o`000?kooooo0ol0000oooooo`009_oo
ool00ol0003oooooooooo`3kooooo`;o0000@_ooool002Kooooo00?o0000ooooooooool0nOooool2
o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003o
ooooooooo`3dooooo`;o0000BOooool002Kooooo0_l0003booooo`?o0000Boooool002Kooooo00?o
0000ooooooooool0koooool2o`0004kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3/ooooo`?o0000D?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3Zooooo`;o0000Doooool000?ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>Sooooo0_l0001Eooooo`000oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
003Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0h_ooool3o`0005[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Ooooo
o`?o0000GOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo1?l0001P
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`Co00001_ooool2o`000=Sooooo1?l0001Tooooo`009_ooool00ol0003oooooooooo`3D
ooooo`?o0000J?ooool002Kooooo00?o0000ooooooooool0d?ooool4o`0006_ooooo000Vooooo`03
o`000?oooooooooo0<cooooo1?l0001_ooooo`009_ooool00ol0003oooooooooo`39ooooo`?o0000
Loooool002Kooooo0_l00035ooooo`Go0000M_ooool002Kooooo00?o0000ooooooooool0__ooool6
o`0007_ooooo000Vooooo`03o`000?oooooooooo0;Sooooo1_l00021ooooo`009_ooool00ol0003o
ooooooooo`2cooooo`Go0000Qoooool002Kooooo00?o0000ooooooooool0[Oooool6o`0008cooooo
000Vooooo`;o0000Y?ooool:o`0009;ooooo000Vooooo`03o`000?oooooooooo04Gooooo>ol0000D
ooooo`oo0000W?ooool002Kooooo00?o0000ooooooooool0=Oooool@o`0003_ooooo5?l0002[oooo
o`009_ooool00ol0003oooooooooo`0`ooooo`Go0000ooooool;ooooo`009_ooool2o`0002cooooo
1Ol0003ooooooa3ooooo000Vooooo`03o`000?oooooooooo02Kooooo1Ol0003ooooooaGooooo000V
ooooo`03o`000?oooooooooo027ooooo1Ol0003ooooooa[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo01cooooo1Ol0003ooooooaoooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`?o0000oooooolT
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`0001Oooooo0_l0003oooooobOooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0ol0003oooooobWooooo000;oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01;ooooo0_l0003oooooobcooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo0_l0003oooooobkooooo000;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00kooooo0_l0003ooooooc3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000007ooooo`;o00003?ooool3o`000?oooooo<_ooool002Kooooo00?o0000oooo
ooooool02Oooool2o`000?oooooo=Oooool002Kooooo00?o0000ooooooooool01oooool2o`000?oo
oooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo>Oooool002Kooooo0_l0
0004ooooo`;o0000oooooolkooooo`009_ooool00ol0003oooooooooo`03o`000?oooooo?Oooool0
02Kooooo0ol0003ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co0000
1_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo@?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`00
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003o
oooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003o
oooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003o
oooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3o
ooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000QOooool008cooooo00?o0000ooooooooool01_ooool0
2_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@
00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0QOooool008co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<
c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^08Kooooo002<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0QOoo
ool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo08Cooooo
0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool0Poooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wooooo1ol00005ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<08Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24396 m
.11905 .19701 L
.21429 .16506 L
.30952 .14452 L
.40476 .13082 L
.5 .11916 L
.59524 .10543 L
.69048 .08683 L
.78571 .06233 L
.88095 .03266 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`7ooooo0ol0000mooooo`009_ooool00ol0003oooooooooo`3looooo`?o0000@?ooool0
02Kooooo00?o0000ooooooooool0nOooool3o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Ko
oooo0ol00016ooooo`009_ooool2o`000??ooooo1?l00019ooooo`009_ooool00ol0003ooooooooo
o`3_ooooo`?o0000COooool002Kooooo00?o0000ooooooooool0k?ooool3o`00053ooooo000Voooo
o`03o`000?oooooooooo0>Wooooo0ol0001Cooooo`009_ooool00ol0003oooooooooo`3Vooooo`?o
0000E_ooool002Kooooo0_l0003Sooooo`Co0000FOooool002Kooooo00?o0000ooooooooool0gooo
ool3o`0005gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Kooooo`Co0000H?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Gooooo`Co0000I?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=Cooooo0ol0001Xooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003@ooooo`Co0000Jooo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0c?ooool4o`0006oo
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`39ooooo`?o0000Loooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<Cooooo1Ol0001fooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000;oooooo1_l0001kooooo`009_ooool00ol0003oooooooooo`2hooooo`Ko0000POooool0
02Kooooo00?o0000ooooooooool0/oooool5o`0008Oooooo000Vooooo`03o`000?oooooooooo0:go
oooo1_l0002<ooooo`009_ooool00ol0003oooooooooo`2Vooooo`Oo0000T_ooool002Kooooo0_l0
002Pooooo`Oo0000VOooool002Kooooo00?o0000ooooooooool0V?ooool7o`000:3ooooo000Voooo
o`03o`000?oooooooooo097ooooo1ol0002Wooooo`009_ooool00ol0003oooooooooo`29ooooo`So
0000[_ooool002Kooooo00?o0000ooooooooool0P_ooool7o`000;Kooooo000Vooooo`;o0000O?oo
ool7o`000;gooooo000Vooooo`03o`000?oooooooooo07Cooooo1ol00034ooooo`009_ooool00ol0
003oooooooooo`1/ooooo`So0000boooool002Kooooo00?o0000ooooooooool0IOooool7o`000=?o
oooo000Vooooo`;o0000Goooool7o`000=[ooooo000Vooooo`03o`000?oooooooooo05Oooooo1ol0
003Qooooo`009_ooool00ol0003oooooooooo`1Aooooo`Ko0000j?ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0C?ooool5o`000>kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`17ooooo`Go0000loooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol00013
ooooo`Co0000n?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0?_ooool5o`000?cooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo1Ol0003o
ooooo`;ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Kooooo0ol0003oooooo`Oooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo0ol0003o
ooooo`[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007
ooooo`;o0000<Oooool3o`000?oooooo3Oooool002Kooooo00?o0000ooooooooool0;Oooool3o`00
0?oooooo4?ooool002Kooooo00?o0000ooooooooool0:_ooool3o`000?oooooo4oooool002Kooooo
00?o0000ooooooooool09oooool3o`000?oooooo5_ooool002Kooooo0_l0000Uooooo`?o0000oooo
oolIooooo`009_ooool00ol0003oooooooooo`0Qooooo`?o0000oooooolLooooo`009_ooool00ol0
003oooooooooo`0Nooooo`?o0000oooooolOooooo`009_ooool00ol0003oooooooooo`0Kooooo`?o
0000oooooolRooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool2o`0001Sooooo0_l0003oooooobOooooo000Vooooo`03o`000?oooooooooo01Gooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01?ooooo0_l0003oooooob_ooooo000Vooooo`03
o`000?oooooooooo017ooooo0_l0003oooooobgooooo000Vooooo`03o`000?oooooooooo00oooooo
0_l0003ooooooboooooo000Vooooo`;o00003_ooool2o`000?oooooo<Oooool002Kooooo00?o0000
ooooooooool02_ooool3o`000?oooooo<oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMoooo
o`04ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooocKooooo0003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooocSooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0
0004ooooo`;o0000ooooooljooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0
003ooooooccooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02o`000?oooooo
?_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool3o`000?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIV
o`000005ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co
00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
QOooool008cooooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^
k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S80QOooool008cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oZJVYoa0@4?ooool0Q?ooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oa0@4?l0003o^[Zj08Gooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00002_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool0Q?ooool0
08Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
QOooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Ooo
ool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28092 m
.11905 .23023 L
.21429 .19102 L
.30952 .16108 L
.40476 .13751 L
.5 .11724 L
.59524 .09754 L
.69048 .07643 L
.78571 .05295 L
.88095 .02717 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0o?ooool3o`00043ooooo000Vooooo`;o0000nOoo
ool4o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0
003oooooooooo`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0kOooool4o`0004ko
oooo000Vooooo`;o0000j_ooool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0
001Fooooo`009_ooool00ol0003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000oooo
ooooool0g_ooool4o`0005gooooo000Vooooo`03o`000?oooooooooo0=[ooooo1?l0001Qooooo`00
9_ooool2o`000=Kooooo1Ol0001Uooooo`009_ooool00ol0003oooooooooo`3Aooooo`Co0000J_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<go
oooo1?l0001^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo1?l0001booooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<7ooooo1?l0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2mooooo`Co0000O_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Sooooo1Ol00022ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0]?ooool4o`0008Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000/Ooo
ool4o`0008_ooooo000Vooooo`03o`000?oooooooooo0:cooooo1?l0002?ooooo`009_ooool00ol0
003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000ooooooooool0Xoooool5o`0009Oo
oooo000Vooooo`03o`000?oooooooooo09kooooo1Ol0002Looooo`009_ooool2o`0009[ooooo1Ol0
002Qooooo`009_ooool00ol0003oooooooooo`2Dooooo`Go0000Y_ooool002Kooooo00?o0000oooo
ooooool0Soooool5o`000:_ooooo000Vooooo`03o`000?oooooooooo08_ooooo1?l0002`ooooo`00
9_ooool00ol0003oooooooooo`26ooooo`Go0000]?ooool002Kooooo0_l00022ooooo`Go0000^Ooo
ool002Kooooo00?o0000ooooooooool0O?ooool5o`000;kooooo000Vooooo`03o`000?oooooooooo
07Oooooo1Ol00033ooooo`009_ooool00ol0003oooooooooo`1booooo`Go0000b?ooool002Kooooo
0_l0001_ooooo`Co0000cOooool002Kooooo00?o0000ooooooooool0J_ooool4o`000=7ooooo000V
ooooo`03o`000?oooooooooo06Kooooo1?l0003Eooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Q
ooooo`Go0000fOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo1?l0003Nooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0005Wooooo1?l0003R
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Eooooo`Co0000i_ooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool4o`000>[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04kooooo0ol0003^ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`?o0000lOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l00019ooooo`?o0000m?ooool0
02Kooooo00?o0000ooooooooool0AOooool3o`000?Oooooo000Vooooo`03o`000?oooooooooo04;o
oooo0ol0003jooooo`009_ooool00ol0003oooooooooo`0oooooo`?o0000oOooool002Kooooo0_l0
000mooooo`?o0000ooooool1ooooo`009_ooool00ol0003oooooooooo`0iooooo`?o0000ooooool4
ooooo`009_ooool00ol0003oooooooooo`0fooooo`?o0000ooooool7ooooo`009_ooool00ol0003o
ooooooooo`0cooooo`?o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0aooooo`;o0000
ooooool=ooooo`009_ooool2o`00033ooooo0_l0003oooooo`oooooo000Vooooo`03o`000?oooooo
oooo02cooooo0ol0003ooooooa7ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooo
oaCooooo000Vooooo`03o`000?oooooooooo02Oooooo0ol0003ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o00008oooool3o`000?oooooo6ooo
ool002Kooooo00?o0000ooooooooool08?ooool2o`000?oooooo7_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01kooooo0_l0003oooooob3ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo0ol0003oooooob;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0000Iooooo`;o0000oooooolUooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01Oooooo0_l0003oooooobOooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Eooooo`;o0000oooooolYooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo
0_l0003oooooob_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool2o`000?oooooo
;Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo
1?l00006ooooo`;o00004?ooool2o`000?oooooo;oooool002Kooooo00?o0000ooooooooool03Ooo
ool2o`000?oooooo<Oooool002Kooooo00?o0000ooooooooool02oooool2o`000?oooooo<oooool0
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooc?ooooo000Vooooo`03
o`000?oooooooooo00Sooooo0_l0003oooooocKooooo000Vooooo`;o00001oooool2o`000?oooooo
>?ooool002Kooooo00?o0000ooooooooool01?ooool2o`000?oooooo>_ooool002Kooooo00?o0000
ooooooooool00_ooool2o`000?oooooo??ooool002Kooooo00?o0000ooooooooool00_l0003ooooo
ockooooo000Vooooo`?o0000oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool0Poooool008cooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooo
ooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo
000000_ooooo00CoA4A4omgMgOoooooo0000Q_ooool008cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0008Kooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00002_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000Q_ooool0
08Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000008Kooooo0029
ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000
ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0QOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.11905 .25615 L
.21429 .21243 L
.30952 .17652 L
.40476 .14655 L
.5 .1205 L
.59524 .09648 L
.69048 .07304 L
.78571 .04926 L
.88095 .02486 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Nooooo`Co0000GOooool002Kooooo00?o0000oooo
ooooool0f_ooool4o`00067ooooo000Vooooo`03o`000?oooooooooo0=Gooooo1Ol0001Uooooo`00
9_ooool2o`000=;ooooo1?l0001Zooooo`009_ooool00ol0003oooooooooo`3=ooooo`Co0000K_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<Wo
oooo1?l0001booooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Gooooo1?l0001fooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0`Oooool4
o`0007[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000;gooooo1?l0001nooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2hooooo`Go0000P_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Cooooo1?l00027ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0/?ooool4o`0008_ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000[Ooo
ool4o`0008oooooo000Vooooo`03o`000?oooooooooo0:Sooooo1?l0002Cooooo`009_ooool00ol0
003oooooooooo`2Uooooo`?o0000Uoooool002Kooooo00?o0000ooooooooool0XOooool4o`0009[o
oooo000Vooooo`03o`000?oooooooooo09gooooo1?l0002Nooooo`009_ooool2o`0009_ooooo0ol0
002Rooooo`009_ooool00ol0003oooooooooo`2Fooooo`Co0000YOooool002Kooooo00?o0000oooo
ooooool0T_ooool4o`000:Wooooo000Vooooo`03o`000?oooooooooo08oooooo0ol0002]ooooo`00
9_ooool00ol0003oooooooooo`2;ooooo`Co0000/?ooool002Kooooo0_l00029ooooo`?o0000]?oo
ool002Kooooo00?o0000ooooooooool0Q?ooool4o`000;Oooooo000Vooooo`03o`000?oooooooooo
083ooooo1?l0002kooooo`009_ooool00ol0003oooooooooo`1mooooo`?o0000_oooool002Kooooo
0_l0001jooooo`Co0000`_ooool002Kooooo00?o0000ooooooooool0MOooool4o`000<Kooooo000V
ooooo`03o`000?oooooooooo07;ooooo0ol0003:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1^
ooooo`Co0000cOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo0ol0003Aooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0006Sooooo0ol0003D
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`?o0000eoooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool4o`000=[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05kooooo0ol0003Nooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`?o0000hOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001Iooooo`?o0000i?ooool0
02Kooooo00?o0000ooooooooool0EOooool3o`000>Oooooo000Vooooo`03o`000?oooooooooo05;o
oooo0ol0003Zooooo`009_ooool00ol0003oooooooooo`1?ooooo`?o0000kOooool002Kooooo0_l0
001>ooooo`;o0000l?ooool002Kooooo00?o0000ooooooooool0B_ooool3o`000?;ooooo000Voooo
o`03o`000?oooooooooo04Sooooo0_l0003eooooo`009_ooool00ol0003oooooooooo`15ooooo`?o
0000moooool002Kooooo00?o0000ooooooooool0@_ooool3o`000?[ooooo000Vooooo`;o0000@Ooo
ool2o`000?gooooo000Vooooo`03o`000?oooooooooo03gooooo0ol0003oooooo`009_ooool00ol0
003oooooooooo`0kooooo`;o0000ooooool3ooooo`009_ooool00ol0003oooooooooo`0hooooo`?o
0000ooooool5ooooo`009_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool8ooooo`009_oo
ool2o`0003Gooooo0_l0003oooooo`[ooooo000Vooooo`03o`000?oooooooooo037ooooo0ol0003o
ooooo`cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003ooooooooo
o`0_ooooo`;o0000ooooool?ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0]ooooo`;o0000oooooolAooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o0000:oooool2o`000?oooooo4ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Xooooo`?o0000oooooolEooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_ooool2o`000?oooooo6?ooool000?ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Tooooo`;o0000oooooolJooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02;ooooo0_l0003ooooooacooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00027ooooo0_l0003ooooooakooooo
000Vooooo`03o`000?oooooooooo01gooooo0ol0003oooooob3ooooo000Vooooo`03o`000?oooooo
oooo01_ooooo0_l0003oooooob?ooooo000Vooooo`03o`000?oooooooooo01Wooooo0_l0003ooooo
obGooooo000Vooooo`03o`000?oooooooooo01Oooooo0_l0003oooooobOooooo000Vooooo`;o0000
5_ooool2o`000?oooooo:Oooool002Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`3oooooobWooooo000Vooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Voooo
o`03o`000?oooooooooo013ooooo0_l0003oooooobkooooo000Vooooo`03o`000?oooooooooo00ko
oooo0_l0003ooooooc3ooooo000Vooooo`;o00003Oooool2o`000?oooooo<_ooool002Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`03o`000?oooooo
oooo00Wooooo0_l0003oooooocGooooo000Vooooo`03o`000?oooooooooo00Oooooo0_l0003ooooo
ocOooooo000Vooooo`;o00001_ooool2o`000?oooooo>Oooool002Kooooo00?o0000ooooooooool0
0oooool2o`000?oooooo>oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc_ooooo
000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo00;o0000oooooolnooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@
413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003ooooo
ofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o0000ooooooooool01_oo
ool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o
410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?o
c<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`22ooooo`00S?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool6
o`0000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo08?ooooo002<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb
<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<08Co
oooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool0Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo00001Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00025ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33109 m
.11905 .2771 L
.21429 .23064 L
.30952 .1909 L
.40476 .15666 L
.5 .12657 L
.59524 .09928 L
.69048 .07366 L
.78571 .04886 L
.88095 .02439 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Oooooo`?o0000GOooool002Kooooo00?o0000oooo
ooooool0foooool4o`00063ooooo000Vooooo`03o`000?oooooooooo0=Oooooo1?l0001Tooooo`00
9_ooool2o`000=Gooooo0ol0001Xooooo`009_ooool00ol0003oooooooooo`3@ooooo`Co0000Jooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<co
oooo1?l0001_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo0ol0001cooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<7ooooo1?l0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2mooooo`Co0000O_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;Sooooo1Ol00022ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0]?ooool4o`0008Oooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000/Ooo
ool4o`0008_ooooo000Vooooo`03o`000?oooooooooo0:cooooo1?l0002?ooooo`009_ooool00ol0
003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000ooooooooool0YOooool3o`0009Oo
oooo000Vooooo`03o`000?oooooooooo0:;ooooo0ol0002Jooooo`009_ooool2o`000:3ooooo0ol0
002Mooooo`009_ooool00ol0003oooooooooo`2Kooooo`Co0000X?ooool002Kooooo00?o0000oooo
ooooool0V?ooool3o`000:Cooooo000Vooooo`03o`000?oooooooooo09Gooooo0ol0002Wooooo`00
9_ooool00ol0003oooooooooo`2Booooo`?o0000Z_ooool002Kooooo0_l0002@ooooo`?o0000[Ooo
ool002Kooooo00?o0000ooooooooool0Roooool4o`000;3ooooo000Vooooo`03o`000?oooooooooo
08Sooooo0ol0002dooooo`009_ooool00ol0003oooooooooo`25ooooo`?o0000]oooool002Kooooo
0_l00023ooooo`?o0000^_ooool002Kooooo00?o0000ooooooooool0O_ooool4o`000;gooooo000V
ooooo`03o`000?oooooooooo07_ooooo0ol00031ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1h
ooooo`?o0000a?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Gooooo0ol00037ooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0007;ooooo0ol0003:
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1_ooooo`?o0000cOooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K?ooool3o`000=3ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo06Wooooo0ol0003Cooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`?o0000e_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001Tooooo`?o0000fOooool0
02Kooooo00?o0000ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05go
oooo0ol0003Oooooo`009_ooool00ol0003oooooooooo`1Jooooo`?o0000h_ooool002Kooooo0_l0
001Hooooo`?o0000iOooool002Kooooo00?o0000ooooooooool0E?ooool3o`000>Sooooo000Voooo
o`03o`000?oooooooooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1?ooooo`?o
0000kOooool002Kooooo00?o0000ooooooooool0COooool2o`000?3ooooo000Vooooo`;o0000C?oo
ool2o`000?;ooooo000Vooooo`03o`000?oooooooooo04Sooooo0ol0003dooooo`009_ooool00ol0
003oooooooooo`16ooooo`;o0000moooool002Kooooo00?o0000ooooooooool0A?ooool2o`000?Wo
oooo000Vooooo`03o`000?oooooooooo047ooooo0ol0003kooooo`009_ooool2o`00043ooooo0_l0
003nooooo`009_ooool00ol0003oooooooooo`0mooooo`;o0000ooooool1ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0>_ooool3o`000?oooooo0ooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool2o`000?oooooo1_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0003Kooooo0_l0003oooooo`Sooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0=?ooool2o`000?oooooo2_ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo03;ooooo0_l0003oooooo`cooooo0003ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<?ooool2o`000?oooooo3_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`;o0000
ooooool@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1Oooool4o`0000Kooooo0_l0000]ooooo`;o0000oooooolBooooo`009_ooool00ol0003ooooooooo
o`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Wooooo`?o0000oooooolF
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooooolIooooo`009_ooool00ol0003o
ooooooooo`0Sooooo`;o0000oooooolKooooo`009_ooool2o`0002;ooooo0_l0003ooooooagooooo
000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoooooo000Vooooo`03o`000?oooooo
oooo01gooooo0_l0003oooooob7ooooo000Vooooo`03o`000?oooooooooo01_ooooo0_l0003ooooo
ob?ooooo000Vooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo000Vooooo`;o0000
6?ooool2o`000?oooooo9oooool002Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`3oooooobOooooo000Vooooo`03o`000?oooooooooo01Cooooo0_l0003oooooob[ooooo000Voooo
o`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Vooooo`;o00004_ooool00ol0003o
ooooooooo`3oooooobcooooo000Vooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo00gooooo0_l0003ooooooc7ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00_o
oooo0_l0003ooooooc?ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolcooooo`00
2oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000So
oooo0_l0003oooooocKooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000;ooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolhooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooo0_l0003ooooo
oc_ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooooooo0_l0003oooooocgooooo000Vooooo`;o000000?ooooo
o`000?ooool0oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo
00?oZJVYoa0@4?ooool01Oooool3o`000?oooooo@?ooool000_ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooom0ooooo`002ooo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RH
oooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0
003o<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@
okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0
003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l00006ooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`000?oooooo@?ooool0
00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`000?ooooooB_oo
ool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co00000?ooooooB_oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co00000?ooooooB_oo
ool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo0?ooooooBOoo
ool00?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005oooo
o`03o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03
o`000?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0003o410@00Ko
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04oooo
o`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o
^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c025ooooo`00S?ooool00ol0003ooooo
ooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0
0oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgM
o`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`000025ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B40QOooool008cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0QOooool008Wooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000So
oooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l0
00000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`27oooo
o`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0Qoooool0
08Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0
003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4125ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34889 m
.11905 .29449 L
.21429 .24642 L
.30952 .20419 L
.40476 .16704 L
.5 .13403 L
.59524 .10416 L
.69048 .07651 L
.78571 .05032 L
.88095 .02497 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0noooool4o`00043ooooo000Vooooo`;o0000n?oo
ool4o`0004Cooooo000Vooooo`03o`000?oooooooooo0?;ooooo1Ol00018ooooo`009_ooool00ol0
003oooooooooo`3^ooooo`Co0000COooool002Kooooo00?o0000ooooooooool0j_ooool4o`00057o
oooo000Vooooo`;o0000ioooool4o`0005Gooooo000Vooooo`03o`000?oooooooooo0>;ooooo1?l0
001Iooooo`009_ooool00ol0003oooooooooo`3Oooooo`?o0000GOooool002Kooooo00?o0000oooo
ooooool0foooool4o`00063ooooo000Vooooo`03o`000?oooooooooo0=Oooooo1?l0001Tooooo`00
9_ooool2o`000=Gooooo0ol0001Xooooo`009_ooool00ol0003oooooooooo`3@ooooo`Co0000Jooo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0<co
oooo1?l0001_ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<Wooooo0ol0001cooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0aOooool4
o`0007Kooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<;ooooo0ol0001jooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2oooooo`?o0000OOooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;cooooo0ol00020ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0^?ooool4o`0008?ooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000]_oo
ool3o`0008Oooooo000Vooooo`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`009_ooool00ol0
003oooooooooo`2_ooooo`?o0000SOooool002Kooooo00?o0000ooooooooool0[?ooool3o`00093o
oooo000Vooooo`03o`000?oooooooooo0:Sooooo1?l0002Cooooo`009_ooool2o`000:Kooooo0ol0
002Gooooo`009_ooool00ol0003oooooooooo`2Rooooo`?o0000V_ooool002Kooooo00?o0000oooo
ooooool0Woooool3o`0009gooooo000Vooooo`03o`000?oooooooooo09_ooooo1?l0002Pooooo`00
9_ooool00ol0003oooooooooo`2Hooooo`?o0000Y?ooool002Kooooo0_l0002Fooooo`?o0000Yooo
ool002Kooooo00?o0000ooooooooool0T_ooool3o`000:[ooooo000Vooooo`03o`000?oooooooooo
08oooooo0ol0002]ooooo`009_ooool00ol0003oooooooooo`2<ooooo`?o0000/?ooool002Kooooo
0_l0002:ooooo`?o0000/oooool002Kooooo00?o0000ooooooooool0Q_ooool3o`000;Kooooo000V
ooooo`03o`000?oooooooooo08?ooooo0ol0002iooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`20
ooooo`?o0000_?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07gooooo0ol0002oooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`0007[ooooo0ol00032
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`?o0000aOooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool3o`000<Sooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo077ooooo0ol0003;ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001]ooooo`?o0000d?ooool0
02Kooooo00?o0000ooooooooool0JOooool3o`000=?ooooo000Vooooo`03o`000?oooooooooo06Oo
oooo0_l0003Fooooo`009_ooool00ol0003oooooooooo`1Tooooo`?o0000f?ooool002Kooooo0_l0
001Rooooo`?o0000foooool002Kooooo00?o0000ooooooooool0Goooool2o`000=kooooo000Voooo
o`03o`000?oooooooooo05cooooo0ol0003Pooooo`009_ooool00ol0003oooooooooo`1Jooooo`;o
0000hoooool002Kooooo00?o0000ooooooooool0Eoooool3o`000>Gooooo000Vooooo`;o0000EOoo
ool3o`000>Sooooo000Vooooo`03o`000?oooooooooo05;ooooo0_l0003[ooooo`009_ooool00ol0
003oooooooooo`1@ooooo`;o0000kOooool002Kooooo00?o0000ooooooooool0C_ooool2o`000>oo
oooo000Vooooo`03o`000?oooooooooo04_ooooo0ol0003aooooo`009_ooool2o`0004[ooooo0_l0
003dooooo`009_ooool00ol0003oooooooooo`17ooooo`;o0000m_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo04Gooooo0_l0003hooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`13ooooo`;o0000n_ooool000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool3o`00047ooooo0_l0003looooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03oooooo0_l0
003nooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0??ooool3o`000?oooooo
0Oooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0003Oooooo
0_l0003oooooo`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000V
ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000Vooooo`03o`000?oooooooooo
033ooooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3o
oooo000Vooooo`;o0000;Oooool2o`000?oooooo4_ooool002Kooooo00?o0000ooooooooool0:_oo
ool2o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?ooool2o`000?oooooo5_ooool0
02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03
o`000?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o00009?ooool2o`000?oooooo
6oooool002Kooooo00?o0000ooooooooool08Oooool2o`000?oooooo7Oooool002Kooooo00?o0000
ooooooooool07oooool2o`000?oooooo7oooool002Kooooo00?o0000ooooooooool07Oooool2o`00
0?oooooo8Oooool002Kooooo0_l0000Looooo`;o0000oooooolSooooo`009_ooool00ol0003ooooo
ooooo`0Iooooo`;o0000oooooolUooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`0Eooooo`;o0000oooooolYooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?oooooo:Oooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0000Booooo`;o0000ooooool/ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0@ooooo`;o
0000ooooool^ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0>ooooo`;o0000ooooool`ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
00cooooo0_l0003ooooooc;ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3o
oooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool002Kooooo00?o0000oooooooo
ool01oooool2o`000?oooooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo
>Oooool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool002Kooooo0_l00003
ooooo`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003ooooo
ockooooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`25ooooo`00S?ooool0
0ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo
1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Q
ooooooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o0000
1Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool0Q?ooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80QOooool008Wooooo1ol00005oooo
o`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0008Gooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .36355 m
.11905 .30919 L
.21429 .26022 L
.30952 .2164 L
.40476 .17722 L
.5 .14202 L
.59524 .11004 L
.69048 .08053 L
.78571 .05277 L
.88095 .02612 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02kooooo1?l00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolBooooo`Co0000:_ooool002Kooooo
00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo0_l0003oooooo`cooooo1?l0
000aooooo`009_ooool00ol0003oooooooooo`3oooooo`Oooooo1?l0000eooooo`009_ooool00ol0
003oooooooooo`3oooooo`Cooooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
0000??ooool002Kooooo00?o0000ooooooooool0o?ooool3o`00043ooooo000Vooooo`;o0000nOoo
ool4o`0004?ooooo000Vooooo`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0
003oooooooooo`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0kOooool4o`0004ko
oooo000Vooooo`;o0000j_ooool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0
001Fooooo`009_ooool00ol0003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000oooo
ooooool0goooool3o`0005gooooo000Vooooo`03o`000?oooooooooo0=cooooo0ol0001Pooooo`00
9_ooool2o`000=[ooooo0ol0001Sooooo`009_ooool00ol0003oooooooooo`3Eooooo`Co0000I_oo
ool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0=;o
oooo0ol0001Zooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
0<oooooo0ol0001]ooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool3
o`00073ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000<Wooooo0ol0001cooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`35ooooo`Co0000M_ooool000?ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0<;ooooo0ol0001jooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0_oooool3o`0007gooooo0003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000_Ooo
ool3o`00083ooooo000Vooooo`03o`000?oooooooooo0;Sooooo1?l00023ooooo`009_ooool00ol0
003oooooooooo`2eooooo`?o0000Qoooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[o
oooo000Vooooo`03o`000?oooooooooo0:oooooo0ol0002=ooooo`009_ooool2o`000:gooooo0ol0
002@ooooo`009_ooool00ol0003oooooooooo`2Xooooo`Co0000Toooool002Kooooo00?o0000oooo
ooooool0YOooool3o`0009Oooooo000Vooooo`03o`000?oooooooooo0:;ooooo0ol0002Jooooo`00
9_ooool00ol0003oooooooooo`2Oooooo`?o0000WOooool002Kooooo0_l0002Looooo`Co0000X?oo
ool002Kooooo00?o0000ooooooooool0V?ooool3o`000:Cooooo000Vooooo`03o`000?oooooooooo
09Gooooo0ol0002Wooooo`009_ooool00ol0003oooooooooo`2Booooo`?o0000Z_ooool002Kooooo
0_l0002@ooooo`?o0000[Oooool002Kooooo00?o0000ooooooooool0S?ooool3o`000;3ooooo000V
ooooo`03o`000?oooooooooo08Wooooo0ol0002cooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`26
ooooo`?o0000]_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Cooooo0_l0002iooooo`002oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3o`00087ooooo0ol0002k
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1nooooo`?o0000__ooool000_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O?ooool2o`000<7ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07Wooooo0ol00033ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o0000a_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0001eooooo`?o0000b?ooool0
02Kooooo00?o0000ooooooooool0LOooool3o`000<_ooooo000Vooooo`03o`000?oooooooooo06oo
oooo0_l0003>ooooo`009_ooool00ol0003oooooooooo`1/ooooo`?o0000d?ooool002Kooooo0_l0
001[ooooo`;o0000doooool002Kooooo00?o0000ooooooooool0J?ooool2o`000=Gooooo000Voooo
o`03o`000?oooooooooo06Gooooo0ol0003Gooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o
0000f_ooool002Kooooo00?o0000ooooooooool0H?ooool3o`000=cooooo000Vooooo`;o0000Gooo
ool2o`000=oooooo000Vooooo`03o`000?oooooooooo05_ooooo0ol0003Qooooo`009_ooool00ol0
003oooooooooo`1Iooooo`;o0000i?ooool002Kooooo00?o0000ooooooooool0Eoooool2o`000>Ko
oooo000Vooooo`03o`000?oooooooooo05Cooooo0ol0003Xooooo`009_ooool2o`0005?ooooo0_l0
003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l0
00000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo04kooooo0_l0003_ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1;ooooo`?o0000lOooool000?ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool3o`0004Wooooo0_l0003dooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo0_l0
003fooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0AOooool2o`000?Sooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0@oooool2o`000?[ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@Oooool2o`000?cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00043ooooo0_l0003nooooo`009_oo
ool00ol0003oooooooooo`0looooo`?o0000ooooool1ooooo`009_ooool00ol0003oooooooooo`0j
ooooo`;o0000ooooool4ooooo`009_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6oooo
o`009_ooool00ol0003oooooooooo`0fooooo`;o0000ooooool8ooooo`009_ooool2o`0003Gooooo
0_l0003oooooo`[ooooo000Vooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000V
ooooo`03o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo
02kooooo0_l0003ooooooa3ooooo000Vooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa;o
oooo000Vooooo`;o0000:oooool2o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?oo
ool2o`000?oooooo5_ooool002Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3o
oooooaKooooo000Vooooo`03o`000?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`;o
00009?ooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Oooool2o`000?oooooo
7Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo
00?o0000ooooooooool07oooool2o`000?oooooo7oooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool07Oooool2o`000?oooooo8Oooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool2o`000?oooooo8oooool000_ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Iooooo`;o
0000oooooolUooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`002oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`;o
0000oooooolYooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYoooo
o`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo01;ooooo0_l0003oooooobcooooo000Vooooo`;o00004Oooool2o`00
0?oooooo;_ooool002Kooooo00?o0000ooooooooool03_ooool2o`000?oooooo<?ooool002Kooooo
00?o0000ooooooooool03?ooool2o`000?oooooo<_ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool0
02Kooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool002Kooooo00?o0000oooooooo
ool01Oooool2o`000?oooooo>Oooool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo
>oooool002Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc_ooooo000V
ooooo`;o000000?oooooo`000?l00000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o
410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYoooo
o`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_oo
ool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnH
V9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o
0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0
003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08Gooooo002<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c025ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100QOooool008Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000QOoo
ool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool0
0ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .37583 m
.11905 .32179 L
.21429 .27239 L
.30952 .22754 L
.40476 .18691 L
.5 .15002 L
.59524 .11629 L
.69048 .08506 L
.78571 .05569 L
.88095 .02754 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co0000??ooool002Kooooo0_l0
003mooooo`?o0000@?ooool002Kooooo00?o0000ooooooooool0n?ooool4o`0004?ooooo000Voooo
o`03o`000?oooooooooo0?Cooooo1?l00017ooooo`009_ooool00ol0003oooooooooo`3aooooo`?o
0000Boooool002Kooooo0_l0003^ooooo`Co0000C_ooool002Kooooo00?o0000ooooooooool0jOoo
ool4o`0005;ooooo000Vooooo`03o`000?oooooooooo0>Kooooo0ol0001Fooooo`009_ooool00ol0
003oooooooooo`3Rooooo`Co0000FOooool002Kooooo00?o0000ooooooooool0goooool3o`0005go
oooo000Vooooo`;o0000gOooool3o`00063ooooo000Vooooo`03o`000?oooooooooo0=Wooooo0ol0
001Sooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0eOooool4o`0006Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0d_ooool3o`0006[ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3?
ooooo`?o0000KOooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000c?ooool3o`00073ooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<Wooooo0ol0001cooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0aOooool4o`0007Kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`32ooooo`?o0000N_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Kooooo0_l0
0030ooooo`?o0000OOooool002Kooooo00?o0000ooooooooool0_?ooool3o`00083ooooo000Voooo
o`03o`000?oooooooooo0;Sooooo1?l00023ooooo`009_ooool00ol0003oooooooooo`2eooooo`?o
0000Qoooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[ooooo000Vooooo`;o0000/?oo
ool3o`0008gooooo000Vooooo`03o`000?oooooooooo0:cooooo0ol0002@ooooo`009_ooool00ol0
003oooooooooo`2Yooooo`?o0000Toooool002Kooooo00?o0000ooooooooool0Y_ooool3o`0009Ko
oooo000Vooooo`03o`000?oooooooooo0:?ooooo0ol0002Iooooo`009_ooool2o`000:;ooooo0_l0
002Looooo`009_ooool00ol0003oooooooooo`2Nooooo`?o0000W_ooool002Kooooo00?o0000oooo
ooooool0Voooool3o`000:7ooooo000Vooooo`03o`000?oooooooooo09Wooooo0_l0002Tooooo`00
9_ooool2o`0009Oooooo0ol0002Vooooo`009_ooool00ol0003oooooooooo`2Dooooo`;o0000ZOoo
ool002Kooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo08kooooo0ol0002^ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool2o`000;7ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000ROooool3
o`000;?ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08Kooooo0ol0002fooooo`002oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`24ooooo`;o0000^Oooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0POooool3o`000;_ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2o`0007gooooo0_l00031
ooooo`009_ooool00ol0003oooooooooo`1iooooo`?o0000`oooool002Kooooo00?o0000oooooooo
ool0Moooool2o`000<Kooooo000Vooooo`03o`000?oooooooooo07Cooooo0ol00038ooooo`009_oo
ool2o`0007;ooooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool0
02Kooooo00?o0000ooooooooool0K?ooool3o`000=3ooooo000Vooooo`03o`000?oooooooooo06[o
oooo0_l0003Cooooo`009_ooool00ol0003oooooooooo`1Xooooo`;o0000eOooool002Kooooo0_l0
001Vooooo`?o0000eoooool002Kooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo000Voooo
o`03o`000?oooooooooo063ooooo0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o
0000goooool002Kooooo00?o0000ooooooooool0Foooool3o`000>7ooooo000Vooooo`;o0000F_oo
ool2o`000>Cooooo000Vooooo`03o`000?oooooooooo05Oooooo0_l0003Vooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0E?ooool3o`000>Sooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05;ooooo0_l0003[ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000D?ooool2o`000>gooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0C_oo
ool2o`000>oooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1<ooooo`;o0000
lOooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`;o0000loooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`18ooooo`;o0000mOooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000Aoooool2o`000?Oooooo
000Vooooo`03o`000?oooooooooo04Cooooo0_l0003iooooo`009_ooool00ol0003oooooooooo`12
ooooo`;o0000noooool002Kooooo00?o0000ooooooooool0@?ooool2o`000?gooooo000Vooooo`03
o`000?oooooooooo03kooooo0_l0003oooooo`009_ooool2o`0003gooooo0_l0003oooooo`;ooooo
000Vooooo`03o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo000Vooooo`03o`000?oooooo
oooo03Sooooo0_l0003oooooo`Kooooo000Vooooo`03o`000?oooooooooo03Kooooo0_l0003ooooo
o`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000Vooooo`;o0000
<oooool2o`000?oooooo3?ooool002Kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_oo
ool002Kooooo00?o0000ooooooooool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000oooo
ooooool0;?ooool2o`000?oooooo4_ooool002Kooooo0_l0000[ooooo`;o0000oooooolDooooo`00
9_ooool00ol0003oooooooooo`0Xooooo`;o0000oooooolFooooo`002oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?oooooo5_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool2o`000?oo
oooo6Oooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool08oooool2o`000?oooooo6oooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Qooooo`;o0000oooooolMooooo`00
2oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0Oooooo`;o0000oooooolOooooo`002oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`;o0000oooooolQooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo01_ooooo0_l0003oooooob?ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool06Oooool2
o`000?oooooo9Oooool002Kooooo0_l0000Hooooo`;o0000oooooolWooooo`009_ooool00ol0003o
ooooooooo`0Eooooo`;o0000oooooolYooooo`009_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0?oooooo:Oooool002Kooooo00?o0000ooooooooool04_ooool2o`000?oooooo;?oo
ool002Kooooo0_l0000Aooooo`;o0000ooooool^ooooo`009_ooool00ol0003oooooooooo`0>oooo
o`;o0000ooooool`ooooo`009_ooool00ol0003oooooooooo`0<ooooo`;o0000oooooolbooooo`00
9_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo<_ooool002Kooooo00?o
0000ooooooooool02Oooool2o`000?oooooo=Oooool002Kooooo0_l00008ooooo`;o0000oooooolg
ooooo`009_ooool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`009_ooool00ol0003o
ooooooooo`03ooooo`;o0000oooooolkooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooockooooo000V
ooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3o
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol0003ooooooooooooo
oooo000000kooooo00?oZJVYoa0@4?ooool01Oooool3o`000?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooom0ooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o
0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oa0@4?l0003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l00006ooooo`;o
0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`000?ooooooB_ooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
00000?ooooooB_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
00000?ooooooB_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo0?ooooooBOooool00?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00co
oooo0_l00005ooooo`03o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo
0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`00
0?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo
0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<Q_ooool008cooooo00?o
0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM
08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`24
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?lQ
8B7o0000oeEEEOl00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
ob4Q8On7QhOooooooiRHV?l00000QOooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000008Gooooo
0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE
08Gooooo0029ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000go
oooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38627 m
.11905 .33269 L
.21429 .28316 L
.30952 .23764 L
.40476 .19596 L
.5 .15773 L
.59524 .1225 L
.69048 .08971 L
.78571 .05878 L
.88095 .02908 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`Co0000??ooool002Kooooo0_l0
003mooooo`?o0000@?ooool002Kooooo00?o0000ooooooooool0nOooool3o`0004?ooooo000Voooo
o`03o`000?oooooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003oooooooooo`3booooo`Co
0000BOooool002Kooooo0_l0003`ooooo`?o0000COooool002Kooooo00?o0000ooooooooool0k?oo
ool3o`00053ooooo000Vooooo`03o`000?oooooooooo0>Wooooo0ol0001Cooooo`009_ooool00ol0
003oooooooooo`3Vooooo`?o0000E_ooool002Kooooo00?o0000ooooooooool0h_ooool4o`0005Wo
oooo000Vooooo`;o0000h?ooool3o`0005gooooo000Vooooo`03o`000?oooooooooo0=cooooo0ol0
001Pooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0fOooool3o`0006?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0eOooool4o`0006Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3B
ooooo`?o0000J_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000coooool3o`0006gooooo0003
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0<cooooo0ol0001`ooooo`00
0oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0bOooool3o`0007?ooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`36ooooo`?o0000M_ooool000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Kooooo0_l0
0034ooooo`?o0000NOooool002Kooooo00?o0000ooooooooool0`?ooool3o`0007cooooo000Voooo
o`03o`000?oooooooooo0;gooooo0ol0001oooooo`009_ooool00ol0003oooooooooo`2jooooo`?o
0000P_ooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Vooooo`;o0000]Ooo
ool3o`0008Sooooo000Vooooo`03o`000?oooooooooo0;7ooooo0ol0002;ooooo`009_ooool00ol0
003oooooooooo`2^ooooo`?o0000S_ooool002Kooooo00?o0000ooooooooool0Zoooool3o`00097o
oooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`009_ooool2o`000:Oooooo0ol0
002Fooooo`009_ooool00ol0003oooooooooo`2Sooooo`?o0000VOooool002Kooooo00?o0000oooo
ooooool0XOooool2o`0009cooooo000Vooooo`03o`000?oooooooooo09kooooo0ol0002Nooooo`00
9_ooool2o`0009cooooo0ol0002Qooooo`009_ooool00ol0003oooooooooo`2Iooooo`;o0000Y?oo
ool002Kooooo00?o0000ooooooooool0U_ooool3o`000:Kooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo09Cooooo0_l0002Yooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000S_ooool3
o`000:kooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08cooooo0_l0002aooooo`002oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`?o0000/oooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Qoooool2o`000;Kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2o`0008?ooooo0ol0002j
ooooo`009_ooool00ol0003oooooooooo`20ooooo`;o0000_Oooool002Kooooo00?o0000oooooooo
ool0OOooool3o`000;oooooo000Vooooo`03o`000?oooooooooo07_ooooo0_l00032ooooo`009_oo
ool2o`0007Wooooo0ol00034ooooo`009_ooool00ol0003oooooooooo`1fooooo`;o0000aoooool0
02Kooooo00?o0000ooooooooool0M?ooool2o`000<Wooooo000Vooooo`03o`000?oooooooooo077o
oooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool002Kooooo0_l0
001]ooooo`?o0000d?ooool002Kooooo00?o0000ooooooooool0J_ooool2o`000=?ooooo000Voooo
o`03o`000?oooooooooo06Sooooo0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Uooooo`?o
0000eoooool002Kooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo000Vooooo`;o0000HOoo
ool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Oooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4
A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0Foooool3o`000>7ooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo05Wooooo0_l0003Tooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`?o0000Eoooool2o`000>Kooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0E?oo
ool3o`000>Sooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1Booooo`;o0000
joooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1@ooooo`;o0000kOooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1>ooooo`;o0000koooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000COooool2o`000?7ooooo
000Vooooo`03o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool00ol0003oooooooooo`18
ooooo`;o0000mOooool002Kooooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000Vooooo`03
o`000?oooooooooo04Cooooo0_l0003iooooo`009_ooool2o`0004?ooooo0_l0003kooooo`009_oo
ool00ol0003oooooooooo`10ooooo`;o0000oOooool002Kooooo00?o0000ooooooooool0?_ooool2
o`000?oooooo000Vooooo`03o`000?oooooooooo03cooooo0_l0003oooooo`;ooooo000Vooooo`03
o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo000Vooooo`;o0000>Oooool2o`000?oooooo
1_ooool002Kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool002Kooooo00?o0000
ooooooooool0=?ooool2o`000?oooooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`00
0?oooooo3?ooool002Kooooo0_l0000aooooo`;o0000ooooool>ooooo`009_ooool00ol0003ooooo
ooooo`0^ooooo`;o0000ooooool@ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01_ooool00ol0003oooooooooo`0Zooooo`;o0000oooooolDooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Xooooo`;o
0000oooooolFooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0002Oooooo00?o0000ooooooooool0oooooolFooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Uooooo`;o
0000oooooolIooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Sooooo`;o0000oooooolKooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool07oooool2o`000?oooooo7oooool0
02Kooooo0_l0000Nooooo`;o0000oooooolQooooo`009_ooool00ol0003oooooooooo`0Kooooo`;o
0000oooooolSooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`009_ooool2o`0001Kooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYoooo
o`009_ooool00ol0003oooooooooo`0Booooo`;o0000ooooool/ooooo`009_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000ooooool^ooooo`009_ooool00ol0003oooooooooo`0>ooooo`;o0000oooo
ool`ooooo`009_ooool2o`0000gooooo0_l0003ooooooc;ooooo000Vooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0oooooolbooooo`009_ooool00ol0003oooooooooo`09ooooo`;o
0000ooooooleooooo`009_ooool00ol0003oooooooooo`07ooooo`;o0000oooooolgooooo`009_oo
ool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`009_ooool2o`0000Cooooo0_l0003o
oooooc_ooooo000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolkoooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00_l0003oooooockooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00V?ooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo002>ooooo`05oa0@4?l0
003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo
00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000oooooooo
ool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o
410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Aooooo`00T?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool6o`0000Cooooo00?o0000ooooooooool0TOooool0093ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo
00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool0
TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0TOooool008gooooo1ol00004ooooo`;o00004ooo
ool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmV
IVKo000009?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39525 m
.11905 .34221 L
.21429 .2927 L
.30952 .24678 L
.40476 .20429 L
.5 .16499 L
.59524 .12847 L
.69048 .09427 L
.78571 .06184 L
.88095 .03062 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02oooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_l00002oooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0oooooolDooooo`?o0000:Oooool002Kooooo
00?o0000ooooooooool0ooooool@ooooo`Co0000;?ooool002Kooooo0_l0003oooooo`kooooo0ol0
000`ooooo`009_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000cooooo`009_ooool00ol0
003oooooooooo`3oooooo`Oooooo0ol0000fooooo`009_ooool00ol0003oooooooooo`3oooooo`Co
oooo0ol0000iooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0ol0000looooo`009_oo
ool2o`000?kooooo0ol0000oooooo`009_ooool00ol0003oooooooooo`3jooooo`?o0000@_ooool0
02Kooooo00?o0000ooooooooool0moooool3o`0004Gooooo000Vooooo`03o`000?oooooooooo0?Co
oooo0ol00018ooooo`009_ooool2o`000?;ooooo0ol0001;ooooo`009_ooool00ol0003ooooooooo
o`3^ooooo`?o0000C_ooool002Kooooo00?o0000ooooooooool0joooool3o`00057ooooo000Voooo
o`03o`000?oooooooooo0>Sooooo0ol0001Dooooo`009_ooool00ol0003oooooooooo`3Uooooo`?o
0000Eoooool002Kooooo0_l0003Tooooo`;o0000F_ooool002Kooooo00?o0000ooooooooool0h?oo
ool3o`0005cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Mooooo`?o0000Goooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Jooooo`?o0000H_ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=Oooooo0ol0001Uooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Dooooo`?o0000J?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0dOooool3o`0006_o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3>ooooo`?o0000K_ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<_ooooo0ol0001aooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<Wooooo0ol0001dooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool0
02Kooooo00?o0000ooooooooool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<3o
oooo0ol0001looooo`009_ooool00ol0003oooooooooo`2mooooo`?o0000Ooooool002Kooooo0_l0
002kooooo`?o0000P_ooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Voooo
o`03o`000?oooooooooo0;Cooooo0ol00028ooooo`009_ooool00ol0003oooooooooo`2aooooo`?o
0000Roooool002Kooooo00?o0000ooooooooool0[_ooool3o`0008kooooo000Vooooo`;o0000[?oo
ool3o`00097ooooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`009_ooool00ol0
003oooooooooo`2Vooooo`?o0000U_ooool002Kooooo00?o0000ooooooooool0Xoooool3o`0009Wo
oooo000Vooooo`;o0000X_ooool2o`0009cooooo000Vooooo`03o`000?oooooooooo09kooooo0ol0
002Nooooo`009_ooool00ol0003oooooooooo`2Kooooo`?o0000XOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0VOooool2o`000:Cooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Fooooo`?o0000Y_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002D
ooooo`;o0000ZOooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0TOooool3o`000:_ooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo0ol0002^
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2<ooooo`;o0000/Oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROooool3o`000;?ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000R?ooool2
o`000;Kooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`009_ooool00ol0003o
ooooooooo`22ooooo`?o0000^_ooool002Kooooo00?o0000ooooooooool0P?ooool2o`000;gooooo
000Vooooo`;o0000O_ooool3o`000;oooooo000Vooooo`03o`000?oooooooooo07_ooooo0_l00032
ooooo`009_ooool00ol0003oooooooooo`1hooooo`?o0000a?ooool002Kooooo00?o0000oooooooo
ool0M_ooool2o`000<Oooooo000Vooooo`03o`000?oooooooooo07Cooooo0_l00039ooooo`009_oo
ool2o`0007;ooooo0ol0003;ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool0
02Kooooo00?o0000ooooooooool0KOooool2o`000=3ooooo000Vooooo`03o`000?oooooooooo06[o
oooo0ol0003Booooo`009_ooool00ol0003oooooooooo`1Xooooo`;o0000eOooool002Kooooo0_l0
001Wooooo`;o0000eoooool002Kooooo00?o0000ooooooooool0I?ooool2o`000=Wooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1Qooooo`?o0000fooo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Goooool2o`000=kooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Mooooo`;o0000h?ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Kooooo`;o0000h_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05Wooooo
0_l0003Tooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo0ol0003Vooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05Cooooo0_l0003Yooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Cooooo`;o0000
joooool002Kooooo00?o0000ooooooooool0D?ooool2o`000>gooooo000Vooooo`03o`000?oooooo
oooo04kooooo0_l0003_ooooo`009_ooool00ol0003oooooooooo`1<ooooo`;o0000lOooool002Ko
oooo00?o0000ooooooooool0B_ooool2o`000??ooooo000Vooooo`;o0000BOooool2o`000?Gooooo
000Vooooo`03o`000?oooooooooo04Kooooo0_l0003gooooo`009_ooool00ol0003oooooooooo`14
ooooo`;o0000nOooool002Kooooo00?o0000ooooooooool0@_ooool2o`000?_ooooo000Vooooo`03
o`000?oooooooooo043ooooo0_l0003mooooo`009_ooool2o`0003oooooo0_l0003oooooo`009_oo
ool00ol0003oooooooooo`0looooo`;o0000ooooool2ooooo`009_ooool00ol0003oooooooooo`0j
ooooo`;o0000ooooool4ooooo`009_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6oooo
o`009_ooool2o`0003Oooooo0_l0003oooooo`Sooooo000Vooooo`03o`000?oooooooooo03Cooooo
0_l0003oooooo`[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000;ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3o
oooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o
0000;?ooool2o`000?oooooo4_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool000_ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:?ooool2o`000?oooooo5_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Uooooo`;o0000oooooolIooooo`009_ooool2o`00
02Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo027ooooo0_l0003ooooooago
oooo000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoooooo000Vooooo`03o`000?oo
oooooooo01gooooo0_l0003oooooob7ooooo000Vooooo`;o00007?ooool2o`000?oooooo8oooool0
02Kooooo00?o0000ooooooooool06Oooool2o`000?oooooo9Oooool002Kooooo00?o0000oooooooo
ool05oooool2o`000?oooooo9oooool002Kooooo00?o0000ooooooooool05Oooool2o`000?oooooo
:Oooool002Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3oooooobWooooo000V
ooooo`;o00004oooool2o`000?oooooo;?ooool002Kooooo00?o0000ooooooooool04?ooool2o`00
0?oooooo;_ooool002Kooooo00?o0000ooooooooool03_ooool2o`000?oooooo<?ooool002Kooooo
00?o0000ooooooooool03?ooool2o`000?oooooo<_ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3ooooooc;ooooo000Vooooo`;o00002_ooool2o`000?oooooo=Oooool0
02Kooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooocWooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`0000;ooooo00?o0000ooooooooool0oooooolkooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00;o0000oooooolnooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0ol0003ooooood3ooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool0P_ooool008cooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@
413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Q?oo
ool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`00
0?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`24ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0
000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`00
0026ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40307 m
.11905 .35057 L
.21429 .30119 L
.30952 .255 L
.40476 .21191 L
.5 .17171 L
.59524 .13408 L
.69048 .09859 L
.78571 .06478 L
.88095 .0321 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`;ooooo0_l0000mooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool0
02Kooooo00?o0000ooooooooool0n_ooool3o`0004;ooooo000Vooooo`03o`000?oooooooooo0?Oo
oooo0ol00015ooooo`009_ooool2o`000?Gooooo0ol00018ooooo`009_ooool00ol0003ooooooooo
o`3aooooo`?o0000Boooool002Kooooo00?o0000ooooooooool0k_ooool3o`0004kooooo000Voooo
o`03o`000?oooooooooo0>_ooooo0ol0001Aooooo`009_ooool00ol0003oooooooooo`3Xooooo`?o
0000E?ooool002Kooooo0_l0003Vooooo`?o0000Eoooool002Kooooo00?o0000ooooooooool0hooo
ool2o`0005[ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Pooooo`?o0000G?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Mooooo`?o0000Goooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=[ooooo0ol0001Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Gooooo`?o0000IOoo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0e?ooool3o`0006So
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Aooooo`?o0000Joooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0<kooooo0ol0001^ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<cooooo0ol0001aooooo`009_ooool00ol0003oooooooooo`38ooooo`?o0000M?ooool0
02Kooooo00?o0000ooooooooool0a_ooool2o`0007Oooooo000Vooooo`03o`000?oooooooooo0<?o
oooo0ol0001iooooo`009_ooool00ol0003oooooooooo`30ooooo`?o0000O?ooool002Kooooo0_l0
002oooooo`;o0000Ooooool002Kooooo00?o0000ooooooooool0^oooool3o`00087ooooo000Voooo
o`03o`000?oooooooooo0;Sooooo0ol00024ooooo`009_ooool00ol0003oooooooooo`2fooooo`;o
0000Qoooool002Kooooo00?o0000ooooooooool0/oooool3o`0008Wooooo000Vooooo`;o0000/_oo
ool2o`0008cooooo000Vooooo`03o`000?oooooooooo0:kooooo0ol0002>ooooo`009_ooool00ol0
003oooooooooo`2[ooooo`?o0000TOooool002Kooooo00?o0000ooooooooool0ZOooool2o`0009Co
oooo000Vooooo`;o0000Yoooool3o`0009Kooooo000Vooooo`03o`000?oooooooooo0:?ooooo0ol0
002Iooooo`009_ooool00ol0003oooooooooo`2Qooooo`;o0000W?ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0W_ooool3o`0009kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Kooooo`?o0000XOooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002I
ooooo`;o0000Y?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0U_ooool3o`000:Kooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Cooooo0_l0002Y
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Aooooo`?o0000Zoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool3o`000:kooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000SOooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08Wooooo0ol0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`;o0000]_ooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Poooool3o`000;[ooooo000Vooooo`03o`000?oooooooooo083ooooo0_l0002m
ooooo`009_ooool00ol0003oooooooooo`1mooooo`?o0000_oooool002Kooooo00?o0000oooooooo
ool0Noooool2o`000<;ooooo000Vooooo`03o`000?oooooooooo07Sooooo0ol00034ooooo`009_oo
ool2o`0007Oooooo0_l00037ooooo`009_ooool00ol0003oooooooooo`1dooooo`;o0000bOooool0
02Kooooo00?o0000ooooooooool0LOooool3o`000<_ooooo000Vooooo`03o`000?oooooooooo06oo
oooo0_l0003>ooooo`009_ooool00ol0003oooooooooo`1]ooooo`;o0000d?ooool002Kooooo0_l0
001/ooooo`;o0000d_ooool002Kooooo00?o0000ooooooooool0JOooool2o`000=Cooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1Wooooo`;o0000e_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0IOooool2o`000=Sooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Sooooo`;o0000f_ooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Pooooo`?o0000g?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo05kooooo
0_l0003Oooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo0_l0003Qooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05[ooooo0_l0003Sooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Iooooo`;o0000
iOooool002Kooooo00?o0000ooooooooool0E_ooool2o`000>Oooooo000Vooooo`03o`000?oooooo
oooo05Cooooo0_l0003Yooooo`009_ooool00ol0003oooooooooo`1Booooo`;o0000joooool002Ko
oooo00?o0000ooooooooool0D?ooool2o`000>gooooo000Vooooo`;o0000Coooool2o`000>oooooo
000Vooooo`03o`000?oooooooooo04cooooo0_l0003aooooo`009_ooool00ol0003oooooooooo`1:
ooooo`;o0000loooool002Kooooo00?o0000ooooooooool0B?ooool2o`000?Gooooo000Vooooo`03
o`000?oooooooooo04Kooooo0_l0003gooooo`009_ooool2o`0004Gooooo0_l0003iooooo`009_oo
ool00ol0003oooooooooo`12ooooo`;o0000noooool002Kooooo00?o0000ooooooooool0@?ooool2
o`000?gooooo000Vooooo`03o`000?oooooooooo03kooooo0_l0003oooooo`009_ooool2o`0003go
oooo0_l0003oooooo`;ooooo000Vooooo`03o`000?oooooooooo03[ooooo0_l0003oooooo`Cooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo03Sooooo0_l0003oooooo`Kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03Ko
oooo0_l0003oooooo`Sooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo03Cooooo0_l0003oooooo`[ooooo000;ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000<_ooool2o`000?oo
oooo3?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Go
oooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_ooool000_ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool2o`000?oo
oooo4?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo02[ooooo0_l0003ooooooaCooooo000Vooooo`;o0000:Oooool2o`000?oooooo5_ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`03o`000?oooooooooo02?ooooo0_l0
003ooooooa_ooooo000Vooooo`;o00008_ooool2o`000?oooooo7Oooool002Kooooo00?o0000oooo
ooooool07oooool2o`000?oooooo7oooool002Kooooo00?o0000ooooooooool07Oooool2o`000?oo
oooo8Oooool002Kooooo00?o0000ooooooooool06oooool2o`000?oooooo8oooool002Kooooo00?o
0000ooooooooool06Oooool2o`000?oooooo9Oooool002Kooooo0_l0000Hooooo`;o0000oooooolW
ooooo`009_ooool00ol0003oooooooooo`0Eooooo`;o0000oooooolYooooo`009_ooool00ol0003o
ooooooooo`0Cooooo`;o0000ooooool[ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o0000
ooooool]ooooo`009_ooool00ol0003oooooooooo`0?ooooo`;o0000ooooool_ooooo`009_ooool2
o`0000kooooo0_l0003ooooooc7ooooo000Vooooo`03o`000?oooooooooo00_ooooo0_l0003ooooo
oc?ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0?oooooo<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`08ooooo`;o0000oooooolfooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001_ooool2o`000?oooooo>?oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04ooooo`;o0000ooooooljooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool00_ooool2o`000?oooooo??ooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02o`000?oooooo?_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`?o
0000oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`00
0?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo
@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zj
o`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co
00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000QOooool008cooooo00?o0000oooo
ooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A408Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@
4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0Q_ooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
1_l00005ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0QOooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00omgMgOoIVIVooooo`24ooooo`00ROooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`23ooooo`00
ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c025oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .40992 m
.11905 .35796 L
.21429 .30876 L
.30952 .2624 L
.40476 .21883 L
.5 .17787 L
.59524 .13926 L
.69048 .10263 L
.78571 .06753 L
.88095 .0335 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5Oooool3o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4_ooool3o`0002_ooooo000Vooooo`;o0000ooooool@ooooo`?o0000;_oo
ool002Kooooo00?o0000ooooooooool0ooooool<ooooo`?o0000<Oooool002Kooooo00?o0000oooo
ooooool0ooooool9ooooo`?o0000=?ooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o
0000=oooool002Kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000>_ooool002Kooooo0_l0
003oooooo`;ooooo0_l0000mooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool0
02Kooooo00?o0000ooooooooool0n_ooool3o`0004;ooooo000Vooooo`03o`000?oooooooooo0?So
oooo0_l00015ooooo`009_ooool2o`000?Kooooo0ol00017ooooo`009_ooool00ol0003ooooooooo
o`3booooo`?o0000B_ooool002Kooooo00?o0000ooooooooool0l?ooool2o`0004gooooo000Voooo
o`03o`000?oooooooooo0>gooooo0ol0001?ooooo`009_ooool00ol0003oooooooooo`3[ooooo`;o
0000D_ooool002Kooooo0_l0003Yooooo`?o0000E?ooool002Kooooo00?o0000ooooooooool0iOoo
ool3o`0005Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3Sooooo`;o0000F_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Pooooo`?o0000G?ooool000?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=gooooo0ol0001Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003Jooooo`?o0000H_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0eoooool3o`0006Go
oooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Dooooo`?o0000J?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=7ooooo0ol0001[ooooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`000<oooooo0ol0001^ooooo`009_ooool00ol0003oooooooooo`3;ooooo`?o0000LOooool0
02Kooooo00?o0000ooooooooool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Ko
oooo0_l0001gooooo`009_ooool00ol0003oooooooooo`33ooooo`?o0000NOooool002Kooooo0_l0
0031ooooo`?o0000O?ooool002Kooooo00?o0000ooooooooool0__ooool2o`0007oooooo000Voooo
o`03o`000?oooooooooo0;_ooooo0ol00021ooooo`009_ooool00ol0003oooooooooo`2hooooo`?o
0000Q?ooool002Kooooo00?o0000ooooooooool0]_ooool2o`0008Oooooo000Vooooo`;o0000]?oo
ool3o`0008Wooooo000Vooooo`03o`000?oooooooooo0;7ooooo0_l0002<ooooo`009_ooool00ol0
003oooooooooo`2^ooooo`?o0000S_ooool002Kooooo00?o0000ooooooooool0Zoooool3o`00097o
oooo000Vooooo`;o0000Z_ooool2o`0009Cooooo000Vooooo`03o`000?oooooooooo0:Kooooo0ol0
002Fooooo`009_ooool00ol0003oooooooooo`2Tooooo`;o0000VOooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0X_ooool2o`0009_ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Oooooo`?o0000WOooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0002M
ooooo`;o0000X?ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0V_ooool3o`000:;ooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Sooooo0_l0002U
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Eooooo`?o0000Yoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o0000T_ooool2
o`000:cooooo000Vooooo`03o`000?oooooooooo08kooooo0ol0002^ooooo`009_ooool00ol0003o
ooooooooo`2<ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2o`000;?ooooo
000Vooooo`;o0000R?ooool3o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002h
ooooo`009_ooool00ol0003oooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000oooooooo
ool0POooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`009_oo
ool2o`0007gooooo0_l00031ooooo`009_ooool00ol0003oooooooooo`1jooooo`;o0000`oooool0
02Kooooo00?o0000ooooooooool0N?ooool2o`000<Gooooo000Vooooo`03o`000?oooooooooo07Ko
oooo0_l00037ooooo`009_ooool00ol0003oooooooooo`1cooooo`?o0000bOooool002Kooooo0_l0
001booooo`;o0000c?ooool002Kooooo00?o0000ooooooooool0Koooool2o`000<kooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`1]ooooo`;o0000d?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0J_ooool3o`000=;ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Xooooo`;o0000eOooool000?ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Vooooo`;o0000eoooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06Cooooo
0_l0003Iooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo0ol0003Kooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05oooooo0_l0003Nooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`;o0000Doooool2o`000>_ooooo
000Vooooo`03o`000?oooooooooo053ooooo0_l0003]ooooo`009_ooool00ol0003oooooooooo`1>
ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000Vooooo`03
o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool2o`0004Wooooo0_l0003eooooo`009_oo
ool00ol0003oooooooooo`16ooooo`;o0000moooool002Kooooo00?o0000ooooooooool0A?ooool2
o`000?Wooooo000Vooooo`03o`000?oooooooooo04;ooooo0_l0003kooooo`009_ooool2o`00047o
oooo0_l0003mooooo`009_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
??ooool2o`000?oooooo0_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0>_ooool2o`000?oo
oooo1?ooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0>?ooool2o`000?oooooo1_ooool000_ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000fooooo`;o0000ooooool8ooooo`00
2oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`0dooooo`;o0000ooooool:ooooo`002oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`;o0000ooooool<ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo033ooooo0_l0003oooooo`kooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0;_ooool2
o`000?oooooo4?ooool002Kooooo0_l0000]ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`009_ooool00ol0003oooooooooo`0Qooooo`;o0000oooooolMooooo`00
9_ooool00ol0003oooooooooo`0Oooooo`;o0000oooooolOooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`;o0000oooooolQooooo`009_ooool2o`0001cooooo0_l0003oooooob?ooooo000Voooo
o`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo000Vooooo`03o`000?oooooooooo01Oo
oooo0_l0003oooooobOooooo000Vooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo
000Vooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolYooooo`009_ooool2
o`0001?ooooo0_l0003oooooobcooooo000Vooooo`03o`000?oooooooooo013ooooo0_l0003ooooo
obkooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0>ooooo`;o0000ooooool`
ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00cooooo0_l0
003ooooooc;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000;ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`;o0000ooooooleooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01oooool2o`000?oooooo=oooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`;o0000ooooooliooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00003oooo
o`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooocko
oooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006
ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_oo
ool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
oooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0oooo
o`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:
ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9
ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Go
oooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo
00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@4100
1_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Co
oooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`00
0?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<08Gooooo002<ooooo`03o`000?oooooo
oooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<
c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo
00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P25ooooo`00
S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08?ooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko
00001Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo08Cooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?nj^[X0QOooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000=ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool0Q?ooool008Wo
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o000008Gooooo0029oooo
o`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooo
ooooool03?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0QOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41598 m
.11905 .36452 L
.21429 .31551 L
.30952 .26904 L
.40476 .22508 L
.5 .18348 L
.59524 .14401 L
.69048 .10634 L
.78571 .07008 L
.88095 .03479 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0n_ooool3o`0004;ooooo000Vooooo`;o0000n?ooool3o`0004Gooooo000Vooooo`03o`000?oo
oooooooo0?Cooooo0ol00018ooooo`009_ooool00ol0003oooooooooo`3aooooo`?o0000Boooool0
02Kooooo00?o0000ooooooooool0k_ooool3o`0004kooooo000Vooooo`03o`000?oooooooooo0>_o
oooo0ol0001Aooooo`009_ooool2o`000>Wooooo0ol0001Dooooo`009_ooool00ol0003ooooooooo
o`3Uooooo`?o0000Eoooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>?ooooo0_l0001Jooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>3ooooo0ol0001Looooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0gOooool3o`0005oooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000=_ooooo0_l0
001Rooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Hooooo`?o
0000I?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Gooooo0ol0001Woooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0doooool2o`0006[ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000dOooool3o`0006cooooo000Vooooo`03o`000?oooooooooo0<kooooo0_l0001_
ooooo`009_ooool00ol0003oooooooooo`3;ooooo`?o0000LOooool002Kooooo00?o0000oooooooo
ool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Cooooo0ol0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`;o0000O?ooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;co
oooo0ol00020ooooo`009_ooool00ol0003oooooooooo`2jooooo`;o0000Poooool002Kooooo0_l0
002hooooo`?o0000QOooool002Kooooo00?o0000ooooooooool0]Oooool2o`0008Sooooo000Voooo
o`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`009_ooool00ol0003oooooooooo`2`ooooo`;o
0000SOooool002Kooooo0_l0002_ooooo`;o0000Soooool002Kooooo00?o0000ooooooooool0Zooo
ool3o`00097ooooo000Vooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2Vooooo`?o0000U_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Cooooo0_l0002I
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:;ooooo0_l0002Kooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Oooooo`?o0000WOooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0WOooool2
o`000:3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09[ooooo0ol0002Rooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Hooooo`;o0000YOooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002F
ooooo`?o0000Yoooool002Kooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000Vooooo`03
o`000?oooooooooo097ooooo0_l0002/ooooo`009_ooool00ol0003oooooooooo`2>ooooo`?o0000
[_ooool002Kooooo0_l0002=ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0ROooool3
o`000;?ooooo000Vooooo`03o`000?oooooooooo08Oooooo0_l0002fooooo`009_ooool00ol0003o
ooooooooo`25ooooo`;o0000^?ooool002Kooooo00?o0000ooooooooool0P_ooool3o`000;[ooooo
000Vooooo`;o0000POooool2o`000;gooooo000Vooooo`03o`000?oooooooooo07gooooo0ol0002o
ooooo`009_ooool00ol0003oooooooooo`1kooooo`;o0000`_ooool002Kooooo00?o0000oooooooo
ool0N?ooool3o`000<Cooooo000Vooooo`03o`000?oooooooooo07Kooooo0_l00037ooooo`009_oo
ool2o`0007Gooooo0_l00039ooooo`009_ooool00ol0003oooooooooo`1aooooo`?o0000boooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo06oooooo0_l0
003>ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1]ooooo`;o0000d?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0006_ooooo0_l0003Booooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo06Wooooo0_l0003Dooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Ioooool2o`000=Kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool2o`000=Sooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Hoooool2o`000=[ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`00067ooooo
0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o0000goooool002Kooooo00?o0000
ooooooooool0G?ooool2o`000>7ooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l0003Soooo
o`009_ooool00ol0003oooooooooo`1Hooooo`;o0000iOooool002Kooooo0_l0001Gooooo`;o0000
ioooool002Kooooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`03o`000?oooooo
oooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool002Ko
oooo00?o0000ooooooooool0C_ooool2o`000>oooooo000Vooooo`;o0000COooool2o`000?7ooooo
000Vooooo`03o`000?oooooooooo04[ooooo0_l0003cooooo`009_ooool00ol0003oooooooooo`18
ooooo`;o0000mOooool002Kooooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000Vooooo`;o
0000AOooool2o`000?Wooooo000Vooooo`03o`000?oooooooooo04;ooooo0_l0003kooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`10ooooo`;o0000oOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0?_ooool2o`000?oo
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo03cooooo0_l0003oooooo`;ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000>_ooool2o`000?oooooo1?ooool000_ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool0>?ooool2o`000?oooooo1_ooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0dooooo`;o0000ooooool:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03;ooooo0_l0003o
ooooo`cooooo000Vooooo`;o0000<Oooool2o`000?oooooo3_ooool002Kooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000ooooooooool0;?ooool2o`000?oooooo
4_ooool002Kooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool002Kooooo0_l0000Y
ooooo`;o0000oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool002Kooooo00?o0000ooooooooool09Oooool2o`000?oooooo6Oooool002Kooooo
00?o0000ooooooooool08oooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Ooo
ool2o`000?oooooo7Oooool002Kooooo0_l0000Pooooo`;o0000oooooolOooooo`009_ooool00ol0
003oooooooooo`0Mooooo`;o0000oooooolQooooo`009_ooool00ol0003oooooooooo`0Kooooo`;o
0000oooooolSooooo`009_ooool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`009_oo
ool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`009_ooool2o`0001Kooooo0_l0003o
ooooobWooooo000Vooooo`03o`000?oooooooooo01?ooooo0_l0003oooooob_ooooo0003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0000=ooooo`;o0000oooooolaooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00_ooooo0_l0003ooooooc?ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?oooooo<oooool000?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`;o0000oooooolfooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool2o`000?oooooo>?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00005ooooo`;o0000ooooooljoooo
o`009_ooool00ol0003oooooooooo`02ooooo`;o0000oooooollooooo`009_ooool00ol0003ooooo
ooooo`02o`000?oooooo?_ooool002Kooooo0ol0003ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@oooo
o`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o
410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYoooo
o`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_oo
ool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnH
V9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000oooo
ooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Oooooo00?o0000ooooooooool0Q?ooool008cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool5o`0008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`0:ooooo`04odA4A?oM
gMgoooooo`0008Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo
0000Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo
00_ooooo00?oMgMgolc<c?l00000Q_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00oo^
k^koA4A4o`000026ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003_ooool00omgMgOo
0000ooooo`25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42139 m
.11905 .37037 L
.21429 .32155 L
.30952 .27501 L
.40476 .23072 L
.5 .18856 L
.59524 .14833 L
.69048 .10972 L
.78571 .07241 L
.88095 .03598 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0n_ooool3o`0004;ooooo000Vooooo`;o0000nOooool2o`0004Gooooo000Vooooo`03o`000?oo
oooooooo0?Gooooo0ol00017ooooo`009_ooool00ol0003oooooooooo`3booooo`?o0000B_ooool0
02Kooooo00?o0000ooooooooool0l?ooool2o`0004gooooo000Vooooo`03o`000?oooooooooo0>go
oooo0ol0001?ooooo`009_ooool2o`000>cooooo0_l0001Booooo`009_ooool00ol0003ooooooooo
o`3Xooooo`?o0000E?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>Gooooo0ol0001Gooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>?ooooo0_l0001Jooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0h?ooool3o`0005cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000=gooooo0ol0
001Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Kooooo`;o
0000H_ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Sooooo0ol0001Toooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0eOooool3o`0006Oooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000e?ooool2o`0006[ooooo000Vooooo`03o`000?oooooooooo0=3ooooo0ol0001/
ooooo`009_ooool00ol0003oooooooooo`3>ooooo`;o0000Koooool002Kooooo00?o0000oooooooo
ool0boooool3o`00077ooooo000Vooooo`03o`000?oooooooooo0<Sooooo0ol0001dooooo`009_oo
ool2o`000<Oooooo0_l0001gooooo`009_ooool00ol0003oooooooooo`33ooooo`?o0000NOooool0
02Kooooo00?o0000ooooooooool0`Oooool2o`0007cooooo000Vooooo`03o`000?oooooooooo0;oo
oooo0_l0001nooooo`009_ooool00ol0003oooooooooo`2looooo`?o0000P?ooool002Kooooo0_l0
002kooooo`;o0000Poooool002Kooooo00?o0000ooooooooool0]oooool3o`0008Gooooo000Voooo
o`03o`000?oooooooooo0;Gooooo0_l00028ooooo`009_ooool00ol0003oooooooooo`2booooo`?o
0000R_ooool002Kooooo0_l0002aooooo`;o0000SOooool002Kooooo00?o0000ooooooooool0[_oo
ool2o`0008oooooo000Vooooo`03o`000?oooooooooo0:_ooooo0ol0002Aooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2Yooooo`;o0000U?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Kooooo0ol0002F
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:Cooooo0_l0002Iooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Rooooo`;o0000Voooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Woooool3
o`0009gooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09gooooo0_l0002Pooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Jooooo`?o0000X_ooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002I
ooooo`;o0000YOooool002Kooooo00?o0000ooooooooool0UOooool3o`000:Oooooo000Vooooo`03
o`000?oooooooooo09?ooooo0_l0002Zooooo`009_ooool00ol0003oooooooooo`2Aooooo`;o0000
[?ooool002Kooooo0_l0002?ooooo`?o0000[_ooool002Kooooo00?o0000ooooooooool0S?ooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08[ooooo0_l0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`?o0000]Oooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Q?ooool2o`000;[ooooo000Vooooo`03o`000?oooooooooo087ooooo0_l0002l
ooooo`009_ooool00ol0003oooooooooo`1nooooo`?o0000__ooool002Kooooo00?o0000oooooooo
ool0O?ooool2o`000<7ooooo000Vooooo`03o`000?oooooooooo07[ooooo0_l00033ooooo`009_oo
ool2o`0007Wooooo0_l00035ooooo`009_ooool00ol0003oooooooooo`1fooooo`;o0000aoooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo07?ooooo0ol0
0039ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1aooooo`;o0000c?oo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0006oooooo0_l0003>ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo06gooooo0_l0003@ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Joooool2o`000=;ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0JOooool2o`000=Cooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Ioooool2o`000=Kooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0006Kooooo
0_l0003Hooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o0000f_ooool002Kooooo00?o0000
ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Ooooo
o`009_ooool00ol0003oooooooooo`1Looooo`;o0000hOooool002Kooooo0_l0001Kooooo`;o0000
hoooool002Kooooo00?o0000ooooooooool0F?ooool2o`000>Gooooo000Vooooo`03o`000?oooooo
oooo05Kooooo0_l0003Wooooo`009_ooool00ol0003oooooooooo`1Dooooo`;o0000jOooool002Ko
oooo00?o0000ooooooooool0D_ooool2o`000>_ooooo000Vooooo`;o0000DOooool2o`000>gooooo
000Vooooo`03o`000?oooooooooo04kooooo0_l0003_ooooo`009_ooool00ol0003oooooooooo`1<
ooooo`;o0000lOooool002Kooooo00?o0000ooooooooool0B_ooool2o`000??ooooo000Vooooo`;o
0000BOooool2o`000?Gooooo000Vooooo`03o`000?oooooooooo04Kooooo0_l0003gooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`14ooooo`;o0000nOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0@_ooool2o`000?_o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo043ooooo0_l0003mooooo`002oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0003kooooo0_l0003oooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0looooo`;o
0000ooooool2ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo
03Sooooo0_l0003oooooo`Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0=_ooool2o`000?oooooo2?ooool0
02Kooooo0_l0000eooooo`;o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0booooo`;o
0000ooooool<ooooo`009_ooool00ol0003oooooooooo`0`ooooo`;o0000ooooool>ooooo`009_oo
ool00ol0003oooooooooo`0^ooooo`;o0000ooooool@ooooo`009_ooool2o`0002gooooo0_l0003o
oooooa;ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooooaCooooo000Vooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooooaKooooo000Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0oooooolFooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooo
oolIooooo`009_ooool2o`0002Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo000Vooooo`03o`000?oooooooooo01oooooo0_l0003ooooooaoo
oooo000Vooooo`03o`000?oooooooooo01gooooo0_l0003oooooob7ooooo000Vooooo`03o`000?oo
oooooooo01_ooooo0_l0003oooooob?ooooo000Vooooo`;o00006_ooool2o`000?oooooo9Oooool0
02Kooooo00?o0000ooooooooool05oooool2o`000?oooooo9oooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool04oooool2o`000?oooooo:oooool000?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool3o`00017ooooo0_l0003oooooobgooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03ooo
ool2o`000?oooooo;oooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo
0_l0003ooooooc7ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool2o`000?oooooo
<oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0oooooolcooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Wooooo0_l0003oooooocKooooo000Vooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000Vooooo`03o`000?oooooooooo00Cooooo
0_l0003ooooooc[ooooo000Vooooo`03o`000?oooooooooo00;ooooo0_l0003ooooooccooooo000V
ooooo`03o`000?oooooooooo00;o0000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;o
c<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co00001_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0003o
oooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00003o
oooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003o
oooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3o
ooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o0000
ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko0000
1Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`23ooooo`00S?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08;ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko0000
1Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c024ooooo`00ROooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@
413o0000o`000003o`0000gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`26oooo
o`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo
00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooooooo
ool03?ooool00omEEEGoIVIVo`00000=ooooo`Co0000QOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42623 m
.11905 .37561 L
.21429 .32697 L
.30952 .28038 L
.40476 .23581 L
.5 .19316 L
.59524 .15224 L
.69048 .1128 L
.78571 .07453 L
.88095 .03706 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0`ooooo`?o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5_ooool2o`0002Sooooo000Vooooo`03o`00
0?oooooooooo0?oooooo4oooool3o`0002[ooooo000Vooooo`;o0000oooooolAooooo`?o0000;Ooo
ool002Kooooo00?o0000ooooooooool0ooooool>ooooo`;o0000<?ooool002Kooooo00?o0000oooo
ooooool0ooooool;ooooo`?o0000<_ooool002Kooooo00?o0000ooooooooool0ooooool9ooooo`;o
0000=Oooool002Kooooo00?o0000ooooooooool0ooooool6ooooo`?o0000=oooool002Kooooo0_l0
003oooooo`Cooooo0ol0000jooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000m
ooooo`009_ooool00ol0003oooooooooo`3mooooo`?o0000?oooool002Kooooo00?o0000oooooooo
ool0noooool2o`0004;ooooo000Vooooo`;o0000n_ooool2o`0004Cooooo000Vooooo`03o`000?oo
oooooooo0?Kooooo0ol00016ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool0
02Kooooo00?o0000ooooooooool0lOooool3o`0004_ooooo000Vooooo`03o`000?oooooooooo0>oo
oooo0_l0001>ooooo`009_ooool2o`000>gooooo0ol0001@ooooo`009_ooool00ol0003ooooooooo
o`3Zooooo`;o0000Doooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo0>Sooooo0_l0001Eooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0>Gooooo0ol0001Gooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0hoooool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000>3ooooo0ol0
001Looooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3Mooooo`?o
0000Goooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=_ooooo0_l0001Roooo
o`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0f?ooool3o`0006Cooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0006ooooo`;o0000e_ooool3o`0006Oooooo000Vooooo`03o`000?oooooooooo0=?ooooo0_l0001Z
ooooo`009_ooool00ol0003oooooooooo`3@ooooo`?o0000K?ooool002Kooooo00?o0000oooooooo
ool0c_ooool2o`0006oooooo000Vooooo`03o`000?oooooooooo0<_ooooo0ol0001aooooo`009_oo
ool2o`000<Wooooo0ol0001dooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool0
02Kooooo00?o0000ooooooooool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<7o
oooo0_l0001looooo`009_ooool00ol0003oooooooooo`2oooooo`;o0000O_ooool002Kooooo0_l0
002mooooo`?o0000P?ooool002Kooooo00?o0000ooooooooool0^_ooool2o`0008?ooooo000Voooo
o`03o`000?oooooooooo0;Oooooo0ol00025ooooo`009_ooool00ol0003oooooooooo`2eooooo`;o
0000R?ooool002Kooooo0_l0002cooooo`?o0000R_ooool002Kooooo00?o0000ooooooooool0/?oo
ool2o`0008gooooo000Vooooo`03o`000?oooooooooo0:kooooo0_l0002?ooooo`002oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`2[ooooo`?o0000TOooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Wooooo0_l0002D
ooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01Oooool3
o`000:Oooooo0_l0002Fooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2Tooooo`?o0000V?ooool000_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0X_ooool2
o`0009_ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0:3ooooo0_l0002Mooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Nooooo`;o0000Woooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0002L
ooooo`?o0000XOooool002Kooooo00?o0000ooooooooool0VOooool2o`000:Cooooo000Vooooo`03
o`000?oooooooooo09Oooooo0_l0002Vooooo`009_ooool00ol0003oooooooooo`2Eooooo`;o0000
Z?ooool002Kooooo0_l0002Dooooo`;o0000Z_ooool002Kooooo00?o0000ooooooooool0T?ooool3
o`000:cooooo000Vooooo`03o`000?oooooooooo08kooooo0_l0002_ooooo`009_ooool00ol0003o
ooooooooo`2<ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2o`000;?ooooo
000Vooooo`;o0000R?ooool3o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002h
ooooo`009_ooool00ol0003oooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000oooooooo
ool0POooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002nooooo`009_oo
ool2o`0007gooooo0_l00031ooooo`009_ooool00ol0003oooooooooo`1jooooo`;o0000`oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooo
oooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo07Sooooo0_l0
0035ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1fooooo`;o0000aooo
ool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool3o`0007?ooooo0ol00039ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo077ooooo0_l0003<ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
Koooool2o`000<kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0KOooool2o`000=3ooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool3o`000=;ooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`0006Wooooo
0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Vooooo`;o0000eoooool002Kooooo00?o0000
ooooooooool0I?ooool2o`000=Wooooo000Vooooo`03o`000?oooooooooo067ooooo0ol0003Koooo
o`009_ooool00ol0003oooooooooo`1Oooooo`;o0000g_ooool002Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`;o0000Doooool2o`000>_ooooo
000Vooooo`03o`000?oooooooooo053ooooo0_l0003]ooooo`009_ooool00ol0003oooooooooo`1>
ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000Vooooo`;o
0000Boooool2o`000??ooooo000Vooooo`03o`000?oooooooooo04Sooooo0_l0003eooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`16ooooo`;o0000moooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0A?ooool2o`000?Wo
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo04;ooooo0_l0003kooooo`002oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00043ooooo0_l0003mooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0nooooo`;o
0000ooooool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0??ooool2o`000?oooooo0_ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0joooo
o`;o0000ooooool4ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Kooooo000Voooo
o`;o0000=oooool2o`000?oooooo2?ooool002Kooooo00?o0000ooooooooool0=?ooool2o`000?oo
oooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`000?oooooo3?ooool002Kooooo00?o
0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo0_l0000_ooooo`;o0000ooooool@
ooooo`009_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`009_ooool00ol0003oooooooooo`0Qooooo`;o0000oooooolMooooo`00
9_ooool00ol0003oooooooooo`0Oooooo`;o0000oooooolOooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`;o0000oooooolQooooo`009_ooool2o`0001cooooo0_l0003oooooob?ooooo000Voooo
o`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo0003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0
000Dooooo`03o`000?oooooooooo0?oooooo:Oooool000?ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Booooo`;o0000ooooool/ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
4?ooool2o`000?oooooo;_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`;o0000
ooooool`ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool2o`000?oo
oooo<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo0_l0000<ooooo`03o`000?oooooooooo0?oooooo<_ooool002Ko
oooo00?o0000ooooooooool02Oooool2o`000?oooooo=Oooool002Kooooo00?o0000ooooooooool0
1oooool2o`000?oooooo=oooool002Kooooo00?o0000ooooooooool01Oooool2o`000?oooooo>Ooo
ool002Kooooo00?o0000ooooooooool00oooool2o`000?oooooo>oooool002Kooooo0_l00003oooo
o`03o`000?oooooooooo0?oooooo>oooool002Kooooo00?o0000ooooooooool00_l0003oooooocko
oooo000Vooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo
002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo
00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0QOooool008Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool0Qoooool008Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02_ooool00ooMgMgo410@oiRHV027ooooo`00ROooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@4125ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4306 m
.11905 .38033 L
.21429 .33185 L
.30952 .28521 L
.40476 .24039 L
.5 .1973 L
.59524 .15577 L
.69048 .11558 L
.78571 .07645 L
.88095 .03804 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003kooooo`?o0000@_ooool002Kooooo00?o
0000ooooooooool0n?ooool2o`0004Gooooo000Vooooo`03o`000?oooooooooo0?Gooooo0ol00017
ooooo`009_ooool00ol0003oooooooooo`3booooo`?o0000B_ooool002Kooooo00?o0000oooooooo
ool0l?ooool2o`0004gooooo000Vooooo`;o0000k_ooool3o`0004oooooo000Vooooo`03o`000?oo
oooooooo0>_ooooo0_l0001Booooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j?ooool3o`0005Cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0iOooool3o`0005Oooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Sooooo`;o0000F_ooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000h?oo
ool3o`0005cooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0=ko
oooo0_l0001Oooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g?ooool2o`00
067ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Iooooo`?o0000Hoooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Hooooo`;o0000I_ooool002Kooooo00?o0000ooooooooool0e?ooool3
o`0006Sooooo000Vooooo`03o`000?oooooooooo0=;ooooo0_l0001[ooooo`009_ooool00ol0003o
ooooooooo`3?ooooo`?o0000KOooool002Kooooo00?o0000ooooooooool0cOooool2o`00073ooooo
000Vooooo`;o0000c?ooool2o`0007;ooooo000Vooooo`03o`000?oooooooooo0<Sooooo0ol0001d
ooooo`009_ooool00ol0003oooooooooo`36ooooo`;o0000Moooool002Kooooo00?o0000oooooooo
ool0`oooool3o`0007Wooooo000Vooooo`03o`000?oooooooooo0<7ooooo0_l0001looooo`009_oo
ool2o`000<3ooooo0_l0001nooooo`009_ooool00ol0003oooooooooo`2looooo`?o0000P?ooool0
02Kooooo00?o0000ooooooooool0^_ooool2o`0008?ooooo000Vooooo`03o`000?oooooooooo0;Oo
oooo0ol00025ooooo`009_ooool2o`000;Kooooo0_l00028ooooo`009_ooool00ol0003ooooooooo
o`2booooo`?o0000R_ooool002Kooooo00?o0000ooooooooool0/?ooool2o`0008gooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0:kooooo0_l0002?ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Zoooool3
o`00097ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000ZOooool2o`0009Cooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Oooooo0_l0002Fooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2T
ooooo`?o0000V?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0X_ooool2o`0009_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:3ooooo0_l0002M
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`0009oooooo0_l0002Oooooo`009_ooool00ol0003oooooooooo`2Kooooo`?o0000XOooool002Ko
oooo00?o0000ooooooooool0VOooool2o`000:Cooooo000Vooooo`03o`000?oooooooooo09Oooooo
0_l0002Vooooo`009_ooool2o`0009Kooooo0_l0002Xooooo`009_ooool00ol0003oooooooooo`2C
ooooo`;o0000Z_ooool002Kooooo00?o0000ooooooooool0T?ooool3o`000:cooooo000Vooooo`03
o`000?oooooooooo08kooooo0_l0002_ooooo`009_ooool00ol0003oooooooooo`2<ooooo`;o0000
/Oooool002Kooooo0_l0002;ooooo`;o0000/oooool002Kooooo00?o0000ooooooooool0Qoooool3
o`000;Gooooo000Vooooo`03o`000?oooooooooo08Gooooo0_l0002hooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000^_ooool002Kooooo00?o0000ooooooooool0POooool2o`000;cooooo
000Vooooo`;o0000Ooooool3o`000;kooooo000Vooooo`03o`000?oooooooooo07cooooo0_l00031
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0N_oo
ool2o`000<?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Sooooo0_l0
0035ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000M_ooool2o`000<Oooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Loooool3o`000<Wooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1aooooo`;o0000c?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1_ooooo`;o0000
c_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1]ooooo`;o0000d?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
K?ooool2o`000=;ooooo000Vooooo`03o`000?oooooooooo06Wooooo0_l0003Dooooo`009_ooool0
0ol0003oooooooooo`1Wooooo`;o0000e_ooool002Kooooo00?o0000ooooooooool0IOooool2o`00
0=Sooooo000Vooooo`03o`000?oooooooooo06?ooooo0_l0003Jooooo`009_ooool2o`00067ooooo
0ol0003Looooo`009_ooool00ol0003oooooooooo`1Nooooo`;o0000goooool002Kooooo00?o0000
ooooooooool0G?ooool2o`000>7ooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l0003Soooo
o`009_ooool00ol0003oooooooooo`1Hooooo`;o0000iOooool002Kooooo0_l0001Gooooo`;o0000
ioooool002Kooooo00?o0000ooooooooool0E?ooool2o`000>Wooooo000Vooooo`03o`000?oooooo
oooo05;ooooo0_l0003[ooooo`009_ooool00ol0003oooooooooo`1@ooooo`;o0000kOooool002Ko
oooo0_l0001?ooooo`;o0000koooool002Kooooo00?o0000ooooooooool0C?ooool2o`000?7ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04[ooooo0_l0003cooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`18ooooo`;o
0000mOooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0A_ooool2o`000?Oooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000A?ooool2o`000?Wooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04;o
oooo0_l0003kooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`10ooooo`;o0000oOooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0noooo
o`;o0000ooooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0looooo`;o0000ooooool2ooooo`009_ooool2o`00
03_ooooo0_l0003oooooo`Cooooo000Vooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`Ko
oooo000Vooooo`03o`000?oooooooooo03Kooooo0_l0003oooooo`Sooooo000Vooooo`03o`000?oo
oooooooo03Cooooo0_l0003oooooo`[ooooo000Vooooo`;o0000<oooool2o`000?oooooo3?ooool0
02Kooooo00?o0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo00?o0000oooooooo
ool0;_ooool2o`000?oooooo4?ooool002Kooooo00?o0000ooooooooool0;?ooool2o`000?oooooo
4_ooool002Kooooo00?o0000ooooooooool0:_ooool2o`000?oooooo5?ooool002Kooooo0_l0000Y
ooooo`;o0000oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
0?oooooo5_ooool002Kooooo00?o0000ooooooooool09Oooool2o`000?oooooo6Oooool002Kooooo
00?o0000ooooooooool08oooool2o`000?oooooo6oooool002Kooooo00?o0000ooooooooool08Ooo
ool2o`000?oooooo7Oooool002Kooooo0_l0000Pooooo`;o0000oooooolOooooo`009_ooool00ol0
003oooooooooo`0Mooooo`;o0000oooooolQooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool06oooool2o`000?oooooo8oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Iooooo`;o0000oooooolUooooo`000oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00005ooo
ool2o`000?oooooo9oooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Eooooo`;o0000oooo
oolYooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool2o`000?oooooo
:oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool2o`000?oooooo;oooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo0_l0000>ooooo`;o0000oooooolaooooo`009_ooool00ol0003oooooooooo`0;ooooo`;o
0000oooooolcooooo`009_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo
<oooool002Kooooo00?o0000ooooooooool02?ooool2o`000?oooooo=_ooool002Kooooo00?o0000
ooooooooool01_ooool2o`000?oooooo>?ooool002Kooooo0_l00005ooooo`;o0000ooooooljoooo
o`009_ooool00ol0003oooooooooo`02ooooo`;o0000oooooollooooo`009_ooool00ol0003ooooo
ooooo`02o`000?oooooo?_ooool002Kooooo0ol0003ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo
000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`25ooooo`00S?ooool00ol0
003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
0005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo08Gooooo002<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00cooooo00?oZJVYoeEEEOooool0QOooool008cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l0
0005ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool0Q?ooool008cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03Oooool00omEEEGoc<c<ooooo`24ooooo`00ROooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000
o`000003o`0000gooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`24ooooo`00ROoo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S80QOooool008Wooooo
1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo1Ol00025ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43456 m
.11905 .38459 L
.21429 .33625 L
.30952 .28956 L
.40476 .24452 L
.5 .20103 L
.59524 .15896 L
.69048 .1181 L
.78571 .07818 L
.88095 .03892 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003looooo`;o0000@_ooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016
ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool002Kooooo00?o0000oooooooo
ool0lOooool3o`0004_ooooo000Vooooo`;o0000l?ooool2o`0004kooooo000Vooooo`03o`000?oo
oooooooo0>cooooo0ol0001@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j?ooool2o`0005Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000hooo
ool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>3o
oooo0ol0001Looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g_ooool2o`00
05oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Looooo`;o0000HOooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Jooooo`?o0000Hoooool002Kooooo00?o0000ooooooooool0eoooool2
o`0006Kooooo000Vooooo`03o`000?oooooooooo0=Cooooo0ol0001Xooooo`009_ooool00ol0003o
ooooooooo`3Booooo`;o0000Joooool002Kooooo00?o0000ooooooooool0coooool3o`0006gooooo
000Vooooo`;o0000c_ooool2o`00073ooooo000Vooooo`03o`000?oooooooooo0<_ooooo0_l0001b
ooooo`009_ooool00ol0003oooooooooo`38ooooo`?o0000M?ooool002Kooooo00?o0000oooooooo
ool0a_ooool2o`0007Oooooo000Vooooo`03o`000?oooooooooo0<?ooooo0ol0001iooooo`009_oo
ool2o`000<;ooooo0_l0001looooo`009_ooool00ol0003oooooooooo`2oooooo`;o0000O_ooool0
02Kooooo00?o0000ooooooooool0_?ooool3o`00083ooooo000Vooooo`03o`000?oooooooooo0;[o
oooo0_l00023ooooo`009_ooool2o`000;Sooooo0ol00025ooooo`009_ooool00ol0003ooooooooo
o`2eooooo`;o0000R?ooool002Kooooo00?o0000ooooooooool0/_ooool3o`0008[ooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;3ooooo0_l0002=ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0[_ooool2
o`0008oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000Zoooool3o`00097ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Wooooo0_l0002Dooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2W
ooooo`;o0000U_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Y?ooool3o`0009Sooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0_l0002K
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:7ooooo0_l0002Mooooo`009_ooool00ol0003oooooooooo`2Nooooo`;o0000Woooool002Ko
oooo00?o0000ooooooooool0Voooool3o`000:7ooooo000Vooooo`03o`000?oooooooooo09Wooooo
0_l0002Tooooo`009_ooool2o`0009Sooooo0_l0002Vooooo`009_ooool00ol0003oooooooooo`2E
ooooo`;o0000Z?ooool002Kooooo00?o0000ooooooooool0Toooool2o`000:[ooooo000Vooooo`03
o`000?oooooooooo093ooooo0ol0002/ooooo`009_ooool00ol0003oooooooooo`2>ooooo`;o0000
[oooool002Kooooo0_l0002=ooooo`;o0000/Oooool002Kooooo00?o0000ooooooooool0R_ooool2
o`000;?ooooo000Vooooo`03o`000?oooooooooo08Oooooo0ol0002eooooo`009_ooool00ol0003o
ooooooooo`25ooooo`;o0000^?ooool002Kooooo00?o0000ooooooooool0Poooool2o`000;[ooooo
000Vooooo`;o0000P_ooool2o`000;cooooo000Vooooo`03o`000?oooooooooo07kooooo0ol0002n
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0O?oo
ool2o`000<7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07[ooooo0_l0
0033ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000N?ooool2o`000<Gooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0M_ooool2o`000<Oooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1cooooo`?o0000bOooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`;o0000
c?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1_ooooo`;o0000c_ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
K_ooool2o`000=3ooooo000Vooooo`03o`000?oooooooooo06_ooooo0_l0003Booooo`009_ooool0
0ol0003oooooooooo`1Yooooo`;o0000e?ooool002Kooooo00?o0000ooooooooool0Ioooool2o`00
0=Kooooo000Vooooo`03o`000?oooooooooo06Gooooo0_l0003Hooooo`009_ooool2o`0006Cooooo
0_l0003Jooooo`009_ooool00ol0003oooooooooo`1Pooooo`?o0000g?ooool002Kooooo00?o0000
ooooooooool0G_ooool2o`000=oooooo000Vooooo`03o`000?oooooooooo05cooooo0_l0003Qoooo
o`009_ooool00ol0003oooooooooo`1Jooooo`;o0000hoooool002Kooooo0_l0001Iooooo`;o0000
iOooool002Kooooo00?o0000ooooooooool0E_ooool2o`000>Oooooo000Vooooo`03o`000?oooooo
oooo05Cooooo0_l0003Yooooo`009_ooool00ol0003oooooooooo`1Booooo`;o0000joooool002Ko
oooo0_l0001Aooooo`;o0000kOooool002Kooooo00?o0000ooooooooool0C_ooool2o`000>oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04cooooo0_l0003aooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1:ooooo`;o
0000loooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0B?ooool2o`000?Gooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000A_ooool2o`000?Oooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Co
oooo0_l0003iooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`12ooooo`;o0000noooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`10oooo
o`;o0000oOooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0nooooo`;o0000ooooool002Kooooo0_l0000moooo
o`;o0000ooooool2ooooo`009_ooool00ol0003oooooooooo`0jooooo`;o0000ooooool4ooooo`00
9_ooool00ol0003oooooooooo`0hooooo`;o0000ooooool6ooooo`009_ooool00ol0003ooooooooo
o`0fooooo`;o0000ooooool8ooooo`009_ooool2o`0003Gooooo0_l0003oooooo`[ooooo000Voooo
o`03o`000?oooooooooo03;ooooo0_l0003oooooo`cooooo000Vooooo`03o`000?oooooooooo033o
oooo0_l0003oooooo`kooooo000Vooooo`03o`000?oooooooooo02kooooo0_l0003ooooooa3ooooo
000Vooooo`03o`000?oooooooooo02cooooo0_l0003ooooooa;ooooo000Vooooo`;o0000:oooool2
o`000?oooooo5?ooool002Kooooo00?o0000ooooooooool0:?ooool2o`000?oooooo5_ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3ooooooaKooooo000Vooooo`03o`00
0?oooooooooo02Gooooo0_l0003ooooooaWooooo000Vooooo`03o`000?oooooooooo02?ooooo0_l0
003ooooooa_ooooo000Vooooo`;o00008_ooool2o`000?oooooo7Oooool002Kooooo00?o0000oooo
ooooool07oooool2o`000?oooooo7oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01gooooo0_l0003oooooob7ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool06oooool2o`000?oooooo8oooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0001Wooooo0_l0
003oooooobGooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05oooool2o`000?oooooo9ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo
0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04oooool2o`000?oooooo:oooool000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo0_l0003oooooobgooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006oooo
o`;o00004?ooool2o`000?oooooo;oooool002Kooooo00?o0000ooooooooool03Oooool2o`000?oo
oooo<Oooool002Kooooo00?o0000ooooooooool02oooool2o`000?oooooo<oooool002Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooc?ooooo000Vooooo`03o`000?oooooo
oooo00Sooooo0_l0003oooooocKooooo000Vooooo`;o00001oooool2o`000?oooooo>?ooool002Ko
oooo00?o0000ooooooooool01?ooool2o`000?oooooo>_ooool002Kooooo00?o0000ooooooooool0
0_ooool2o`000?oooooo??ooool002Kooooo00?o0000ooooooooool00_l0003oooooockooooo000V
ooooo`?o0000oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo
002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@25ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool00000QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo
00[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P25ooooo`00S?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`05olc<c?l0003o0000o`000?o<c<`0QOooool008Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@4025ooooo`00
ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooookZj^_l00000QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@25oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43816 m
.11905 .38846 L
.21429 .34022 L
.30952 .29349 L
.40476 .24824 L
.5 .20441 L
.59524 .16184 L
.69048 .12037 L
.78571 .07975 L
.88095 .03972 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3mooooo`?o0000?oooool002Kooooo0_l0003looooo`;o0000@_ooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Kooooo0ol00016
ooooo`009_ooool00ol0003oooooooooo`3dooooo`;o0000BOooool002Kooooo00?o0000oooooooo
ool0lOooool3o`0004_ooooo000Vooooo`;o0000l?ooool2o`0004kooooo000Vooooo`03o`000?oo
oooooooo0>cooooo0ol0001@ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j?ooool2o`0005Gooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Uooooo`?o0000Eoooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000hooo
ool2o`0005[ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>7o
oooo0_l0001Looooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g_ooool3o`00
05kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Looooo`;o0000HOooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Kooooo`;o0000Hoooool002Kooooo00?o0000ooooooooool0f?ooool2
o`0006Gooooo000Vooooo`03o`000?oooooooooo0=Gooooo0ol0001Wooooo`009_ooool00ol0003o
ooooooooo`3Cooooo`;o0000J_ooool002Kooooo00?o0000ooooooooool0dOooool2o`0006cooooo
000Vooooo`;o0000d?ooool2o`0006kooooo000Vooooo`03o`000?oooooooooo0<gooooo0_l0001`
ooooo`009_ooool00ol0003oooooooooo`3:ooooo`?o0000L_ooool002Kooooo00?o0000oooooooo
ool0b?ooool2o`0007Gooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Cooooo0ol0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`;o0000O?ooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;co
oooo0ol00020ooooo`009_ooool2o`000;_ooooo0_l00023ooooo`009_ooool00ol0003ooooooooo
o`2gooooo`?o0000QOooool002Kooooo00?o0000ooooooooool0]Oooool2o`0008Sooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;;ooooo0ol0002:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/?ooool2
o`0008gooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000[_ooool2o`0008oooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:_ooooo0ol0002Aooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Y
ooooo`;o0000U?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Yoooool2o`0009Kooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Cooooo0ol0002H
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:?ooooo0_l0002Kooooo`009_ooool00ol0003oooooooooo`2Pooooo`;o0000WOooool002Ko
oooo00?o0000ooooooooool0W_ooool2o`0009oooooo000Vooooo`03o`000?oooooooooo09_ooooo
0ol0002Qooooo`009_ooool2o`0009[ooooo0_l0002Tooooo`009_ooool00ol0003oooooooooo`2G
ooooo`;o0000Y_ooool002Kooooo00?o0000ooooooooool0UOooool2o`000:Sooooo000Vooooo`03
o`000?oooooooooo09?ooooo0_l0002Zooooo`009_ooool00ol0003oooooooooo`2@ooooo`?o0000
[?ooool002Kooooo0_l0002?ooooo`;o0000[oooool002Kooooo00?o0000ooooooooool0S?ooool2
o`000;7ooooo000Vooooo`03o`000?oooooooooo08[ooooo0_l0002cooooo`009_ooool00ol0003o
ooooooooo`27ooooo`?o0000]Oooool002Kooooo00?o0000ooooooooool0QOooool2o`000;Sooooo
000Vooooo`;o0000Q?ooool2o`000;[ooooo000Vooooo`03o`000?oooooooooo087ooooo0_l0002l
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0O_oo
ool3o`000;kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07cooooo0_l0
0031ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000N_ooool2o`000<?ooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0N?ooool2o`000<Gooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1fooooo`;o0000aoooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1cooooo`?o0000
bOooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1aooooo`;o0000c?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
L?ooool2o`000<kooooo000Vooooo`03o`000?oooooooooo06gooooo0_l0003@ooooo`009_ooool0
0ol0003oooooooooo`1[ooooo`;o0000d_ooool002Kooooo00?o0000ooooooooool0JOooool2o`00
0=Cooooo000Vooooo`03o`000?oooooooooo06Oooooo0_l0003Fooooo`009_ooool2o`0006Kooooo
0_l0003Hooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o0000f_ooool002Kooooo00?o0000
ooooooooool0H?ooool3o`000=cooooo000Vooooo`03o`000?oooooooooo05kooooo0_l0003Ooooo
o`009_ooool00ol0003oooooooooo`1Looooo`;o0000hOooool002Kooooo0_l0001Kooooo`;o0000
hoooool002Kooooo00?o0000ooooooooool0F?ooool2o`000>Gooooo000Vooooo`03o`000?oooooo
oooo05Kooooo0_l0003Wooooo`009_ooool00ol0003oooooooooo`1Dooooo`;o0000jOooool002Ko
oooo0_l0001Cooooo`;o0000joooool002Kooooo00?o0000ooooooooool0D?ooool2o`000>gooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo04kooooo0_l0003_ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1<ooooo`;o
0000lOooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0B_ooool2o`000??ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000B?ooool2o`000?Gooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04Ko
oooo0_l0003gooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`14ooooo`;o0000nOooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`12oooo
o`;o0000noooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`10ooooo`;o0000oOooool002Kooooo0_l0000ooooo
o`;o0000ooooool002Kooooo00?o0000ooooooooool0??ooool2o`000?oooooo0_ooool002Kooooo
00?o0000ooooooooool0>_ooool2o`000?oooooo1?ooool002Kooooo00?o0000ooooooooool0>?oo
ool2o`000?oooooo1_ooool002Kooooo0_l0000gooooo`;o0000ooooool8ooooo`009_ooool00ol0
003oooooooooo`0dooooo`;o0000ooooool:ooooo`009_ooool00ol0003oooooooooo`0booooo`;o
0000ooooool<ooooo`009_ooool00ol0003oooooooooo`0`ooooo`;o0000ooooool>ooooo`009_oo
ool00ol0003oooooooooo`0^ooooo`;o0000ooooool@ooooo`009_ooool2o`0002gooooo0_l0003o
oooooa;ooooo000Vooooo`03o`000?oooooooooo02[ooooo0_l0003ooooooaCooooo000Vooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooooaKooooo000Vooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0oooooolFooooo`009_ooool00ol0003oooooooooo`0Uooooo`;o0000oooo
oolIooooo`009_ooool2o`0002Cooooo0_l0003ooooooa_ooooo000Vooooo`03o`000?oooooooooo
027ooooo0_l0003ooooooagooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0O
ooooo`;o0000oooooolOooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01gooooo0_l0003oooooob7ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Kooooo`;o0000oooo
oolSooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo0_l0003oooooobGooooo0003
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Gooooo0_l0003oooooobWooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Cooooo`;o0000ooooool[ooooo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
01;ooooo0_l0003oooooobgooooo000Vooooo`03o`000?oooooooooo00oooooo0_l0003ooooooboo
oooo000Vooooo`03o`000?oooooooooo00gooooo0_l0003ooooooc7ooooo000Vooooo`03o`000?oo
oooooooo00_ooooo0_l0003ooooooc?ooooo000Vooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0oooooolcooooo`009_ooool2o`0000Wooooo0_l0003oooooocKooooo000Vooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooocSooooo000Vooooo`03o`000?oooooooooo00Cooooo
0_l0003ooooooc[ooooo000Vooooo`03o`000?oooooooooo00;ooooo0_l0003ooooooccooooo000V
ooooo`;o000000?oooooo`000?l00000oooooolnooooo`009_ooool3o`000?oooooo@?ooool002Ko
oooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0
003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj
^P06ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000
oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3
o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413o
oooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooo
od7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o
00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00
UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b
[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`04oa0@4?l0003o
A4A4olc<c8Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo
00?oV9RHoa0@4?oMgMd0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00on7QhOoEEEE
ooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool02_ooool01Oo<c<co8B4Q
o`000?mEEEGo000008Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go8B4QohN7Qooo
ooooV9RHo`000025ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000008Gooooo0029ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@25ooooo`00ROooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000003?ooool01Oo<c<co410@o`000?lb<S;ok^k^08Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .44145 m
.11905 .39197 L
.21429 .34382 L
.30952 .29704 L
.40476 .25161 L
.5 .20745 L
.59524 .16444 L
.69048 .12242 L
.78571 .08116 L
.88095 .04045 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->-20,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`000003ooooool0003ooooo
017ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool002Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0aooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool2o`0002Oooooo000Vooooo`03o`00
0?oooooooooo0?oooooo5?ooool3o`0002Wooooo000Vooooo`;o0000oooooolCooooo`;o0000;?oo
ool002Kooooo00?o0000ooooooooool0ooooool?ooooo`?o0000;_ooool002Kooooo00?o0000oooo
ooooool0ooooool=ooooo`;o0000<Oooool002Kooooo00?o0000ooooooooool0ooooool:ooooo`?o
0000<oooool002Kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000=_ooool002Kooooo0_l0
003oooooo`Oooooo0_l0000hooooo`009_ooool00ol0003oooooooooo`3oooooo`?ooooo0ol0000j
ooooo`009_ooool00ol0003oooooooooo`3oooooo`7ooooo0_l0000mooooo`009_ooool00ol0003o
ooooooooo`3nooooo`;o0000?oooool002Kooooo0_l0003looooo`?o0000@Oooool002Kooooo00?o
0000ooooooooool0nOooool2o`0004Cooooo000Vooooo`03o`000?oooooooooo0?Oooooo0_l00016
ooooo`009_ooool00ol0003oooooooooo`3eooooo`;o0000B?ooool002Kooooo00?o0000oooooooo
ool0l_ooool3o`0004[ooooo000Vooooo`;o0000lOooool2o`0004gooooo000Vooooo`03o`000?oo
oooooooo0>kooooo0_l0001?ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0k?ooool2o`00057ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0j_ooool2o`0005?ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Wooooo`?o0000EOooool000?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04ooooo`?o0000iOoo
ool2o`0005Sooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0>?o
oooo0_l0001Jooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0h?ooool3o`00
05cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Nooooo`;o0000Goooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool4o`0000Kooooo0_l0003Mooooo`;o0000HOooool002Kooooo00?o0000ooooooooool0fOooool3
o`0006?ooooo000Vooooo`03o`000?oooooooooo0=Oooooo0_l0001Vooooo`009_ooool00ol0003o
ooooooooo`3Dooooo`?o0000J?ooool002Kooooo00?o0000ooooooooool0d_ooool2o`0006_ooooo
000Vooooo`;o0000d?ooool3o`0006gooooo000Vooooo`03o`000?oooooooooo0<gooooo0_l0001`
ooooo`009_ooool00ol0003oooooooooo`3;ooooo`;o0000L_ooool002Kooooo00?o0000oooooooo
ool0b?ooool3o`0007Cooooo000Vooooo`03o`000?oooooooooo0<Kooooo0_l0001gooooo`009_oo
ool2o`000<Gooooo0_l0001iooooo`009_ooool00ol0003oooooooooo`31ooooo`?o0000Noooool0
02Kooooo00?o0000ooooooooool0_oooool2o`0007kooooo000Vooooo`03o`000?oooooooooo0;go
oooo0_l00020ooooo`009_ooool2o`000;cooooo0_l00022ooooo`009_ooool00ol0003ooooooooo
o`2hooooo`?o0000Q?ooool002Kooooo00?o0000ooooooooool0]_ooool2o`0008Oooooo000;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0;Cooooo0_l00029ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool2
o`0008_ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05
ooooo`?o0000/?ooool2o`0008gooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:gooooo0ol0002?ooooo`002oooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2[
ooooo`;o0000T_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0ZOooool2o`0009Cooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Oooooo0_l0002F
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool2
o`000:Gooooo0ol0002Hooooo`009_ooool00ol0003oooooooooo`2Rooooo`;o0000Voooool002Ko
oooo00?o0000ooooooooool0X?ooool2o`0009gooooo000Vooooo`03o`000?oooooooooo09kooooo
0_l0002Oooooo`009_ooool2o`0009cooooo0ol0002Qooooo`009_ooool00ol0003oooooooooo`2I
ooooo`;o0000Y?ooool002Kooooo00?o0000ooooooooool0Uoooool2o`000:Kooooo000Vooooo`03
o`000?oooooooooo09Gooooo0_l0002Xooooo`009_ooool00ol0003oooooooooo`2Cooooo`;o0000
Z_ooool002Kooooo0_l0002Aooooo`?o0000[?ooool002Kooooo00?o0000ooooooooool0S_ooool2
o`000:oooooo000Vooooo`03o`000?oooooooooo08cooooo0_l0002aooooo`009_ooool00ol0003o
ooooooooo`2:ooooo`;o0000/oooool002Kooooo00?o0000ooooooooool0R?ooool2o`000;Gooooo
000Vooooo`;o0000Qoooool2o`000;Oooooo000Vooooo`03o`000?oooooooooo08Cooooo0_l0002i
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool0P_oo
ool2o`000;_ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo083ooooo0_l0
002mooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000OOooool3o`000;oooooo0003ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0Noooool2o`000<;ooooo0003ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`1iooooo`;o0000a?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`;o0000
a_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1eooooo`;o0000b?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o0000
M?ooool2o`000<[ooooo000Vooooo`03o`000?oooooooooo077ooooo0_l0003<ooooo`009_ooool0
0ol0003oooooooooo`1_ooooo`;o0000c_ooool002Kooooo00?o0000ooooooooool0KOooool2o`00
0=3ooooo000Vooooo`03o`000?oooooooooo06[ooooo0ol0003Booooo`009_ooool2o`0006Wooooo
0_l0003Eooooo`009_ooool00ol0003oooooooooo`1Vooooo`;o0000eoooool002Kooooo00?o0000
ooooooooool0I?ooool2o`000=Wooooo000Vooooo`03o`000?oooooooooo067ooooo0ol0003Koooo
o`009_ooool00ol0003oooooooooo`1Oooooo`;o0000g_ooool002Kooooo0_l0001Nooooo`;o0000
h?ooool002Kooooo00?o0000ooooooooool0Foooool2o`000>;ooooo000Vooooo`03o`000?oooooo
oooo05Wooooo0_l0003Tooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o0000i_ooool002Ko
oooo0_l0001Eooooo`;o0000jOooool002Kooooo00?o0000ooooooooool0D_ooool2o`000>_ooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`00
0?oooooooooo053ooooo0_l0003]ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`1>ooooo`;o
0000koooool000_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool0C?ooool2o`000?7ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000B_ooool2o`000??ooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo04So
oooo0_l0003eooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`16ooooo`;o0000moooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`14oooo
o`;o0000nOooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`12ooooo`;o0000noooool002Kooooo0_l00011oooo
o`;o0000oOooool002Kooooo00?o0000ooooooooool0?_ooool2o`000?oooooo000Vooooo`03o`00
0?oooooooooo03cooooo0_l0003oooooo`;ooooo000Vooooo`03o`000?oooooooooo03[ooooo0_l0
003oooooo`Cooooo000Vooooo`;o0000>Oooool2o`000?oooooo1_ooool002Kooooo00?o0000oooo
ooooool0=_ooool2o`000?oooooo2?ooool002Kooooo00?o0000ooooooooool0=?ooool2o`000?oo
oooo2_ooool002Kooooo00?o0000ooooooooool0<_ooool2o`000?oooooo3?ooool002Kooooo00?o
0000ooooooooool0<?ooool2o`000?oooooo3_ooool002Kooooo0_l0000_ooooo`;o0000ooooool@
ooooo`009_ooool00ol0003oooooooooo`0/ooooo`;o0000oooooolBooooo`009_ooool00ol0003o
ooooooooo`0Zooooo`;o0000oooooolDooooo`009_ooool00ol0003oooooooooo`0Xooooo`;o0000
oooooolFooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo5_oo
ool002Kooooo0_l0000Vooooo`;o0000oooooolIooooo`009_ooool00ol0003oooooooooo`0Soooo
o`;o0000oooooolKooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool08Oooool2
o`000?oooooo7Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`0Oooooo`;o0000oooooolOooooo`000oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00007Oooool2o`000?oooooo8Ooo
ool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Kooooo`;o0000oooooolSooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool2o`000?oooooo9Oooool000?ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolWooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05Oooool2o`000?oooooo:Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Doooo
o`;o0000ooooool[ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o0000ooooool]ooooo`00
9_ooool00ol0003oooooooooo`0?ooooo`;o0000ooooool_ooooo`009_ooool00ol0003ooooooooo
o`0=ooooo`;o0000oooooolaooooo`009_ooool00ol0003oooooooooo`0;ooooo`;o0000oooooolc
ooooo`009_ooool2o`0000_ooooo00?o0000ooooooooool0oooooolcooooo`009_ooool00ol0003o
ooooooooo`08ooooo`;o0000oooooolfooooo`009_ooool00ol0003oooooooooo`06ooooo`;o0000
oooooolhooooo`009_ooool00ol0003oooooooooo`04ooooo`;o0000ooooooljooooo`009_ooool2
o`0000?ooooo0_l0003ooooooccooooo000Vooooo`03o`000?oooooooooo00;o0000oooooolnoooo
o`009_ooool3o`000?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00V?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo
002>ooooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool5o`0000Gooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o
410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o
c<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B6;ooooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP2Coooo
o`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0T_ooool0093ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?oMgMgofIV
I_ooool0TOooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`00
00Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000kooooo00?o0000oooo
ooooool0T?ooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000okZj^_ooooooV9RHoa0@402Booooo`00SOooool7o`00
00Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Booooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Note, however, the rather small time step size that we took, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ". In part, this is because the forward-difference method used for the time \
derivative is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so small steps are required to achieve reasonable accuracy. But there is \
also another reason. If we attempt to run the code with a larger time step \
size, we run into an immediate problem: ",
  StyleBox["numerical instability",
    FontSlant->"Italic"],
  ". This is shown in Cell ",
  ButtonBox["6.57",
    ButtonData:>"Cell 6.57",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.05"}], TraditionalForm]]],
  ".  So that we need not reevaluate previous cells defining ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", we use an ",
  StyleBox["Unset ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "command to clear only specific values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["T",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:70"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(Do[Unset[T[j, n]], {j, 1, M - 1}, {n, 1, 200}];\), 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox[\(\[CapitalDelta]t\  = \ 0.05\),
          FontColor->RGBColor[0, 0, 1]], ";"}], 
      "\n"}], "\[IndentingNewLine]", \(Table[
        ListPlot[Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}], 
          PlotJoined \[Rule] True, PlotRange \[Rule] {0,  .4}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
              ToString[\[CapitalDelta]t\ n]], {n, 0, 10, 2}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.57"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.11905 .01391 L
.21429 .04944 L
.30952 .09734 L
.40476 .14833 L
.5 .19314 L
.59524 .22249 L
.69048 .22713 L
.78571 .19777 L
.88095 .12515 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00;ooooo1ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`09oooo
o`Oo00009oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0fooooo`;o00004Oooool2o`0000;ooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`0@ooooo`Oo0000ooooool6ooooo`03o`000?oooooooooo023o
oooo000Vooooo`03o`000?oooooooooo01Oooooo1Ol0003oooooo`03o`000?oooooooooo027ooooo
000Vooooo`;o00007Oooool3o`000?cooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000
ooooooooool07oooool3o`000?Sooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000oooo
ooooool08_ooool2o`000?Gooooo00?o0000ooooooooool08oooool002Kooooo00?o0000oooooooo
ool09?ooool3o`000?7ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
9oooool3o`000>kooooo00?o0000ooooooooool09?ooool002Kooooo0_l0000[ooooo`;o0000jooo
ool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`0/ooooo`?o0000ioooool0
0ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`0_ooooo`;o0000i?ooool00ol0
003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`0aooooo`?o0000h?ooool00ol0003o
ooooooooo`0Xooooo`009_ooool2o`0003Gooooo0ol0003Mooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo03Oooooo0_l0003Jooooo`03o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo03Wooooo0_l0003Gooooo`03o`000?oooooooooo02[ooooo000Voooo
o`03o`000?oooooooooo03_ooooo0_l0003Dooooo`03o`000?oooooooooo02_ooooo000Vooooo`03
o`000?oooooooooo03gooooo0_l0003Booooo`03o`000?oooooooooo02_ooooo000Vooooo`;o0000
@?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`000?oo
oooooooo043ooooo0_l0003=ooooo`03o`000?oooooooooo02gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`12ooooo`;o0000b_ooool00ol0003o
ooooooooo`0^ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
04Cooooo0_l00038ooooo`03o`000?oooooooooo02kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`16ooooo`;o0000aOooool00ol0003oooooooooo`0_ooooo`000oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol00018ooooo`;o0000`_ooool00ol0003oooooooooo`0`ooooo`000oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1:ooooo`;o0000_oooool00ol0003o
ooooooooo`0aooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`2looooo`03o`000?oooooooooo037ooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1=ooooo`;o0000^oooool00ol0003oooooooooo`0booooo`000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_oo
ool2o`00053ooooo0_l0002hooooo`03o`000?oooooooooo03?ooooo000Vooooo`03o`000?oooooo
oooo057ooooo0_l0002eooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo
05?ooooo0_l0002booooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Go
oooo0_l0002`ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03o`000?oooooooooo05Oooooo
0_l0002]ooooo`03o`000?oooooooooo03Kooooo000Vooooo`;o0000F_ooool2o`000:[ooooo00?o
0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool0Foooool2o`000:Oooooo00?o0000
ooooooooool0>?ooool002Kooooo00?o0000ooooooooool0GOooool2o`000:Gooooo00?o0000oooo
ooooool0>?ooool002Kooooo00?o0000ooooooooool0Goooool2o`000:;ooooo00?o0000oooooooo
ool0>Oooool002Kooooo00?o0000ooooooooool0HOooool2o`0009oooooo00?o0000ooooooooool0
>_ooool002Kooooo0_l0001Tooooo`03o`000?oooooooooo09[ooooo0_l0000mooooo`009_ooool0
0ol0003oooooooooo`1Tooooo`;o0000VOooool00ol0003oooooooooo`0mooooo`009_ooool00ol0
003oooooooooo`1Vooooo`;o0000U_ooool00ol0003oooooooooo`0nooooo`009_ooool00ol0003o
ooooooooo`1Xooooo`;o0000T_ooool2o`00047ooooo000Vooooo`;o0000Joooool2o`0008oooooo
00?o0000ooooooooool0@Oooool002Kooooo00?o0000ooooooooool0K?ooool2o`0008cooooo00?o
0000ooooooooool0@_ooool002Kooooo00?o0000ooooooooool0K_ooool2o`0008Sooooo0_l00015
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`1`ooooo`;o0000QOooool00ol0003oooooooooo`15
ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0L_ooool2o`0008;ooooo00?o0000ooooooooool0A_ooool0
00_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0001d
ooooo`;o0000O_ooool2o`0004Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Kooooo0_l0001kooooo`03o`000?oooooo
oooo04Wooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo07Sooooo0_l0001hooooo`03o`000?oooooooooo04[ooooo000;oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07[ooooo0_l0001eooooo`03o`000?oooooooooo04_ooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07cooooo0_l0001a
ooooo`;o0000C_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo
000000Oooooo0_l0001oooooo`?o0000KOooool00ol0003oooooooooo`1>ooooo`009_ooool00ol0
003oooooooooo`21ooooo`;o0000J_ooool00ol0003oooooooooo`1?ooooo`009_ooool00ol0003o
ooooooooo`23ooooo`;o0000I_ooool2o`0005;ooooo000Vooooo`03o`000?oooooooooo08Gooooo
0_l0001Sooooo`03o`000?oooooooooo05;ooooo000Vooooo`;o0000R?ooool2o`00063ooooo00?o
0000ooooooooool0Doooool002Kooooo00?o0000ooooooooool0ROooool2o`0005cooooo0_l0001F
ooooo`009_ooool00ol0003oooooooooo`2;ooooo`;o0000FOooool00ol0003oooooooooo`1Foooo
o`009_ooool00ol0003oooooooooo`2=ooooo`?o0000EOooool00ol0003oooooooooo`1Gooooo`00
9_ooool00ol0003oooooooooo`2@ooooo`?o0000Coooool3o`0005[ooooo000Vooooo`;o0000U?oo
ool3o`0004Wooooo0ol0001Mooooo`009_ooool00ol0003oooooooooo`2Fooooo`?o0000@oooool3
o`00063ooooo000Vooooo`03o`000?oooooooooo09Wooooo1?l0000looooo`?o0000Hoooool002Ko
oooo00?o0000ooooooooool0WOooool3o`0003Gooooo1?l0001Vooooo`009_ooool00ol0003ooooo
ooooo`2Pooooo`?o0000;oooool3o`0006[ooooo000Vooooo`;o0000Y?ooool3o`0002Wooooo0ol0
001]ooooo`009_ooool00ol0003oooooooooo`2Vooooo`?o00008oooool3o`00073ooooo0003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`2Yoooooa7o00003ooo
ool3o`0007?ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;[ooooo3ol0
001fooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`?o0000oooooom0ooooo`000oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00?oEEEEofIVI_l000001Oooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo
@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003o
oooood3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0
003ooooooooooooooooo000000gooooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nH
V9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01?ooool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooo
oom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo
@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003o
ooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooooomYooooo`00W?ooool2o`0000_o
oooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOooool009cooooo
00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<ZKooooo
002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08kooooo002Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?o
c<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool0
1?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006
oooooomgMgOoV9RHoooooonHV9SoMgMgS_ooool009Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
402>ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^
ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0S?oo
ool009Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00002>ooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@08kooooo002Aooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0S_ooool0097ooooo1ol00004ooooo`;o00004oooool00ol0003o
ooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11885 m
.11905 .10367 L
.21429 .08034 L
.30952 .10507 L
.40476 .13288 L
.5 .15451 L
.59524 .16069 L
.69048 .14215 L
.78571 .08961 L
.88095 .09039 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000Boooo
o`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0=?ooool01?l0003oooooooooool0000Aooooo`;o00000_ooool2o`0000Wooooo000Voooo
o`03o`000?oooooooooo0?oooooo6oooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003o
ooooooooo`3ooooooa[ooooo00?o0000ooooooooool08oooool002Kooooo0_l0003ooooooa[ooooo
00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oo
oooooooo02Gooooo000Vooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0V
ooooo`009_ooool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool09oooool002Ko
oooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo02Sooooo000Vooooo`;o0000
oooooolEooooo`03o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo0?oooooo4ooo
ool00ol0003oooooooooo`0Zooooo`009_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000
ooooooooool0:oooool002Kooooo00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo
02cooooo000Vooooo`;o0000oooooolAooooo`03o`000?oooooooooo02gooooo000Vooooo`03o`00
0?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0^ooooo`009_ooool00ol0003ooooooooo
o`3oooooo`kooooo00?o0000ooooooooool0;oooool002Kooooo00?o0000ooooooooool0ooooool=
ooooo`03o`000?oooooooooo033ooooo000Vooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0
003oooooooooo`0aooooo`009_ooool2o`000?oooooo3?ooool00ol0003oooooooooo`0booooo`00
9_ooool00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0<oooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0
003oooooooooo`0dooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo2?ooool00ol0003oooooooooo`0eooooo`000oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo03Kooooo0003ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`000?oooooo1_ooool00ol0003oooooooooo`0gooooo`000oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0eooooo`Go0000b_ooool00ol0003oooooooooo`0hoooo
o`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool4o`0000Gooooo1?l00035
ooooo`03o`000?oooooooooo03Wooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0]ooooo`Co00003Oooool4o`000:7ooooo4Ol0000>ooooo`03o`000?oooooooooo03[ooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
1?l00006ooooo`;o0000:Oooool5o`0001Gooooo1?l0002Kooooo`;o00004Oooool>o`0003gooooo
000Vooooo`03o`000?oooooooooo02Cooooo1?l0000Nooooo`Co0000UOooool2o`0005kooooo000V
ooooo`03o`000?oooooooooo023ooooo1?l0000Vooooo`Co0000T?ooool00ol0003oooooooooo`1N
ooooo`009_ooool00ol0003oooooooooo`0Looooo`Co0000;_ooool4o`0008[ooooo0_l0001Qoooo
o`009_ooool00ol0003oooooooooo`0Fooooo`Ko0000=_ooool4o`0008Cooooo0_l0001Sooooo`00
9_ooool2o`00013ooooo1ol00010ooooo`?o0000Ooooool2o`0006Gooooo000Vooooo`03o`000?oo
oooooooo00Sooooo1ol0001:ooooo`Co0000NOooool2o`0006Oooooo000Vooooo`04o`000?oooooo
ooooooooo`Oo0000EOooool4o`0007Cooooo00?o0000ooooooooool0Ioooool002Kooooo1?l0001P
ooooo`?o0000Koooool2o`0006[ooooo000Vooooo`03o`000?oooooooooo06Cooooo1?l0001Yoooo
o`;o0000K?ooool002Kooooo0_l0001Yooooo`Co0000Hoooool2o`0006kooooo000Vooooo`03o`00
0?oooooooooo06cooooo0ol0001Nooooo`;o0000L?ooool002Kooooo00?o0000ooooooooool0Kooo
ool4o`0005Wooooo00?o0000ooooooooool0L?ooool002Kooooo00?o0000ooooooooool0Loooool4
o`0005?ooooo0_l0001cooooo`009_ooool2o`0007Sooooo1?l0001=ooooo`;o0000MOooool002Ko
oooo00?o0000ooooooooool0Noooool5o`0004Gooooo0ol0001gooooo`009_ooool00ol0003ooooo
ooooo`20ooooo`Co0000??ooool5o`0007[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo08Cooooo
1?l0000cooooo`Go0000Ooooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo1?l0000Zooooo`Go0000
Q?ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo
0ol0002<ooooo`Wo00007?ooool5o`0008Wooooo000;ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo3ol00008ooooo`Go0000
S_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Y?ooool8o`0009?ooooo000;ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom0ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l00000
1oooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o
0000oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3ooooood3ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0oooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`00
00Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000V
ooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo
0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3o
oooood3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`009_oo
ool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03
o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0
003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo
0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3o
oooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0000Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000V
ooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0oooo
o`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_oo
ool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool0
02Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3o
oooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8b
olc<c006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0oooooom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00onYZJWo410@ooooo`05ooooo`?o0000oooooom0ooooo`002oooool01Ol0003ooooo
oooooooooooo000000gooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`3ooooood3o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`05ooooo`03
o`000?oooooooooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3ooooood3ooooo0003ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooood3ooooo0003ooooo`05o`000?oo
ooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooom0ooooo`000oooool01Ol0003ooooooooooooooooo000000gooooo
00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom0ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Ooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4o`0000Kooooo0_l0003o
oooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oo
oooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo
0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooo
ooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003oooooooooo`3o
oooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooooooo
ool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooo
oom1ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3ooooood3ooooo000;oooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000oooo
oom0ooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2
o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b
<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`00
0?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o
^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo08;ooooo002<ooooo`03o`00
0?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`24
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0Q?oo
ool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o
410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`24ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool0Q?ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`24ooooo`00ROooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00kooooo00?o0000ooooooooool0Q?ooool008Wooooo1ol00005ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000026ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19314 m
.11905 .23507 L
.21429 .04241 L
.30952 .16855 L
.40476 .11743 L
.5 .11588 L
.59524 .09889 L
.69048 .20806 L
s
.69048 .20806 m
.74753 0 L
s
.82157 0 m
.88095 .23065 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo0_l0
000Aooooo`;o00000_ooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0=Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01oooooo000Voooo
o`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o0000f?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool0
eoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
8?ooool002Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000ooooooooool0e_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool0
02Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool08_ooool002Kooooo0_l0003Fooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003ooooo
ooooo`3Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Rooooo`009_ooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02?ooooo000Vooooo`;o0000>?ooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Toooo
o`009_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000009_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo000Vooooo`03o`00
0?oooooooooo03Kooooo00Co0000oooooooooooo0000V_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool09?ooool002Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`009_ooool2
o`0003Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Vooooo`009_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09_ooool000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Vooooo`000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Wooooo`000oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Oooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Xooooo`000oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:?ooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oo
ooooooooooooool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08go
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wo
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo1?l00006ooooo`;o0000<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
02Wooooo000Vooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Zooooo`009_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0HOooool4o`0002Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02[ooooo000Vooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1Jooooo`Ko00000oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Doooool6o`0000[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:oooool002Kooooo0_l0000^oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool5o`00017ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0:oooool002Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo1_l0000Gooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000Vooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0eoooooa7o0000
7_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0/ooooo`009_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool09?ooool@o`00033ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Ooo
ool002Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02;ooooo0_l00011ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo000Vooooo`;o0000;?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo0_l00014ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02kooooo000Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Looooo`;o0000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0^ooooo`009_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool2o`0004Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0;_ooool002Kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Oooooo0_l0001<ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo000V
ooooo`;o0000:_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo0_l0001?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02oooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Aooooo`;o0000D_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`oooo
o`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`;o
0000Eoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0`ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo0_l0001Jooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo037o
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o
00009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo0_l0001Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo037ooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`05ooooo`;o0000Goooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`002oooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool2o`0006;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool000_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zooooo`04o`000?oooooo0000o`00
06Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<oooool000_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Oooooo0_l0000Uooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0<oooool002Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Cooooo000Vooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`009_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool002Kooooo0_l0000S
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool002Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo000Vooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`00
9_ooool2o`00027ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0fooooo`009_oo
ool00ol0003oooooo`000002o`0001kooooo00?o0000ooooooooool0XOooool01Ol0003ooooooooo
oooooooo000003Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0gooooo`009_oo
ool2o`0000?ooooo0_l0000Kooooo`03o`000?oooooooooo0:?ooooo00Co0000oooooooooooo0000
=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo000Vooooo`03o`000?oo
oooooooo00Cooooo0_l0000Iooooo`03o`000?oooooooooo0:Cooooo0_l0000gooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=oooool002Kooooo00?o0000ooooooooool01_ooool3
o`0001Gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>?ooool002Kooooo00?o0000ooooooooool02Oooool2o`00
01?ooooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Sooooo000Vooooo`03o`000?oooooooooo00_ooooo0ol0000?ooooo`03o`000?oooooooooo0>3o
oooo00Co0000oooooooooooo0000>oooool002Kooooo0_l0000?ooooo`;o00003Oooool00ol0003o
ooooooooo`3Pooooo`04o`000?ooooooooooo`0003_ooooo000Vooooo`03o`000?oooooooooo013o
oooo0ol00009ooooo`03o`000?oooooooooo0>7ooooo00?o0000ooooool00000??ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo01?ooooo0_l00007oooo
o`03o`000?oooooooooo0>7ooooo00?o0000ooooool00000??ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooooooool0hoooool2o`00
03cooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo0ol0000Gooooo`?o000000?oooooo`000?ooool0i?ooool00ol0
003oooooooooo`0kooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0oooooolSooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3ooooood3ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000005ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2
o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`3ooooood3ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooood3ooooo000;ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooo
oooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oo
oooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003ooooooooo
o`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000oooo
ooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`00
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00oooool3o`000?oooooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooo
od3ooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`00
9_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool0
0ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Ko
oooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o
0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Voooo
o`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`00
0?oooooooooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0oooooom0ooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMg
Molb<S801_ooool00ol0003oooooooooo`3ooooood3ooooo000;ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003ooooo
od3ooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P06oooo
o`03o`000?oooooooooo0?oooooo@?ooool000_ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0?oooooo@?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`;o0000oooooom1
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0
oooooom0ooooo`009_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo@?ooool000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`000?oo
oooo@?ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`3ooooood3ooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0oooooom0ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRH
V?oooooo^[Zjo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom0
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@04ooooo`Co00001_ooool2o`000?oooooo@Oooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool2o`000?oooooo@Ooo
ool002Kooooo00?o0000ooooooooool0oooooom0ooooo`009_ooool00ol0003oooooooooo`3ooooo
od3ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo0_l0003ooooood7ooooo
000Vooooo`03o`000?oooooooooo0?oooooo@?ooool002Kooooo00?o0000ooooooooool0oooooom0
ooooo`009_ooool00ol0003oooooooooo`3ooooood3ooooo000Vooooo`03o`000?oooooooooo0?oo
oooo@?ooool002Kooooo0_l0003ooooood7ooooo000Vooooo`03o`000?oooooooooo0?oooooo@?oo
ool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom0ooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oom0ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oo
oooooooo0?oooooo@?ooool000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Oooooo0ol0003ooooood3ooooo000;ooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool0
08[ooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo
00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000QOooool008co
oooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@
ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^08Kooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0QOooool008cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0Poooool008Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100QOooool008Wo
oooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<08Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24396 m
0 0 rlineto s
.02381 .24396 m
.07696 .61803 L
s
.1355 .61803 m
.16983 0 L
s
.26033 0 m
.29589 .61803 L
s
.33062 .61803 m
.38565 0 L
s
.43802 0 m
.5 .40014 L
s
.5 .40014 m
.5341 0 L
s
.62226 0 m
.64554 .61803 L
s
.71853 .61803 m
.73306 0 L
s
.83949 0 m
.85433 .61803 L
s
.9421 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2
o`0000kooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool2
o`0000;ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Nooooo`009_ooool2o`0002[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01kooooo000Vooooo`;o0000:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07ooo
ool002Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Oooooo`009_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Ooooo
o`009_ooool2o`0002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo0003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Oooooo`000oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo023ooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo1?l00006ooooo`;o0000:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?oo
ool002Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool08?ooool002Kooooo0_l0000Xooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Pooooo`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Poooo
o`009_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Pooooo`009_ooool2o`0002Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo000Vooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo023ooooo000Vooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo000Vooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
023ooooo000Vooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool08?ooool002Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08?ooool002Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo027ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooooooo
o`05ooooo`?o00009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Oooool000_ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08Ooo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool08Oooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000000Oooooo0_l0000Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Qooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`009_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Qooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`009_ooool2o`0002Oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo
000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo000Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo027ooooo000Vooooo`;o0000
9oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
8_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool0
02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool002Kooooo
0_l0000Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b
<_oMgMgooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo0003ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;o
oooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Rooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`00
02Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
02?ooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`0002Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000V
ooooo`;o00009_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool08oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Sooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000Vooooo`03o`00
0?oooooo000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02?ooooo000Vooooo`03o`000?oooooo000002Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02?ooooo000Vooooo`03o`000?oooooo
000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02?ooooo000Vooooo`?o00009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08oooool002Kooooo00?o0000ooooool000009?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooool0
00009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool08oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool000_ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Co0000oooooooooooo00008oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool0
00_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo1?l0000S
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0S
ooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool0
1?l0003oooooooooool0000Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Tooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Cooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00Co0000oooooooooooo00008oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool09?ooool002Kooooo0_l000000ooooooo0000ooooo`0R
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0T
ooooo`009_ooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo000Vooooo`05o`000?oooooooooo
ooooool000008_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09?ooool002Kooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool2o`00
00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09?ooool002Kooooo00Go0000ooooooooooooooooo`00000Qoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Toooo
o`009_ooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Cooooo000Vooooo`05o`000?oooooooooooooo
ool000008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool09_ooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool0
02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0002Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool09?ooool002Kooooo0_l00003ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Tooooo`009_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00009oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Tooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool2o`00
00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooo`00000Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000009oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`00000Wooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo0_l0000X
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Yooooo`;o0000:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`000oooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`;o0000:?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo0003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool2o`0000Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool002Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Kooooo000Vooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`009_ooool2o`00
00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Vooooo`009_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool002Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo
000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Vooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09_ooool002Kooooo0_l00007ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool09_ooool002Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Vooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09_ooool000_ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo000;ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00001_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Kooooo000;ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Vooooo`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool09_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool09_ooool002Kooooo0_l00008ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool09oooool002Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Kooooo0_l00009ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool002Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oo
oooo000Vooooo`;o00002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo
000Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Wooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool09oooool002Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Wooooo`009_ooool2o`0000[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Wooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`000oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`?o00002_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Sooooo0003ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
02Sooooo0003ooooo`05o`000?ooooooooooooooool000003Oooool00ol@413o0000okZj^P04oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0:?ooool000?ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Xooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@04ooooo`Co00001_ooool2o`0000_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Xooooo`009_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Xooooo`009_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo0_l0000<ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`009_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Ko
oooo0_l0000=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool002Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo
000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Yooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:Oooool002Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02Wooooo000Vooooo`;o00003Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Yooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:Oooool000_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Yooooo`002oooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Yooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001oooool3o`0000gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Yooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000oooooom:ooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l00000oooooom:ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000oooooom:ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool0oooooom9ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<08Gooooo002<
ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0
003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@
4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o
^[ZjoooooomgMgOo<S8b08Gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`23ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ojVYZOl@413ooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol@413o0000okZj^P25ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o
0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo08Cooooo0029ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000008Gooooo0029
ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000
ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28092 m
0 0 rlineto s
.02381 .28092 m
.02814 .61803 L
s
.15531 .61803 m
.15848 0 L
s
.26288 0 m
.26563 .61803 L
s
.35966 .61803 m
.36281 0 L
s
.44821 0 m
.45147 .61803 L
s
.53395 .61803 m
.53623 0 L
s
.63317 0 m
.63464 .61803 L
s
.73479 .61803 m
.73595 0 L
s
.84261 0 m
.84394 .61803 L
s
.97289 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooool000002oooool00ol0003oooooooooo`0;oooo
o`;o00003Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo0_l00002ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`000ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`04oooo
o`?o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_ooool2o`0002Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Woooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Nooooo`002oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01Oooool3o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool00omEEEGoIVIVo`000007ooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
02Kooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0N
ooooo`009_ooool2o`0002Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000Voooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Noooo
o`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Nooooo`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo0003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000000Gooooo1?l00006ooooo`;o00009oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Wooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01kooooo000Vooooo`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_ooool000_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07_oo
ool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0
000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Nooooo`002oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`002oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00009Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Oooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo
000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo0_l0000Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool2o`0002Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000;ooooo`05
o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o00009Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000_o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Kooooo0_l0000Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`002oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool01Oooool2o`00
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o
000000Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Oooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`00
02Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000V
ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o0000
9_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0O
ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb
<S801oooool00omgMgOo<S8booooo`04ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool000?ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0002Go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03
ogMgMolb<S;ooooo00Cooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Oooooo`000oooool01Ol0003ooooooooooooooooo000000go
oooo00?o410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Ooooo
o`000oooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0
003oooooooooo`07ooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`;o00009_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool0
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?oo
ool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Oooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000V
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0O
ooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_oo
ool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`009_ooool2o`0002Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oo
oooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Oooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool2o`0002Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo000;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool2o`0002Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo01oooooo000;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0_l0
000Vooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Oooooo`002oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
1oooool3o`0002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01oooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool0003ooooood[ooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00003ooooood[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`00003ooooood[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`3oooooodWooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`00
0?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?o
QhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0
0oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0Poooool008co
oooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@
ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo08Cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0008Gooooo
002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo0000Q_ooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0008Kooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o0000
1Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l00000Q_ooool008Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000008Kooooo0029ooooo`Oo00001Oooool2o`0001;o
oooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0QOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0 1.54508 [
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -18 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(0.05)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.15)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.2)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.3)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.35)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.4)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
0 0 rlineto s
.02381 .30902 m
.02415 .61803 L
s
.15528 .61803 m
.15554 0 L
s
.25928 0 m
.25948 .61803 L
s
.35591 .61803 m
.3561 0 L
s
.4477 0 m
.44786 .61803 L
s
.54035 .61803 m
.54047 0 L
s
.63773 0 m
.63783 .61803 L
s
.73856 .61803 m
.73865 0 L
s
.8441 0 m
.84421 .61803 L
s
.9759 .61803 m
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00EOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool4o`000003oa0@4?oooooooooo01cooooo001Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00T
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B409Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<?ooool00ol0003oooooooooo`0Nooooo`00EOooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h09Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Uooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Go
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<?ooool0
0ol0003oooooooooo`0Nooooo`00EOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h09?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
9_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b033ooooo00?o
0000ooooooooool07_ooool005Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00`ooooo`03o`00
0?oooooooooo01kooooo001Eooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Rooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Wooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@033ooooo00?o0000ooooooooool07_oo
ool005Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
9?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000`ooooo`03o`000?oooooooooo01kooooo001E
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;_ooool00omEEEGoIVIVo`00000Pooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Ooooooooo0000<Ol0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Voooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02_ooool2o`0000gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool000003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000gooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P[ooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03ooo
ool2o`0000;ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
0oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo1?l00006ooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000;ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`05ooooo`?o00009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEE
EOmVIVKo000000Oooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o
00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_oo
ool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003
oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000001Oooool4o`0000Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
9_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_oo
ool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Voooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o0000
9_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool0
02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo
0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0N
ooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`00
9_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo0003ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`000oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo0003ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`000oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8b
olc<c006ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01ko
oooo000;ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01kooooo000;ooooo`05o`000?ooooooooooooooool000003_ooool00onYZJWo
410@ooooo`05ooooo`?o00009Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Nooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Nooooo`009_ooool2o`0002Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`;o00009_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05o`000?ooooooooooooooool00000
3_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
7_ooool000?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo0003ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Cooooo1?l00006ooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Ko
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool002Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo0_l0000Vooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Noooo
o`009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`009_oo
ool2o`0002Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01kooooo000Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo
000Vooooo`;o00009_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool07_ooool002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool07_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01kooooo000;ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07_ooool000_ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0000Uooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Nooooo`002oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000oooooom:ooooo`002ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000oooooom:ooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000oooooom:ooooo`002ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0oooooom9ooooo`00oooo
oomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000
okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000oooo
ooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM08Cooooo002<ooooo`03o`000?oooooooooo00Ko
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`23ooooo`00S?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0P_ooool008cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`23ooooo`00
S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c024
ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`26ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`00
0?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co0000QOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.132336, -0.0320875, \
0.00432536, 0.00266613}}]
}, Closed]]
}, Open  ]],

Cell["\<\
\tThe result shows that the solution immediately blows up. What \
happened? \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Von Neumann Stability Analysis", "Section",
  CellTags->{"i:19", "c:16"}],

Cell[TextData[{
  "The problem encountered in the previous example is one of numerical \
instability caused by an overly large step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". ",
  StyleBox[ButtonBox["Von Neumann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Von_Neumann.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" stability analysis",
    FontSlant->"Italic"],
  " provides us with the tools we need to understand and overcome this \
problem. The analysis relies on the idea that certain short-wavelength \
spatial modes in the numerical solution can be unstable. In the stability \
analysis for these modes, it suffices to neglect boundary conditions and \
source terms, if any, and  solve the recursion relation analytically, using \
Fourier modes. That is, keeping only one mode, we write ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n = \(a\_n\) \[ExponentialE]\^\(\[ImaginaryI]\ \
k\ \ x\_j\)\)]],
  ",where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is the wavenumber of the mode. Applying this ansatz to the FTCS method ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  ",  and neglecting the source term, we find that we can divide out a factor \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ \ x\_j\)\)]],
  "from both sides, leaving us with the following difference equation for ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  ":"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(n + 1\)\), "=", 
          RowBox[{\(a\_n\), "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", "k", "  ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], \(a\_n\)}], 
                  "-", \(2  a\_n\), "+", 
                  RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{\(-\[ImaginaryI]\), " ", "k", "  ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]]}]], \(a\_n\)}]}], 
                ")"}]}]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell["\<\
Using a trigonometric identity, this equation can be rewritten as\
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(n + 1\)\), "=", 
          RowBox[{\(a\_n\), "[", 
            RowBox[{"1", "-", 
              RowBox[{"4", 
                FractionBox[
                  RowBox[{"\[Chi]", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"]], 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.6)"],

Cell["\<\
Linear homogeneous difference equations of this sort have a general \
solution of the form \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`a\_n = A\ \[Xi]\^n\)]],
  ", "
}], "NE2",
  CellTags->"(6.2.7)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\)\(\ \)\)\)]],
  " is an undetermined constant, dependent on the initial condition. The \
parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  " is called the amplification factor, since it is the factor by which the \
solution is amplified in a single ",
  "time step",
  ". This parameter can be determined by substitution of Eq. ",
  ButtonBox["(6.2.7)",
    ButtonData:>"(6.2.7)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(6.2.6)",
    ButtonData:>"(6.2.6)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[Xi]", "=", 
        RowBox[{"1", "-", 
          RowBox[{"4", 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{"k", " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.8)"],

Cell[TextData[{
  "The amplification factor  depends on the step size in both time and space, \
and on the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " of the mode in question. The important issue facing us is that, for \
certain choices of these parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\)\)]],
  " can be larger that unity. If this is so, the solution is unstable, \
because as the time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases, the solution blows up like ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Xi]\^n\) \[ExponentialE]\^\(\[ImaginaryI]\ \
k\ \ x\_j\)\)]],
  ". However, if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(|\)\(\[Xi]\)\(|\)\),
            "TraditionalForm"], "<", "1"}], TraditionalForm]]],
  " for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", then each mode will decay in time rather than grow, and the solution \
will be well behaved. (The decay of these modes does not necessarily imply \
that the solution to the heat equation goes to zero, because boundary \
conditions and source terms neglected here can keep the solution finite. \
Rather, it implies that any short-wavelength noise in the solution will decay \
away. This is just what we want to happen in order to obtain a smooth \
solution.)"
}], "Text"],

Cell[TextData[{
  "\tThese considerations lead us to the condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(1\)\)\
\)\)]],
  " for all wavenumbers ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "  in order for our numerical solution to be stable. In Fig. ",
  ButtonBox["6.6",
    ButtonData:>"Fig. 6.6",
    ButtonStyle->"Hyperlink"],
  ", we graph Eq. ",
  ButtonBox["(6.2.8)",
    ButtonData:>"(6.2.8)",
    ButtonStyle->"Hyperlink"],
  "  vs. ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " for several values of the parameter ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"\[Chi]", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"]], TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.456168 0.147151 [
[.17539 .44367 -3 -9 ]
[.17539 .44367 3 0 ]
[.32696 .44367 -3 -9 ]
[.32696 .44367 3 0 ]
[.47854 .44367 -3 -9 ]
[.47854 .44367 3 0 ]
[.63011 .44367 -3 -9 ]
[.63011 .44367 3 0 ]
[.78169 .44367 -3 -9 ]
[.78169 .44367 3 0 ]
[.93327 .44367 -3 -9 ]
[.93327 .44367 3 0 ]
[1.025 .45617 0 -6 ]
[1.025 .45617 28 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -12 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .45617 m
.17539 .46242 L
s
[(1)] .17539 .44367 0 1 Mshowa
.32696 .45617 m
.32696 .46242 L
s
[(2)] .32696 .44367 0 1 Mshowa
.47854 .45617 m
.47854 .46242 L
s
[(3)] .47854 .44367 0 1 Mshowa
.63011 .45617 m
.63011 .46242 L
s
[(4)] .63011 .44367 0 1 Mshowa
.78169 .45617 m
.78169 .46242 L
s
[(5)] .78169 .44367 0 1 Mshowa
.93327 .45617 m
.93327 .46242 L
s
[(6)] .93327 .44367 0 1 Mshowa
.125 Mabswid
.05412 .45617 m
.05412 .45992 L
s
.08444 .45617 m
.08444 .45992 L
s
.11476 .45617 m
.11476 .45992 L
s
.14507 .45617 m
.14507 .45992 L
s
.2057 .45617 m
.2057 .45992 L
s
.23602 .45617 m
.23602 .45992 L
s
.26633 .45617 m
.26633 .45992 L
s
.29665 .45617 m
.29665 .45992 L
s
.35728 .45617 m
.35728 .45992 L
s
.38759 .45617 m
.38759 .45992 L
s
.41791 .45617 m
.41791 .45992 L
s
.44822 .45617 m
.44822 .45992 L
s
.50885 .45617 m
.50885 .45992 L
s
.53917 .45617 m
.53917 .45992 L
s
.56948 .45617 m
.56948 .45992 L
s
.5998 .45617 m
.5998 .45992 L
s
.66043 .45617 m
.66043 .45992 L
s
.69074 .45617 m
.69074 .45992 L
s
.72106 .45617 m
.72106 .45992 L
s
.75138 .45617 m
.75138 .45992 L
s
.81201 .45617 m
.81201 .45992 L
s
.84232 .45617 m
.84232 .45992 L
s
.87264 .45617 m
.87264 .45992 L
s
.90295 .45617 m
.90295 .45992 L
s
.96358 .45617 m
.96358 .45992 L
s
.9939 .45617 m
.9939 .45992 L
s
.25 Mabswid
0 .45617 m
1 .45617 L
s
gsave
1.025 .45617 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-3)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-2)] .01131 .16186 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(-1)] .01131 .30902 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03465 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .60331 L
.02605 .6033 L
.02729 .60328 L
.02846 .60325 L
.03053 .60317 L
.03279 .60306 L
.03527 .6029 L
.0379 .60268 L
.04262 .60219 L
.04749 .60153 L
.05205 .60077 L
.06244 .59856 L
.07305 .59562 L
.08274 .59234 L
.10458 .58292 L
.14429 .55923 L
.18248 .52979 L
.22313 .4934 L
.26226 .45583 L
.30384 .41598 L
.34391 .38039 L
.38246 .35109 L
.402 .33871 L
.42346 .32738 L
.44388 .31899 L
.45301 .31603 L
.46295 .31339 L
.46838 .31221 L
.4734 .31128 L
.4781 .31055 L
.4833 .30991 L
.48553 .30969 L
.48794 .30948 L
.49002 .30934 L
.4923 .30921 L
.49473 .30911 L
.49605 .30907 L
.49728 .30904 L
.49844 .30902 L
.49949 .30902 L
.50071 .30902 L
.50186 .30903 L
.50301 .30905 L
.50425 .30907 L
.50542 .30911 L
.50648 .30915 L
.5091 .30928 L
.51158 .30945 L
.5165 .30989 L
Mistroke
.52187 .31055 L
.53144 .31217 L
.54032 .31419 L
.56088 .32073 L
.5795 .3288 L
.61962 .35251 L
.65822 .38217 L
.69928 .4189 L
.73882 .45687 L
.77684 .49338 L
.81732 .52963 L
.85628 .55963 L
.87613 .5724 L
.89769 .58402 L
.91843 .59276 L
.92832 .59604 L
.93759 .59857 L
.94643 .60049 L
.95595 .60201 L
.9611 .60259 L
.96369 .60282 L
.96652 .60302 L
.96894 .60315 L
.9703 .60321 L
.97153 .60325 L
.97268 .60328 L
.97393 .6033 L
.97511 .60332 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60328 L
.03053 .60325 L
.03279 .60319 L
.03527 .60311 L
.0379 .603 L
.04262 .60275 L
.04749 .60242 L
.05205 .60205 L
.06244 .60094 L
.07305 .59947 L
.08274 .59783 L
.10458 .59312 L
.14429 .58128 L
.18248 .56656 L
.22313 .54836 L
.26226 .52957 L
.30384 .50965 L
.34391 .49185 L
.38246 .4772 L
.402 .47102 L
.42346 .46535 L
.44388 .46115 L
.45301 .45967 L
.46295 .45835 L
.46838 .45776 L
.4734 .4573 L
.4781 .45693 L
.4833 .45661 L
.48553 .4565 L
.48794 .4564 L
.49002 .45633 L
.4923 .45626 L
.49473 .45621 L
.49605 .45619 L
.49728 .45618 L
.49844 .45617 L
.49949 .45617 L
.50071 .45617 L
.50186 .45617 L
.50301 .45618 L
.50425 .4562 L
.50542 .45621 L
.50648 .45623 L
.5091 .4563 L
.51158 .45638 L
.5165 .4566 L
Mistroke
.52187 .45693 L
.53144 .45774 L
.54032 .45876 L
.56088 .46202 L
.5795 .46606 L
.61962 .47791 L
.65822 .49274 L
.69928 .51111 L
.73882 .5301 L
.77684 .54835 L
.81732 .56647 L
.85628 .58147 L
.87613 .58786 L
.89769 .59367 L
.91843 .59804 L
.92832 .59968 L
.93759 .60095 L
.94643 .60191 L
.95595 .60266 L
.9611 .60295 L
.96369 .60307 L
.96652 .60317 L
.96894 .60323 L
.9703 .60326 L
.97153 .60328 L
.97268 .6033 L
.97393 .60331 L
.97511 .60332 L
.97619 .60332 L
Mfstroke
gsave
.47854 .52974 -85.5938 -14.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 29.5 translate 1 -1 scale
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 11.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 11.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.438 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 17.438 moveto
(\\200\\200) show
85.875 17.438 moveto
(\\200) show
67.875 24.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.062 11.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.750 17.438 moveto
(\\200\\200) show
102.000 17.438 moveto
(\\200) show
104.062 17.438 moveto
(\\200) show
99.062 23.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
108.188 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47854 .23544 -85.5938 -14.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 29.5 translate 1 -1 scale
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 11.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 11.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 17.438 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 17.438 moveto
(\\200\\200) show
85.875 17.438 moveto
(\\200) show
67.875 24.500 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
99.062 11.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.750 17.438 moveto
(\\200\\200) show
102.000 17.438 moveto
(\\200) show
104.062 17.438 moveto
(\\200) show
99.062 23.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
108.188 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7059 .08829 -82.5 -14.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 28.9375 translate 1 -1 scale
63.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
66.250 10.938 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
74.875 10.938 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.750 16.875 moveto
(\\200\\200\\200\\200\\200\\200\\200\\200) show
81.750 16.875 moveto
(\\200\\200) show
85.875 16.875 moveto
(\\200) show
67.875 23.938 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
79.875 20.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
90.000 16.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
96.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
102.000 16.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?oo
ooooE?ooool000Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooE?ooool000Sooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooE?ooool000Ko00001_ooool00ol0003oooooooooo`03ooooo`?o0000SOooool4o`000<;ooooo
000;ooooo`03ojVYZOl@413ooooo00Cooooo00?o0000ooooooooool0Qoooool6o`0000Cooooo1ol0
002kooooo`002_ooool00ol@413o0000okZj^P05ooooo`03o`000?oooooooooo08Cooooo0ol0000A
ooooo`;o0000^Oooool000_ooooo00?o^[Zjob4Q8Oooool01?ooool00ol0003oooooooooo`22oooo
o`;o00005_ooool00ol0003oooooooooo`2fooooo`002?ooool01Ol@413oV9RHoooooonj^[[o0000
00Gooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Gooooo`;o0000]_ooool000So
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo07oooooo0_l0000Loooo
o`03o`000?oooooooooo0;?ooooo000Booooo`03o`000?oooooooooo07gooooo0_l0000Oooooo`;o
0000/oooool001;ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo0;3ooooo000Booooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool08ooo
ool2o`000;3ooooo000Booooo`;o0000Noooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo0:gooooo000Booooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0:?ooool2o`00
0:gooooo000Booooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`2Zooooo`004_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool04Oooool00olb<S;o0000o`000003o`000003oc8b<_oooooooooo00;o0000
0_ooool2o`0008Wooooo000Booooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Aooooo`03oiRHV?m4A4Cooooo00;ooooo00[oA4A4oiRHV?oooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgMROooool001;ooooo00?o0000ooooooooool0MOooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo017ooooo00Go410@omgMgOoooooogMgMoa0@4004
ooooo`04omgMgOl0003o410@olc<c8[ooooo000Booooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?oo
ool01?o^k^ko8B4Qoa0@4?o^k^j:ooooo`004_ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03oooool01Oo^k^ko410@onk^k_l@413ok^k^00Cooooo
00Go8B4QogMgMomgMgOo<S8booooo`04o`0008Gooooo000Booooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03ogMgMolQ8B7oEEEE00Cooooo
0_l00002ooooo`;o000000?oooooo`000?ooool0Q_ooool001;ooooo0_l0001booooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool03oooool00ooMgMgo0000omgMg@0<ooooo`03o`000?oo
oooooooo08Cooooo000Booooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0?ooooo`03ojVYZOoooooooooo00cooooo00?o0000ooooooooool0Poooool0
01;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
01[ooooo00Co0000oooooooooooo0000QOooool001;ooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo01[ooooo0_l0000Cooooo`Co000000?o410@oooo
ooooool0K?ooool001;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02Kooooo1_l00004ooooo`03o`000?oooooooooo06kooooo000Booooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05oooooago0000
3_ooool00ol0003oooooooooo`1^ooooo`004_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool09Oooool6o`0000Cooooo00?o0000ooooooooool0K_oo
ool001;ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo00Cooooo00GoEEEEoiRHV?ooooooooooolc<c002
o`000003oiRHV?oooooooooo01oooooo00?o0000ooooooooool0K_ooool001;ooooo0_l0001/oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?ooool01OmEEEGoV9RHoooooomEEEGo
QhN702?ooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_o<c<co8B4Qolc<c005
ooooo`03oc8b<_l0003o000000?o000000Go<S8boooooooooooooooooiRHV002o`000003odA4A?nj
^[[ooooo00cooooo00?oEEEEofIVI_l00000L?ooool001;ooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Cooooo00?ok^k^oc8b<_l000001_ooool0
0onHV9SoA4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@okZj^_o^k^koMgMgoa0@
4020ooooo`004_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool01?ooool00onYZJWo410@onk^kP06ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?oo
ool00ol0003oooooooooo`22ooooo`004_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool01?ooool01?mgMgOoA4A4oc8b<_o^k^h5ooooo`05ohN7Qomg
MgOoooooofIVI_n7QhL01?ooool00ol0003oooooooooo`22ooooo`004_ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00oooool01?lb<S;oZJVYoiRH
V?mEEED5ooooo`05onk^k_l@413ok^k^oa0@4?o^k^h01?ooool00ol0003oooooooooo`22ooooo`00
4_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo04gooooo00[o0000oooooooooooo
<S8bo`000?lQ8B7ok^k^oooooonHV9SoEEEE1Oooool00omgMgOo8B4QoeEEE@03ooooo`03oa0@4?l0
003o000000?o0000POooool001;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00cooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`22
ooooo`004_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool03?ooool00onYZJWoooooooooo`04ooooo`03o`000?oooooooooo08;ooooo000Booooo`;o
0000I_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo09Oooooo000Booooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2Gooooo`004_oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0U_oo
ool001;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo09Gooooo000Booooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`2Eooooo`004_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool0U?ooool001;ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo09?ooooo0008ooooo`Go00001Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Toooool000Sooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`2Booooo`001_l00003ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001O
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0TOooool000[ooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0TOooool000_ooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0T?ooool000cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
T?ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`2?ooooo`002?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo08oooooo000Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`2>ooooo`004_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0SOooool001;ooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo08gooooo000Booooo`;o0000Foooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo08cooooo000Booooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0J?ooool00ol0003oooooooooo`2<ooooo`004_ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo01Kooooo00?o<S8bo`000?l000000ol000000olb<S;ooooooooo
o`02o`0000;ooooo0_l00014ooooo`03o`000?oooooooooo08_ooooo000Booooo`03o`000?oooooo
oooo05Sooooo00?o0000ooooooooool05oooool00onHV9SoA4A4ooooo`02ooooo`0:odA4A?nHV9So
ooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMgDCooooo00?o0000ooooooooool0Roooool001;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oMgMgoooooomgM
gOl@41001?ooool01?oMgMgo0000oa0@4?o<c<`Jooooo`Go00009oooool00ol0003oooooooooo`2:
ooooo`004_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01Wooooo00GoQhN7ogMg
MoooooooIVIVohN7Q`04ooooo`04onk^k_lQ8B7o410@onk^kQ[ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo08[ooooo000Booooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool06Oooool01Oo^k^ko410@onk^k_l@413ok^k^00Cooooo00Co8B4QogMgMomgMgOo
<S8b6oooool00onHV9So8B4Qonk^kP0Yooooo`03o`000?oooooooooo08Wooooo000Booooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool06oooool00omgMgOo8B4QoeEEE@04ooooo`;o0000
0_ooool6o`0001Oooooo00?oV9RHob4Q8Oo^k^h0:?ooool00ol0003oooooooooo`29ooooo`004_oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01cooooo00?ogMgMo`000?oMgMd02ooo
ool00ol0003oooooooooo`0Hooooo`03ogMgMomVIVKooooo02Sooooo00?o0000ooooooooool0R?oo
ool001;ooooo0_l0001Fooooo`03o`000?oooooooooo01gooooo00?oZJVYooooooooool02oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Qoooool0
01;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01?ooooo00Go0000okZj^_ooooooV9RHoa0@400Zooooo`03o`000?oooooooooo08Oooooo000Boooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000E
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:oooool00ol0003oooooooooo`26ooooo`004_ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02cooooo0_l0000:ooooo`Ko0000=_ooool0
0ol0003oooooooooo`26ooooo`004_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
01Sooooo7Ol0000<ooooo`_o0000:Oooool00ol0003oooooooooo`25ooooo`004_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo03Wooooo1_l0000gooooo`03o`000?oooooooooo08Go
oooo000Booooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`24ooooo`004_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0Q?ooool001;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0L
ooooo`05oeEEEOnHV9Soooooooooooo<c<`00_l000000onHV9Soooooooooo`1Cooooo`03o`000?oo
oooooooo08?ooooo000Booooo`;o0000DOooool00ol0003oooooooooo`0Nooooo`05oeEEEOnHV9So
oooooeEEEOn7QhL0Eoooool00ol0003oooooooooo`23ooooo`004_ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo00Gok^k^oc8b<_o<c<co8B4Qolc<c004ooooo`03oc8b<_l0
003o000000?o000000Go<S8boooooooooooooooooiRHV002o`000003odA4A?nj^[[ooooo017ooooo
1?l000000ol@413oooooooooo`0/ooooo`03o`000?oooooooooo08;ooooo000Booooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool08?ooool00oo^k^ko<S8bo`000005ooooo`03oiRHV?m4
A4Cooooo00;ooooo00?oA4A4oiRHV?ooool00_ooool01Ol@413o^[Zjonk^k_mgMgOo410@01Cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`22ooooo`004_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo02;ooooo00?oZJVYoa0@4?o^k^h01Oooool01Ol@413ogMgMoooo
oooMgMgo410@00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo087ooooo000Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08_oo
ool01?mgMgOoA4A4oc8b<_o^k^h4ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0POooool001;ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Sooooo`04oc8b<_nYZJWoV9RHoeEEE@Co
oooo00Gok^k^oa0@4?o^k^ko410@onk^kP04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`20ooooo`004_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo027ooooo00Oo<S8bo`000?lQ8B7ok^k^oooooonHV9SoEEEE00Cooooo00?oMgMg
ob4Q8OmEEED00oooool00ol@413o0000o`000003o`0001Gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`20ooooo`004_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
02gooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0Ooooool001;ooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0^ooooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool05?ooool00omEEEGo
IVIVo`00000cooooo`03o`000?oooooooooo07oooooo000Booooo`;o0000C?ooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo07kooooo000Booooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`1nooooo`004_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0OOooool001;ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo07gooooo000Booooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1looooo`00
4_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0
O?ooool001;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo07_ooooo0009ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0Noooool000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08cooooo00?o0000oooo
ooooool0N_ooool000Ko00001Oooool00ol0003oooooooooo`04ooooo`?o0000A_ooool00ol0003o
ooooooooo`10ooooo`co0000@Oooool00ol0003oooooooooo`1jooooo`002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0>Oooool7o`0000cooooo
1_l0000looooo`03o`000?oooooooooo07Wooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0gooooo`?o00006Oooool3o`0003Wooooo00?o
0000ooooooooool0NOooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo03Cooooo0ol0000Oooooo`?o0000=oooool00ol0003oooooooooo`1h
ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0<oooool2o`0002Gooooo0ol0000dooooo`03o`000?oooooooooo07Sooooo0009ooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0aooooo`;o
0000:_ooool3o`0003;ooooo00?o0000ooooooooool0Moooool001;ooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0`ooooo`;o0000;oooool2o`00033ooooo00?o0000ooooooooool0
Moooool001;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0^ooooo`;o0000<ooo
ool2o`0002oooooo00?o0000ooooooooool0M_ooool001;ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0]ooooo`;o0000=oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo07Gooooo000Booooo`;o0000@oooool00ol0003oooooooooo`0[ooooo`;o0000>_ooool2o`00
02gooooo00?o0000ooooooooool0MOooool001;ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03cooooo0_l0000/ooooo`03o`000?oooooooooo07Co
oooo000Booooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:Oooool2o`00047ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1dooooo`004_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0@_ooool2o`0002[ooooo00?o
0000ooooooooool0Loooool001;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0X
ooooo`;o0000Aoooool2o`0002Sooooo00?o0000ooooooooool0Loooool001;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1booooo`004_ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo07;ooooo000Booooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
9Oooool2o`0004oooooo0_l0000Vooooo`03o`000?oooooooooo077ooooo000Booooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0LOooool001;ooooo0_l0000nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo073ooooo000Booooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08oooool2o`00
05Oooooo0_l0000Tooooo`03o`000?oooooooooo06oooooo000Booooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0Koooool001;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1^ooooo`004_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo0_l0
001Oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K_ooool001;ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`004_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo06gooooo000Booooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0K?ooool001;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1/ooooo`004_oo
ool2o`0003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Joooool001;ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1[ooooo`004_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
06[ooooo000Booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0JOooool001;ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Yooooo`004_ooool00ol0003ooooooooo
o`0Zooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Go0000:Oooool01OnHV9So410@o`000?lb<S;oc<c<02_ooooo0_l000000ol@413ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Kooooo00OoA4A4o`000?l0003o<S8bomgMgOoooooo0000
02Oooooo00Gok^k^oc8b<_l0003o410@olc<c00nooooo`004_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool2o`0000?ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Yooooo`05oa0@4?nj^[[oooooogMgMolb<S80;?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Sooooo00CoMgMgoc8b<_oooooo00009oooool01OmEEEGoMgMg
oooooonHV9So8B4Q03kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0
;_ooool00ol0003oooooooooo`0Wooooo`Go00004oooool2o`0001Wooooo00Co0000oooooooooooo
00009_ooool01Ol0003ooooooooooooooooo000003kooooo000Booooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Ko
oooo00?oV9RHob4Q8Oo^k^h0;?ooool00onYZJWo410@ooooo`0Xooooo`04odA4A?oMgMgoooooo`00
01Kooooo00?o0000ooooooooool05Oooool01OmgMgOo<S8boooooooooooo000002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0nooooo`004_ooool2o`0002gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool0:_ooool0
0ol@413o0000okZj^P0Yooooo`04omgMgOmEEEGoooooo`0001Oooooo00?o0000ooooooooool04Ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool08oooool01Ol0003oEEEE
o`000?l@413oc<c<03kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
:_ooool00onj^[[o8B4Qooooo`0Yooooo`03ogMgMoo<c<co000001Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?oEEEEohN7Qoooool0
@?ooool001;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01oooool01Ol0003o^[ZjoooooonHV9So410@02Wooooo
00Go410@oiRHV?oooooo^[Zjo`00000Zooooo`03onk^k_m4A4Co000001Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?ogMgMoa0@4?nH
V9P0@?ooool001;ooooo00?o0000ooooooooool0:_ooool00omEEEGoIVIVo`000005ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7oc<c<02Wo
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0[ooooo`03ogMgMol0003ooooo01Wooooo00?o0000oooo
ooooool03_ooool4o`0000Gooooo00?o0000ooooooooool08oooool01?o<c<coA4A4o`000?l@410n
ooooo`004_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Cooooo000Booooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Hoooool001;ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`12ooooo`;o00000_ooool00ol@413o0000o`000007ooooo`03oc8b
<_l0003o000000?o000000?o<S8booooooooool00_l00002ooooo`;o00001?ooool001;ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`12ooooo`05o`000?ooooook^k^oc8b<_o<c<`0
2?ooool00onHV9SoA4A4ooooo`02ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool0
1?l0003oV9RHoc8b<_o<c<`:ooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`002oooooooo`0003?o00002oooool00ol0003o410@oiRHV00;ooooo`05ohN7
QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo2?l00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool5o`0000Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`07ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool01?l0003ok^k^oeEEEOn7QhL:ooooo`05onk^k_l@413o
k^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`004_ooool00ol0003ooooooooo
o`0/ooooo`;o00005Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo0ol0
000<ooooo`03o`000?oooooooooo01Cooooo1_l0000Aooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool01Ol0003oooooodA4A?l0003o410@00[ooooo00?oMgMgob4Q8OmEEED0
1?ooool2o`0000;ooooo0_l00004ooooo`004_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0;oooool5o`0002cooooo1Ol0000aooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0<ooooo`03omgMgOl0
003ogMgM00kooooo000Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0/ooooo`Co0000=_ooool3o`0002oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00gooooo00?oZJVYooooooooool03Oooool0
01;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02[ooooo0ol0000mooooo`?o0000;Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
03gooooo0_l0000Oooooo`004_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:?ooool3o`0004?ooooo0ol0000[ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0GOooool001;ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Kooooo0ol00019ooooo`?o0000:Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo05gooooo000Booooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`;o0000Coooool3o`0002Oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Looooo`004_ooool2o`0002Wooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`;o0000E?ooool3o`0002Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`1Kooooo`004_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool3o`0005Wooooo0ol0000Soooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Foooool001;ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0?ooooo`;o00008oooool2o`0001;ooooo00?o<S8bo`000?l0
00000ol000000olb<S;oooooooooo`02o`0000;ooooo0_l0000nooooo`;o00008_ooool2o`00017o
oooo00?o0000ooooooooool0F_ooool001;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo023ooooo0ol0000Dooooo`03oiRHV?m4A4Cooooo00;ooooo
00[oA4A4oiRHV?ooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM6oooool2o`000003oa0@4?oo
oooooooo023ooooo0_l0000Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0FOoo
ool001;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01oooooo0_l0000Hooooo`05oa0@4?oMgMgoooooomgMgOl@41001?ooool01?oMgMgo0000oa0@
4?o<c<`Mooooo`03o`000?oooooooooo02?ooooo0_l0000Qooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0FOooool001;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01kooooo0_l0000Jooooo`05ohN7QomgMgOoooooofIVI_n7QhL0
1?ooool01?o^k^ko8B4Qoa0@4?o^k^hJooooo`Go00009_ooool2o`00023ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Hooooo`004_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool07?ooool3o`0001cooooo00Gok^k^oa0@4?o^k^ko
410@onk^kP04ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q[ooooo00CoA4A4omgMgOoooooo0000:Oooool2
o`0001oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Gooooo`004_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool2o`00
023ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo1_l0000Eooooo`04omgMgOmEEEGooooo
o`0002_ooooo0_l0000Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Eoooool0
01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo0_l0000Rooooo`03omgMgOl0003ogMgM00_ooooo00?o0000ooooooooool05_ooool00omg
MgOoc<c<o`00000]ooooo`;o00007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Kooooo000Booooo`;o00008oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wo
oooo0_l0000Uooooo`03ojVYZOoooooooooo00_ooooo00?o0000ooooooooool05Oooool00oo^k^ko
A4A4o`00000_ooooo`?o00006oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Go
oooo000Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Gooooo`?o0000=_ooool00ol0003oooooooooo`0Eooooo`03ogMgMol0003ooooo037ooooo
0_l0000Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool001;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo0_l0
000fooooo`04o`000?ooooooooooo`0004gooooo0_l0000Iooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0E?ooool001;ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Gooooo0_l0000iooooo`;o00002_ooool6o`00043ooooo0ol0
000Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Doooool001;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0;ooooo`;o00005_ooool2o`0002Oooooo7Ol0000<
ooooo`_o0000=Oooool2o`0001Kooooo0_l0000=ooooo`03o`000?oooooooooo05;ooooo000Boooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Doooo
o`;o0000BOooool6o`0004Gooooo0_l0000Fooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0D_ooool001;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01?ooooo0_l0002Hooooo`;o00005Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo057ooooo000Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
2_ooool2o`0001Cooooo0_l0000_ooooo`05oeEEEOnHV9Soooooooooooo<c<`00_l000000onHV9So
ooooooooo`1Sooooo`;o00005?ooool2o`0000_ooooo00?o0000ooooooooool0D?ooool001;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo
0_l0000booooo`05oeEEEOnHV9SooooooeEEEOn7QhL0JOooool2o`0001Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1?ooooo`004_ooool2o`0001cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Aooooo`;o0000=?ooool01Oo^k^ko<S8bolc<c?lQ8B7oc<c<00Co
oooo00?o<S8bo`000?l000000ol000001Olb<S;oooooooooooooooooV9RH00;o000000?oA4A4okZj
^_ooool04Oooool4o`000003oa0@4?oooooooooo03oooooo0_l0000Cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0C_ooool001;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`;o00004_ooool2o`0003Oooooo00?ok^k^oc8b<_l000001Oooool00onHV9So
A4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@okZj^_o^k^koMgMgoa0@400Doooo
o`03o`000?oooooooooo04?ooooo0_l0000Booooo`;o00002_ooool00ol0003oooooooooo`1=oooo
o`004_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool2o`0003[ooooo00?oZJVYoa0@4?o^k^h01Oooool01Ol@413ogMgMoooooooMgMgo410@
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`;o00004_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04cooooo000Booooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`;o0000??ooool01?mgMgOo
A4A4oc8b<_o^k^h4ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Oooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Boooool001;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07oooo
o`;o00004?ooool2o`0003kooooo00Co<S8bojVYZOnHV9SoEEEE1?ooool01Oo^k^ko410@onk^k_l@
413ok^k^00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`;o00004?oo
ool2o`0000Wooooo00?o0000ooooooooool0B_ooool001;ooooo00?o0000ooooooooool05Oooool2
o`0000Wooooo00?o0000ooooooooool03_ooool2o`0003kooooo00Oo<S8bo`000?lQ8B7ok^k^oooo
oonHV9SoEEEE00Cooooo00?oMgMgob4Q8OmEEED00oooool00ol@413o0000o`000003o`0001Gooooo
00?o0000ooooooooool0Boooool2o`00013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`19ooooo`004_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo0_l0
000?ooooo`;o0000Boooool00ooMgMgo0000omgMg@05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0COooool2o`0000oooooo0_l00008ooooo`;o0000BOooool001;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0001>
ooooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool05?ooool00omEEEGoIVIVo`00001A
ooooo`?o00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Kooooo000Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool2o`0000gooooo0ol00035oooo
o`?o00003?ooool2o`0000Sooooo00?o0000ooooooooool0AOooool001;ooooo0_l0000Booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3o`000<_ooooo0ol0000;ooooo`;o
00001oooool00ol0003oooooooooo`14ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Gooooo0_l0000:ooooo`?o0000dOooool3o`0000[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`13ooooo`004_ooool00ol0003oooooooooo`0>ooooo`;o00001ooo
ool00ol0003oooooooooo`07ooooo`?o0000eoooool3o`0000Sooooo0_l00006ooooo`;o0000@ooo
ool001;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`?o00001oooool3
o`000=gooooo0ol00007ooooo`;o00001_ooool00ol0003oooooooooo`10ooooo`004_ooool00ol0
003oooooooooo`0;ooooo`;o00001?ooool3o`0000Oooooo0ol0003Sooooo`?o00001_ooool2o`00
00Gooooo0_l00010ooooo`004_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooooooo
o`?o00001oooool3o`000>Wooooo0ol00005ooooo`;o00001Oooool00ol0003oooooooooo`0moooo
o`002Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool02?ooool2o`000004
ooooool0003o0000o`0000Gooooo1Ol0003_ooooo`Go00000_ooool3o`0000?ooooo0ol0000loooo
o`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo1Ol00003ooooo`Go
0000nOooool=o`0003[ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool<o`000?oooooo1?ooool;o`0003Oooooo000;ooooo`03o`000?oooooooooo00Cooooo2Ol0
003ooooooaCooooo2?l0000booooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooE?ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
oeCooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomDooooo`00
2Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0017ooooo00Co
8B4Qo`000?l0003oV9RHoooooomDooooo`004oooool00onj^[[o0000ooooo`3ooooooe?ooooo000@
ooooo`05oiRHV?l@413o0000o`000?nHV9P0oooooomDooooo`004?ooool00ol0003oZJVYooooo`3o
oooooeKooooo000@ooooo`03o`000?o^k^kooooo0?ooooooE_ooool0013ooooo00?oV9RHodA4A?oM
gMd0oooooomFooooo`004Oooool00onHV9So0000o`00003ooooooeGooooo000Aooooo`03o`000?o<
c<cooooo0?ooooooEOooool0017ooooo00Go410@ohN7Qoooooook^k^ofIVIP3ooooooe?ooooo000A
ooooo`05olc<c?m4A4Co0000o`000?nHV9P0oooooomCooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-0.407144, -3.22755, \
0.0270539, 0.0278675}}],

Cell["\<\
Fig. 6.6 Von Neumann stability analysis for the heat equation\
\>", \
"Caption",
  CellTags->"Fig. 6.6"],

Cell[TextData[{
  "From the figure, one can see that the most unstable wavenumber satisfies \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], "=", "\[Pi]"}], 
        TraditionalForm]]],
  ". For this wavenumber, Eq. ",
  ButtonBox["(6.2.8)",
    ButtonData:>{"Chapter6.nb", "(6.2.8)"},
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          RowBox[{"1", "-", 
            RowBox[{"4", " ", 
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]]}]}]}], 
        TraditionalForm]]],
  ", and the solution is stable for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi] \[GreaterEqual] \ \(-1. \)\)]],
  " This implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[Chi]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]], "\[LessEqual]", 
          " ", \(1\/2\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.9)"],

Cell[TextData[{
  " in order for the FTCS method to be stable.  This inequality is known as a \
",
  ButtonBox["Courant",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Courant.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " condition. The Courant condition sets a rather stringent limit on the \
maximum time step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " for a given value of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". For example, in  the problem solved in the previous section, we took ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1/4\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.1"}], 
        TraditionalForm]]],
  ", implying a maximum time step size given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.02"}], 
        TraditionalForm]]],
  ".  Thus, the first solution, with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.01"}], TraditionalForm]]],
  ", worked well, but the second solution, with ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          "\[CapitalDelta]",
          StyleBox["t ",
            FontSlant->"Italic"],
          "= 0.05"
        }]], TraditionalForm]]],
  ", violated the Courant condition and the method failed. \t"
}], "Text",
  CellTags->"i:65"]
}, Closed]],

Cell[CellGroupData[{

Cell["CTCS Method", "Section",
  CellTags->{"i:20", "c:17"}],

Cell[TextData[{
  "The FTCS method uses a forward-difference approximation for the time \
derivative, which is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". A higher-accuracy difference approximation to the time derivative would \
be preferable. One simple approach is the CTCS method, where both the time \
and space derivatives are center-differenced. For the heat equation, this \
corresponds to the difference equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%\(n + 1\)\), "=", 
          RowBox[{\(T\_j\%\(n - 1\)\), "+", 
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"2", "\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.10)"],

Cell[TextData[{
  "Unfortunately, however, von Neumann stability analysis of this equation \
leads us to the conclusion that the CTCS method is unstable for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " time step size. For, when we substitute in  ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n = \(\[Xi]\^n\) \[ExponentialE]\^\(\
\[ImaginaryI]\ k\ x\_j\)\)]],
  ", we obtain a quadratic equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\^2 + \[Alpha]\ \[Xi] - 1 \[Equal] 0\)]],
  ","
}], "NE2",
  CellTags->"(6.2.11)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Alpha]", "=", 
          RowBox[{
            FractionBox[
              RowBox[{"8", "\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{"k", " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
        TraditionalForm]]],
  ". The two solutions for \[Xi] are plotted in Cell ",
  ButtonBox["6.58",
    ButtonData:>"Cell 6.58",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol\  = 
        Solve[\[Xi]\^\(\(2\)\(\ \)\) + \[Alpha]\ \[Xi]\  - \ 1 \[Equal] 
            0, \[Xi]];\)\), "\n", 
    \(\(Plot[Evaluate[\[Xi] /. sol], {\[Alpha], 0, 1}, 
        AxesLabel \[Rule] {"\<\[Alpha]\>", "\<\[Xi]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.58"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.378492 0.224827 [
[.21429 .36599 -9 -9 ]
[.21429 .36599 9 0 ]
[.40476 .36599 -9 -9 ]
[.40476 .36599 9 0 ]
[.59524 .36599 -9 -9 ]
[.59524 .36599 9 0 ]
[.78571 .36599 -9 -9 ]
[.78571 .36599 9 0 ]
[.97619 .36599 -3 -9 ]
[.97619 .36599 3 0 ]
[1.025 .37849 0 -6 ]
[1.025 .37849 10 6 ]
[.01131 .04125 -24 -4.5 ]
[.01131 .04125 0 4.5 ]
[.01131 .15367 -12 -4.5 ]
[.01131 .15367 0 4.5 ]
[.01131 .26608 -24 -4.5 ]
[.01131 .26608 0 4.5 ]
[.01131 .49091 -18 -4.5 ]
[.01131 .49091 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .37849 m
.21429 .38474 L
s
[(0.2)] .21429 .36599 0 1 Mshowa
.40476 .37849 m
.40476 .38474 L
s
[(0.4)] .40476 .36599 0 1 Mshowa
.59524 .37849 m
.59524 .38474 L
s
[(0.6)] .59524 .36599 0 1 Mshowa
.78571 .37849 m
.78571 .38474 L
s
[(0.8)] .78571 .36599 0 1 Mshowa
.97619 .37849 m
.97619 .38474 L
s
[(1)] .97619 .36599 0 1 Mshowa
.125 Mabswid
.07143 .37849 m
.07143 .38224 L
s
.11905 .37849 m
.11905 .38224 L
s
.16667 .37849 m
.16667 .38224 L
s
.2619 .37849 m
.2619 .38224 L
s
.30952 .37849 m
.30952 .38224 L
s
.35714 .37849 m
.35714 .38224 L
s
.45238 .37849 m
.45238 .38224 L
s
.5 .37849 m
.5 .38224 L
s
.54762 .37849 m
.54762 .38224 L
s
.64286 .37849 m
.64286 .38224 L
s
.69048 .37849 m
.69048 .38224 L
s
.7381 .37849 m
.7381 .38224 L
s
.83333 .37849 m
.83333 .38224 L
s
.88095 .37849 m
.88095 .38224 L
s
.92857 .37849 m
.92857 .38224 L
s
.25 Mabswid
0 .37849 m
1 .37849 L
s
gsave
1.025 .37849 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .04125 m
.03006 .04125 L
s
[(-1.5)] .01131 .04125 1 0 Mshowa
.02381 .15367 m
.03006 .15367 L
s
[(-1)] .01131 .15367 1 0 Mshowa
.02381 .26608 m
.03006 .26608 L
s
[(-0.5)] .01131 .26608 1 0 Mshowa
.02381 .49091 m
.03006 .49091 L
s
[(0.5)] .01131 .49091 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .06373 m
.02756 .06373 L
s
.02381 .08622 m
.02756 .08622 L
s
.02381 .1087 m
.02756 .1087 L
s
.02381 .13118 m
.02756 .13118 L
s
.02381 .17615 m
.02756 .17615 L
s
.02381 .19863 m
.02756 .19863 L
s
.02381 .22111 m
.02756 .22111 L
s
.02381 .2436 m
.02756 .2436 L
s
.02381 .28856 m
.02756 .28856 L
s
.02381 .31104 m
.02756 .31104 L
s
.02381 .33353 m
.02756 .33353 L
s
.02381 .35601 m
.02756 .35601 L
s
.02381 .40097 m
.02756 .40097 L
s
.02381 .42346 m
.02756 .42346 L
s
.02381 .44594 m
.02756 .44594 L
s
.02381 .46842 m
.02756 .46842 L
s
.02381 .51339 m
.02756 .51339 L
s
.02381 .53587 m
.02756 .53587 L
s
.02381 .55835 m
.02756 .55835 L
s
.02381 .58084 m
.02756 .58084 L
s
.02381 .01877 m
.02756 .01877 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15367 m
.06244 .14906 L
.10458 .14393 L
.14415 .13901 L
.18221 .13419 L
.22272 .12897 L
.26171 .12384 L
.30316 .11829 L
.34309 .11284 L
.3815 .10752 L
.42237 .10175 L
.46172 .09611 L
.49955 .09061 L
.53984 .08465 L
.57861 .07884 L
.61984 .07256 L
.65954 .06644 L
.69774 .06046 L
.73838 .05402 L
.77751 .04774 L
.81909 .04099 L
.85916 .0344 L
.89771 .02798 L
.93871 .02109 L
.97619 .01472 L
s
.02381 .60332 m
.06244 .5988 L
.10458 .59399 L
.14415 .58956 L
.18221 .5854 L
.22272 .58106 L
.26171 .57699 L
.30316 .57275 L
.34309 .56877 L
.3815 .56503 L
.42237 .56114 L
.46172 .5575 L
.49955 .55407 L
.53984 .55051 L
.57861 .54718 L
.61984 .54372 L
.65954 .54047 L
.69774 .53743 L
.73838 .53428 L
.77751 .53132 L
.81909 .52826 L
.85916 .52539 L
.89771 .5227 L
.93871 .51992 L
.97619 .51744 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooolUooooo`Co00007?ooool0027ooooo0ol0
003ooooooaoooooo1_l0000Pooooo`008Oooool00ol0003oooooooooo`3ooooooaWooooo1_l0000V
ooooo`008Oooool00ol0003oooooooooo`3ooooooa;ooooo1ol0000/ooooo`008Oooool00ol0003o
ooooooooo`3oooooo`cooooo1_l0000cooooo`002?ooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooo`Ko
oooo1_l0000iooooo`002_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo1_l0000oooooo`001Ol00005ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3iooooo`Ko0000AOoo
ool000[ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000loooool6
o`0004_ooooo000:ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo0>cooooo1ol0001Aooooo`002_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0i_ooool6o`0005Sooooo000:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Pooooo`Ko
0000G_ooool000Sooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0
f_ooool6o`0006Cooooo000Qooooo`03o`000?oooooooooo0=?ooooo1ol0001Zooooo`008Oooool0
0ol0003oooooooooo`3=ooooo`Ko0000LOooool0027ooooo0ol00037ooooo`Ko0000Moooool0027o
oooo00?o0000ooooooooool0`Oooool6o`0007gooooo000Qooooo`03o`000?oooooooooo0;_ooooo
1_l00023ooooo`008Oooool00ol0003oooooooooo`2eooooo`Ko0000ROooool0027ooooo00?o0000
ooooooooool0[_ooool7o`0008oooooo000Qooooo`03o`000?oooooooooo0:Gooooo2Ol0002Foooo
o`008Oooool00ol0003oooooooooo`2Looooo`Wo0000Woooool0027ooooo0ol0002Eooooo`Oo0000
Z?ooool0027ooooo00?o0000ooooooooool0Soooool6o`000:oooooo000Qooooo`03o`000?oooooo
oooo08Wooooo1_l0002eooooo`008Oooool00ol0003oooooooooo`23ooooo`Ko0000^oooool0027o
oooo00?o0000ooooooooool0OOooool6o`000<7ooooo000Qooooo`03o`000?oooooooooo07Cooooo
2Ol00037ooooo`008Oooool00ol0003oooooooooo`1Zooooo`[o0000d?ooool0027ooooo0ol0001T
ooooo`Ko0000f_ooool0027ooooo00?o0000ooooooooool0G_ooool6o`000>3ooooo000Qooooo`03
o`000?oooooooooo05Sooooo1_l0003Vooooo`008Oooool00ol0003oooooooooo`1Booooo`Ko0000
k?ooool0027ooooo00?o0000ooooooooool0Boooool7o`000?;ooooo000Qooooo`03o`000?oooooo
oooo04;ooooo2Ol0003iooooo`008Oooool00ol0003oooooooooo`0iooooo`Wo0000ooooool3oooo
o`008Oooool3o`0003;ooooo1ol0003oooooo`cooooo000Qooooo`03o`000?oooooooooo02Wooooo
2Ol0003ooooooa?ooooo000Qooooo`03o`000?oooooooooo023ooooo2Ol0003ooooooacooooo000Q
ooooo`03o`000?oooooooooo01[ooooo1_l0003oooooobGooooo000Hooooo`Co000000?o410@oooo
ooooool00_ooool00ol0003oooooooooo`0@ooooo`[o0000ooooool[ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo2_l0003oooooocGooooo000?ooooo`Ko0000
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko0000ooooooloooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0?ooooooAOooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo02kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Gooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<02Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<033ooooo1?l00000
0ol@413oooooooooo`0Hooooo`008Oooool00ol0003oooooooooo`0^ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Vooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B409_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40<_oo
ool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0^ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Wooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000009_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^02Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B409_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oo
oooooooo02kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Gooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01[o
oooo000Qooooo`03o`000?oooooooooo02kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
02Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo02Sooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003ooooo
ooooo`0Jooooo`008Oooool3o`0002kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000booooo`03o`00
0?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@9_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0`ooooo`03oeEEEOmVIVKo000001cooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
oooooc_ooooo00OoV9RHo`000?l0003oEEEEonk^k_mVIVKo000000?ooooo000Qooooo`03o`000?oo
oooooooo0?oooooo>oooool01_l0003oZJVYoooooon7QhOo<S8bofIVIPCooooo000Qooooo`03o`00
0?oooooooooo0?oooooo>oooool01_l0003oooooooooooooooooQhN7odA4A0Cooooo000Joooooooo
0000>_l0000;ooooo`06ob4Q8Oo<c<cooooooooooonHV9So<S8b1?ooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00OoZJVYob4Q
8OoMgMgok^k^oc8b<_mEEEGo^[Zj00?ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Aooooo`06oiRHV?l0003o0000oiRHV?nj^[[o<S8b
0oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo8_ooool7o`0001cooooo000Q
ooooo`03o`000?oooooooooo0?oooooo5_ooool<o`0002?ooooo000Qooooo`03o`000?oooooooooo
0?oooooo2Oooool=o`0002oooooo000Qooooo`03o`000?oooooooooo0?cooooo3?l0000looooo`00
8Oooool00ol0003oooooooooo`3`ooooo`co0000B?ooool0027ooooo00?o0000ooooooooool0hooo
ool=o`0005Cooooo000Qooooo`?o0000eoooool<o`00067ooooo000Qooooo`03o`000?oooooooooo
0<[ooooo3Ol0001]ooooo`008Oooool00ol0003oooooooooo`2nooooo`co0000N_ooool0027ooooo
00?o0000ooooooooool0/_ooool<o`0008Kooooo000Qooooo`03o`000?oooooooooo0:Gooooo3Ol0
002Booooo`008Oooool00ol0003oooooooooo`2Iooooo`co0000Woooool0027ooooo00?o0000oooo
ooooool0S?ooool=o`000:_ooooo000Qooooo`?o0000P?ooool<o`000;Sooooo000Qooooo`03o`00
0?oooooooooo07Cooooo3?l00034ooooo`008Oooool00ol0003oooooooooo`1Zooooo`[o0000d?oo
ool0027ooooo00?o0000ooooooooool0I?ooool6o`000=[ooooo000Qooooo`03o`000?oooooooooo
05_ooooo2Ol0003Pooooo`008Oooool00ol0003oooooooooo`1?ooooo`co0000jOooool0027ooooo
00?o0000ooooooooool0@_ooool=o`000?Gooooo000Qooooo`?o0000>Oooool9o`000?oooooo0ooo
ool0027ooooo00?o0000ooooooooool0<_ooool7o`000?oooooo3?ooool0027ooooo00?o0000oooo
ooooool0:Oooool9o`000?oooooo4oooool0027ooooo00?o0000ooooooooool07Oooool<o`000?oo
oooo7?ooool0027ooooo00?o0000ooooooooool05?ooool9o`000?oooooo:?ooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00gooooo1ol0003ooooooc7ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool:o`000?oooooo>?ooool0
01[ooooo00?o0000ooooooooool01?ooool6o`000?oooooo@_ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008?ooool01?lQ
8B7o0000o`000?nHV9SoooooodGooooo000Rooooo`03okZj^_l0003ooooo0?ooooooA?ooool001oo
oooo00GoV9RHoa0@4?l0003o0000oiRHV03oooooodGooooo000Oooooo`03o`000?nYZJWooooo0?oo
ooooAoooool001oooooo00?o0000onk^k_ooool0oooooom7ooooo`007oooool00onHV9SoA4A4omgM
g@3oooooodOooooo000Pooooo`03oiRHV?l0003o00000?ooooooA_ooool0023ooooo00?o0000olc<
c?ooool0oooooom6ooooo`008?ooool01Ol@413oQhN7ooooooo^k^koIVIV0?ooooooA?ooool0023o
oooo00Goc<c<odA4A?l0003o0000oiRHV03oooooodCooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.114019, -1.72342, \
0.00420373, 0.0178073}}]
}, Open  ]],

Cell[TextData[{
  "One of the two solutions has ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(>\)\(1\)\)\)\)]],
  " for all possible ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " values, corresponding to all possible ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", so the CTCS method does not work for the heat equation. However, the \
CTCS method does work for other equations, such as the wave equation and the \
Schr\[ODoubleDot]dinger equation. (See the exercises.) "
}], "Text"],

Cell["\<\
\tA way to modify the CTCS method so that it works for the heat \
equation is discussed in the next sub-subsection.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lax Method", "Section",
  CellTags->{"i:21", "c:18"}],

Cell[TextData[{
  "Finding a stable, efficient algorithm for the solution of a PDE is \"more \
of an art than a science\", in the words of Press, Flannery, Teukolsky, and \
Vetterling (",
  ButtonBox["1992",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "). Nowhere is this more evident than in the Lax method. In this method, we \
make a seemingly trivial modification to the previous CTCS method for the \
heat equation, and completely change the equations stability properties. The \
change that we make is as follows: in the differenced  time derivative,\n",
  Cell[BoxData[
      FormBox[
        FractionBox[\(T\_j\%\(n + 1\) - T\_j\%\(n - 1\)\), 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]], TraditionalForm]]],
  ", we replace ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n - 1\)\)]],
  " by its average value from surrounding grid points: ",
  Cell[BoxData[
      FormBox[
        FractionBox[\(T\_j\%\(n + 1\) - \(1\/2\) \((T\_\(j + 1\)\%\(n - 1\) + 
                  T\_\(j - 1\)\%\(n - 1\))\)\), 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]], TraditionalForm]]],
  ". The resulting difference equation is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(T\_j\%\(n + 1\)\), "=", 
        RowBox[{\(\(1\/2\) \((T\_\(j + 1\)\%\(n - 1\) + 
                T\_\(j - 1\)\%\(n - 1\))\)\), "+", 
          RowBox[{"2", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
          RowBox[{
            FractionBox[
              RowBox[{"2", "\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                "2"]], \(\((T\_\(j + 1\)\%n - 2  T\_j\%n + 
                  T\_\(j - 1\)\%n)\)\(.\)\)}]}]}], TraditionalForm]]]], "NE2",\

  CellTags->"(6.2.12)"],

Cell[TextData[{
  "Von Neumann stability analysis of this equation leads to the following \
quadratic equation for the amplification factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Xi]\^2\), "+", " ", 
            RowBox[{"8", "\[Delta]", " ", 
              RowBox[{\(sin\^2\), "(", 
                RowBox[{"k", " ", 
                  RowBox[{
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "/", "2"}]}], ")"}], 
              "\[Xi]"}], "-", 
            RowBox[{"cos", " ", "k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], "=", "0"}], 
        TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ". This is the same as Eq. ",
  ButtonBox["(6.2.11)",
    ButtonData:>"(6.2.11)",
    ButtonStyle->"Hyperlink"],
  ", except that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"cos", " ", "k", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " replaces the constant term. But this makes a big difference .  The \
magnitude of the solution to this quadratic is plotted in Cell ",
  ButtonBox["6.59",
    ButtonData:>"Cell 6.59",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta] = 1/5\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol\  = 
        Solve[\[Xi]\^\(\(2\)\(\ \)\) + 
              8  \[Delta]\ Sin[\((k\ /2)\)]^2  \[Xi] - Cos[\ k]\  \[Equal] 
            0, \[Xi]];\)\), "\n", 
    \(\(Plot[
        Evaluate[Abs[\((\[Xi] /. sol)\)] /. \[Delta] \[Rule] 1/5], {k, 0, 
          2  Pi}, AxesLabel \[Rule] {"\<k\>", "\<|\[Xi]|\>"}, 
        PlotLabel \[Rule] \*"\"\<|\[Xi]|, for \[Chi] \[CapitalDelta]t/\!\(\
\[CapitalDelta]x\^2\)=1/5\>\""];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.59"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.0147151 0.588604 [
[.17539 .00222 -3 -9 ]
[.17539 .00222 3 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -3 -9 ]
[.47854 .00222 3 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -3 -9 ]
[.78169 .00222 3 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -11 0 ]
[.02381 .64303 11 12 ]
[.5 .63053 -64.7188 0 ]
[.5 .63053 64.7188 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(1)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(2)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(3)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(4)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(6)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\310) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\310) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -125.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.438 moveto
(\\310) show
69.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.438 moveto
(\\310) show
81.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
117.188 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
129.188 13.438 moveto
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.188 13.438 moveto
(\\220) show
147.188 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
159.188 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
164.438 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
176.438 13.438 moveto
(\\220) show
182.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
188.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60331 L
.02729 .6033 L
.02846 .60329 L
.03053 .60326 L
.03279 .60322 L
.03527 .60315 L
.0379 .60306 L
.04262 .60286 L
.04749 .6026 L
.05205 .60229 L
.06244 .60139 L
.07305 .60017 L
.08274 .59877 L
.10458 .59461 L
.12357 .58973 L
.14429 .58288 L
.16396 .57464 L
.18493 .56357 L
.20635 .54916 L
.22652 .5317 L
.24659 .50882 L
.26507 .47988 L
.2748 .4594 L
.28389 .43431 L
.28911 .41525 L
.29386 .39193 L
.29905 .34654 L
.30031 .3094 L
.30102 .31205 L
.30166 .31445 L
.30316 .31988 L
.30455 .32488 L
.31447 .35786 L
.32364 .38517 L
.3444 .43825 L
.36493 .48136 L
.38402 .51461 L
.40363 .54269 L
.42213 .56402 L
.44259 .58208 L
.45144 .58815 L
.46118 .59364 L
.4709 .59789 L
.47622 .59969 L
.48119 .60105 L
.48584 .60203 L
.49009 .60269 L
.49243 .60295 L
Mistroke
.49367 .60306 L
.49499 .60316 L
.49626 .60323 L
.4974 .60328 L
.49856 .60331 L
.49964 .60332 L
.50081 .60331 L
.50206 .60329 L
.50324 .60325 L
.50431 .6032 L
.50557 .60312 L
.50694 .60301 L
.50943 .60275 L
.51204 .60239 L
.5148 .60192 L
.51976 .60082 L
.52855 .59809 L
.53825 .59392 L
.54837 .58827 L
.55763 .58191 L
.5785 .56337 L
.59746 .54128 L
.61818 .51108 L
.63947 .47281 L
.65879 .43077 L
.67915 .37716 L
.68808 .34977 L
.69315 .33289 L
.69563 .32423 L
.69789 .31609 L
.699 .312 L
.7002 .33169 L
.70125 .3508 L
.7024 .36406 L
.70361 .37481 L
.70491 .38422 L
.70723 .39807 L
.71233 .42099 L
.71711 .4375 L
.72712 .46387 L
.73792 .4853 L
.75794 .5146 L
.77903 .53696 L
.79875 .55293 L
.81711 .56477 L
.83582 .57453 L
.85612 .58303 L
.87744 .59002 L
.89759 .59509 L
.91744 .5988 L
Mistroke
.92745 .60023 L
.93847 .60148 L
.94797 .60229 L
.95665 .60283 L
.96144 .60304 L
.96397 .60313 L
.96667 .6032 L
.968 .60323 L
.96926 .60326 L
.97048 .60328 L
.97161 .60329 L
.97268 .6033 L
.97381 .60331 L
.97494 .60332 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.02499 .6033 L
.02605 .60326 L
.02729 .60318 L
.02846 .60307 L
.03053 .6028 L
.03279 .60239 L
.03527 .60181 L
.0379 .60103 L
.04262 .59924 L
.04749 .59686 L
.05205 .59414 L
.06244 .58618 L
.07305 .57554 L
.08274 .56363 L
.10458 .52932 L
.14429 .4418 L
.18248 .32972 L
.22313 .18323 L
.24192 .10578 L
.25181 .06206 L
.25721 .03711 L
.25985 .02461 L
.261 .01908 L
.26226 .01642 L
.26357 .02287 L
.26482 .02904 L
.26757 .04285 L
.27341 .07336 L
.28367 .13266 L
.28875 .16654 L
.29153 .1874 L
.29415 .20947 L
.29875 .26283 L
.30003 .29335 L
.30074 .31102 L
.30139 .31343 L
.30384 .32233 L
.30853 .33861 L
.31367 .35535 L
.32402 .38625 L
.34253 .43389 L
.36333 .47829 L
.38251 .51219 L
.40238 .54107 L
.42097 .56283 L
.43974 .5799 L
.45033 .58744 L
.46038 .59323 L
.47008 .59758 L
Mistroke
.47521 .59938 L
.48066 .60092 L
.48571 .60201 L
.49028 .60271 L
.49249 .60296 L
.49365 .60306 L
.49488 .60315 L
.49595 .60321 L
.49713 .60327 L
.4982 .6033 L
.4992 .60331 L
.50047 .60332 L
.50111 .60331 L
.50181 .6033 L
.50306 .60326 L
.50422 .6032 L
.5056 .60312 L
.50685 .60302 L
.50968 .60272 L
.51199 .6024 L
.51451 .60197 L
.51959 .60086 L
.52425 .59955 L
.52922 .59784 L
.53816 .59397 L
.54843 .58823 L
.55955 .58045 L
.57971 .56211 L
.59963 .53843 L
.62068 .50698 L
.65862 .43118 L
.67811 .38017 L
.68896 .34689 L
.69374 .33085 L
.69646 .32127 L
.69779 .31644 L
.69901 .31193 L
.70017 .2862 L
.70138 .26062 L
.7026 .24351 L
.70394 .22821 L
.70917 .18192 L
.72023 .10904 L
.72526 .08057 L
.73065 .05198 L
.73326 .03865 L
.73572 .02633 L
.7368 .02103 L
.73794 .01547 L
.73919 .02001 L
Mistroke
.74034 .02554 L
.7782 .18845 L
.81851 .33294 L
.8573 .44589 L
.87702 .49267 L
.89854 .53485 L
.91915 .56611 L
.92834 .57707 L
.93827 .5868 L
.94361 .59111 L
.94852 .59451 L
.95312 .59719 L
.95816 .59958 L
.9627 .60122 L
.96693 .60233 L
.96927 .60277 L
.9714 .60305 L
.97258 .60317 L
.97386 .60326 L
.97507 .6033 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00C_ooool4o`000003oa0@4?oooooooooo02Kooooo1Ol0000Yooooo`05
oiRHV?l@413o0000oc8b<_o<c<`0:oooool2o`000003oa0@4?oooooooooo02Sooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Xooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0<?ooool0053ooooo00?o0000
ooooooooool0:?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Wooooo00Go410@okZj^_ooooooMgMg
oc8b<P0/ooooo`03o`000?oooooooooo02cooooo00?oMgMgoc8b<_ooool09oooool01OmEEEGoMgMg
oooooonHV9So8B4Q033ooooo001@ooooo`03o`000?oooooooooo02Wooooo00?oV9RHob4Q8Oo^k^h0
;_ooool00ol0003oooooooooo`0Wooooo`Go0000;_ooool00ol0003oooooooooo`0Vooooo`05o`00
0?ooooooooooooooool00000<?ooool0053ooooo00?o0000ooooooooool0:_ooool00onHV9So8B4Q
onk^kP0/ooooo`03ojVYZOl@413ooooo02Sooooo00CoA4A4omgMgOoooooo0000;_ooool00omgMgOo
<S8booooo`0Wooooo`05o`000?nHV9SooooooiRHV?lQ8B40<?ooool0053ooooo00?o0000oooooooo
ool0:oooool00omgMgOoIVIVooooo`0Zooooo`03oa0@4?l0003o^[Zj02Wooooo00CogMgMoeEEEOoo
oooo0000:oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Sooooo00Go0000oeEEEOl0003o410@olc<
c00`ooooo`00D?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o^[Zj
ob4Q8Oooool0:Oooool00omgMgOoc<c<o`00000[ooooo`03o`000?oooooooooo02[ooooo00?oEEEE
ohN7Qoooool0<_ooool0053ooooo00?o0000ooooooooool0:?ooool01Ol0003o^[ZjoooooonHV9So
410@02Wooooo00Go410@oiRHV?oooooo^[Zjo`00000Zooooo`03onk^k_m4A4Co000002_ooooo00?o
0000ooooooooool0:_ooool00ooMgMgo410@oiRHV00booooo`00C_ooool00omEEEGoIVIVo`00000Z
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:Oooool01OnYZJWo410@o`000?l@413oZJVY02_ooooo
00?oMgMgo`000?ooool0:_ooool4o`0002[ooooo00Coc<c<odA4A?l0003o410@<?ooool00?oooooo
JOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
oooooc?ooooo0_l00002ooooo`03oa0@4?l0003o000000_ooooo000Qooooo`03o`000?oooooooooo
0?oooooo=?ooool01Ol0003oooooonk^k_lb<S;oc<c<00cooooo000Qooooo`03o`000?oooooooooo
0?oooooo=?ooool01?l0003oV9RHoc8b<_o<c<`=ooooo`006_ooooooo`0003?o00002oooool00ol0
003o410@oiRHV00>ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00Co0000onk^k_mEEEGoQhN73Oooool0027ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01kooooo00Go0000oooo
oom4A4Co0000oa0@400<ooooo`008Oooool00ol0003oooooooooo`15ooooo`;o0000T?ooool2o`00
05[ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0AOooool2o`0008oo
oooo00?o0000ooooool00000F_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooo000008kooooo00?o0000ooooool00000FOooool2o`00013ooooo
000Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool00000S_ooool01?l0003ooooooooo
ool0001Zooooo`008Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000008kooooo00Co
0000oooooooooooo0000J_ooool0027ooooo00?o0000ooooooooool0AOooool01?l0003ooooooooo
ool0002=ooooo`04o`000?ooooooooooo`0006[ooooo000Qooooo`?o0000AOooool01?l0003ooooo
ooooool0002=ooooo`04o`000?ooooooooooo`0006[ooooo000Qooooo`03o`000?oooooooooo04Co
oooo00Go0000ooooooooooooooooo`00002<ooooo`05o`000?ooooooooooooooool00000J_ooool0
027ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo000008cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003oooooooooo`14oooo
o`05o`000?ooooooooooooooool00000S?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Oooooo000Qooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`00002<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool0027ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Wooooo`008Oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06Kooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
I_ooool0027ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`008Oooool3
o`0004;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0I_ooool0027ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Go
oooo000Qooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`26ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0027ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo000Qooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0I?ooool0027ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Tooooo`00
8Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Cooooo000Qooooo`?o0000@?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Tooooo`008Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06Cooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Hoooool0027o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Sooooo`008Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Poooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06?ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1S
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0H_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06;ooooo0007
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0H_ooool000Oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Qooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Qooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0HOooool0027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Qooooo`008Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0H?ooool0027ooooo0ol0000looooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
063ooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0H?ooool0027ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Oooooo`008Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0Goooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Ooooo
o`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1looooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Nooooo`008Oooool3o`0003Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0G_ooool0
027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Nooooo`008Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05gooooo000Qooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0GOooool0027ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Mooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05cooooo000Qoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Looooo`008Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo05cooooo000Qooooo`?o0000=oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo07[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Kooooo`008Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05[ooooo
000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F_ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Jooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0000eooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05Wooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0FOooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Hooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05So
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Oooooo000Qooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool0
027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`008Oooool3o`0003;o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Fooooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo000Q
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
EOooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo07Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Eooooo`008Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Cooooo000Qooooo`?o0000<?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo05Co
oooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Doooool0027ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Pooooo`;o0000Moooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool08?ooool2o`0007Kooooo0_l0000Rooooo`03o`000?oooooooooo05?ooooo000Qoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool08Oooool2o`0007Kooooo0_l0000Roooo
o`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooo`00001eooooo`03o`000?oooooo000002?ooooo00?o0000oooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Pooooo`04o`00
0?oooooo0000o`0007Cooooo00?o0000ooooool000008oooool00ol0003oooooooooo`1Booooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo
0000M?ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo05;ooooo000Qooooo`?o0000
;Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0007?ooooo0_l000000ooooooo
0000ooooo`0Sooooo`03o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool0001cooooo`04o`000?ooooooooooo`00
02Cooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooooooooooo
000002?ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooooooo
oooo000002Cooooo00?o0000ooooooooool0D?ooool0027ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000L_ooool01Ol0003ooooooooo
oooooooo000002Cooooo00?o0000ooooooooool0D?ooool0027ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0D?oo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;ooooo0_l0001_ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1?ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo04oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Gooooo0ol0000Zooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1>ooooo`001oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`04ooooo`;o0000KOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_ooool000Oooooo00Go410@
oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0C_oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0COooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo0_l0001[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1=ooooo`008Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1<ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1<ooooo`008Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1;ooooo`008Oooool3o`0002Oooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04_ooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`09ooooo`;o0000IOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0B_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0BOoo
ool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo0_l0001Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`18ooooo`008Oooool3o`0002Co
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04So
oooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`;o0000Goooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Aoooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo013ooooo0_l0001Mooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`17ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`16ooooo`00
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool2o`0005_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Cooooo`;o0000FOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0AOooool0
027ooooo0ol0000Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Fooooo`;o00005_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04Gooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`;o0000E_ooool2o`0001Sooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`13ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool05oooool2o`0005Cooooo0_l0000Jooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0@oooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool2o`0001_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`13ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool2o`0005;ooooo0_l0000L
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@_ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0Coooool2o`0001gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`12ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Kooooo`;o0000D?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0@Oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool3o`0001cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo04gooooo0_l0000Oooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0@Oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo043ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0@?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool08_ooool2o`0004[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03oooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
04Gooooo0_l0000Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0?_ooool0027o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0?Oooool0027ooooo0ol0000Hooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`008Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`11ooooo`;o0000;?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03cooooo000Q
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0]ooooo`;o0000@?ooool2o`0002oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`00
8Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo0_l0000cooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0cooooo`;o0000??ooool2o`0003Cooooo0_l0000Sooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0eooooo`;o0000>oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0>Oooool0027ooooo0ol0000Dooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`;o0000>?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Ko
oooo0_l0000jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=oooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`;o0000?Oooool00ol0003ooooo
ooooo`0dooooo`;o0000??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03;ooooo0_l0000nooooo`;o00008?ooool00ol0003ooooooooo
o`0fooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo0_l00011
ooooo`;o0000<_ooool2o`00047ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0e
ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@_ooool2o`00033ooooo0_l00013ooooo`;o00007_ooool00ol0003oooooooooo`0eoooo
o`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo0_l00016ooooo`;o
0000;_ooool2o`0004Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0dooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo0_l0001:ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Aoooool2o`0001gooooo00?o0000ooooooooool0
<oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`;o00007?oo
ool00ol0003oooooooooo`0booooo`008Oooool3o`0000gooooo00?o0000ooooooooool06Oooool2
o`0004oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1=ooooo`;o00006oooool0
0ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Sooooo0_l0001Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0D?ooool3o`00
01Wooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Fooooo`?o0000EOooool00ol0003oooooooooo`0Qooooo`;o0000E_ooool3o`0001Oo
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Dooooo`?o0000FOooool2o`00023ooooo0_l0001Jooooo`?o00005Oooool00ol0003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo0ol0
001Mooooo`;o00007_ooool00ol0003oooooooooo`1Mooooo`?o00004oooool00ol0003ooooooooo
o`0]ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo0ol0001Q
ooooo`Co00006Oooool2o`0006?ooooo0ol0000Aooooo`03o`000?oooooooooo02cooooo000Qoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool3o`0006Oooooo0ol0000Foooo
o`03o`000?oooooooooo06Kooooo0ol0000?ooooo`03o`000?oooooooooo02_ooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o00003?ooool5o`0006co
oooo0_l0000Cooooo`;o0000K?ooool5o`0000_ooooo00?o0000ooooooooool0:_ooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
2?l0001booooo`Co00003?ooool4o`0007?ooooo2?l00004ooooo`?o0000:Oooool001[ooooo00?o
0000ooooooooool01?ooool>o`0007kooooo3Ol0001nooooo`co00009?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00J?ooool00ol0003oooooooooo`03ooooo`04ob4Q8Ol0003o0000oiRHV0Gooooo00?o
0000ooooooooool00oooool00ol0003o^[Zjooooo`0Xooooo`05oeEEEOnHV9Soooooooooooo<c<`0
0_l000000onHV9Soooooooooo`2fooooo`00J?ooool00ol0003oooooooooo`05ooooo`03okZj^_l0
003ooooo00Cooooo00?o0000ooooooooool00oooool2oc8b<R[ooooo00GoEEEEoiRHV?ooooooEEEE
ohN7Q`0Jooooo`03ob4Q8OoMgMgooooo02Wooooo00?o8B4QomgMgOooool0LOooool006Sooooo00?o
0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oV9RH00Gooooo00?o0000ooooooooool0
0oooool00on7QhOo0000okZj^P0;ooooo`03oa0@4?l0003o000000;o000000Go410@oooooooooooo
k^k^oeEEE@02o`000004oeEEEOo^k^kooooooa0@40Go00002Oooool01Oo^k^ko<S8bolc<c?lQ8B7o
c<c<00Wooooo00?o<S8bo`000?l000000ol000001Olb<S;oooooooooooooooooV9RH00;o000000Ko
A4A4okZj^_oooooooooooiRHV?mEEED3ooooo`03oc8b<_l0003o000000?o000000?o<S8boooooooo
ool00_l00002ooooo`;o00004?ooool4o`000006oa0@4?oooooooooooooooonHV9SoEEEE1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM06Sooooo001Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ojVYZOooool01oooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00gooooo00?o0000
ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool0
2oooool00oo^k^ko<S8bo`00000:ooooo`03oiRHV?m4A4Cooooo00;ooooo00?oA4A4oiRHV?ooool0
0_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Ko0000omgMgOoooooooooooiRHV?m4A4@3
ooooo`0:odA4A?nHV9Soooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@Sooooo1_l00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000omgMgOooool01_ooool00omgMgOo<S8booooo`1Woooo
o`006_ooool00ol0003oooooooooo`03ooooo`04ob4Q8Ol0003o0000oiRHV0Gooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`02ooooo`03o`000?o^k^kooooo00Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ojVYZOl@413ok^k^00[ooooo00Go410@omgMgOoooooogMgMoa0@
4004ooooo`03o`000?oooooooooo00Gooooo0_mgMgL3ooooo`05oa0@4?oMgMgoooooomgMgOl@4100
1?ooool01?oMgMgo0000oa0@4?o<c<`Cooooo`03o`000?oooooooooo00Cooooo0_mgMgL8ooooo`03
o`000?oooooooooo06Kooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o^[Zjo`000?ooool0
1?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?oV9RHodA4A?oMgMd0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000kooooo00CoMgMgodA4A?lb<S;ok^k^2Oooool01On7
QhOoMgMgoooooomVIVKoQhN700Cooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP02
ooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool01?o^k^ko8B4Qoa0@4?o^k^h9ooooo`Ko0000
1?ooool00ol0003oooooooooo`04ooooo`03onk^k_l@413ok^k^00Kooooo00?oMgMgoc8b<_ooool0
Ioooool001[ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oV9RH00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`03ooooo`03oiRHV?l0003o000000Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooooooooomg
MgOoEEEE0oooool00ol0003o<S8bomgMg@0<ooooo`04oc8b<_nYZJWoV9RHoeEEE@Wooooo00Gok^k^
oa0@4?o^k^ko410@onk^kP04ooooo`03o`000?oooooooooo00Kooooo00WoEEEEoiRHV?oooooooooo
onk^k_l@413ok^k^oa0@4?o^k^h01?ooool01?lQ8B7oMgMgogMgMolb<S8Cooooo`03o`000?oooooo
oooo00Gooooo00?oEEEEoiRHV?ooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<06Sooooo000J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ojVYZOooool01oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00?ooooo00?o0000olc<c?ooool01_ooool00ol0003oooooooooo`0A
ooooo`03oa0@4?l0003o000000?o00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
0_l000001?nYZJWo8B4Qo`000?lQ8B48ooooo`07oc8b<_l0003o8B4Qonk^k_ooooooV9RHoeEEE@09
ooooo`03ogMgMolQ8B7oEEEE00?ooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413o
oooo00;ooooo00?oMgMgob4Q8OmEEED01?ooool2o`0000;ooooo1_l0000>ooooo`03o`000?oooooo
oooo00Gooooo00?ogMgMoa0@4?ooool00_ooool00ol0003oooooooooo`1Zooooo`006_ooool00ol0
003oooooooooo`02ooooo`03o`000?o^k^kooooo00Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`03ooooo`05oa0@4?n7QhOoooooonk^k_mVIVH01?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Wooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooooooo`07
ooooo`07oeEEEOnHV9SooooooooooooMgMgo0000omgMg@0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01_ooool01OmEEEGoV9RHoooooooooooo000006cooooo000Jooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHodA4A?oMgMd01oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00?ooooo00Goc<c<odA4A?l0003o0000oiRHV004ooooo`03o`000?oooooooooo01?o
oooo00?o410@okZj^_ooool0:_ooool00onYZJWoooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o^[ZjodA4A?ooool00_ooool00onYZJWoooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?oEEEEofIVI_l000002?ooool01?nj^[[oA4A4ooooooooool4o`0006Wooooo000Jooooo`03
o`000?oooooooooo00?ooooo00?oV9RHo`000?l000001_ooool00ol0003oooooooooo`1Qooooo`04
okZj^_l@413o0000oa0@44kooooo00?o0000ooooooooool0Q_ooool001[ooooo00?o0000oooooooo
ool00oooool00ol0003oc<c<ooooo`06ooooo`03o`000?oooooooooo0;3ooooo00Co0000oooooooo
oooo0000R?ooool001[ooooo00?o0000ooooooooool00oooool01Ol@413oQhN7ooooooo^k^koIVIV
00Cooooo00?o0000ooooooooool0/Oooool2o`0008Wooooo000Jooooo`03o`000?oooooooooo00?o
oooo00Goc<c<odA4A?l0003o0000oiRHV004ooooo`03o`000?oooooooooo0?oooooo?Oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.736113, -0.0840035, \
0.0270832, 0.00697441}}]
}, Open  ]],

Cell[TextData[{
  "For this value of \[Delta], one can see that the solution is stable since \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Xi]\)\(|\)\(\(\[LessEqual]\)\(\ \)\(1\)\)\
\)\)]],
  ".  In fact, by varying the value of \[Delta], one finds that the maximum \
possible value of \[Delta] is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(1/4\)\)\)]],
  ".  Thus, the Courant condition for Eq. ",
  ButtonBox["(6.2.12)",
    ButtonData:>{"Chapter6.nb", "(6.2.12)"},
    ButtonStyle->"Hyperlink"],
  " is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], "\[LessEqual]", 
        " ", \(1/4. \)}], TraditionalForm]]]], "NE2",
  CellTags->"(6.2.13)"],

Cell[TextData[{
  "\tThe Lax modification to the CTCS method has improved matters over the \
original FTCS method: the new method is now second-order accurate in both \
time and space. However,  the Courant condition of Eq. ",
  ButtonBox["(6.2.13)",
    ButtonData:>"(6.2.13)",
    ButtonStyle->"Hyperlink"],
  "  is still a rather stringent criterion for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", making this method impractical for real-world problems. It would be \
better if we could find a method that loosens this condition. One such method \
is discussed below."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit methods. The Crank-Nicolson algorithm.", "Section",
  CellTags->{"i:22", "c:19"}],

Cell[TextData[{
  "Problems that exhibit diffusive behavior, such as the heat equation,  are \
often best treated by ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " methods. As an example of an implicit method, take the FTCS method \
applied to the heat equation, Eq. ",
  ButtonBox["(6.2.5)",
    ButtonData:>"(6.2.5)",
    ButtonStyle->"Hyperlink"],
  ", and replace the forward-differenced time derivative with a ",
  "backward-difference",
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[PartialD]T/\[PartialD]t\)\( | \_\(t\_n\)\)\), "\[Rule]",
           " ", 
          RowBox[{\((T\_j\%n - T\_j\%\(n - 1\))\), "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " . Then the heat equation becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%n - T\_j\%\(n - 1\)\), "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_j\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\)\%n - 
                  2  T\_j\%n + T\_\(j - 1\)\%n)\)}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.14)"],

Cell[TextData[{
  "This algorithm could be called the BTCS (backward time centered space) \
method, but instead it is referred to as an ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " method. The reason is that Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " does not explicitly provide ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  ", given ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%\(n - 1\)\)]],
  ". Rather, since ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " now appears on both sides of Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  ", it provides a set of coupled linear equations for ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`T\_j\%n\)]]]], TraditionalForm]]],
  "which we must solve. This is as opposed to previous methods such as FTCS, \
where ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  "is given explicitly without needing to solve any equations. These previous \
methods are called ",
  StyleBox["explicit ",
    FontSlant->"Italic"],
  " methods."
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  "\tThe added complexity of Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  "  is offset by its superior stability properties. Von Neumann stability \
analysis applied to Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " yields the following amplification factor:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          SuperscriptBox[
            RowBox[{"[", 
              RowBox[{"1", "+", 
                RowBox[{"4", " ", "\[Delta]", " ", 
                  RowBox[{\(sin\^2\), "(", 
                    RowBox[{"k", " ", 
                      RowBox[{
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], "/", "2"}]}], 
                    ")"}]}]}], "]"}], \(-1\)]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}]}], TraditionalForm]]],
  ".  Thus, |",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi] | \(\(\[LessEqual]\)\(\ \)\(1\)\)\)]],
  " for any value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  ". This method is stable for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tHowever, the method is still only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", because of the backward time difference. A second-order method can now \
be easily obtained by taking the average of the ",
  "right-hand",
  " side in Eq. ",
  ButtonBox["(6.2.14)",
    ButtonData:>"(6.2.14)",
    ButtonStyle->"Hyperlink"],
  " between time steps ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_j\%n - T\_j\%\(n - 1\)\), "=", 
          RowBox[{\(1\/2\), "[", 
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], 
                " ", \((S\_j\%n + S\_j\%\(n - 1\))\)}], "+", 
              RowBox[{
                FractionBox[
                  RowBox[{"\[Chi]", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], 
                    "2"]], \((T\_\(j + 1\)\%n - 2  T\_j\%n + 
                    T\_\(j - 1\)\%n + T\_\(j + 1\)\%\(n - 1\) - 
                    2  T\_j\%\(n - 1\) + T\_\(j - 1\)\%\(n - 1\))\)}]}], 
            "]"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.16)"],

Cell[TextData[{
  "Now the right-hand and left-hand sides are both centered at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1/2\)]],
  ", so the time derivative is now second-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  Equation ",
  ButtonBox["(6.2.16)",
    ButtonData:>"(6.2.16)",
    ButtonStyle->"Hyperlink"],
  " is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Crank",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Crank.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" -",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Nicolson",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Nicolson.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  " scheme.  ",
  "Von",
  " Neumann analysis of this equation leads to the following amplification \
factor:"
}], "Text",
  CellTags->"i:23"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Xi]", "=", 
          FractionBox[
            RowBox[{"1", "-", 
              RowBox[{"2", " ", "\[Delta]", " ", 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], ")"}]}]}], 
            
            RowBox[{"1", "+", 
              RowBox[{"2", " ", "\[Delta]", " ", 
                RowBox[{\(sin\^2\), "(", 
                  RowBox[{"k", " ", 
                    RowBox[{
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "/", "2"}]}], 
                  ")"}]}]}]]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.17)"],

Cell[TextData[{
  "which also exhibits stability for any choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". The Crank-Nicolson method is an implicit scheme  that is very useful for \
solving linear problems with diffusive behavior. Below, we implement the \
Crank-",
  "Nicolson",
  " scheme in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell["\tFirst, we choose values for the parameters:", "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(L = 1; 
    M = 10; \[CapitalDelta]t = 0.05; \[CapitalDelta]x = L/M; \[Chi]\  = \ 
      1/4;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.60"],

Cell[TextData[{
  "Note the large time step size relative to the Courant condition for the \
FTCS  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.02"}], 
          ")"}], TraditionalForm]]],
  "or the CTCS-Lax ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "\[LessEqual]", " ", "0.01"}], 
          ")"}], TraditionalForm]]],
  " method. "
}], "Text"],

Cell["\<\
\tNext, we choose initial and boundary conditions, and a source \
term:\
\>", "Text"],

Cell[BoxData[{
    \(\(T0[x_]\  = \ Sin[Pi\ x/L]\  // N;\)\), "\n", 
    \(\(T[0, n_]\  := 0;\)\), "\n", 
    \(\(T[M, n_]\  := \ 0;\)\), "\n", 
    \(\(S[j_, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.61"],

Cell["\<\
These initial and boundary conditions correspond to a single \
Fourier mode, which should decay away according to\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \(\[ExponentialE]\^\(\(-\[Chi]\)\ \(\[Pi]\^2\) 
                t/\ L\^2\)\) sin\ \((\[Pi]\ x/L)\)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.18)"],

Cell[TextData[{
  "Now we solve Eq. ",
  ButtonBox["(6.2.16)",
    ButtonData:>"(6.2.16)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  ". This equation couples the different ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " values together, so we need to solve a set of linear equations. This can \
be easily done using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", particularly since the equations are \"sparse\" (most elements are \
zero), and the method of ",
  StyleBox["Gaussian elimination",
    FontSlant->"Italic"],
  " can be employed. (These details need not concern us; ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes care of them.  Those who wish to learn about Gaussian elimination \
and sparse-matrix solution techniques are referred to ",
  ButtonBox["Press et. al. (1992)",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  ", or any other book on basic numerical techniques.]"
}], "Text"],

Cell[TextData[{
  "\t  Since the output of ",
  StyleBox["Solve ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a list of substitutions, it is more convenient to write the recursion \
relation in terms of  this list of substitutions rather than ",
  Cell[BoxData[
      \(TraditionalForm\`T\_j\%n\)]],
  " itself .  To this end, we define  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sol", "[", 
          StyleBox["n",
            FontSlant->"Plain"], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "as this list of substitutions for the solution at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  StyleBox[". ",
    FontWeight->"Bold"],
  "For instance, the initial condition is given by the following list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol[0]\  = \ 
      Table[T[j, 0] \[Rule] \ T0[j\ \[CapitalDelta]x], {j, 1, 
          M - 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.62"],

Cell[BoxData[
    \({T[1, 0] \[Rule] 0.30901699437494745`, 
      T[2, 0] \[Rule] 0.5877852522924731`, 
      T[3, 0] \[Rule] 0.8090169943749475`, 
      T[4, 0] \[Rule] 0.9510565162951535`, T[5, 0] \[Rule] 1.`, 
      T[6, 0] \[Rule] 0.9510565162951536`, 
      T[7, 0] \[Rule] 0.8090169943749475`, 
      T[8, 0] \[Rule] 0.5877852522924732`, 
      T[9, 0] \[Rule] 0.30901699437494756`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that we need not add the end points to the list, since they are \
already determined by the boundary conditions. We can then write the \
Crank-Nicolson method as the following recursion relation on ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{\(sol[n_]\), " ", ":=", " ", 
      RowBox[{\(sol[n]\), " ", "=", " ", "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          RowBox[{\({vars, eqns}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*define\ the\ variables*) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", " ", 
            
            RowBox[{\(vars = \ Table[T[j, n], {j, 1, M - 1}]\), ";", " ", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*define\ the\ equations\ \((Eqs . \ 6  .2  .16)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{"eqns", "=", " ", 
                
                RowBox[{\(Table[
                    T[j, n] - 
                        T[j, n - 
                            1]\  == \(1\/2\) \((\[CapitalDelta]t\ \((S[j, 
                                    n] + S[j, 
                                    n - 1])\) + \(\(\[Chi]\ \
\[CapitalDelta]t\)\/\[CapitalDelta]x\^2\) \((T[j + 1, n] - 2  T[j, n] + 
                                  T[j - 1, n] + T[j + 1, n - 1] - 
                                  2  T[j, n - 1] + T[j - 1, n - 1])\))\), {j, 
                      1, M - 1}]\), 
                  StyleBox["/.",
                    FontColor->RGBColor[0, 0, 1]], 
                  StyleBox[\(sol[n - 1]\),
                    FontColor->RGBColor[0, 0, 1]]}]}], ";", 
              "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\(Solve[eqns, vars]\)[\([1]\)]\)}]}], 
          "]"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.63"],

Cell[TextData[{
  "The recursion comes about because ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " calls ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[\(n - 1\),
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ";",
  StyleBox[" ",
    FontWeight->"Bold"],
  " see the substitution command (in blue) in the definition of ",
  StyleBox["eqns",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". We can now evaluate the solution and animate the result. In Cell ",
  ButtonBox["6.64",
    ButtonData:>"Cell 6.64",
    ButtonStyle->"Hyperlink"],
  " we compare this solution with the exact solution, Eq. ",
  ButtonBox["(6.2.18)",
    ButtonData:>"(6.2.18)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = \ 
        Table[ListPlot[
            Table[{\[CapitalDelta]x\ j, \ T[j, n]}, {j, 0, M}] /. sol[n], 
            PlotJoined \[Rule] True, PlotRange \[Rule] {{0, L}, {0, 1}}, 
            AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
            PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
                ToString[\[CapitalDelta]t\ n], 
            DisplayFunction \[Rule] Identity], {n, 0, 40, 5}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ t/
                      L\^2\)\) Sin[Pi\ x/L], {x, 0, L}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] RGBColor[1, 0, 0]], {t, 0, 
            40\ \[CapitalDelta]t, 5\ \[CapitalDelta]t}];\)\ \), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.64"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .19098 L
.2 .36327 L
.3 .5 L
.4 .58779 L
.5 .61803 L
.6 .58779 L
.7 .5 L
.8 .36327 L
.9 .19098 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .07855 L
.08481 .16272 L
.12636 .23895 L
.16632 .30843 L
.20885 .37703 L
.2498 .43673 L
.29331 .49226 L
.33524 .53707 L
.37557 .57141 L
.39599 .58533 L
.41848 .59788 L
.43982 .60702 L
.44937 .61023 L
.4598 .61311 L
.46545 .6144 L
.4707 .61542 L
.47614 .6163 L
.48106 .61694 L
.48591 .61743 L
.48813 .6176 L
.49048 .61776 L
.49299 .61788 L
.4941 .61793 L
.4953 .61797 L
.49658 .618 L
.49778 .61802 L
.49852 .61803 L
.49921 .61803 L
.50051 .61803 L
.50171 .61803 L
.503 .61801 L
.50421 .61798 L
.50533 .61795 L
.50792 .61784 L
.51065 .61769 L
.51331 .61749 L
.51579 .61727 L
.52142 .61664 L
.53077 .61515 L
.54076 .61297 L
.55151 .60996 L
.56317 .6059 L
.58433 .59647 L
.6273 .56927 L
.66867 .53328 L
.70845 .49018 L
.75081 .43591 L
.79157 .37638 L
.83491 .30636 L
Mistroke
.87666 .23353 L
.91682 .15967 L
.95955 .07832 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`03ool00?l0003o00000?oo0000;_l000000ooo003oooooooooo`09oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03ool00?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Noooo
o`03o`000?oo003ooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ooo003o0000ooooo`09oooo
o`;o00000_ooool2o`0000Wooooo000Nooooo`03o`000?oo003ooooo0?oooooo;Oooool00ooo003o
ooooooooo`0Hooooo`007_ooool00ol0003oooooool0003oooooobcooooo00?oo`00ooooooooool0
6Oooool001kooooo00?o0000oooooooo0000ooooool/ooooo`03ool00?oooooooooo01Wooooo000N
ooooo`04o`000?ooooooooooool00?oooooo:_ooool00ooo003oooooooooo`0Jooooo`007_ooool0
1Ol0003oooooooooool0003oo`000?oooooo:Oooool00ooo003oooooooooo`0Jooooo`007_ooool0
1Ol0003oooooooooooooooooo`000?oooooo:?ooool00ooo003oooooooooo`0Kooooo`007_ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooo9?ooool00ol0003oo`00ooooo`0L
ooooo`007_ooool3o`0000;ooooo00?oo`00ooooooooool0oooooolTooooo`03ool00?oooooooooo
01cooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0oooooolRooooo`03
o`000?oo003ooooo01gooooo000Nooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
oooooolRooooo`03ool00?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o
o`00ooooooooool0oooooolPooooo`03o`000?oo003ooooo01kooooo000Nooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0oooooolPooooo`03ool00?oooooooooo01kooooo000Noooo
o`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0oooooolNooooo`03o`000?oo003ooooo
01oooooo000Nooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0oooooolNooooo`03
ool00?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
oooooolLooooo`03o`000?oo003ooooo023ooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool0oooooolLooooo`03ool00?oooooooooo023ooooo000Nooooo`?o00001oooool0
0ooo003oooooooooo`3ooooooa[ooooo00?o0000ool00?ooool08Oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oo`00ooooo`3ooooooa[ooooo00?oo`00ooooooooool08Oooool001ko
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`3ooooooaSooooo00?o0000ool00?oo
ool08_ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oo`00ooooo`3ooooooaSooooo
00?oo`00ooooooooool08_ooool001kooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`3ooooooaKooooo00?o0000ool00?ooool08oooool001kooooo00?o0000ooooooooool02_ooool0
0ooo003oooooooooo`3ooooooaCooooo00?o0000ool00?ooool09?ooool001kooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`3ooooooaCooooo00?o0000ool00?ooool09?ooool001ko
oooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo00?o0000ool00?oo
ool09Oooool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo
00?o0000ool00?ooool09Oooool001kooooo0ol0000<ooooo`03ool00?oooooooooo0?oooooo4?oo
ool00ol0003oo`00ooooo`0Vooooo`007_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo0?oooooo4?ooool00ol0003oo`00ooooo`0Vooooo`007_ooool00ol0003oooooooooo`0=oooo
o`03ool00?oooooooooo0?oooooo3_ooool00ol0003oo`00ooooo`0Wooooo`007_ooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo0?oooooo3_ooool00ol0003oo`00ooooo`0Wooooo`00
7_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo3?ooool00ol0003oo`00
ooooo`0Xooooo`007_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo3?oo
ool00ol0003oo`00ooooo`0Xooooo`007_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo0?oooooo2_ooool00ol0003oo`00ooooo`0Yooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo0?oooooo2_ooool00ol0003oo`00ooooo`0Yooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo0?oooooo2?ooool00ol0003oo`00ooooo`0Zooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?l0003ooooo0?oooooo1oooool00ol0003oo`00ooooo`0[ooooo`001?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`00017ooooo00?o
o`00ooooooooool0ooooool6ooooo`03o`000?oo003ooooo02_ooooo0004ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo017ooooo00?o
o`00o`000?ooool0ooooool5ooooo`03o`000?oo003ooooo02cooooo0004ooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o
o`00ooooooooool0ooooool4ooooo`03o`000?oo003ooooo02cooooo0004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
4_ooool00ooo003o0000ooooo`3oooooo`?ooooo00?o0000ool00?ooool0;Oooool000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`0Cooooo`03ool00?oooooooooo0?oooooo0_ooool00ol0003oo`00ooooo`0]ooooo`00
7_ooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo0?oooooo0Oooool00ol0003oo`00
ooooo`0^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo0?oooooo00?o
0000ool00?ooool0;_ooool001kooooo00?o0000ooooooooool05?ooool00ooo003o0000ooooo`3n
ooooo`03o`000?oo003ooooo02oooooo000Nooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0oOooool00ol0003oo`00ooooo`0_ooooo`007_ooool3o`0001Gooooo00?oo`00o`000?oo
ool0o?ooool00ol0003oo`00ooooo`0`ooooo`007_ooool00ol0003oooooooooo`0Fooooo`03ool0
0?oooooooooo0?_ooooo00?o0000ool00?ooool0<?ooool001kooooo00?o0000ooooooooool05_oo
ool00ooo003o0000ooooo`3jooooo`03o`000?oo003ooooo037ooooo000Nooooo`03o`000?oooooo
oooo01Oooooo00?oo`00ooooooooool0nOooool00ol0003oo`00ooooo`0aooooo`007_ooool00ol0
003oooooooooo`0Gooooo`03ool00?l0003ooooo0?Sooooo00?o0000ool00?ooool0<_ooool001ko
oooo00?o0000ooooooooool06?ooool00ooo003o0000ooooo`3fooooo`03o`000?ooooooo`0003?o
oooo000Nooooo`03o`000?oooooooooo01Sooooo00?oo`00o`000?ooool0m_ooool00ol0003oo`00
ooooo`0cooooo`007_ooool00ol0003oooooooooo`0Iooooo`03ool00?l0003ooooo0?Cooooo00?o
0000ool00?ooool0=?ooool001kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`3c
ooooo`03o`000?oo003ooooo03Cooooo000Nooooo`?o00006_ooool00ooo003o0000ooooo`3boooo
o`03o`000?oo003ooooo03Gooooo000Nooooo`03o`000?oooooooooo01_ooooo00?oo`00oooooooo
ool0lOooool00ol0003oo`00ooooo`0eooooo`007_ooool00ol0003oooooooooo`0Kooooo`03ool0
0?l0003ooooo0?3ooooo00?o0000ool00?ooool0=_ooool001kooooo00?o0000ooooooooool07?oo
ool00ooo003oooooooooo`3_ooooo`03ool00?oooooooooo03Kooooo000Nooooo`03o`000?oooooo
oooo01cooooo00?oo`00o`000?ooool0k_ooool00ol0003oo`00ooooo`0gooooo`007_ooool00ol0
003oooooooooo`0Mooooo`03ool00?oooooooooo0>gooooo00?oo`00ooooooooool0=oooool001ko
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`3[ooooo`03o`000?oo003ooooo03So
oooo000Nooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?ooool0j_ooool00ol0003oo`00
ooooo`0iooooo`007_ooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo0>Wooooo00?o
o`00ooooooooool0>Oooool001kooooo00?o0000ooooooooool07oooool00ooo003o0000ooooo`3X
ooooo`03o`000?oo003ooooo03[ooooo000Nooooo`?o00008?ooool00ooo003oooooooooo`3Woooo
o`03ool00?oooooooooo03[ooooo000Nooooo`03o`000?oooooooooo023ooooo00?oo`00o`000?oo
ool0i_ooool00ol0003oo`00ooooo`0kooooo`007_ooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo0>Gooooo00?oo`00ooooooooool0>oooool001kooooo00?o0000ooooooooool08Ooo
ool00ooo003o0000ooooo`3Tooooo`03ool00?oooooooooo03cooooo000Nooooo`03o`000?oooooo
oooo02;ooooo00?oo`00o`000?ooool0h_ooool00ol0003oo`00ooooo`0mooooo`007_ooool00ol0
003oooooooooo`0Sooooo`03ool00?oooooooooo0>7ooooo00?oo`00ooooooooool0?Oooool001ko
oooo00?o0000ooooooooool08oooool00ooo003o0000ooooo`3Pooooo`03o`000?oo003ooooo03ko
oooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0goooool00ooo003o
ooooooooo`0nooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ooo003o0000ooooo`3Nooooo`03
o`000?oo003ooooo03oooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Go
oooo0ol0000Uooooo`03ool00?l0003ooooo0=cooooo00?o0000ool00?ooool0@?ooool000Cooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooo
ooooool09Oooool00ooo003o0000ooooo`3Looooo`03o`000?oo003ooooo043ooooo0004ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooo
oooo02Kooooo00?oo`00o`000?ooool0f_ooool00ol0003oo`00ooooo`11ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`0W
ooooo`03ool00?oooooooooo0=Wooooo00?oo`00ooooooooool0@Oooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool09oooool0
0ooo003o0000ooooo`3Hooooo`03o`000?oo003ooooo04;ooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo02Sooooo00?oo`00
ooooooooool0eoooool00ooo003oooooooooo`12ooooo`007_ooool00ol0003oooooooooo`0Xoooo
o`03ool00?l0003ooooo0=Kooooo00?o0000ool00?ooool0@oooool001kooooo00?o0000oooooooo
ool0:Oooool00ooo003o0000ooooo`3Dooooo`03o`000?oo003ooooo04Cooooo000Nooooo`03o`00
0?oooooooooo02Wooooo00?oo`00o`000?ooool0e?ooool00ol0003oo`00ooooo`14ooooo`007_oo
ool00ol0003oooooooooo`0Zooooo`03ool00?l0003ooooo0=;ooooo00?o0000ool00?ooool0AOoo
ool001kooooo0ol0000[ooooo`03ool00?oooooooooo0=7ooooo00?o0000ool00?ooool0AOooool0
01kooooo00?o0000ooooooooool0:oooool00ooo003o0000ooooo`3@ooooo`03o`000?oo003ooooo
04Kooooo000Nooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0coooool00ol0003o
o`00ooooo`16ooooo`007_ooool00ol0003oooooooooo`0/ooooo`03ool00?l0003ooooo0<kooooo
00?o0000ool00?ooool0Aoooool001kooooo00?o0000ooooooooool0;Oooool00ooo003o0000oooo
o`3<ooooo`03o`000?oo003ooooo04Sooooo000Nooooo`03o`000?oooooooooo02gooooo00?oo`00
o`000?ooool0c?ooool00ol0003oo`00ooooo`18ooooo`007_ooool00ol0003oooooooooo`0^oooo
o`03ool00?l0003ooooo0<[ooooo00?o0000ool00?ooool0BOooool001kooooo00?o0000oooooooo
ool0;oooool00ooo003oooooooooo`39ooooo`03o`000?oo003ooooo04Wooooo000Nooooo`03o`00
0?oooooooooo02oooooo00?oo`00o`000?ooool0b?ooool00ol0003oo`00ooooo`1:ooooo`007_oo
ool3o`00033ooooo00?oo`00ooooooooool0aoooool00ol0003oo`00ooooo`1:ooooo`007_ooool0
0ol0003oooooooooo`0`ooooo`03ool00?l0003ooooo0<Kooooo00?o0000ool00?ooool0Boooool0
01kooooo00?o0000ooooooooool0<Oooool00ooo003o0000ooooo`34ooooo`03o`000?oo003ooooo
04cooooo000Nooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0`oooool00ol0003o
o`00ooooo`1<ooooo`007_ooool00ol0003oooooooooo`0booooo`03ool00?l0003ooooo0<;ooooo
00?o0000ool00?ooool0COooool001kooooo00?o0000ooooooooool0<oooool00ooo003ooooooooo
o`31ooooo`03o`000?oo003ooooo04gooooo000Nooooo`03o`000?oooooooooo03?ooooo00?oo`00
o`000?ooool0`?ooool00ol0003oo`00ooooo`1>ooooo`007_ooool00ol0003oooooooooo`0doooo
o`03ool00?l0003ooooo0;kooooo00?o0000ool00?ooool0Coooool001kooooo00?o0000oooooooo
ool0=Oooool00ooo003oooooooooo`2mooooo`03o`000?oo003ooooo04oooooo000Nooooo`?o0000
=Oooool00ooo003o0000ooooo`2looooo`03o`000?oo003ooooo053ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo00?oo`00ooooooooool0^oooool00ooo003oooooooooo`1@ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`03ool00?oooooooooo0;Wooooo00?o0000ool00?ooool0DOooool0
01kooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`2iooooo`03ool00?oooooooooo
057ooooo000Nooooo`03o`000?oooooooooo03Sooooo00?oo`00ooooooooool0]oooool00ol0003o
o`00ooooo`1Booooo`007_ooool00ol0003oooooooooo`0hooooo`03ool00?l0003ooooo0;Kooooo
00?o0000ool00?ooool0Doooool001kooooo00?o0000ooooooooool0>Oooool00ooo003ooooooooo
o`2eooooo`03ool00?oooooooooo05?ooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo03[ooooo
00?oo`00ooooooooool0/oooool00ol0003oo`00ooooo`1Dooooo`001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003o
ooooooooo`0jooooo`03ool00?oooooooooo0;?ooooo00?oo`00ooooooooool0E?ooool000Cooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0kooooo`03ool00?oooooooooo0;7ooooo00?o0000ool00?ooool0EOooool000Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool3
o`0003_ooooo00?oo`00o`000?ooool0/?ooool00ol0003oo`00ooooo`1Fooooo`001?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oo
oooooooo03cooooo00?oo`00o`000?ooool0[_ooool00ol0003oo`00ooooo`1Gooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003ooooooooo
o`0mooooo`03ool00?oooooooooo0:gooooo00?o0000ool00?ooool0Eoooool000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0?Ooo
ool00ooo003o0000ooooo`2/ooooo`03o`000?oo003ooooo05Sooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo03kooooo
00?oo`00o`000?ooool0Z_ooool00ol0003oo`00ooooo`1Iooooo`007_ooool00ol0003ooooooooo
o`0oooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool0FOooool001kooooo00?o0000
ooooooooool0?oooool00ooo003o0000ooooo`2Xooooo`03o`000?oo003ooooo05[ooooo000Noooo
o`03o`000?oooooooooo043ooooo00?oo`00o`000?ooool0Y_ooool00ol0003oo`00ooooo`1Koooo
o`007_ooool00ol0003oooooooooo`11ooooo`03ool00?l0003ooooo0:Cooooo00?o0000ool00?oo
ool0G?ooool001kooooo0ol00011ooooo`03ool00?l0003ooooo0:Cooooo00?o0000ool00?ooool0
G?ooool001kooooo00?o0000ooooooooool0@_ooool00ooo003o0000ooooo`2Rooooo`03o`000?oo
003ooooo05gooooo000Nooooo`03o`000?oooooooooo04?ooooo00?oo`00o`000?ooool0X?ooool0
0ol0003oo`00ooooo`1Nooooo`007_ooool00ol0003oooooooooo`13ooooo`03ool00?l0003ooooo
0:3ooooo00?oo`00ooooooooool0G_ooool001kooooo00?o0000ooooooooool0A?ooool00ooo003o
0000ooooo`2Nooooo`03o`000?oo003ooooo05oooooo000Nooooo`03o`000?oooooooooo04Gooooo
00?oo`00o`000?ooool0W?ooool00ol0003oo`00ooooo`1Pooooo`007_ooool00ol0003ooooooooo
o`15ooooo`03ool00?oooooo000009_ooooo00?o0000ool00?ooool0HOooool001kooooo00?o0000
ooooooooool0A_ooool00ooo003o0000ooooo`2Jooooo`03o`000?oo003ooooo067ooooo000Noooo
o`03o`000?oooooooooo04Oooooo00?oo`00o`000?ooool0V?ooool00ol0003oo`00ooooo`1Roooo
o`007_ooool3o`0004Oooooo00?oo`00ooooool00000Uoooool00ol0003oo`00ooooo`1Sooooo`00
7_ooool00ol0003oooooooooo`18ooooo`03ool00?l0003ooooo09Kooooo00?oo`00ooooooooool0
Hoooool001kooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`2Dooooo`03o`000?oo
003ooooo06Cooooo000Nooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooool00000Toooool0
0ol0003oo`00ooooo`1Uooooo`007_ooool00ol0003oooooooooo`1:ooooo`03ool00?oooooo0000
097ooooo00?o0000ool00?ooool0I_ooool001kooooo00?o0000ooooooooool0Boooool00ooo003o
0000ooooo`2@ooooo`03ool00?oooooooooo06Kooooo000Nooooo`03o`000?oooooooooo04cooooo
00?oo`00o`000?ooool0S_ooool00ol0003oo`00ooooo`1Wooooo`007_ooool00ol0003ooooooooo
o`1<ooooo`03ool00?oooooo000008gooooo00?o0000ool00?ooool0J?ooool001kooooo00?o0000
ooooooooool0COooool00ooo003o0000ooooo`2<ooooo`03ool00?oooooooooo06Sooooo000Noooo
o`03o`000?oooooooooo04kooooo00?oo`00o`000?ooool0R_ooool00ooo003oooooooooo`1Yoooo
o`007_ooool3o`0004oooooo00?oo`00o`000?ooool0R?ooool00ooo003oooooooooo`1Zooooo`00
7_ooool00ol0003oooooooooo`1@ooooo`03ool00?l0003ooooo08Kooooo00?o0000ool00?ooool0
Joooool001kooooo00?o0000ooooooooool0D?ooool00ooo003o0000ooooo`26ooooo`03ool00?oo
oooooooo06_ooooo000Nooooo`03o`000?oooooooooo057ooooo00?oo`00o`000?ooool0Q?ooool0
0ooo003oooooooooo`1/ooooo`007_ooool00ol0003oooooooooo`1Booooo`03ool00?l0003ooooo
08;ooooo00?oo`00ooooooooool0KOooool001kooooo00?o0000ooooooooool0Doooool00ooo003o
ooooooooo`21ooooo`03ool00?oooooooooo06gooooo000Nooooo`03o`000?oooooooooo05?ooooo
00?oo`00o`000?ooool0P?ooool00ooo003oooooooooo`1^ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`1Dooooo`03ool00?l0003ooooo07kooooo00?oo`00ooooooooool0Koooool000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Gooooo00?o0000ooooooooool0EOooool00ooo003o0000ooooo`1looooo`03ool00?oooooooooo
073ooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Gooooo0ol0001Fooooo`03ool00?oooooooooo07_ooooo00?oo`00ooooooooool0L?ooool0
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Ooo
ool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0LOoo
ool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1Oooool00ol0003oooooooooo`1Hooooo`03ool00?l0003ooooo07Kooooo00?o0000ool00?ooool0
Loooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`1Iooooo`03ool00?l0003ooooo07Cooooo00?o0000ool00?oo
ool0M?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001Oooool00ol0003oooooooooo`1Jooooo`03ool00?l0003ooooo07;ooooo00?o0000ool0
0?ooool0MOooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01Oooool00ol0003oooooooooo`1Kooooo`03ool00?l0003ooooo073ooooo00?o0000
ool00?ooool0M_ooool001kooooo00?o0000ooooooooool0G?ooool00ooo003o0000ooooo`1^oooo
o`03o`000?oo003ooooo07Oooooo000Nooooo`03o`000?oooooooooo05gooooo00?oo`00o`000?oo
ool0K?ooool00ol0003oo`00ooooo`1hooooo`007_ooool00ol0003oooooooooo`1Nooooo`03ool0
0?l0003ooooo06[ooooo00?o0000ool00?ooool0NOooool001kooooo00?o0000ooooooooool0Gooo
ool00ooo003o0000o`00001Wooooo`;o000000?oo`00ooooooooool0NOooool001kooooo0ol0001P
ooooo`03ool00?oooooo000006Gooooo00?o0000oooooooo0000O?ooool001kooooo00?o0000oooo
ooooool0HOooool00ooo003oooooo`00001Sooooo`03o`000?ooooooo`0007gooooo000Nooooo`03
o`000?oooooooooo06;ooooo00?oo`00ooooool00000HOooool00ol0003oo`00ool0001nooooo`00
7_ooool00ol0003oooooooooo`1Sooooo`;oo`0000?o0000ooooooooool0GOooool00ol0003oo`00
ooooo`1oooooo`007_ooool00ol0003oooooooooo`1Uooooo`03ool00?l0003ooooo05cooooo00?o
0000ool00?ooool0P?ooool001kooooo00?o0000ooooooooool0I_ooool00ooo003o0000o`00001I
ooooo`;o000000?oo`00ooooooooool0P?ooool001kooooo00?o0000ooooooooool0Ioooool00ooo
003oooooo`00001Gooooo`03o`000?ooooooo`0008?ooooo000Nooooo`03o`000?oooooooooo06So
oooo00?oo`00ooooool00000EOooool00ol0003oooooool00024ooooo`007_ooool00ol0003ooooo
ooooo`1Yooooo`03ool00?oooooo000005?ooooo00?o0000oooooooo0000QOooool001kooooo0ol0
001Zooooo`03ool00?oooooo0000057ooooo00?o0000oooooooo0000Q_ooool001kooooo00?o0000
ooooooooool0Joooool00ooo003oooooo`00001?ooooo`03o`000?ooooooo`0008Oooooo000Noooo
o`03o`000?oooooooooo06cooooo00?oo`00ooooool00000COooool00ol0003oooooool00028oooo
o`007_ooool00ol0003oooooooooo`1]ooooo`04ool00?oooooo0000o`0004Wooooo0_l000000ooo
ooooo`00ooooo`28ooooo`007_ooool00ol0003oooooooooo`1^ooooo`04ool00?ooooooooooo`00
04Oooooo00Co0000oooooooo003oo`00R_ooool001kooooo00?o0000ooooooooool0Koooool2ool0
0003ooooool0003ooooo04Cooooo00?o0000oooooooo0000S?ooool001kooooo00?o0000oooooooo
ool0LOooool2ool00003o`000?oooooooooo047ooooo00?o0000ool00?oo0000SOooool001kooooo
00?o0000ooooooooool0Loooool00ooo003o0000ooooo`10ooooo`;oo`00Soooool001kooooo00?o
0000ooooooooool0M?ooool2ool003oooooo00?oo`00ooooooooool0Soooool001kooooo0ol0001f
ooooo`;oo`00>oooool2ool009;ooooo000Nooooo`03o`000?oooooooooo07Oooooo00?o0000ool0
0?l00000=oooool2ool00003o`000?oooooooooo097ooooo000Nooooo`03o`000?oooooooooo07Wo
oooo0_oo0002o`00037ooooo0_l000000ooo003oooooooooo`2Dooooo`007_ooool00ol0003ooooo
ooooo`1kooooo`03ool00?oooooo000000;o0000:oooool3o`0000;oo`00Uoooool001kooooo00?o
0000ooooooooool0O?ooool3ool00003ooooool0003o000000;o00008oooool4o`0000?oo`00VOoo
ool001kooooo00?o0000ooooooooool0Ooooool3ool000;ooooo0ol0000Mooooo`?o00000_ooool2
ool009cooooo000Nooooo`03o`000?oooooooooo08;ooooo1?oo00001?oooooo0000o`000?l0000G
ooooo`?o00000oooool2ool009kooooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`26ooooo`?oo`0000?oooooo`000?l000000_l0000?ooooo`Co00000_ooool4ool0
0:3ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ROooool2ool000?o
oooo0ol00009ooooo`?o00000oooool3ool00:Cooooo000Gooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Roooool6ool000?o00000oooool3o`0000Koo`00Yoooool001Oooooo00?o
0000ooooooooool01?ooool3o`00097ooooo2Ooo002]ooooo`005oooool00ol0003oooooooooo`3o
ooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o0000oooooooo
ool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002L
ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2U
ooooo`00W?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04oooo
o`;o<S8bY_ooool009;ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0S_ooool009Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgN>ooooo`00U?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooo
oooooooooooo410@08kooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`2<ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000008kooooo002Aooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo
00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@4100S_ooool0
097ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2>ooooo`00TOooool7o`0000Cooooo0_l0000C
ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP2>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .10351 L
.2 .19688 L
.3 .27098 L
.4 .31856 L
.5 .33495 L
.6 .31856 L
.7 .27098 L
.8 .19688 L
.9 .10351 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .04239 L
.08481 .08781 L
.12636 .12895 L
.16632 .16644 L
.20885 .20346 L
.2498 .23568 L
.29331 .26564 L
.33524 .28983 L
.37557 .30836 L
.39599 .31587 L
.41848 .32264 L
.43982 .32757 L
.44937 .32931 L
.4598 .33086 L
.46545 .33155 L
.4707 .3321 L
.47614 .33258 L
.48106 .33293 L
.48591 .33319 L
.48813 .33328 L
.49048 .33337 L
.49299 .33344 L
.4941 .33346 L
.4953 .33348 L
.49658 .3335 L
.49778 .33351 L
.49852 .33351 L
.49921 .33352 L
.50051 .33352 L
.50171 .33351 L
.503 .3335 L
.50421 .33349 L
.50533 .33347 L
.50792 .33341 L
.51065 .33333 L
.51331 .33323 L
.51579 .33311 L
.52142 .33276 L
.53077 .33196 L
.54076 .33079 L
.55151 .32916 L
.56317 .32697 L
.58433 .32188 L
.6273 .3072 L
.66867 .28778 L
.70845 .26452 L
.75081 .23523 L
.79157 .20311 L
.83491 .16532 L
Mistroke
.87666 .12602 L
.91682 .08617 L
.95955 .04227 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`03ool00?l0003o00000?oo0000;_l000000ooo003oooooooooo`09oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oo003ooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Noooo
o`;o000000?oo`00ooooooooool0>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`03ool00?l0003ooooo
00Wooooo0_l00002ooooo`;o00002Oooool001kooooo00Co0000ooooool0003oo`00ooooool[oooo
o`03ool00?oooooooooo01Wooooo000Nooooo`05o`000?ooooooooooo`000?oo0000oooooolYoooo
o`03ool00?oooooooooo01[ooooo000Nooooo`06o`000?ooooooooooooooool0003oo`00oooooolW
ooooo`03ool00?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ool0
0?ooool0oooooolTooooo`03ool00?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?ooool0oooooolRooooo`03ool00?oooooooooo01gooooo000Nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ool00?ooool0oooooolPooooo`03ool00?oooooooooo01kooooo
000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0oooooolNooooo`03ool00?oo
oooooooo01oooooo000Nooooo`?o00001_ooool00ol0003oo`00ooooo`3ooooooacooooo00?oo`00
ooooooooool08?ooool001kooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`3ooooo
oa[ooooo00?oo`00ooooooooool08Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003o
o`00ooooo`3ooooooaSooooo00?oo`00ooooooooool08_ooool001kooooo00?o0000ooooooooool0
2Oooool00ol0003oo`00ooooo`3ooooooaKooooo00?oo`00ooooooooool08oooool001kooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`3ooooooaCooooo00?oo`00ooooooooool09?oo
ool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3ooooooa;ooooo00?oo`00
ooooooooool09Oooool001kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`3ooooo
oa3ooooo00?oo`00ooooooooool09_ooool001kooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`3oooooo`kooooo00?oo`00ooooooooool09oooool001kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`3oooooo`cooooo00?oo`00ooooooooool0:?ooool001kooooo0ol0
000?ooooo`03ool00?oooooooooo0?oooooo2_ooool00ooo003oooooooooo`0Yooooo`007_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0?oooooo2?ooool00ooo003oooooooooo`0Z
ooooo`007_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0?oooooo1_ooool00ooo
003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo0?oo
oooo1?ooool00ooo003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooooooo0?oooooo0_ooool00ooo003oooooooooo`0]ooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`03ool00?oooooooooo0?oooooo00?oo`00ooooooooool0;_ooool001kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`3mooooo`03ool00?oooooooooo02oooooo000Noooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0n_ooool2ool003;ooooo000Nooooo`03
o`000?oooooooooo01Oooooo0_oo003iooooo`03ool00?l0003ooooo03;ooooo000Nooooo`?o0000
6?ooool00ol0003oo`00ooooo`3fooooo`03ool00?l0003ooooo03?ooooo000Nooooo`03o`000?oo
oooooooo01Wooooo00?o0000ool00?ooool0m?ooool00ooo003o0000ooooo`0dooooo`007_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oo003ooooo0?;ooooo00?oo`00o`000?ooool0=Oooool0
01kooooo00?o0000ooooooooool06oooool00ol0003oo`00ooooo`3`ooooo`03ool00?l0003ooooo
03Kooooo000Nooooo`03o`000?oooooooooo01cooooo00?o0000ool00?ooool0k_ooool00ooo003o
0000ooooo`0gooooo`007_ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0>_ooooo
00?oo`00ooooooooool0>?ooool001kooooo00?o0000ooooooooool07oooool00ooo003ooooooooo
o`3Yooooo`03ool00?oooooooooo03Wooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0iooo
ool00ooo003oooooooooo`0jooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo0>Gooooo00?oo`00ooooooooool0>oooool000Cooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool08_ooool00ooo003ooooo
ooooo`3Sooooo`03ool00?oooooooooo03cooooo0004ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP05ooooo`?o00008oooool00ooo003oooooooooo`3Qooooo`03ool0
0?oooooooooo03gooooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0goooool00ooo003ooooo
ooooo`0nooooo`001?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo0=gooooo00?oo`00ooooooooool0
?oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo0=_ooooo00?oo`00oooooooo
ool0@?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo0=Wooooo00?oo`00oooo
ooooool0@Oooool001kooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`3Gooooo`03
ool00?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool0
eOooool00ooo003oooooooooo`13ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03ool00?oo
oooooooo0=?ooooo00?oo`00ooooooooool0A?ooool001kooooo00?o0000ooooooooool0:oooool0
0ooo003o0000ooooo`3@ooooo`03o`000?oo003ooooo04Kooooo000Nooooo`?o0000;?ooool00ooo
003o0000ooooo`3>ooooo`03o`000?oo003ooooo04Oooooo000Nooooo`03o`000?oooooooooo02go
oooo00?oo`00o`000?ooool0c?ooool00ol0003oo`00ooooo`18ooooo`007_ooool00ol0003ooooo
ooooo`0^ooooo`03ool00?l0003ooooo0<[ooooo00?o0000ool00?ooool0BOooool001kooooo00?o
0000ooooooooool0;oooool00ooo003o0000ooooo`38ooooo`;oo`00Boooool001kooooo00?o0000
ooooooooool0<?ooool2ool00<Oooooo00?oo`00ooooooooool0Boooool001kooooo00?o0000oooo
ooooool0<_ooool00ooo003oooooooooo`33ooooo`03ool00?oooooooooo04cooooo000Nooooo`03
o`000?oooooooooo03?ooooo00?oo`00ooooooooool0`Oooool00ooo003oooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`0dooooo`03ool00?oooooooooo0;oooooo00?oo`00ooooooooool0
C_ooool001kooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`2mooooo`03ool00?oo
oooooooo04oooooo000Nooooo`?o0000=_ooool2ool00;cooooo00?oo`00ooooooooool0D?ooool0
01kooooo00?o0000ooooooooool0=oooool00ol0003oo`00ooooo`2iooooo`03ool00?oooooooooo
057ooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ool00?ooool0]oooool00ooo003o
ooooooooo`1Booooo`007_ooool00ol0003oooooooooo`0iooooo`03o`000?oo003ooooo0;Gooooo
00?oo`00ooooooooool0Doooool001kooooo00?o0000ooooooooool0>_ooool00ol0003oo`00oooo
o`2booooo`03o`000?oo003ooooo05Gooooo000Nooooo`03o`000?oooooooooo03cooooo00?oo`00
ooooooooool0[oooool00ol0003oo`00ooooo`1Fooooo`007_ooool00ol0003oooooooooo`0moooo
o`;oo`00[_ooool2ool005Sooooo000Nooooo`03o`000?oooooooooo03kooooo00?o0000ool00?oo
ool0Z_ooool00ol0003oo`00ooooo`1Iooooo`007_ooool00ol0003oooooooooo`10ooooo`03ool0
0?oooooooooo0:Oooooo00?o0000ool00?ooool0F_ooool001kooooo00?o0000ooooooooool0@Ooo
ool00ooo003o0000ooooo`2Tooooo`03o`000?oo003oo`0005cooooo000Nooooo`?o0000@_ooool0
0ooo003o0000ooooo`2Rooooo`03o`000?oo003ooooo05gooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_oo002Qooooo`03o`000?oo003ooooo05kooooo000Nooooo`03o`000?oooooooooo04Go
oooo00?oo`00o`000?ooool0W?ooool2o`000003ool00?oooooooooo05kooooo000Nooooo`03o`00
0?oooooooooo04Kooooo00?oo`00o`000?ooool0V_ooool00ol0003oo`00ool0001Qooooo`007_oo
ool00ol0003oooooooooo`17ooooo`03ool00?l0003ooooo09Sooooo00?o0000ool00?ooool0H_oo
ool001kooooo00?o0000ooooooooool0B?ooool00ooo003o0000o`00002Eooooo`;o000000?oo`00
ooooooooool0H_ooool001kooooo00?o0000ooooooooool0BOooool2ool00003o`000?oooooooooo
097ooooo00?o0000ool00?oo0000IOooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Boooool00ooo
003o0000ooooo`2@ooooo`03o`000?oo003ooooo06Kooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1<oooo
o`;oo`0000?o0000ooooooooool0Roooool00ol0003oo`00ool0001Xooooo`001?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000C_ooool00ooo003o0000ooooo`2:oooo
o`;oo`00J_ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?o0000ooooooooool0Coooool2ool00003o`000?oooooooooo08Gooooo00?o0000
ool00?ooool0Joooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Kooooo00?o0000ooooooooool0DOooool00ooo003o0000ooooo`24ooooo`;oo`00KOoo
ool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o
0000ooooooooool0D_ooool00ooo003o0000ooooo`21ooooo`;oo`00Koooool000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0Dooo
ool2ool00003o`000?oooooooooo07gooooo00?oo`00o`000?ooool0Koooool000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0EOoo
ool00ooo003o0000ooooo`1kooooo`;oo`00L_ooool001kooooo00?o0000ooooooooool0E_ooool2
ool007Wooooo0_oo00000ol0003oooooooooo`1aooooo`007_ooool00ol0003oooooooooo`1Hoooo
o`;oo`00M_ooool00ooo003o0000o`00001dooooo`007_ooool00ol0003oooooooooo`1Jooooo`;o
o`00L_ooool2ool00003o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo05cooooo
0_oo001^ooooo`;oo`0000?o0000ooooooooool0M_ooool001kooooo0ol0001Nooooo`03ool00?l0
003ooooo06[ooooo00?oo`00o`000?ooool0NOooool001kooooo00?o0000ooooooooool0Goooool2
ool00003o`000?oooooooooo06Gooooo0_oo001looooo`007_ooool00ol0003oooooooooo`1Qoooo
o`;oo`0000?o0000ooooooooool0HOooool2ool007kooooo000Nooooo`03o`000?oooooooooo06?o
oooo0_oo00000ol0003oooooooooo`1Mooooo`;oo`00P?ooool001kooooo00?o0000ooooooooool0
IOooool2ool000;o0000FOooool00ol0003oo`00ool00022ooooo`007_ooool00ol0003ooooooooo
o`1Wooooo`;oo`000_l0001Eooooo`03o`000?oo003oo`0008Cooooo000Nooooo`03o`000?oooooo
oooo06Wooooo0_oo0002o`00057ooooo00?o0000ool00?oo0000Q_ooool001kooooo00?o0000oooo
ooooool0Joooool2ool000;o0000COooool00ol0003oo`00ool00028ooooo`007_ooool00ol0003o
ooooooooo`1]ooooo`;oo`000_l00019ooooo`03o`000?oo003oo`0008[ooooo000Nooooo`?o0000
Koooool3ool00003o`000?oooooooooo04?ooooo0ooo002<ooooo`007_ooool00ol0003ooooooooo
o`1booooo`?oo`00@?ooool3ool008oooooo000Nooooo`03o`000?oooooooooo07Gooooo1?oo000j
ooooo`;oo`0000?o0000ooooooooool0Soooool001kooooo00?o0000ooooooooool0Moooool2o`00
00?oo`00=?ooool3ool00003o`000?oooooooooo097ooooo000Nooooo`03o`000?oooooooooo07_o
oooo00Co0000ool00?oo003oo`000_l0000Yooooo`;o00001?oo002Gooooo`007_ooool00ol0003o
ooooooooo`1oooooo`?oo`001Ol0000Mooooo`?o00001Ooo002Kooooo`007_ooool00ol0003ooooo
ooooo`22ooooo`Ooo`001?l0000Aooooo`Go00001?oo002Pooooo`007_ooool00ol0003ooooooooo
o`29oooooa[oo`00Y?ooool001kooooo00?o0000ooooooooool0Toooool5o`000:oooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
B?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8
ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0003o
ooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o
0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003ooooo
ofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM083ooooo0028ooooo`03o`000?oo
oooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool0
0oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooooooo
o`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0O_ooool008Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo07oooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0P?ooool008Gooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@
o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08;ooooo0025ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0P_ooool008Gooooo
1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003ooooo
ooooo`0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00021ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .0561 L
.2 .1067 L
.3 .14686 L
.4 .17265 L
.5 .18153 L
.6 .17265 L
.7 .14686 L
.8 .1067 L
.9 .0561 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .02288 L
.08481 .04739 L
.12636 .06958 L
.16632 .08982 L
.20885 .1098 L
.2498 .12718 L
.29331 .14335 L
.33524 .1564 L
.37557 .1664 L
.39599 .17046 L
.41848 .17411 L
.43982 .17677 L
.44937 .17771 L
.4598 .17855 L
.46545 .17892 L
.4707 .17922 L
.47614 .17947 L
.48106 .17966 L
.48591 .1798 L
.48813 .17985 L
.49048 .1799 L
.49299 .17994 L
.4941 .17995 L
.4953 .17996 L
.49658 .17997 L
.49778 .17998 L
.49852 .17998 L
.49921 .17998 L
.50051 .17998 L
.50171 .17998 L
.503 .17997 L
.50421 .17996 L
.50533 .17995 L
.50792 .17992 L
.51065 .17988 L
.51331 .17982 L
.51579 .17976 L
.52142 .17957 L
.53077 .17914 L
.54076 .17851 L
.55151 .17763 L
.56317 .17645 L
.58433 .1737 L
.6273 .16578 L
.66867 .1553 L
.70845 .14275 L
.75081 .12694 L
.79157 .10961 L
.83491 .08921 L
Mistroke
.87666 .06801 L
.91682 .0465 L
.95955 .02281 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`;oo`00ool0000^o`0000;oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool01?l0003oooooool00?oo000<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0_oo0000
0ooooooo0000ooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo000Nooooo`04o`000?oooooo
ooooooooo`;oo`00=oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0eooooo`03o`000?oo003ooooo00;ooooo00?o
0000ooooooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`03
ooooo`;oo`00oooooolSooooo`;oo`007_ooool001kooooo00?o0000ooooooooool01?ooool00ol0
003oo`00ooooo`3ooooooaoooooo0_oo000Pooooo`007_ooool00ol0003oooooooooo`06ooooo`;o
o`00oooooolLooooo`03o`000?oo003ooooo027ooooo000Nooooo`03o`000?oooooooooo00Sooooo
0_oo003ooooooaSooooo00?o0000ool00?oo00008oooool001kooooo00?o0000ooooooooool02_oo
ool2ool00?oooooo5?ooool00ol0003oo`00ool0000Uooooo`007_ooool00ol0003oooooooooo`0<
ooooo`03ool00?l0003ooooo0?oooooo3oooool00ol0003oo`00ool0000Wooooo`007_ooool00ol0
003oooooooooo`0=ooooo`;oo`00ooooool>ooooo`;oo`00:Oooool001kooooo0ol0000?ooooo`;o
o`00ooooool:ooooo`;oo`00:oooool001kooooo00?o0000ooooooooool04Oooool00ooo003o0000
ooooo`3oooooo`Gooooo00?o0000ool00?ooool0;?ooool001kooooo00?o0000ooooooooool04_oo
ool2ool00003o`000?oooooooooo0?oooooo00?o0000ool00?oo0000;_ooool001kooooo00?o0000
ooooooooool05?ooool2ool00003o`000?oooooooooo0?_ooooo00?o0000ool00?oo0000<?ooool0
01kooooo00?o0000ooooooooool05_ooool00ooo003o0000ooooo`3jooooo`;oo`00<_ooool001ko
oooo00?o0000ooooooooool05oooool2ool00003o`000?oooooooooo0?Gooooo0_oo000dooooo`00
7_ooool00ol0003oooooooooo`0Iooooo`;oo`0000?o0000ooooooooool0lOooool2ool003Kooooo
000Nooooo`03o`000?oooooooooo01_ooooo0_oo00000ol0003oooooooooo`3]ooooo`;oo`00>?oo
ool001kooooo00?o0000ooooooooool07Oooool3ool00>_ooooo00?o0000ool00?ooool0>Oooool0
01kooooo0ol0000Pooooo`;oo`00ioooool00ol0003oo`00ool0000kooooo`007_ooool00ol0003o
ooooooooo`0Rooooo`;oo`00hoooool00ol0003oo`00ool0000mooooo`007_ooool00ol0003ooooo
ooooo`0Tooooo`;oo`00h?ooool2ool003oooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ool00?oo0000g?ooool2ool0047ooooo000Nooooo`03o`000?oooooooooo02Oooooo00?o0000
ool00?oo0000f?ooool2ool004?ooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ool0
0?oo0000e?ooool2ool004Gooooo000Nooooo`03o`000?oooooooooo02_ooooo00?o0000ool00?oo
0000d?ooool2ool004Oooooo000Nooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo0000
c?ooool2ool004Wooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ool00?oo0000b?oo
ool2ool004_ooooo000Nooooo`?o0000<Oooool00ol0003oo`00ool00034ooooo`;oo`00COooool0
01kooooo00?o0000ooooooooool0<oooool00ol0003oo`00ool00030ooooo`;oo`00Coooool001ko
oooo00?o0000ooooooooool0=?ooool2o`0000?oo`00^_ooool3ool00003o`000?oooooooooo04ko
oooo000Nooooo`03o`000?oooooooooo03Kooooo0_l000000oooooooo`00ool0002fooooo`;oo`00
0_l0001Booooo`007_ooool00ol0003oooooooooo`0hooooo`;o000000?oooooool00?oo0000/_oo
ool2ool000;o0000E?ooool001kooooo00?o0000ooooooooool0>_ooool2o`000003oooooooo003o
o`000:kooooo0_oo0002o`0005Kooooo000Nooooo`03o`000?oooooooooo03cooooo0ol00002ool0
0:[ooooo0_oo0002o`0005Sooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00005ooooo`03o`000?oooooooooo03oooooo0_l00002ool00:Kooooo0_oo00000ol0
003oooooooooo`1Iooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`11ooooo`;o00000_oo002Q
ooooo`?oo`0000?o0000ooooooooool0Foooool000Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0A?ooool00ol0003oo`00ool0002M
ooooo`;oo`0000?o0000ooooooooool0G_ooool000Cooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol00016ooooo`03o`000?oo003oo`0009Wooooo0_oo0000
0ol0003oooooooooo`1Pooooo`001?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool01?ooool00ol0003oooooooooo`19ooooo`;oo`00U?ooool3ool006Gooooo0004oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04_ooooo0ooo002>ooooo`?oo`0000?o0000ooooooooool0IOooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooooooo
o`1>ooooo`?oo`00R?ooool3ool00003o`000?oooooooooo06Sooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
D?ooool00ol0003oo`00ool00023ooooo`?oo`000_l0001/ooooo`007_ooool00ol0003ooooooooo
o`1Cooooo`?oo`00OOooool3ool000;o0000Koooool001kooooo00?o0000ooooooooool0EOooool0
1?l0003oo`00ool00?oo001gooooo`?oo`000ol0001aooooo`007_ooool00ol0003oooooooooo`1H
ooooo`04o`000?oo003oo`00ool0077ooooo0ooo0003o`0007Cooooo000Nooooo`03o`000?oooooo
oooo05_ooooo00Co0000ool00?oo003oo`00Joooool3ool000?o0000Moooool001kooooo0ol0001O
ooooo`?oo`0000?o0000ooooooooool0HOooool4ool000;o0000Noooool001kooooo00?o0000oooo
ooooool0H_ooool4ool00003o`000?oooooooooo05Wooooo1?oo0002o`0007oooooo000Nooooo`03
o`000?oooooooooo06Kooooo1?oo001Dooooo`Coo`000_l00023ooooo`007_ooool00ol0003ooooo
ooooo`1Zooooo`Coo`00C?ooool4ool000?o0000Q_ooool001kooooo00?o0000ooooooooool0K_oo
ool6ool0047ooooo1Ooo0003o`0008[ooooo000Nooooo`03o`000?oooooooooo07;ooooo0_l00006
ool003Oooooo1?oo0004o`0008kooooo000Nooooo`03o`000?oooooooooo07Kooooo1?l00007ool0
02_ooooo1Ooo0004o`0009;ooooo000Nooooo`03o`000?oooooooooo083ooooo00?o0000ool00?oo
00002Ooo0003o`0000kooooo0ol0000<ool009_ooooo000Nooooo`03o`000?oooooooooo08cooooo
5?oo002Wooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool0
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo
00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo
00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1Oooool3o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8oooo
o`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?oooooo
Coooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003o
oooooe7ooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o
00001Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b
3_ooool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj
^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0Q?ooool008cooooo00?o
0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`22
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q
8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo08?ooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<08Cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0Q_ooool008Wooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo08Kooooo0029ooooo`Oo00001Oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00025ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .0304 L
.2 .05783 L
.3 .07959 L
.4 .09357 L
.5 .09838 L
.6 .09357 L
.7 .07959 L
.8 .05783 L
.9 .0304 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .01234 L
.08481 .02557 L
.12636 .03755 L
.16632 .04847 L
.20885 .05925 L
.2498 .06863 L
.29331 .07736 L
.33524 .0844 L
.37557 .0898 L
.39599 .09199 L
.41848 .09396 L
.43982 .09539 L
.44937 .0959 L
.4598 .09635 L
.46545 .09655 L
.4707 .09671 L
.47614 .09685 L
.48106 .09695 L
.48591 .09703 L
.48813 .09706 L
.49048 .09708 L
.49299 .0971 L
.4941 .09711 L
.4953 .09711 L
.49658 .09712 L
.49778 .09712 L
.49852 .09712 L
.49921 .09712 L
.50051 .09712 L
.50171 .09712 L
.503 .09712 L
.50421 .09712 L
.50533 .09711 L
.50792 .09709 L
.51065 .09707 L
.51331 .09704 L
.51579 .097 L
.52142 .0969 L
.53077 .09667 L
.54076 .09633 L
.55151 .09586 L
.56317 .09522 L
.58433 .09374 L
.6273 .08946 L
.66867 .08381 L
.70845 .07703 L
.75081 .0685 L
.79157 .05915 L
.83491 .04814 L
Mistroke
.87666 .0367 L
.91682 .02509 L
.95955 .01231 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`?oo`00ool0000]o`0000;oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`03ool000[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool01_l0
003oo`00ool00?oo003oooooo`0000_ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool001kooooo00?o
0000ooooooooool00oooool3ool00003o`000?oooooooooo037ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0<Ooo
ool2o`0000?oo`001?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000Wooooo000N
ooooo`03o`000?oooooooooo00Kooooo0ooo00000ol0003oooooooooo`3ooooooaKooooo0_l00003
ool0027ooooo000Nooooo`03o`000?oooooooooo00Wooooo1?oo00000ol0003oooooooooo`3ooooo
o`kooooo0_l00004ool002Cooooo000Nooooo`03o`000?oooooooooo00gooooo0ooo00000ol0003o
ooooooooo`3oooooo`Sooooo0_l00003ool002Sooooo000Nooooo`03o`000?oooooooooo013ooooo
0ooo00000ol0003oooooooooo`3oooooo`;ooooo0_l00003ool002_ooooo000Nooooo`03o`000?oo
oooooooo01?ooooo0ooo0002o`000?_ooooo0ol00003ool002kooooo000Nooooo`03o`000?oooooo
oooo01Kooooo1?oo00000ol0003oooooooooo`3cooooo`;o00001?oo000aooooo`007_ooool00ol0
003oooooooooo`0Jooooo`?oo`000_l0003]ooooo`03o`000?oo003oo`0000?oo`00=Oooool001ko
oooo0ol0000Mooooo`?oo`000_l0003Wooooo`Coo`00>_ooool001kooooo00?o0000ooooooooool0
8?ooool3ool000;o0000hOooool3ool003kooooo000Nooooo`03o`000?oooooooooo02?ooooo1?oo
0002o`000=Wooooo00Co0000ool00?oo003oo`00@Oooool001kooooo00?o0000ooooooooool09ooo
ool4ool00003o`000?oooooooooo0=7ooooo00Co0000ool00?oo003oo`00A?ooool001kooooo00?o
0000ooooooooool0:oooool4ool00<gooooo00Co0000ool00?oo003oo`00Aoooool001kooooo00?o
0000ooooooooool0;oooool4ool00<Gooooo00?o0000ool00?oo00000_oo001:ooooo`007_ooool0
0ol0003oooooooooo`0cooooo`Goo`00_?ooool5ool004kooooo000Nooooo`03o`000?oooooooooo
03Kooooo0_l00004ool00;Cooooo1?oo00000ol0003oooooooooo`1@ooooo`007_ooool00ol0003o
ooooooooo`0iooooo`?o00001?oo002/ooooo`Coo`000_l0001Eooooo`007_ooool3o`0003kooooo
0_l00004ool00:?ooooo1Ooo0002o`0005Wooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o
0000ool00?oo00000_oo002Kooooo`Coo`000_l0001Nooooo`007_ooool00ol0003oooooooooo`18
ooooo`Coo`0000?o0000ooooooooool0T?ooool4ool00003o`000?oooooooooo067ooooo000Noooo
o`03o`000?oooooooooo04cooooo1Ooo00000ol0003oooooooooo`26ooooo`Goo`00J?ooool001ko
oooo00?o0000ooooooooool0DOooool4ool000;o0000O_ooool00ol0003oo`00ool00002ool006go
oooo000Nooooo`03o`000?oooooooooo05Gooooo1Ooo0002o`0007?ooooo0_l00005ool0077ooooo
000Nooooo`03o`000?oooooooooo05[ooooo1ooo00000ol0003oooooooooo`1Uooooo`;o00001_oo
001fooooo`007_ooool00ol0003oooooooooo`1Qooooo`Woo`00F?ooool9ool007cooooo000Noooo
o`03o`000?oooooooooo06Wooooo00?o0000ool00?oo00002?oo0015ooooo`Woo`00QOooool001ko
oooo0ol0001_ooooo`Go00001_oo000hooooo`Ooo`000ol0002;ooooo`007_ooool00ol0003ooooo
ooooo`1eooooo`Go00004_oo000Doooooa;oo`001?l0002Aooooo`007_ooool00ol0003ooooooooo
o`27ooooo`Go00005?oo0004o`000:?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3
o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo
0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04oooo
o`?o0000oooooom8ooooo`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`00
0?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool0
0omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go
410@o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooo
ooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`0:o`000?oo
ooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@
4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1ooooo
o`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`1nooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c020ooooo`00QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`00
00Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0P_ooool0
08Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`22ooooo`00QOooool7o`0000Gooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`Go00001?ooool4o`00087ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .01648 L
.2 .03134 L
.3 .04314 L
.4 .05071 L
.5 .05332 L
.6 .05071 L
.7 .04314 L
.8 .03134 L
.9 .01648 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00666 L
.08481 .0138 L
.12636 .02026 L
.16632 .02616 L
.20885 .03197 L
.2498 .03704 L
.29331 .04175 L
.33524 .04555 L
.37557 .04846 L
.39599 .04964 L
.41848 .0507 L
.43982 .05148 L
.44937 .05175 L
.4598 .05199 L
.46545 .0521 L
.4707 .05219 L
.47614 .05227 L
.48106 .05232 L
.48591 .05236 L
.48813 .05238 L
.49048 .05239 L
.49299 .0524 L
.4941 .0524 L
.4953 .05241 L
.49658 .05241 L
.49778 .05241 L
.49852 .05241 L
.49921 .05241 L
.50051 .05241 L
.50171 .05241 L
.503 .05241 L
.50421 .05241 L
.50533 .05241 L
.50792 .0524 L
.51065 .05238 L
.51331 .05237 L
.51579 .05235 L
.52142 .05229 L
.53077 .05217 L
.54076 .05198 L
.55151 .05173 L
.56317 .05138 L
.58433 .05058 L
.6273 .04828 L
.66867 .04522 L
.70845 .04157 L
.75081 .03697 L
.79157 .03192 L
.83491 .02598 L
Mistroke
.87666 .0198 L
.91682 .01354 L
.95955 .00664 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Coo`00ool0000Zo`0000Coo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool01?l0003oooooooooooooool7ool000Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool6
ool000?ooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oo003oo`0000Coo`00;?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oo003oo`0000Coo`002Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool2
o`0000Wooooo000Nooooo`03o`000?oooooooooo00kooooo1ooo003oooooo`?ooooo1ooo000Yoooo
o`007_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003oo`0000Coo`00m_ooool6ool0033o
oooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ool00?oo00001Ooo003Xooooo`Ooo`00
=_ooool001kooooo00?o0000ooooooooool08?ooool2o`0000Koo`00g?ooool6ool00003o`000?oo
oooooooo03[ooooo000Nooooo`03o`000?oooooooooo02Kooooo0_l00006ool00=3ooooo1_oo0000
0ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0/ooooo`;o00001_oo0034oooo
o`Koo`0000?o0000ooooooooool0A_ooool001kooooo00?o0000ooooooooool0<_ooool2o`0000Oo
o`00]_ooool7ool00003o`000?oooooooooo04cooooo000Nooooo`?o0000>?ooool3o`0000Woo`00
Y?ooool9ool000;o0000E?ooool001kooooo00?o0000ooooooooool0@?ooool4o`0000Woo`00TOoo
ool:ool000?o0000G?ooool001kooooo00?o0000ooooooooool0B_ooool3o`0000Ooo`00Poooool7
ool000?o0000I_ooool001kooooo00?o0000ooooooooool0E?ooool:ool006oooooo00?o0000ool0
0?oo00001ooo001`ooooo`007_ooool00ol0003oooooooooo`1Nooooo`coo`00F?ooool<ool007Wo
oooo000Nooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?oo00003_oo000looooo`coo`00
QOooool001kooooo00?o0000ooooooooool0Loooool7o`0003coo`000_l0002?ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0
003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oo
ooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8
ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Go
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3
o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom8ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0
003oooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo
00?o0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003o
ooooofWooooo002Hooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0
003o^[Zjooooo`2Yooooo`00V?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003o
ooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8H_o
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000
oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo097ooooo002@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003o
ooooooooo`2Aooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Aooooo`00SOooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03
oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`2Aooooo`00SOooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2Aooooo`00SOooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo
0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000Toooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00893 L
.2 .01699 L
.3 .02338 L
.4 .02748 L
.5 .0289 L
.6 .02748 L
.7 .02338 L
.8 .01699 L
.9 .00893 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00359 L
.08481 .00745 L
.12636 .01094 L
.16632 .01412 L
.20885 .01725 L
.2498 .01999 L
.29331 .02253 L
.33524 .02458 L
.37557 .02615 L
.39599 .02679 L
.41848 .02736 L
.43982 .02778 L
.44937 .02793 L
.4598 .02806 L
.46545 .02812 L
.4707 .02816 L
.47614 .0282 L
.48106 .02823 L
.48591 .02826 L
.48813 .02826 L
.49048 .02827 L
.49299 .02828 L
.4941 .02828 L
.4953 .02828 L
.49658 .02828 L
.49778 .02828 L
.49852 .02828 L
.49921 .02828 L
.50051 .02828 L
.50171 .02828 L
.503 .02828 L
.50421 .02828 L
.50533 .02828 L
.50792 .02828 L
.51065 .02827 L
.51331 .02826 L
.51579 .02825 L
.52142 .02822 L
.53077 .02815 L
.54076 .02805 L
.55151 .02791 L
.56317 .02773 L
.58433 .0273 L
.6273 .02605 L
.66867 .02441 L
.70845 .02243 L
.75081 .01995 L
.79157 .01722 L
.83491 .01402 L
Mistroke
.87666 .01069 L
.91682 .00731 L
.95955 .00358 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Soo`00ool0000So`0000Ooo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`03ooooo`;o00003Ooo000:ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool<ool00003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool00ol0003oooooooooo`0>oooo
o`Co00003Ooo000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo01_ooooo3Ooo0002o`00013ooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0Hooooo`Oo
00003?oo003Fooooo`goo`001Ol0000dooooo`007_ooool00ol0003oooooooooo`0Uooooo`Ko0000
3Ooo002mooooo`coo`001_l00010ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co00003?oo
002Tooooo`goo`000ol0001?ooooo`007_ooool00ol0003oooooooooo`13ooooo`03o`000?oo003o
o`0000_oo`0000?o0000ooooooooool0Q_ooool00ol0003oo`00ool0000;ool00003o`000?oooooo
oooo05cooooo000Nooooo`03o`000?oooooooooo057ooooo3Ooo0003o`0006Wooooo1?l0000=ool0
06cooooo000Nooooo`03o`000?oooooooooo05kooooo8ooo000[ooooob;oo`00NOooool001kooooo
00?o0000ooooooooool0L?oooolAo`0002_oo`003ol0002<ooooo`007_ooool3o`000?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o0000oooooom8ooooo`00
1?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0003o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o0000oooooom8ooooo`001?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105oooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodSooooo0004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Eooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool3o`00
0?ooooooB?ooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005oooool00ol0003ooooo
ooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Gooooo00?oEEEE
ofIVI_l00000oooooomAooooo`00oooooomYooooo`00TOooool2o`0000_ooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0/Oooool0097ooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[;ooooo0026ooooo`05oa0@4?l0
003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`1oooooo`00R?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0O_ooool008Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo1_l00005ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`1oooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c020ooooo`00QOooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003
o`0000gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08;ooooo0025ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo08;ooooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00000<
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00087ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00484 L
.2 .00921 L
.3 .01267 L
.4 .01489 L
.5 .01566 L
.6 .01489 L
.7 .01267 L
.8 .00921 L
.9 .00484 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00194 L
.08481 .00402 L
.12636 .0059 L
.16632 .00762 L
.20885 .00931 L
.2498 .01079 L
.29331 .01216 L
.33524 .01326 L
.37557 .01411 L
.39599 .01446 L
.41848 .01477 L
.43982 .01499 L
.44937 .01507 L
.4598 .01514 L
.46545 .01517 L
.4707 .0152 L
.47614 .01522 L
.48106 .01524 L
.48591 .01525 L
.48813 .01525 L
.49048 .01526 L
.49299 .01526 L
.4941 .01526 L
.4953 .01526 L
.49658 .01526 L
.49778 .01526 L
.49852 .01526 L
.49921 .01526 L
.50051 .01526 L
.50171 .01526 L
.503 .01526 L
.50421 .01526 L
.50533 .01526 L
.50792 .01526 L
.51065 .01525 L
.51331 .01525 L
.51579 .01524 L
.52142 .01523 L
.53077 .01519 L
.54076 .01514 L
.55151 .01506 L
.56317 .01496 L
.58433 .01473 L
.6273 .01406 L
.66867 .01317 L
.70845 .01211 L
.75081 .01077 L
.79157 .0093 L
.83491 .00757 L
Mistroke
.87666 .00577 L
.91682 .00394 L
.95955 .00193 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000Nooooo`Soo`00ool0000So`0000Ooo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`05oooooa[oo`003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oooolIool000Kooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool00ol0003oooooooooo`0Eoooo
o`[o00006Ooo0002ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo6Ooo0008o`0001Oooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`0/ooooo`co
00006Ooo002:oooooa[oo`002_l00018ooooo`007_ooool00ol0003oooooooooo`1:ooooo`Oo0000
8ooo0012ooooobGoo`001_l0001Vooooo`007_ooool00ol0003oooooooooo`1Yooooo`_o0000@_oo
000=o`0008Cooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003ooooo
ooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3
o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
oooooom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`005Oooool4o`000003oa0@4?oooooooooo00;ooooo
00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodSooooo000Gooooo`03
o`000?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005ooo
ool00ol0003oooooooooo`3oooooodoooooo000Eooooo`03oeEEEOmVIVKo00000?ooooooDOooool0
0?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03
o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`00
0?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0003o410@00Kooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05
oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj
00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@24ooooo`00S?ooool00ol0003oooooooooo`06
ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`00
0?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool0
0oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo08?ooooo002<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0P_ooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0Poooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<08Cooooo0029ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08Kooooo0029ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Q_ooool008Wooooo1ol00005ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03
oeEEEOmVIVKo000000gooooo1?l00025ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00262 L
.2 .00499 L
.3 .00687 L
.4 .00807 L
.5 .00849 L
.6 .00807 L
.7 .00687 L
.8 .00499 L
.9 .00262 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00105 L
.08481 .00217 L
.12636 .00318 L
.16632 .00411 L
.20885 .00502 L
.2498 .00582 L
.29331 .00656 L
.33524 .00716 L
.37557 .00762 L
.39599 .0078 L
.41848 .00797 L
.43982 .00809 L
.44937 .00813 L
.4598 .00817 L
.46545 .00819 L
.4707 .0082 L
.47614 .00821 L
.48106 .00822 L
.48591 .00823 L
.48813 .00823 L
.49048 .00823 L
.49299 .00823 L
.4941 .00824 L
.4953 .00824 L
.49658 .00824 L
.49778 .00824 L
.49852 .00824 L
.49921 .00824 L
.50051 .00824 L
.50171 .00824 L
.503 .00824 L
.50421 .00824 L
.50533 .00824 L
.50792 .00823 L
.51065 .00823 L
.51331 .00823 L
.51579 .00823 L
.52142 .00822 L
.53077 .0082 L
.54076 .00817 L
.55151 .00813 L
.56317 .00807 L
.58433 .00795 L
.6273 .00759 L
.66867 .00711 L
.70845 .00653 L
.75081 .00581 L
.79157 .00502 L
.83491 .00408 L
Mistroke
.87666 .00311 L
.91682 .00213 L
.95955 .00104 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000NoooooaGoo`00ool0000:o`0001?oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Go00009_oo0002ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo9_oo0004o`0000kooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:
ooooo`007_ooool00ol0003oooooooooo`0/ooooo`co0000??oo0003ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0?ooo000:o`0002kooooo00?o0000ooooooooool02?ooool2o`00
00;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`1Yooooo`_o0000@_oo000=o`0008Co
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo
00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooom8ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0
oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Gooooo0ol0003oooooodSooooo0004ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
B?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005
ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Gooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8
ooooo`005oooool00ol0003oooooooooo`04ooooo`?o0000oooooom8ooooo`005oooool00ol0003o
ooooooooo`3oooooodoooooo000Gooooo`03o`000?oooooooooo0?ooooooCoooool001Oooooo00?o
0000ooooooooool0oooooom?ooooo`005Oooool00omEEEGoIVIVo`00003ooooooe7ooooo003ooooo
ofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o
^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooo
ooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@20ooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00onYZJWoEEEE
ooooo`08ooooo`03o`000?oooooooooo07kooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Ooooool008Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0P?ooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo
00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`22ooooo`00QOooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`22
ooooo`00QOooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000=oooo
o`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003?ooool5o`0000Cooooo1?l00021oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.1 .00142 L
.2 .0027 L
.3 .00372 L
.4 .00437 L
.5 .0046 L
.6 .00437 L
.7 .00372 L
.8 .0027 L
.9 .00142 L
1 0 L
s
1 0 0 r
0 0 m
.04057 .00056 L
.08481 .00117 L
.12636 .00172 L
.16632 .00222 L
.20885 .00271 L
.2498 .00314 L
.29331 .00354 L
.33524 .00386 L
.37557 .00411 L
.39599 .00421 L
.41848 .0043 L
.43982 .00437 L
.44937 .00439 L
.4598 .00441 L
.46545 .00442 L
.4707 .00443 L
.47614 .00443 L
.48106 .00444 L
.48591 .00444 L
.48813 .00444 L
.49048 .00444 L
.49299 .00444 L
.4941 .00444 L
.4953 .00444 L
.49658 .00444 L
.49778 .00444 L
.49852 .00444 L
.49921 .00444 L
.50051 .00444 L
.50171 .00444 L
.503 .00444 L
.50421 .00444 L
.50533 .00444 L
.50792 .00444 L
.51065 .00444 L
.51331 .00444 L
.51579 .00444 L
.52142 .00443 L
.53077 .00442 L
.54076 .00441 L
.55151 .00439 L
.56317 .00436 L
.58433 .00429 L
.6273 .00409 L
.66867 .00384 L
.70845 .00353 L
.75081 .00313 L
.79157 .00271 L
.83491 .0022 L
Mistroke
.87666 .00168 L
.91682 .00115 L
.95955 .00056 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo01Gooooo001@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00X
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Gooooo`00D?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Wooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Gooooo`00D?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Xoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool05oooool0053ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo01Oooooo001@ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Vooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Xooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Zooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool05ooo
ool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo01Oooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@
olc<c0[ooooo000NoooooaGoo`00ool0000:o`0001?oo`002oooool01?o^k^ko8B4Qoa0@4?o^k^h:
ooooo`007_ooool00ol0003oooooooooo`0=ooooo`Go0000Mooo000<ooooo`03o`000?oooooooooo
00_oooooN?oo0004o`0000kooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:
ooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool03Oooool2o`0001[oo`0000?o0000ooooooooool03Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00009oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3
o`000?ooooooB?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodSooooo
0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo0ol0003oooooodSooooo
0004ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000?ooooooB?ooool000Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo0004ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool0
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00ol0003oooooooooo`04oooo
o`?o0000oooooom8ooooo`005oooool00ol0003oooooooooo`3oooooodoooooo000Gooooo`03o`00
0?oooooooooo0?ooooooCoooool001Oooooo00?o0000ooooooooool0oooooom?ooooo`005Oooool0
0omEEEGoIVIVo`00003ooooooe7ooooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go
410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
0_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003o
ooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`Go00001Oooool2ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooooonHV9So8B4Qonk^k_oo
ooooA4A41Oooool2ob4Q8H_ooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^09?ooooo002@ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP2Booooo`00T?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`2Aoooo
o`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00003_ooool00ol0003oooooooooo`2@oooo
o`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01Ol0003o^[ZjoooooonHV9So410@09;ooooo002=ooooo`Oo00001?ooool2o`00
01?ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool02oooool01OnH
V9So410@o`000?lQ8B7oc<c<09;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.101772, -0.0802184, \
0.00411939, 0.00666531}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The method works beautifully, following the exact result precisely \
even for these rather course grids in time and space.\
\>", "Text"],

Cell["\<\
\tFinally, we note that, just as it was possible to create an \
interpolation function for grid solutions to ODEs, it is possible to do the \
same for grid solutions to PDEs:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tsol\  = \ 
      Interpolation[
        Flatten[Table[
            Table[{j\ \[CapitalDelta]x, n\ \[CapitalDelta]t, T[j, n]}, {j, 0, 
                  M}] /. sol[n], {n, 0, 25}], 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.65"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 1.25`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command used here removes an extra set of brackets that the ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function finds objectionable. We can plot the solution function ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"Tsol", "[", 
            RowBox[{
              StyleBox["x",
                FontSlant->"Plain"], ",", 
              StyleBox["t",
                FontSlant->"Plain"]}], "]"}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  "vs. both ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["t",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and we do so in Cell ",
  ButtonBox["6.66",
    ButtonData:>"Cell 6.66",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[Tsol[x, t], {x, 0, 1}, {t, 0, 1.25}, 
        AxesLabel \[Rule] {"\<x\>", "\<t\>", "\<T[x,t]\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.66"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 24 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 24 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 6 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -40 -3.77786 ]
[-0.05457 .39542 0 8.22214 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.25)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.5)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.75)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(1)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1.25)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -101 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.637 .734 .919 r
.38313 .58323 .40512 .60371 .44184 .59468 .42013 .57442 Metetra
.638 .739 .922 r
.42013 .57442 .44184 .59468 .47911 .5854 .45771 .56534 Metetra
.64 .744 .925 r
.45771 .56534 .47911 .5854 .51694 .5758 .49588 .55588 Metetra
.643 .75 .926 r
.49588 .55588 .51694 .5758 .55533 .56576 .53463 .54591 Metetra
.648 .754 .927 r
.53463 .54591 .55533 .56576 .59429 .55522 .57397 .53534 Metetra
.653 .759 .927 r
.57397 .53534 .59429 .55522 .63381 .5441 .6139 .52409 Metetra
.658 .762 .926 r
.6139 .52409 .63381 .5441 .67389 .53238 .6544 .51211 Metetra
.664 .764 .925 r
.6544 .51211 .67389 .53238 .71454 .52001 .69548 .49937 Metetra
.67 .766 .922 r
.69548 .49937 .71454 .52001 .75573 .50702 .73711 .48588 Metetra
.675 .766 .919 r
.73711 .48588 .75573 .50702 .79747 .49343 .7793 .47167 Metetra
.679 .765 .916 r
.7793 .47167 .79747 .49343 .83976 .47928 .82203 .4568 Metetra
.682 .762 .912 r
.82203 .4568 .83976 .47928 .88261 .46464 .86533 .44136 Metetra
.684 .759 .908 r
.86533 .44136 .88261 .46464 .92603 .4496 .90918 .42546 Metetra
.685 .755 .904 r
.90918 .42546 .92603 .4496 .97003 .43424 .95362 .4092 Metetra
.63 .732 .921 r
.36056 .56222 .38313 .58323 .42013 .57442 .39785 .55375 Metetra
.631 .739 .925 r
.39785 .55375 .42013 .57442 .45771 .56534 .43574 .54498 Metetra
.633 .745 .928 r
.43574 .54498 .45771 .56534 .49588 .55588 .47424 .53576 Metetra
.638 .751 .931 r
.47424 .53576 .49588 .55588 .53463 .54591 .51336 .52594 Metetra
.643 .757 .932 r
.51336 .52594 .53463 .54591 .57397 .53534 .5531 .51541 Metetra
.65 .763 .932 r
.5531 .51541 .57397 .53534 .6139 .52409 .59344 .50406 Metetra
.657 .767 .931 r
.59344 .50406 .6139 .52409 .6544 .51211 .63437 .49183 Metetra
.664 .77 .928 r
.63437 .49183 .6544 .51211 .69548 .49937 .67589 .47868 Metetra
.671 .772 .925 r
.67589 .47868 .69548 .49937 .73711 .48588 .71798 .46463 Metetra
.678 .772 .921 r
.71798 .46463 .73711 .48588 .7793 .47167 .76063 .44972 Metetra
.683 .77 .917 r
.76063 .44972 .7793 .47167 .82203 .4568 .80382 .43403 Metetra
.687 .767 .913 r
.80382 .43403 .82203 .4568 .86533 .44136 .84757 .41766 Metetra
.689 .763 .908 r
.84757 .41766 .86533 .44136 .90918 .42546 .89187 .40075 Metetra
.691 .758 .903 r
.89187 .40075 .90918 .42546 .95362 .4092 .93675 .38345 Metetra
.621 .73 .925 r
.33741 .54067 .36056 .56222 .39785 .55375 .37497 .53268 Metetra
.622 .737 .929 r
.37497 .53268 .39785 .55375 .43574 .54498 .41316 .52436 Metetra
.625 .745 .933 r
.41316 .52436 .43574 .54498 .47424 .53576 .452 .51551 Metetra
.63 .753 .936 r
.452 .51551 .47424 .53576 .51336 .52594 .49149 .50595 Metetra
.638 .761 .937 r
.49149 .50595 .51336 .52594 .5531 .51541 .53162 .49553 Metetra
.646 .768 .937 r
.53162 .49553 .5531 .51541 .59344 .50406 .57239 .48412 Metetra
.655 .773 .936 r
.57239 .48412 .59344 .50406 .63437 .49183 .61378 .47165 Metetra
.665 .777 .933 r
.61378 .47165 .63437 .49183 .67589 .47868 .65576 .45807 Metetra
.674 .779 .929 r
.65576 .45807 .67589 .47868 .71798 .46463 .69832 .44339 Metetra
.681 .779 .924 r
.69832 .44339 .71798 .46463 .76063 .44972 .74144 .42768 Metetra
.688 .777 .919 r
.74144 .42768 .76063 .44972 .80382 .43403 .78511 .41103 Metetra
.693 .773 .913 r
.78511 .41103 .80382 .43403 .84757 .41766 .82932 .39357 Metetra
.696 .768 .907 r
.82932 .39357 .84757 .41766 .89187 .40075 .87407 .37548 Metetra
.697 .762 .902 r
.87407 .37548 .89187 .40075 .93675 .38345 .91939 .35695 Metetra
.609 .726 .928 r
.31365 .51855 .33741 .54067 .37497 .53268 .35146 .51123 Metetra
.61 .736 .934 r
.35146 .51123 .37497 .53268 .41316 .52436 .38994 .50354 Metetra
.614 .746 .939 r
.38994 .50354 .41316 .52436 .452 .51551 .42911 .49523 Metetra
.621 .756 .943 r
.42911 .49523 .452 .51551 .49149 .50595 .46896 .48606 Metetra
.63 .766 .944 r
.46896 .48606 .49149 .50595 .53162 .49553 .50951 .47585 Metetra
.641 .774 .944 r
.50951 .47585 .53162 .49553 .57239 .48412 .55072 .46445 Metetra
.653 .781 .942 r
.55072 .46445 .57239 .48412 .61378 .47165 .59258 .45175 Metetra
.665 .786 .939 r
.59258 .45175 .61378 .47165 .65576 .45807 .63505 .43769 Metetra
.676 .788 .934 r
.63505 .43769 .65576 .45807 .69832 .44339 .67811 .42231 Metetra
.686 .788 .928 r
.67811 .42231 .69832 .44339 .74144 .42768 .72172 .40566 Metetra
.694 .785 .921 r
.72172 .40566 .74144 .42768 .78511 .41103 .76587 .38788 Metetra
.7 .781 .914 r
.76587 .38788 .78511 .41103 .82932 .39357 .81055 .36914 Metetra
.704 .774 .907 r
.81055 .36914 .82932 .39357 .87407 .37548 .85576 .34966 Metetra
.705 .767 .9 r
.85576 .34966 .87407 .37548 .91939 .35695 .90152 .32967 Metetra
.593 .721 .933 r
.28926 .49583 .31365 .51855 .35146 .51123 .32729 .48943 Metetra
.594 .733 .941 r
.32729 .48943 .35146 .51123 .38994 .50354 .36604 .4826 Metetra
.599 .746 .947 r
.36604 .4826 .38994 .50354 .42911 .49523 .40552 .47503 Metetra
.608 .759 .951 r
.40552 .47503 .42911 .49523 .46896 .48606 .44575 .46643 Metetra
.62 .771 .953 r
.44575 .46643 .46896 .48606 .50951 .47585 .48671 .45657 Metetra
.634 .782 .952 r
.48671 .45657 .50951 .47585 .55072 .46445 .52839 .44524 Metetra
.649 .791 .95 r
.52839 .44524 .55072 .46445 .59258 .45175 .57073 .43233 Metetra
.665 .797 .945 r
.57073 .43233 .59258 .45175 .63505 .43769 .61372 .41776 Metetra
.679 .8 .939 r
.61372 .41776 .63505 .43769 .67811 .42231 .6573 .40156 Metetra
.692 .799 .931 r
.6573 .40156 .67811 .42231 .72172 .40566 .70143 .38383 Metetra
.702 .796 .923 r
.70143 .38383 .72172 .40566 .76587 .38788 .74609 .36472 Metetra
.709 .79 .914 r
.74609 .36472 .76587 .38788 .81055 .36914 .79126 .34445 Metetra
.713 .782 .906 r
.79126 .34445 .81055 .36914 .85576 .34966 .83693 .32331 Metetra
.715 .772 .898 r
.83693 .32331 .85576 .34966 .90152 .32967 .88312 .30158 Metetra
.573 .714 .938 r
.2642 .4725 .28926 .49583 .32729 .48943 .30242 .46732 Metetra
.573 .729 .948 r
.30242 .46732 .32729 .48943 .36604 .4826 .3414 .46163 Metetra
.579 .745 .955 r
.3414 .46163 .36604 .4826 .40552 .47503 .38119 .45507 Metetra
.59 .761 .96 r
.38119 .45507 .40552 .47503 .44575 .46643 .42179 .44727 Metetra
.605 .777 .963 r
.42179 .44727 .44575 .46643 .48671 .45657 .46318 .43792 Metetra
.624 .791 .962 r
.46318 .43792 .48671 .45657 .52839 .44524 .50533 .42678 Metetra
.644 .803 .959 r
.50533 .42678 .52839 .44524 .57073 .43233 .54819 .41368 Metetra
.664 .81 .953 r
.54819 .41368 .57073 .43233 .61372 .41776 .59172 .39854 Metetra
.683 .814 .945 r
.59172 .39854 .61372 .41776 .6573 .40156 .63585 .3814 Metetra
.699 .813 .936 r
.63585 .3814 .6573 .40156 .70143 .38383 .68054 .36239 Metetra
.712 .809 .925 r
.68054 .36239 .70143 .38383 .74609 .36472 .72573 .34169 Metetra
.721 .801 .915 r
.72573 .34169 .74609 .36472 .79126 .34445 .7714 .3196 Metetra
.725 .791 .904 r
.7714 .3196 .79126 .34445 .83693 .32331 .81754 .29646 Metetra
.726 .779 .894 r
.81754 .29646 .83693 .32331 .88312 .30158 .86416 .27265 Metetra
.544 .704 .944 r
.23846 .44853 .2642 .4725 .30242 .46732 .2768 .44494 Metetra
.544 .722 .956 r
.2768 .44494 .30242 .46732 .3414 .46163 .31599 .44078 Metetra
.55 .742 .965 r
.31599 .44078 .3414 .46163 .38119 .45507 .35606 .43556 Metetra
.564 .763 .972 r
.35606 .43556 .38119 .45507 .42179 .44727 .39701 .42885 Metetra
.584 .784 .975 r
.39701 .42885 .42179 .44727 .46318 .43792 .43883 .42022 Metetra
.609 .803 .974 r
.43883 .42022 .46318 .43792 .50533 .42678 .48147 .40939 Metetra
.636 .817 .97 r
.48147 .40939 .50533 .42678 .54819 .41368 .52489 .39615 Metetra
.663 .827 .962 r
.52489 .39615 .54819 .41368 .59172 .39854 .569 .38038 Metetra
.688 .832 .952 r
.569 .38038 .59172 .39854 .63585 .3814 .61373 .36215 Metetra
.708 .831 .94 r
.61373 .36215 .63585 .3814 .68054 .36239 .659 .3416 Metetra
.724 .825 .927 r
.659 .3416 .68054 .36239 .72573 .34169 .70476 .31899 Metetra
.734 .815 .914 r
.70476 .31899 .72573 .34169 .7714 .3196 .75096 .29469 Metetra
.74 .802 .902 r
.75096 .29469 .7714 .3196 .81754 .29646 .79757 .26915 Metetra
.74 .786 .89 r
.79757 .26915 .81754 .29646 .86416 .27265 .84462 .24283 Metetra
.505 .689 .95 r
.212 .42389 .23846 .44853 .2768 .44494 .2504 .42238 Metetra
.502 .711 .964 r
.2504 .42238 .2768 .44494 .31599 .44078 .28973 .4202 Metetra
.509 .735 .976 r
.28973 .4202 .31599 .44078 .35606 .43556 .33003 .41677 Metetra
.526 .763 .983 r
.33003 .41677 .35606 .43556 .39701 .42885 .37132 .4115 Metetra
.553 .79 .987 r
.37132 .4115 .39701 .42885 .43883 .42022 .41357 .40389 Metetra
.587 .815 .986 r
.41357 .40389 .43883 .42022 .48147 .40939 .45673 .39354 Metetra
.624 .835 .981 r
.45673 .39354 .48147 .40939 .52489 .39615 .50074 .38021 Metetra
.66 .848 .972 r
.50074 .38021 .52489 .39615 .569 .38038 .54548 .36374 Metetra
.693 .854 .96 r
.54548 .36374 .569 .38038 .61373 .36215 .59086 .34421 Metetra
.719 .852 .945 r
.59086 .34421 .61373 .36215 .659 .3416 .63678 .32182 Metetra
.739 .844 .929 r
.63678 .32182 .659 .3416 .70476 .31899 .68314 .2969 Metetra
.751 .831 .913 r
.68314 .2969 .70476 .31899 .75096 .29469 .72989 .26992 Metetra
.757 .814 .898 r
.72989 .26992 .75096 .29469 .79757 .26915 .777 .24145 Metetra
.757 .795 .884 r
.777 .24145 .79757 .26915 .84462 .24283 .82447 .21208 Metetra
.449 .666 .955 r
.18479 .39856 .212 .42389 .2504 .42238 .22314 .39973 Metetra
.441 .691 .971 r
.22314 .39973 .2504 .42238 .28973 .4202 .26253 .40014 Metetra
.447 .721 .984 r
.26253 .40014 .28973 .4202 .33003 .41677 .30301 .39904 Metetra
.469 .756 .993 r
.30301 .39904 .33003 .41677 .37132 .4115 .3446 .39569 Metetra
.505 .793 .997 r
.3446 .39569 .37132 .4115 .41357 .40389 .38729 .38945 Metetra
.552 .827 .997 r
.38729 .38945 .41357 .40389 .45673 .39354 .431 .37982 Metetra
.603 .854 .991 r
.431 .37982 .45673 .39354 .50074 .38021 .47563 .36646 Metetra
.653 .873 .981 r
.47563 .36646 .50074 .38021 .54548 .36374 .52107 .3492 Metetra
.697 .88 .966 r
.52107 .3492 .54548 .36374 .59086 .34421 .56717 .32812 Metetra
.732 .878 .948 r
.56717 .32812 .59086 .34421 .63678 .32182 .61379 .30349 Metetra
.757 .867 .929 r
.61379 .30349 .63678 .32182 .68314 .2969 .66082 .27574 Metetra
.772 .85 .91 r
.66082 .27574 .68314 .2969 .72989 .26992 .70817 .24548 Metetra
.778 .829 .892 r
.70817 .24548 .72989 .26992 .777 .24145 .7558 .21344 Metetra
.777 .806 .876 r
.7558 .21344 .777 .24145 .82447 .21208 .80369 .18035 Metetra
.367 .628 .954 r
.1568 .3725 .18479 .39856 .22314 .39973 .19497 .37712 Metetra
.35 .655 .969 r
.19497 .37712 .22314 .39973 .26253 .40014 .2343 .38087 Metetra
.352 .691 .981 r
.2343 .38087 .26253 .40014 .30301 .39904 .27487 .38281 Metetra
.378 .735 .99 r
.27487 .38281 .30301 .39904 .3446 .39569 .31673 .382 Metetra
.428 .785 .996 r
.31673 .382 .3446 .39569 .38729 .38945 .35983 .3776 Metetra
.494 .832 .998 r
.35983 .3776 .38729 .38945 .431 .37982 .40411 .36898 Metetra
.567 .872 .995 r
.40411 .36898 .431 .37982 .47563 .36646 .44944 .3557 Metetra
.639 .899 .984 r
.44944 .3557 .47563 .36646 .52107 .3492 .49564 .33753 Metetra
.7 .911 .968 r
.49564 .33753 .52107 .3492 .56717 .32812 .54255 .31458 Metetra
.747 .908 .948 r
.54255 .31458 .56717 .32812 .61379 .30349 .58997 .28721 Metetra
.778 .894 .926 r
.58997 .28721 .61379 .30349 .66082 .27574 .63774 .25598 Metetra
.796 .872 .904 r
.63774 .25598 .66082 .27574 .70817 .24548 .68575 .22168 Metetra
.802 .845 .883 r
.68575 .22168 .70817 .24548 .7558 .21344 .73392 .18524 Metetra
.799 .817 .865 r
.73392 .18524 .7558 .21344 .80369 .18035 .78223 .14761 Metetra
.245 .564 .936 r
.128 .34568 .1568 .3725 .19497 .37712 .16579 .35471 Metetra
.21 .588 .945 r
.16579 .35471 .19497 .37712 .2343 .38087 .2049 .36277 Metetra
.203 .626 .949 r
.2049 .36277 .2343 .38087 .27487 .38281 .24545 .36867 Metetra
.234 .68 .955 r
.24545 .36867 .27487 .38281 .31673 .382 .28749 .37119 Metetra
.302 .747 .962 r
.28749 .37119 .31673 .382 .35983 .3776 .331 .36926 Metetra
.396 .816 .971 r
.331 .36926 .35983 .3776 .40411 .36898 .37587 .36204 Metetra
.504 .878 .976 r
.37587 .36204 .40411 .36898 .44944 .3557 .42195 .34897 Metetra
.609 .922 .973 r
.42195 .34897 .44944 .3557 .49564 .33753 .46903 .32974 Metetra
.697 .942 .961 r
.46903 .32974 .49564 .33753 .54255 .31458 .51686 .30451 Metetra
.761 .941 .941 r
.51686 .30451 .54255 .31458 .58997 .28721 .5652 .27375 Metetra
.802 .924 .917 r
.5652 .27375 .58997 .28721 .63774 .25598 .61382 .2382 Metetra
.823 .896 .893 r
.61382 .2382 .63774 .25598 .68575 .22168 .66257 .19888 Metetra
.829 .863 .871 r
.66257 .19888 .68575 .22168 .73392 .18524 .71133 .15701 Metetra
.825 .828 .851 r
.71133 .15701 .73392 .18524 .78223 .14761 .76008 .1138 Metetra
.066 .456 .883 r
.09834 .31807 .128 .34568 .16579 .35471 .1355 .33274 Metetra
.002 .466 .867 r
.1355 .33274 .16579 .35471 .2049 .36277 .17417 .34634 Metetra
0 .498 .849 r
.17417 .34634 .2049 .36277 .24545 .36867 .21453 .35738 Metetra
.018 .559 .842 r
.21453 .35738 .24545 .36867 .28749 .37119 .25664 .36427 Metetra
.108 .646 .853 r
.25664 .36427 .28749 .37119 .331 .36926 .30051 .36562 Metetra
.239 .748 .878 r
.30051 .36562 .331 .36926 .37587 .36204 .34601 .36034 Metetra
.395 .847 .908 r
.34601 .36034 .37587 .36204 .42195 .34897 .39293 .34765 Metetra
.551 .925 .928 r
.39293 .34765 .42195 .34897 .46903 .32974 .44101 .32717 Metetra
.68 .966 .932 r
.44101 .32717 .46903 .32974 .51686 .30451 .48992 .29912 Metetra
.771 .973 .92 r
.48992 .29912 .51686 .30451 .5652 .27375 .53933 .26412 Metetra
.827 .954 .899 r
.53933 .26412 .5652 .27375 .61382 .2382 .58896 .22315 Metetra
.853 .921 .875 r
.58896 .22315 .61382 .2382 .66257 .19888 .63856 .17757 Metetra
.86 .881 .852 r
.63856 .17757 .66257 .19888 .71133 .15701 .68798 .12895 Metetra
.852 .84 .832 r
.68798 .12895 .71133 .15701 .76008 .1138 .73719 .07886 Metetra
0 .284 .759 r
.0678 .28963 .09834 .31807 .1355 .33274 .10398 .31147 Metetra
0 .27 .695 r
.10398 .31147 .1355 .33274 .17417 .34634 .1419 .33221 Metetra
.29 0 0 r
.1419 .33221 .17417 .34634 .21453 .35738 .18181 .34992 Metetra
.245 0 0 r
.18181 .34992 .21453 .35738 .25664 .36427 .22383 .36257 Metetra
.138 0 0 r
.22383 .36257 .25664 .36427 .30051 .36562 .26799 .3683 Metetra
.26799 .3683 .30051 .36562 .34601 .36034 .31413 .36566 Metetra
.229 .746 .753 r
.31413 .36566 .34601 .36034 .39293 .34765 .36201 .35362 Metetra
.447 .88 .82 r
.36201 .35362 .39293 .34765 .44101 .32717 .41126 .33165 Metetra
.636 .965 .862 r
.41126 .33165 .44101 .32717 .48992 .29912 .46146 .30005 Metetra
.77 .994 .875 r
.46146 .30005 .48992 .29912 .53933 .26412 .51218 .25968 Metetra
.848 .981 .866 r
.51218 .25968 .53933 .26412 .58896 .22315 .563 .21185 Metetra
.884 .944 .847 r
.563 .21185 .58896 .22315 .63856 .17757 .61362 .15839 Metetra
.891 .898 .827 r
.61362 .15839 .63856 .17757 .68798 .12895 .66382 .10135 Metetra
.881 .85 .808 r
.66382 .10135 .68798 .12895 .73719 .07886 .71353 .04274 Metetra
0 .056 .546 r
.03634 .26033 .0678 .28963 .10398 .31147 .07105 .2913 Metetra
.531 0 0 r
.07105 .2913 .10398 .31147 .1419 .33221 .10779 .32122 Metetra
.533 0 0 r
.10779 .32122 .1419 .33221 .18181 .34992 .1469 .34764 Metetra
.474 0 0 r
.1469 .34764 .18181 .34992 .22383 .36257 .18859 .36788 Metetra
.361 0 0 r
.18859 .36788 .22383 .36257 .26799 .3683 .23291 .37948 Metetra
.194 0 0 r
.23291 .37948 .26799 .3683 .31413 .36566 .27971 .38046 Metetra
.27971 .38046 .31413 .36566 .36201 .35362 .32868 .36942 Metetra
.32868 .36942 .36201 .35362 .41126 .33165 .37934 .34563 Metetra
.554 .916 .736 r
.37934 .34563 .41126 .33165 .46146 .30005 .43113 .30952 Metetra
.747 .99 .793 r
.43113 .30952 .46146 .30005 .51218 .25968 .48345 .26225 Metetra
.861 .996 .811 r
.48345 .26225 .51218 .25968 .563 .21185 .53576 .20565 Metetra
.911 .962 .806 r
.53576 .20565 .563 .21185 .61362 .15839 .58762 .14218 Metetra
.922 .912 .792 r
.58762 .14218 .61362 .15839 .66382 .10135 .63876 .07456 Metetra
.91 .857 .777 r
.63876 .07456 .66382 .10135 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{328.625, 266.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0001CB000`400?l00000o`00003ooooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooolHooooo`Co000000?o410@ooooooooool0O?ooool00?oooooo
6_ooool00ol0003oooooooooo`1nooooo`00oooooolJooooo`03o`000?oooooooooo07kooooo003o
oooooa[ooooo00?o0000ooooooooool0O_ooool00?oooooo6_ooool00ol0003oooooooooo`1noooo
o`00oooooolJooooo`03o`000?oooooooooo07kooooo003ooooooa[ooooo00?o0000ooooooooool0
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07;ooooo003ooooooaSooooo00?oEEEEofIVI_l00000
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg07;ooooo003oooooobCooooo00Go410@oooooooooooo
oooooa0@401booooo`00oooooolTooooo`05o`000?ooooooooooooooool00000L_ooool00?oooooo
9?ooool01Ol0003ooooooooooooooooo000007;ooooo003oooooobCooooo00Go410@oooooooooooo
oooooa0@401booooo`00oooooolTooooo`05ogMgMonHV9SooooooiRHV?mgMgL0L_ooool00?oooooo
7_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1booooo`00oooooolKooooo`?o0000
00?oooooo`000?l00000N_ooool00?oooooo6Oooool2o`0000Cooooo0_l0001jooooo`00oooooolF
ooooo`?o00001Oooool4o`0007Wooooo003ooooooa?ooooo0ol00007ooooo`05o`000?oXflKo0000
onSKa_l00000NOooool00=[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<027ooooo0_l000000ooooooo0000ooooo`06ooooo`05o`000?oX
flKoj=_6o`000?oXflH00_l0001hooooo`00f_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407_ooool3o`0000_ooooo00Co0000onSKa_oX
flKo00000_oXflH2o`0007Oooooo003Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000001cooooo0_l0000=ooooo`05o`000?oXflKoj=_6onSKa_l000000ooX
flH00ol0003oooooooooo`1eooooo`00f_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P0Iooooo`?o00003_ooool00ol0003oj=_6onSKaP02onSKaP04o`00
0?oXflKoj=_6onSKaP;o0000M_ooool00=[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
olc<c?l0003o0000o`000?o<c<`05oooool2o`00017ooooo00?o0000onSKa_oXflH00ooXflH01?l0
003oj=_6onSKa_oXflH2o`0007Gooooo003Jooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413o^[Zjoooooonj^[[o410@01Cooooo0ol00002ooooo`03o`000?oooooooooo00gooooo00?o
0000onSKa_oXflH01?oXflH00ol0003oj=_6onSKaP02onSKaP03o`000?oooooooooo07?ooooo003J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000001;ooooo
0_l0000Dooooo`03o`000?oXflKoj=_600Goj=_600?o0000onSKa_oXflH00_oXflH2o`0007Cooooo
003Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00oo
oooo0ol0000Eooooo`03o`000?oXflKoj=_600Koj=_600?o0000onSKa_oXflH00ooXflH2o`0007?o
oooo003kooooo`?o00006?ooool00ol0003oj=_6onSKaP06onSKaP03o`000?oXflKoj=_600Coj=_6
0_l0001booooo`00V?ooool2o`0000;ooooo0_l0001Kooooo`;o000000?oooooo`000?ooool05ooo
ool00ol0003oj=_6onSKaP07onSKaP03o`000?oXflKoj=_600Coj=_60_l0001booooo`00V?ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMgESooooo0ol0000Kooooo`03o`000?oXflKoj=_600Soj=_6
00?o0000onSKa_oXflH00ooXflH00ol0003ohMW>o`00001booooo`00VOooool01?oMgMgo0000oa0@
4?o<c<aGooooo`;o00007Oooool00ol0003oj=_6onSKaP09onSKaP03o`000?oXflKoj=_600;oj=_6
00?o0000on7Ic_oQfLh00_l0001aooooo`00VOooool01?o^k^ko8B4Qoa0@4?o^k^iDooooo`?o0000
7oooool00ol0003oj=_6onSKaP09onSKaP05o`000?oXflKoj=_6onSKa_l000001?oQfLh2o`00073o
oooo002Iooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0ol0000Pooooo`03o`000?oXflKoj=_600[o
j=_600Co0000onSKa_oXflKo00001_oQfLh00ol0003oooooooooo`1^ooooo`00V?ooool2o`0000;o
oooo0_l0001>ooooo`?o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oXflKoj=_600_o
j=_600?o0000onSKa_l000001ooQfLh3o`0006kooooo003Zooooo`;o00009Oooool00ol0003oj=_6
onSKaP0;onSKaP03o`000?oXflKo000000SohMW>0_l0001^ooooo`00ioooool3o`0002Kooooo00?o
0000onSKa_oXflH03?oXflH2o`0000WohMW>0_l0001^ooooo`00[Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08_ooool3o`0002Sooooo
00?o0000onSKa_oXflH03OoXflH00ol0003ohMW>on7IcP09on7IcP;o0000KOooool00:gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q023o
oooo0_l00002ooooo`03o`000?oooooooooo02Gooooo00?o0000onSKa_oXflH03OoXflH2o`0000co
hMW>0_l0001/ooooo`00[Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`?o0000;?ooool00ol0003oj=_6onSKaP0<onSKaP04o`000?oQfLkohMW>
o`0000_ohMW>0_l0001/ooooo`00[Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Kooooo`;o0000;_ooool00ol0003ok>W:o`00000<onSKaP05o`000?oQ
fLkohMW>on7Ic_l000003?oQfLh2o`0006_ooooo002]ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<01Sooooo0ol0000_ooooo`05o`000?o/jL[ok>W:oncY
b_l000002_oXflH00ol0003ohMW>on7IcP02on7IcP03o`000?oQfLkohMW>00[ohMW>0ol00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0A?ooool00:gooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo01Sooooo0_l000000ooooooo0000ooooo`0^ooooo`03o`000?o/jL[ok>W:00?ok>W:00?o
0000onSKa_oXflH01ooXflH00ol0003ohMW>on7IcP02on7IcP03o`000?oQfLkohMW>00WohMW>00Co
0000om[Ge?l0003o00002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`13ooooo`00[Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P05Oooool3o`0003?ooooo00?o0000oncY
b_o/jLX01?o/jLX00ol0003oj=_6onSKaP05onSKaP03o`000?oQfLkohMW>00?ohMW>00?o0000on7I
c_oQfLh02?oQfLh01?l0003of]ODom[Ge?oJem@2o`0000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0@_ooool00:gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@417ooooo0_l0000eooooo`03o`00
0?o/jL[ok>W:00Kok>W:00?o0000onSKa_oXflH00ooXflH00ol0003ohMW>on7IcP04on7IcP03o`00
0?oQfLkohMW>00OohMW>00?o0000om[Ge?oJem@00ooJem@2o`0000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0@oooool00=3ooooo
0ol0000fooooo`03o`000?o/jL[ok>W:00Sok>W:00Go0000onSKa_oXflKoj=_6o`000007on7IcP03
o`000?oQfLkohMW>00KohMW>00?o0000om[Ge?oJem@01?oJem@2o`0000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c014
ooooo`00cOooool4o`0003Sooooo00?o0000oncYb_o/jLX02Oo/jLX00ol0003oj=_6o`000008on7I
cP03o`000?oQfLkohMW>00GohMW>00?o0000om[Ge?oJem@01_oJem@2o`0000Gooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool0
0<_ooooo0_l0000kooooo`03o`000?o/jL[ok>W:00_ok>W:00?o0000on7Ic_oQfLh01ooQfLh00ol0
003ohMW>on7IcP04on7IcP03o`000?oJemCof]OD00Sof]OD0_l00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0A_oo
ool00<Sooooo0ol0000looooo`03o`000?o/jL[ok>W:00cok>W:00?o0000on7Ic_oQfLh01ooQfLh0
0ol0003ohMW>on7IcP03on7IcP03o`000?oJemCof]OD00Wof]OD0_l00004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00015ooooo`00a_oo
ool2o`0003kooooo00?o0000oncYb_o/jLX03?o/jLX00ol0003oi>GCo`000008on7IcP03o`000?oQ
fLkohMW>00;ohMW>00?o0000om[Ge?oJem@02ooJem@2o`0006Gooooo0033ooooo`?o0000@?ooool0
0ol0003ok>W:oncYbP0;oncYbP05o`000?oTiM?oi>GConCUdol000001ooQfLh01Ol0003ohMW>on7I
c_oQfLko000000oof]OD0_l0001Tooooo`00`Oooool2o`0000?ooooo00?o0000ooooooooool0??oo
ool00ol0003ok>W:oncYbP0;oncYbP03o`000?oTiM?oi>GC00?oi>GC00?o0000on7Ic_oQfLh01?oQ
fLh01?l0003ohMW>on7Ic_l0000@om[Ge0;o0000I?ooool00;kooooo0ol00013ooooo`03o`000?o/
jL[ok>W:00_ok>W:00?o0000onCUdooTiM<01OoTiM<00ol0003ohMW>on7IcP03on7IcP03o`000?oQ
fLko0000013of]OD00Co0000om?CfOl0003o0000Hoooool00;cooooo0_l00015ooooo`03o`000?o/
jL[ok>W:00_ok>W:00?o0000onCUdooTiM<01ooTiM<00ol0003ohMW>on7IcP02on7IcP;o00004?oJ
em@01?l0003odm?Iom?CfOoCdmT2o`0006;ooooo0023ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Oooooo`?o0000Aoooool00ol0003ok>W:
oncYbP0:oncYbP03o`000?oTiM?oi>GC00Woi>GC00Go0000on7Ic_oQfLkohMW>o`00000@om[Ge003
o`000?oCdmWodm?I00?odm?I00?o0000ooooooooool0H?ooool008?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003o
ooooooooo`14ooooo`03o`000?o/jL[ok>W:00[ok>W:00?o0000onCUdooTiM<02ooTiM<01Ol0003o
hMW>o`000?oJemCo000000kof]OD00?o0000om?CfOoCdmT01?oCdmT2o`00067ooooo0023ooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo0_l0001;ooooo`03o`000?o/jL[ok>W:
00[ok>W:00?o0000onCUdooTiM<03?oTiM<2o`0000;of]OD00?o0000om[Ge?oJem@02ooJem@00ol0
003odm?Iom?Cf@06om?Cf@;o0000H?ooool008?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0001[ooooo0ol0001=ooooo`03o`000?o/jL[ok>W:00[ok>W:00?o0000
onCUdooTiM<02ooTiM<00ol0003og>7Jo`000002om[Ge003o`000?oJemCof]OD00[of]OD00?o0000
om?CfOoCdmT02?oCdmT00ol0003oooooooooo`1Nooooo`00Poooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0004oooooo00?o0000oncYb_o/jLX02_o/
jLX00ol0003oi>GConCUd`0;onCUd`07o`000?oLhM[og>7JomcQf_l0003of]ODo`00000:om[Ge0;o
00002ooCdmT2o`0005oooooo0023ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo
c<c<o`00000Eooooo`?o00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?o/jL[ok>W:00[o
k>W:00?o0000onCUdooTiM<02ooTiM<00ol0003og>7JomcQfP03omcQfP;o00002OoJem@00ol0003o
dm?Iom?Cf@0<om?Cf@;o0000G_ooool008?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000001?ooooo0_l0001Booooo`;o00002oo/jLX00ol0003oi>GConCUd`0;onCUd`03
o`000?oLhM[og>7J00Gog>7J00?o0000om[Ge?oJem@01_oJem@00ol0003odm?Iom?Cf@0=om?Cf@;o
0000G_ooool008?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oo
oooo0ol0001Dooooo`03o`000?oYm/ko000000Wok>W:00?o0000onCUdooTiM<02ooTiM<00ol0003o
g>7JomcQfP06omcQfP;o00001_oJem@00ol0003odm?Iom?Cf@0?om?Cf@;o0000GOooool00:Gooooo
0_l0001Fooooo`04o`000?oYm/kojOK>onWfcP;o00001_o/jLX00ol0003oi>GConCUd`0;onCUd`03
o`000?oLhM[og>7J00Oog>7J0_l00005om[Ge003o`000?oCdmWodm?I013odm?I0_l0001Mooooo`00
X_ooool3o`0000;ooooo00?o0000ooooooooool0D_ooool00ol0003ojOK>onWfcP04onWfcP;o0000
0oo/jLX00ol0003oi>GConCUd`0;onCUd`03o`000?oLhM[og>7J00Sog>7J00?o0000omcQf_l00000
0ooJem@00ol0003odm?Iom?Cf@0@om?Cf@04o`000?o<dMgo0000o`0005cooooo002Oooooo`?o0000
FOooool00ol0003ojOK>onWfcP07onWfcP03o`000?o/jL[o000000goi>GC00?o0000omcQf_oLhMX0
2OoLhMX01_l0003og>7JomcQf_l0003of]ODo`0001;odm?I00Co0000olcAgOo<dMgoc=7M0_l0001K
ooooo`00WOooool2o`0005_ooooo00?o0000onWfc_oYm/h02OoYm/h2o`0000coi>GC00?o0000omcQ
f_oLhMX02_oLhMX00ol0003og>7JomcQfP02o`00017odm?I0_l00005olcAg@;o0000F_ooool009[o
oooo0ol0001Looooo`03o`000?oYm/kojOK>00[ojOK>00?o0000on;af?l000002_oTiM<00ol0003o
g>7JomcQfP0;omcQfP05o`000?oLhM[o0000omCLg_l000004?oCdmT00ol0003oc=7MolcAg@05olcA
g@;o0000F_ooool009Sooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000onWfc_oY
m/h02_oYm/h01Ol0003oh_7Hon;af?oRlMSo000000Soi>GC00?o0000omcQf_oLhMX03?oLhMX2o`00
00?oe=cN00?o0000om?CfOoCdmT03?oCdmT00ol0003oc=7MolcAg@07olcAg@;o0000FOooool009Go
oooo0ol0001Pooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP00ooRlMP2o`0000Go
i>GC00?o0000omcQf_oLhMX03OoLhMX00ol0003oe=cNomCLgP03omCLgP03o`000?oCdmWodm?I00Wo
dm?I0_l0000;olcAg@03o`000?oooooooooo05Oooooo001Jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Tooooo`;o0000H_ooool00ol0003ojOK>onWfcP09onWfcP03
o`000?oRlMSoh_7H00Koh_7H00Go0000onCUdooTiM?oi>GCo`00000?omcQfP;o00001_oDg=h00ol0
003odm?Iom?Cf@07om?Cf@03o`000?o<dMgoc=7M00coc=7M00?o0000ooooooooool0E_ooool005[o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A4027ooooo0ol0001Sooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP02?oRlMP0
0ol0003oi>GCo`00000?omcQfP03o`000?oDg=ko000000Ooe=cN00?o0000om?CfOoCdmT01OoCdmT0
0ol0003oc=7MolcAg@0=olcAg@;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0>Oooool005[ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^023ooooo0_l00002ooooo`03o`000?oooooooooo063ooooo
00?o0000onWfc_oYm/h02OoYm/h00ol0003oh_7Hon;af009on;af0?o00003OoLhMX2o`0000?oe=cN
00?o0000omCLg_oDg=h01?oDg=h00ol0003odm?Iom?Cf@03om?Cf@;o00004Oo<dMd2o`0000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0hooooo`00
F_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006Ko
oooo00?o0000onWfc_oYm/h02OoYm/h00ol0003oh_7Hon;af009on;af005o`000?oJjmoof^_Oom[[
gol000002ooLhMX00ol0003oe=cNomCLgP03omCLgP03o`000?oDg=koe=cN00Goe=cN00Go0000om?C
fOoCdmWodm?Io`00000ColcAg@;o00001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool0=oooool005[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo01Sooooo0ol0001Xooooo`03o`000?oYm/kojOK>00WojOK>00?o0000on;af?oRlMP02OoR
lMP00ol0003of^_Oom[[g`03om[[g`03o`000?oLhM[og>7J00Oog>7J00?o0000omCLg_oDg=h01?oD
g=h00ol0003oe=cNomCLgP06omCLgP03o`000?oCdmWo000001?oc=7M00Co0000olK>h?l0003o0000
1_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0>?ooool005[ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Gooooo0ol0001Zooooo`03
o`000?oYm/kojOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`05om[[g`03
o`000?oLhM[og>7J00Gog>7J00?o0000omCLg_oDg=h01OoDg=h00ol0003oe=cNomCLgP06omCLgP;o
00004_o<dMd2o`0000?oa/kP00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`00F_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00000oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oYm/kojOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[
g`07om[[g`03o`000?oLhM[og>7J00?og>7J00?o0000omCLg_oDg=h01_oDg=h00ol0003oe=cNomCL
gP05omCLgP03o`000?o=f>;o0000017oc=7M00?o0000olK>h?o6c^001?o6c^000ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`00F_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Booooo`;o
0000K_ooool00ol0003ojOK>onWfcP08onWfcP03o`000?oRlMSoh_7H00Woh_7H00?o0000om[[gooJ
jml02OoJjml01Ol0003og>7JomcQf_oLhM[o000000Woe=cN00?o0000omCLg_oDg=h01?oDg=h01Ol0
003ocMSRolgHh_o=f>;o000000koc=7M0_l00007olK>h0;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool0>oooool007kooooo0ol0001_ooooo`03o`000?oYm/ko
jOK>00SojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`0;om[[g`03o`000?oLhM[o
000000[oe=cN00?o0000omCLg_oDg=h00_oDg=h2o`0000GocMSR00?o0000olcAgOo<dMd02_o<dMd0
0ol0003oa/kPolK>h008olK>h003o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00003?ooool01OnHV9So0000o`000?m4A4Co^[Zj02Wooooo001looooo`;o000000?o
ooooo`000?ooool0K_ooool00ol0003ojOK>onWfcP08onWfcP03o`000?oRlMSoh_7H00Woh_7H00?o
0000om[[gooJjml03?oJjml2o`0000_oe=cN00Go0000omCLg_oDg=koe=cNo`000008olgHhP03o`00
0?o<dMgoc=7M00Soc=7M00?o0000olK>h?o6c^002Oo6c^02o`0002Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@400Yooooo`00NOooool3o`0007;ooooo00?o0000onWfc_oYm/h02?oYm/h00ol0003oh_7H
on;af009on;af003o`000?oJjmoof^_O00cof^_O00Co0000om;Ui?oBiNCo00002_oDg=h01?l0003o
e=cNo`000?l0000:olgHhP03o`000?o<dMgoc=7M00Goc=7M0_l0000=olK>h0;o00008oooool00ol0
003oooooooooo`0[ooooo`00Moooool2o`0007Cooooo0ol00008onWfcP03o`000?oRlMSoh_7H00Wo
h_7H00?o0000om[[gooJjml03?oJjml00ol0003od^GTom;Ui002om;Ui003o`000?oDg=koe=cN00Oo
e=cN0_l0000<olgHhP03o`000?o<dMgoc=7M00Coc=7M00?o0000olK>h?o6c^003_o6c^000ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02_ooooo001dooooo`?o0000M_ooool00ol0003og?k?
omcnc`05o`0000;ojOK>00?o0000on;af?oRlMP02OoRlMP00ol0003of^_Oom[[g`0<om[[g`03o`00
0?oBiNCod^GT00Cod^GT00?o0000omCLg_oDg=h01_oDg=h00ol0003ocMSRolgHhP0<olgHhP04o`00
0?o<dMgoc=7MolcAg@;o00004Oo6c^02o`0002;ooooo00?o0000ooooooooool0:oooool0077ooooo
0ol000000ooooooo0000ooooo`1eooooo`03o`000?oLo/oog?k?00Kog?k?0ol0000:on;af003o`00
0?oJjmoof^_O00_of^_O0_l00008om;Ui003o`000?oDg=koe=cN00?oe=cN0ol0000?olgHhP03o`00
0?o<dMgo000001?oa/kP0ol0000Oooooo`03oa0@4?l0003o000000?o0000:_ooool006oooooo0_l0
0005ooooo`03o`000?oooooooooo07;ooooo00?o0000omcncooLo/l01_oLo/l01?l0003ofO_MomWk
gOoInmd2o`0000Ooh_7H00?o0000om[[gooJjml02ooJjml00ol0003od^GTom;Ui009om;Ui005o`00
0?oDg=koe=cNomCLg_l000000_o=f>800ol0003ocMSRolgHhP0=olgHhP;o00004oo6c^001?l0003o
`L_Ro`000?l0000Qooooo`03o`000?oooooooooo02_ooooo001/ooooo`?o0000Noooool00ol0003o
g?k?omcnc`06omcnc`03o`000?oInmgofO_M00CofO_M0_l00004on;af003o`000?oJjmoof^_O00_o
f^_O00?o0000om;Ui?oBiN@02ooBiN@00ol0003oe=cNo`000003olgHhP03o`000?o=f>;ocMSR00co
cMSR00?o0000olODi?l000004Oo6c^02o`0000?o`L_R0_l0000Pooooo`03o`000?oooooooooo02_o
oooo0015ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0007gooooo00?o0000omcncooL
o/l01_oLo/l00ol0003ofO_MomWkg@07omWkg@;o000000?oh_7Ho`000?oJjml03?oJjml00ol0003o
d^GTom;Ui00<om;Ui0;o00001?o=f>800ol0003ocMSRolgHhP0:olgHhP;o00000oo7e>@00ol0003o
a/kPolK>h00=olK>h003o`000?o1bn;o`L_R00Co`L_R00?o0000ooooooooool0C?ooool004Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1iooooo`03
o`000?oLo/oog?k?00Kog?k?00?o0000omWkgOoInmd02OoInmd3o`0000cof^_O00?o0000om;Ui?oB
iN@03?oBiN@00ol0003obmoWo`000005olgHhP03o`000?o=f>;ocMSR00SocMSR00?o0000olODi?o7
e>@01?o7e>@00ol0003oa/kPolK>h00:olK>h0;o00001oo1bn82o`0004gooooo0015ooooo`05oa0@
4?ooooooooooooooool@41006oooool2o`00083ooooo00?o0000omcncooLo/l01_oLo/l00ol0003o
fO_MomWkg@09omWkg@05o`000?oCm>KodoCVom?di_l000002OoJjml2o`0000kod^GT00Go0000ol_O
ioo;gnOobmoWo`000004olgHhP03o`000?o=f>;ocMSR00KocMSR0_l00008olODi003o`000?o6c^3o
a/kP00Soa/kP00?o0000ol7;h_o1bn802?o1bn82o`0004cooooo0015ooooo`05o`000?oooooooooo
ooooool000006?ooool3o`00087ooooo00?o0000omcncooLo/l01_oLo/l00ol0003ofO_MomWkg@09
omWkg@03o`000?oCm>KodoCV00?odoCV0_l00006om[[g`03o`000?oBiNCod^GT00cod^GT0_l00005
ol_Oi`05o`000?o=f>;ocMSRolgHh_l000001oo=f>800ol0003oamCTolODi009olODi003o`000?o6
c^3oa/kP00Goa/kP0_l0000<ol7;hP;o0000Boooool004Gooooo00Go0000ooooooooooooooooo`00
000Fooooo`;o0000Poooool00ol0003og?k?omcnc`06omcnc`03o`000?oInmgofO_M00WofO_M00?o
0000om?di_oCm>H01_oCm>H2o`0000?of^_O00?o0000om;Ui?oBiN@03?oBiN@00ol0003obmoWol_O
i`06ol_Oi`04o`000?o=f>;ocMSRo`0000GocMSR0_l0000<olODi003o`000?o6c^3oa/kP00Coa/kP
00?o0000ol7;h_o1bn803Oo1bn800ol0003oooooooooo`19ooooo`00AOooool01Ol@413ooooooooo
oooooooo410@01?ooooo0ol00002ooooo`03o`000?oooooooooo083ooooo00?o0000omcncooLo/l0
1OoLo/l00ol0003ofO_MomWkg@08omWkg@;o00002ooCm>H00ol0003of^_Oo`00000=om;Ui0;o0000
2_o;gnL00ol0003ocMSRo`000004olgHhP03o`000?o7e>CoamCT00goamCT00Co0000olK>h?o6c^3o
a/kP0_l0000@ol7;hP;o0000B_ooool004Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o
0000Qoooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00SofO_M00?o0000om?di_oC
m>H02ooCm>H3o`0000cod^GT00?o0000ol_Oioo;gnL02oo;gnL2o`0000;ocMSR0_l0000AolODi003
o`000?o6c^3o000001?o`L_R00?o0000ooooooooool0B?ooool004Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`;o0000ROooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00So
fO_M00?o0000om?di_oCm>H02ooCm>H01Ol0003ocNcZolg/j_o=k>[o000000[od^GT00?o0000ol_O
ioo;gnL03Oo;gnL00ol0003ocMSRo`00000ColODi0;o00005?o1bn82o`0004Wooooo001Eooooo`?o
000000?oooooo`000?ooool0Qoooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00So
fO_M00?o0000om?di_oCm>H02ooCm>H00ol0003ocNcZolg/jP03olg/jP;o00001_oBiN@2o`0000oo
bmoW0ol0000BolODi0;o000000?o`M3Uo`000?o1bn804Oo1bn82o`000003okg9hol0003o000004So
oooo001Cooooo`;o0000S?ooool00ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00SofO_M
00?o0000om?di_oCm>H02_oCm>H2o`0000SocNcZ0_l00003om;Ui003o`000?o;gnOobmoW00cobmoW
1_l0000AolODi003o`000?o1d>Go`M3U00;o`M3U00?o0000ol7;h_o1bn803Oo1bn82o`0000Co_LWS
00?o0000ooooooooool0A_ooool0053ooooo0ol0002=ooooo`03o`000?oLo/oog?k?00Gog?k?00?o
0000omWkgOoInmd01ooInmd2o`0000codoCV00?o0000olg/j_o=k>X02_o=k>X00ol0003od^GTo`00
000<ol_Oi`?o000000?obmoWo`000?o5fNP00_o5fNP2o`0000koamCT0_l00006ol7@i@03o`000?o1
bn;o`L_R00[o`L_R0_l00007okg9h`03o`000?oooooooooo04Gooooo001?ooooo`;o0000S_ooool0
0ol0003og?k?omcnc`05omcnc`03o`000?oInmgofO_M00OofO_M00?o0000om?di_oCm>H02_oCm>H2
o`0000gocNcZ0ol00009ol_Oi`?o00000_o;gnL2o`0000GoaMWX0_l0000;olODi0;o00002Oo1d>D0
0ol0003o`L_Rol7;hP08ol7;hP03o`000?nmbN?o_LWS00Oo_LWS0_l00016ooooo`00Coooool3o`00
08cooooo00Co0000omcncooLo/oog?k?1ol00007omWkg@03o`000?oCm>KodoCV00[odoCV00?o0000
olg/j_o=k>X03?o=k>X01Ol0003oanC]olOTkOo7i>go000000GobmoW0ol00003ol_Oi`;o00002?o5
fNP2o`0000WoamCT00?o0000ol7@iOo1d>D02_o1d>D00ol0003o`L_Rol7;hP05ol7;hP;o00002onm
bN<00ol0003oooooooooo`14ooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0Qoooool6
o`0000;o_og;00?o0000olGngoo5o]l00_o5o]l4o`0000;ofO_M00?o0000om?di_oCm>H02_oCm>H0
0ol0003ocNcZolg/jP0;olg/jP;o00001Oo7i>d00ol0003obmoWo`000002o`0000GobmoW00?o0000
olGIj?o5fNP02?o5fNP00ol0003oaMWXo`000006olODi0;o00003_o1d>D00ol0003o`L_Rol7;hP02
ol7;hP;o00003_nmbN<2o`0000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool004Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00000_ooool00ol0003oooooooooo`25ooooo`03o`00
0?nooL_o_og;00Go_og;00?o0000olGngoo5o]l01oo5o]l4o`0000WodoCV0_l0000=olg/jP03o`00
0?o7i>goanC]00CoanC]0ol00006ol_Oi`;o00003?o5fNP00ol0003oaMWXo`000003olODi0;o0000
4Oo1d>D01?l0003o`L_Ro`000?l0000@okg9h`;o00001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool004Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o000000Goooooo`000?ooooooooooo`000025
ooooo`03o`000?nooL_o_og;00Go_og;00?o0000olGngoo5o]l01oo5o]l00ol0003oaOW[olGij`02
olGij`?o00001OoCm>H00ol0003ocNcZolg/jP0;olg/jP;o00001?o7i>d3o`0000?oanC]00Co0000
ol_Oioo;gnOobmoW0_l0000?olGIj005o`000?o5fNSo0000olODi?l000004oo1d>D2o`0001?o_LWS
00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`0Mooooo`00A?ooool01Ol@413ooooooooooooooooo410@00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo087ooooo00?o0000okom
bonooL/01?nooL/2o`0000WoaOkO00?o0000olGijoo5nN/01_o5nN/3o`000003om?di_l0003ocNcZ
00cocNcZ00?o0000olOTkOo7i>d00_o7i>d2o`0000OoanC]00?o0000ol_Oiol000004Oo5fNP01?l0
003oaMWXo`000?l0000Bol7@i@;o000000?o_LgVo`000?nmbN<04_nmbN<2o`0000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool07_oo
ool004Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000ooooo`20ooooo`03o`000?nooL_o_og;00Co_og;00?o0000olGngoo5o]l01oo5
o]l2o`0000_oaOW[0ol0000;olg/jP;o00000_o7i>d3o`0000WoanC]0_l0000BolGIj0;o000000?o
`=CYo`000?o1d>D04?o1d>D00ol0003o_LgVokg=iP02okg=iP03o`000?nmbN?o_LWS00ko_LWS0_l0
00000onianCo0000o`000005ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool004Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`1nooooo`03
o`000?nooL_o_og;00Co_og;00?o0000olGngoo5o]l01oo5o]l00ol0003oaOW[olGij`0:olGij`04
o`000?o2l?3o`_3`ol;`l0;o00002?o=k>X00ol0003oanC]o`000002o`0000[oanC]0_l00002ol7M
k@03o`000?o5fNSoaMWX00goaMWX0_l00002ol3Dj@03o`000?o0e>Wo000000ko`M3U0_l00006okg=
iP03o`000?nmbN?o_LWS00_o_LWS0_l00004okW7i003o`000?oooooooooo00?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool08Oooool0
04Cooooo00Go410@oooooooooooooooooa0@4004ooooo`?o00001Oooool2o`000003ooooool0003o
oooo07cooooo00?o0000okombonooL/01?nooL/00ol0003oaOkOolGng`06olGng`;o00002oo5nN/2
o`0000Ko`_3`0_l00004olg/jPCo00003?o7i>d00ol0003o`Mg]ol7Mk@03ol7Mk@03o`000?o5fNSo
aMWX00[oaMWX0_l00005ol3Dj@03o`000?o0e>Wo000000_o`M3U0_l00008okg=iP03o`000?nmbN?o
_LWS00Wo_LWS0_l00007okW7i003o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0Qooooo`00A?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01Oooool2o`000003oooo
ool0003ooooo07Wooooo0_l00006okomb`03o`000?o5o]ooaOkO00KoaOkO00?o0000olGijoo5nN/0
2Oo5nN/2o`0000[o`_3`1Ol0000=olOTk@;o00001oo1gNd00ol0003oaMWXolGIj008olGIj003o`00
0?o0e>Wo`=CY00Go`=CY00Co0000ol3DjOo0e>Wo00002Oo1d>D00ol0003o_LgVokg=iP09okg=iP03
o`000?nmbN?o_LWS00Oo_LWS00?o0000okW7i?nian@01onian@2o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00023ooooo0014ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01?ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?ooool0Moooool00ol0
003o_og;okomb`04okomb`;o00002?o5o]l00ol0003oaOW[olGij`09olGij`03o`000?o2l?3o`_3`
00Wo`_3`1Ol0000<olOTk@;o00002_o1gNd00ol0003oaMWXolGIj005olGIj0;o00002Oo0e>T01?l0
003o`=CYol3DjOl00006ol7@i@;o00003OnmcNH00ol0003o_LWSokg9h`04okg9h`;o00002onian@0
0ol0003oooooooooo`0nooooo`00COooool2o`0000Wooooo1?l0001fooooo`03o`000?nooL_o_og;
00Co_og;00?o0000olGngoo5o]l01_o5o]l2o`0000[oaOW[0_l00009ol;`l0Go00000onoj?800ol0
003oanC]olOTk@08olOTk@03o`000?o1gNgo`Mg]00_o`Mg]00?o0000olGIj?o5fNP00_o5fNP2o`00
00co`=CY00Co0000ol3DjOo0e>Wo00000oo1d>D2o`0000oo_LgV00?o0000okg9honmbN<00_nmbN<2
o`0000go^LOT0_l0000oooooo`00COooool00ol0003oooooooooo`0:ooooo`?o0000M?ooool00ol0
003o_og;okomb`04okomb`03o`000?o5o]ooaOkO00KoaOkO00?o0000olGijoo5nN/02Oo5nN/00ol0
003o`_3`ol;`l006ol;`l0?o00000_o2l?000ol0003o_nSbokoXlP04okoXlP;o00001_o7i>d2o`00
00oo`Mg]00Co0000olGIj?l0003o00003_o0e>T01ol0003o`=CYol3DjOo0e>Wo0000ol7@iOl00000
4_nmcNH01?l0003o_LWSo`000?l0000@okW7i0;o0000?_ooool004gooooo00?o0000ooooooooool0
2oooool3o`0007;ooooo00?o0000okombonooL/01?nooL/00ol0003oaOkOolGng`06olGng`03o`00
0?o5nN_oaOW[00SoaOW[0_l00007ol;`l0;o00000oo2l?02o`0000Wo_nSb00Co0000olOTkOo7i>go
anC]0_l0000Aol7Mk@;o00004Oo0e>T00ol0003o`=CYol3Dj@02o`0001?o_LgV0_l0000CokW7i003
o`000?oooooooooo03cooooo001=ooooo`03o`000?oooooooooo00cooooo1?l0001_ooooo`03o`00
0?nooL_o_og;00;o_og;3_l00007olGij`;o00001_o2l?03o`0000?o`_3`0_l0000<okoXlP03o`00
0?o7i>go0000017o`Mg]0_l00002okgHk@03o`000?o0e>Wo`=CY00oo`=CY0_l000000onkd>Wo0000
okg=iP0@okg=iP;o000000?o^L[Wo`000?nian@04_nian@2o`0003gooooo001<ooooo`;o00003ooo
ool2o`000003ohL00?l0003ooooo06cooooo00?o0000okombonooL/01?l00007oj;gg0;o00001?n^
mnh4o`0000;oaOW[00?o0000ol;`l?o2l?000oo2l?03o`0000Co`_3`0_l0000>okoXlP?o00003oo1
gNd2o`0000Go_MS]00?o0000ol3DjOo0e>T03?o0e>T2o`000005ok_@jOl0003o^m3Yok_@jOl00000
3_nmcNH2o`0000Co^L[W00?o0000okW7i?nian@04?nian@2o`0003gooooo001=ooooo`03o`000?oo
oooooooo00kooooo1Ol0001Zooooo`Co000000?oSNZlo`000?l000001onRmm`00ol0003o[_O^ojkg
kP08ojkgkP?o00000_o2l?03o`0000Go`_3`0_l0000>okoXlP;o00000onkh?800ol0003o`Mg]ol7M
k@0:ol7Mk@;o00002?nmf>d00ol0003o`=CYol3Dj@08ol3Dj@?o00000onkd>T01Ol0003o^m3Yok_@
jOnkd>Wo000000[o_LgV0ol00007okW:i`03o`000?nianCo^LOT00go^LOT0_l000000ongaNGo0000
o`00000looooo`00C?ooool00ol0003oooooooooo`0@ooooo`05o`000?l0B<;o0000ohL00?l00000
Ioooool3o`0000;oSNZl0_l00007oj;gg0;o00002On^mnh2o`0000;o/_7f1?l00006ol;`l003o`00
0?noj?;o_nSb00co_nSb0_l00006ok_PlP03o`000?o1gNgo`Mg]00So`Mg]00?o0000okgHkOnmf>d0
2Onmf>d00ol0003o`=CYol3Dj@05ol3Dj@;o00001onkd>T01Ol0003o^m3Yok_@jOnkd>Wo000000Oo
_LgV0_l0000:okW:i`03o`000?nianCo^LOT00_o^LOT0_l00004okO5i@;o0000>oooool004cooooo
0ol0000Aooooo`04o`000?l0B<;o0000ohL000;o0000I?ooool00ol0003oSNZlohgZ_002ohgZ_003
o`000?nRmmcoX_OL00GoX_OL0_l00009ojkgkP;o000000Co/_7fo`000?l0003o00001?nblOH3o`00
0003ol;`l?l0003o000000go_nSb0_l00009ok_PlP03o`000?o1gNgo`Mg]00Go`Mg]0_l0000=okgH
k@03o`000?o0e>Wo`=CY00;o`=CY0_l0000:ok_@j@05o`000?nkd>Wo^m3Yok_@jOl000001?nmcNH2
o`0000go^L[W00?o0000okW7i?nian@01onian@3o`0000Oo]lGU0_l0000jooooo`00C?ooool00ol0
003oooooooooo`0Booooo`03o`000?l0B<;o000000;oQ`000_l0001Qooooo`04o`000?n=j[coSNZl
ohgZ_0;o00001_nRmm`2o`0000Wo[_O^1Ol00009ok;amP?o00003Onoj?800ol0003o^n3bok_PlP0:
ok_PlP03o`000?o1gNgo`Mg]00;o`Mg]0_l0000@okgHk@04o`000?o0e>Wo0000o`0000go^m3Y00Ko
0000ok_@jOnkd>Wo^m3Yo`000?nmcNH2o`00013o^L[W00?o0000okW7i?nian@01?nian@2o`0000[o
]lGU0_l0000jooooo`00:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04oooool3o`00
00?oQ`000_l0001Mooooo`;o00000on=j[`00ol0003oX_OLoj;gg004oj;gg0;o00002_n^mnh3o`00
00[o/_7f0_l00003ok?Ym`;o00002Onoj?82o`0000ko^n3b00Co0000ol7MkOl0003o00004_nmf>d2
o`0000oo^m3Y00Co0000ok_@jOnkd>Wo^m3Y0_l0000BokW:i`03o`000?nianCo^LOT00;o^LOT0_l0
000=okO5i@;o0000>Oooool002Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Eooooo`Co00000_n70002o`0005[ooooo00Co0000ohgZ_?n=j[coSNZl0_l00006oj;gg003
o`000?n^mnko[_O^00So[_O^0ol0000:ok;amP;o00001oncjOL2o`0000Go_nSb0_l0000@ok_PlP?o
00004Onmf>d2o`0000;o^M?]00?o0000ok_@jOnkd>T03Onkd>T3o`000003okS=j_l0003o^L[W01;o
^L[W00Co0000okW7i?l0003o00004?ngaND00ol0003oooooooooo`0gooooo`00:Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02oooo
o`;o00006?ooool00ol0003o47CRo`000006o`0005Oooooo00?o0000ohgZ_?n=j[`00_l00006oj;g
g0;o00002?n^mnh3o`0000_o/_7f0_l0000;ok?Ym`;o000000?o_nSbo`000?l000004?nkh?82o`00
00?o^=[a00?o0000okgHkOnmf>d03?nmf>d2o`0000Go^M?]00?o0000ok_@jOnkd>T02onkd>T3o`00
00?o^<gZ00?o0000okW:ionib^L04?nib^L2o`0001;o]lGU0_l0000hooooo`00:Oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo01Sooooo00Co0000oa1dh_l0003o00000_n80004o`0005?ooooo0_l00002
ohgZ_004o`000?nRmmcoX_OLoj;gg0[o00000_n^mnh4o`0000_o/_7f0_l0000>ok?Ym`?o00003onk
h?82o`0000Ko^=[a00?o0000okgHkOnmf>d02Onmf>d2o`0000So^M?]00?o0000ok_@jOnkd>T02?nk
d>T2o`0000;o^<gZ00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`0<okW:i`?o000000?o
]/SWo`000?ngaND04_ngaND2o`0003Oooooo000Yooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?l@M>;o47CR00;o00000on80003o`00053ooooo00?o0000ohgZ_?n=j[`0
2Ol00006ohg/k@Oo00002OnblOH2o`0000ko/nWg0_l00003ok;Qm`03o`000?nkh?;o^n3b00[o^n3b
0_l00009okSJl@;o00001onmf>d2o`0000_o^M?]00?o0000ok_@jOnkd>T01Onkd>T2o`0000Go^<gZ
00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`09okW:i`;o00001Onfb>L00ol0003o]lGU
okO5i@0@okO5i@;o0000=oooool002Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0001_ooooo00Go0000oa1dh_l@M>;o
47CRo`000005ohP000;o0000COooool01?l0003oSNZlo`000?l00004og;Qd@;o00001_n=k>d6o`00
00CoVnci1Ol00002ok;amP;o00003_ncjOL2o`0000Ko/^7g0_l00008ok_PlP;o00003Onhf_400ol0
003o_MS]okgHk@02okgHk@;o00003_nidnd00ol0003o^m3Yok_@j@02ok_@j@;o00002?nhcNX00ol0
003o^<gZokS=jP02okS=jP03o`000?nib^Oo^L[W00Ko^L[W0_l00008okK8i`03o`000?ngaNGo]lGU
00co]lGU0ol000000onda>Ko0000o`00000fooooo`00:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06oooool01?l0003o47CRoa1dh_l@M>82o`0000GoR0000_l00019ooooo`Co00000omb
hM43o`0000GoSNc]0ol000000on=k>go0000o`00000<oi_/n@?o00003OncjOL2o`0000[o/^7g0_l0
0004ok_PlP;o00004?nhf_401?l0003o_MS]o`000?l0000AokWCk@04o`000?nkd>Wo0000o`0000_o
^<gZ00?o0000okS=j_nhcNX00_nhcNX00ol0003o^L[WokW:i`02okW:i`?o00002onfb>L00ol0003o
]lGUokO5i@09okO5i@;o00001Onda>H2o`0003Gooooo000Yooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo
01cooooo00?o0000oa1dh_l@M>800_l@M>82o`0000GoR0000ol00015ooooo`?o00000ombhM42o`00
00GoSNc]0ol000001?n=k>go0000o`000?l0000;oi_/n@?o00000onSi_/2o`0000Wo/nWg0_l0000>
ok;Qm`04o`000?nkh?;o0000o`0001;o^=[a0_l0000CokWCk@;o00003OnhcNX00ol0003o^<gZokS=
jP03okS=jP04o`000?nib^Oo0000o`0000ko]/SW00?o0000okO5iOngaND01_ngaND3o`0000So]<CV
00?o0000ooooooooool01oooool4o`000003oa0@4?oooooooooo02Gooooo001;ooooo`03o`000?oo
oooooooo01gooooo00?o0000oa1dh_l@M>800ol@M>800ol0003oR000ohP00005ohP000;o0000@Ooo
ool3o`0000;oL^7A0ol00005ohg/k@;o00000_n=k>d2o`0000coVnci0_l00008oj?Vn`;o00001Onc
jOL2o`00013o/^7g0ol0000AokSJl@;o000000?o]MC`o`000?nidnd04?nidnd2o`000003okK?k?l0
003o^<gZ00go^<gZ00?o0000okS=j_nhcNX00_nhcNX2o`00017o]/SW00?o0000okO5iOngaND00ong
aND2o`0000_o]<CV0_l0000:ooooo`03o`000?oooooooooo02Oooooo001:ooooo`03o`000?oooooo
oooo01oooooo0ol00003oa1dhPOo00000_n80002o`0003cooooo1?l000000ombhM7o0000o`000009
o`000004ohg/kOl0003o0000o`0000_oVnci0ol0000<oj?Vn`;o000000?o/nWgo`000?l000003onb
hOL3o`0000?o/M[e00?o0000okSJlOnhf_403?nhf_42o`0000Co]MC`00?o0000okWCkOnidnd03?ni
dnd2o`0000Co]/o/00?o0000okS=j_nhcNX03?nhcNX01_l0003o^<gZo`000?l0003o]L[Yo`0001;o
]/SW00?o0000okO5iOl000000_l0000>okC4iP;o00002Oooool00ol0003oooooooooo`0Wooooo`00
B_ooool00ol0003oooooooooo`0Qooooo`Go000000?o47CRo`000?l000000omi0009o`0003Gooooo
1ol00005ofGHj0Wo00002_nKk?T2o`00013oXnKk0ol0000>ok;Qm`;o00001onaf_D00ol0003o^=[a
okSJl@08okSJl@?o00001onee?000ol0003o^M?]okWCk@08okWCk@?o00001onfcn`00ol0003o^<gZ
okS=jP0;okS=jP;o00001?neb^T00ol0003o]/SWokK8i`0?okK8i`;o00004Onda>H2o`0000Wooooo
00?o0000ooooooooool09oooool004[ooooo00?o0000ooooooooool08_ooool01?l0003o?Y3_ocj@
kolnT>l5o`0000SoN@001_l0000^ooooo`Ko00001_mUf>P7o`0000GoPN3i1Ol00002oi_/n@?o0000
3onSi_/3o`0000?oYmok0_l00009ok;Qm`?o00002_naf_D00ol0003o^=[aokSJl@05okSJl@;o0000
2onee?000ol0003o^M?]okWCk@05okWCk@;o00002onfcn`00ol0003o^<gZokS=jP07okS=jP?o0000
00?o]L[Yo`000?neb^T01?neb^T00ol0003o]/SWokK8i`0;okK8i`?o000000?o]<KXo`000?nda>H0
4Onda>H2o`0000Sooooo00?o0000ooooooooool09oooool004[ooooo0_l0000Tooooo`03o`000?ln
T>oo?Y3_00Co?Y3_0ol00009ogT000Oo00009_ooool7o`0000KoIMSX1_l0000=oh7Pn@Co00003_nS
i_/3o`0000SoYmok00?o0000ok;QmonbhOL01?nbhOL2o`0000ko/M[e00?o0000okSJlOnhf_400_nh
f_42o`0000ko]MC`00?o0000okWCkOnidnd00_nidnd2o`0000go]/o/00?o0000okS=j_nhcNX01Onh
cNX2o`0000Go]L[Y00?o0000okG:jOneb^T00oneb^T00ol0003o]/SWokK8i`08okK8i`;o00001Ond
a^P00ol0003o]<CVokC4iP0?okC4iP?o00001oooool00ol0003oooooooooo`0Wooooo`00B_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?lnT>oo?Y3_00Ko?Y3_00?o0000ogT00?mi00002Omi0003
o`000003och00?l0003o000000?o00007_ooool:o`0000?oIMSX1_l0000<oh7Pn@Co00001?nAgoh3
o`0000SoXnKk0ol0000<ojOOn`;o000000Co/^7go`000?l0003o00004Onaf_D01?l0003o^=[ao`00
0?l0000AokGDl004o`000?nidngo0000o`00013o]/o/00?o0000okS=j_nhcNX00_nhcNX2o`0000So
]L[Y00?o0000okG:jOneb^T00_neb^T00ol0003o]/SWokK8i`06okK8i`;o00002?nda^P00ol0003o
]<CVokC4iP0;okC4iP?o000000?o//?Vo`000?l000001oooool00ol0003oooooooooo`0Wooooo`00
B_ooool00ol0003oooooooooo`0Uooooo`03o`000?lnT>oo?Y3_00Ko?Y3_0_l0000:ogT000go0000
4_ooool;o`0000Ko?KoP1_l0000<oh7Pn@?o00002onAgoh3o`0000;oXnKk0ol0000@ojOOn`?o0000
4onaf_D3o`0001;o]MC`0_l0000CokK?k004o`000?nhcN[o0000o`0000[o]L[Y00?o0000okG:jOne
b^T00oneb^T00ol0003o]/SWokK8i`02okK8i`?o00002onda^P00ol0003o]<CVokC4iP08okC4iP;o
00001Onb`nH2o`0000Cooooo00?oEEEEofIVI_l00000:Oooool004Wooooo0ol0000Wooooo`03o`00
0?lnT>oo?Y3_00Ko?Y3_0ol00003ogT000Go00002?mL000Po`000003ocfoh?l0003o000000Go0000
1_mUd?P5o`0000?oPN3i1?l0000@oi7OoP?o00004?nWgo/3o`0000?oZ=Wh00?o0000ok7JmOnaf_D0
3Onaf_D3o`0000?o/=Cc00?o0000okGDl?nee?003?nee?03o`0000;o/]3_00?o0000okK?k?nfcn`0
4?nfcn`2o`0000go]L[Y00?o0000okG:jOneb^T00oneb^T01?l0003o]/SWo`000?l0000>okC6j003
o`000?nda>Ko]<CV00Ko]<CV0_l00008ok;3iP;o0000;oooool004Wooooo00?o0000ooooooooool0
:?ooool00ol0003o?Y3_ocj@k`07ocj@k`Co00005?mL000:o`0000Co<@003?l00002ofG@n0;o0000
3OmUd?P4o`00017oTMon0ol00003oi[Jo@03o`000?nWgo_oYmok00_oYmok0_l00007ojSIn003o`00
0?naf_Go/M[e00[o/M[e0_l00007ok3Dl`03o`000?nee?3o]MC`00Wo]MC`0_l00006ok;@k`03o`00
0?nfcnco]/o/00co]/o/0ol00002ok?;k003o`000?neb^Wo]L[Y00_o]L[Y00?o0000okG:jOneb^T0
0_neb^T2o`00017o]<KX00?o0000okC4i_nda>H00_nda>H3o`0000[o//?V0_l0000_ooooo`00;_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Yooooo`Co00001_lnT>l00ol0003o=IKaocFFl@05o`0000_o
G0001?l0000;oc4000So00001_m=_oH3o`0000[oIM3h1Ol00004ogkDo`;o00003?nAgoh3o`0000Oo
V][m0_l00009ojOOn`;o00002_nXfOP2o`0000So/M[e0_l0000:ok3Dl`03o`000?nee?3o]MC`00Ko
]MC`0_l00009ok;@k`03o`000?nfcnco]/o/00Wo]/o/0_l00006ok?;k003o`000?neb^Wo]L[Y00_o
]L[Y1?l000000oncanWo0000okC6j00AokC6j004o`000?nda>Ko0000o`0000ko//?V0_l0000^oooo
o`00;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0:_ooool00ol0003oGJ3doefPm006o`000003ocj@kol0003o=IKa
00Go=IKa1Ol00003oe`000?o00003Ola0006o`0000OoCKof0ol00003odfomP?o00000_mUd?P5o`00
00_oO]Co0ol00006oi7OoP?o00003?nJf_d2o`0000CoYmok0ol0000>ojSIn003o`000?naf_Go/M[e
00;o/M[e0ol0000=ok3Dl`03o`000?nee?3o]MC`00;o]MC`0ol0000<ok;@k`03o`000?nfcnco]/o/
00Ko]/o/0_l00009ok?;k003o`000?neb^Wo]L[Y00Wo]L[Y0_l00005ok?7j@03o`000?nda^So]<KX
00oo]<KX0_l0000Aok;3iP;o0000;Oooool002kooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00;ooooo0ol0000/ooooo`03o`000?mMX?CoGJ3d00GoGJ3d2Ol00004ocFF
l@[o00001ola0005o`0000;o>jkd0ol00002odfomP?o00000om=_oH8o`0001?oO]Co0_l000001?nA
goko0000o`000?l0000Aoi[Jo@04o`000?nWgo_o0000o`0001;oZ=Wh00Co0000ok7JmOl0003o0000
4On`e?<01?l0003o]MC`o`000?l0000@ok;@k`03o`000?nfcnco]/o/00;o]/o/0ol0000<ok?;k003
o`000?neb^Wo]L[Y00Ko]L[Y0_l00002ok?7j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nd
a^P02onda^P3o`000003ok;4j?l0003o//?V013o//?V0_l0000]ooooo`00;_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/ooooo`03
o`000?mMX?CoGJ3d00SoGJ3d00?o0000oeVWn?mIYoP00_mIYoP=o`000003oc>Pl_l0003o000000Ko
00000olk[_@>o`0000SoKLSn0_l0000AogkDo`Co00004_nJf_d4o`0001?oZ=Wh0ol0000Bok3Dl`;o
00004onbd>l01?l0003o]/o/o`000?l0000@ok?;k003o`000?neb^Wo]L[Y00;o]L[Y0ol00005ok?7
j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nda^P02?nda^P2o`0000Go//CX00?o0000ok;3
i_nb`nH03onb`nH2o`0002cooooo000^ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0;Oooool00ol0003oGJ3doefPm008
oefPm003o`000?mIYoSoFJOh00SoFJOh00?o0000oeZ`nomJ/?/00omJ/?/<o`0000;oH;cm0ol00004
of2lo@03o`000?m]b?koKLSn00coKLSn0ol00009ogkDo`Go00001?n=dol2o`0000goV][m0ol00004
oioEn`03o`000?nXfOSoZ=Wh00goZ=Wh0ol00003ojWCmP03o`000?n`e??o/=Cc00co/=Cc0ol00002
ojk@l@03o`000?nbd>oo/]3_013o/]3_0_l0000Cok?;k004o`000?neb^Wo0000o`0000So/lOY00?o
0000ok?7jOncanT00oncanT00ol0003o]<KXokC6j006okC6j0;o00002?nba>P00ol0003o//?Vok;3
iP0>ok;3iP?o0000:oooool002kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;oooool00ol0003oGJ3doefPm008oefPm0;o00002OmI
YoP2o`0000[oF[3k0_l00002of2lo@?o00002?mP_?d2o`0000ooKLSn0_l00002ogkDo`Go00002on=
dol2o`0000OoV][m1?l00008oioEn`;o00002_nXfOP3o`0000OoZM?f00?o0000ok3Dlon`e?<02On`
e?<2o`0000Ko[]3a00?o0000ok;@konbd>l03?nbd>l3o`000003ok7<k_l0003o/l_/01;o/l_/0_l0
000;ok?7j@03o`000?ncanWo/lOY00?o/lOY00?o0000okC6j?nda^P00_nda^P3o`0000_o//CX00?o
0000ok;3i_nb`nH02_nb`nH3o`000003ok32iol0003o000002_ooooo000>ooooo`;o00002oooool0
0ol0003o^[Zjooooo`0<ooooo`;o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool2o`00037ooooo00?o0000oefPm?mMX?@02OmMX?@00ol0003oFJOhoeVW
n008oeVWn003o`000?mJ/?_oF[3k00SoF[3k0ol0000=of2lo@;o00003?m]b?h5o`0001;oSM?o0_l0
0002oi[Jo@?o00003_nOeO/2o`0000GoZ=Wh0ol0000;ojWCmP03o`000?n`e??o/=Cc00Ko/=Cc0_l0
0009ojk@l@03o`000?nbd>oo/]3_00Wo/]3_0_l00005ok7<kP03o`000?ncbnco/l_/00go/l_/0ol0
00000onab>_o0000ok?7j@0;ok?7j@03o`000?ncanWo/lOY00?o/lOY00Co0000okC6j?l0003o0000
3_nba>P00ol0003o//?Vok;3iP07ok;3iP?o00001On``^L2o`0002[ooooo000>ooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`08o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h<oooo
o`Co00001Oooool00ol0003oooooooooo`0aooooo`03o`000?mMX?CoGJ3d00WoGJ3d00?o0000oeVW
n?mIYoP02?mIYoP2o`0000KoF[3k0_l00003oeZ`n`03o`000?mP_?goH;cm00coH;cm00?o0000ofg8
o_m]b?h00_m]b?h7o`0000GoPL_o0_l0000@ohgCo`Co00004onOeO/00ol0003oZ=Who`000002o`00
00ooZM?f00?o0000ok3Dlon`e?<00_n`e?<3o`0000co[]3a00?o0000ok;@konbd>l01_nbd>l2o`00
00So/Lc^00?o0000ok?;k?ncbn`02_ncbn`2o`0000Go/LS[00?o0000ok?7jOncanT02_ncanT00ol0
003o/lOYok?7j@02ok?7j@;o00004Onba>P00ol0003o//?Vok;3iP03ok;3iP?o00002On``^L00ol0
003oooooooooo`0Xooooo`000oooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o
0000odA4A?nj^[X01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03;ooooo00?o
0000oefPm?mMX?@02OmMX?@00ol0003oFJOhoeVWn009oeVWn003o`000?mJ/?_oF[3k00?o00001_mJ
/?/2o`0000OoH;cm2_l0000>oh7;o`;o00002On=dol5o`0000CoU]3l00?o0000oioEnonOeO/03onO
eO/4o`0001;oZM?f00Co0000ok3Dlol0003o00004?n^d?400ol0003o/]3_ok;@k`02ok;@k`?o0000
2onac>h00ol0003o/l_/ok?;k006ok?;k0?o00002?nab>/00ol0003o/lOYok?7j@09ok?7j@03o`00
0?ncanWo000000;o000000?o/LGYo`000?nba>P04Onba>P00ol0003o//?Vo`000002o`0000co/<;W
0_l0000Yooooo`001Oooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooobco00002?mh
`Oh2o`00013oPL_o0_l00002ohgCo`Go00002_nFd?`2o`0000coWmGk0ol00004oj;An003o`000?nY
doKoZM?f00koZM?f1?l0000Bojk@l@04o`000?nbd>oo0000o`0000oo/Lc^00?o0000ok?;k?ncbn`0
0oncbn`2o`0000co/LS[00?o0000ok?7jOncanT02?ncanT2o`0000Go/LGY00?o0000ok;4j?nba>P0
3onba>P2o`00013o/<;W0_l0000Xooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo0_l0000fooooo`03o`000?mbZ_CoLZ[d00[oLZ[d00?o0000og2`n?m`/?P0
0om`/?P3o`0000?oL;3h00?o0000og:hnomb^?/02_mb^?/2o`0000goN<7n0_l0000>oh7;o`Co0000
4OnFd?`2o`0000KoWmGk1?l00008oj;An0;o00002onYdoH3o`0000CoZLoc00?o0000ojk@lOn^d?40
3on^d?43o`00017o/Lc^00?o0000ok?;k?l000000_l0000>ok78j`03o`000?ncanWo/lOY00Ko/lOY
0_l00002ok75j@03o`000?naaNWo/LGY00?o/LGY00?o0000ok;4j?nba>P02onba>P3o`000003ok33
j?l0003o/<;W00oo/<;W0_l0000Xooooo`001Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0=_ooool00ol0003oLZ[dog:Zm00:og:Zm003o`00
0?m`/?So000000;o00001om`/?P2o`0000coL[Sk0_l0000=ogS1oP03o`000?n1boooPL_o00KoPL_o
1Ol00004ohg:o003o`000?nFd?coU]3l013oU]3l00?o0000oioEnonOeO/00ol0000>oj;An003o`00
0?nYdoKoZM?f00CoZM?f1?l00008ojW?l`03o`000?n^d?7o[]3a00_o[]3a0ol00003ojg<l003o`00
0?nac>ko/Lc^00ko/Lc^0_l0000Bok78j`03o`000?ncanWo/lOY00;o/lOY0ol00005ok75j@03o`00
0?naaNWo/LGY00?o/LGY00?o0000ok;4j?nba>P02?nba>P2o`0000Go/<?X00?o0000ok32ion``^L0
3_n``^L2o`0002Oooooo0005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0gooooo`03o`000?mbZ_CoLZ[d00SoLZ[d1?l0000;og2`n003o`00
0?mb^?_oL[Sk00_oL[Sk00?o0000ogS1o_mh`Oh02omh`Oh2o`0000;oPL_o1?l0000:ohg:o0;o0000
3onFd?`4o`0001;oX]7h00?o0000ojWCm_nYdoH00ol0000=ojW?l`03o`000?n^d?7o[]3a00Oo[]3a
0ol00007ojg<l003o`000?nac>ko/Lc^00[o/Lc^0ol00002ojo9k@03o`000?nab>_o/LS[013o/LS[
00Co0000ok?7jOl0003o00002?naaNT00ol0003o/LGYok75j@03ok75j@03o`000?nba>So//CX00Ko
//CX0_l00008ok33j003o`000?n``^Oo/<;W00go/<;W0ol0000Vooooo`000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool06Oooool2o`00
03Wooooo00?o0000og:Zm?mbZ_@01?mbZ_@3o`0000CoLZ[d00?o0000og2`n?m`/?P02Om`/?P2o`00
00coL[Sk0_l00007ogS1oPSo00004?n=b_`2o`0000SoU]3l1Ol00004oi_=n@03o`000?nRdOSoX]7h
00ooX]7h0ol0000AojW?l`03o`000?n^d?7o[]3a00?o[]3a0ol0000;ojg<l003o`000?nac>ko/Lc^
00Ko/Lc^0ol00006ojo9k@03o`000?nab>_o/LS[00oo/LS[0_l0000;ok75j@03o`000?naaNWo/LGY
00?o/LGY00?o0000ok;4j?nba>P00_nba>P3o`0000[o/<?X00?o0000ok32ion``^L02_n``^L3o`00
0003ojo1iol0003o000000Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
00Cooooo00CoA4A4o`000?l0003o<S8b0OoMgMd000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Wooooo00?o0000og:Zm?mbZ_@00ol00008
og:Zm003o`000?m`/?SoL;3h00[oL;3h00?o0000og:hnomb^?/01Omb^?/=o`0000SoQ/?k00?o0000
ohg:o?n=b_`03on=b_`00ol0003oU]3loiK@o005o`0000[oVlgi00?o0000oj;An?nRdOP02onRdOP3
o`0000?oY<ge00?o0000ojW?lonYco<03onYco<00ol0003o[]3ao`000002o`0000oo[Lc`00?o0000
ok7<k_nac>h00onac>h2o`0000[o[lW]00?o0000ok78jonab>/02onab>/3o`000003ok36jol0003o
/LGY00_o/LGY00?o0000ok75jOnaaNT00onaaNT01?l0003o//CXo`000?l0000>ok33j003o`000?n`
`^Oo/<;W00Ko/<;W0ol00005ojo1i`;o00002_ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo0OmgMgL1oc8b<P000_ooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000Kooooo`03o`000?oooooooooo03[ooooo0_l0
000<og:Zm003o`000?m`/?SoL;3h00CoL;3h3Ol00008oh:ln@03o`000?n6`o_oQ/?k00_oQ/?k0_l0
000>ohg:o0Co00004?nKcOT2o`0000SoX]7h0ol00007ojC=m@03o`000?nYco?oZLoc00goZLoc1?l0
000Bojg<l003o`000?nac>ko000000;o00003On_bNd00ol0003o/LS[ok78j`07ok78j`?o00001On`
a^/00ol0003o/LGYok75j@09ok75j@03o`000?naaNWo/LGY00?o/LGY0_l0000@ok33j003o`000?n`
`^Oo/<;W00?o/<;W0ol00009ojo1i`;o00002Oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo0Ol0000004Oooooo0_l0000hooooo`?o000000?oooooo`000?mbZ_@01_mbZ_@<
o`0000SoP;Kf00?o0000oh:lnOn2_?T02on2_?T00ol0003oQ/?kohK3n`0<ohK3n`;o00001on=b_`5
o`0000CoULSi00?o0000oi_=nOnKcOT03onKcOT00ol0003oX]7hoj;An003oj;An0;o00002onTcOD0
0ol0003oZLocojW?l`09ojW?l`?o00001?nZc?400ol0003o[Lc`ojg<l00?ojg<l0;o00004On_bNd0
0ol0003o/LS[ok78j`03ok78j`?o00002On`a^/00ol0003o/LGYok75j@09ok75j@03o`000?naaNWo
000000;o000000?o[lCYo`000?n``nP04?n``nP00ol0003o/<;Wo`000002o`0000co[l7W0_l00009
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool1ogMgM`7o<S8b0016oooo
o`03o`000?oooooooooo03Gooooo0ol00005ooooo`Oo00002?n1/?<00ol0003oP;Kfoh2fmP0:oh2f
mP03o`000?n2_?WoP[ci00_oP[ci0_l0000>ohK3n`03o`000?n=b_coSL[l00Co00002_nEb?T00ol0
003oVlgioi_=n@0?oi_=n@03o`000?nRdOSo000000;o00003_nTcOD00ol0003oZLocojW?l`04ojW?
l`Co00002?nZc?400ol0003o[Lc`ojg<l00;ojg<l0?o000000?o[LW_o`000?n_bNd04On_bNd00ol0
003o/LS[o`000002o`0000go/<K[00?o0000ok75jOnaaNT01onaaNT3o`0000Go[lCY00?o0000ok33
j?n``nP03_n``nP2o`00013o[l7W0_l00008ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIV
I_ooool00oooool01?l0003o8B4Qo`000?lb<S81olc<c0008oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo03;ooooo0ol0000:ooooo`03o`000?n1/??oPK3c00_oPK3c00?o
0000oh2fm_n0]_H02_n0]_H00ol0003oP[cioh:ln@0<oh:ln@03o`000?n6`o_oQ/?k00WoQ/?k1Ol0
000?oiG8n@;o00003_nKcOT4o`00017oY<ge00?o0000ojW?lonYco<00ol0000=oj[<l@03o`000?n]
c?3o[Lc`00Oo[Lc`0ol00005ojg9k`03o`000?n_bNgo[lW]00oo[lW]0_l0000Aok36j`03o`000?na
aNWo/LGY00?o/LGY0ol00003ojo4j@03o`000?n_a>Wo[lCY00?o[lCY00?o0000ok33j?n``nP02_n`
`nP3o`000003ojo2j?l0003o[l7W00oo[l7W0ol00007ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`008oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0_ooooo`?o00003_ooool00ol0003oPK3coh6`l`0;oh6`l`03o`000?n0
]_KoP;Kf00[oP;Kf00?o0000oh:lnOn2_?T03?n2_?T01?l0003oQ/?kohK3non6`o/7o`0000GoT<?h
00?o0000oiG8nOnEb?T03_nEb?T00ol0003oVlgioi_=n@06oi_=n@Go00001?nOb_H00ol0003oY<ge
ojC=m@0=ojC=m@Co00004OnZc?400ol0003o[Lc`ojg<l003ojg<l0?o00002On]bNl00ol0003o[lW]
ojo9k@0;ojo9k@?o000000?o[/O/o`000?n`a^/04On`a^/00ol0003o/LGYo`000002o`0000Ko[lCY
00?o0000ojo4jOn_a>T01?n_a>T00ol0003o/<?Xok33j006ok33j0?o00001On_`^P00ol0003o[l7W
ojo1i`0>ojo1i`;o00001oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`02ooooo`008oooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`;o0000;Oooool3o`0001;o
oooo0_l0000<oh6`l`03o`000?n0]_KoP;Kf00[oP;Kf00?o0000oh:lnOn2_?T02On2_?T6o`0000go
T<?h00?o0000oiG8nOnEb?T03_nEb?T00ol0003oVlgioi_=n@05o`0000[oWl[f0_l0000:ojC=m@?o
00001?nVb_<00ol0003oZ/caoj[<l@0?oj[<l@03o`000?n]c?3o000000;o00003On]bNl00ol0003o
[lW]ojo9k@07ojo9k@?o00001On^an`00ol0003o/<K[ok36j`0?ok36j`;o00002_n_a>T00ol0003o
[lCYojo4j@03ojo4j@03o`000?n``nSo/<?X00?o/<?X0ol00009ojo2j003o`000?n_`NOo[l7W00go
[l7W0_l00005ooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00000Oooool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Yooooo`?o00005oooool00ol0
003oPK3coh6`l`0:oh6`l`03o`000?n0]_KoP;Kf00[oP;Kf00Co0000oh:lnOn2_?WoP[ci1ol00005
ohbmm`03o`000?n@`oSoT<?h00coT<?h0_l0000=oiG8n@Co00004OnOb_H00ol0003oY<geojC=m@04
ojC=m@?o00002?nVb_<00ol0003oZ/caoj[<l@0=oj[<l@?o00004On]bNl00ol0003o[lW]ojo9k@03
ojo9k@?o00002On^an`00ol0003o/<K[ok36j`0;ok36j`?o000000?o[/GZo`000?n_a>T02_n_a>T0
0ol0003o[lCYojo4j@03ojo4j@03o`000?n``nSo000000;o00003?n_`^P00ol0003o[l7Wojo1i`0:
ojo1i`?o000000?oooooo`000?ooool08Oooool002?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02Oooooo0_l0000Kooooo`03o`000?n1/??oPK3c00[oPK3c00?o0000oh2fm_n0]_H01?n0
]_H9o`0000goS;gg00?o0000oi33n?n@`oP03On@`oP00ol0003oULSioiG8n@05oiG8n@Go00001?nJ
a_H00ol0003oWl[foio:mP0?oio:mP03o`000?nTcOGoY<ge00?o00003?nVb_<00ol0003oZ/caoj[<
l@09oj[<l@?o00000onZbO000ol0003o[LW_ojg9k`0?ojg9k`03o`000?n_bNgo000000;o00003On^
an`00ol0003o/<K[ok36j`07ok36j`?o00001On^aNX00ol0003o[lCYojo4j@08ojo4j@03o`000?n_
a>Wo[lCY00?o[lCY0_l0000@ojo2j003o`000?n_`NOo[l7W00Ko[l7W0ol00004ooooo`03o`000?oo
oooooooo023ooooo000Sooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgoooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool3o`0001kooooo00?o
0000oh6`lon1/?<01?n1/?<<o`0000SoRkSd00?o0000ohbmmon<_OL03?n<_OL00ol0003oT<?hoi33
n00=oi33n003o`000?nEb?WoULSi00Co00002_nJa_H00ol0003oWl[foio:mP0=oio:mPCo00004?nV
b_<00ol0003oZ/caoj[<l@04oj[<l@Co00001onZbO000ol0003o[LW_ojg9k`0=ojg9k`?o00004On^
an`00ol0003o/<K[ok36j`03ok36j`?o00002On^aNX00ol0003o[lCYojo4j@08ojo4j@03o`000?n_
a>Wo000000;o000000?o[/?Yo`000?n_`^P03on_`^P00ol0003o[l7Wojo1i`03ojo1i`?o00002?oo
ool00ol0003oooooooooo`0Oooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Kooooo0_l0000Sooooo`?o0000
8_ooool6o`0000SoRkCa00?o0000oh^hm?n;^?@02_n;^?@00ol0003oS;ggohbmm`0<ohbmm`03o`00
0?n@`oSoT<?h00_oT<?h1?l0000?oi[6mP;o00002_nOb_H3o`0000?oX/Sc00?o0000ojK:lonVb_<0
3onVb_<00ol0003oZ/caoj[<l@03o`0000coZ/W`00?o0000ojg9kon]bNl02On]bNl3o`0000;o[<O]
00?o0000ojk7k?n^an`04?n^an`00ol0003o/<K[o`000002o`0000go[/GZ00?o0000ojo4jOn_a>T0
1_n_a>T3o`0000Go[/?Y00?o0000ojo2j?n_`^P03_n_`^P00ol0003o[l7Wo`000002o`0000_ooooo
00?o0000ooooooooool07oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Gooooo00?o0000ooooooooool07oooool3o`0002Kooooo00?o0000oh^dlOn;]?40
2on;]?400ol0003oRkSdoh^hm00:oh^hm003o`000?n<_OOoS;gg00coS;gg00?o0000oi33n?n@`oP0
1On@`oP5o`0000CoUl;e00?o0000oi[6m_nJa_H03_nJa_H00ol0003oWl[foio:mP04oio:mP?o0000
1onRb?<00ol0003oY/[cojK:l`0>ojK:l`?o00004?nZbO000ol0003o[LW_ojg9k`04ojg9k`Co0000
1_n/and00ol0003o[/O/ojk7k00?ojk7k0;o00004?n^aNX00ol0003o[lCYojo4j@03ojo4j@?o0000
0on^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So[l;X00go[l;X0_l0000>ooooo`03o`00
0?oooooooooo01oooooo0015ooooo`03o`000?oooooooooo01cooooo0ol0000Zooooo`03o`000?n;
]?7oRkCa00_oRkCa00?o0000oh^hm?n;^?@02_n;^?@00ol0003oS;ggohbmm`0<ohbmm`03o`000?n@
`oSoT<?h00Co00002_nG`_D00ol0003oV/Kfoi[6mP0>oi[6mP03o`000?nOb_KoWl[f00?o00002onR
b?<00ol0003oY/[cojK:l`0:ojK:l`?o00000_nWao400ol0003oZ/W`oj[9l00?oj[9l003o`000?n]
bNoo[LW_00?o00002on/and00ol0003o[/O/ojk7k00;ojk7k0?o000000?o[LG[o`000?n^aNX04?n^
aNX00ol0003o[lCYo`000002o`0000Ko[/?Y00?o0000ojk3jOn^`nT01?n^`nT00ol0003o[l;Xojo2
j009ojo2j0?o00004?ooool00ol0003oooooooooo`0Oooooo`00AOooool00ol0003oooooooooo`0I
ooooo`?o0000;_ooool00ol0003oRkCaoh^dl@0;oh^dl@03o`000?n;^?CoRkSd00[oRkSd00?o0000
ohbmmon<_OL02On<_OL5o`0000ooUl;e0_l0000=oi[6mPCo00003onRb?<00ol0003oY/[cojK:l`06
ojK:l`?o00001_nWao400ol0003oZ/W`oj[9l00>oj[9l0?o00003on/and00ol0003o[/O/ojk7k007
ojk7k0?o00001On]aN/00ol0003o[/GZojk5jP0>ojk5jP;o00002_n^`nT00ol0003o[/?Yojk3j@03
ojk3j@03o`000?n_`^So[l;X00Ko[l;X0ol0000Cooooo`03o`000?oooooooooo01oooooo0014oooo
o`?o00005oooool3o`0003;ooooo00?o0000oh^dlOn;]?402on;]?400ol0003oRkSdoh^hm00:oh^h
m004o`000?n<_OOoS;ggohbmm`Oo00001OnD__@00ol0003oUl;eoiO2m@0>oiO2m@03o`000?nJa_Ko
V/Kf00GoV/Kf1Ol00004oik5l`03o`000?nRb??oX/Sc00goX/Sc00?o0000ojK:lonVb_<00onVb_<2
o`0000[oYlOa00?o0000oj[9l?nZbO002_nZbO03o`0000;oZ/K^00?o0000ojc7kOn/and03_n/and0
0ol0003o[/O/ojk7k003ojk7k0?o00002On]aN/00ol0003o[/GZojk5jP0:ojk5jP?o000000?o[L?Z
o`000?n^`nT02_n^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So[l;X00?o[l;X0_l0000F
ooooo`03o`000?oooooooooo01oooooo0015ooooo`03o`000?oooooooooo01?ooooo0ol0000foooo
o`03o`000?n;]?7oRkCa00_oRkCa00?o0000oh^hm?n;^?@01?n;^?@9o`0000goU;kd00?o0000oiO2
mOnG`_D03_nG`_D00ol0003oV/Kfoi[6mP04o`0000[oW/Gc00?o0000oj;8lonRb?<03OnRb?<00ol0
003oY/[co`000002o`0000goYlOa00?o0000oj[9l?nZbO001_nZbO03o`0000KoZ/K^00?o0000ojc7
kOn/and03_n/and00ol0003o[/O/o`000002o`0000go[LG[00?o0000ojk5j_n^aNX01_n^aNX3o`00
00Go[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/?Yojk3j@03ojk3j@03o`000?n_`^So0000
00;o00006?ooool00ol0003oooooooooo`0Oooooo`00A?ooool00ol0003oooooooooo`0Booooo`;o
0000>_ooool00ol0003oRkCaoh^dl@08oh^dl@Wo00002?nB^_800ol0003oU;kdoiBnm00<oiBnm0;o
00003OnG`_D4o`0000ooW/Gc00?o0000oj;8lonRb?<02onRb?<4o`00013oYlOa00?o0000oj[9l?nZ
bO000onZbO02o`0000[oZ/K^00?o0000ojc7kOn/and03?n/and3o`00017o[LG[00?o0000ojk5j_n^
aNX00on^aNX2o`0000Wo[L?Z00?o0000ojk3jOn^`nT02?n^`nT00ol0003o[/?Yojk3j@02ojk3j@?o
00007?ooool00ol0003oooooooooo`0Nooooo`00A?ooool2o`00013ooooo0ol0000mooooo`04o`00
0?n;]?7oRkCaoh^dl@Ko00001OnB]_000ol0003oT[[boi:jlP0:oi:jlP03o`000?nD__CoU;kd00go
U;kd00?o0000oiO2mOnG`_D01OnG`_D5o`0000CoVl;c00?o0000oik5lonNaO<03OnNaO<00ol0003o
X/Scoj;8l`05oj;8l`Go00001?nTa_400ol0003oYlOaojO7l@0>ojO7l@03o`000?nZbO3o000000;o
00003OnZa^h00ol0003o[<O]ojc7k@08ojc7k@?o00000on[aN`00ol0003o[LG[ojg5j`0?ojg5j`03
o`000?n^aN[o000000;o00003?n]`nX00ol0003o[/?Yojk3j@08ojk3j@Co00007oooool00ol0003o
ooooooooo`0Nooooo`00A?ooool00ol0003oooooooooo`0<ooooo`?o0000@Oooool3o`0000coT[K`
00?o0000oi:jl_nB^_802_nB^_82o`0000koU;kd00?o0000oiO2mOnG`_D01?l0000:oi_2l`03o`00
0?nNaO?oW/Gc00goW/Gc00?o0000oj;8lonRb?<01?l0000:ojC6l@03o`000?nWao7oYlOa00coYlOa
1?l0000@oj[6kP03o`000?n/ango[<O]00Co[<O]0ol00007oj_5k003o`000?n]aN_o[LG[00go[LG[
0ol0000@ojg3jP03o`000?n^`nWo[/?Y00Co[/?Y1Ol0000Qooooo`03o`000?oooooooooo01kooooo
0014ooooo`03o`000?oooooooooo00Wooooo0ol00016ooooo`03o`000?nB]_3oT[K`00_oT[K`00?o
0000oi:jl_nB^_802onB^_800ol0003oU;kdoiBnm009oiBnm0Go00003onK`_<00ol0003oW/Gcoik5
l`0;oik5l`Co00003onTa_400ol0003oYlOaojO7l@08ojO7l@?o00001?nWaNl00ol0003oZ/K^oj[6
kP0>oj[6kP03o`000?n/ango[<O]00?o00002on[aN`00ol0003o[LG[ojg5j`09ojg5j`?o00000_n/
a>/00ol0003o[L?Zojg3jP0?ojg3jP03o`000?n^`nWo[/?Y00?o00001?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo0014ooooo`03o`000?oooooooooo00Kooooo0ol0001:
ooooo`03o`000?nB]_3oT[K`00_oT[K`00?o0000oi:jl_nB^_802onB^_801?l0003oU;kdoiBnm?nD
__@7o`0000GoVKkb00?o0000oi_2lonK`_<03OnK`_<00ol0003oW/Gcoik5l`05oik5l`Go00001?nQ
a?400ol0003oY<KaojC6l@0=ojC6l@03o`000?nWao7oYlOa00CoYlOa0ol00008ojO5k`03o`000?nZ
a^koZ/K^00coZ/K^1?l0000?oj_5k003o`000?n]aN_o[LG[00Co[LG[1?l00006ojc4j`03o`000?n]
`n[o[L?Z00ko[L?Z0ol00008ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool004Cooooo0_l00004ooooo`?o0000C_ooool00ol0003oT[K`oi:fl00;oi:fl003o`000?nB^_;o
T[[b00SoT[[b1_l0000=oiVnlP03o`000?nK`_?oVl;c00goVl;c00?o0000oik5lonNaO<01?l0000:
oj74l@03o`000?nTa_7oY<Ka00goY<Ka00?o0000ojO7lOnWao400ol0000<ojO5k`03o`000?nZa^ko
Z/K^00SoZ/K^0ol00002ojW5k@03o`000?n[aNcoZlG/00ooZlG/00?o0000ojg5jon]aN/00ol0000;
ojc4j`03o`000?n]`n[o[L?Z00[o[L?Z0ol0000<ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07_ooool004?ooooo00Co0000oooooooooooooooo0ol0001Booooo`03o`000?nB]_3o
T[K`00_oT[K`00Co0000oi:jl_nB^_;oT[[b1_l00005oiRkl003o`000?nI__;oVKkb00coVKkb00?o
0000oi_2lonK`_<02onK`_<4o`0000ooXLCa00?o0000ojC6lOnTa_402onTa_44o`00013oYlG_00?o
0000oj[6k_nZa^h01?nZa^h3o`0000KoZLG]00?o0000oj_5k?n[aN`03_n[aN`3o`0000oo[<C[00?o
0000ojg3j_n]`nX01_n]`nX3o`00013ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Nooooo`00>Oooool4o`000003oa0@4?oooooooooo00?ooooo1?l0001Fooooo`03o`000?nB]_3o
T[K`00SoT[K`1_l0000<oiRkl003o`000?nI__;oVKkb00coVKkb00?o0000oi_2lonK`_<01OnK`_<5
o`0000?oW/7a00?o0000oj74lOnQa?403_nQa?400ol0003oY<KaojC6l@05ojC6l@Go00001?nUa>l0
0ol0003oYlG_ojO5k`0>ojO5k`03o`000?nZa^koZ/K^00?o00002_nYaNd00ol0003oZlG/oj_5k00:
oj_5k0?o000000?oZlC/o`000?n/a>/04?n/a>/00ol0003o[L?Zojg3jP03ojg3jP;o00004oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo000kooooo`03o`000?oooooooooo
00Gooooo0_l0001Iooooo`04o`000?nB]_3oT[K`oi:fl0Ko00001OnG^>h00ol0003oV;_`oiRkl00;
oiRkl003o`000?nI__;oVKkb00coVKkb00?o0000oi_2lonK`_<01?l00009oik1l@03o`000?nQa?7o
XLCa00koXLCa00?o0000ojC6lOnTa_401?l0000:ojG4k`03o`000?nWaNooYlG_00coYlG_1?l0000>
ojW5k@03o`000?n[aNcoZlG/00KoZlG/0ol00005oj_4k003o`000?n/a>_o[<C[00oo[<C[00?o0000
ojg3j_l000000_l0000Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Gooooo`?o00003?nG^>h00ol0
003oV;_`oiRkl00;oiRkl003o`000?nI__;oVKkb00[oVKkb1?l0000>oik1l@03o`000?nQa?7oXLCa
00coXLCa1?l0000?ojG4k`03o`000?nWaNooYlG_00SoYlG_0ol00002ojS4kP03o`000?nYaNgoZLG]
00koZLG]00?o0000oj_5k?n[aN`00on[aN`2o`0000WoZlC/00?o0000ojc4jon/a>/03On/a>/3o`00
01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`00>oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Oooooo00?o0000oiNhk_nG^>h03?nG^>h00ol0003o
V;_`oiRkl00;oiRkl003o`000?nI__;oVKkb00GoVKkb1?l00004oifnl003o`000?nN`O7oW/7a00co
W/7a00?o0000oj74lOnQa?402?nQa?43o`0000?oXl;_00?o0000ojG4konUa>l03_nUa>l00ol0003o
YlG_ojO5k`04ojO5k`?o00001_nXa>h00ol0003oZLG]ojW5k@0>ojW5k@03o`000?n[aNco000000;o
00003?n[a>`00ol0003o[<C[ojc4j`09ojc4j`?o00007Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01gooooo000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Eoooool00ol0003oUkS^oiNhkP0<oiNhkP03o`000?nH^o3oV;_`00_oV;_`00?o0000oiVnl_nI__80
1?l00009oifnl003o`000?nN`O7oW/7a00coW/7a00?o0000oj74lOnQa?401?nQa?43o`0000OoXl;_
00?o0000ojG4konUa>l03_nUa>l00ol0003oYlG_ojO5k`03o`0000[oZ<C^00?o0000ojW5kOnYaNd0
3?nYaNd3o`00013oZlC/00?o0000ojc4jon/a>/01?n/a>/4o`00027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Mooooo`00>oooool00ol0003oooooooooo`0:ooooo`;o0000F?oo
ool00ol0003oUkS^oiNhkP0<oiNhkP03o`000?nH^o3oV;_`00SoV;_`1Ol0000>oifnl003o`000?nN
`O7oW/7a00coW/7a00?o0000oj74lOnQa?400ol0000;oj?2k`03o`000?nUa>ooYLC_00coYLC_1?l0
000>ojS4kP03o`000?nYaNgoZLG]00SoZLG]0ol00003ojW3k003o`000?n[a>coZlC/00koZlC/00?o
0000ojc4jon/a>/00ol0000Vooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Ooo
ool003_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Fooooo`03o`000?nG^>ko
UkS^00coUkS^00Co0000oiRkl?nH^o3oV;_`1_l00004oiblk`03o`000?nM__3oWKk`00goWKk`00?o
0000oik1lOnN`O402_nN`O44o`0000ooXl;_00?o0000ojG4konUa>l02?nUa>l3o`0000?oY/?^00?o
0000ojS4k_nXa>h03OnXa>h00ol0003oZLG]ojW5k@04ojW5k@?o00001onY`n`00ol0003oZlC/oj_4
k00<oj_4k0Co0000:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01gooooo000i
ooooo`03oeEEEOmVIVKo000000oooooo00?o0000ooooooooool0E_ooool00ol0003oUkS^oiNhkP0:
oiNhkPGo00002onL_>l00ol0003oWKk`oifnl00=oifnl003o`000?nN`O7oW/7a00GoW/7a1?l00004
oj70k`03o`000?nS`^ooXl;_00goXl;_00?o0000ojG4konUa>l01?nUa>l3o`0000OoY/?^00?o0000
ojS4k_nXa>h03OnXa>h00ol0003oZLG]ojW5k@03o`0000_oZL?/00?o0000oj_4k?n[a>`02?n[a>`3
o`0002kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`00C?ooool00ol0
003oooooooooo`1Fooooo`03o`000?nG^>koUkS^00GoUkS^1?l00003oi^ik@03o`000?nL_>ooW;c_
00_oW;c_00?o0000oifnl?nM__003OnM__000ol0003oW/7aoik1l@04o`0000WoXL3_00?o0000oj?2
konS`^l03OnS`^l00ol0003oYLC_ojG4k`03o`0000_oY/?^00?o0000ojS4k_nXa>h02onXa>h4o`00
00ooZL?/00?o0000oj_4k?n[a>`01?n[a>`3o`0003;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Looooo`00COooool2o`0005Oooooo00?o0000oiNhk_nG^>h01?l00008oi^ik@03
o`000?nL_>ooW;c_00_oW;c_00?o0000oifnl?nM__002onM__04o`0000koXL3_00?o0000oj?2konS
`^l02onS`^l4o`0000ooY/?^00?o0000ojS4k_nXa>h01OnXa>h5o`0000?oZ<?]00?o0000ojW3k?nY
`n`03_nY`n`00ol0003oZlC/oj_4k003o`0003Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Looooo`00Coooool00ol0003oooooooooo`1Eooooo`;o00003OnK^Nd00ol0003oW;c_
oiblk`0;oiblk`03o`000?nM__3oWKk`00GoWKk`1Ol00004oinnkP03o`000?nQ`>ooXL3_00coXL3_
00?o0000oj?2konS`^l01OnS`^l5o`0000?oY<7^00?o0000ojK3k_nV`nh03_nV`nh00ol0003oZ<C^
ojS4kP04o`0000WoZ<?]00?o0000ojW3k?nY`n`03?nY`n`4o`0003[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Looooo`00D?ooool00ol0003oooooooooo`1Eooooo`03o`000?nK
^NgoVkW]00coVkW]00?o0000oiblkonL_>l02onL_>l00ol0003oWKk`oifnl004o`0000[oWkk^00?o
0000oj70konQ`>l03?nQ`>l00ol0003oXl;_oj?2k`04o`0000WoY<7^00?o0000ojK3k_nV`nh03?nV
`nh4o`0000koZ<?]00?o0000ojW3k?nY`n`02?nY`n`3o`0003kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Looooo`00DOooool00ol0003oooooooooo`1Eooooo`03o`000?nK^Ngo
VkW]00coVkW]00?o0000oiblkonL_>l02?nL_>l5o`0000ooWkk^00?o0000oj70konQ`>l02_nQ`>l4
o`0000koY<7^00?o0000ojK3k_nV`nh02?nV`nh3o`0000?oYl;]00?o0000ojS3kOnX`nd03OnX`nd0
0ol0003oZL?/ojW3k004ojW3k0?o0000@_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01cooooo001Booooo`03o`000?oooooooooo05Gooooo00?o0000oi^ikOnK^Nd03?nK^Nd01?l0
003oW;c_oiblkonL_>l6o`0000GoWkc]00?o0000oinnk_nO_^h03OnO_^h00ol0003oXL3_oj70k`05
oj70k`Co00001?nS`>h00ol0003oY<7^ojC1kP0<ojC1kP03o`000?nV`nkoY/?^00CoY/?^0ol00007
ojO2k@03o`000?nX`ngoZ<?]00goZ<?]00?o0000ojW3k?nY`n`00ol00016ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool07?ooool005?ooooo0_l0001Fooooo`03o`000?nK^NgoVkW]
00[oVkW]1Ol0000<oinlk@03o`000?nO_^koWkk^00goWkk^00?o0000oj70konQ`>l01?l00009oj?0
kP03o`000?nT`NkoY<7^00coY<7^00?o0000ojK3k_nV`nh00ol0000;ojO2k@03o`000?nX`ngoZ<?]
00coZ<?]0ol00019ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool005Go
oooo00?o0000ooooooooool0E?ooool00ol0003oVkW]oi^ik@05oi^ik@Co00000onN^^`00ol0003o
Wkc]oinlk@0<oinlk@03o`000?nO_^koWkk^00_oWkk^1?l0000>oj?0kP03o`000?nT`NkoY<7^00[o
Y<7^1?l0000?ojO2k@03o`000?nX`ngoZ<?]00SoZ<?]0ol0001=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool06oooool005Kooooo00?o0000ooooooooool0E?ooool00ol0003oVkW]
oi^ik@04o`0000SoW[[/00?o0000oinlkOnO_>d03?nO_>d00ol0003oWkk^oinnkP05oinnkPGo0000
0onR_^d00ol0003oXl3^oj?0kP0=oj?0kP03o`000?nT`NkoY<7^00GoY<7^1?l00004ojG1k@03o`00
0?nW`^goYl;]00goYl;]00?o0000ojS3kOnX`nd01?nX`nd3o`00057ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Kooooo`00Eoooool00ol0003oooooooooo`1Dooooo`;o00003OnN
^^`00ol0003oWkc]oinlk@0<oinlk@03o`000?nO_^koWkk^00Co00002OnR_^d00ol0003oXl3^oj?0
kP0=oj?0kP03o`000?nT`NkoY<7^00Co00002OnU`Nd00ol0003oYl;]ojO2k@0=ojO2k@03o`000?nX
`ngoZ<?]00?o0000EOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo001H
ooooo`;o0000E_ooool00ol0003oW[[/oijjk00;oijjk003o`000?nO_>goWkc]00[oWkc]1?l0000>
oj:nk@03o`000?nS`>koXl3^00coXl3^0ol0000>ojG1k@03o`000?nW`^goYl;]00_oYl;]1?l0001H
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06oooool005[ooooo00?o0000oooo
ooooool0E?ooool00ol0003oW[[/oijjk00;oijjk003o`000?nO_>goWkc]00GoWkc]1?l00003oj6m
k003o`000?nR_^goX[k]00goX[k]00?o0000oj?0k_nS`>h02?nS`>h3o`0000;oY;o]00?o0000ojG1
kOnU`Nd03OnU`Nd00ol0003oYl;]ojO2k@05ojO2k@Go0000GOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01_ooooo001Kooooo`03o`000?oooooooooo05Cooooo00?o0000oijjk?nN
^^`02onN^^`00ol0003oWkc]oinlk@04o`0000SoXKg/00?o0000oj:nkOnR_^d03OnR_^d00ol0003o
Xl3^oj?0kP04oj?0kP?o00001_nT_nd00ol0003oYL7]ojG1k@0=ojG1k@03o`000?nW`^goYl;]00Co
0000Hoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo001Looooo`03o`00
0?oooooooooo05Cooooo00?o0000oijjk?nN^^`02OnN^^`4o`0000goXKg/00?o0000oj:nkOnR_^d0
3OnR_^d00ol0003oXl3^oj?0kP03o`0000[oY;o]00?o0000ojG1kOnU`Nd03?nU`Nd3o`0006Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`00GOooool2o`0005Gooooo00?o
0000oijjk?nN^^`01?nN^^`4o`0000CoXK_[00?o0000oj6mk?nQ_N`02onQ_N`00ol0003oX[k]oj:n
k@0;oj:nk@Co00003_nT_nd00ol0003oYL7]ojG1k@08ojG1k@?o0000Joooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01[ooooo001Oooooo`03o`000?oooooooooo05?ooooo00?o0000
oijjk?nN^^`00ol00009oj6kj`03o`000?nQ_NcoXKg/00_oXKg/00?o0000oj:nkOnR_^d01OnR_^d5
o`0000?oXkk/00?o0000ojBokOnT_nd03OnT_nd00ol0003oYL7]ojG1k@04ojG1k@?o0000Koooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo001Pooooo`03o`000?oooooooooo
05?ooooo0_l0000=oj6kj`;o00003?nQ_N`00ol0003oX[k]oj:nk@04o`0000WoXkk/00?o0000ojBo
kOnT_nd03OnT_nd00ol0003oYL7]ojG1k@03o`0007?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Jooooo`00HOooool00ol0003oooooooooo`1Dooooo`03o`000?nQ^n_oXK_[00co
XK_[00?o0000oj6mk?nQ_N`01onQ_N`5o`0000koXkk/00?o0000ojBokOnT_nd02onT_nd4o`0007Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`00H_ooool2o`0005Gooooo
00?o0000oj6kjonQ^n/03?nQ^n/01?l0003oXKg/oj6mk?nQ_N`5o`0000GoXkg/00?o0000oj>nk?nS
_^`03?nS_^`00ol0003oY;o]ojBok@05ojBok@Go0000Noooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01[ooooo001Tooooo`03o`000?oooooooooo05?ooooo00?o0000oj6kjonQ^n/0
2_nQ^n/5o`0000_oXkg/00?o0000oj>nk?nS_^`03?nS_^`00ol0003oY;o]ojBok@04o`00087ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`00IOooool00ol0003ooooooooo
o`1Cooooo`03o`000?nQ^n_oXK_[00GoXK_[1?l00002oj>kj`03o`000?nS_NcoXkg/00coXkg/00?o
0000oj>nk?nS_^`02_nS_^`4o`0008Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`00I_ooool00ol0003oooooooooo`1Cooooo`03o`000?nQ^n_oXK_[00Co00001onS^n/0
0ol0003oXkg/oj>mk00<oj>mk003o`000?nS_^coXkk/00GoXkk/1?l0002:ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06Oooool006Oooooo00?o0000ooooooooool0Doooool2o`00
00coXk_[00?o0000oj>mk?nS_N`03?nS_N`00ol0003oXkk/oj>nk004o`0008oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Iooooo`00J?ooool2o`0005Cooooo00?o0000oj>kjonS
^n/02onS^n/00ol0003oXkg/oj>mk00:oj>mk0Co0000U?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Wooooo001Zooooo`03o`000?oooooooooo05;ooooo00?o0000oj>kjonS^n/0
2onS^n/00ol0003oXkg/oj>mk005oj>mk0Co0000V?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Wooooo001[ooooo`03o`000?oooooooooo05;ooooo00?o0000oj>kjonS^n/02onS
^n/00ol0003oXkg/oj>mk004o`0009gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Iooooo`00K?ooool00ol0003oooooooooo`1Booooo`03o`000?nS^n_oXk_[00WoXk_[1?l0002R
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool006gooooo0_l0001Coooo
o`03o`000?nS^n_oXk_[00CoXk_[1?l0002Wooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool006oooooo00?o0000ooooooooool0DOooool00ol0003oXk_[oj>kj`03o`000:_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`00L?ooool00ol0003ooooo
ooooo`1Aooooo`;o0000[oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo
001aooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Sooooo001booooo`;o0000D?ooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool007Cooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06?ooool007Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool007Kooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool007Oooooo0_l0001;ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Gooooo`00NOooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo0;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`00N_ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Gooooo`00Noooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0;Go
oooo00Go0000ooooooooooooooooo`00000Iooooo`00O?ooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo0;Kooooo00Go0000ooooooooooooooooo`00000Iooooo`00OOooool2o`0004Co
oooo00?o0000ooooooooool0]oooool01?l0003oooooooooool0000Iooooo`00Ooooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooool000006Oooool0083ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2hooooo`04o`000?ooooooooooo`0001So
oooo0021ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
o`00000Hooooo`00P_ooool2o`0003oooooo00?o0000ooooooooool0^_ooool2o`0001Sooooo0024
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0^Oooool3o`0001Sooooo0025oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]Oooool4o`0001_ooooo0026ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0/Oooool4o`0001oooooo0027ooooo`;o0000
>_ooool00ol0003oooooooooo`2^ooooo`?o00008oooool008Wooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`2Zooooo`Co00009_ooool008[ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`2Vooooo`Co0000:_ooool008_ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`2Rooooo`Co0000;_ooool008cooooo0_l0000eooooo`03o`000?oooooooooo09ko
oooo1?l0000booooo`00S_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09[ooooo
1?l0000fooooo`00Soooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Oooooo0ol0
000jooooo`00T?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09?ooooo1?l0000m
ooooo`00TOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08oooooo1?l00011oooo
o`00T_ooool2o`0002oooooo00?o0000ooooooooool0Roooool4o`0004Gooooo002Dooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0Qoooool4o`0004Wooooo002Eooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0Poooool4o`0004gooooo002Fooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0Ooooool4o`00057ooooo002Gooooo`;o0000:_ooool00ol0
003oooooooooo`1looooo`?o0000EOooool009Wooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1iooooo`Co0000F?ooool009[ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1eooooo`Co0000G?ooool009_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1aooooo`Co0000H?ooool009cooooo0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001T
ooooo`00W_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Xoooo
o`00Woooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo0ol0001/ooooo`00
X?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;ooooo1?l0001_ooooo`00XOoo
ool2o`0001oooooo00?o0000ooooooooool0G_ooool4o`0007?ooooo002Sooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0F_ooool4o`0007Oooooo002Tooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0E_ooool4o`0007_ooooo002Uooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0D_ooool4o`0007oooooo002Vooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0Coooool3o`0008?ooooo002Wooooo`;o00006Oooool00ol0003ooooooooo
o`1;ooooo`Co0000Q_ooool00:Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17
ooooo`Co0000R_ooool00:[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13oooo
o`Co0000S_ooool00:_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co
0000T_ooool00:cooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo1?l0002Fooooo`00[_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo0ol0002Jooooo`00[oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo1?l0002Mooooo`00/?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo1?l0002Qooooo`00/Oooool2o`0000oo
oooo00?o0000ooooooooool0;?ooool4o`000:Gooooo002cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:?ooool4o`000:Wooooo002dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09?ooool4o`000:gooooo002eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool4o`000;7ooooo002fooooo`;o00002Oooool00ol0003oooooooooo`0Noooo
o`?o0000]Oooool00;Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`Co
0000^?ooool00;Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000
_?ooool00;[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000`?oo
ool00;_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000a?ooool0
0;cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l00038ooooo`00__ooool01?l0003o
ooooooooool00009ooooo`?o0000c?ooool00;oooooo00?o0000ooooool000001Oooool4o`000<oo
oooo0030ooooo`;o000000?oooooo`000?l000000_l0003Cooooo`00`Oooool2o`000=Oooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 409.75}, {332.188, 0}} -> {-0.2017, -0.068318, \
0.0037428, 0.0037428}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Von Neumann  and Mixed Boundary Conditions", "Section",
  CellTags->{"i:24", "c:20"}],

Cell[TextData[{
  "Grid methods can also be employed in problems involving von Neumann  or \
mixed boundary conditions. Take, for example,  a heat flow problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  "  with  a boundary condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = \(-\[CapitalGamma]\)\)]],
  ".  This von Neumann  condition can be met by finite-differencing the \
derivative at the boundary  ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(T\_1\%n - T\_0\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], 
          "=", \(\(-\[CapitalGamma]\)/\[Kappa]\)}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.19)"],

Cell["\<\
from which we can obtain the boundary-value for the temperature in \
terms of the interior points:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), " ", "=", 
          RowBox[{\(T\_1\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], 
              " ", \(\(\[CapitalGamma]/\[Kappa]\)\(\ \)\)}]}]}], 
        TraditionalForm]]],
  ". "
}], "NE2",
  CellTags->"(6.2.20)"],

Cell[TextData[{
  " \t On the other hand, the left-hand side of Eq. ",
  ButtonBox["(6.2.19)",
    ButtonData:>"(6.2.19)",
    ButtonStyle->"Hyperlink"],
  " is a forward-difference form for the derivative at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", and is only first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". Thus, the error in our numerical method will scale only as the first \
power of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". This is unfortunate, because the centered-difference equations used for \
the interior points are all of second-order accuracy in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". It would be better to use a more accurate approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\^\[Prime]\)(x = 0, t)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t One simple improvement is to place the boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " ",
  StyleBox["halfway",
    FontSlant->"Italic"],
  " ",
  StyleBox["between",
    FontSlant->"Italic"],
  " the grid points ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ". Then we can use a ",
  StyleBox["centered-difference",
    FontSlant->"Italic"],
  " form for the von Neumann boundary condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(T\^\[Prime]\)(x = 0, t)\), "\[Rule]", " ", 
            RowBox[{\([T\_1\%n - T\_0\%n]\), "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], 
          "=", \(\(-\[CapitalGamma]\)/\[Kappa]\)}], TraditionalForm]]],
  ". The equation is the same as before, but now it is second-order rather \
than first-order accurate. The only change that we need make is to the \
location of the grid points. Now,  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "(", \(j - 1/2\), ")"}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\)]],
  "."
}], "NE2",
  CellTags->"(6.2.21)"],

Cell[TextData[{
  "Considering now the  the boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", if this condition is also von Neumann , then ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " must fall between the ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  "st and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th points in order to employ the same centered-difference scheme there. \
Therefore,  Eq. ",
  ButtonBox["(6.2.21)",
    ButtonData:>"(6.2.21)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "(", \(M - 1/2\  - \ 1/2\), 
            ")"}]}], TraditionalForm]]],
  " and so ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". On the other hand, if the boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " is Dirichlet, then we need to have the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th grid point fall at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and this implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1/2)\)\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor example, consider the heat equation with insulating boundary \
conditions at both ends, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = \(\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                  L\)\)\) = 0\)\)]],
  " . For the grid we use Eq. ",
  ButtonBox["(6.2.21)",
    ButtonData:>"(6.2.21)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". For this example, we take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L = 1\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1/4\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{",", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "=", "0.05"}]}], 
        TraditionalForm]]],
  " and set source terms equal to zero:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 10;\)\), "\n", 
    \(\(L = 1. ;\)\), "\n", 
    \(\(\[CapitalDelta]x = L/\((M - 1)\);\)\), "\n", 
    \(\(x[j_]\  = \ \[CapitalDelta]x \((j - 1/2)\);\)\), "\n", 
    \(\(\[Chi]\  = \ 1/4;\)\), "\n", 
    \(\(\[CapitalDelta]t\  = \ 0.05;\)\), "\n", 
    \(\(S[j_, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.67"],

Cell[TextData[{
  "According to  Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  " the boundary conditions are satisfied by  the equations"
}], "Text"],

Cell[BoxData[{
    \(\(T[0, n_]\  = \ T[1, n];\)\), "\n", 
    \(\(T[M, n_]\  = \ T[M - 1, n];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.68"],

Cell["\<\
For the initial condition, we again choose a single Fourier mode as \
a test, but this time we choose a cosine mode so as to satisfy the boundary \
conditions:\
\>", "Text"],

Cell[BoxData[
    \(\(T0[x_]\  = \ Cos[\ Pi\ x\ /L];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.69"],

Cell[TextData[{
  "In theory this mode should decay away exponentially at the rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\ \((\[Pi]/L)\)\^2\)]],
  ". We can now run any of our previously discussed methods to solve for the \
temperature evolution. We use the Crank-Nicolson module created in the \
previous section, and plot the result in Cell ",
  ButtonBox["6.71",
    ButtonData:>"Cell 6.71",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol[0]\  = \ 
      Table[T[j, 0] \[Rule] \ T0[x[j]], {j, 1, M - 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.70"],

Cell[BoxData[
    \({T[1, 0] \[Rule] 0.984807753012208`, 
      T[2, 0] \[Rule] 0.8660254037844387`, 
      T[3, 0] \[Rule] 0.6427876096865394`, 
      T[4, 0] \[Rule] 0.3420201433256688`, 
      T[5, 0] \[Rule] 6.123233995736766`*^-17, 
      T[6, 0] \[Rule] \(-0.3420201433256685`\), 
      T[7, 0] \[Rule] \(-0.6427876096865394`\), 
      T[8, 0] \[Rule] \(-0.8660254037844384`\), 
      T[9, 0] \[Rule] \(-0.984807753012208`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = \ 
        Table[ListPlot[Table[{x[j], \ T[j, n]}, {j, 0, M}] /. sol[n], 
            PlotJoined \[Rule] True, PlotRange \[Rule] {{0, L}, {\(-1\), 1}}, 
            AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
            PlotLabel \[Rule] "\<T[x,t],t=\>" <> 
                ToString[\[CapitalDelta]t\ n], 
            DisplayFunction \[Rule] Identity], {n, 0, 40, 5}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ t/
                      L\^2\)\) Cos[Pi\ x/L], {x, 0, L}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {RGBColor[1, 0, 0], 
                Dashing[{0.05, 0.05}]}], {t, 0, 40\ \[CapitalDelta]t, 
            5\ \[CapitalDelta]t}];\)\ \), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.71"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61334 m
.05556 .61334 L
.16667 .57663 L
.27778 .50765 L
.38889 .41471 L
.5 .30902 L
.61111 .20333 L
.72222 .11038 L
.83333 .0414 L
.94444 .00469 L
s
.94444 .00469 m
1 .00469 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .61803 m
.00123 .61803 L
.00236 .61803 L
.00365 .61801 L
.00488 .618 L
.00706 .61796 L
.00942 .6179 L
.01203 .61781 L
.01479 .6177 L
.01975 .61744 L
.02486 .61709 L
.02966 .61669 L
.04057 .61553 L
.0517 .61397 L
.06188 .61221 L
.08481 .60713 L
.10474 .60145 L
.1265 .59395 L
.16918 .5754 L
.21027 .55303 L
.25393 .52481 L
.296 .49378 L
.33648 .46088 L
.37953 .4232 L
.42099 .38493 L
.46086 .34692 L
.50331 .30581 L
.54416 .26628 L
.58759 .22505 L
.62943 .1868 L
.66967 .15199 L
.7125 .11771 L
.75372 .08797 L
.79336 .06286 L
.83558 .04032 L
.8762 .02308 L
.89683 .01609 L
.91939 .00985 L
.94095 .0053 L
.95057 .00372 L
.961 .00232 L
.96647 .00171 L
.97151 .00124 L
.97624 .00086 L
.98143 .00053 L
.98609 .00029 L
.99045 .00014 L
.99286 8e-05 L
.99505 4e-05 L
.99627 2e-05 L
Mistroke
.99759 1e-05 L
.99884 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo9_ooool3ool001Co
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool5ool0017o00005?oo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`kooooo1Ooo0003
o`0002Oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool;oooo
o`?oo`000_ooool3o`0002[ooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooo`Wo
oooo0ooo0002ooooo`?o0000;Oooool002Wooooo00?o0000ooooooooool0ooooool:ooooo`?o0000
<?ooool002Wooooo00?o0000ooooooooool0ooooool7ooooo`?o0000<oooool002Wooooo00?o0000
ooooooooool0ooooool4ooooo`?o0000=_ooool002Wooooo0_l0003oooooo`;ooooo0ol0000ioooo
o`00:Oooool00ol0003oooooooooo`3mooooo`?o0000??ooool002Wooooo00?o0000ooooooooool0
n?ooool3ool000;o0000?oooool002Wooooo00?o0000ooooooooool0mOooool3ool000;o0000@_oo
ool002Wooooo00?o0000ooooooooool0loooool2ool000;o0000AOooool002Wooooo0_l0003boooo
o`;oo`0000?o0000ooooooooool0A_ooool002Wooooo00?o0000ooooooooool0koooool2ool000;o
0000BOooool002Wooooo00?o0000ooooooooool0kOooool2ool000;o0000Boooool002Wooooo00?o
0000ooooooooool0k?ooool00ooo003oooooo`00001=ooooo`00:Oooool00ol0003oooooooooo`3/
ooooo`;o0000C_ooool002Wooooo0_l0003[ooooo`;o0000D?ooool002Wooooo00?o0000oooooooo
ool0jOooool00ol0003oooooooooo`1@ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0>Oooooo0_l0001Cooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3Uooooo`;o0000EOooool000Co00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000i?ooool00ol0
003oooooooooo`1Eooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0>;ooooo0_l0001Hoooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0goooool2ool00003o`000?oooooo
oooo05Sooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0g?ooool3ool00003o`000?oooooo
oooo05[ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Kooooo`04ool00?oo
oooo0000o`0005gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo
1?l00006ooooo`;o0000foooool00ooo003o0000o`00001Oooooo`00:Oooool00ol0003ooooooooo
o`3Iooooo`03ool00?l0003ooooo063ooooo000Yooooo`03o`000?oooooooooo0=Oooooo0_oo0000
0ol0003oooooooooo`1Pooooo`00:Oooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo
06?ooooo000Yooooo`;o0000e_ooool00ooo003oooooooooo`1Tooooo`00:Oooool00ol0003ooooo
ooooo`3Cooooo`03o`000?oo003ooooo06Kooooo000Yooooo`03o`000?oooooooooo0=;ooooo00?o
0000ool00?ooool0Ioooool002Wooooo00?o0000ooooooooool0dOooool00ol0003oooooooooo`1X
ooooo`00:Oooool00ol0003oooooooooo`3@ooooo`03o`000?oooooooooo06Wooooo000Yooooo`;o
0000d?ooool00ol0003oooooooooo`1Zooooo`00:Oooool00ol0003oooooooooo`3>ooooo`03o`00
0?oooooooooo06_ooooo000Yooooo`03o`000?oooooooooo0<cooooo0_l0001^ooooo`00:Oooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo06kooooo000Yooooo`03o`000?oooooooooo
0<[ooooo00?o0000ooooooooool0Koooool002Wooooo0_l0003:ooooo`03o`000?oooooooooo073o
oooo000Yooooo`03o`000?oooooooooo0<Oooooo0_oo001cooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`35ooooo`;oo`0000?o0000ooooooooool0L_ooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0<?o
oooo0_oo00000ol0003oooooooooo`1dooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol00032ooooo`03ool00?oooooo000007Oo
oooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0<7ooooo00?oo`00ooooool00000N?ooool000kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`30oooo
o`03ool00?oooooo000007Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooool00000N_ooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0__ooool00ooo003o0000o`00001kooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`;o0000__ooool00ooo003o0000ooooo`1looooo`00:Oooool00ol0003o
ooooooooo`2looooo`03ool00?l0003ooooo07gooooo000Yooooo`03o`000?oooooooooo0;cooooo
00?o0000ooooooooool0OOooool002Wooooo00?o0000ooooooooool0^oooool00ol0003ooooooooo
o`1nooooo`00:Oooool2o`000;[ooooo0_l00021ooooo`00:Oooool00ol0003oooooooooo`2hoooo
o`03o`000?oooooooooo087ooooo000Yooooo`03o`000?oooooooooo0;Oooooo00?o0000oooooooo
ool0P_ooool002Wooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`23ooooo`00:Ooo
ool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo08Cooooo000Yooooo`;o0000]Oooool0
0ol0003oooooooooo`25ooooo`00:Oooool00ol0003oooooooooo`2booooo`;o0000R?ooool002Wo
oooo00?o0000ooooooooool0/Oooool00ooo003oooooooooo`28ooooo`00:Oooool00ol0003ooooo
ooooo`2`ooooo`03ool00?oooooooooo08Wooooo000Yooooo`03o`000?oooooooooo0:oooooo00?o
o`00ooooooooool0R_ooool002Wooooo0_l0002_ooooo`03ool00?oooooooooo08_ooooo000Yoooo
o`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0S?ooool000Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo0:_ooooo0_oo002?ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0Soooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o0000ZOooool00ooo003o0000ooooo`2@ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0:Sooooo00?oo`00o`000?ooool0TOooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo0:Oooooo00?oo`00o`000?ooool0T_ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Vooooo`03ool00?l0003ooooo09?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Vooooo`03o`000?oooooooooo09?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000Y_ooool00ol0
003oooooooooo`2Dooooo`00:Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo09Go
oooo000Yooooo`03o`000?oooooooooo0:;ooooo0_l0002Hooooo`00:Oooool00ol0003ooooooooo
o`2Qooooo`03o`000?oooooooooo09Sooooo000Yooooo`;o0000XOooool00ol0003oooooooooo`2I
ooooo`00:Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo09[ooooo000Yooooo`03
o`000?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo01kooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo
013ooooo000Yooooo`03o`000?oooooooooo02gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Nooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000009oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooooooo01;ooooo000Yoooo
o`;o0000;_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h09oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00007_ooool2ool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oo
oooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001gooooo00?oo`00ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Wooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o
0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
9Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000007?ooool00ooo003o
ooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Yoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o
0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00000Kooooo`03ool00?oooooooooo00Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0Booooo`00:Oooool0
0ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01Wo
oooo00?oo`00ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4
A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@0`ooooo`03oeEEEOmVIVKo000001Cooooo000Yooooo`;o0000Uoooool00ooo003ooooooooo
o`2Sooooo`00:Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo0:Cooooo000Yoooo
o`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0Voooool2o`0000;ooooo0_l00004oooo
o`00:Oooool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo09cooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`000003ool00?l0003o000009?o00002oooool01?oM
gMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o0000
00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`00:Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Yooooo`03o`000?oooooooooo
08kooooo00?o0000ooooooooool0XOooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo0:cooooo000Yooooo`;o0000SOooool00ol0003ooooo
ooooo`2]ooooo`00:Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo0:kooooo000Y
ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0[oooool002Wooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`2`ooooo`00:Oooool2o`0008Wooooo00?o0000oooooooo
ool0/Oooool002Wooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`2booooo`00:Ooo
ool00ol0003oooooooooo`26ooooo`03ool00?oooooooooo0;?ooooo000Yooooo`03o`000?oooooo
oooo08Gooooo0_oo002eooooo`00:Oooool00ol0003oooooooooo`24ooooo`03ool00?oooooooooo
0;Gooooo000Yooooo`;o0000Q?ooool00ooo003oooooooooo`2fooooo`00:Oooool00ol0003ooooo
ooooo`22ooooo`03ool00?oooooooooo0;Oooooo000Yooooo`03o`000?oooooooooo087ooooo00?o
o`00ooooooooool0^?ooool002Wooooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`2i
ooooo`00:Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo0;[ooooo000Yooooo`;o
0000Ooooool00ooo003oooooooooo`2kooooo`00:Oooool00ol0003oooooooooo`1mooooo`03ool0
0?oooooooooo0;cooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1looooo`03
ool00?oooooooooo0;gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`2nooooo`001_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000N_ooool00ol0
003oooooooooo`2oooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0`?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool0`Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo0<;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo0<?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000M_ooool00ol0003oooooooooo`34ooooo`00:Ooo
ool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo0<Gooooo000Yooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool0a_ooool002Wooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`37ooooo`00:Oooool2o`00077ooooo00?oo`00o`000?ooool0bOooool002Wooooo
00?o0000ooooooooool0Koooool00ooo003oooooooooo`3:ooooo`00:Oooool00ol0003ooooooooo
o`1]ooooo`;oo`00cOooool002Wooooo00?o0000ooooooooool0K?ooool00ooo003o0000ooooo`3=
ooooo`00:Oooool00ol0003oooooooooo`1[ooooo`03ool00?l0003ooooo0<kooooo000Yooooo`;o
0000Joooool00ooo003oooooooooo`3?ooooo`00:Oooool00ol0003oooooooooo`1Yooooo`03ool0
0?oooooooooo0=3ooooo000Yooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0dOoo
ool002Wooooo00?o0000ooooooooool0I_ooool00ol0003oo`00ooooo`3Cooooo`00:Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oo003ooooo0=Cooooo000Yooooo`;o0000IOooool00ol0003o
o`00ooooo`3Eooooo`00:Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0=Kooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo067ooooo0_l0003Iooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`3Iooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool3o`0005oooooo00?o0000ooooooooool0f_ooool000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0GOooool2o`000=gooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`3Moooo
o`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo0=kooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool0goooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00
05Wooooo00?o0000ool00?oo0000hOooool002Wooooo00?o0000ooooooooool0Eoooool00ol0003o
o`00ooooo`3Rooooo`00:Oooool00ol0003oooooooooo`1Fooooo`03o`000?oo003ooooo0>?ooooo
000Yooooo`03o`000?oooooooooo05Gooooo00?o0000ool00?ooool0i?ooool002Wooooo0_l0001D
ooooo`03o`000?oo003oo`000>Kooooo000Yooooo`03o`000?oooooooooo05;ooooo00?o0000ool0
0?ooool0ioooool002Wooooo00?o0000ooooooooool0DOooool2ool00>Wooooo000Yooooo`03o`00
0?oooooooooo053ooooo00?oo`00ooooooooool0jOooool002Wooooo00?o0000ooooooooool0C_oo
ool00ol0003oo`00ooooo`3[ooooo`00:Oooool2o`0004kooooo00?o0000ool00?ooool0k?ooool0
02Wooooo00?o0000ooooooooool0Boooool2o`000>oooooo000Yooooo`03o`000?oooooooooo04Wo
oooo0_l0003aooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?7ooooo
000Yooooo`03o`000?oooooooooo04Kooooo0_l0003dooooo`00:Oooool2o`0004Kooooo00?o0000
ooooooooool0m?ooool002Wooooo00?o0000ooooooooool0@oooool2o`000?Oooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3g
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`10ooooo`;o0000n_ooool0
00Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`0003kooooo0_l000000oooooooo`00ool0003iooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo03gooooo00Co0000oooooooo003oo`00noooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo03_ooooo0_l000000oooooooo`00ooooo`3looooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooo003oo`00o_ooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Sooooo0_l00002ool00?oooooo0Oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000hoooo
o`03o`000?oo003oo`000?oooooo0oooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003o
o`00ool0003oooooo`Gooooo000Yooooo`03o`000?oooooooooo03?ooooo0_l000000ooo003ooooo
ooooo`3oooooo`Gooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooo
ool8ooooo`00:Oooool2o`00037ooooo0_l0003oooooo`_ooooo000Yooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0ooooool;ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`;o
0000ooooool>ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o0000ooooool@ooooo`00:Ooo
ool00ol0003oooooooooo`0Wooooo`?o0000oooooolCooooo`00:Oooool2o`0002Gooooo0ol00002
ool00?oooooo5?ooool002Wooooo00?o0000ooooooooool08Oooool3o`0000?oo`00oooooolFoooo
o`00:Oooool00ol0003oooooooooo`0Nooooo`?o00000ooo003ooooooaWooooo000Yooooo`03o`00
0?oooooooooo01_ooooo0ol00003ool00?oooooo7?ooool002Wooooo00?o0000ooooooooool06?oo
ool3o`0000?oo`00oooooolOooooo`00:Oooool2o`0001Kooooo0ol00002ooooo`03ool00?oooooo
oooo0?oooooo8?ooool002Wooooo00?o0000ooooooooool04_ooool3o`000?oooooo:?ooool001oo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0ol0003oooooob_o
oooo000Qooooo`03o`000?oooooooooo00Gooooo3Ol00002ool000?o0000ooooool^ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`goo`00oooooolcooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmV
IVKo00000?ooooooAoooool00?ooooooJOooool00:Cooooo0_l0000;ooooo`03o`000?nj^[[ooooo
00cooooo0_l00005ooooo`03o`000?nj^[[ooooo09kooooo002Tooooo`03o`000?oooooooooo00[o
oooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Oooooo`00VOooool01Ol@413o0000
o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7
QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03
ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0Q_ooool009_ooooo00?o0000ooooooooool01_ooool02_l0003ooooooooo
ooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Ooo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
08Kooooo002Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@4100Q_ooool009_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002
ooooo`05o`000?ooooooooooooooool00000Q_ooool009_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`000026ooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Go
oooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooo
oooooooooa0@4026ooooo`00V?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Hoooo
o`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooo
ooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .47414 m
.05556 .47414 L
.16667 .45423 L
.27778 .4168 L
.38889 .36636 L
.5 .30902 L
.61111 .25167 L
.72222 .20124 L
.83333 .16381 L
.94444 .14389 L
s
.94444 .14389 m
1 .14389 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .47578 m
.00123 .47577 L
.00236 .47577 L
.00365 .47576 L
.00488 .47576 L
.00706 .47573 L
.00942 .4757 L
.01203 .47566 L
.01479 .4756 L
.01975 .47545 L
.02486 .47527 L
.02966 .47505 L
.04057 .47442 L
.0517 .47358 L
.06188 .47263 L
.08481 .46989 L
.10474 .46683 L
.1265 .46278 L
.16918 .45277 L
.21027 .4407 L
.25393 .42547 L
.296 .40872 L
.33648 .39097 L
.37953 .37063 L
.42099 .34998 L
.46086 .32947 L
.50331 .30728 L
.54416 .28596 L
.58759 .26371 L
.62943 .24306 L
.66967 .22428 L
.7125 .20578 L
.75372 .18973 L
.79336 .17618 L
.83558 .16402 L
.8762 .15471 L
.89683 .15094 L
.91939 .14758 L
.94095 .14512 L
.95057 .14427 L
.961 .14351 L
.96647 .14318 L
.97151 .14293 L
.97624 .14272 L
.98143 .14254 L
.98609 .14242 L
.99045 .14233 L
.99286 .1423 L
.99505 .14228 L
.99627 .14227 L
Mistroke
.99759 .14226 L
.99884 .14226 L
1 .14226 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo5?ooool;o`0000Soo`000_l0000Dooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`3oooooo`gooooo1Ooo0002o`0002Wooooo000>ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`3oooooo`Kooooo1ooo0002o`0002kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo0_ooool4ool000?o0000
=?ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oOooool6o`0003Wooooo000>ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0n?ooool5o`0003oo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?Cooooo1?l00014ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3aooooo`;oo`0000?o0000oooooooo
ool0A_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000>oo
oooo0ooo001;ooooo`00:Oooool00ol0003oooooooooo`3[ooooo`?oo`00C_ooool002Wooooo00?o
0000ooooooooool0ioooool4ool0057ooooo000Yooooo`03o`000?oooooooooo0>Cooooo0ooo0000
0ol0003oooooooooo`1Booooo`00:Oooool2o`000>?ooooo0ol0001Gooooo`00:Oooool00ol0003o
ooooooooo`3Oooooo`?o0000F_ooool002Wooooo00?o0000ooooooooool0g?ooool3o`0005gooooo
000Yooooo`03o`000?oooooooooo0=Wooooo0ol0001Pooooo`00:Oooool00ol0003oooooooooo`3E
ooooo`;oo`000_l0001Sooooo`00:Oooool2o`000=Cooooo0_oo00000ol0003oooooooooo`1Toooo
o`00:Oooool00ol0003oooooooooo`3Aooooo`03o`000?oo003ooooo06Sooooo000Yooooo`03o`00
0?oooooooooo0<kooooo0_l00002ool006[ooooo000Yooooo`03o`000?oooooooooo0<cooooo00Co
0000ool00?oo003oo`00K?ooool002Wooooo00?o0000ooooooooool0b_ooool3ool006oooooo000Y
ooooo`;o0000bOooool2ool007;ooooo000Yooooo`03o`000?oooooooooo0<Kooooo0_l0001doooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0`oooool3o`0007Kooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0`Oooool2o`0007Wooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`000;oooooo0_l0001kooooo`001_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0;gooooo0_l0001mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
^_ooool2ool00003o`000?oooooooooo07gooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
^?ooool00ol0003oo`00o`000021ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0]_ooool00ol0003oo`00ool00023ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000;Gooooo00?o0000ool0
0?oo0000QOooool002Wooooo00?o0000ooooooooool0/_ooool00ol0003oo`00ool00027ooooo`00
:Oooool00ol0003oooooooooo`2`ooooo`03o`000?oo003oo`0008Wooooo000Yooooo`03o`000?oo
oooooooo0:kooooo00?o0000ool00?oo0000Roooool002Wooooo0_l0002]ooooo`;o000000?oo`00
ooooooooool0Roooool002Wooooo00?o0000ooooooooool0Z_ooool2o`00093ooooo000Yooooo`03
o`000?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo02Cooooo00Cok^k^oc8b<_l0003o<S8b0_l00004ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<033ooooo1?l000000ol@413oooooooooo`0@ooooo`00:Oooool00ol0003o
ooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool09Oooool01OmgMgOoV9RHo`000?l0003oMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B409oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0X
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Kooooo0_l00002ooooo`03oa0@4?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00000Wooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool04_ooool002Wo
oooo0_l0000^ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Woooo
o`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Uooooo`?o00000ooo
ool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B409oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0booooo`03o`000?oooooooooo
01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0002Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo
02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000027ooooo0ooo0003ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@03;ooooo00?o0000ooooooooool04_ooool002Wo
oooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@400Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
000Oooooo`;oo`0000?o0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`00000booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07Oooool00ooo003o0000oooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Wooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY033ooooo00?oEEEE
ofIVI_l000005?ooool002Wooooo0_l0002Jooooo`;oo`00XOooool002Wooooo00?o0000oooooooo
ool0Uoooool2ool00:?ooooo000Yooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0
V_ooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo
003oo`0009cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonFo`000003ool0
0?l0003o000009;o00002oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00:Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`;o000000?oooooo`000?ooool03Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04onk^
k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Fooooo`;o00008?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00
:Oooool00ol0003oooooooooo`2;ooooo`;o0000YOooool2o`0000;ooooo0_l00004ooooo`00:Ooo
ool00ol0003oooooooooo`29ooooo`;o0000/Oooool002Wooooo0_l00028ooooo`;o0000/oooool0
02Wooooo00?o0000ooooooooool0QOooool2ool00;Gooooo000Yooooo`03o`000?oooooooooo08?o
oooo0_oo002gooooo`00:Oooool00ol0003oooooooooo`21ooooo`;oo`00^Oooool002Wooooo0_l0
0020ooooo`;oo`00^oooool002Wooooo00?o0000ooooooooool0OOooool2ool00003o`000?oooooo
oooo0;[ooooo000Yooooo`03o`000?oooooooooo07_ooooo0_oo00000ol0003oooooooooo`2loooo
o`00:Oooool00ol0003oooooooooo`1jooooo`03ool00?l0003ooooo0;oooooo000Yooooo`03o`00
0?oooooooooo07Sooooo00?o0000ool00?ooool0`Oooool002Wooooo0_l0001gooooo`;o0000a?oo
ool002Wooooo00?o0000ooooooooool0M?ooool2o`000<Kooooo000Yooooo`03o`000?oooooooooo
07;ooooo0_l00038ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`;o0000b_ooool002Wooooo
00?o0000ooooooooool0K_ooool2o`000<cooooo000Yooooo`;o0000K?ooool3o`000<kooooo000Y
ooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?oo0000d?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?oo0000d_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo003oo`000=Cooooo
0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00?ooooo0ol0001Rooooo`;o00000_oo003Fooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo063ooooo0_l00002ool00=Sooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`1Nooooo`;o00000_oo003Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo0ol00002ool00=cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Ioooo
o`;o0000hOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0001Hooooo`;o0000hoooool002Wooooo00?o0000oooo
ooooool0EOooool2o`000>Gooooo000Yooooo`03o`000?oooooooooo05;ooooo0ol0003Wooooo`00
:Oooool00ol0003oooooooooo`1@ooooo`;o0000j_ooool002Wooooo0_l0001?ooooo`03o`000?oo
003oo`000>_ooooo000Yooooo`03o`000?oooooooooo04_ooooo00Co0000ool00?oo003oo`00kOoo
ool002Wooooo00?o0000ooooooooool0B?ooool01?l0003oo`00ool00?oo003`ooooo`00:Oooool0
0ol0003oooooooooo`15ooooo`;o00000_oo003cooooo`00:Oooool00ol0003oooooooooo`13oooo
o`04o`000?oo003oo`00ool00?Gooooo000Yooooo`;o0000@Oooool2o`0000;oo`00n?ooool002Wo
oooo00?o0000ooooooooool0?Oooool3o`000?cooooo000Yooooo`03o`000?oooooooooo03[ooooo
0ol0003oooooo`00:Oooool00ol0003oooooooooo`0hooooo`;o0000ooooool3ooooo`00:Oooool0
0ol0003oooooooooo`0eooooo`?o0000ooooool5ooooo`00:Oooool2o`0003?ooooo0ooo003ooooo
o`Sooooo000Yooooo`03o`000?oooooooooo02gooooo1Ooo003oooooo`_ooooo000>ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02Sooooo1Ooo0002o`000?oooooo3_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02Cooooo0_l00002ool000?o0000oooooolBooooo`003_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`0001gooooo1ol0003ooooooaWooooo000>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01Oooooo1_l0003oooooob3ooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04?ooool3o`0000Goo`00oooooolU
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool>
o`0000Soo`00oooooolZooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`?oo`00oooooolbooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo
?Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool0
0omEEEGoIVIVo`00003oooooodOooooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go
410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
0_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003o
ooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0NOooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00Co
oooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
N?ooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0
003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool0Moooool0093ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1hooooo`00
T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<07Wooooo002=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07_ooooo002=ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool0Noooool008gooooo1ol00004ooooo`;o0000
4oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001joooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .39862 m
.05556 .39862 L
.16667 .38781 L
.27778 .3675 L
.38889 .34013 L
.5 .30902 L
.61111 .2779 L
.72222 .25054 L
.83333 .23023 L
.94444 .21942 L
s
.94444 .21942 m
1 .21942 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .39901 m
.00123 .39901 L
.00236 .399 L
.00365 .399 L
.00488 .399 L
.00706 .39898 L
.00942 .39897 L
.01203 .39894 L
.01479 .39891 L
.01975 .39883 L
.02486 .39873 L
.02966 .39862 L
.04057 .39828 L
.0517 .39782 L
.06188 .39731 L
.08481 .39583 L
.10474 .39418 L
.1265 .39199 L
.16918 .38659 L
.21027 .38008 L
.25393 .37186 L
.296 .36282 L
.33648 .35324 L
.37953 .34227 L
.42099 .33112 L
.46086 .32005 L
.50331 .30808 L
.54416 .29657 L
.58759 .28457 L
.62943 .27343 L
.66967 .26329 L
.7125 .25331 L
.75372 .24464 L
.79336 .23733 L
.83558 .23077 L
.8762 .22575 L
.89683 .22371 L
.91939 .2219 L
.94095 .22057 L
.95057 .22011 L
.961 .2197 L
.96647 .21953 L
.97151 .21939 L
.97624 .21928 L
.98143 .21918 L
.98609 .21911 L
.99045 .21907 L
.99286 .21905 L
.99505 .21904 L
.99627 .21903 L
Mistroke
.99759 .21903 L
.99884 .21903 L
1 .21903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo9?ooool6ool001Cooooo000Yooooo`03o`000?oooooooooo0?oo
oooo3?ooool3ool000?ooooo2ol00006ool000Ko00005?ooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo0?oooooo0Oooool;ool000Ko0000:oooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3kooooo`?o00000_oo0006o`0003Kooooo0004o`00
00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00oooool3o`000?;ooooo2Ol00011ooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0>cooooo1?oo0002o`0004[ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3Uooooo`Ooo`0000?o0000ooooooooool0COooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3Qooooo`Coo`000_l0001Eooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
g?ooool6o`0005[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000f?ooool5o`00063ooooo000Yooooo`03o`00
0?oooooooooo0=;ooooo00?oo`00o`000?l000000_l0001Uooooo`00:Oooool00ol0003ooooooooo
o`3>ooooo`04o`000?oo003oo`00ool006[ooooo000Yooooo`03o`000?oooooooooo0<[ooooo1Ooo
001]ooooo`00:Oooool2o`000<Oooooo1?oo001booooo`00:Oooool00ol0003oooooooooo`31oooo
o`?o00000_oo001fooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`Co00007oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`00
0003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo02gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Uooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@04o`0002?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So
8B4Q03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Vooooo`05oa0@4?ooooooooooooooool@41002oooool2ool000?o0000
9oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000boooo
o`03o`000?oooooooooo01;ooooo000Yooooo`;o0000;_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h09oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00009oooool01Ol0003ooooooooooooooooo000000Sooooo0ooo00001Ol0003oV9RH
oooooonHV9So8B4Q02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S80<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Vooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oo`00ool00?oo0003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`09oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00booooo`03o`00
0?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000002Oooooo00Ko410@oooooooooooooooooa0@4?ooool4ool000Kooooo00?oEEEE
ohN7Qoooool0:Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41009oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009oooool00omgMgOoV9RHo`000003ool0
00[ooooo00?ogMgMoa0@4?nHV9P0:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`00000booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
9oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool09?ooool5o`000003
oc8b<_o^k^kooooo00_ooooo00Coc<c<odA4A?l0003o410@9oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03oeEEEOmVIVKo000001Cooooo000Y
ooooo`;o0000X?ooool3o`0009[ooooo000Yooooo`03o`000?oooooooooo09_ooooo1?l0002Moooo
o`00:Oooool00ol0003oooooooooo`2Gooooo`;oo`000_l0002Gooooo`;o00000_ooool2o`0000Co
oooo000Yooooo`03o`000?oooooooooo09Cooooo0ooo002Kooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool002WoooooU?l00003ool009Co00002oooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`06ooooo`Goo`0000?oooooo`000?ooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`;oo`0000?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool02Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00:Oooool00ol0003oooooooooo`26ooooo`Co
0000Z?ooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`23ooooo`?o0000
]_ooool002Wooooo0_l00021ooooo`?o0000^Oooool002Wooooo00?o0000ooooooooool0Noooool2
ool000?o0000_?ooool002Wooooo00?o0000ooooooooool0N?ooool3ool000;o0000_oooool002Wo
oooo00?o0000ooooooooool0M?ooool4ool00003o`000?oooooooooo0<7ooooo000Yooooo`;o0000
LOooool4ool000;o0000a_ooool002Wooooo00?o0000ooooooooool0KOooool3ool000?o0000bOoo
ool002Wooooo00?o0000ooooooooool0Joooool4o`000<gooooo000Yooooo`03o`000?oooooooooo
06Kooooo1Ol0003Aooooo`00:Oooool00ol0003oooooooooo`1Rooooo`Co0000e_ooool002Wooooo
0_l0001Nooooo`?oo`000_l0003Jooooo`00:Oooool00ol0003oooooooooo`1Hooooo`Goo`0000?o
0000ooooooooool0g?ooool002Wooooo00?o0000ooooooooool0Doooool5ool000;o0000h_ooool0
02Wooooo00?o0000ooooooooool0D?ooool3ool000;o0000ioooool002Wooooo00?o0000oooooooo
ool0C?ooool5o`000>_ooooo000Yooooo`;o0000B?ooool5o`000?3ooooo000Yooooo`03o`000?oo
oooooooo03oooooo1?oo0004o`000?Gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0iooooo`Koo`000_l0003kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Gooooo1?oo0003o`000?oooooo0Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`00037o
oooo0_l00002ool00003o`000?oooooooooo0?oooooo1Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0Yooooo`So0000ooooool<ooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool07_ooool00ol0003oo`00ool00004ool000Co0000oooooolDooooo`001_ooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01?ooooo0ol00009ool00?oooooo7_ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07
ooooo`_oo`002ol0003oooooob[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`003_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oo
oooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool001oooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0003oooooocgo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00W?oo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0YOoo
ool009cooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<ZKooooo002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02
ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4
A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0OOooool009Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`1looooo`00U?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0Noooool009Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool0O?ooool0
09Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
OOooool0097ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo
00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo07oooooo002Aooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`1oooooo`00TOooool7o`0000Cooooo0_l0000Cooooo`03
o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co0000O_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .35763 m
.05556 .35763 L
.16667 .35177 L
.27778 .34075 L
.38889 .3259 L
.5 .30902 L
.61111 .29213 L
.72222 .27728 L
.83333 .26626 L
.94444 .2604 L
s
.94444 .2604 m
1 .2604 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .35758 m
.00123 .35758 L
.00236 .35758 L
.00365 .35758 L
.00488 .35757 L
.00706 .35757 L
.00942 .35756 L
.01203 .35754 L
.01479 .35753 L
.01975 .35749 L
.02486 .35743 L
.02966 .35737 L
.04057 .35719 L
.0517 .35694 L
.06188 .35666 L
.08481 .35587 L
.10474 .35497 L
.1265 .35379 L
.16918 .35088 L
.21027 .34736 L
.25393 .34293 L
.296 .33805 L
.33648 .33288 L
.37953 .32696 L
.42099 .32095 L
.46086 .31497 L
.50331 .30851 L
.54416 .3023 L
.58759 .29582 L
.62943 .28981 L
.66967 .28434 L
.7125 .27895 L
.75372 .27428 L
.79336 .27033 L
.83558 .26679 L
.8762 .26408 L
.89683 .26298 L
.91939 .262 L
.94095 .26129 L
.95057 .26104 L
.961 .26082 L
.96647 .26072 L
.97151 .26065 L
.97624 .26059 L
.98143 .26054 L
.98609 .2605 L
.99045 .26048 L
.99286 .26047 L
.99505 .26046 L
.99627 .26046 L
Mistroke
.99759 .26046 L
.99884 .26046 L
1 .26045 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo3_ooool:ool000ko00001?oo000Doooo
o`00:Oooool00ol0003oooooooooo`3mooooo`Wo00001_oo0002o`0002kooooo000Yooooo`03o`00
0?oooooooooo02gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool9ool000Co0000
:?ooool4o`000003oa0@4?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A402Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Uoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?l00007ool00005ob4Q8OnHV9SooooooiRHV?lQ
8B40<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`0]ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Xooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000007Oooool5ool000[o00002oooool01Ol0003ooooooooooooooooo000003;ooooo
00?o0000ooooooooool04_ooool002Wooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Wooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool0000Wooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q01Gooooo2?oo0004o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooo
ooooo`0]ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Vooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Wooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00oooooo0ol00003ool000;o0000
4?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00boooo
o`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo00Sooooo2Ol0000Hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@03;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Woooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Wooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV003o`0000?oo`000_l0000Qooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000003;ooooo00?o0000oooooooo
ool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool3o`0000Ooo`009_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03
oeEEEOmVIVKo000001Cooooo000Yooooo`;o0000Z_ooool5o`0000Goo`00ROooool002Wooooo00?o
0000ooooooooool0X_ooool7o`0009?ooooo000Yooooo`03o`000?oooooooooo09cooooo1?oo0002
o`00093ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0UOooool00ol0
003oo`00ool00004ool009Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonE
o`0000Coo`00T_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo1ol000001?ooooooo`00ool00?l0000>ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co
k^k^ob4Q8Ol@413ok^k^1Oooool002Wooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00[ooooo1ol0000Wooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo
000Yooooo`03o`000?oooooooooo07_ooooo0ol00004ool00;3ooooo0_l00002ooooo`;o00001?oo
ool002Wooooo00?o0000ooooooooool0M?ooool3o`0000Ooo`00__ooool002Wooooo0_l0001_oooo
o`Go00001?oo0035ooooo`00:Oooool00ol0003oooooooooo`1Wooooo`Oo0000c_ooool002Wooooo
00?o0000ooooooooool0G_ooool7ool000;o0000eOooool002Wooooo00?o0000ooooooooool0F?oo
ool6ool000;o0000g?ooool002Wooooo0_l0001Cooooo`?o00000ooo00000ol0003oooooooooo`3Q
ooooo`00:Oooool00ol0003oooooooooo`1:ooooo`So0000j_ooool002Wooooo00?o0000oooooooo
ool0?oooool2o`0000Koo`000ol0003booooo`00:Oooool00ol0003oooooooooo`0dooooo`Co0000
2Ooo003kooooo`00:Oooool00ol0003oooooooooo`0Vooooo`Coo`002_l0003oooooo`Wooooo000Y
ooooo`;o00005_ooool5o`0000coo`00oooooolGooooo`00:Oooool?ool000Wo0000oooooolXoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`00
0?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool0
00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo
0ol0003oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
00Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooooooo
o`05ooooo`?o0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAooo
ool00?ooooooJOooool009Sooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006oooo
o`03o`000?nj^[[ooooo0:Wooooo002Hooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03
o`000?oooooooooo00Cooooo0_lb<S:Zooooo`00S_ooool01Ol@413o0000o`000?l0003o410@00Go
oooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Go
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`00
0?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
NOooool0093ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07Oo
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Q
oa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0N?ooool0093ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01i
ooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool0
0ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1kooooo`00SOooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03
o`000?oooooooooo07_ooooo002=ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool0
1?ooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo1Ol00004ooooo`Co0000N_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3354 m
.05556 .3354 L
.16667 .33221 L
.27778 .32624 L
.38889 .31818 L
.5 .30902 L
.61111 .29986 L
.72222 .2918 L
.83333 .28582 L
.94444 .28264 L
s
.94444 .28264 m
1 .28264 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .33522 m
.00123 .33522 L
.00236 .33522 L
.00365 .33522 L
.00488 .33522 L
.00706 .33522 L
.00942 .33521 L
.01203 .3352 L
.01479 .33519 L
.01975 .33517 L
.02486 .33514 L
.02966 .33511 L
.04057 .33501 L
.0517 .33488 L
.06188 .33473 L
.08481 .3343 L
.10474 .33382 L
.1265 .33318 L
.16918 .33161 L
.21027 .32971 L
.25393 .32732 L
.296 .32469 L
.33648 .3219 L
.37953 .3187 L
.42099 .31546 L
.46086 .31223 L
.50331 .30874 L
.54416 .30539 L
.58759 .3019 L
.62943 .29865 L
.66967 .2957 L
.7125 .29279 L
.75372 .29027 L
.79336 .28814 L
.83558 .28623 L
.8762 .28477 L
.89683 .28418 L
.91939 .28365 L
.94095 .28326 L
.95057 .28313 L
.961 .28301 L
.96647 .28296 L
.97151 .28292 L
.97624 .28288 L
.98143 .28286 L
.98609 .28284 L
.99045 .28282 L
.99286 .28282 L
.99505 .28281 L
.99627 .28281 L
Mistroke
.99759 .28281 L
.99884 .28281 L
1 .28281 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00Aooooob3o00000_oo000Dooooo`00:Oooool00ol0003oooooooooo`0]
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Wooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`0Yooooo`05oa0@4?ooooooooooooooool@41002?ooool4o`00
00[oo`002ol00003oooooa3oo`003_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003o
ooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Gooooo3ol00006ool00004okZj
^_oooooo^[Zjo`0003;ooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0
;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Woooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Vooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Fooooo`koo`000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0`ooooo`03oeEEEOmVIVKo0000
01Cooooo000Yooooo`;o0000aOooool9o`0000;oo`00KOooool002Wooooo00?o0000ooooooooool0
]?ooool;ool000Go0000N?ooool002Wooooo00?o0000ooooooooool0Zoooool5o`0000Coo`001Ol0
001iooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo09Wooooo2Ooo0009
o`0008Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`0000Ooo`00Sol0
000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`Goo`002Ol00005ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`00:Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
0003o`0002gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ooooooooool0JOoo
ool;o`0000?oo`00^oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003oooooooooo`1H
ooooo`Co00002_oo0003o`000=?ooooo000Yooooo`;o0000B?ooool@o`0000Goo`00h?ooool002Wo
oooo00?o0000ooooooooool0=_ooool4o`0000ooo`00loooool002Wooooo00?o0000ooooooooool0
7_ooool00ol0003oo`00ool0000:ool000_o00000oooool00ooo003oooooooooo`3oooooo`7ooooo
000Yoooooa3oo`003_l00004ool00?oooooo7_ooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0003ooooo
ockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0
oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000ooooooln
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413o
oooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006oooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOooooo003o
ooooofWooooo002Pooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0
003o^[Zjooooo`2Rooooo`00X?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003o
ooooooooo`03ooooo`;o<S8bXoooool009Gooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnH
V9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B63ooooo`00Uoooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[o
k^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B63ooooo`00Uooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`29ooooo`00Uoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool0
ROooool009Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0ROooool009Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000So
oooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l0
00000ol0000=ooooo`03o`000?oooooooooo08Wooooo002Dooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Wo
oooo002Dooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo
00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00002;ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32333 m
.05556 .32333 L
.16667 .3216 L
.27778 .31836 L
.38889 .31399 L
.5 .30902 L
.61111 .30405 L
.72222 .29967 L
.83333 .29643 L
.94444 .2947 L
s
.94444 .2947 m
1 .2947 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .32316 m
.00123 .32316 L
.00236 .32316 L
.00365 .32316 L
.00488 .32316 L
.00706 .32316 L
.00942 .32315 L
.01203 .32315 L
.01479 .32314 L
.01975 .32313 L
.02486 .32312 L
.02966 .3231 L
.04057 .32304 L
.0517 .32297 L
.06188 .32289 L
.08481 .32266 L
.10474 .3224 L
.1265 .32206 L
.16918 .32121 L
.21027 .32018 L
.25393 .31889 L
.296 .31747 L
.33648 .31597 L
.37953 .31424 L
.42099 .31249 L
.46086 .31075 L
.50331 .30887 L
.54416 .30706 L
.58759 .30517 L
.62943 .30342 L
.66967 .30183 L
.7125 .30026 L
.75372 .2989 L
.79336 .29775 L
.83558 .29672 L
.8762 .29593 L
.89683 .29561 L
.91939 .29533 L
.94095 .29512 L
.95057 .29505 L
.961 .29498 L
.96647 .29495 L
.97151 .29493 L
.97624 .29491 L
.98143 .2949 L
.98609 .29489 L
.99045 .29488 L
.99286 .29488 L
.99505 .29488 L
.99627 .29488 L
Mistroke
.99759 .29488 L
.99884 .29488 L
1 .29488 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo2?ooool4o`0000ooo`003Ol00002
ool001Cooooo000Yooooo`03o`000?oooooooooo0<cooooo2ol00007ool000ko00004?oo000:o`00
03Kooooo000Yooooo`03o`000?oooooooooo0;_ooooo00?o0000ool00?oo00000_oo000<o`0000;o
oooo2Ooo001Kooooo`;o00000_ooool2o`0000Cooooo000Yooooo`03o`000?oooooooooo0:?ooooo
3Ol0000<ool007Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:OoooonEo`00013o
o`00Q_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool=ool000Go00002?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0
02Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Qooooo`_oo`003_l00003ool0
0003o`000?oooooooooo03Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000oooo
ooooool0?oooool3o`0000Ooo`003_l00005ool000Co0000d_ooool2o`0000;ooooo0_l00004oooo
o`00:Oooool00ol0003oo`00ool0000>ool000gooooo4?oo000>o`0000Woo`00n_ooool002Wooooo
8Ol0003ooooooaoooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o
0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o0000oooooolmoooo
o`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo
00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o
0000oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolmoooo
o`003_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooocgooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000
ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qoooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooocgooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIV
I_l00000oooooom7ooooo`00oooooomYooooo`00V?ooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Kooooo00?o0000okZj^_ooool0ZOooool009Sooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<Z[ooooo002>ooooo`05oa0@4?l0003o
0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool0
1?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
07Wooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1gooooo`00
T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413o
k^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01?ooool6o`0000Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo07Sooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Wooooo002=ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1kooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001?ooool00ol0003oooooooooo`1kooooo`00SOooool7o`0000Cooooo0_l0000Coooo
o`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIV
I_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001jooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31678 m
.05556 .31678 L
.16667 .31585 L
.27778 .31409 L
.38889 .31171 L
.5 .30902 L
.61111 .30632 L
.72222 .30395 L
.83333 .30219 L
.94444 .30125 L
s
.94444 .30125 m
1 .30125 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31665 m
.00123 .31665 L
.00236 .31665 L
.00365 .31665 L
.00488 .31665 L
.00706 .31665 L
.00942 .31665 L
.01203 .31664 L
.01479 .31664 L
.01975 .31663 L
.02486 .31663 L
.02966 .31662 L
.04057 .31659 L
.0517 .31655 L
.06188 .3165 L
.08481 .31638 L
.10474 .31624 L
.1265 .31605 L
.16918 .3156 L
.21027 .31504 L
.25393 .31435 L
.296 .31358 L
.33648 .31277 L
.37953 .31184 L
.42099 .31089 L
.46086 .30995 L
.50331 .30894 L
.54416 .30796 L
.58759 .30694 L
.62943 .306 L
.66967 .30514 L
.7125 .30429 L
.75372 .30356 L
.79336 .30294 L
.83558 .30238 L
.8762 .30196 L
.89683 .30178 L
.91939 .30163 L
.94095 .30152 L
.95057 .30148 L
.961 .30144 L
.96647 .30143 L
.97151 .30142 L
.97624 .30141 L
.98143 .3014 L
.98609 .30139 L
.99045 .30139 L
.99286 .30139 L
.99505 .30139 L
.99627 .30139 L
Mistroke
.99759 .30139 L
.99884 .30139 L
1 .30139 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3Uooooo`Oo00004?oo000>o`00013o
o`003?l00002ool000[ooooo0_l00002ooooo`;o00001?ooool002Wooooo00?o0000ooooooooool0
XooooolAo`0000coo`003_l0000@ool000Oo0000COooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Cooooo000YoooooiKo00004?oo000=o`0000Coo`00M?l0000;ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo2ooo000>o`00013oo`003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wo
oooo00?o0000ooooooooool07?ooool?ool000ko00004?oo000>o`0000Goo`001?l0000Dooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b1Oooool002Wooooo00?o0000ool00?oo
00003_oo000@o`000?oooooo5Oooool2o`0000;ooooo0_l00004ooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo
?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_ooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0
003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo
0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03
o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Y
ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@ooooooooool00oooool0
0ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolmooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool009cooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0:Gooooo002L
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:V
ooooo`00T_ooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj
^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM07gooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0O?ooool009Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1kooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`1looooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0OOooool0097ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1oooooo`00TOooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo07oooooo002Aooooo`Oo00001?ooool2o`0001?ooooo00?o
0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00
000=ooooo`Co0000O_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31323 m
.05556 .31323 L
.16667 .31272 L
.27778 .31177 L
.38889 .31048 L
.5 .30902 L
.61111 .30755 L
.72222 .30627 L
.83333 .30531 L
.94444 .3048 L
s
.94444 .3048 m
1 .3048 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31314 m
.00123 .31314 L
.00236 .31314 L
.00365 .31314 L
.00488 .31313 L
.00706 .31313 L
.00942 .31313 L
.01203 .31313 L
.01479 .31313 L
.01975 .31313 L
.02486 .31312 L
.02966 .31312 L
.04057 .3131 L
.0517 .31308 L
.06188 .31306 L
.08481 .31299 L
.10474 .31291 L
.1265 .31281 L
.16918 .31257 L
.21027 .31227 L
.25393 .31189 L
.296 .31148 L
.33648 .31104 L
.37953 .31054 L
.42099 .31003 L
.46086 .30952 L
.50331 .30897 L
.54416 .30845 L
.58759 .3079 L
.62943 .30739 L
.66967 .30692 L
.7125 .30647 L
.75372 .30607 L
.79336 .30574 L
.83558 .30544 L
.8762 .30521 L
.89683 .30511 L
.91939 .30503 L
.94095 .30497 L
.95057 .30495 L
.961 .30493 L
.96647 .30492 L
.97151 .30492 L
.97624 .30491 L
.98143 .30491 L
.98609 .3049 L
.99045 .3049 L
.99286 .3049 L
.99505 .3049 L
.99627 .3049 L
Mistroke
.99759 .3049 L
.99884 .3049 L
1 .3049 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0a?oooolCo`0000Ooo`003_l0000@ool000ko0000
4?oo000>o`0000[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00:Ooooon2o`0000Ko
o`003_l0000@ool000go00004?oo000>o`0000Woo`00DOl0000;ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Yooooo`03o`000?oo003oo`0000koo`003Oooool00ol0003oo`00ool0000=ool000ko
00004?oo000>o`00013oo`003_l0000:ool000?o000000?oooooo`000?ooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool002Wo
oooo8Ol0000Jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02Oooool01?lQ8B7o
MgMgogMgMolb<S85ooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`007oooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00003oooooodOo
oooo003oooooofWooooo002Hooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`2Yooooo`00V?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`04ooooo`;o<S8bZ_ooool008kooooo00Go410@o`000?l0003o0000oa0@4005
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Wo
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000_ooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool01oooool00omgMgOo<S8booooo`1hooooo`00T?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0Moooool0093ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1_l0
0004ooooo`03o`000?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8boooo
o`1hooooo`00T?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4Q
ogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c01iooooo`00SOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o0000
3Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
Noooool008gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool0Noooool008gooooo1ol00004ooooo`;o00004oooool00ol0003ooooo
ooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000cooooo
1Ol00004ooooo`Co0000N_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.309017 0.309017 [
[.2 .29652 -9 -9 ]
[.2 .29652 9 0 ]
[.4 .29652 -9 -9 ]
[.4 .29652 9 0 ]
[.6 .29652 -9 -9 ]
[.6 .29652 9 0 ]
[.8 .29652 -9 -9 ]
[.8 .29652 9 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .30902 m
.2 .31527 L
s
[(0.2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(0.4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(0.6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(0.8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(1)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .3113 m
.05556 .3113 L
.16667 .31103 L
.27778 .31051 L
.38889 .30981 L
.5 .30902 L
.61111 .30822 L
.72222 .30752 L
.83333 .30701 L
.94444 .30673 L
s
.94444 .30673 m
1 .30673 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
0 .31124 m
.00123 .31124 L
.00236 .31124 L
.00365 .31124 L
.00488 .31124 L
.00706 .31124 L
.00942 .31124 L
.01203 .31124 L
.01479 .31124 L
.01975 .31124 L
.02486 .31123 L
.02966 .31123 L
.04057 .31122 L
.0517 .31121 L
.06188 .3112 L
.08481 .31116 L
.10474 .31112 L
.1265 .31107 L
.16918 .31093 L
.21027 .31077 L
.25393 .31057 L
.296 .31035 L
.33648 .31011 L
.37953 .30984 L
.42099 .30956 L
.46086 .30929 L
.50331 .30899 L
.54416 .30871 L
.58759 .30841 L
.62943 .30814 L
.66967 .30789 L
.7125 .30764 L
.75372 .30743 L
.79336 .30725 L
.83558 .30708 L
.8762 .30696 L
.89683 .30691 L
.91939 .30687 L
.94095 .30683 L
.95057 .30682 L
.961 .30681 L
.96647 .30681 L
.97151 .3068 L
.97624 .3068 L
.98143 .3068 L
.98609 .3068 L
.99045 .3068 L
.99286 .3068 L
.99505 .30679 L
.99627 .30679 L
Mistroke
.99759 .30679 L
.99884 .30679 L
1 .30679 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool4
o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3o
ooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnoooo
o`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`3oooooocgooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool6o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo
000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo0?oooooo?Oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooocgooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o0000oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oooooo?Oooool0
00Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000
ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo0_l000000ol@413oooooooooo`0Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00`ooooo`Co000000?o410@oooooooo
ool04?ooool002Wooooo00?o0000ooooooooool0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q03;ooooo00?o0000oooo
ooooool04_ooool002Wooooo00?o0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<_ooool00ol0
003oooooooooo`0Booooo`00:Oooool2o`0002kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^02Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B409oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0b
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo02gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo02Kooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0002Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`09oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00booooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooo
oooo02gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo02Wooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@4100<_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`0]ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@02Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH02Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000<_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`0]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMg
Mol0003ooooo02Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
42Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<?oo
ool00omEEEGoIVIVo`00000Dooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002ooooo`;o
00001?ooool002Wooooo00?o0000ooooooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool002WoooooN?l0000@ool000ko00004?oo000=o`00013oo`003_l0000@ool000ko
00004?oo000>o`00013oo`003_l0000;ooooo`04omgMgOl0003o410@olc<c0Gooooo000Yooooo`03
o`000?oo003oo`0000koo`003_l0000?ool000ko00004?oo000>o`00013oo`003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`09ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Yooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b
<PGooooo000Yooooo`03o`000?oooooooooo0?oooooo<oooool2o`0000;ooooo0_l00004ooooo`00
:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00
:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wo
oooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
oooo?Oooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`3oooooocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3ooooo
ocgooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`000?oooooo?_oo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolm
ooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oo
oooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Ooo
ool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3ooooo
ocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo
000Yooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`000?oooooo?Oooool000kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
oooooolmooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`00
3_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Ko
oooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool0
0ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yoooo
o`;o0000oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`3oooooocgooooo0006ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
ocgooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`;o0000oooooolnooooo`00:Oooool00ol0003ooooooooo
o`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`;o0000
oooooolnooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Oooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`?o
0000oooooolmooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oooooo
JOooool00:3ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj
^[[ooooo0:;ooooo002Pooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S:Sooooo`00UOooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00001Oooool2ob4Q8H?ooooo002Gooooo`03o`00
0?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`00
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4QPoooool009Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h0Roooool009Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^08[ooooo002Goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`03ogMgMomVIVKooooo08Wooooo002Dooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00003_oo
ool00ol0003oooooooooo`28ooooo`00U?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@08[ooooo
002Dooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o
0000ooooooooool02oooool01OnHV9So410@o`000?lQ8B7oc<c<08[ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.138417, -1.13153, \
0.00419705, 0.0135819}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The close agreement between the numerical result (solid) and the \
exact solution (dashed) speaks for itself.\
\>", "Text"],

Cell[TextData[{
  "\tMixed boundary conditions are more of a challenge. Now both the function \
and its derivative are required on the boundary. For example, at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " the general mixed boundary condition is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = a\ [T(0, t) - \[Tau]]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa], \ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " are given constants. How do we obtain second-order-accurate values for \
both ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and its derivative at the boundary point?"
}], "Text"],

Cell[TextData[{
  "\tSince the boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " falls halfway between the ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1\)]],
  " grid points, one  simple approach  is to  use the average value, ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \((T\_0\%n + T\_1\%n)\)\)]],
  ", to approximate ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0. \)]],
  " We still use the centered-difference form for the first derivative for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
              0\)\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", so the mixed boundary condition becomes"
}], "Text"],

Cell[TextData[{
  "\[Kappa] ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(T\_1\%n - T\_0\%n\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], 
          "=", \(a[\(1\/2\) \((T\_0\%n + T\_1\%n)\) - \[Tau]]\)}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.22)"],

Cell[TextData[{
  "Solving for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), Cell[""]}], TraditionalForm]]],
  " yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\%n\), "=", 
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", "a", " ", "\[Tau]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(2  \[Kappa]\), " ", "-", 
                    RowBox[{"a", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]}], 
                  ")"}], \(T\_1\%n\)}]}], 
            RowBox[{\(2\ \[Kappa]\), "+", 
              RowBox[{"a", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}]]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.23)"],

Cell[TextData[{
  "Similarly, for a mixed boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = L\)\(,\)\)\)]],
  " namely ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa] \[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                L\)\)\) = \(-b\)\ \((T(L, t) - \[Tau])\)\)]],
  ", we take a grid for which ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " falls halfway between gridpoints ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\( | \_\(x = 
                L\)\)\) = \(1\/2\) \((T\_M\%n + \ T\_\(M - 1\)\%n)\)\)]],
  ". Then the boundary condition is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Kappa]", 
          FormBox[
            RowBox[{
              FractionBox[\(T\_M\%n - T\_\(M - 1\)\%n\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], 
              "=", \(-b[\(1\/2\) \((T\_\(M - 1\)\%n + 
                          T\_M\%n)\) - \[Tau]]\)}],
            "TraditionalForm"]}], ","}], TraditionalForm]]]], "NE2",
  CellTags->"(6.2.24)"],

Cell["which leads to ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(T\_M\%n\), "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"2", " ", "b", " ", "\[Tau]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{\(2  \[Kappa]\), " ", "-", 
                    RowBox[{"b", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]}], 
                  ")"}], \(T\_\(M - 1\)\%n\)}]}], 
            RowBox[{\(2\ \[Kappa]\), "+", 
              RowBox[{"b", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}]], "."}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.25)"],

Cell["\<\
Implementation of these boundary conditions follows the same course \
as in our previous examples, and is left to the exercises.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple Spatial Dimensions", "Section",
  CellTags->"c:21"],

Cell[CellGroupData[{

Cell["Explicit Methods", "Subsubsection"],

Cell["\<\
The explicit methods discussed previously generalize easily to PDEs \
in multiple spatial dimensions. Continuing with our heat equation model, we \
now consider the problem in two dimensions:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(T(x, y, 
            t)\) = \[Chi]\ \((\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2)\) \(T(x, y, t)\) + S(x, y, t)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.26)"],

Cell[TextData[{
  "For simplicity, we take the boundary to be a rectangular box of sides ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ", and create a rectangular spatial grid in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(j = 0\), ",", 
          "1", ",", "2", ",", "...", ",", \(M\_x\)}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(y\_k\), "=", 
            RowBox[{"k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(k = 0\), ",", 
          "1", ",", "2", ",", "...", ",", \(M\_y\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.27)"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"where", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}], " ", "=", " ", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], " ", "=", " ", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  ". (Nonrectangular boundaries are treated in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell["\<\
\t The FTCS method on this grid is a trivial extension of the \
method in one-dimension:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(T\_\(j\ k\)\%n\), "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_\(j\ k\)\%n\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((T\_\(j + 1\ k\)\%n - 2  T\_\(j\ k\)\%n + 
                  T\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{"\[Chi]", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((T\_\(j\ k + 1\)\%n - 2  T\_\(j\ k\)\%n + 
                  T\_\(j\ k - 1\)\%\(\(\ \)\(n\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.28)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.2.28)",
    ButtonData:>"(6.2.28)",
    ButtonStyle->"Hyperlink"],
  " is valid for the points interior to the rectangle, and must be \
supplemented by boundary conditions that determine the points on the \
boundary, as well as by initial conditions specifying ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%\(\(\ \)\(0\)\)\)]],
  ".von Neumann stability analysis for this difference equation considers the \
stability of  a Fourier mode of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\^n\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \(k\_x\
\) x\)\) \[ExponentialE]\^\(\[ImaginaryI]\ k\_y\ y\)\)]],
  ", and leads to a Courant condition that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Chi]", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], "\[LessEqual]", " ", 
        RowBox[{\(1\/2\), 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], 
          FractionBox[
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "2"], 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "+", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]}]]}]}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(6.2.29)"],

Cell["\<\
(see the exercises).  The other explicit methods discussed \
previously, CTCS and Lax, also can be easily extended to multiple dimensions. \
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Wave Equation with Nonuniform Wave Speed", "Subsubsection",
  CellTags->"i:26"],

Cell["\<\
As an example of an explicit method in two dimensions,  we \
construct the numerical solution to a wave equation in two dimensions with \
nonuniform wave speed, \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\((\[PartialD]t)\)\^2\) \(z(x, y, 
            t)\) = \(\(c\^2\)(x, 
              y)\)\ [\[PartialD]\^2\/\[PartialD]x\^2 + \[PartialD]\^2\/\
\[PartialD]y\^2] \(z(x, y, t)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 0) = \(z\_o\)(x, y), \ \(z\& . \)(x, y, 
          0) = \(v\_o\)(x, y)\)]],
  ". Here we take the simple case ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o = \(v\_o = 0\)\)]],
  ". For boundary conditions",
  ",",
  " we choose a square domain with unit sides and take an oscillating \
boundary condition,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z(0, y, t) = \(z(1, y, t) = \(z(x, 1, t) = 0\)\); \ 
      z(x, 0, t) = \(x(1 - x)\) sin\ 2  t\)]],
  ". "
}], "Text"],

Cell["\tFor the wave speed, we choose ", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c(x, y)\  = 
        1\/10\ \((1\  - 
              0.7\ exp[\(-2\) \((x - 0.5)\)\^2 - 5 \((y - 0.5)\)\^2])\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The wave speed, plotted in Cell ",
  ButtonBox["6.72",
    ButtonData:>"Cell 6.72",
    ButtonStyle->"Hyperlink"],
  ",  has a minimum at the center of the box."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\[IndentingNewLine]\), "\n", 
    \(\(\(cw[x_, y_]\  = \ 
        1/10\ \((1\  -  .7\ Exp[\(-2\) \((x - 0.5)\)\^2 - 
                    5 \((y - 0.5)\)\^2])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Plot3D[cw[x, y], {x, 0, 1}, {y, 0, 1}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel -> "\<wave speed\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -32.0625 0 ]
[.5 .82364 32.0625 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01831 .30146 -24 -2.77304 ]
[.01831 .30146 0 6.22696 ]
[.00629 .37681 -24 -2.83694 ]
[.00629 .37681 0 6.16306 ]
[-0.00633 .45589 -24 -2.90433 ]
[-0.00633 .45589 0 6.09567 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -93.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(wave) show
93.125 13.000 moveto
(speed) show
123.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03056 .29676 m
.03669 .29441 L
s
[(0.04)] .01831 .30146 1 -0.38377 Mshowa
.0186 .37226 m
.02475 .36998 L
s
[(0.06)] .00629 .37681 1 -0.36957 Mshowa
.00604 .4515 m
.01223 .44931 L
s
[(0.08)] -0.00633 .45589 1 -0.35459 Mshowa
.125 Mabswid
.02763 .3153 m
.03131 .3139 L
s
.02465 .33406 m
.02834 .33267 L
s
.02164 .35304 m
.02533 .35167 L
s
.01552 .39171 m
.01921 .39035 L
s
.0124 .41139 m
.0161 .41005 L
s
.00924 .43132 m
.01295 .43 L
s
.03347 .27844 m
.03714 .27702 L
s
.03634 .26033 m
.04 .2589 L
s
.0028 .47193 m
.00652 .47063 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.696 .653 .803 r
.37539 .76904 .39806 .80578 .43711 .78916 .41473 .74956 Metetra
.691 .64 .794 r
.41473 .74956 .43711 .78916 .47659 .77263 .45444 .73029 Metetra
.683 .627 .787 r
.45444 .73029 .47659 .77263 .51651 .7565 .49454 .71163 Metetra
.675 .616 .782 r
.49454 .71163 .51651 .7565 .5569 .74104 .53506 .69397 Metetra
.665 .605 .778 r
.53506 .69397 .5569 .74104 .59781 .72653 .57605 .67767 Metetra
.655 .595 .776 r
.57605 .67767 .59781 .72653 .63928 .71318 .61759 .66303 Metetra
.645 .587 .776 r
.61759 .66303 .63928 .71318 .68139 .70112 .65977 .65024 Metetra
.634 .581 .777 r
.65977 .65024 .68139 .70112 .7242 .69042 .70267 .63938 Metetra
.624 .577 .781 r
.70267 .63938 .7242 .69042 .76779 .68105 .74638 .63042 Metetra
.615 .575 .786 r
.74638 .63042 .76779 .68105 .81222 .67289 .791 .62319 Metetra
.606 .575 .793 r
.791 .62319 .81222 .67289 .85755 .66575 .83659 .61744 Metetra
.599 .578 .801 r
.83659 .61744 .85755 .66575 .90381 .65938 .88321 .61283 Metetra
.594 .584 .811 r
.88321 .61283 .90381 .65938 .95103 .6535 .9309 .60896 Metetra
.591 .593 .822 r
.9309 .60896 .95103 .6535 .99922 .6478 .97966 .60542 Metetra
.705 .645 .787 r
.35246 .72906 .37539 .76904 .41473 .74956 .39211 .70638 Metetra
.698 .632 .779 r
.39211 .70638 .41473 .74956 .45444 .73029 .43206 .68403 Metetra
.689 .618 .772 r
.43206 .68403 .45444 .73029 .49454 .71163 .47233 .66254 Metetra
.679 .606 .767 r
.47233 .66254 .49454 .71163 .53506 .69397 .51296 .64242 Metetra
.668 .594 .763 r
.51296 .64242 .53506 .69397 .57605 .67767 .55401 .62415 Metetra
.656 .583 .762 r
.55401 .62415 .57605 .67767 .61759 .66303 .59558 .6081 Metetra
.643 .574 .762 r
.59558 .6081 .61759 .66303 .65977 .65024 .63777 .59452 Metetra
.63 .566 .764 r
.63777 .59452 .65977 .65024 .70267 .63938 .68069 .58351 Metetra
.617 .56 .768 r
.68069 .58351 .70267 .63938 .74638 .63042 .72447 .57502 Metetra
.605 .556 .773 r
.72447 .57502 .74638 .63042 .791 .62319 .76921 .56887 Metetra
.594 .555 .78 r
.76921 .56887 .791 .62319 .83659 .61744 .81501 .5647 Metetra
.585 .557 .789 r
.81501 .5647 .83659 .61744 .88321 .61283 .86195 .56209 Metetra
.578 .562 .8 r
.86195 .56209 .88321 .61283 .9309 .60896 .91006 .56053 Metetra
.574 .57 .812 r
.91006 .56053 .9309 .60896 .97966 .60542 .95936 .55948 Metetra
.715 .645 .778 r
.32924 .68736 .35246 .72906 .39211 .70638 .36922 .66134 Metetra
.707 .631 .77 r
.36922 .66134 .39211 .70638 .43206 .68403 .40944 .63579 Metetra
.698 .618 .764 r
.40944 .63579 .43206 .68403 .47233 .66254 .4499 .61137 Metetra
.686 .604 .759 r
.4499 .61137 .47233 .66254 .51296 .64242 .49066 .58872 Metetra
.673 .592 .757 r
.49066 .58872 .51296 .64242 .55401 .62415 .53177 .56842 Metetra
.658 .58 .756 r
.53177 .56842 .55401 .62415 .59558 .6081 .57335 .55091 Metetra
.643 .569 .757 r
.57335 .55091 .59558 .6081 .63777 .59452 .61553 .53652 Metetra
.627 .56 .759 r
.61553 .53652 .63777 .59452 .68069 .58351 .65845 .52535 Metetra
.611 .552 .763 r
.65845 .52535 .68069 .58351 .72447 .57502 .70225 .51736 Metetra
.596 .546 .769 r
.70225 .51736 .72447 .57502 .76921 .56887 .74708 .51229 Metetra
.582 .544 .777 r
.74708 .51229 .76921 .56887 .81501 .5647 .79305 .50976 Metetra
.571 .544 .786 r
.79305 .50976 .81501 .5647 .86195 .56209 .84026 .50921 Metetra
.561 .547 .796 r
.84026 .50921 .86195 .56209 .91006 .56053 .88876 .51003 Metetra
.555 .555 .809 r
.88876 .51003 .91006 .56053 .95936 .55948 .93857 .51156 Metetra
.728 .653 .775 r
.3056 .64602 .32924 .68736 .36922 .66134 .34597 .61681 Metetra
.72 .64 .768 r
.34597 .61681 .36922 .66134 .40944 .63579 .3865 .58823 Metetra
.709 .627 .763 r
.3865 .58823 .40944 .63579 .4499 .61137 .42721 .56104 Metetra
.696 .613 .76 r
.42721 .56104 .4499 .61137 .49066 .58872 .46812 .53599 Metetra
.681 .6 .759 r
.46812 .53599 .49066 .58872 .53177 .56842 .50933 .51376 Metetra
.664 .587 .759 r
.50933 .51376 .53177 .56842 .57335 .55091 .55096 .49487 Metetra
.646 .575 .761 r
.55096 .49487 .57335 .55091 .61553 .53652 .59316 .47968 Metetra
.626 .564 .764 r
.59316 .47968 .61553 .53652 .65845 .52535 .63609 .46833 Metetra
.607 .554 .769 r
.63609 .46833 .65845 .52535 .70225 .51736 .67992 .46076 Metetra
.588 .546 .776 r
.67992 .46076 .70225 .51736 .74708 .51229 .72483 .45668 Metetra
.57 .541 .783 r
.72483 .45668 .74708 .51229 .79305 .50976 .77096 .45562 Metetra
.555 .54 .793 r
.77096 .45562 .79305 .50976 .84026 .50921 .81841 .45696 Metetra
.542 .542 .803 r
.81841 .45696 .84026 .50921 .88876 .51003 .86727 .45997 Metetra
.534 .548 .815 r
.86727 .45997 .88876 .51003 .93857 .51156 .91755 .46387 Metetra
.744 .672 .78 r
.28134 .60739 .3056 .64602 .34597 .61681 .32215 .57548 Metetra
.736 .66 .775 r
.32215 .57548 .34597 .61681 .3865 .58823 .36307 .54431 Metetra
.725 .647 .772 r
.36307 .54431 .3865 .58823 .42721 .56104 .40408 .51476 Metetra
.711 .635 .771 r
.40408 .51476 .42721 .56104 .46812 .53599 .44524 .48767 Metetra
.694 .622 .771 r
.44524 .48767 .46812 .53599 .50933 .51376 .48663 .46379 Metetra
.674 .608 .773 r
.48663 .46379 .50933 .51376 .55096 .49487 .52838 .44369 Metetra
.652 .595 .777 r
.52838 .44369 .55096 .49487 .59316 .47968 .57067 .42778 Metetra
.629 .582 .782 r
.57067 .42778 .59316 .47968 .63609 .46833 .61368 .4162 Metetra
.604 .57 .789 r
.61368 .4162 .63609 .46833 .67992 .46076 .6576 .40889 Metetra
.579 .559 .796 r
.6576 .40889 .67992 .46076 .72483 .45668 .70263 .40552 Metetra
.556 .551 .804 r
.70263 .40552 .72483 .45668 .77096 .45562 .74893 .40559 Metetra
.536 .547 .813 r
.74893 .40559 .77096 .45562 .81841 .45696 .79663 .40839 Metetra
.52 .547 .823 r
.79663 .40839 .81841 .45696 .86727 .45997 .84583 .41312 Metetra
.509 .551 .834 r
.84583 .41312 .86727 .45997 .91755 .46387 .89657 .41891 Metetra
.762 .701 .794 r
.2562 .57368 .28134 .60739 .32215 .57548 .29751 .5398 Metetra
.755 .692 .791 r
.29751 .5398 .32215 .57548 .36307 .54431 .33888 .50676 Metetra
.745 .683 .791 r
.33888 .50676 .36307 .54431 .40408 .51476 .3803 .47549 Metetra
.731 .672 .793 r
.3803 .47549 .40408 .51476 .44524 .48767 .4218 .4469 Metetra
.712 .661 .797 r
.4218 .4469 .44524 .48767 .48663 .46379 .46348 .42177 Metetra
.69 .648 .803 r
.46348 .42177 .48663 .46379 .52838 .44369 .50548 .40073 Metetra
.664 .634 .81 r
.50548 .40073 .52838 .44369 .57067 .42778 .54798 .38419 Metetra
.634 .62 .818 r
.54798 .38419 .57067 .42778 .61368 .4162 .59118 .37232 Metetra
.602 .605 .827 r
.59118 .37232 .61368 .4162 .6576 .40889 .63529 .36504 Metetra
.57 .591 .835 r
.63529 .36504 .6576 .40889 .70263 .40552 .68052 .36201 Metetra
.539 .579 .844 r
.68052 .36201 .70263 .40552 .74893 .40559 .72706 .36268 Metetra
.512 .571 .852 r
.72706 .36268 .74893 .40559 .79663 .40839 .77507 .36632 Metetra
.491 .566 .86 r
.77507 .36632 .79663 .40839 .84583 .41312 .82463 .37205 Metetra
.477 .567 .868 r
.82463 .37205 .84583 .41312 .89657 .41891 .87581 .37895 Metetra
.783 .743 .816 r
.22988 .54647 .2562 .57368 .29751 .5398 .27174 .51157 Metetra
.778 .739 .817 r
.27174 .51157 .29751 .5398 .33888 .50676 .31364 .47754 Metetra
.769 .735 .822 r
.31364 .47754 .33888 .50676 .3803 .47549 .35555 .44534 Metetra
.755 .73 .829 r
.35555 .44534 .3803 .47549 .4218 .4469 .39752 .4159 Metetra
.736 .723 .839 r
.39752 .4159 .4218 .4469 .46348 .42177 .43963 .39003 Metetra
.711 .714 .851 r
.43963 .39003 .46348 .42177 .50548 .40073 .48202 .36837 Metetra
.679 .702 .864 r
.48202 .36837 .50548 .40073 .54798 .38419 .52489 .35133 Metetra
.64 .687 .878 r
.52489 .35133 .54798 .38419 .59118 .37232 .56843 .33909 Metetra
.597 .669 .89 r
.56843 .33909 .59118 .37232 .63529 .36504 .61288 .33155 Metetra
.552 .65 .899 r
.61288 .33155 .63529 .36504 .68052 .36201 .65844 .32839 Metetra
.51 .631 .906 r
.65844 .32839 .68052 .36201 .72706 .36268 .70534 .32904 Metetra
.474 .615 .91 r
.70534 .32904 .72706 .36268 .77507 .36632 .75372 .33273 Metetra
.447 .604 .913 r
.75372 .33273 .77507 .36632 .82463 .37205 .8037 .33859 Metetra
.432 .599 .915 r
.8037 .33859 .82463 .37205 .87581 .37895 .85534 .34564 Metetra
.802 .796 .847 r
.20211 .52644 .22988 .54647 .27174 .51157 .24455 .49153 Metetra
.799 .8 .852 r
.24455 .49153 .27174 .51157 .31364 .47754 .28702 .45746 Metetra
.792 .805 .862 r
.28702 .45746 .31364 .47754 .35555 .44534 .32952 .42518 Metetra
.779 .808 .876 r
.32952 .42518 .35555 .44534 .39752 .4159 .37207 .3956 Metetra
.758 .81 .894 r
.37207 .3956 .39752 .4159 .43963 .39003 .41475 .36953 Metetra
.727 .809 .915 r
.41475 .36953 .43963 .39003 .48202 .36837 .45771 .34758 Metetra
.686 .802 .937 r
.45771 .34758 .48202 .36837 .52489 .35133 .50111 .33017 Metetra
.633 .787 .956 r
.50111 .33017 .52489 .35133 .56843 .33909 .54518 .31747 Metetra
.571 .763 .969 r
.54518 .31747 .56843 .33909 .61288 .33155 .59013 .30939 Metetra
.507 .734 .975 r
.59013 .30939 .61288 .33155 .65844 .32839 .6362 .3056 Metetra
.449 .702 .975 r
.6362 .3056 .65844 .32839 .70534 .32904 .68358 .30553 Metetra
.404 .674 .971 r
.68358 .30553 .70534 .32904 .75372 .33273 .73245 .30845 Metetra
.376 .654 .965 r
.73245 .30845 .75372 .33273 .8037 .33859 .78293 .31347 Metetra
.366 .642 .962 r
.78293 .31347 .8037 .33859 .85534 .34564 .83509 .31965 Metetra
.812 .853 .88 r
.17268 .51318 .20211 .52644 .24455 .49153 .2157 .47923 Metetra
.81 .867 .89 r
.2157 .47923 .24455 .49153 .28702 .45746 .25879 .44603 Metetra
.802 .882 .904 r
.25879 .44603 .28702 .45746 .32952 .42518 .30195 .41448 Metetra
.785 .896 .922 r
.30195 .41448 .32952 .42518 .37207 .3956 .34518 .38544 Metetra
.756 .906 .943 r
.34518 .38544 .37207 .3956 .41475 .36953 .38857 .35967 Metetra
.71 .909 .965 r
.38857 .35967 .41475 .36953 .45771 .34758 .43223 .33776 Metetra
.647 .901 .983 r
.43223 .33776 .45771 .34758 .50111 .33017 .47635 .3201 Metetra
.567 .877 .993 r
.47635 .3201 .50111 .33017 .54518 .31747 .52112 .30685 Metetra
.479 .838 .994 r
.52112 .30685 .54518 .31747 .59013 .30939 .56676 .29794 Metetra
.396 .792 .987 r
.56676 .29794 .59013 .30939 .6362 .3056 .61349 .29303 Metetra
.329 .747 .977 r
.61349 .29303 .6362 .3056 .68358 .30553 .66152 .2916 Metetra
.288 .711 .97 r
.66152 .2916 .68358 .30553 .73245 .30845 .71101 .29295 Metetra
.272 .688 .969 r
.71101 .29295 .73245 .30845 .78293 .31347 .76209 .29622 Metetra
.28 .677 .971 r
.76209 .29622 .78293 .31347 .83509 .31965 .81484 .30054 Metetra
.806 .904 .91 r
.1415 .50531 .17268 .51318 .2157 .47923 .18507 .47312 Metetra
.8 .924 .919 r
.18507 .47312 .2157 .47923 .25879 .44603 .22879 .44155 Metetra
.783 .943 .93 r
.22879 .44155 .25879 .44603 .30195 .41448 .27264 .41141 Metetra
.751 .957 .939 r
.27264 .41141 .30195 .41448 .34518 .38544 .31663 .38348 Metetra
.699 .961 .945 r
.31663 .38348 .34518 .38544 .38857 .35967 .36082 .35844 Metetra
.624 .948 .941 r
.36082 .35844 .38857 .35967 .43223 .33776 .40533 .33684 Metetra
.529 .915 .928 r
.40533 .33684 .43223 .33776 .47635 .3201 .45031 .31903 Metetra
.423 .864 .905 r
.45031 .31903 .47635 .3201 .52112 .30685 .49594 .30516 Metetra
.323 .807 .881 r
.49594 .30516 .52112 .30685 .56676 .29794 .54244 .29515 Metetra
.243 .753 .865 r
.54244 .29515 .56676 .29794 .61349 .29303 .59 .28872 Metetra
.19 .714 .863 r
.59 .28872 .61349 .29303 .66152 .2916 .63882 .28536 Metetra
.168 .691 .876 r
.63882 .28536 .66152 .2916 .71101 .29295 .68907 .28444 Metetra
.176 .685 .901 r
.68907 .28444 .71101 .29295 .76209 .29622 .74087 .2852 Metetra
.207 .69 .931 r
.74087 .2852 .76209 .29622 .81484 .30054 .79429 .28682 Metetra
.781 .935 .931 r
.10857 .50072 .1415 .50531 .18507 .47312 .15266 .47084 Metetra
.765 .955 .935 r
.15266 .47084 .18507 .47312 .22879 .44155 .197 .44143 Metetra
.734 .969 .933 r
.197 .44143 .22879 .44155 .27264 .41141 .24155 .41317 Metetra
.683 .97 .923 r
.24155 .41317 .27264 .41141 .31663 .38348 .28633 .38674 Metetra
.607 .952 .901 r
.28633 .38674 .31663 .38348 .36082 .35844 .33139 .36274 Metetra
.512 .914 .866 r
.33139 .36274 .36082 .35844 .40533 .33684 .37683 .34164 Metetra
.406 .858 .822 r
.37683 .34164 .40533 .33684 .45031 .31903 .42277 .32374 Metetra
.303 .796 .781 r
.42277 .32374 .45031 .31903 .49594 .30516 .4694 .30919 Metetra
.217 .739 .752 r
.4694 .30919 .49594 .30516 .54244 .29515 .51688 .2979 Metetra
.156 .696 .742 r
.51688 .2979 .54244 .29515 .59 .28872 .5654 .28963 Metetra
.123 .673 .755 r
.5654 .28963 .59 .28872 .63882 .28536 .61515 .28393 Metetra
.12 .67 .789 r
.61515 .28393 .63882 .28536 .68907 .28444 .66628 .28026 Metetra
.144 .683 .837 r
.66628 .28026 .68907 .28444 .74087 .2852 .7189 .27794 Metetra
.19 .705 .889 r
.7189 .27794 .74087 .2852 .79429 .28682 .77309 .27627 Metetra
.747 .944 .947 r
.07404 .49701 .10857 .50072 .15266 .47084 .1186 .46969 Metetra
.724 .96 .944 r
.1186 .46969 .15266 .47084 .197 .44143 .16351 .44268 Metetra
.685 .966 .932 r
.16351 .44268 .197 .44143 .24155 .41317 .20875 .41652 Metetra
.625 .957 .909 r
.20875 .41652 .24155 .41317 .28633 .38674 .25433 .39179 Metetra
.545 .929 .873 r
.25433 .39179 .28633 .38674 .33139 .36274 .30027 .36896 Metetra
.453 .883 .828 r
.30027 .36896 .33139 .36274 .37683 .34164 .34667 .34844 Metetra
.358 .828 .78 r
.34667 .34844 .37683 .34164 .42277 .32374 .39365 .33048 Metetra
.274 .773 .742 r
.39365 .33048 .42277 .32374 .4694 .30919 .44133 .31519 Metetra
.208 .729 .719 r
.44133 .31519 .4694 .30919 .51688 .2979 .48988 .30251 Metetra
.165 .7 .719 r
.48988 .30251 .51688 .2979 .5654 .28963 .53947 .29222 Metetra
.148 .69 .74 r
.53947 .29222 .5654 .28963 .61515 .28393 .59024 .28397 Metetra
.156 .698 .782 r
.59024 .28397 .61515 .28393 .66628 .28026 .64233 .27727 Metetra
.188 .718 .836 r
.64233 .27727 .66628 .28026 .7189 .27794 .69586 .27159 Metetra
.239 .743 .892 r
.69586 .27159 .7189 .27794 .77309 .27627 .75091 .26633 Metetra
.716 .935 .96 r
.0381 .4919 .07404 .49701 .1186 .46969 .08308 .4671 Metetra
.693 .95 .956 r
.08308 .4671 .1186 .46969 .16351 .44268 .12852 .44243 Metetra
.656 .955 .945 r
.12852 .44243 .16351 .44268 .20875 .41652 .17441 .41835 Metetra
.603 .947 .923 r
.17441 .41835 .20875 .41652 .25433 .39179 .22074 .39528 Metetra
.537 .924 .892 r
.22074 .39528 .25433 .39179 .30027 .36896 .26756 .37361 Metetra
.463 .89 .855 r
.26756 .37361 .30027 .36896 .34667 .34844 .31492 .35365 Metetra
.389 .849 .819 r
.31492 .35365 .34667 .34844 .39365 .33048 .36293 .3356 Metetra
.325 .81 .792 r
.36293 .3356 .39365 .33048 .44133 .31519 .4117 .31955 Metetra
.277 .779 .779 r
.4117 .31955 .44133 .31519 .48988 .30251 .46135 .30544 Metetra
.249 .762 .784 r
.46135 .30544 .48988 .30251 .53947 .29222 .51204 .2931 Metetra
.242 .758 .807 r
.51204 .2931 .53947 .29222 .59024 .28397 .56389 .28225 Metetra
.256 .766 .844 r
.56389 .28225 .59024 .28397 .64233 .27727 .61701 .2725 Metetra
.288 .781 .889 r
.61701 .2725 .64233 .27727 .69586 .27159 .67152 .26343 Metetra
.333 .798 .933 r
.67152 .26343 .69586 .27159 .75091 .26633 .72747 .25457 Metetra
.694 .915 .97 r
.00095 .48363 .0381 .4919 .08308 .4671 .04631 .46103 Metetra
.676 .93 .97 r
.04631 .46103 .08308 .4671 .12852 .44243 .09224 .43843 Metetra
.649 .938 .965 r
.09224 .43843 .12852 .44243 .17441 .41835 .13873 .41617 Metetra
.612 .938 .954 r
.13873 .41617 .17441 .41835 .22074 .39528 .18578 .39455 Metetra
.566 .928 .937 r
.18578 .39455 .22074 .39528 .26756 .37361 .23342 .37387 Metetra
.515 .911 .917 r
.23342 .37387 .26756 .37361 .31492 .35365 .28171 .35435 Metetra
.465 .889 .898 r
.28171 .35435 .31492 .35365 .36293 .3356 .33072 .33615 Metetra
.422 .866 .884 r
.33072 .33615 .36293 .3356 .4117 .31955 .38055 .31932 Metetra
.39 .849 .88 r
.38055 .31932 .4117 .31955 .46135 .30544 .4313 .30382 Metetra
.373 .837 .886 r
.4313 .30382 .46135 .30544 .51204 .2931 .48308 .28952 Metetra
.371 .833 .903 r
.48308 .28952 .51204 .2931 .56389 .28225 .53601 .2762 Metetra
.384 .835 .927 r
.53601 .2762 .56389 .28225 .61701 .2725 .59019 .26358 Metetra
.407 .838 .953 r
.59019 .26358 .61701 .2725 .67152 .26343 .64571 .25133 Metetra
.438 .84 .976 r
.64571 .25133 .67152 .26343 .72747 .25457 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00moooool4o`000003oa0@4?oooooooooo06[ooooo003iooooo`03o`00
0?oooooooooo06cooooo003iooooo`03o`000?oooooooooo06cooooo003iooooo`03o`000?oooooo
oooo06cooooo003iooooo`03o`000?oooooooooo06cooooo003iooooo`03o`000?oooooooooo06co
oooo003iooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Pooooo`00
moooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0H?ooool00?oooooo
1?ooool01Ol@413ooooooooooooooooo410@063ooooo003oooooo`Cooooo00Go0000oooooooooooo
ooooo`00001Pooooo`00ooooool4ooooo`05o`000?ooooooooooooooool00000H?ooool00?oooooo
1?ooool01Ol@413ooooooooooooooooo410@063ooooo003mooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg063ooooo003jooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^063ooooo003hooooo`;o00001?ooool2o`0006Sooooo003eooooo`?o00001_oo
ool00ol0003oooooo`00001Wooooo`00l_ooool3o`0000Wooooo00?o0000ooooool00000Ioooool0
0?3ooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Kooooo002jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000IOooool00;[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000IOooool00;[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`00^_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006?ooooo002jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol00002ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Qooooo`00^_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`;o00007?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo063ooooo002jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000oooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Goooool00;[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT03?ooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Oooooo`00N?ooool2o`0000;ooooo0_l0001Kooooo`;o000000?oooooo`000?ooool08Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo001hooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMF?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05kooooo001iooooo`04omgMgOl0003o410@olc<c5Oooooo0_l0
000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0GOooool007Wooooo00Cok^k^
ob4Q8Ol@413ok^k^E?ooool3o`0002_ooooo00?o0000ooooooooool01_ooool2o`0005kooooo001i
ooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0G?ooool007Sooooo0_l00002ooooo`;o0000C_ooool3o`0000;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05_ooooo003:oooo
o`;o00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0F_ooool00<Oooooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0F_ooool00<Cooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
FOooool008kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<01oooooo0_l00002ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Hooooo`00S_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407?ooool3o`0003gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Hooooo`00S_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Jooooo`;o0000@?ooool00ol0003oooooooooo`0;
ooooo`;o0000FOooool008kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B405oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000kooooo`00S_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`;o
000000?oooooo`000?ooool0@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403_ooooo002>ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0D
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0??oo
ool008kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01;ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0>oooool008kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40gooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0>_ooool00:gooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0>Oooool00:_o
oooo0_l00004ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03_ooooo002Xooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00kooooo`00Y_ooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Aooooo`00Xoooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1@ooooo`00XOooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo053o
oooo002Nooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0Coooool009cooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0C_ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Tooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0C_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0COooool006?ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00007?ooool2o`0006[ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00
001>ooooo`00Hoooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
6_ooool3o`0006cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1<ooooo`00Hooo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0006oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1;ooooo`00Hoooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04_ooooo001Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o0000M?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000M_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04Wooooo0025ooooo`;o0000NOooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Wooooo0022ooooo`?o00000_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo01Wooooo0_l0001:ooooo`00Ooooool3o`0007kooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`17ooooo`00OOooool2o`0008;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`17ooooo`00N_ooool3o`0008Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`16ooooo`00N?ooool2o`0000;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo04Gooooo001eooooo`?o00001Oooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0AOooool007?ooooo0_l0002<
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0A?ooool003_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00023ooooo0ol0002>ooooo`03o`000?oooooo
oooo01cooooo0ol00015ooooo`00>oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool2o`0000?ooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Kooooo000kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Looooo`?o0000Toooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`0Wooooo`00>oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0009Kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Sooooo000kooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eooooo`?o0000V?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`04odA4A?oMgMgoooooo`0000[ooooo0ol000000ol@413oooooooooo`0Iooooo`00>oooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool04Oooool3o`0000?ooooo00?o
0000ooooooooool0UOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000cooooo00?o410@okZj^_oo
ool06_ooool003_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41004Oooool2o`0009kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000<ooooo`03oiRHV?lb<S;o
oooo01[ooooo000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00kooooo0ol0002Pooooo`03o`000?oooooooooo027ooooo0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000<ooooo`03omgMgOl0003o^[Zj01[ooooo
001Looooo`?o0000X_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00_ooooo00?oEEEEogMgMom4
A4@06_ooool005Wooooo0ol00003ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Oooooo`05omgMgOl@413oooooob4Q8OoMgMd06Oooool005Oooooo
0_l0002Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07oooool01OmVIVKoQhN7
oooooonHV9SoEEEE01Wooooo001Dooooo`?o0000Z_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01gooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Gooooo`00DOoo
ool3o`000003ooooool0003ooooo0:[ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05_ooool004oooooo0_l0
0005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0kooooo`00C?ooool3o`000;?ooooo00?o0000ooooooooool09Oooool2o`0003cooooo000Uoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`000;Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0jooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002
ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0i
ooooo`009Oooool01Ol@413ooooooooooooooooo410@01_ooooo0_l0002kooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0>?ooool002Gooooo00Go0000ooooooooooooooooo`00000H
ooooo`?o0000_Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Sooooo000Uoooo
o`05o`000?ooooooooooooooool000005_ooool3o`000;oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0gooooo`009Oooool01Ol@413ooooooooooooooooo410@01?ooooo0ol00003
ooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0f
ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol00033ooooo`Co0000:_ooool2
o`0003Sooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`000<7ooooo1Ol00002
og3Gn@03o`000?m`eoWo000002_ooooo00?o0000ooooooooool0=Oooool003Gooooo0ol000000ooo
oooo0000ooooo`2looooo`Co00001_m`eoT2o`0000;oL=Oi0_l0000Zooooo`03o`000?oooooooooo
03Cooooo000cooooo`;o0000_Oooool5o`0000OoL=Oi0ol000000om`eoWo0000og3Gn@03og3Gn@;o
0000:?ooool00ol0003oooooooooo`0dooooo`00<?ooool3o`000;_ooooo1?l00009og3Gn@?o0000
1Om`eoT00ol0003oL=Oiog3Gn@03og3Gn@03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
<oooool002oooooo0_l0002iooooo`Co00001?mXe_<2o`0000CoL=Oi0ol00009og3Gn@03o`000?m`
eoWoL=Oi00Go00009oooool00ol0003oooooooooo`0booooo`00;oooool3o`000;?ooooo1Ol0000:
ofSFl`Co00002Om`eoT6o`0000GoELc^0_l0000Uooooo`;o0000<oooool002oooooo00Co0000oooo
ool0003o0000[_ooool4o`0000goJ=Kc0ol000000omXe_?o0000o`000003og3Gn@Ko00001?mEc>h0
0ol0003oELc^oeG<kP06oeG<kP;o00008_ooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Fooooo`00;ooo
ool01Ol0003ooooooooooooooooo00000:Wooooo1?l0000>ofSFl`?o00000omXe_<6o`0000_oELc^
00?o0000oeG<k_mEc>h01omEc>h2o`0002?ooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B405_ooool002ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Rooooo`Co00001?mReNd3o`0000Wo
J=Kc2?l00006odW7h`Co00002?mEc>h00ol0003oELc^o`00000:o`00027ooooo00?o0000oooooooo
ool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000F
ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo1Ol0000;of;E
k@?o00000omXe_<5o`0000goBLOS3Ol0000;ocfni0?o00007oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Kooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Uoooool4o`00013oH]G]2?l00007
odW7h`Wo00001ol`]mH4o`000003ocfni?l0003o?KkT00go?KkT0_l0000Nooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
5_ooool002kooooo0_l00007ooooo`03o`000?oooooooooo09;ooooo1Ol0000=of;Ek@Wo00001?m1
a=P9o`0000co<;OF6ol0000Looooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Sooooo000^ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0SOooool4o`0000GoG]GW1?l00004of;Ek@Go00000om1a=P:o`0000Co9k;84Ol0
000:obB^eP;o00003ol`]><2o`0001Wooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV00Hooooo`00;_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo08Oooooo1Ol0000;oekEiaco00001olNZlTAo`0000?o9:kF00Co0000obB^e_l0003o0000
3ol`]><2o`0001[ooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@410Fooooo`00;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08;ooooo1?l0000;oekEi`Go00001?lm`/h<o`0000Co7jc13ol0000:ob^`h0?o00001?l][nHJ
o`0001Sooooo00?o0000ooooooooool0;?ooool002gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1mooooo`So00001_mNeNL5o`0000Co?L;>5Ol0000:oc2fg0?o00003ol[/>02o`00
00Oo;JoV00Co0000obf_i_l][nKo;JoV0ol0000>ocB`kP03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0:oooool002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1ioooo
o`?o00002?mOe^8Ho`0000Oo?/3M;?l00005obf_iP;o00003Old/>h2o`0001Oooooo00?o0000oooo
ooooool0:_ooool002gooooo0ol0000=ooooo`03o`000?oooooooooo07Cooooo1?l00008oeoFhPCo
00000olo`lP?o`0000Go?/3M1ol00006ofG:o0;o00003OmD_oX2o`0000koBKKh00?o0000odF`n?m5
/?P00om5/?P=o`0000[o=;3^00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`00
;Oooool00ol0003oooooooooo`0>ooooo`;o0000LOooool3o`0000SoGmKR1?l00002oco3b0co0000
0_mBc^43o`0000;oD/kQ1_l0000?ofG:o003o`000?mD_o[oE;oj00coE;oj00?o0000odVfn?m9]_P0
3?m9]_P2o`0000CoAK3h00?o0000odF`n?m5/?P01_m5/?P00ol0003oAjghodN]n009o`0000;o=;3^
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`002_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1[ooooo`?o
00001omOe^8Ao`0000CoD/kQ2?l00004og[FoP?o00003omUb_`2o`0000goE;oj0_l0000>odVfn003
o`000?m5/?SoAK3h00;oAK3h00?o0000odF`n?m5/?P01_m5/?P00ol0003oAjghodN]n008odN]n0Co
00005?ooool2o`0002_ooooo000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Voooooaco00001?mBc^46o`0000coN]Kn0ol00007ofG:
o1oo00001_m9]_P00ol0003oAK3hodF`n002odF`n003o`000?m5/?SoAK3h00KoAK3h00?o0000odN]
n?m7[OP02om7[OP00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo000:ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00006
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0H_ooool3o`0000OoHmWQ0ol00000
0om6alOo0000o`000008o`0000OoK=gW1Ol0000Bog[FoPWo00002?n1^oT00ol0003oL[?iog:cn@0;
og:cn@03o`000?mW[?SoIjch00KoIjch3?l00009odF`n003o`000?m7[OSoAjgh00_oAjgh00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Wooooo`002_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oMgMgoooooo`0000Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Nooooo`?o00001omSfN49o`000004odg;
aol0003o0000o`0000WoK=gW1?l00003oi7PoP?o00002_mje_h5o`0000?oT/?h00?o0000oh6knOn1
^oT03?n1^oT00ol0003oL[?iog:cn@0;og:cn@03o`000?mW[?SoIjch00coIjch00?o0000of2WmomP
YoL00_mPYoL8o`0000;oAK3h00?o0000odN]n?m7[OP02om7[OP00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02Oooooo000:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000?ooooo00CogMgMoeEEEOoooooo00001_ooool2o`0001Kooooo00?o0000
ooooooooool0F_ooool3o`0000OoHmWQ3Ol00008ofcMi`Go00002OnAh?h2o`0000?oN]Kn1Ol00009
oi;3n003o`000?n1^oWoPK_i00coPK_i00?o0000og:cnOmb/oT02omb/oT00ol0003oIjchofN/n00<
ofN/n003o`000?mPYoOoH:Og00;oH:Og00?o0000of2WmomPYoL01?mPYoL8o`0000WoAjgh00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`002_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000000Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1Fooooo`?o00001omSfN4@o`0000GoK=gW1Ol0
000<oi7PoPGo00003onB`oP00ol0003oPK_ioh6kn@0<oh6kn@03o`000?mb/oWoL[?i00_oL[?i00?o
0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2WmomPYoOo000000WoH:Og00?o0000oefTm_mMY?H0
0_mMY?H8o`0000;oAjgh00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Uooooo`002_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1AoooooaOo
00001on7j^d7o`0000coTN3n0ol00004oj;9m003o`000?nB`oSoT/?h00koT/?h00?o0000oh6knOn1
^oT03?n1^oT00ol0003oL[?iog:cn@0;og:cn@03o`000?mW[?SoIjch00coIjch00Go0000of2WmomP
YoOoH:Ogo`000009of2Wm`03o`000?mMY?KoGJCf00WoGJCf1?l0000Booooo`;o00009oooool000[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool3
o`0000SoK=gR3?l00009ohOZk@Go000000CoYNKko`000?l0003o00001onAh?h4o`0000SoX/Wd00?o
0000oi;3n?nB`oP03_nB`oP00ol0003oPK_ioh6kn@0<oh6kn@03o`000?mb/oWoL[?i00_oL[?i00?o
0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2WmomPYoOo000000WoH:Og00?o0000oefTm_mMY?H0
2omMY?H00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo000/ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0BOooool3o`0000SoK=gR2_l000000omWfm;o0000o`00
0008ohOZk@Go00001onUi_/2o`0000;oTN3n0ol0000=oj;9m003o`000?nB`oSoT/?h00koT/?h00?o
0000oh6knOn1^oT01On1^oT@o`0000GoL[?i00?o0000ofN/n?mW[?P03?mW[?P01Ol0003oH:Ogof2W
momPYoOo000000WoH:Og00?o0000oefTm_mMY?H02omMY?H00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOoo
ool3o`0000SoK=gR1ol000001?mKdlOo0000o`000?mWfm83o`0000OoQn[]1_l0000:ojGVn`?o0000
4OnRbO@00ol0003oT/?hoi;3n00<oi;3n0Wo00001on=Y^H00ol0003oPZ7Woh:Qi`06oh:Qi`oo0000
1_mW[?P01?l0003oH:Ogof2Wmol00009of2Wm`03o`000?mMY?KoGJCf00coGJCf00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Sooooo`00:oooool3o`0001cooooo00?o0000ooooooooool0
@Oooool3o`0000SoK=gR1_l00002oe_Ca`?o000000?oIm_Bo`000?l000001on7j^d6o`0000_oYNKk
0_l00003ojo=k`03o`000?nRbOCoX/Wd00ooX/Wd00?o0000oi;3n?nB`oP01_nB`oP5o`0000;oV:_S
00?o0000ohfVi_n=Y^H03?n=Y^H00ol0003oPZ7Woh:Qi`0;oh:Qi`03o`000?miWNSoNIgX00KoNIgX
3?l00008of2Wm`03o`000?mMY?KoGJCf00coGJCf00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Rooooo`00:oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03gooooo3_l0
00000omSfM7o0000o`000003oe_Ca`;o000000?oIm_Bo`000?l000003Ol0000<ojGVn`;o00001_n_
cNl00ol0003oX/Wdoj;9m00?oj;9m003o`000?nB`oSoT/?h00Go00002?nHZn<00ol0003oSJKVohfV
iP0<ohfViP03o`000?n2XNOoPZ7W00_oPZ7W00?o0000ogVMj?miWNP03?miWNP01?l0003oLY[Yog:J
jOmbV^T8o`0000;oH:Og00?o0000oefTm_mMY?H03?mMY?H00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo027ooooo000[ooooo`03o`000?oooooooooo01kooooo0_l0000jooooo`?o00001omg
hnD3o`0000;oHmWA0ol00002oe_Ca`Oo00001onOl_04o`000003okGXmol0003o000000WoYNKk0ol0
0009ojo=k`03o`000?nRbOCoX/Wd00goX/Wd1?l0000>oiR[h`03o`000?n=Y^KoSJKV00_oSJKV00?o
0000oh:Qion2XNL03?n2XNL00ol0003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl00000
1_mbV^T8o`0000[oGJCf00?o0000ooooooooool03oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo000[ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0=Oooool2o`0000OoMn?U0ol00003of?Id@;o
00000_mKdlL4o`0000;oPnWM0_l00007oiobl0?o00001_nej?L2o`0000GoYNKk0_l0000=ojo=k`03
o`000?nRbOCoX/Wd00WoX/Wd0ol00002oj>_h003o`000?nHZn?oV:_S00goV:_S00?o0000ohfVi_n=
Y^H03?n=Y^H00ol0003oPZ7Woh:Qi`0;oh:Qi`03o`000?miWNSoNIgX00goNIgX00Co0000og:JjOmb
V^Wo00002OmbV^T00ol0003oKYWZofjIjP02ofjIjPWo00000_mMY?H00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo000[ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0<Oooool3o`0000KoMn?U0ol00003of?Id@So00000on3jMd2o`0000KoWo;`0ol0000;
okGXm`;o000000?oYNKko`000?l000004?n_cNl00ol0003oX/Wdoj;9m004oj;9m0Co00001_nS[n00
0ol0003oV:_SoiR[h`0=oiR[h`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh:Qion2XNL02on2XNL0
0ol0003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjI
jP0:ofjIjPCo00004_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo000[ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0;_ooool2o`0000KoMn?U2ol000000omch]?o0000o`000004oh?Yg@;o0000
1_nOl_03o`0000ko]NSg0ol0000Bojo=k`03o`000?nRbOCoX/Wd00?o00002onS[n000ol0003oV:_S
oiR[h`0=oiR[h`03o`000?n=Y^KoSJKV00_oSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0003oNIgX
ogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0<ofjIjP03
o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`00:_ooool3o`0002Cooooo00?o0000oooo
ooooool0:_ooool3o`000003ogOSiOl0003o000000So000000CoM^?Jo`000?l0003o00000omch]<2
o`0000CoPnWM0_l00005oiobl0Co00003Onej?L3o`0000?o^/oZ00?o0000ojo=kon_cNl03on_cNl3
o`0000koXjoP00?o0000oiR[honHZn<03OnHZn<00ol0003oSJKVohfViP0<ohfViP03o`000?n2XNOo
PZ7W00coPZ7W00?o0000ogVMj?miWNP02omiWNP01Ol0003oLY[Yog:JjOmbV^Wo000000WoLY[Y00?o
0000ofjIj_m^VNX03Om^VNX00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool002[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Wooooo`Ko00000_n3jNX2o`0000GoM^?J
0_l00003og?Rd`?o00001?n3jMd2o`0000CoWo;`1Ol0000=okGXm`;o00001onjcnX00ol0003o[lg_
ojo=k`0;ojo=k`?o000000?o[K?Mo`000?nS[n003onS[n000ol0003oV:_SoiR[h`0=oiR[h`03o`00
0?n=Y^KoSJKV00_oSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0003oNIgXogVMj00<ogVMj005o`00
0?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0=ofjIjP03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02?ooooo0ol00006oh?YjP;o00001OmfhmX2o`0000?oLn;C0_l00002oh?Yg@oo00003?nej?L2o`00
00[o^/oZ00?o0000ojo=kon_cNl01on_cNl3o`0000Go[K?M00?o0000oj>_h?nS[n003_nS[n000ol0
003oV:_SoiR[h`0<oiR[h`03o`000?n=Y^KoSJKV00coSJKV00?o0000oh:Qion2XNL03?n2XNL00ol0
003oNIgXogVMj00<ogVMj005o`000?mbV^WoLY[Yog:JjOl000002OmbV^T00ol0003oKYWZofjIjP0<
ofjIjP03o`000?oooooooooo00kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo000Zooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool08?ooool2o`0000KoPnWZ0ol00004ogKSfP?o00000_mch]<7o`000003oi_ci_l0
003o000000;o/_Ka0ol00003ok;fl@04o`000?o1io7o`NOaol7Wl@?o00001_nej?L3o`0000go^/oZ
00?o0000ojo=kon_cNl00on_cNl3o`0000Wo[K?M00?o0000oj>_h?nS[n003_nS[n000ol0003oV:_S
oiR[h`0<oiR[h`03o`000?n=Y^KoSJKV00GoSJKV7ol00005ogVMj003o`000?mbV^WoLY[Y00;oLY[Y
00?o0000og:JjOmbV^T01ombV^T00ol0003oKYWZofjIjP0<ofjIjP03o`000?oooooooooo013ooooo
00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo000Zooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07?ooool3
o`0000KoPnWZ0_l00005ogKSfPSo00001_nKlnH00ol0003o/_Kao`000002o`0000Co/_Ka0_l00007
ol7Wl@?o000000?o]NSgo`000?l000004OnjcnX00ol0003o[lg_o`000002o`0000co[K?M00?o0000
oj>_h?nS[n003_nS[n000ol0003oV:_SoiR[h`0:oiR[h`[o00001onAUmD00ol0003oRICHohVDf00<
ohVDf003o`000?n3T][oPi;J00KoPi;J2ol00009og:Jj@03o`000?m^VN[oKYWZ00coKYWZ00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`00:_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Wooooo0_l00007oh?YjP;o00000omfhmX6o`0000;oRngO0_l00006oi_c
iPCo00001_nbm_400ol0003o`NOaol7Wl@09ol7Wl@?o00004_njcnX2o`00013o[K?M00?o0000oj>_
h?nS[n003_nS[n000ol0003oV:_SoiR[h`02oiR[h`Oo00000onJV]<00ol0003oTIOEoi6Ge@0<oi6G
e@03o`000?n9U=SoRICH00coRICH00?o0000oh>Bf_n3T]X02on3T]X00ol0003oOI3Logf@g002ogf@
g0So00000_mbV^T00ol0003oKYWZofjIjP0<ofjIjP03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06oooool002Wooooo0ol0000[ooooo`03o`000?oooooooooo01Gooooo0ol00007oh?YjPWo
00001?n;kMl2o`0000KoVo?V1?l00006ok;fl@;o00002oo1io401Ol0003o`/oTol;?i?o2cnCo0000
00oo^/oZ0_l000000onf]]Wo0000ojfcg@0@ojfcg@03o`000?nS[n3oXjoP00coXjoP1_l0000;oiZJ
d`03o`000?nAUmGoTIOE00_oTIOE00?o0000ohVDf?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0<oh>B
fP03o`000?mmT=coOI3L00;oOI3L00?o0000ogf@g?mmT=`01?mmT=`8o`0000[oKYWZ00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01;ooooo3_l00003ohW/i0;o00001On;kMl00ol0003oVo?Voi_ciP04oi_ciP?o
00001onbm_42o`0000_o`NOa0_l00005ol;?i003o`000?njcn[o^/oZ00[o^/oZ0_l00004okJff@03
o`000?n]/mgo[K?M00oo[K?M00?o0000oj>_h?nS[n002?nS[n03o`0000;oXYkA00?o0000oiZJdonJ
V]<03?nJV]<00ol0003oTIOEoi6Ge@0<oi6Ge@03o`000?n9U=SoRICH00coRICH00?o0000oh>Bf_n3
T]X02on3T]X00ol0003oOI3Logf@g003ogf@g003o`000?mmT=coOI3L00KoOI3L00?o0000ogZAg_mj
TMh00_mjTMh8o`0000;oKYWZ00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`?o00002?n@kNl2o`0000GoRNcT0_l00005oh_]g`;o00001?nKlnH3
o`0000Wo/_Ka00?o0000ol7WlOo1io402_o1io400ol0003o`/oTol;?i006ol;?i003o`000?njcn[o
^/oZ00Oo^/oZ0_l00007okJff@03o`000?n]/mgo[K?M00ko[K?M00?o0000oj>_h?nS[n001?nS[n04
o`0000KoXYkA00?o0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0;oi6Ge@03o`000?n9U=So
RICH00coRICH00?o0000oh>Bf_n3T]X03?n3T]X00ol0003oOI3Logf@g002ogf@g003o`000?mmT=co
OI3L00OoOI3L00?o0000ogZAg_mjTMh02OmjTMh4o`00017ooooo0_l0000Kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0:ooooo`?o00002On@kNl2o`0000KoRNcT00?o0000oh_]gon;kMl00on;kMl2o`0000?oVo?V
1Ol00008ok;fl@;o00002oo1io42o`0000[o`/oT00?o0000ok[?j_njcnX01OnjcnX00ol0003o][KI
okJff@08okJff@03o`000?n]/mgo[K?M00ko[K?M00?o0000oj>_h?nS[n000ol0000:oj:Nd@03o`00
0?nJV]?oVY[C00coVY[C00?o0000oi6GeOnAUmD03?nAUmD00ol0003oRICHohVDf00<ohVDf003o`00
0?n3T][oPi;J00_oPi;J00?o0000ogf@g?mmT=`00ommT=`00ol0003oOI3Logf@g006ogf@g003o`00
0?mjTMkoNY7N00coNY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0_ooooo`;o00002?ooool2o`00
00[oT>g_0_l00006ohW/i0;o00001?n;kMl2o`0000;oVo?V2ol00004ok;fl@03o`000?o1io7o`NOa
00[o`NOa00?o0000ol;?i?o2cn@02oo2cn@00ol0003o^/oZok[?jP02ok[?jP;o00003?nf]]T00ol0
003o[K?Mojfcg@0=ojfcg@?o00003_nRW]400ol0003oVY[CoiZJd`0<oiZJd`03o`000?nAUmGoTIOE
00_oTIOE00?o0000ohVDf?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0<oh>BfP03o`000?mmT=coOI3L
00?oOI3L00?o0000ogf@g?mmT=`01_mmT=`00ol0003oNY7NogZAgP0<ogZAgP03o`000?oooooooooo
017ooooo00?o0000ooooooooool05oooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`?o00002_n@kNl2o`0000KoRNcT0_l0
0003oh_]g`Oo00000on^n>`00ol0003o`?C`ol3dl005ol3dl0Ko00002_o1io400ol0003o`/oTol;?
i00=ol;?i004o`000?njcn[o0000o`0000ko][KI00?o0000ojfcgOn]/md02_n]/md3o`000003ojVR
col0003oXYkA00koXYkA00?o0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0<oi6Ge@03o`00
0?n9U=SoRICH00coRICH00?o0000oh>Bf_n3T]X02on3T]X00ol0003oOI3Logf@g004ogf@g003o`00
0?mmT=coOI3L00GoOI3L00?o0000ogZAg_mjTMh03?mjTMh00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`;o0000<oooool4o`00
00_oT>g_0_l00006ohW/i0So000000?o[_S/o`000?l000001?n^n>`2o`0000Wo`?C`00?o0000olSU
k?o8iN`00_o8iN`3o`0000Go`NOa0_l0000@ol;?i0;o00004Onf]]T00ol0003o[K?Mojfcg@06ojfc
g@?o00001OnYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?oVY[C00coVY[C00?o0000oi6G
eOnAUmD02onAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][oPi;J00coPi;J00?o0000ogf@
g?mmT=`00ommT=`00ol0003oOI3Logf@g006ogf@g003o`000?mjTMkoNY7N00coNY7N00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Fooooo`001oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7QhOooooo00Kooooo0_l0000c
ooooo`So00001_n@kNl2o`0000;oRNcT2?l00003oiodj0Co00001On^n>`00ol0003o`?C`ol3dl007
ol3dl0;o00002?o8iN`3o`000003ol7WlOl0003o`/oT013o`/oT00?o0000okbie_l000004_nf]]T0
0ol0003o[K?Mojfcg@03ojfcg@;o00002?nYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?o
VY[C00coVY[C00?o0000oi6GeOnAUmD03?nAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][o
Pi;J00_oPi;J00?o0000ogf@g?mmT=`01?mmT=`00ol0003oOI3Logf@g006ogf@g003o`000?mjTMko
NY7N00_oNY7N00?o0000ooooooooool04Oooool2o`0001Oooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P01_oo
ool00ol0003oooooooooo`0`ooooo`;o00002?nLl?@:o`0000;oV_;/0_l00005oiodj0?o00001_n^
n>`2o`0000Wo`?C`00?o0000olSUk?o8iN`02_o8iN`3o`0000oo`/oT0_l00003okbieP03o`000?nf
]]Wo][KI013o][KI00?o0000ojfcgOl000000_l0000;ojVRc`03o`000?nRW]7oXYkA00goXYkA00?o
0000oiZJdonJV]<03?nJV]<00ol0003oTIOEoi6Ge@0;oi6Ge@03o`000?n9U=SoRICH00coRICH00?o
0000oh>Bf_n3T]X03?n3T]X00ol0003oOI3Logf@g004ogf@g003o`000?mmT=coOI3L00GoOI3L00?o
0000ogZAg_mjTMh03?mjTMh00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Oooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`0^ooooo`;o00003?nLl?@2o`0000Ko
V_;/0_l00004oiodj0?o00001on^n>`2o`0000Wo`?C`0_l0000<olSUk005o`000?o7c^3oalkPolO>
h?l000003?o2cn@2o`0000Ko_;WF00?o0000okJffOnf]]T03onf]]T2o`0000ooZJ;?00?o0000oj:N
dOnRW]403?nRW]400ol0003oVY[CoiZJd`0<oiZJd`03o`000?nAUmGoTIOE00coTIOE00?o0000ohVD
f?n9U=P03?n9U=P00ol0003oPi;Joh>BfP0;oh>BfP03o`000?mmT=coOI3L00CoOI3L00?o0000ogf@
g?mmT=`01_mmT=`00ol0003oNY7NogZAgP0<ogZAgP03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05?ooool002Sooooo00?o0000ooooooooool0;?ooool2o`0000coW?3d0_l00006oi[bk0;o
00000onOm>P4o`0000So[_S/00?o0000ol3dl?o0m?001oo0m?02o`0000cob>G/0_l00005olO>h003
o`000?o2cnCo`/oT00So`/oT00?o0000okbie_nl^MH01onl^MH00ol0003o][KIokJff@0<okJff@;o
000000?o/:G=o`000?nYX/l03_nYX/l00ol0003oXYkAoj:Nd@0=oj:Nd@03o`000?nJV]?oVY[C00co
VY[C00?o0000oi6GeOnAUmD02onAUmD00ol0003oRICHohVDf00<ohVDf003o`000?n3T][oPi;J00co
Pi;J00?o0000ogf@g?mmT=`01?mmT=`00ol0003oOI3Logf@g005ogf@g003o`000?mjTMkoNY7N00co
NY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`00:?ooool00ol0003ooooo
ooooo`0Zooooo`;o00002onLl?@3o`0000KoV_;/0_l00002oiodj0?o000000?oWoCXo`000?n^n>`0
1on^n>`2o`0000Wo`?C`00?o0000olSUk?o8iN`02oo8iN`00ol0003oalkPolO>h006olO>h0;o0000
1_o2cn@2o`0000_o_;WF00?o0000okJffOnf]]T02Onf]]T2o`0000Co/:G=00?o0000ojVRconYX/l0
3OnYX/l00ol0003oXYkAoj:Nd@0<oj:Nd@03o`000?nJV]?oVY[C00coVY[C00?o0000oi6GeOnAUmD0
1OnAUmDOo`0000GoPi;J00?o0000ogf@g?mmT=`01OmmT=`00ol0003oOI3Logf@g005ogf@g003o`00
0?mjTMkoNY7N00coNY7N00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00:?oo
ool2o`0002Wooooo0_l0000;oic`m0;o00001onJl^`2o`0000;oWoCX0_l00002oiodj0;o00002?n^
n>`00ol0003o`?C`ol3dl007ol3dl0;o00003?o8iN`2o`0000_oalkP00Co0000ol;?i?o2cnCo`/oT
0_l0000=okbieP03o`000?nf]]Wo][KI00Oo][KI0_l00006ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?
00?o0000oj:NdOnRW]403OnRW]400ol0003oVY[CoiZJd`09oiZJd`[o00001onDSl/00ol0003oSXg=
ohj=c@0<ohj=c@03o`000?n9S=3oRHc@00KoRHc@3ol00006ogf@g003o`000?mjTMkoNY7N00coNY7N
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`009oooool2o`0002Sooooo0_l0
000;oic`m0;o00001onJl^`2o`000003oiodj?l0003o000001Co00001?o0m?000ol0003ob>G/olSU
k00:olSUk0;o00003_o7c^000ol0003o`/oTo`00000@okbieP03o`000?nf]]Wo][KI00Go][KI00?o
0000ok2UcOn`YLd01on`YLd00ol0003oZJ;?ojVRc`0=ojVRc`03o`000?nRW]7oXYkA00coXYkA00?o
0000oiZJdonJV]<00_nJV]<7o`0000?oVY7900?o0000oiB?bonDSl/03?nDSl/00ol0003oSXg=ohj=
c@0<ohj=c@03o`000?n9S=3oRHc@00_oRHc@00?o0000ohF<d_n5S=801On5S=8=o`0000[oNY7N00?o
0000ooooooooool04?ooool2o`0000Wooooo1?l000000ol@413oooooooooo`04ooooo`00:?ooool0
0ol0003oooooooooo`0Tooooo`So00001OnLl?@2o`0000?oV_;/2_l00003ojogkP03o`000?nkn>ko
^oS^00Oo^oS^00?o0000olSak_o8lNh01Oo8lNh6o`0000[ob>G/00?o0000olO>h?o7c^003_o7c^02
o`0001;o_;WF00?o0000okJffOnf]]T00_nf]]T2o`0000[o/:G=00?o0000ojVRconYX/l03OnYX/l0
0ol0003oXYkAoj:Nd@0;oj:Nd@Ko00002onJTLT00ol0003oU8o;oiB?b`0;oiB?b`03o`000?n>SLgo
SXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=000ol0003oQHcBohF<dP05ohF<dP03o`000?n5S=;o
QHcB00CoQHcB00?o0000oh:=eOn2SMD00_n2SMD8o`0000;oNY7N00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo
02?ooooo0_l00008ojK`m`[o00000_nWm?44o`0000Go[oO^0_l00008ok_hkP;o00002Oo8lNh00ol0
003ocN7WolgQi`02olgQi`?o00001Oo8iN`2o`00013oalkP00?o0000ol6je?l000004onl^MH01?l0
003o][KIo`000?l0000=ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?00?o0000oj:NdOnRW]401onRW]43
o`0000;oXIC800?o0000oiZAbOnJTLT03?nJTLT00ol0003oU8o;oiB?b`0<oiB?b`03o`000?n>SLgo
SXg=00coSXg=00?o0000ohV<d?n9S=002on9S=000ol0003oQHcBohF<dP06ohF<dP03o`000?n5S=;o
QHcB00CoQHcB00?o0000oh:=eOn2SMD02On2SMD4o`0001Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Qooooo`;o00002onVl?L2o`00
00OoYoCa0ol00007ojogkP03o`000?nkn>ko^oS^00Oo^oS^00?o0000olSak_o8lNh02?o8lNh00ol0
003ocN7WolgQi`06olgQi`?o000000?ob>G/o`000?o7c^003oo7c^02o`0000?o`K[D00?o0000okbi
e_nl^MH04?nl^MH2o`0000oo/:G=00?o0000ojVRconYX/l03_nYX/l00ol0003oXYkAoj:Nd@03oj:N
d@?o00001_nQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=
cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5S=;oQHcB00KoQHcB00?o0000ohF<
d_n5S=800on5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`009oooool00ol0003oooooooooo`0Nooooo`?o
00002onVl?L2o`0000KoYoCa1?l00007ojogkP;o00002?nkn>h2o`0000Wob?7^0_l0000;olgQi`?o
00003oo7c^000ol0003o`K[Dol6je004ol6je003o`000?nl^MKo_;WF00go_;WF0_l000000onfZLco
0000ok2Uc@0?ok2Uc@03o`000?nYX/ooZJ;?00goZJ;?00?o0000oj:NdOnRW]400ol00009oj6Db003
o`000?nJTLWoVY7900coVY7900?o0000oiB?bonDSl/02onDSl/00ol0003oSXg=ohj=c@0<ohj=c@03
o`000?n9S=3oRHc@00coRHc@00?o0000ohF<d_n5S=801_n5S=800ol0003oQHcBohF<dP04ohF<dP03
o`000?n2SMGoPXgE00coPXgE00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo01cooooo0_l0000<ojK`m`;o0000
1OnWm?45o`0000Oo[oO^0_l00008ok_hkP;o00002_o8lNh00ol0003ocN7WolgQi`0:olgQi`05o`00
0?o:c]cob/kLol[>g?l000003Oo7c^000ol0003o`K[Dol6je005ol6je003o`000?nl^MKo_;WF00co
_;WF00?o0000okJYc?nfZL`00_nfZL`00ol0003o/:G=ok2Uc@0=ok2Uc@03o`000?nYX/ooZJ;?00go
ZJ;?0ol0000<oj6Db003o`000?nJTLWoVY7900coVY7900?o0000oiB?bonDSl/03?nDSl/00ol0003o
SXg=ohj=c@0<ohj=c@03o`000?n9S=3oRHc@00coRHc@00?o0000ohF<d_n5S=801_n5S=800ol0003o
QHcBohF<dP03ohF<dP03o`000?n2SMGoPXgE00coPXgE00?o0000ooooooooool04Oooool3o`0000Oo
oooo00?o0000ooooooooool01_ooool002Kooooo0ol0000Kooooo`;o00003OnVl?L00ol0003oYoCa
ojOdl@03ojOdl@;o00000_nWm?400ol0003o[oO^ojogkP06ojogkP03o`000?nkn>ko^oS^00Oo^oS^
00?o0000olSak_o8lNh02Oo8lNh00ol0003ocN7WolgQi`0:olgQi`03o`000?o:c]cob/kL00?ob/kL
00?o0000olO>h?o7c^002?o7c^02o`0000Wo`K[D00?o0000okbie_nl^MH02Onl^MH2o`0000Go]ZW<
00?o0000ok2UcOn`YLd03_n`YLd00ol0003oZJ;?ojVRc`09ojVRc`?o000000?oYYS6o`000?nQU<P0
3OnQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd0
3?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5S=;oQHcB00OoQHcB00?o0000ohF<d_n5S=80
0on5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oooooooooo00gooooo1?l000000ooooooo0000
ooooo`06ooooo`03o`000?oooooooooo00Kooooo000Wooooo`03o`000?oooooooooo01Sooooo0_l0
000=ojK`m`;o00000onWm?43o`0000;oYoCa0_l00007ojogkP;o00002?nkn>h2o`0000_ob?7^00?o
0000olgQioo=hNL02Oo=hNL2o`0000Oob/kL00?o0000olO>h?o7c^001_o7c^000ol0003o`K[Dol6j
e00:ol6je003o`000?nl^MKo_;WF00Ko_;WF0_l00008okJYc003o`000?n`YLgo/:G=00go/:G=00?o
0000ojVRconYX/l01_nYX/l3o`0000GoYYS600?o0000oj6Db?nQU<P02onQU<P00ol0003oVY79oiZA
b@0<oiZAb@03o`000?nDSl_oU8o;00coU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<
d00<ohV<d003o`000?n5S=;oQHcB00KoQHcB00?o0000ohF<d_n5S=800on5S=800ol0003oPXgEoh:=
e@0<oh:=e@03o`000?oooooooooo00[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o
EEEEofIVI_l000002?ooool002Oooooo00?o0000ooooooooool05_ooool5o`0000[oY_3g0_l00002
ojOdl@?o00000onWm?42o`0000So[oO^00?o0000ok_hk_nkn>h01onkn>h00ol0003ob?7^olSakP09
olSakP;o00002oo=hNL00ol0003ob/kLol[>g008ol[>g003o`000?o7c^3oalkP00?oalkP0_l0000>
ol6je003o`000?nl^MKo_;WF00?o_;WF0_l0000:okJYc003o`000?n`YLgo/:G=00ko/:G=00?o0000
ojVRconYX/l00_nYX/l3o`0000SoYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZAb@0<
oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<
ohV<d003o`000?n5S=;oQHcB00OoQHcB00?o0000ohF<d_n5S=800on5S=800ol0003oPXgEoh:=e@0<
oh:=e@03o`000?oooooooooo00Gooooo1?l00008ooooo`03o`000?oooooooooo00kooooo000Voooo
o`03o`000?oooooooooo01Gooooo0_l00005ojg^n0Go00000onVl?L2o`000004ojOdlOl0003o0000
o`0000GoYoCa00?o0000ojogk_n_mnh00_n_mnhCo`0000Sob?7^00?o0000olgQioo=hNL02_o=hNL0
0ol0003ob/kLol[>g00:ol[>g005o`000?o7c^3oalkPolO>h?l000004?o1^]@00ol0003o_;WFokbi
eP02okbieP03o`000?nfZLco]ZW<00_o]ZW<00?o0000ok2UcOn`YLd03On`YLd00ol0003oZJ;?o`00
0002o`0000coYYS600?o0000oj6Db?nQU<P02onQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nD
Sl_oU8o;00coU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00;ohV<d003o`000?n5
S=;oQHcB00SoQHcB00?o0000ohF<d_n5S=800_n5S=800ol0003oPXgEoh:=e@0<oh:=e@03o`000?oo
oooooooo00;ooooo0ol0000<ooooo`03o`000?oooooooooo00kooooo000Vooooo`03o`000?oooooo
oooo01?ooooo0_l0000<ojg^n1?o00000onimO400ol0003o`oC_ol?dk`07ol?dk`03o`000?o<k>_o
c>c[00?oc>c[1Ol00002olSakP03o`000?o=hNOocN7W00[ocN7W00?o0000ol[>g?o:c]`03?o:c]`0
0ol0003oalkPo`00000Bol6je004o`000?nl^MKo0000o`0000oo]ZW<00?o0000ok2UcOn`YLd03?n`
YLd2o`0000ooYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nD
Sl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<d00<ohV<d003o`000?n5
S=;oQHcB00SoQHcB00Go0000ohF<d_n5S=;oQHcBo`00000?oh:=e@Co00004?ooool00ol0003ooooo
ooooo`0=ooooo`009_ooool00ol0003oooooooooo`0Aooooo`;o00003On]k_P4o`0000Oo/O?d0_l0
0008okWel@;o00002?o3m>l2o`0000_oc>c[1?l00009olgQi`;o00003oo:c]`2o`0001?o`K[D0_l0
000AokJYc003o`000?n`YLgo/:G=00[o/:G=0_l000000on/VlGo0000ojJHaP0>ojJHaP03o`000?nQ
U<SoXIC800coXIC800?o0000oiZAbOnJTLT03?nJTLT00ol0003oU8o;oiB?b`0;oiB?b`03o`000?n>
SLgoSXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=000ol0003oQHcBohF<dP08ohF<dP03o`000?n5
S=;oQHcB00;oQHcB00?o0000oh:=eOn2SMD03?n2SMD00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00gooooo000Uooooo`?o00004Oooool00ol0003o[Nkhojg^n00;ojg^n0?o00002Onalo@0
0ol0003o^OGaokWel@07okWel@03o`000?o3m>oo`oC_00Oo`oC_00?o0000olc/joo<k>/02_o<k>/0
0ol0003ocmgSoloMh`02oloMh`?o00001Oo=hNL00ol0003ob/kLol[>g00>ol[>g003o`000?o4_=;o
000001;o`K[D00?o0000ok^/bol000004_nfZL`00ol0003o/:G=ok2Uc@07ok2Uc@;o00001?n/VlD0
0ol0003oYYS6ojJHaP0=ojJHaP03o`000?nQU<SoXIC800_oXIC800?o0000oiZAbOnJTLT03?nJTLT0
0ol0003oU8o;oiB?b`0<oiB?b`03o`000?n>SLgoSXg=00coSXg=00?o0000ohV<d?n9S=003?n9S=00
0ol0003oQHcBohF<dP08ohF<dP05o`000?n5S=;oQHcBohF<d_l000003on2SMD00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00gooooo000Vooooo`03o`000?oooooooooo00kooooo0_l0000<
ojg^n0?o00002Onalo@2o`0000Wo^OGa00?o0000ol?dkoo3m>l01oo3m>l00ol0003oc>c[olc/j`09
olc/j`;o00002?o?gN<3o`000003olgQiol0003ob/kL00oob/kL00Go0000olBld_o4_=;oa;cBo`00
000?ol6je0;o00000onk[</00ol0003o]ZW<okJYc00?okJYc003o`000?n`YLgo/:G=00Co/:G=0ol0
0006ojbKa@03o`000?nVV<KoYYS600goYYS600?o0000oj6Db?nQU<P03?nQU<P00ol0003oVY79oiZA
b@0<oiZAb@03o`000?nDSl_oU8o;00_oU8o;00?o0000ohj=cOn>SLd03?n>SLd00ol0003oRHc@ohV<
d00<ohV<d003o`000?n5S=;oQHcB00WoQHcB00Go0000ohF<d_n5S=;oQHcBo`00000>oh:=e@03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03Oooool000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo00cooooo0_l0000;ojg^n0?o00002_nalo@2o`00
00Wo^OGa0_l00008ol?dk`;o00002oo<k>/00ol0003ocmgSoloMh`0:oloMh`?o00003_o:c]`2o`00
00Goa;cB00?o0000ol6je?o1^]@02oo1^]@00ol0003o^jc;ok^/b`04ok^/b`03o`000?nfZLco]ZW<
00oo]ZW<00Co0000ok2UcOn`YLgo/:G=0_l0000:ojbKa@03o`000?nVV<KoYYS600goYYS600?o0000
oj6Db?nQU<P02onQU<P00ol0003oVY79oiZAb@0<oiZAb@03o`000?nDSl_oU8o;00GoU8o;;_l00003
ohF<dP04o`000?n5S=;oQHcBo`0000ooPXgE00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool02_ooool2o`0000[o[Nkh1?l0000:ok7cm0;o00002_nimO400ol0003o`oC_ol?dk`07ol?dk`03
o`000?o<k>_oc>c[00[oc>c[00?o0000oloMhoo?gN<02_o?gN<01Ol0003oc<cJolc<f_o<c=[o0000
00cob/kL00?o0000olBld_o4_=801_o4_=800ol0003o`K[Dol6je008ol6je0;o00001onk[</00ol0
003o]ZW<okJYc00?okJYc004o`000?n`YLgo0000o`0000co[9_500?o0000ojJHa_nVV<H03OnVV<H0
0ol0003oXIC8oj6Db00<oj6Db003o`000?nJTLWoVY7900[oVY792Ol00007oiJ;aP03o`000?nAR/So
TH[800coTH[800?o0000ohj:bon>R//03?n>R//00ol0003oRX[=ohZ:c@06ohZ:cA3o00001_n2SMD0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo00Wooooo2?l00003ojg^n0Go00002onalo@00ol0003o^OGa
okWel@08okWel@;o00002?o3m>l2o`0000_oc>c[0_l0000<oloMh`03o`000?o<c=[oc<cJ00?oc<cJ
00?o0000ol[>g?o:c]`02?o:c]`00ol0003oa;cBolBldP08olBldP03o`000?o1^]Co`K[D00Ko`K[D
00?o0000ok^/bonk[</02?nk[</00ol0003o]ZW<okJYc00>okJYc0;o00003_n/VlD00ol0003oYYS6
ojJHaP0>ojJHaP03o`000?nQU<SoXIC800_oXIC800?o0000oiZAbOnJTLT01OnJTLT5o`0000;oVhg4
00?o0000oiJ;a_nFRlH03?nFRlH00ol0003oTH[8oi6:b00<oi6:b003o`000?n>R/_oSX[;00coSX[;
00?o0000ohZ:cOn:R/d02On:R/d01?l0003oRX[=ohZ:cOl00008ohR<d0So00004?ooool00ol0003o
ooooooooo`0=ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`07
ooooo`;o00002?naj_P<o`0000Go/O?d0_l0000:okWel@03o`000?o3m>oo`oC_00Oo`oC_00?o0000
olc/joo<k>/02_o<k>/00ol0003ocmgSoloMh`0;oloMh`03o`000?o<c=[oc<cJ00Goc<cJ00?o0000
ol[>g?o:c]`01_o:c]`00ol0003oa;cBolBldP0:olBldP03o`000?o1^]Co`K[D00Co`K[D00?o0000
ok^/bonk[</02Onk[</00ol0003o]ZW<okJYc00=okJYc003o`000?naWlGo000000oo[9_500?o0000
ojJHa_nVV<H03OnVV<H00ol0003oXIC8oj6Db00;oj6Db003o`000?nJTLWoVY7900Go00002?nKSL@0
0ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800coTH[800?o0000ohj:bon>R//03?n>R//0
0ol0003oRX[=ohZ:c@0:ohZ:c@04o`000?n:R/goRX[=o`0000koR8c@00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0<ooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003o
ooooooooo`05ooooo`;o00001onaj_P3o`0000;o/N[h0_l00008okO_m@_o00001OnimO400ol0003o
`oC_ol?dk`07ol?dk`03o`000?o<k>_oc>c[00Woc>c[0_l0000<oloMh`;o00002Oo<c=X00ol0003o
b/kLol[>g003ol[>g0;o00003_o4_=801?l0003o`K[Dol6je?o1^]@2o`0000go^jc;00?o0000okJY
c?nfZL`02_nfZL`2o`0000?o/Io500?o0000ojbKaOn/VlD03?n/VlD00ol0003oYYS6ojJHaP0=ojJH
aP03o`000?nQU<SoXIC800[oXIC81?l0000=oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:
b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00_oRX[=00?o0000ohZ:
cOl000003on8S=000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo0003ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
okZj^_oooooo^[Zjoa0@4004ooooo`?o00001?ooool2o`0000Oo/N[h0_l00004ok7Zn003o`000?ng
koGo]noe00[o]noe00?o0000okoal_nolO801_nolO8Bo`0000Soc>c[00?o0000oloMhoo?gN<02oo?
gN<00ol0003oc<cJolc<fP0:olc<fP05o`000?o:c]cob/kLol[>g?l000004Oo4_=800ol0003o`K[D
o`00000@ok^/b`03o`000?nfZLco]ZW<00Oo]ZW<0_l00005ok6Oa@03o`000?n/VlGo[9_500go[9_5
00?o0000ojJHa_nVV<H03OnVV<H00ol0003oXIC8oj6Db004oj6Db0Go00000_nPT<<00ol0003oVhg4
oi^=a00<oi^=a003o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;
ohj:b`0<ohj:b`03o`000?n:R/goRX[=00[oRX[=00?o0000ohZ:cOl000003on8S=000ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oooooo^[Zjo`000005oooo
o`04o`000?ooooooooooooooo`;o00001_naj_P3o`0000Co/N[h0_l0000;okO_m@;o00002onolO80
0ol0003oano^olO_kP07olO_kP03o`000?o>inSoc^OX00?oc^OX1Ol00002olc/j`03o`000?o?gN?o
cmgS00_ocmgS00?o0000olc<f_o<c=X03?o<c=X00ol0003ob/kLo`00000BolBldP;o00004Onk[</0
0ol0003o]ZW<okJYc006okJYc003o`000?naWlGo/Io500Ko/Io500?o0000ojbKaOn/VlD03?n/VlD0
0ol0003oYYS6ojJHaP0=ojJHaP03o`000?nQU<SoXIC800Co00002?nPT<<00ol0003oVhg4oi^=a00<
oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<
ohj:b`03o`000?n:R/goRX[=00_oRX[=00?o0000ohZ:cOl000003_n8S=000ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00cooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`04o`00
0?oooooo0000o`0000Go/N[h0ol00005ok7Zn0;o00003?ngkoD00ol0003o_o7bokoalP09okoalP;o
00002Oo7knh00ol0003oc^OXolkWj009olkWj0?o00002oo?gN<2o`0000ooc<cJ0_l0000BolBldP03
o`000?nn[/[o000001;o^jc;00?o0000okJYc?nfZL`00onfZL`2o`0000Wo/Io500?o0000ojbKaOn/
VlD03On/VlD00ol0003oYYS6ojJHaP0<ojJHaP?o00003?nPT<<00ol0003oVhg4oi^=a00<oi^=a003
o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03
o`000?n:R/goRX[=00_oRX[=0_l0000?ohR<d003o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool002Gooooo0_l00004ok7Zn0?o00001_naj_P2o`0000co]noe0_l0000;okoalP03o`00
0?o7knkoano^00Soano^00?o0000olkWj?o>inP02Oo>inP01?l0003ocm[QoloJhOo?f^42o`0000So
cmgS00?o0000olc<f_o<c=X03_o<c=X00ol0003oakgAo`00000AolBldP05o`000?nn[/[o_Zk:okj^
b_l000004Onk[</01?l0003o]ZW<okJYc?nfZL`2o`0000_o/Io500?o0000ojbKaOn/VlD03On/VlD0
0ol0003oYYS6ojJHaP09ojJHaP?o000000?oYI?2o`000?nPT<<03?nPT<<00ol0003oVhg4oi^=a00=
oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<
ohj:b`03o`000?n:R/goRX[=00_oRX[=0_l0000?ohR<d003o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool002Cooooo1ol00008ok7Zn003o`000?ngkoGo]noe00[o]noe0_l0000;okoa
lP;o00002Oo7knh2o`0000_oc^OX00?o0000oloJhOo?f^401?o?f^43o`0000CocmgS00?o0000olc<
f_o<c=X03_o<c=X01Ol0003oakgAolNmdOo7_M7o000000koa;cB0_l00005okj^bP03o`000?nk[<_o
^jc;00oo^jc;00?o0000okJYc?l000003_naWlD00ol0003o[9_5ojbKa@0<ojbKa@03o`000?nVV<Ko
YYS600KoYYS60ol00005ojFC`P03o`000?nPT<?oX93300_oX93300?o0000oi^=a?nKSL@03?nKSL@0
0ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800goTH[800?o0000ohj:bon>R//03?n>R//0
0ol0003oRX[=ohZ:c@0;ohZ:c@;o00003_n8S=000ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo000Tooooo`[o00000onaj_P2o`0000co]noe00?o0000okoal_nolO802OnolO82o`00
00[oano^00?o0000olkWj?o>inP02_o>inP00ol0003ocm[QoloJh@08oloJh@;o000000?ocmgSo`00
0?o<c=X03oo<c=X00ol0003oakgAolNmd@03olNmd@03o`000?o4_=;oa;cB00[oa;cB00?o0000okj^
b_nn[/X01Onn[/X00ol0003o^jc;ok^/b`0?ok^/b`;o00003onaWlD00ol0003o[9_5ojbKa@0=ojbK
a@03o`000?nVV<KoYYS600;oYYS60ol00008ojFC`P03o`000?nPT<?oX93300_oX93300?o0000oi^=
a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0<oiJ;aP03o`000?nAR/SoTH[800coTH[800?o0000ohj:
bon>R//03?n>R//00ol0003oRX[=ohZ:c@0<ohZ:c@03o`000?n8S=3oR8c@00goR8c@00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`009?ooool2o`0000Sooooo1_l00009okO_m@;o
00002onolO800ol0003oano^olO_kP09olO_kP03o`000?o>inSoc^OX00Woc^OX0_l0000<oloJh@?o
00003oo<c=X00ol0003oakgAolNmd@05olNmd@03o`000?o4_=;oa;cB00Soa;cB00?o0000okj^b_nn
[/X01onn[/X00ol0003o^jc;ok^/b`0=ok^/b`03o`000?nfX/Go0000013o/Io500?o0000ojbKaOn/
VlD03?n/VlD00ol0003oYYS6o`000002o`0000_oYI?200?o0000oj2@`onPT<<03?nPT<<00ol0003o
Vhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003o
SX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00goRX[=00?o0000ohR<d?n8S=003?n8S=000ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00_ooooo
1Ol00003okO_m@03o`000?nolO;o_o7b00Wo_o7b0_l0000:olO_kP;o00002oo>inP00ol0003ocm[Q
oloJh@0;oloJh@05o`000?o=bmSocL_Holg;f?l000003?o<c=X2o`0000WoakgA00?o0000olBld_o4
_=801_o4_=800ol0003o_Zk:okj^bP08okj^bP03o`000?nk[<_o^jc;00_o^jc;0_l00003okJRa@03
o`000?naWlGo/Io500go/Io500?o0000ojbKaOn/VlD03?n/VlD2o`0000ooYI?200?o0000oj2@`onP
T<<02onPT<<00ol0003oVhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600_oUX_600?o0000oi6:b?nA
R/P03OnAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00coRX[=00?o0000ohR<d?n8
S=003On8S=000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000Wooooo`03o`00
0?oooooooooo00oooooo2Ol00005okoalP03o`000?o7knkoano^00Woano^00?o0000olkWj?o>inP0
2_o>inP00ol0003ocm[QoloJh@0;oloJh@03o`000?o=bmSocL_H00?ocL_H00?o0000olc<f_o<c=X0
2?o<c=X00ol0003oakgAolNmd@0:olNmd@03o`000?o4_=;oa;cB00?oa;cB0_l0000<okj^bP03o`00
0?nk[<_o^jc;00Wo^jc;00?o0000okJRaOnfX/D00onfX/D00ol0003o/Io5ok6Oa@0>ok6Oa@03o`00
0?n/VlGo[9_500Wo[9_50_l000000onYU/;o0000ojFC`P0>ojFC`P03o`000?nPT<?oX93300_oX933
00?o0000oi^=a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0<oiJ;aP03o`000?nAR/SoTH[800coTH[8
00?o0000ohj:bon>R//03?n>R//00ol0003oRX[=ohZ:c@0<ohZ:c@;o00003_n8S=000ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo000Xooooo`03o`000?oooooooooo01Oooooo2?l0
0008olO_kP03o`000?o>inSoc^OX00Woc^OX0_l0000=oloJh@03o`000?o=bmSocL_H00GocL_H0_l0
0007olc<fP03o`000?o7_M7oakgA00coakgA00Go0000olBld_o4_=;oa;cBo`00000?okj^bP03o`00
0?nk[<_o^jc;00Ko^jc;0_l00007okJRa@03o`000?naWlGo/Io500go/Io500?o0000ojbKaOn/VlD0
1on/VlD2o`0000CoZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``0;oj2@``03o`00
0?nKSLCoVhg400coVhg400?o0000oiJ;a_nFRlH02onFRlH00ol0003oTH[8oi6:b00=oi6:b003o`00
0?n>R/_oSX[;00coSX[;00?o0000ohZ:cOn:R/d03?n:R/d2o`0000goR8c@00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`00:Oooool2o`0001oooooo1Ol00002olO_kP03o`000?o>
inSoc^OX00Woc^OX00?o0000oloJhOo?f^403?o?f^400ol0003ocL_Holg;f008olg;f003o`000?o<
c=[oc<cJ00?oc<cJ00?o0000olNmdOo7_M403_o7_M400ol0003oa;cBo`00000@okj^bP03o`000?nk
[<_o^jc;00Go^jc;00?o0000okJRaOnfX/D01onfX/D00ol0003o/Io5ok6Oa@0=ok6Oa@03o`000?n/
VlGo[9_500Co[9_50ol00006ojVF`P03o`000?nUTl;oYI?200goYI?200?o0000oj2@`onPT<<02onP
T<<00ol0003oVhg4oi^=a00<oi^=a003o`000?nFRlKoUX_600coUX_600?o0000oi6:b?nAR/P03?nA
R/P00ol0003oSX[;ohj:b`0<ohj:b`03o`000?n:R/goRX[=00coRX[=00?o0000ohR<d?l000003On8
S=000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000[ooooo`03o`000?oooooo
oooo027ooooo1Ol00008olkWj003o`000?o?f^7ocm[Q00_ocm[Q0_l0000<olg;f005o`000?o<c=[o
c<cJolc<f_l000004Oo7_M42o`0001;o_Zk:00?o0000ok^/bonk[</00onk[</00ol0003o]Z;5okJR
a@09okJRa@03o`000?naWlGo/Io500go/Io500Co0000ojbKaOn/VlGo[9_50_l00009ojVF`P03o`00
0?nUTl;oYI?200goYI?200?o0000oj2@`onPT<<02onPT<<00ol0003oVhg4oi^=a00=oi^=a003o`00
0?nFRlKoUX_600_oUX_600?o0000oi6:b?nAR/P03?nAR/P00ol0003oSX[;ohj:b`0<ohj:b`03o`00
0?n:R/goRX[=00coRX[=00?o0000ohR<d?l000003On8S=000ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo000/ooooo`03o`000?oooooooooo02Gooooo1Ol00002olkWj003o`000?o?
f^7ocm[Q00_ocm[Q00?o0000olg;f?o=bmP03Oo=bmP00ol0003oc<cJo`00000AolNmd@03o`000?o1
/L[o000001;o_Zk:00Co0000ok^/bonk[<_o^jc;0_l0000<okJRa@03o`000?naWlGo/Io500go/Io5
00Co0000ojbKaOl0003o00003?nYU/800ol0003oYI?2ojFC`P0=ojFC`P03o`000?nPT<?oX93300_o
X93300?o0000oi^=a?nKSL@03?nKSL@00ol0003oUX_6oiJ;aP0;oiJ;aP03o`000?nAR/SoTH[800Ko
TH[8;_l00006ohR<d003o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002gooooo
00?o0000ooooooooool0:Oooool3o`0000cocm[Q00?o0000olg;f?o=bmP03_o=bmP2o`00017oakgA
00Go0000ol6ab_o1/L[o`K7:o`00000Bokj^bP03o`000?nk[<_o000000oo]Z;500?o0000ok6OaOna
WlD03?naWlD2o`0000koZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``0;oj2@``03
o`000?nKSLCoVhg400coVhg400?o0000oiJ;a_nFRlH01OnFRlH?o`0000OoU8_600?o0000oi:;bOnB
RlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`04o`000?n>S/ooSXk?o`0000GoSXk?2?l0000=oooo
o`03o`000?oooooooooo00[ooooo000^ooooo`;o0000;?ooool3o`0000Socm[Q00?o0000olg;f?o=
bmP03_o=bmP01?l0003ob;k@olRnd?l0000>olNmd@;o00001Oo1/LX00ol0003o_Zk:okj^bP0?okj^
bP;o00004?nfX/D00ol0003o/Io5ok6Oa@0:ok6Oa@;o000000?o[YW2o`000?nYU/803_nYU/800ol0
003oYI?2ojFC`P0<ojFC`P03o`000?nPT<?oX93300coX93300?o0000oi^=a?nKSL@02_nKSL@9o`00
00OoV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;
00coShc;00?o0000ohj>col000003?n>S/l00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo000`ooooo`03o`000?oooooooooo02cooooo0_l00005oloJh@03o`000?o=bmSocL_H00ko
cL_H00?o0000olRnd?o8_]000_o8_]000ol0003oakgAolNmd@0:olNmd@03o`000?o1/L[o`K7:00Go
`K7:00?o0000okj^b_nn[/X03_nn[/X00ol0003o^JG5o`00000@okJRa@03o`000?naWlGo/Io500So
/Io50_l00004ojjI`P03o`000?nYU/;oZIK200coZIK200?o0000ojFC`_nUTl803OnUTl800ol0003o
X933oj2@``0;oj2@``03o`000?nKSLCoVhg400GoVhg41Ol00002oib=``03o`000?nHRlCoV8_400co
V8_400?o0000oiB;a_nDRlH03?nDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00co
Shc;00Co0000ohj>con>S/oo00003?n>S/l00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo000aooooo`03o`000?oooooooooo02gooooo0ol000000oo?f^7o0000olg;f00?olg;f003
o`000?o8_]3ob;k@00Cob;k@00?o0000olNmdOo7_M402?o7_M400ol0003o`K7:ol6abP07ol6abP03
o`000?nn[/[o_Zk:00_o_Zk:0_l00003okVUa@03o`000?nfX/Go]Z;500ko]Z;500?o0000ok6OaOna
WlD01OnaWlD2o`0000Ko[YW200?o0000ojVF`_nYU/803?nYU/800ol0003oYI?2ojFC`P0=ojFC`P03
o`000?nPT<?oX93300_oX93300?o0000oi^=a?nKSL@01Ol00008oib=``03o`000?nHRlCoV8_400_o
V8_400?o0000oiB;a_nDRlH03?nDRlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00go
Shc;00Co0000ohj>con>S/oo00002on>S/l00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo000booooo`03o`000?oooooooooo02oooooo0_l0000>olg;f0;o00002?o8_]000ol0003o
akgAolNmd@06olNmd@03o`000?o1/L[o`K7:00Wo`K7:00?o0000okj^b_nn[/X02Onn[/X00ol0003o
^JG5okVUa@03okVUa@03o`000?nfX/Go]Z;500ko]Z;500?o0000ok6OaOnaWlD01?naWlD00ol0003o
[YW2ojjI`P06ojjI`P03o`000?nYU/;oZIK200goZIK200?o0000ojFC`_nUTl803OnUTl800ol0003o
X933oj2@``09oj2@``Co00003OnLSL<00ol0003oV8_4oiR;a00;oiR;a003o`000?nDRlKoU8_600go
U8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`05o`000?n>S/ooSXk?ohj>
col000002on>S/l00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000cooooo`03
o`000?oooooooooo033ooooo00?o0000olg;f?o=bmP02_o=bmP00ol0003ob;k@olRnd009olRnd003
o`000?o7_M7oakgA00?oakgA0_l0000<ol6abP03o`000?nn[/[o_Zk:00Oo_Zk:0_l00007okVUa@03
o`000?nfX/Go]Z;500ko]Z;500Co0000ok6OaOnaWlGo/Io50_l0000:ojjI`P03o`000?nYU/;oZIK2
00coZIK200?o0000ojFC`_nUTl803OnUTl800ol0003oX933oj2@``04oj2@``Go00000_nPSl800ol0
003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03?nDRlH00ol0
003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00Go0000ohj>con>S/ooSXk?o`00000;
ohj>c`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool003Cooooo0_l0000aoooo
o`03o`000?o=bmSocL_H00SocL_H00?o0000olRnd?o8_]002oo8_]001Ol0003oakgAolNmdOo7_M7o
000000oo`K7:00?o0000okj^b_nn[/X01Onn[/X00ol0003o^JG5okVUa@07okVUa@03o`000?nfX/Go
]Z;500ko]Z;500Co0000ok6OaOl0003o00003?n^VL800ol0003oZIK2ojVF`P0<ojVF`P03o`000?nU
Tl;oYI?200goYI?200?o0000oj2@`onPT<<01?l00008oj2?`P03o`000?nLSL?oW8g300coW8g300?o
0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900coTX_900?o
0000ohn<bon?S</03?n?S</01Ol0003oSXk?ohj>con>S/oo000000_oSXk?00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`00=_ooool00ol0003oooooooooo`0_ooooo`03o`000?o=
bmSocL_H00GocL_H0_l0000?olRnd003o`000?o7_M7o0000017o`K7:00?o0000okj^b_nn[/X00onn
[/X00ol0003o^JG5okVUa@09okVUa@03o`000?nfX/Go]Z;500go]Z;50_l0000?ojjI`P03o`000?nY
U/;oZIK200coZIK200?o0000ojFC`_nUTl803?nUTl83o`0000coX8o200?o0000oib=`onLSL<03?nL
SL<00ol0003oV8_4oiR;a00<oiR;a003o`000?nDRlKoU8_600coU8_600?o0000oi:;bOnBRlT03?nB
RlT00ol0003oShc;ohn<b`0<ohn<b`03o`000?n>S/ooSXk?00;oSXk?00?o0000ohj>con>S/l02?n>
S/l00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000gooooo`03o`000?oooooo
oooo02oooooo00?o0000olg;f?o=bmP00oo=bmP00ol0003ob;k@olRnd00?olRnd0;o00004_o1/LX0
1?l0003o_Zk:okj^b_nn[/X2o`0000co^JG500?o0000okJRaOnfX/D03?nfX/D00ol0003o/Yc2o`00
000?ojjI`P03o`000?nYU/;oZIK200coZIK200?o0000ojFC`_nUTl802OnUTl83o`000003ojBA`Ol0
003oX8o200coX8o200?o0000oib=`onLSL<03?nLSL<00ol0003oV8_4oiR;a00<oiR;a003o`000?nD
RlKoU8_600goU8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;ohn<b`0<ohn<b`03o`000?n>
S/ooSXk?00;oSXk?00?o0000ohj>con>S/l02?n>S/l00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo000hooooo`03o`000?oooooooooo02oooooo00Go0000olg;f?o=bmSocL_Ho`00
000AolRnd003o`000?o3/l_o000001?o`K7:00?o0000okj^b_l000003oniYLD00ol0003o]Z;5okJR
a@09okJRa@;o00000onbW<800ol0003o[YW2ojjI`P0<ojjI`P03o`000?nYU/;oZIK200goZIK200?o
0000ojFC`_nUTl801OnUTl83o`0000GoY97100?o0000oj2?`_nPSl802onPSl800ol0003oW8g3oib=
``0<oib=``03o`000?nHRlCoV8_400_oV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;
b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00_n>S/l00ol0003oSXk?ohj>
c`08ohj>c`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool003Wooooo0_l0000`
ooooo`03o`000?o=bmSo0000017ob;k@00Go0000ol>cboo3/l_o`k?;o`00000Bol6abP;o00004?ni
YLD00ol0003o]Z;5okJRa@07okJRa@;o00001OnbW<800ol0003o[YW2ojjI`P0=ojjI`P03o`000?nY
U/;oZIK200coZIK200?o0000ojFC`_nUTl800_nUTl83o`0000SoY97100?o0000oj2?`_nPSl802onP
Sl800ol0003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03?nD
RlH00ol0003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00goShc;00?o0000ohj>con>S/l00_n>
S/l00ol0003oSXk?ohj>c`07ohj>c`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool003_ooooo00?o0000ooooooooool0;_ooool2o`00013ob;k@00?o0000ol>cboo3/l/00oo3/l/0
0ol0003o`K7:ol6abP0>ol6abP03o`000?nlZ<Ko0000017o^JG500?o0000okJRaOnfX/D01OnfX/D0
0ol0003o/Yc2ok:L`P05ok:L`P03o`000?n^VL;o[YW200go[YW200?o0000ojVF`_nYU/803?nYU/80
0ol0003oYI?2o`000002o`0000_oY97100?o0000oj2?`_nPSl803?nPSl800ol0003oW8g3oib=``0<
oib=``03o`000?nHRlCoV8_400_oV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0003oTX_9oi:;b@0<
oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00on>S/l00ol0003oSXk?ohj>c`07
ohj>c`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool003cooooo00?o0000oooo
ooooool0;oooool00ol0003ob;k@olRnd00<olRnd003o`000?o3/l_o`k?;00Co`k?;00?o0000ol6a
b_o1/LX03Oo1/LX01Ol0003o_:S6okbXa_nlZ<Ko0000013o^JG500?o0000okJRaOnfX/D00onfX/D2
o`0000Wo/Yc200?o0000ojjI`_n^VL803?n^VL800ol0003oZIK2ojVF`P0<ojVF`P;o00003onTTL40
0ol0003oX8o2oj2?`P0;oj2?`P03o`000?nLSL?oW8g300coW8g300?o0000oiR;a?nHRl@02onHRl@0
0ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900coTX_900?o0000ohn<bon?S</03?n?S</0
0ol0003oSXk?ohj>c`04ohj>c`03o`000?n>S/ooSXk?00KoSXk?00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`00?Oooool00ol0003oooooooooo`0_ooooo`03o`000?o8_]3ob;k@
00Wob;k@0_l00008ol>cb`03o`000?o1/L[o`K7:00[o`K7:0_l00004okbXaP03o`000?niYLGo^JG5
00oo^JG500?o0000okJRaOnfX/D00_l0000;ok:L`P03o`000?n^VL;o[YW200go[YW200?o0000ojVF
`_nYU/802OnYU/82o`000003ojRD`Ol0003oY97100koY97100?o0000oj2?`_nPSl802onPSl800ol0
003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH03OnDRlH00ol0
003oTX_9oi:;b@0<oi:;b@03o`000?n?S<_oShc;00coShc;00?o0000ohj>con>S/l00on>S/l00ol0
003oSXk?ohj>c`07ohj>c`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool003ko
oooo0_l0000`ooooo`03o`000?o8_]3ob;k@00Oob;k@00?o0000ol>cboo3/l/02Oo3/l/00ol0003o
`K7:ol6abP08ol6abP03o`000?nlZ<Ko_:S600Go_:S600?o0000okVUaOniYLD03_niYLD00ol0003o
]Z;5o`00000>ok:L`P03o`000?n^VL;o[YW200co[YW200?o0000ojVF`_nYU/801onYU/82o`0000Co
Z9C100?o0000ojBA`OnTTL403?nTTL400ol0003oX8o2oj2?`P0<oj2?`P03o`000?nLSL?oW8g300co
W8g300?o0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP0=oiB;aP03o`000?nBRlWoTX_900co
TX_900?o0000ohn<bon?S</03?n?S</00ol0003oSXk?ohj>c`04ohj>c`03o`000?n>S/ooSXk?00Ko
SXk?00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00@?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?o8_]3ob;k@00Gob;k@00?o0000ol>cboo3/l/02_o3/l/00ol0003o`K7:
ol6abP07ol6abP03o`000?nlZ<Ko_:S600Ko_:S600?o0000okVUaOniYLD03_niYLD2o`0000oo/Yc2
00?o0000ojjI`_n^VL803On^VL800ol0003oZIK2ojVF`P03ojVF`P?o00001_nXU<400ol0003oY971
ojBA`@0=ojBA`@03o`000?nPSl;oX8o200_oX8o200?o0000oib=`onLSL<03?nLSL<00ol0003oV8_4
oiR;a00<oiR;a003o`000?nDRlKoU8_600coU8_600?o0000oi:;bOnBRlT03?nBRlT00ol0003oShc;
ohn<b`06ohn<baSo00002?ooool00ol0003oooooooooo`08ooooo`00@Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?o8_]3ob;k@00?ob;k@00?o0000ol>cboo3/l/03?o3/l/00ol0003o`K7:ol6a
bP05ol6abP03o`000?nlZ<Ko_:S600So_:S600?o0000okVUaOniYLD03?niYLD00ol0003o]J33o`00
000@ok:L`P03o`000?n^VL;o[YW200co[YW200Co0000ojVF`_nYU/;oZIK20_l00009ojRD`@03o`00
0?nTTL7oY97100goY97100?o0000oj2?`_nPSl802onPSl800ol0003oW8g3oib=``0<oib=``03o`00
0?nHRlCoV8_400coV8_400?o0000oiB;a_nDRlH02OnDRlHKo`0000OoTho<00?o0000oi:AconBTLl0
1?nBTLl00ol0003oTY7?oi:Ac`06oi:Ac`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool004;ooooo00?o0000ooooooooool0;_ooool01Ol0003ob;k@olRnd?o8_]3o0000013o`k?;
00?o0000ol6ab_o1/LX00_o1/LX2o`0000_o_:S600?o0000okVUaOniYLD02_niYLD2o`0000?o]J33
00?o0000ok:L`_nbW<803OnbW<800ol0003o[YW2ojjI`P0<ojjI`P04o`000?nYU/;o0000o`0000co
Z9C100?o0000ojBA`OnTTL403OnTTL400ol0003oX8o2oj2?`P0;oj2?`P03o`000?nLSL?oW8g300co
W8g300?o0000oiR;a?nHRl@02onHRl@00ol0003oU8_6oiB;aP02oiB;aPOo00001?nHS/L00ol0003o
UHk9oiF>b@0<oiF>b@03o`000?nCSlcoTho<00goTho<00?o0000oi:AconBTLl01?nBTLl00ol0003o
TY7?oi:Ac`06oi:Ac`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool004?ooooo
0_l0000_ooooo`03o`000?o8_]3o0000017o`k?;00Go0000ol6ab_o1/L[o`K7:o`00000>okbXaP03
o`000?niYLGo^JG500So^JG500?o0000okFP`oneX<<00oneX<<00ol0003o/Yc2ok:L`P0=ok:L`P03
o`000?n^VL;o[YW200co[YW20_l0000>ojRD`@03o`000?nTTL7oY97100goY97100?o0000oj2?`_nP
Sl802onPSl800ol0003oW8g3oib=``0<oib=``03o`000?nHRlCoV8_400WoV8_41ol0000<oiR>a`03
o`000?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`03?nCSl`00ol0003oTY7?oi:Ac`05oi:Ac`03
o`000?nBTLooTY7?00GoTY7?00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`00
AOooool00ol0003oooooooooo`0]ooooo`03o`000?o3/l_o`k?;017o`k?;00?o0000ol6ab_l00000
3onlZ<H00ol0003o^JG5okVUa@06okVUa@;o00001oneX<<00ol0003o/Yc2ok:L`P0=ok:L`P03o`00
0?n^VL;o[YW200Wo[YW20_l000000on/Ul7o0000ojRD`@0>ojRD`@03o`000?nTTL7oY97100coY971
00?o0000oj2?`_nPSl803?nPSl800ol0003oW8g3oib=``0;oib=``03o`000?nHRlCoV8_400;oV8_4
1ol00003oiZ>a@03o`000?nHS/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<
oi>?c00=oi>?c003o`000?nBTLooTY7?00GoTY7?00?o0000oi:AconBTLl01OnBTLl00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo0016ooooo`03o`000?oooooooooo02cooooo00?o
0000ol>cboo3/l/04Oo3/l/2o`00017o_:S600?o0000okVUaOniYLD01?niYLD00ol0003o]J33okFP
``07okFP``03o`000?nbW<;o/Yc200go/Yc200?o0000ojjI`_n^VL801on^VL82o`0000Co[9O100?o
0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@0=ojBA`@03o`000?nPSl;oX8o200_oX8o200?o
0000oib=`onLSL<02OnLSL<7o`0000_oVXk500?o0000oiR>aonHS/L03?nHS/L00ol0003oUHk9oiF>
b@0=oiF>b@03o`000?nCSlcoTho<00coTho<00?o0000oi:AconBTLl01OnBTLl00ol0003oTY7?oi:A
c`05oi:Ac`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool004Oooooo00?o0000
ooooooooool0;?ooool00ol0003o`k?;ol>cb`0?ol>cb`03o`000?nn[<Oo0000017o_:S600?o0000
okVUaOniYLD00oniYLD00ol0003o]J33okFP``08okFP``03o`000?nbW<;o/Yc200ko/Yc200?o0000
ojjI`_n^VL800on^VL83o`0000Ko[9O100?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@0=
ojBA`@03o`000?nPSl;oX8o200_oX8o200?o0000oib=`onLSL<00_nLSL<7o`0000?oWHo400?o0000
oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900coUHk900?o0000
oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`05oi:Ac`03o`000?nBTLooTY7?00CoTY7?00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`00B?ooool00ol0003oooooooooo`0/oooo
o`03o`000?o3/l_o`k?;00go`k?;00Go0000okj/aonn[<Oo_Zc7o`00000AokbXaP03o`000?niYLGo
^JG500;o00003?neX<<00ol0003o/Yc2ok:L`P0=ok:L`P04o`000?n^VL;o[YW2ojjI`P;o00002On/
Ul400ol0003oZ9C1ojRD`@0=ojRD`@03o`000?nTTL7oY97100coY97100?o0000oj2?`_nPSl802_nP
Sl86o`0000_oWHo400?o0000oiZ>aOnJS/D02onJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nE
S/WoUHk900coUHk900?o0000oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`06oi:Ac`03o`000?nB
TLooTY7?00CoTY7?00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`00BOooool2
o`0002gooooo00?o0000ol>cboo3/l/02_o3/l/2o`0000Co_Zc700?o0000okbXa_nlZ<H03onlZ<H0
0ol0003o^JG5o`00000>okFP``03o`000?nbW<;o/Yc200go/Yc200Co0000ojjI`_l0003o00003?n/
Ul400ol0003oZ9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100goY97100?o0000oj2?`_nPSl801_nP
Sl83o`0000;oXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nH
S/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<oi>?c00=oi>?c003o`000?nB
TLooTY7?00KoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo001;ooooo`03o`000?oooooooooo02[ooooo00?o0000ol>cboo3/l/02Oo3/l/0
0ol0003o_Zc7okj/a`05okj/a`03o`000?nlZ<Ko_:S600ko_:S60_l0000@okFP``03o`000?nbW<;o
/Yc200co/Yc20_l0000>ojbG`@03o`000?nXU<7oZ9C100coZ9C100?o0000ojBA`OnTTL403OnTTL40
0ol0003oX8o2oj2?`P03oj2?`P?o00001_nQT<<00ol0003oWHo4oif?a00;oif?a003o`000?nJS/Go
VXk500coVXk500?o0000oiR>aonHS/L03OnHS/L00ol0003oUHk9oiF>b@0<oiF>b@03o`000?nCSlco
Tho<00goTho<00?o0000oi:AconBTLl01_nBTLl00ol0003oTY7?oi:Ac`04oi:Ac`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool004cooooo00?o0000ooooooooool0:_ooool00ol0
003o`k?;ol>cb`07ol>cb`03o`000?nn[<Oo_Zc700Ko_Zc700?o0000okbXa_nlZ<H03OnlZ<H00ol0
003o^:?4o`00000@okFP``03o`000?nbW<;o/Yc200[o/Yc20_l000000on_V/;o0000ojbG`@0>ojbG
`@03o`000?nXU<7oZ9C100coZ9C100?o0000ojBA`OnTTL403?nTTL400ol0003oX8o2oj2?`P03o`00
00WoXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k7
00goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<oi>?c00<oi>?c003o`000?nBTLooTY7?
00OoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo001=ooooo`03o`000?oooooooooo02[ooooo00?o0000ol>cboo3/l/01Oo3/l/00ol0003o
_Zc7okj/a`08okj/a`03o`000?nlZ<Ko_:S600[o_:S60_l00003okRSa003o`000?neX<?o]J3300ko
]J3300?o0000ok:L`_nbW<801onbW<82o`0000Co[i[200?o0000ojbG`On/Ul403?n/Ul400ol0003o
Z9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100_oY9711?l0000<oj6@``03o`000?nMSlCoWHo400co
WHo400?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900co
UHk900?o0000oi>?c?nCSl`03OnCSl`00ol0003oTY7?oi:Ac`07oi:Ac`03o`000?nBTLooTY7?00?o
TY7?00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`00C_ooool2o`0002[ooooo
00?o0000ol>cboo3/l/00oo3/l/2o`0000co_Zc700?o0000okbXa_nlZ<H02?nlZ<H00ol0003o^:?4
okRSa003okRSa003o`000?neX<?o]J3300ko]J3300?o0000ok:L`_nbW<801OnbW<82o`0000Ko[i[2
00?o0000ojbG`On/Ul403On/Ul400ol0003oZ9C1ojRD`@0<ojRD`@03o`000?nTTL7oY97100OoY971
0ol00002ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5
oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700coV8k700?o0000oiF>bOnES/T03OnES/T00ol0003oTho<
oi>?c00<oi>?c003o`000?nBTLooTY7?00OoTY7?00?o0000oi:AconBTLl00onBTLl00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo001@ooooo`03o`000?oooooooooo02Sooooo00Go
0000ol>cboo3/l_o`k?;o`00000>okj/a`03o`000?nlZ<Ko_:S600Ko_:S60_l00007okRSa003o`00
0?neX<?o]J3300go]J3300?o0000ok:L`_nbW<801?nbW<800ol0003o[i[2ojnJ`P06ojnJ`P03o`00
0?n/Ul7o[9O100go[9O100?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@03ojBA`@Co0000
1_nTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400coWHo400?o0000oiZ>aOnJS/D0
3?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`000?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`0
3OnCSl`00ol0003oTY7?oi:Ac`07oi:Ac`03o`000?nBTLooTY7?00;oTY7?00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`00DOooool00ol0003oooooooooo`0Xooooo`03o`000?o3
/l_o0000013o_Zc700?o0000okbXa_nlZ<H01?nlZ<H00ol0003o^:?4okRSa007okRSa003o`000?ne
X<?o]J3300ko]J3300Co0000ok:L`_nbW<;o/Yc20_l0000:ojnJ`P03o`000?n/Ul7o[9O100co[9O1
00?o0000ojRD`OnXU<403?nXU<400ol0003oY971ojBA`@03o`0000[oY9;300?o0000oj6@`onQT<<0
3?nQT<<00ol0003oWHo4oif?a00<oif?a003o`000?nJS/GoVXk500_oVXk500?o0000oiR>aonHS/L0
3OnHS/L00ol0003oUHk9oiF>b@0<oiF>b@03o`000?nCSlcoTho<00goTho<00?o0000oi:AconBTLl0
1_nBTLl8o`0000Cooooo00?o0000ooooooooool01_ooool005;ooooo00?o0000ooooooooool0:?oo
ool00ol0003o_Zc7okj/a`0?okj/a`03o`000?nlZ<Ko_:S600?o_:S600?o0000okRSa?nhXl@02Onh
Xl@00ol0003o]J33okFP``0=okFP``04o`000?nbW<;o0000o`0000co[i[200?o0000ojbG`On/Ul40
3On/Ul400ol0003oZ9C1ojRD`@0;ojRD`@?o00003OnTT/<00ol0003oXI33oj6@``0<oj6@``03o`00
0?nMSlCoWHo400coWHo400?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`0=oiR>a`03o`00
0?nES/WoUHk900coUHk900?o0000oi>?c?nCSl`02OnCSl`<o`0000?oUiOB00Go0000oiNGd_nGUm;o
UiOBo`000004ooooo`03o`000?oooooooooo00Kooooo001Cooooo`;o0000:?ooool00ol0003o_Zc7
okj/a`0@okj/a`03o`000?nlZ<Ko_:S600;o00003?nhXl@00ol0003o]J33okFP``0=okFP``;o0000
3on_V/800ol0003o[9O1ojbG`@0<ojbG`@03o`000?nXU<7oZ9C100SoZ9C10ol000000onWUL?o0000
ojBB``0>ojBB``03o`000?nQT<?oXI3300_oXI3300?o0000oif?a?nMSl@03?nMSl@00ol0003oVXk5
oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700goV8k700?o0000oiF>bOnES/T03?nES/T00ol0003oTho<
oi>?c002oi>?c0Oo00001?nHULl00ol0003oUiOBoiNGdP08oiNGdP03o`000?nGUm;oUiOB00;oUiOB
00Go0000ooooooooooooooooo`000008ooooo`00EOooool00ol0003oooooooooo`0Vooooo`03o`00
0?nn[<Oo_Zc700oo_Zc700?o0000okbXa_l000003onhXl@00ol0003o]J33okFP``0;okFP``03o`00
0?nbW/?o000000oo[i[200?o0000ojbG`On/Ul403On/Ul400ol0003oZ9C1ojRD`@04ojRD`@?o0000
1OnWUL<00ol0003oY9;3ojBB``0<ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@0
3?nMSl@00ol0003oVXk5oiZ>a@0<oiZ>a@03o`000?nHS/OoV8k700coV8k700?o0000oiF>bOnES/T0
1_nES/T;o`0000coV9G?00?o0000oiNGd_nGUm802?nGUm801Ol0003oUiOBoiNGd_nGUm;o000000?o
oooo00?o0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool09Oooool00ol0003o_Zc7
okj/a`0?okj/a`;o00004?nhXl@00ol0003o]J33okFP``09okFP``;o00000onbW/<00ol0003o[i[2
ojnJ`P0=ojnJ`P03o`000?n/Ul7o[9O100co[9O100?o0000ojRD`OnXU<400_nXU<42o`0000SoYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400coWHo4
00?o0000oiZ>aOnJS/D03?nJS/D00ol0003oV8k7oiR>a`09oiR>a`co00001onITld00ol0003oV9G?
oiREc`0=oiREc`03o`000?nGUm;oUiOB00WoUiOB00Go0000oiNGd_nGUm;oUiOBo`000002ooooo`03
o`000?oooooooooo00Kooooo001Gooooo`03o`000?oooooooooo02Gooooo00?o0000okj/aonn[<L0
3Onn[<L00ol0003o^ZO6o`00000@okRSa003o`000?neX<?o]J3300Oo]J330_l00005ok:N``03o`00
0?n_V/;o[i[200go[i[200?o0000ojbG`On/Ul403?n/Ul400ol0003oZ9C1o`000002o`0000[oYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400goWHo4
00?o0000oiZ>aOnJS/D02onJS/D00ol0003oV8k7oiR>a`02oiR>a`Oo00001?nKTl/00ol0003oVI?=
oiVCc@0=oiVCc@03o`000?nHULooV9G?00coV9G?00?o0000oiNGd_nGUm802_nGUm801?l0003oUiOB
oiNGd_l00002ooooo`03o`000?oooooooooo00Kooooo001Hooooo`;o00009_ooool00ol0003o_Zc7
okj/a`0:okj/a`;o00000onjYlH00ol0003o^:?4okRSa00>okRSa003o`000?neX<?o]J3300Go]J33
00?o0000ok:N`onbW/<01_nbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P03o`000?n/Ul7o[9O100co[9O1
0_l0000>ojNE``03o`000?nTT/?oY9;300coY9;300?o0000oj6@`onQT<<03?nQT<<00ol0003oWHo4
oif?a00<oif?a003o`000?nJS/GoVXk500WoVXk51ol0000<oi^Cb`03o`000?nITlgoVI?=00coVI?=
00?o0000oiREconHULl03OnHULl00ol0003oUiOBoiNGdP09oiNGdP04o`000?nGUm;oUiOBo`0000?o
oooo00?o0000ooooooooool01Oooool005[ooooo00?o0000ooooooooool08oooool00ol0003o_Zc7
okj/a`09okj/a`03o`000?njYlKo^ZO600?o^ZO600?o0000okRSa?nhXl@03_nhXl@00ol0003o]J33
okFP``03okFP``;o00002OnbW/<00ol0003o[i[2ojnJ`P0=ojnJ`P03o`000?n/Ul7o[9O100Wo[9O1
0_l000000on[V<?o0000ojNE``0=ojNE``03o`000?nTT/?oY9;300goY9;300?o0000oj6@`onQT<<0
2onQT<<00ol0003oWHo4oif?a00<oif?a003o`000?nJS/GoVXk500;oVXk51ol00003oifCb@03o`00
0?nKTl_oVi?;00goVi?;00?o0000oiVCcOnITld03OnITld00ol0003oV9G?oiREc`0<oiREc`03o`00
0?nGUm;oUiOB00[oUiOB00Co0000oiNGd_nGUm;o00000_ooool00ol0003oooooooooo`05ooooo`00
Foooool00ol0003oooooooooo`0Sooooo`03o`000?nn[<Oo_Zc700Ko_Zc70_l00007okZWaP03o`00
0?nhXlCo^:?400ko^:?400?o0000okFP`oneX<<00_l0000;ok:N``03o`000?n_V/;o[i[200go[i[2
00?o0000ojbG`On/Ul401on/Ul42o`0000CoZiS300?o0000ojNE`onWUL<03?nWUL<00ol0003oY9;3
ojBB``0<ojBB``03o`000?nQT<?oXI3300coXI3300?o0000oif?a?nMSl@02_nMSl@6o`0000_oWI?9
00?o0000oi^CbonKTl/03?nKTl/00ol0003oVI?=oiVCc@0=oiVCc@03o`000?nHULooV9G?00goV9G?
00?o0000oiNGd_nGUm802_nGUm800ol0003oUiOBo`000002ooooo`03o`000?oooooooooo00Gooooo
001Looooo`03o`000?oooooooooo02;ooooo00?o0000okj/aonn[<L01Onn[<L00ol0003o^ZO6okZW
aP08okZWaP03o`000?nhXlCo^:?400go^:?400?o0000okFP`ol000003_nbW/<00ol0003o[i[2ojnJ
`P0=ojnJ`P03o`000?n/Ul7o[9O100?o[9O10ol00006oj^H``03o`000?nWUL?oYiG300coYiG300?o
0000ojBB`onTT/<03?nTT/<00ol0003oXI33oj6@``0<oj6@``03o`000?nMSlCoWHo400GoWHo41Ol0
0002oinCa`03o`000?nMTlWoWI?900coWI?900?o0000oi^CbonKTl/03OnKTl/00ol0003oVI?=oiVC
c@0<oiVCc@03o`000?nHULooV9G?00goV9G?00?o0000oiNGd_nGUm802onGUm801Ol0003oUiOBo`00
0?oooooo000000Oooooo001Mooooo`03o`000?oooooooooo02;ooooo00?o0000okj/aonn[<L00onn
[<L00ol0003o^ZO6okZWaP09okZWaP03o`000?nhXlCo^:?400go^:?40_l0000?ok:N``03o`000?n_
V/;o[i[200go[i[200Co0000ojbG`On/Ul7o[9O10_l00009oj^H``03o`000?nWUL?oYiG300coYiG3
00?o0000ojBB`onTT/<03OnTT/<00ol0003oXI33oj6@``0;oj6@``03o`000?nMSlCoWHo400Go0000
2?nOTlL00ol0003oWI?9oifCb@0<oifCb@03o`000?nKTl_oVi?;00coVi?;00?o0000oiVCcOnITld0
3OnITld00ol0003oV9G?oiREc`0<oiREc`03o`000?nGUm;oUiOB00_oUiOB00Go0000oiNGd_l0003o
ooooo`000007ooooo`00G_ooool2o`0002?ooooo00?o0000okj/aonn[<L00_l0000=okZWaP03o`00
0?nhXlCo^:?400_o^:?400?o0000okBQaOl000004?nbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P04o`00
0?n/Ul7o0000o`0000coZiS300?o0000ojNE`onWUL<03?nWUL<00ol0003oY9;3ojBB``0<ojBB``03
o`000?nQT<?oXI3300[oXI331?l0000=oinCa`03o`000?nMTlWoWI?900coWI?900?o0000oi^CbonK
Tl/03OnKTl/00ol0003oVI?=oiVCc@0<oiVCc@03o`000?nHULooV9G?00goV9G?00?o0000oiNGd_nG
Um802onGUm801?l0003oUiOBo`000?l00007ooooo`00H?ooool00ol0003oooooooooo`0Pooooo`03
o`000?nn[<Oo000000oo^ZO600?o0000okRSa?nhXl@02OnhXl@2o`0000?o]:7500?o0000ok:N`onb
W/<03OnbW/<00ol0003o[i[2ojnJ`P0<ojnJ`P;o00003_n[V<<00ol0003oYiG3ojNE``0<ojNE``03
o`000?nTT/?oY9;300goY9;300?o0000oj6@`onQT<<01_nQT<<3o`0000;oXYC600?o0000oinCaonO
TlL03OnOTlL00ol0003oWI?9oifCb@0;oifCb@03o`000?nKTl_oVi?;00goVi?;00?o0000oiVCcOnI
Tld03OnITld00ol0003oV9G?oiREc`0<oiREc`03o`000?nGUm;oUiOB00coUiOB0ol00007ooooo`00
HOooool00ol0003oooooooooo`0Pooooo`03o`000?njYlKo^ZO600oo^ZO600?o0000okRSa?nhXl@0
1onhXl@00ol0003o]:75okBQa@03okBQa@03o`000?nbW/?o/Yk300ko/Yk300?o0000ojnJ`_n_V/80
2On_V/82o`000003ojfKa?l0003oZiS300koZiS300?o0000ojNE`onWUL<02onWUL<00ol0003oY9;3
ojBB``0=ojBB``03o`000?nQT<?oXI3300?oXI330ol00006oj:DaP03o`000?nOTlOoWi?700coWi?7
00?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<oi^Cb`03o`000?nITlgoVI?=00goVI?=
00?o0000oiREconHULl03OnHULl00ol0003oUiOBoiNGdP0;oiNGdP;o000000?oooooo`000?ooool0
1Oooool006;ooooo00?o0000ooooooooool07oooool00ol0003o^ZO6okZWaP0?okZWaP03o`000?nh
XlCo^:?400Go^:?40_l00007okBQa@03o`000?nbW/?o/Yk300go/Yk300?o0000ojnJ`_n_V/801on_
V/82o`0000Co[I_400?o0000oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``0<ojNE``03o`000?nT
T/?oY9;300coY9;300?o0000oj6@`onQT<<00ol00009oj:DaP03o`000?nOTlOoWi?700coWi?700?o
0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0=oi^Cb`03o`000?nITlgoVI?=00goVI?=00?o
0000oiREconHULl03?nHULl00ol0003oUiOBoiNGdP09oiNGdPKo00001_ooool006?ooooo0_l0000P
ooooo`03o`000?njYlKo^ZO600oo^ZO600?o0000okRSa?nhXl@00onhXl@00ol0003o]:75okBQa@07
okBQa@03o`000?nbW/?o/Yk300go/Yk300?o0000ojnJ`_n_V/801?n_V/83o`0000Ko[I_400?o0000
oj^H`on[V<<03On[V<<00ol0003oYiG3ojNE``0;ojNE``03o`000?nTT/?oY9;300_oY9;31?l0000=
oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<
oi^Cb`03o`000?nITlgoVI?=00goVI?=00?o0000oiREconHULl03?nHULl00ol0003oUiOBoiNGdP02
oiNGdPOo00001?ooool2o`0000Kooooo001Uooooo`03o`000?oooooooooo01kooooo00?o0000okZW
a_njYlH03onjYlH00ol0003o^:?4okRSa002o`0000_o]:7500?o0000ok:N`onbW/<03OnbW/<01?l0
003o[i[2ojnJ`_n_V/82o`0000[o[I_400?o0000oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``0<
ojNE``03o`000?nTT/?oY9;300OoY9;30ol00002ojFFaP03o`000?nRU<KoXYC600coXYC600?o0000
oinCaonOTlL03?nOTlL00ol0003oWI?9oifCb@0<oifCb@03o`000?nKTl_oVi?;00goVi?;00?o0000
oiVCcOnITld03?nITld00ol0003oV9G?oiREc`06oiREc`_o00002_ooool3o`0000Kooooo001Voooo
o`03o`000?oooooooooo01gooooo00?o0000okZWa_njYlH03onjYlH00ol0003o^:?4o`00000=okBQ
a@03o`000?nbW/?o/Yk300go/Yk300Co0000ojnJ`_l0003o00003?n]Vl@00ol0003oZiS3oj^H``0<
oj^H``03o`000?nWUL?oYiG300coYiG300?o0000ojBB`onTT/<00onTT/<4o`0000KoYIK600?o0000
oj:Da_nRU<H02onRU<H00ol0003oWi?7oinCa`0=oinCa`03o`000?nMTlWoWI?900coWI?900?o0000
oi^CbonKTl/03?nKTl/00ol0003oVI?=oiVCc@09oiVCc@co00004Oooool4o`0000Wooooo001Woooo
o`03o`000?oooooooooo01gooooo00?o0000okZWa_njYlH03_njYlH2o`0000oo]:7500?o0000ok:N
`onbW/<03?nbW/<2o`0000ko[I_400?o0000oj^H`on[V<<03On[V<<00ol0003oYiG3ojNE``0;ojNE
``03o`000?nTT/?oY9;300?o00002_nUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?7
00coWi?700?o0000oifCbOnMTlT03?nMTlT00ol0003oVi?;oi^Cb`0<oi^Cb`03o`000?nITlgoVI?=
00;oVI?=1ol0000Iooooo`Co00003Oooool006Sooooo0_l0000Mooooo`03o`000?njYlKo^ZO600go
^ZO600?o0000okNUaol000004?ndXLD00ol0003o/Yk3ok:N``09ok:N``;o000000?o/9k5o`000?n]
Vl@03_n]Vl@00ol0003oZiS3oj^H``0<oj^H``03o`000?nWUL?oYiG300[oYiG31?l0000>ojFFaP03
o`000?nRU<KoXYC600_oXYC600?o0000oinCaonOTlL03OnOTlL00ol0003oWI?9oifCb@0;oifCb@03
o`000?nKTl_oVi?;00_oVi?;1_l0000Mooooo`?o00004Oooool006[ooooo00?o0000ooooooooool0
6oooool00ol0003o^ZO6okZWaP0:okZWaP;o00000ongYLL00ol0003o]:75okBQa@0=okBQa@03o`00
0?nbW/?o/Yk300So/Yk300?o0000ok2NaOn`W/D00_n`W/D00ol0003o[I_4ojfKa00<ojfKa003o`00
0?n[V<?oZiS300goZiS300?o0000ojNE`onWUL<01_nWUL<3o`0000;oYiS600?o0000ojFFa_nUU/H0
3OnUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT0
3?nMTlT00ol0003oVi?;oi^Cb`05oi^Cb`Go00007oooool4o`0001Cooooo001[ooooo`03o`000?oo
oooooooo01_ooooo00?o0000okZWa_njYlH01onjYlH2o`0000Go]jG700?o0000okBQaOndXLD03_nd
XLD00ol0003o/Yk3ok:N``05ok:N``;o00001On`W/D00ol0003o[I_4ojfKa00=ojfKa003o`000?n[
V<?oZiS300coZiS300?o0000ojNE`onWUL<00onWUL<3o`0000KoYiS600?o0000ojFFa_nUU/H03?nU
U/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT03?nM
TlT00ol0003oVi?;oi^Cb`05o`00023ooooo1?l0000Hooooo`00K?ooool00ol0003oooooooooo`0J
ooooo`03o`000?njYlKo^ZO600Ko^ZO600?o0000okNUaongYLL01_ngYLL00ol0003o]:75okBQa@0=
okBQa@03o`000?nbW/?o/Yk300?o/Yk30_l00008ok2Na@03o`000?n]VlCo[I_400co[I_400?o0000
oj^H`on[V<<03?n[V<<00ol0003oYiG3ojNE``03o`0000WoYiS600?o0000ojFFa_nUU/H03OnUU/H0
0ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700coWi?700?o0000oifCbOnMTlT02OnMTlT5
o`00027ooooo1?l0000Looooo`00KOooool2o`0001_ooooo00?o0000okZWa_njYlH00onjYlH2o`00
00Wo]jG700?o0000okBQaOndXLD03_ndXLD01Ol0003o/Yk3ok:N`onbW/?o000000[o/9k500?o0000
ojfKa?n]Vl@03On]Vl@00ol0003oZiS3oj^H``0;oj^H``?o00003OnWV<H00ol0003oYIK6ojFFaP0<
ojFFaP03o`000?nRU<KoXYC600coXYC600?o0000oinCaonOTlL03?nOTlL00ol0003oWI?9oifCb@02
oifCb@Oo00008_ooool4o`00023ooooo001_ooooo`03o`000?oooooooooo01Sooooo00Co0000okZW
a_njYlKo^ZO60_l0000<okNUa`03o`000?ndXLGo]:7500go]:7500Co0000ok:N`ol0003o00002on`
W/D00ol0003o[I_4ojfKa00=ojfKa003o`000?n[V<?oZiS300SoZiS30ol000000onZV/Oo0000ojNH
aP0=ojNHaP03o`000?nUU/KoYIK600goYIK600?o0000oj:Da_nRU<H02onRU<H00ol0003oWi?7oinC
a`0;oinCa`Ko00009_ooool3o`0002Cooooo001`ooooo`03o`000?oooooooooo01Sooooo00?o0000
okZWa_l000003_ngYLL00ol0003o]:75okBQa@0=okBQa@;o00003_n`W/D00ol0003o[I_4ojfKa00<
ojfKa003o`000?n[V<?oZiS300GoZiS30ol00005ojZJa`03o`000?nWV<KoYiS600coYiS600?o0000
ojFFa_nUU/H03?nUU/H00ol0003oXYC6oj:DaP0<oj:DaP03o`000?nOTlOoWi?700GoWi?71Ol0000X
ooooo`Co00009oooool0077ooooo00?o0000ooooooooool06?ooool00ol0003o]jG7okNUa`0>okNU
a`03o`000?ndXLGo]:7500[o]:750_l000000onbXLOo0000ok2Na@0=ok2Na@03o`000?n]VlCo[I_4
00go[I_400?o0000oj^H`on[V<<00_n[V<<2o`0000SoZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0
003oYIK6ojFFaP0=ojFFaP03o`000?nRU<KoXYC600_oXYC600?o0000oinCaonOTlL01Ol0000Yoooo
o`Co0000:oooool007;ooooo00?o0000ooooooooool05oooool00ol0003o]jG7okNUa`0>okNUa`03
o`000?ndXLGo]:7500So]:750_l00004ok:Qa`03o`000?n`W/Go/9k500co/9k500?o0000ojfKa?n]
Vl@03?n]Vl@00ol0003oZiS3o`000002o`0000_oZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0003o
YIK6ojFFaP0<ojFFaP03o`000?nRU<KoXYC600[oXYC61?l0000Zooooo`Co0000;oooool007?ooooo
0_l0000Hooooo`03o`000?ngYLOo]jG700ko]jG700?o0000okBQaOndXLD01OndXLD2o`0000Ko/Z77
00?o0000ok2NaOn`W/D03?n`W/D00ol0003o[I_4ojfKa00<ojfKa0;o00003_nZV/L00ol0003oYiS6
ojNHaP0<ojNHaP03o`000?nUU/KoYIK600coYIK600?o0000oj:Da_nRU<H01onRU<H3o`0002[ooooo
1?l0000cooooo`00MOooool00ol0003oooooooooo`0Eooooo`03o`000?ngYLOo]jG700ko]jG700?o
0000okBQaOndXLD01?ndXLD00ol0003o/Z77ok:Qa`07ok:Qa`03o`000?n`W/Go/9k500co/9k500?o
0000ojfKa?n]Vl@02On]Vl@2o`000003ojbMb?l0003oZY[700goZY[700?o0000ojNHa_nWV<H03?nW
V<H00ol0003oYIK6ojFFaP0=ojFFaP03o`000?nRU<KoXYC600?oXYC60ol0000Yooooo`Co0000=ooo
ool007Kooooo00?o0000ooooooooool05Oooool00ol0003o]jG7okNUa`0>okNUa`04o`000?ndXLGo
]:75okBQa@;o00002_nbXLL00ol0003o/9k5ok2Na@0<ok2Na@03o`000?n]VlCo[I_400Oo[I_40_l0
0004ojbMb003o`000?nZV/OoZY[700coZY[700?o0000ojNHa_nWV<H03?nWV<H00ol0003oYIK6ojFF
aP0<ojFFaP03o`000?nRU<KoXYC600?o0000:Oooool3o`0003_ooooo001gooooo`03o`000?oooooo
oooo01Cooooo00?o0000okNUaongYLL03_ngYLL01?l0003o]:75o`000?l0000=ok:Qa`03o`000?n`
W/Go/9k500_o/9k500?o0000ojfKa?n]Vl@01?n]Vl@3o`0000Ko[9g800?o0000ojZJaonZV/L03?nZ
V/L00ol0003oYiS6ojNHaP0<ojNHaP03o`000?nUU/KoYIK600_oYIK61?l0000Xooooo`Co0000?_oo
ool007Sooooo0_l0000Eooooo`03o`000?ngYLOo]jG700go]jG70_l0000?ok:Qa`03o`000?n`W/Go
/9k500co/9k500Co0000ojfKa?n]VlCo[I_40_l0000:ojbMb003o`000?nZV/OoZY[700coZY[700?o
0000ojNHa_nWV<H03?nWV<H00ol0003oYIK6ojFFaP05ojFFaPGo0000:?ooool4o`0004;ooooo001j
ooooo`03o`000?oooooooooo01;ooooo00?o0000okNUaongYLL03?ngYLL00ol0003o]:G9o`00000@
ok:Qa`03o`000?n`W/Go/9k500_o/9k500Co0000ojfKa?l0003o00003?n/WLP00ol0003oZY[7ojZJ
a`0<ojZJa`03o`000?nWV<KoYiS600coYiS600?o0000ojFFa_nUU/H01Ol0000Yooooo`Co0000A_oo
ool007_ooooo00?o0000ooooooooool04_ooool00ol0003o]jG7okNUa`09okNUa`;o00000ondYLT0
0ol0003o/Z77ok:Qa`0=ok:Qa`03o`000?n`W/Go/9k500_o/9k50_l0000?ojbMb003o`000?nZV/Oo
ZY[700coZY[700?o0000ojNHa_nWV<H02onWV<H3o`0002[ooooo1?l0001:ooooo`00O?ooool00ol0
003oooooooooo`0Aooooo`03o`000?ngYLOo]jG700Oo]jG70_l00005okBUb@03o`000?nbXLOo/Z77
00go/Z7700?o0000ok2NaOn`W/D02On`W/D2o`000003ojjPbOl0003o[9g800ko[9g800?o0000ojZJ
aonZV/L03?nZV/L00ol0003oYiS6ojNHaP08ojNHaP?o0000:_ooool3o`0004kooooo001mooooo`;o
00004_ooool00ol0003o]jG7okNUa`05okNUa`03o`000?ndYLWo]:G900Ko]:G900?o0000ok:Qaonb
XLL03OnbXLL00ol0003o/9k5ok2Na@06ok2Na@;o00001?n^X<T00ol0003o[9g8ojbMb00=ojbMb003
o`000?nZV/OoZY[700_oZY[700?o0000ojNHa_nWV<H01OnWV<H3o`0002Wooooo1?l0001Aooooo`00
Ooooool00ol0003oooooooooo`0?ooooo`03o`000?ngYLOo]jG700?o]jG70_l00009okBUb@03o`00
0?nbXLOo/Z7700go/Z7700?o0000ok2NaOn`W/D01?n`W/D2o`0000Ko[Z3900?o0000ojbMb?n/WLP0
3On/WLP00ol0003oZY[7ojZJa`0<ojZJa`03o`000?nWV<KoYiS600;oYiS60_l0000Xooooo`Co0000
EOooool0083ooooo00?o0000ooooooooool03oooool00ol0003o]jG7okNUa`02o`0000co]:G900?o
0000ok:QaonbXLL03OnbXLL01?l0003o/9k5ok2NaOn`W/D2o`0000Wo[Z3900?o0000ojbMb?n/WLP0
3?n/WLP00ol0003oZY[7ojZJa`0<ojZJa`03o`000?nWV<Ko000000;o00009_ooool4o`0005Wooooo
0021ooooo`03o`000?oooooooooo00kooooo00?o0000okNUaol000003_ndYLT00ol0003o/Z77ok:Q
a`0=ok:Qa`04o`000?n`W/Go0000o`0000_o[Z3900?o0000ojbMb?n/WLP03On/WLP00ol0003oZY[7
ojZJa`0:ojZJa`?o00009Oooool4o`0005gooooo0022ooooo`;o00003oooool00ol0003o]:G9okBU
b@0>okBUb@03o`000?nbXLOo/Z7700co/Z770_l0000>ojjPb@03o`000?n/WLSo[9g800co[9g800?o
0000ojZJaonZV/L01onZV/L3o`0002Cooooo1?l0001Qooooo`00Q?ooool00ol0003oooooooooo`0<
ooooo`03o`000?ndYLWo]:G900ko]:G900?o0000ok:QaonbXLL02_nbXLL2o`000003ok2Sbol0003o
[Z3900go[Z3900?o0000ojbMb?n/WLP03On/WLP00ol0003oZY[7ojZJa`03ojZJa`?o00009?ooool3
o`0006Gooooo0025ooooo`03o`000?oooooooooo00cooooo00?o0000okBUbOndYLT03_ndYLT00ol0
003o/Z77ok:Qa`07ok:Qa`;o00001?n`Xl/00ol0003o[Z39ojjPb@0<ojjPb@03o`000?n/WLSo[9g8
00co[9g800?o0000ojZJaonZV/L00ol0000Sooooo`Co0000J?ooool008Kooooo00?o0000oooooooo
ool03?ooool00ol0003o]:G9okBUb@0=okBUb@03o`000?nbXLOo/Z7700Co/Z770ol00006ok2Sb`03
o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP03?n/WLP3o`0002;ooooo1?l0001/ooooo`00
Qoooool00ol0003oooooooooo`0;ooooo`03o`000?ndYLWo]:G900ko]:G900Co0000ok:QaonbXLOo
/Z770_l0000:ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP02?n/WLP3o`00027o
oooo1?l0001`ooooo`00R?ooool2o`0000cooooo00?o0000okBUbOndYLT03OndYLT01?l0003o/Z77
o`000?l0000<ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP01On/WLP3o`00023o
oooo1?l0001dooooo`00R_ooool00ol0003oooooooooo`0:ooooo`03o`000?ndYLWo]:G900co]:G9
0_l0000?ok2Sb`03o`000?n^X<Wo[Z3900co[Z3900?o0000ojbMb?n/WLP00_n/WLP2o`0001oooooo
1?l0001hooooo`00Roooool00ol0003oooooooooo`09ooooo`03o`000?ndYLWo]:G900[o]:G90_l0
00000onbYlgo0000ok2Sb`0?ok2Sb`03o`000?n^X<Wo[Z3900_o[Z3900?o0000ojbMb?l000000_l0
000Nooooo`?o0000O?ooool008cooooo00?o0000ooooooooool02Oooool00ol0003o]:G9okBUb@07
okBUb@;o00001?nbYld00ol0003o/:?;ok2Sb`0=ok2Sb`03o`000?n^X<Wo[Z3900_o[Z390_l0000M
ooooo`Co0000Ooooool008gooooo0_l0000:ooooo`03o`000?ndYLWo]:G900Co]:G90_l00006ok:W
c@03o`000?n`Xl_o/:?;00ko/:?;00?o0000ojjPbOn^X<T01on^X<T3o`0001_ooooo1?l00023oooo
o`00Soooool00ol0003oooooooooo`07ooooo`03o`000?ndYLWo]:G900;o]:G90_l00009ok:Wc@03
o`000?n`Xl_o/:?;00go/:?;00?o0000ojjPbOn^X<T01On^X<T2o`0001[ooooo1?l00027ooooo`00
T?ooool00ol0003oooooooooo`07ooooo`04o`000?ndYLWo0000o`0000_o/ZO=00?o0000ok2Sbon`
Xl/03_n`Xl/00ol0003o[Z39ojjPb@02ojjPb@;o00006?ooool4o`0008_ooooo002Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ok:WcOnbYld03?nbYld00ol0003o/:?;ok2Sb`0=ok2Sb`03o`00
0?n^X<Wo000000;o00005oooool3o`0008oooooo002Booooo`;o00001oooool00ol0003o/ZO=ok:W
c@0=ok:Wc@03o`000?n`Xl_o/:?;00co/:?;0_l0000Fooooo`Co0000T_ooool009Cooooo00?o0000
ooooooooool01Oooool00ol0003o/ZO=ok:Wc@0<ok:Wc@03o`000?n`Xl_o/:?;00[o/:?;0_l0000D
ooooo`Co0000U_ooool009Gooooo00?o0000ooooooooool01?ooool00ol0003o/ZO=ok:Wc@0=ok:W
c@03o`000?n`Xl_o/:?;00Oo/:?;0_l0000Booooo`Co0000V_ooool009Kooooo00?o0000oooooooo
ool01?ooool00ol0003o/ZO=ok:Wc@0<ok:Wc@03o`000?n`Xl_o/:?;00Co/:?;0ol0000@ooooo`Co
0000W_ooool009Oooooo0_l00005ooooo`03o`000?nbYlgo/ZO=00co/ZO=00Co0000ok2Sbon`Xl_o
/:?;0_l0000?ooooo`Co0000X_ooool009Wooooo00?o0000ooooooooool00_ooool00ol0003o/ZO=
ok:Wc@0<ok:Wc@04o`000?n`Xl_o0000o`0000kooooo0ol0002Vooooo`00V_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?nbYlgo/ZO=00_o/ZO=0_l0000<ooooo`Co0000ZOooool009_ooooo00Go
0000ooooooooooooooooo`00000:ok:Wc@?o00002_ooool4o`000:gooooo002Looooo`05o`000?oo
ooooooooooooool000001onbYld2o`0000Wooooo1?l0002aooooo`00WOooool2o`0000;ooooo00?o
0000ok:WcOnbYld00_nbYld2o`0000Oooooo1?l0002eooooo`00Woooool01?l0003oooooo`000?nb
Yld3o`0000Kooooo0ol0002iooooo`00X?ooool00ol0003oooooo`000005ooooo`Co0000_?ooool0
0:7ooooo0_l000000ooooooo0000o`000002o`000<3ooooo002Rooooo`;o0000a?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00<_ooooo00Co410@o`000?l0
003o0000VOooool00<cooooo00?o0000ooooooooool0VOooool00<cooooo00?o0000ooooooooool0
VOooool009oooooo00Go0000olc<c?oMgMgo0000onk^kP02ooooo`06oiRHV?l0003o0000ogMgMol@
413o00001?ooool00olQ8B7o<S8booooo`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1ooo
ool01_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00Wo0000ogMgMol0003o0000oeEEEOo^k^ko
ooooonk^k_mEEED00_l000001_m4A4Co^[Zjooooooooooook^k^oeEEE@;o000000KoA4A4okZj^_oo
ooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@07kooooo002Nooooo`06ojVYZOl0003oQhN7
oiRHV?l0003oV9RH0_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o
^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Oooooo00Ko0000ojVYZOoooooooooookZj
^_l00003ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgooooooo^k^koMgMg
oa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mEEEGoMgMgooooooo^k^ko
EEEEo`0007oooooo002Nooooo`06oeEEEOn7QhOoA4A4oeEEEOmgMgOoEEEE0_ooool01Ol@413oQhN7
ooooooo^k^ko000000Cooooo00Co410@okZj^_nHV9So<S8b0oooool00ol0003oooooooooo`0;oooo
o`05okZj^_n7QhOoIVIVofIVI_l@41000oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0007oooooo
002Nooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool00onj^[[o410@o`000002o`0000?o
oooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00001oooool01_lb<S;o8B4QogMgMomg
MgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000005o`0000;ooooo
1_l00002ooooo`06o`000?ooooooooooooooooo^k^ko0000Ooooool009gooooo00SoZJVYob4Q8Ooo
ooooQhN7oeEEEOoooooo<S8bojVYZ@Cooooo00Ooc<c<o`000?ooooooooooonk^k_l0003ogMgM00;o
oooo00[oV9RHoc8b<_oooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b1oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000?ooooo00go0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOn7QhOo
k^k^oooooon7QhOo<S8b00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOoooooonk^k_mEEEGo0000Ooooool009gooooo0ol00002ooooo`?o00000_ooool01?lb<S;o0000
o`000?nHV9P2ooooo`03oa0@4?l0003o000000;ooooo0ol000000oooooook^k^oeEEE@02o`000003
odA4A?o^k^kooooo00Kooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`03oa0@4?l0003o
MgMg00;o000000GoIVIVonk^k_ooooook^k^oeEEE@02o`000006odA4A?o^k^koooooooooooo^k^ko
EEEE0_l000002_m4A4Cok^k^ooooooooooook^k^oeEEEOl0003o410@olc<c?l0001oooooo`00j?oo
ool00ol0003oooooooooo`1mooooo`00j?ooool00ol0003oooooooooo`1mooooo`00ioooool2o`00
07oooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.108223, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "\tFor the numerical method, we choose CTCS. This explicit method works \
well for the wave equation, being second-order in both the  space and time \
step sizes, and allowing relatively large steps according to the von Neumann \
stability criterion: for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "=", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "=", "\[CapitalDelta]"}]}], 
          ","}], TraditionalForm]]],
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(c\^2\), 
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "2"], 
              "/", \(\[CapitalDelta]\^\(\(2\)\(\ \)\)\)}]}], "\[LessEqual]", 
          " ", \(1/2\)}], TraditionalForm]]],
  " for stability (see the exercises). Therefore, if  ",
  Cell[BoxData[
      \(TraditionalForm\`c \[LessEqual] \ 1/10\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] = \ 1/30\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "\[LessEqual]", 
            " ", \(1/3\ \@2\)}], "=", "0.24"}], TraditionalForm]]],
  ". Below, we choose ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.2"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ grid\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(M\_x = 30; \ M\_y = \ 30;\), 
        "\n", \(L\_\(\(x\)\(\ \)\) = \ \(L\_y = 1\);\), 
        "\n", \(\[CapitalDelta]x\  = \ L\_x/M\_x; \ \[CapitalDelta]y\  = \ 
          L\_y/M\_y;\), "\n", \(\[CapitalDelta]t\  = \ 0.2;\), 
        "\n", \(x[j_]\  := \ j\ \[CapitalDelta]x;\), 
        "\n", \(y[k_]\  := \ k\ \[CapitalDelta]y;\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ initial\ conditions\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\n", \(z0[j_, k_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(v0[j_, k_]\  := \ 0;\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ zeroth\ \(\(step\)\(:\)\)\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(z[j_, k_, 0]\  := \ z0[j, k];\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ define\ the\ wave\ speed\ on\ the\ grid\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(c[j_, k_]\  := \ cw[x[j], y[k]];\), 
        "\[IndentingNewLine]", "\n", 
        StyleBox[\( (*\ boundary\ conditions\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(z[0, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(z[M\_x, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(z[j_, 0, n_]\  := \ 
            x[j] \((1 - x[j])\) Sin[2  n\ \[CapitalDelta]t];\), 
        "\[IndentingNewLine]", \(z[j_, M\_y, n_]\  := \ 0;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.73"],

Cell["The CTCS method for the wave equation is", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_\(j\ k\)\%\(n + 1\)\), "=", 
          
          RowBox[{\(2  z\_\(j\ k\)\%n\), "-", \(z\_\(j\ k\)\%\(n - 1\)\), "+",
             
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j + 1\ k\)\%n - 2  z\_\(j\ k\)\%n + 
                  z\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j\ k + 1\)\%n - 2  z\_\(j\ k\)\%n + 
                  z\_\(j\ k - 1\)\%\(\(\ \)\(n\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["We construct the recursion relation for this method below:", "Text"],

Cell[BoxData[
    \(z[j_, k_, 
        n_]\  := \ \((z[j, k, n]\  = \ 
            2\ z[j, k, n - 1]\  - 
              z[j, k, n - 
                  2]\  + \ \ \(\(\(\[CapitalDelta]t\^2\) 
                      c[j, k]^2\)\/\[CapitalDelta]x\^2\) \((\((z[j + 1, k, 
                          n - 1]\  - \ 2\ z[j, k, n - 1]\  + \ 
                        z[j - 1, k, n - 1])\)\  + \ \((z[j, k + 1, 
                          n - 1]\  - \ 2\ z[j, k, n - 1]\  + \ 
                        z[j, k - 1, n - 1])\))\))\)\  /; \ 
        n \[GreaterEqual] \ 2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.74"],

Cell[TextData[{
  "The method can only be used for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ 2\)]],
  " because evaluation of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th time step  refers back to the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 2\)]],
  "nd step. Therefore, for the first step, we use the trick employed in \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " for second-order ODEs [see Eq. ",
  ButtonBox["(1.4.28)",
    ButtonData:>{"Chapter1.nb", "(1.4.28)"},
    ButtonStyle->"Hyperlink"],
  " and the surrounding discussion]:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_\(j\ k\)\%1\), "=", 
          RowBox[{\(z\_\(j\ k\)\%0\), "+", 
            RowBox[{\(\(v\_o\)\_\(j\ k\)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "+", 
            RowBox[{
              FractionBox[
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], 
                "2"], \(a\_\(j\ \ k\)\)}]}]}], TraditionalForm]]],
  ",\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_o\)\_\(j\ k\)\)]],
  " is the initial velocity (equal to zero for our choice of initial \
conditions), and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j\ k\)\)]],
  " is the initial acceleration, given by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(j\ k\)\), "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\)\(\ \)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j + 1\ k\)\%0 - 2  z\_\(j\ k\)\%0 + 
                  z\_\(j - 1\ k\)\%\(\(\ \)\(0\)\))\)}], "+", 
            RowBox[{
              FractionBox[
                RowBox[{\(c\_\(j\ k\)\%\(\(\ \)\(2\)\)\), " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "2"]}], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \((z\_\(j\ k + 1\)\%0 - 2  z\_\(j\ k\)\%0 + 
                  z\_\(j\ k - 1\)\%\(\(\ \)\(0\)\)\ )\)}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "(this is also equal to zero for our initial conditions). Therefore, we \
simply have ",
  Cell[BoxData[
      \(TraditionalForm\`z\_\(j\ k\)\%1 = z\_\(j\ k\)\%0\)]],
  "=0:"
}], "Text"],

Cell[BoxData[
    \(\(z[j_, k_, 1]\  := \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.75"],

Cell[TextData[{
  "(Of course, this cell must be modified if other initial conditions are \
used.) At each time step, we construct an interpolation function of the \
solution in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(zsol[n_]\  := \ \(zsol[n]\  = \ 
        Interpolation[
          Flatten[Table[{j\ \[CapitalDelta]x, k\ \[CapitalDelta]y, 
                z[j, k, n]}, {j, 0, M\_x}, {k, 0, M\_y}], 1]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.76"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.77",
    ButtonData:>"Cell 6.77",
    ButtonStyle->"Hyperlink"],
  " we plot the solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot3D[Evaluate[\(zsol[n]\)[x, y]], {x, 0, 1}, {y, 0, 1}, 
          PlotPoints \[Rule] 60, PlotRange \[Rule] {\(- .5\),  .5}, 
          Mesh \[Rule] False, 
          PlotLabel -> "\<t=\>"\  <> ToString[n\ \[CapitalDelta]t]], {n, 0, 
          140, 4}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.77"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -11 0 ]
[.5 .82364 11 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42251 Mtetra
.87715 .42251 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31998 .58625 Mtetra
.31998 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58041 Mtetra
.33892 .58041 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43355 Mtetra
.81556 .43355 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42251 .87257 .41599 Mtetra
.87257 .41599 .87715 .42251 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31998 .58625 .31397 .58087 Mtetra
.31397 .58087 .31998 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58041 .33296 .57499 Mtetra
.33296 .57499 .33892 .58041 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43355 .81078 .42711 Mtetra
.81078 .42711 .81556 .43355 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42007 Mtetra
.83351 .42007 .83823 .42657 .84963 .42306 .84494 .41653 Mtetra
.84494 .41653 .84963 .42306 .86108 .41953 .85642 .41298 Mtetra
.85642 .41298 .86108 .41953 .87257 .41599 .86795 .40941 Mtetra
.86795 .40941 .87257 .41599 .8841 .41243 .87952 .40583 Mtetra
.87952 .40583 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57838 Mtetra
.29846 .57838 .30452 .58379 .31397 .58087 .30792 .57544 Mtetra
.30792 .57544 .31397 .58087 .32345 .57793 .31742 .57249 Mtetra
.31742 .57249 .32345 .57793 .33296 .57499 .32696 .56952 Mtetra
.32696 .56952 .33296 .57499 .34251 .57203 .33652 .56655 Mtetra
.33652 .56655 .34251 .57203 .35209 .56907 .34613 .56357 Mtetra
.34613 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43462 Mtetra
.7609 .43462 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41708 Mtetra
.81734 .41708 .82212 .4236 .83351 .42007 .82876 .41353 Mtetra
.82876 .41353 .83351 .42007 .84494 .41653 .84023 .40996 Mtetra
.84023 .40996 .84494 .41653 .85642 .41298 .85174 .40639 Mtetra
.85174 .40639 .85642 .41298 .86795 .40941 .8633 .40279 Mtetra
.8633 .40279 .86795 .40941 .87952 .40583 .8749 .39919 Mtetra
.8749 .39919 .87952 .40583 .89113 .40224 .88655 .39556 Mtetra
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57884 Mtetra
.27348 .57884 .27963 .58424 .28903 .58132 .2829 .57589 Mtetra
.2829 .57589 .28903 .58132 .29846 .57838 .29235 .57294 Mtetra
.29235 .57294 .29846 .57838 .30792 .57544 .30184 .56998 Mtetra
.30184 .56998 .30792 .57544 .31742 .57249 .31136 .56701 Mtetra
.31136 .56701 .31742 .57249 .32696 .56952 .32091 .56403 Mtetra
.32091 .56403 .32696 .56952 .33652 .56655 .3305 .56103 Mtetra
.3305 .56103 .33652 .56655 .34613 .56357 .34012 .55803 Mtetra
.34012 .55803 .34613 .56357 .35576 .56057 .34978 .55501 Mtetra
.34978 .55501 .35576 .56057 .36543 .55756 .35947 .55198 Mtetra
.35947 .55198 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43862 Mtetra
.7225 .43862 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43462 .75593 .42819 Mtetra
.75593 .42819 .7609 .43462 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42116 Mtetra
.77843 .42116 .78334 .42765 .79463 .42414 .78975 .41762 Mtetra
.78975 .41762 .79463 .42414 .80596 .42062 .80111 .41408 Mtetra
.80111 .41408 .80596 .42062 .81734 .41708 .81252 .41051 Mtetra
.81252 .41051 .81734 .41708 .82876 .41353 .82397 .40694 Mtetra
.82397 .40694 .82876 .41353 .84023 .40996 .83547 .40335 Mtetra
.83547 .40335 .84023 .40996 .85174 .40639 .84702 .39974 Mtetra
.84702 .39974 .85174 .40639 .8633 .40279 .85861 .39612 Mtetra
.85861 .39612 .8633 .40279 .8749 .39919 .87025 .39249 Mtetra
.87025 .39249 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.25789 .57635 .2641 .58177 .27348 .57884 .2673 .5734 Mtetra
.2673 .5734 .27348 .57884 .2829 .57589 .27673 .57044 Mtetra
.27673 .57044 .2829 .57589 .29235 .57294 .2862 .56747 Mtetra
.2862 .56747 .29235 .57294 .30184 .56998 .29571 .56449 Mtetra
.29571 .56449 .30184 .56998 .31136 .56701 .30525 .56149 Mtetra
.30525 .56149 .31136 .56701 .32091 .56403 .31483 .55849 Mtetra
.31483 .55849 .32091 .56403 .3305 .56103 .32444 .55547 Mtetra
.32444 .55547 .3305 .56103 .34012 .55803 .33408 .55245 Mtetra
.33408 .55245 .34012 .55803 .34978 .55501 .34376 .54941 Mtetra
.34376 .54941 .34978 .55501 .35947 .55198 .35348 .54637 Mtetra
.35348 .54637 .35947 .55198 .3692 .54895 .36323 .54331 Mtetra
.36323 .54331 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38284 .53716 Mtetra
.38284 .53716 .38877 .54284 .3986 .53976 .39269 .53406 Mtetra
.39269 .53406 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43862 .7174 .43222 Mtetra
.7174 .43222 .7225 .43862 .7336 .43516 .72853 .42872 Mtetra
.72853 .42872 .7336 .43516 .74474 .43168 .7397 .42522 Mtetra
.7397 .42522 .74474 .43168 .75593 .42819 .75092 .4217 Mtetra
.75092 .4217 .75593 .42819 .76716 .42468 .76218 .41817 Mtetra
.76218 .41817 .76716 .42468 .77843 .42116 .77348 .41462 Mtetra
.77348 .41462 .77843 .42116 .78975 .41762 .78483 .41106 Mtetra
.78483 .41106 .78975 .41762 .80111 .41408 .79623 .40749 Mtetra
.79623 .40749 .80111 .41408 .81252 .41051 .80767 .4039 Mtetra
.80767 .4039 .81252 .41051 .82397 .40694 .81915 .4003 Mtetra
.81915 .4003 .82397 .40694 .83547 .40335 .83069 .39668 Mtetra
.83069 .39668 .83547 .40335 .84702 .39974 .84226 .39305 Mtetra
.84226 .39305 .84702 .39974 .85861 .39612 .85389 .3894 Mtetra
.85389 .3894 .85861 .39612 .87025 .39249 .86556 .38574 Mtetra
.86556 .38574 .87025 .39249 .88193 .38884 .87727 .38207 Mtetra
.25164 .57089 .25789 .57635 .2673 .5734 .26107 .56792 Mtetra
.26107 .56792 .2673 .5734 .27673 .57044 .27052 .56494 Mtetra
.27052 .56494 .27673 .57044 .2862 .56747 .28002 .56195 Mtetra
.28002 .56195 .2862 .56747 .29571 .56449 .28954 .55895 Mtetra
.28954 .55895 .29571 .56449 .30525 .56149 .2991 .55594 Mtetra
.2991 .55594 .30525 .56149 .31483 .55849 .3087 .55292 Mtetra
.3087 .55292 .31483 .55849 .32444 .55547 .31833 .54988 Mtetra
.31833 .54988 .32444 .55547 .33408 .55245 .328 .54684 Mtetra
.328 .54684 .33408 .55245 .34376 .54941 .3377 .54378 Mtetra
.3377 .54378 .34376 .54941 .35348 .54637 .34744 .54071 Mtetra
.34744 .54071 .35348 .54637 .36323 .54331 .35721 .53763 Mtetra
.35721 .53763 .36323 .54331 .37301 .54024 .36702 .53454 Mtetra
.36702 .53454 .37301 .54024 .38284 .53716 .37686 .53144 Mtetra
.37686 .53144 .38284 .53716 .39269 .53406 .38674 .52833 Mtetra
.38674 .52833 .39269 .53406 .40259 .53096 .39666 .5252 Mtetra
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52206 Mtetra
.40662 .52206 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .50621 Mtetra
.45695 .50621 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42926 Mtetra
.70114 .42926 .70631 .43569 .7174 .43222 .71226 .42576 Mtetra
.71226 .42576 .7174 .43222 .72853 .42872 .72342 .42224 Mtetra
.72342 .42224 .72853 .42872 .7397 .42522 .73462 .41871 Mtetra
.73462 .41871 .7397 .42522 .75092 .4217 .74587 .41517 Mtetra
.74587 .41517 .75092 .4217 .76218 .41817 .75716 .41161 Mtetra
.75716 .41161 .76218 .41817 .77348 .41462 .7685 .40804 Mtetra
.7685 .40804 .77348 .41462 .78483 .41106 .77988 .40445 Mtetra
.77988 .40445 .78483 .41106 .79623 .40749 .79131 .40085 Mtetra
.79131 .40085 .79623 .40749 .80767 .4039 .80278 .39724 Mtetra
.80278 .39724 .80767 .4039 .81915 .4003 .8143 .39361 Mtetra
.8143 .39361 .81915 .4003 .83069 .39668 .82586 .38996 Mtetra
.82586 .38996 .83069 .39668 .84226 .39305 .83747 .38631 Mtetra
.83747 .38631 .84226 .39305 .85389 .3894 .84913 .38263 Mtetra
.84913 .38263 .85389 .3894 .86556 .38574 .86083 .37895 Mtetra
.86083 .37895 .86556 .38574 .87727 .38207 .87259 .37524 Mtetra
.24535 .5654 .25164 .57089 .26107 .56792 .2548 .56241 Mtetra
.2548 .56241 .26107 .56792 .27052 .56494 .26427 .55941 Mtetra
.26427 .55941 .27052 .56494 .28002 .56195 .27379 .5564 Mtetra
.27379 .5564 .28002 .56195 .28954 .55895 .28333 .55338 Mtetra
.28333 .55338 .28954 .55895 .2991 .55594 .29292 .55035 Mtetra
.29292 .55035 .2991 .55594 .3087 .55292 .30253 .5473 Mtetra
.30253 .5473 .3087 .55292 .31833 .54988 .31218 .54425 Mtetra
.31218 .54425 .31833 .54988 .328 .54684 .32187 .54118 Mtetra
.32187 .54118 .328 .54684 .3377 .54378 .3316 .53811 Mtetra
.3316 .53811 .3377 .54378 .34744 .54071 .34135 .53502 Mtetra
.34135 .53502 .34744 .54071 .35721 .53763 .35115 .53192 Mtetra
.35115 .53192 .35721 .53763 .36702 .53454 .36098 .52881 Mtetra
.36098 .52881 .36702 .53454 .37686 .53144 .37085 .52568 Mtetra
.37085 .52568 .37686 .53144 .38674 .52833 .38075 .52255 Mtetra
.38075 .52255 .38674 .52833 .39666 .5252 .39069 .5194 Mtetra
.39069 .5194 .39666 .5252 .40662 .52206 .40067 .51624 Mtetra
.40067 .51624 .40662 .52206 .41661 .51892 .41068 .51307 Mtetra
.41068 .51307 .41661 .51892 .42664 .51576 .42074 .50989 Mtetra
.42074 .50989 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.44095 .50349 .44681 .5094 .45695 .50621 .45112 .50027 Mtetra
.45112 .50027 .45695 .50621 .46713 .503 .46132 .49704 Mtetra
.46132 .49704 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .4298 Mtetra
.67377 .4298 .67904 .43623 .69007 .43275 .68483 .4263 Mtetra
.68483 .4263 .69007 .43275 .70114 .42926 .69594 .42279 Mtetra
.69594 .42279 .70114 .42926 .71226 .42576 .70708 .41926 Mtetra
.70708 .41926 .71226 .42576 .72342 .42224 .71827 .41572 Mtetra
.71827 .41572 .72342 .42224 .73462 .41871 .72951 .41216 Mtetra
.72951 .41216 .73462 .41871 .74587 .41517 .74079 .40859 Mtetra
.74079 .40859 .74587 .41517 .75716 .41161 .75211 .40501 Mtetra
.75211 .40501 .75716 .41161 .7685 .40804 .76348 .40141 Mtetra
.76348 .40141 .7685 .40804 .77988 .40445 .77489 .39779 Mtetra
.77489 .39779 .77988 .40445 .79131 .40085 .78635 .39417 Mtetra
.78635 .39417 .79131 .40085 .80278 .39724 .79786 .39053 Mtetra
.79786 .39053 .80278 .39724 .8143 .39361 .80941 .38687 Mtetra
.80941 .38687 .8143 .39361 .82586 .38996 .821 .3832 Mtetra
.821 .3832 .82586 .38996 .83747 .38631 .83265 .37951 Mtetra
.83265 .37951 .83747 .38631 .84913 .38263 .84434 .37581 Mtetra
.84434 .37581 .84913 .38263 .86083 .37895 .85608 .3721 Mtetra
.85608 .3721 .86083 .37895 .87259 .37524 .86786 .36837 Mtetra
.23902 .55988 .24535 .5654 .2548 .56241 .24848 .55687 Mtetra
.24848 .55687 .2548 .56241 .26427 .55941 .25798 .55385 Mtetra
.25798 .55385 .26427 .55941 .27379 .5564 .26751 .55082 Mtetra
.26751 .55082 .27379 .5564 .28333 .55338 .27708 .54777 Mtetra
.27708 .54777 .28333 .55338 .29292 .55035 .28669 .54472 Mtetra
.28669 .54472 .29292 .55035 .30253 .5473 .29632 .54166 Mtetra
.29632 .54166 .30253 .5473 .31218 .54425 .306 .53858 Mtetra
.306 .53858 .31218 .54425 .32187 .54118 .31571 .53549 Mtetra
.31571 .53549 .32187 .54118 .3316 .53811 .32545 .53239 Mtetra
.32545 .53239 .3316 .53811 .34135 .53502 .33523 .52928 Mtetra
.33523 .52928 .34135 .53502 .35115 .53192 .34505 .52616 Mtetra
.34505 .52616 .35115 .53192 .36098 .52881 .3549 .52303 Mtetra
.3549 .52303 .36098 .52881 .37085 .52568 .36479 .51989 Mtetra
.36479 .51989 .37085 .52568 .38075 .52255 .37472 .51673 Mtetra
.37472 .51673 .38075 .52255 .39069 .5194 .38468 .51356 Mtetra
.38468 .51356 .39069 .5194 .40067 .51624 .39468 .51038 Mtetra
.39468 .51038 .40067 .51624 .41068 .51307 .40472 .50719 Mtetra
.40472 .50719 .41068 .51307 .42074 .50989 .4148 .50399 Mtetra
.4148 .50399 .42074 .50989 .43083 .5067 .42491 .50077 Mtetra
.42491 .50077 .43083 .5067 .44095 .50349 .43506 .49754 Mtetra
.43506 .49754 .44095 .50349 .45112 .50027 .44525 .4943 Mtetra
.44525 .4943 .45112 .50027 .46132 .49704 .45548 .49105 Mtetra
.45548 .49105 .46132 .49704 .47157 .4938 .46575 .48779 Mtetra
.46575 .48779 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47128 Mtetra
.51767 .47128 .52336 .47741 .53384 .47409 .52817 .46794 Mtetra
.52817 .46794 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44763 Mtetra
.59205 .44763 .59755 .45393 .60832 .45052 .60284 .4442 Mtetra
.60284 .4442 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43382 Mtetra
.63546 .43382 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42684 Mtetra
.65743 .42684 .66276 .43329 .67377 .4298 .66847 .42333 Mtetra
.66847 .42333 .67377 .4298 .68483 .4263 .67956 .4198 Mtetra
.67956 .4198 .68483 .4263 .69594 .42279 .69069 .41626 Mtetra
.69069 .41626 .69594 .42279 .70708 .41926 .70187 .41271 Mtetra
.70187 .41271 .70708 .41926 .71827 .41572 .71309 .40914 Mtetra
.71309 .40914 .71827 .41572 .72951 .41216 .72436 .40556 Mtetra
.72436 .40556 .72951 .41216 .74079 .40859 .73566 .40196 Mtetra
.73566 .40196 .74079 .40859 .75211 .40501 .74702 .39835 Mtetra
.74702 .39835 .75211 .40501 .76348 .40141 .75842 .39473 Mtetra
.75842 .39473 .76348 .40141 .77489 .39779 .76987 .39109 Mtetra
.76987 .39109 .77489 .39779 .78635 .39417 .78136 .38743 Mtetra
.78136 .38743 .78635 .39417 .79786 .39053 .79289 .38376 Mtetra
.79289 .38376 .79786 .39053 .80941 .38687 .80448 .38008 Mtetra
.80448 .38008 .80941 .38687 .821 .3832 .81611 .37638 Mtetra
.81611 .37638 .821 .3832 .83265 .37951 .82779 .37267 Mtetra
.82779 .37267 .83265 .37951 .84434 .37581 .83951 .36894 Mtetra
.83951 .36894 .84434 .37581 .85608 .3721 .85128 .3652 Mtetra
.85128 .3652 .85608 .3721 .86786 .36837 .8631 .36144 Mtetra
.23264 .55431 .23902 .55988 .24848 .55687 .24213 .55128 Mtetra
.24213 .55128 .24848 .55687 .25798 .55385 .25165 .54824 Mtetra
.25165 .54824 .25798 .55385 .26751 .55082 .2612 .54519 Mtetra
.2612 .54519 .26751 .55082 .27708 .54777 .27079 .54213 Mtetra
.27079 .54213 .27708 .54777 .28669 .54472 .28041 .53905 Mtetra
.28041 .53905 .28669 .54472 .29632 .54166 .29007 .53597 Mtetra
.29007 .53597 .29632 .54166 .306 .53858 .29977 .53287 Mtetra
.29977 .53287 .306 .53858 .31571 .53549 .3095 .52976 Mtetra
.3095 .52976 .31571 .53549 .32545 .53239 .31926 .52664 Mtetra
.31926 .52664 .32545 .53239 .33523 .52928 .32907 .52351 Mtetra
.32907 .52351 .33523 .52928 .34505 .52616 .33891 .52037 Mtetra
.33891 .52037 .34505 .52616 .3549 .52303 .34878 .51722 Mtetra
.34878 .51722 .3549 .52303 .36479 .51989 .35869 .51405 Mtetra
.35869 .51405 .36479 .51989 .37472 .51673 .36864 .51087 Mtetra
.36864 .51087 .37472 .51673 .38468 .51356 .37863 .50768 Mtetra
.37863 .50768 .38468 .51356 .39468 .51038 .38865 .50448 Mtetra
.38865 .50448 .39468 .51038 .40472 .50719 .39872 .50127 Mtetra
.39872 .50127 .40472 .50719 .4148 .50399 .40882 .49804 Mtetra
.40882 .49804 .4148 .50399 .42491 .50077 .41895 .4948 Mtetra
.41895 .4948 .42491 .50077 .43506 .49754 .42913 .49155 Mtetra
.42913 .49155 .43506 .49754 .44525 .4943 .43934 .48829 Mtetra
.43934 .48829 .44525 .4943 .45548 .49105 .4496 .48501 Mtetra
.4496 .48501 .45548 .49105 .46575 .48779 .45989 .48173 Mtetra
.45989 .48173 .46575 .48779 .47605 .48451 .47022 .47843 Mtetra
.47022 .47843 .47605 .48451 .4864 .48122 .48059 .47511 Mtetra
.48059 .47511 .4864 .48122 .49678 .47792 .491 .47179 Mtetra
.491 .47179 .49678 .47792 .50721 .4746 .50145 .46845 Mtetra
.50145 .46845 .50721 .4746 .51767 .47128 .51194 .4651 Mtetra
.51194 .4651 .51767 .47128 .52817 .46794 .52247 .46174 Mtetra
.52247 .46174 .52817 .46794 .53872 .46458 .53304 .45836 Mtetra
.53304 .45836 .53872 .46458 .5493 .46122 .54365 .45497 Mtetra
.54365 .45497 .5493 .46122 .55993 .45784 .5543 .45157 Mtetra
.5543 .45157 .55993 .45784 .57059 .45445 .565 .44815 Mtetra
.565 .44815 .57059 .45445 .5813 .45104 .57573 .44472 Mtetra
.57573 .44472 .5813 .45104 .59205 .44763 .58651 .44128 Mtetra
.58651 .44128 .59205 .44763 .60284 .4442 .59732 .43783 Mtetra
.59732 .43783 .60284 .4442 .61367 .44075 .60819 .43436 Mtetra
.60819 .43436 .61367 .44075 .62455 .43729 .61909 .43087 Mtetra
.61909 .43087 .62455 .43729 .63546 .43382 .63003 .42738 Mtetra
.63003 .42738 .63546 .43382 .64642 .43034 .64102 .42387 Mtetra
.64102 .42387 .64642 .43034 .65743 .42684 .65205 .42034 Mtetra
.65205 .42034 .65743 .42684 .66847 .42333 .66313 .41681 Mtetra
.66313 .41681 .66847 .42333 .67956 .4198 .67425 .41326 Mtetra
.67425 .41326 .67956 .4198 .69069 .41626 .68541 .40969 Mtetra
.68541 .40969 .69069 .41626 .70187 .41271 .69662 .40611 Mtetra
.69662 .40611 .70187 .41271 .71309 .40914 .70787 .40252 Mtetra
.70787 .40252 .71309 .40914 .72436 .40556 .71917 .39891 Mtetra
.71917 .39891 .72436 .40556 .73566 .40196 .73051 .39529 Mtetra
.73051 .39529 .73566 .40196 .74702 .39835 .74189 .39165 Mtetra
.74189 .39165 .74702 .39835 .75842 .39473 .75332 .388 Mtetra
.75332 .388 .75842 .39473 .76987 .39109 .7648 .38433 Mtetra
.7648 .38433 .76987 .39109 .78136 .38743 .77633 .38065 Mtetra
.77633 .38065 .78136 .38743 .79289 .38376 .7879 .37695 Mtetra
.7879 .37695 .79289 .38376 .80448 .38008 .79951 .37324 Mtetra
.79951 .37324 .80448 .38008 .81611 .37638 .81118 .36952 Mtetra
.81118 .36952 .81611 .37638 .82779 .37267 .82289 .36578 Mtetra
.82289 .36578 .82779 .37267 .83951 .36894 .83465 .36202 Mtetra
.83465 .36202 .83951 .36894 .85128 .3652 .84645 .35825 Mtetra
.84645 .35825 .85128 .3652 .8631 .36144 .85831 .35446 Mtetra
.22623 .54871 .23264 .55431 .24213 .55128 .23573 .54566 Mtetra
.23573 .54566 .24213 .55128 .25165 .54824 .24527 .5426 Mtetra
.24527 .5426 .25165 .54824 .2612 .54519 .25484 .53953 Mtetra
.25484 .53953 .2612 .54519 .27079 .54213 .26445 .53644 Mtetra
.26445 .53644 .27079 .54213 .28041 .53905 .2741 .53335 Mtetra
.2741 .53335 .28041 .53905 .29007 .53597 .28378 .53024 Mtetra
.28378 .53024 .29007 .53597 .29977 .53287 .2935 .52712 Mtetra
.2935 .52712 .29977 .53287 .3095 .52976 .30325 .524 Mtetra
.30325 .524 .3095 .52976 .31926 .52664 .31304 .52085 Mtetra
.31304 .52085 .31926 .52664 .32907 .52351 .32286 .5177 Mtetra
.32286 .5177 .32907 .52351 .33891 .52037 .33272 .51454 Mtetra
.33272 .51454 .33891 .52037 .34878 .51722 .34262 .51136 Mtetra
.34262 .51136 .34878 .51722 .35869 .51405 .35256 .50817 Mtetra
.35256 .50817 .35869 .51405 .36864 .51087 .36253 .50497 Mtetra
.36253 .50497 .36864 .51087 .37863 .50768 .37254 .50176 Mtetra
.37254 .50176 .37863 .50768 .38865 .50448 .38258 .49854 Mtetra
.38258 .49854 .38865 .50448 .39872 .50127 .39267 .4953 Mtetra
.39267 .4953 .39872 .50127 .40882 .49804 .40279 .49205 Mtetra
.40279 .49205 .40882 .49804 .41895 .4948 .41295 .48879 Mtetra
.41295 .48879 .41895 .4948 .42913 .49155 .42315 .48552 Mtetra
.42315 .48552 .42913 .49155 .43934 .48829 .43339 .48223 Mtetra
.43339 .48223 .43934 .48829 .4496 .48501 .44367 .47893 Mtetra
.44367 .47893 .4496 .48501 .45989 .48173 .45399 .47562 Mtetra
.45399 .47562 .45989 .48173 .47022 .47843 .46434 .4723 Mtetra
.46434 .4723 .47022 .47843 .48059 .47511 .47474 .46897 Mtetra
.47474 .46897 .48059 .47511 .491 .47179 .48517 .46562 Mtetra
.48517 .46562 .491 .47179 .50145 .46845 .49565 .46226 Mtetra
.49565 .46226 .50145 .46845 .51194 .4651 .50617 .45888 Mtetra
.50617 .45888 .51194 .4651 .52247 .46174 .51672 .45549 Mtetra
.51672 .45549 .52247 .46174 .53304 .45836 .52732 .45209 Mtetra
.52732 .45209 .53304 .45836 .54365 .45497 .53796 .44868 Mtetra
.53796 .44868 .54365 .45497 .5543 .45157 .54864 .44525 Mtetra
.54864 .44525 .5543 .45157 .565 .44815 .55936 .44181 Mtetra
.55936 .44181 .565 .44815 .57573 .44472 .57012 .43836 Mtetra
.57012 .43836 .57573 .44472 .58651 .44128 .58092 .43489 Mtetra
.58092 .43489 .58651 .44128 .59732 .43783 .59177 .43141 Mtetra
.59177 .43141 .59732 .43783 .60819 .43436 .60266 .42792 Mtetra
.60266 .42792 .60819 .43436 .61909 .43087 .61359 .42441 Mtetra
.61359 .42441 .61909 .43087 .63003 .42738 .62456 .42089 Mtetra
.62456 .42089 .63003 .42738 .64102 .42387 .63558 .41735 Mtetra
.63558 .41735 .64102 .42387 .65205 .42034 .64664 .4138 Mtetra
.64664 .4138 .65205 .42034 .66313 .41681 .65775 .41024 Mtetra
.65775 .41024 .66313 .41681 .67425 .41326 .6689 .40666 Mtetra
.6689 .40666 .67425 .41326 .68541 .40969 .68009 .40307 Mtetra
.68009 .40307 .68541 .40969 .69662 .40611 .69133 .39946 Mtetra
.69133 .39946 .69662 .40611 .70787 .40252 .70261 .39584 Mtetra
.70261 .39584 .70787 .40252 .71917 .39891 .71394 .39221 Mtetra
.71394 .39221 .71917 .39891 .73051 .39529 .72531 .38856 Mtetra
.72531 .38856 .73051 .39529 .74189 .39165 .73673 .3849 Mtetra
.73673 .3849 .74189 .39165 .75332 .388 .74819 .38122 Mtetra
.74819 .38122 .75332 .388 .7648 .38433 .7597 .37752 Mtetra
.7597 .37752 .7648 .38433 .77633 .38065 .77126 .37381 Mtetra
.77126 .37381 .77633 .38065 .7879 .37695 .78286 .37009 Mtetra
.78286 .37009 .7879 .37695 .79951 .37324 .79451 .36635 Mtetra
.79451 .36635 .79951 .37324 .81118 .36952 .80621 .3626 Mtetra
.80621 .3626 .81118 .36952 .82289 .36578 .81795 .35883 Mtetra
.81795 .35883 .82289 .36578 .83465 .36202 .82975 .35505 Mtetra
.82975 .35505 .83465 .36202 .84645 .35825 .84159 .35125 Mtetra
.84159 .35125 .84645 .35825 .85831 .35446 .85348 .34743 Mtetra
.21976 .54307 .22623 .54871 .23573 .54566 .22929 .54 Mtetra
.22929 .54 .23573 .54566 .24527 .5426 .23885 .53692 Mtetra
.23885 .53692 .24527 .5426 .25484 .53953 .24844 .53383 Mtetra
.24844 .53383 .25484 .53953 .26445 .53644 .25807 .53072 Mtetra
.25807 .53072 .26445 .53644 .2741 .53335 .26774 .52761 Mtetra
.26774 .52761 .2741 .53335 .28378 .53024 .27744 .52448 Mtetra
.27744 .52448 .28378 .53024 .2935 .52712 .28718 .52134 Mtetra
.28718 .52134 .2935 .52712 .30325 .524 .29695 .51819 Mtetra
.29695 .51819 .30325 .524 .31304 .52085 .30676 .51503 Mtetra
.30676 .51503 .31304 .52085 .32286 .5177 .31661 .51185 Mtetra
.31661 .51185 .32286 .5177 .33272 .51454 .3265 .50866 Mtetra
.3265 .50866 .33272 .51454 .34262 .51136 .33642 .50547 Mtetra
.33642 .50547 .34262 .51136 .35256 .50817 .34637 .50226 Mtetra
.34637 .50226 .35256 .50817 .36253 .50497 .35637 .49903 Mtetra
.35637 .49903 .36253 .50497 .37254 .50176 .3664 .4958 Mtetra
.3664 .4958 .37254 .50176 .38258 .49854 .37647 .49255 Mtetra
.37647 .49255 .38258 .49854 .39267 .4953 .38658 .48929 Mtetra
.38658 .48929 .39267 .4953 .40279 .49205 .39673 .48602 Mtetra
.39673 .48602 .40279 .49205 .41295 .48879 .40691 .48274 Mtetra
.40691 .48274 .41295 .48879 .42315 .48552 .41714 .47944 Mtetra
.41714 .47944 .42315 .48552 .43339 .48223 .4274 .47613 Mtetra
.4274 .47613 .43339 .48223 .44367 .47893 .4377 .47281 Mtetra
.4377 .47281 .44367 .47893 .45399 .47562 .44805 .46948 Mtetra
.44805 .46948 .45399 .47562 .46434 .4723 .45843 .46613 Mtetra
.45843 .46613 .46434 .4723 .47474 .46897 .46885 .46277 Mtetra
.46885 .46277 .47474 .46897 .48517 .46562 .47931 .4594 Mtetra
.47931 .4594 .48517 .46562 .49565 .46226 .48981 .45602 Mtetra
.48981 .45602 .49565 .46226 .50617 .45888 .50035 .45262 Mtetra
.50035 .45262 .50617 .45888 .51672 .45549 .51093 .44921 Mtetra
.51093 .44921 .51672 .45549 .52732 .45209 .52156 .44578 Mtetra
.52156 .44578 .52732 .45209 .53796 .44868 .53222 .44234 Mtetra
.53222 .44234 .53796 .44868 .54864 .44525 .54293 .43889 Mtetra
.54293 .43889 .54864 .44525 .55936 .44181 .55368 .43543 Mtetra
.55368 .43543 .55936 .44181 .57012 .43836 .56447 .43195 Mtetra
.56447 .43195 .57012 .43836 .58092 .43489 .5753 .42846 Mtetra
.5753 .42846 .58092 .43489 .59177 .43141 .58617 .42495 Mtetra
.58617 .42495 .59177 .43141 .60266 .42792 .59709 .42143 Mtetra
.59709 .42143 .60266 .42792 .61359 .42441 .60805 .4179 Mtetra
.60805 .4179 .61359 .42441 .62456 .42089 .61906 .41435 Mtetra
.61906 .41435 .62456 .42089 .63558 .41735 .6301 .41079 Mtetra
.6301 .41079 .63558 .41735 .64664 .4138 .64119 .40721 Mtetra
.64119 .40721 .64664 .4138 .65775 .41024 .65233 .40362 Mtetra
.65233 .40362 .65775 .41024 .6689 .40666 .66351 .40002 Mtetra
.66351 .40002 .6689 .40666 .68009 .40307 .67473 .3964 Mtetra
.67473 .3964 .68009 .40307 .69133 .39946 .686 .39277 Mtetra
.686 .39277 .69133 .39946 .70261 .39584 .69731 .38912 Mtetra
.69731 .38912 .70261 .39584 .71394 .39221 .70867 .38546 Mtetra
.70867 .38546 .71394 .39221 .72531 .38856 .72007 .38178 Mtetra
.72007 .38178 .72531 .38856 .73673 .3849 .73152 .37809 Mtetra
.73152 .37809 .73673 .3849 .74819 .38122 .74302 .37439 Mtetra
.74302 .37439 .74819 .38122 .7597 .37752 .75456 .37067 Mtetra
.75456 .37067 .7597 .37752 .77126 .37381 .76615 .36693 Mtetra
.76615 .36693 .77126 .37381 .78286 .37009 .77779 .36318 Mtetra
.77779 .36318 .78286 .37009 .79451 .36635 .78947 .35941 Mtetra
.78947 .35941 .79451 .36635 .80621 .3626 .8012 .35563 Mtetra
.8012 .35563 .80621 .3626 .81795 .35883 .81298 .35183 Mtetra
.81298 .35183 .81795 .35883 .82975 .35505 .82481 .34802 Mtetra
.82481 .34802 .82975 .35505 .84159 .35125 .83668 .34419 Mtetra
.83668 .34419 .84159 .35125 .85348 .34743 .84861 .34035 Mtetra
.21326 .53739 .21976 .54307 .22929 .54 .2228 .5343 Mtetra
.2228 .5343 .22929 .54 .23885 .53692 .23238 .5312 Mtetra
.23238 .5312 .23885 .53692 .24844 .53383 .242 .52809 Mtetra
.242 .52809 .24844 .53383 .25807 .53072 .25165 .52496 Mtetra
.25165 .52496 .25807 .53072 .26774 .52761 .26134 .52182 Mtetra
.26134 .52182 .26774 .52761 .27744 .52448 .27106 .51867 Mtetra
.27106 .51867 .27744 .52448 .28718 .52134 .28082 .51551 Mtetra
.28082 .51551 .28718 .52134 .29695 .51819 .29062 .51234 Mtetra
.29062 .51234 .29695 .51819 .30676 .51503 .30045 .50916 Mtetra
.30045 .50916 .30676 .51503 .31661 .51185 .31032 .50596 Mtetra
.31032 .50596 .31661 .51185 .3265 .50866 .32022 .50275 Mtetra
.32022 .50275 .3265 .50866 .33642 .50547 .33017 .49953 Mtetra
.33017 .49953 .33642 .50547 .34637 .50226 .34015 .4963 Mtetra
.34015 .4963 .34637 .50226 .35637 .49903 .35017 .49305 Mtetra
.35017 .49305 .35637 .49903 .3664 .4958 .36022 .4898 Mtetra
.36022 .4898 .3664 .4958 .37647 .49255 .37032 .48653 Mtetra
.37032 .48653 .37647 .49255 .38658 .48929 .38045 .48325 Mtetra
.38045 .48325 .38658 .48929 .39673 .48602 .39062 .47995 Mtetra
.39062 .47995 .39673 .48602 .40691 .48274 .40083 .47664 Mtetra
.40083 .47664 .40691 .48274 .41714 .47944 .41108 .47333 Mtetra
.41108 .47333 .41714 .47944 .4274 .47613 .42137 .46999 Mtetra
.42137 .46999 .4274 .47613 .4377 .47281 .43169 .46665 Mtetra
.43169 .46665 .4377 .47281 .44805 .46948 .44206 .46329 Mtetra
.44206 .46329 .44805 .46948 .45843 .46613 .45247 .45992 Mtetra
.45247 .45992 .45843 .46613 .46885 .46277 .46291 .45654 Mtetra
.46291 .45654 .46885 .46277 .47931 .4594 .4734 .45314 Mtetra
.4734 .45314 .47931 .4594 .48981 .45602 .48393 .44973 Mtetra
.48393 .44973 .48981 .45602 .50035 .45262 .4945 .44631 Mtetra
.4945 .44631 .50035 .45262 .51093 .44921 .50511 .44287 Mtetra
.50511 .44287 .51093 .44921 .52156 .44578 .51576 .43942 Mtetra
.51576 .43942 .52156 .44578 .53222 .44234 .52645 .43596 Mtetra
.52645 .43596 .53222 .44234 .54293 .43889 .53718 .43248 Mtetra
.53718 .43248 .54293 .43889 .55368 .43543 .54796 .42899 Mtetra
.54796 .42899 .55368 .43543 .56447 .43195 .55878 .42549 Mtetra
.55878 .42549 .56447 .43195 .5753 .42846 .56964 .42197 Mtetra
.56964 .42197 .5753 .42846 .58617 .42495 .58054 .41844 Mtetra
.58054 .41844 .58617 .42495 .59709 .42143 .59149 .4149 Mtetra
.59149 .4149 .59709 .42143 .60805 .4179 .60247 .41134 Mtetra
.60247 .41134 .60805 .4179 .61906 .41435 .61351 .40776 Mtetra
.61351 .40776 .61906 .41435 .6301 .41079 .62458 .40418 Mtetra
.62458 .40418 .6301 .41079 .64119 .40721 .6357 .40057 Mtetra
.6357 .40057 .64119 .40721 .65233 .40362 .64687 .39696 Mtetra
.64687 .39696 .65233 .40362 .66351 .40002 .65808 .39333 Mtetra
.65808 .39333 .66351 .40002 .67473 .3964 .66933 .38968 Mtetra
.66933 .38968 .67473 .3964 .686 .39277 .68063 .38602 Mtetra
.68063 .38602 .686 .39277 .69731 .38912 .69198 .38235 Mtetra
.69198 .38235 .69731 .38912 .70867 .38546 .70336 .37866 Mtetra
.70336 .37866 .70867 .38546 .72007 .38178 .7148 .37496 Mtetra
.7148 .37496 .72007 .38178 .73152 .37809 .72628 .37124 Mtetra
.72628 .37124 .73152 .37809 .74302 .37439 .73781 .3675 Mtetra
.73781 .3675 .74302 .37439 .75456 .37067 .74939 .36376 Mtetra
.74939 .36376 .75456 .37067 .76615 .36693 .76101 .35999 Mtetra
.76101 .35999 .76615 .36693 .77779 .36318 .77268 .35621 Mtetra
.77268 .35621 .77779 .36318 .78947 .35941 .78439 .35242 Mtetra
.78439 .35242 .78947 .35941 .8012 .35563 .79616 .34861 Mtetra
.79616 .34861 .8012 .35563 .81298 .35183 .80797 .34478 Mtetra
.80797 .34478 .81298 .35183 .82481 .34802 .81983 .34094 Mtetra
.81983 .34094 .82481 .34802 .83668 .34419 .83174 .33708 Mtetra
.83174 .33708 .83668 .34419 .84861 .34035 .8437 .33321 Mtetra
.20671 .53168 .21326 .53739 .2228 .5343 .21628 .52857 Mtetra
.21628 .52857 .2228 .5343 .23238 .5312 .22588 .52544 Mtetra
.22588 .52544 .23238 .5312 .242 .52809 .23551 .52231 Mtetra
.23551 .52231 .242 .52809 .25165 .52496 .24519 .51916 Mtetra
.24519 .51916 .25165 .52496 .26134 .52182 .25489 .516 Mtetra
.25489 .516 .26134 .52182 .27106 .51867 .26464 .51283 Mtetra
.26464 .51283 .27106 .51867 .28082 .51551 .27442 .50965 Mtetra
.27442 .50965 .28082 .51551 .29062 .51234 .28424 .50645 Mtetra
.28424 .50645 .29062 .51234 .30045 .50916 .29409 .50324 Mtetra
.29409 .50324 .30045 .50916 .31032 .50596 .30398 .50003 Mtetra
.30398 .50003 .31032 .50596 .32022 .50275 .31391 .4968 Mtetra
.31391 .4968 .32022 .50275 .33017 .49953 .32388 .49355 Mtetra
.32388 .49355 .33017 .49953 .34015 .4963 .33388 .4903 Mtetra
.33388 .4903 .34015 .4963 .35017 .49305 .34392 .48703 Mtetra
.34392 .48703 .35017 .49305 .36022 .4898 .354 .48375 Mtetra
.354 .48375 .36022 .4898 .37032 .48653 .36412 .48046 Mtetra
.36412 .48046 .37032 .48653 .38045 .48325 .37428 .47715 Mtetra
.37428 .47715 .38045 .48325 .39062 .47995 .38447 .47384 Mtetra
.38447 .47384 .39062 .47995 .40083 .47664 .3947 .47051 Mtetra
.3947 .47051 .40083 .47664 .41108 .47333 .40498 .46716 Mtetra
.40498 .46716 .41108 .47333 .42137 .46999 .41529 .46381 Mtetra
.41529 .46381 .42137 .46999 .43169 .46665 .42564 .46044 Mtetra
.42564 .46044 .43169 .46665 .44206 .46329 .43603 .45706 Mtetra
.43603 .45706 .44206 .46329 .45247 .45992 .44647 .45366 Mtetra
.44647 .45366 .45247 .45992 .46291 .45654 .45694 .45026 Mtetra
.45694 .45026 .46291 .45654 .4734 .45314 .46745 .44684 Mtetra
.46745 .44684 .4734 .45314 .48393 .44973 .47801 .4434 Mtetra
.47801 .4434 .48393 .44973 .4945 .44631 .4886 .43995 Mtetra
.4886 .43995 .4945 .44631 .50511 .44287 .49924 .43649 Mtetra
.49924 .43649 .50511 .44287 .51576 .43942 .50991 .43302 Mtetra
.50991 .43302 .51576 .43942 .52645 .43596 .52063 .42953 Mtetra
.52063 .42953 .52645 .43596 .53718 .43248 .53139 .42603 Mtetra
.53139 .42603 .53718 .43248 .54796 .42899 .5422 .42251 Mtetra
.5422 .42251 .54796 .42899 .55878 .42549 .55304 .41899 Mtetra
.55304 .41899 .55878 .42549 .56964 .42197 .56393 .41544 Mtetra
.56393 .41544 .56964 .42197 .58054 .41844 .57486 .41189 Mtetra
.57486 .41189 .58054 .41844 .59149 .4149 .58584 .40831 Mtetra
.58584 .40831 .59149 .4149 .60247 .41134 .59686 .40473 Mtetra
.59686 .40473 .60247 .41134 .61351 .40776 .60792 .40113 Mtetra
.60792 .40113 .61351 .40776 .62458 .40418 .61902 .39752 Mtetra
.61902 .39752 .62458 .40418 .6357 .40057 .63017 .39389 Mtetra
.63017 .39389 .6357 .40057 .64687 .39696 .64137 .39025 Mtetra
.64137 .39025 .64687 .39696 .65808 .39333 .65261 .38659 Mtetra
.65261 .38659 .65808 .39333 .66933 .38968 .66389 .38292 Mtetra
.66389 .38292 .66933 .38968 .68063 .38602 .67522 .37923 Mtetra
.67522 .37923 .68063 .38602 .69198 .38235 .6866 .37553 Mtetra
.6866 .37553 .69198 .38235 .70336 .37866 .69802 .37181 Mtetra
.69802 .37181 .70336 .37866 .7148 .37496 .70949 .36808 Mtetra
.70949 .36808 .7148 .37496 .72628 .37124 .721 .36433 Mtetra
.721 .36433 .72628 .37124 .73781 .3675 .73256 .36057 Mtetra
.73256 .36057 .73781 .3675 .74939 .36376 .74417 .35679 Mtetra
.74417 .35679 .74939 .36376 .76101 .35999 .75583 .353 Mtetra
.75583 .353 .76101 .35999 .77268 .35621 .76753 .34919 Mtetra
.76753 .34919 .77268 .35621 .78439 .35242 .77928 .34537 Mtetra
.77928 .34537 .78439 .35242 .79616 .34861 .79108 .34153 Mtetra
.79108 .34153 .79616 .34861 .80797 .34478 .80293 .33768 Mtetra
.80293 .33768 .80797 .34478 .81983 .34094 .81482 .33381 Mtetra
.81482 .33381 .81983 .34094 .83174 .33708 .82677 .32992 Mtetra
.82677 .32992 .83174 .33708 .8437 .33321 .83876 .32602 Mtetra
.20012 .52592 .20671 .53168 .21628 .52857 .2097 .52279 Mtetra
.2097 .52279 .21628 .52857 .22588 .52544 .21932 .51964 Mtetra
.21932 .51964 .22588 .52544 .23551 .52231 .22898 .51649 Mtetra
.22898 .51649 .23551 .52231 .24519 .51916 .23867 .51332 Mtetra
.23867 .51332 .24519 .51916 .25489 .516 .2484 .51014 Mtetra
.2484 .51014 .25489 .516 .26464 .51283 .25817 .50694 Mtetra
.25817 .50694 .26464 .51283 .27442 .50965 .26797 .50374 Mtetra
.26797 .50374 .27442 .50965 .28424 .50645 .27781 .50052 Mtetra
.27781 .50052 .28424 .50645 .29409 .50324 .28769 .49729 Mtetra
.28769 .49729 .29409 .50324 .30398 .50003 .2976 .49405 Mtetra
.2976 .49405 .30398 .50003 .31391 .4968 .30755 .4908 Mtetra
.30755 .4908 .31391 .4968 .32388 .49355 .31754 .48753 Mtetra
.31754 .48753 .32388 .49355 .33388 .4903 .32757 .48426 Mtetra
.32757 .48426 .33388 .4903 .34392 .48703 .33763 .48097 Mtetra
.33763 .48097 .34392 .48703 .354 .48375 .34774 .47766 Mtetra
.34774 .47766 .354 .48375 .36412 .48046 .35788 .47435 Mtetra
.35788 .47435 .36412 .48046 .37428 .47715 .36806 .47102 Mtetra
.36806 .47102 .37428 .47715 .38447 .47384 .37828 .46768 Mtetra
.37828 .46768 .38447 .47384 .3947 .47051 .38854 .46433 Mtetra
.38854 .46433 .3947 .47051 .40498 .46716 .39883 .46096 Mtetra
.39883 .46096 .40498 .46716 .41529 .46381 .40917 .45758 Mtetra
.40917 .45758 .41529 .46381 .42564 .46044 .41955 .45419 Mtetra
.41955 .45419 .42564 .46044 .43603 .45706 .42996 .45078 Mtetra
.42996 .45078 .43603 .45706 .44647 .45366 .44042 .44736 Mtetra
.44042 .44736 .44647 .45366 .45694 .45026 .45092 .44393 Mtetra
.45092 .44393 .45694 .45026 .46745 .44684 .46146 .44049 Mtetra
.46146 .44049 .46745 .44684 .47801 .4434 .47204 .43703 Mtetra
.47204 .43703 .47801 .4434 .4886 .43995 .48266 .43355 Mtetra
.48266 .43355 .4886 .43995 .49924 .43649 .49332 .43007 Mtetra
.49332 .43007 .49924 .43649 .50991 .43302 .50403 .42657 Mtetra
.50403 .42657 .50991 .43302 .52063 .42953 .51477 .42306 Mtetra
.51477 .42306 .52063 .42953 .53139 .42603 .52556 .41953 Mtetra
.52556 .41953 .53139 .42603 .5422 .42251 .53639 .41599 Mtetra
.53639 .41599 .5422 .42251 .55304 .41899 .54727 .41243 Mtetra
.54727 .41243 .55304 .41899 .56393 .41544 .55818 .40886 Mtetra
.55818 .40886 .56393 .41544 .57486 .41189 .56914 .40528 Mtetra
.56914 .40528 .57486 .41189 .58584 .40831 .58015 .40168 Mtetra
.58015 .40168 .58584 .40831 .59686 .40473 .5912 .39807 Mtetra
.5912 .39807 .59686 .40473 .60792 .40113 .60229 .39445 Mtetra
.60229 .39445 .60792 .40113 .61902 .39752 .61342 .39081 Mtetra
.61342 .39081 .61902 .39752 .63017 .39389 .6246 .38715 Mtetra
.6246 .38715 .63017 .39389 .64137 .39025 .63583 .38348 Mtetra
.63583 .38348 .64137 .39025 .65261 .38659 .6471 .3798 Mtetra
.6471 .3798 .65261 .38659 .66389 .38292 .65841 .3761 Mtetra
.65841 .3761 .66389 .38292 .67522 .37923 .66977 .37238 Mtetra
.66977 .37238 .67522 .37923 .6866 .37553 .68118 .36866 Mtetra
.68118 .36866 .6866 .37553 .69802 .37181 .69263 .36491 Mtetra
.69263 .36491 .69802 .37181 .70949 .36808 .70413 .36115 Mtetra
.70413 .36115 .70949 .36808 .721 .36433 .71568 .35738 Mtetra
.71568 .35738 .721 .36433 .73256 .36057 .72727 .35359 Mtetra
.72727 .35359 .73256 .36057 .74417 .35679 .73892 .34978 Mtetra
.73892 .34978 .74417 .35679 .75583 .353 .7506 .34596 Mtetra
.7506 .34596 .75583 .353 .76753 .34919 .76234 .34212 Mtetra
.76234 .34212 .76753 .34919 .77928 .34537 .77412 .33827 Mtetra
.77412 .33827 .77928 .34537 .79108 .34153 .78596 .3344 Mtetra
.78596 .3344 .79108 .34153 .80293 .33768 .79784 .33052 Mtetra
.79784 .33052 .80293 .33768 .81482 .33381 .80977 .32662 Mtetra
.80977 .32662 .81482 .33381 .82677 .32992 .82175 .3227 Mtetra
.82175 .3227 .82677 .32992 .83876 .32602 .83378 .31877 Mtetra
.19348 .52013 .20012 .52592 .2097 .52279 .20308 .51697 Mtetra
.20308 .51697 .2097 .52279 .21932 .51964 .21272 .51381 Mtetra
.21272 .51381 .21932 .51964 .22898 .51649 .2224 .51063 Mtetra
.2224 .51063 .22898 .51649 .23867 .51332 .23212 .50744 Mtetra
.23212 .50744 .23867 .51332 .2484 .51014 .24187 .50423 Mtetra
.24187 .50423 .2484 .51014 .25817 .50694 .25166 .50102 Mtetra
.25166 .50102 .25817 .50694 .26797 .50374 .26148 .49779 Mtetra
.26148 .49779 .26797 .50374 .27781 .50052 .27134 .49455 Mtetra
.27134 .49455 .27781 .50052 .28769 .49729 .28124 .4913 Mtetra
.28124 .4913 .28769 .49729 .2976 .49405 .29118 .48804 Mtetra
.29118 .48804 .2976 .49405 .30755 .4908 .30115 .48476 Mtetra
.30115 .48476 .30755 .4908 .31754 .48753 .31116 .48147 Mtetra
.31116 .48147 .31754 .48753 .32757 .48426 .32121 .47817 Mtetra
.32121 .47817 .32757 .48426 .33763 .48097 .3313 .47486 Mtetra
.3313 .47486 .33763 .48097 .34774 .47766 .34143 .47153 Mtetra
.34143 .47153 .34774 .47766 .35788 .47435 .35159 .46819 Mtetra
.35159 .46819 .35788 .47435 .36806 .47102 .3618 .46484 Mtetra
.3618 .46484 .36806 .47102 .37828 .46768 .37204 .46148 Mtetra
.37204 .46148 .37828 .46768 .38854 .46433 .38232 .4581 Mtetra
.38232 .4581 .38854 .46433 .39883 .46096 .39264 .45471 Mtetra
.39264 .45471 .39883 .46096 .40917 .45758 .40301 .45131 Mtetra
.40301 .45131 .40917 .45758 .41955 .45419 .41341 .44789 Mtetra
.41341 .44789 .41955 .45419 .42996 .45078 .42385 .44446 Mtetra
.42385 .44446 .42996 .45078 .44042 .44736 .43434 .44102 Mtetra
.43434 .44102 .44042 .44736 .45092 .44393 .44486 .43756 Mtetra
.44486 .43756 .45092 .44393 .46146 .44049 .45542 .43409 Mtetra
.45542 .43409 .46146 .44049 .47204 .43703 .46603 .43061 Mtetra
.46603 .43061 .47204 .43703 .48266 .43355 .47668 .42711 Mtetra
.47668 .42711 .48266 .43355 .49332 .43007 .48737 .4236 Mtetra
.48737 .4236 .49332 .43007 .50403 .42657 .4981 .42007 Mtetra
.4981 .42007 .50403 .42657 .51477 .42306 .50887 .41653 Mtetra
.50887 .41653 .51477 .42306 .52556 .41953 .51969 .41298 Mtetra
.51969 .41298 .52556 .41953 .53639 .41599 .53055 .40941 Mtetra
.53055 .40941 .53639 .41599 .54727 .41243 .54145 .40583 Mtetra
.54145 .40583 .54727 .41243 .55818 .40886 .5524 .40224 Mtetra
.5524 .40224 .55818 .40886 .56914 .40528 .56338 .39863 Mtetra
.56338 .39863 .56914 .40528 .58015 .40168 .57442 .39501 Mtetra
.57442 .39501 .58015 .40168 .5912 .39807 .58549 .39137 Mtetra
.58549 .39137 .5912 .39807 .60229 .39445 .59661 .38772 Mtetra
.59661 .38772 .60229 .39445 .61342 .39081 .60778 .38405 Mtetra
.60778 .38405 .61342 .39081 .6246 .38715 .61899 .38037 Mtetra
.61899 .38037 .6246 .38715 .63583 .38348 .63025 .37667 Mtetra
.63025 .37667 .63583 .38348 .6471 .3798 .64155 .37296 Mtetra
.64155 .37296 .6471 .3798 .65841 .3761 .65289 .36923 Mtetra
.65289 .36923 .65841 .3761 .66977 .37238 .66429 .36549 Mtetra
.66429 .36549 .66977 .37238 .68118 .36866 .67572 .36173 Mtetra
.67572 .36173 .68118 .36866 .69263 .36491 .68721 .35796 Mtetra
.68721 .35796 .69263 .36491 .70413 .36115 .69874 .35417 Mtetra
.69874 .35417 .70413 .36115 .71568 .35738 .71032 .35037 Mtetra
.71032 .35037 .71568 .35738 .72727 .35359 .72195 .34655 Mtetra
.72195 .34655 .72727 .35359 .73892 .34978 .73362 .34271 Mtetra
.73362 .34271 .73892 .34978 .7506 .34596 .74534 .33886 Mtetra
.74534 .33886 .7506 .34596 .76234 .34212 .75711 .335 Mtetra
.75711 .335 .76234 .34212 .77412 .33827 .76893 .33112 Mtetra
.76893 .33112 .77412 .33827 .78596 .3344 .7808 .32722 Mtetra
.7808 .32722 .78596 .3344 .79784 .33052 .79272 .3233 Mtetra
.79272 .3233 .79784 .33052 .80977 .32662 .80468 .31937 Mtetra
.80468 .31937 .80977 .32662 .82175 .3227 .8167 .31543 Mtetra
.8167 .31543 .82175 .3227 .83378 .31877 .82876 .31146 Mtetra
.18679 .51429 .19348 .52013 .20308 .51697 .19642 .51112 Mtetra
.19642 .51112 .20308 .51697 .21272 .51381 .20608 .50793 Mtetra
.20608 .50793 .21272 .51381 .2224 .51063 .21578 .50473 Mtetra
.21578 .50473 .2224 .51063 .23212 .50744 .22552 .50151 Mtetra
.22552 .50151 .23212 .50744 .24187 .50423 .23529 .49829 Mtetra
.23529 .49829 .24187 .50423 .25166 .50102 .2451 .49505 Mtetra
.2451 .49505 .25166 .50102 .26148 .49779 .25494 .4918 Mtetra
.25494 .4918 .26148 .49779 .27134 .49455 .26483 .48854 Mtetra
.26483 .48854 .27134 .49455 .28124 .4913 .27475 .48527 Mtetra
.27475 .48527 .28124 .4913 .29118 .48804 .28471 .48198 Mtetra
.28471 .48198 .29118 .48804 .30115 .48476 .2947 .47868 Mtetra
.2947 .47868 .30115 .48476 .31116 .48147 .30474 .47537 Mtetra
.30474 .47537 .31116 .48147 .32121 .47817 .31481 .47205 Mtetra
.31481 .47205 .32121 .47817 .3313 .47486 .32492 .46871 Mtetra
.32492 .46871 .3313 .47486 .34143 .47153 .33507 .46536 Mtetra
.33507 .46536 .34143 .47153 .35159 .46819 .34526 .462 Mtetra
.34526 .462 .35159 .46819 .3618 .46484 .35549 .45862 Mtetra
.35549 .45862 .3618 .46484 .37204 .46148 .36576 .45523 Mtetra
.36576 .45523 .37204 .46148 .38232 .4581 .37607 .45183 Mtetra
.37607 .45183 .38232 .4581 .39264 .45471 .38641 .44842 Mtetra
.38641 .44842 .39264 .45471 .40301 .45131 .3968 .44499 Mtetra
.3968 .44499 .40301 .45131 .41341 .44789 .40723 .44155 Mtetra
.40723 .44155 .41341 .44789 .42385 .44446 .41769 .43809 Mtetra
.41769 .43809 .42385 .44446 .43434 .44102 .4282 .43462 Mtetra
.4282 .43462 .43434 .44102 .44486 .43756 .43875 .43114 Mtetra
.43875 .43114 .44486 .43756 .45542 .43409 .44934 .42765 Mtetra
.44934 .42765 .45542 .43409 .46603 .43061 .45998 .42414 Mtetra
.45998 .42414 .46603 .43061 .47668 .42711 .47065 .42062 Mtetra
.47065 .42062 .47668 .42711 .48737 .4236 .48137 .41708 Mtetra
.48137 .41708 .48737 .4236 .4981 .42007 .49213 .41353 Mtetra
.49213 .41353 .4981 .42007 .50887 .41653 .50293 .40996 Mtetra
.50293 .40996 .50887 .41653 .51969 .41298 .51377 .40639 Mtetra
.51377 .40639 .51969 .41298 .53055 .40941 .52466 .40279 Mtetra
.52466 .40279 .53055 .40941 .54145 .40583 .53559 .39919 Mtetra
.53559 .39919 .54145 .40583 .5524 .40224 .54656 .39556 Mtetra
.54656 .39556 .5524 .40224 .56338 .39863 .55758 .39193 Mtetra
.55758 .39193 .56338 .39863 .57442 .39501 .56864 .38828 Mtetra
.56864 .38828 .57442 .39501 .58549 .39137 .57975 .38461 Mtetra
.57975 .38461 .58549 .39137 .59661 .38772 .5909 .38093 Mtetra
.5909 .38093 .59661 .38772 .60778 .38405 .6021 .37724 Mtetra
.6021 .37724 .60778 .38405 .61899 .38037 .61334 .37353 Mtetra
.61334 .37353 .61899 .38037 .63025 .37667 .62462 .3698 Mtetra
.62462 .3698 .63025 .37667 .64155 .37296 .63595 .36606 Mtetra
.63595 .36606 .64155 .37296 .65289 .36923 .64733 .36231 Mtetra
.64733 .36231 .65289 .36923 .66429 .36549 .65875 .35854 Mtetra
.65875 .35854 .66429 .36549 .67572 .36173 .67023 .35475 Mtetra
.67023 .35475 .67572 .36173 .68721 .35796 .68174 .35095 Mtetra
.68174 .35095 .68721 .35796 .69874 .35417 .69331 .34714 Mtetra
.69331 .34714 .69874 .35417 .71032 .35037 .70492 .34331 Mtetra
.70492 .34331 .71032 .35037 .72195 .34655 .71658 .33946 Mtetra
.71658 .33946 .72195 .34655 .73362 .34271 .72829 .33559 Mtetra
.72829 .33559 .73362 .34271 .74534 .33886 .74004 .33171 Mtetra
.74004 .33171 .74534 .33886 .75711 .335 .75184 .32782 Mtetra
.75184 .32782 .75711 .335 .76893 .33112 .7637 .32391 Mtetra
.7637 .32391 .76893 .33112 .7808 .32722 .7756 .31998 Mtetra
.7756 .31998 .7808 .32722 .79272 .3233 .78755 .31604 Mtetra
.78755 .31604 .79272 .3233 .80468 .31937 .79955 .31208 Mtetra
.79955 .31208 .80468 .31937 .8167 .31543 .8116 .3081 Mtetra
.8116 .3081 .8167 .31543 .82876 .31146 .82371 .3041 Mtetra
.18006 .50842 .18679 .51429 .19642 .51112 .18971 .50522 Mtetra
.18971 .50522 .19642 .51112 .20608 .50793 .19939 .50201 Mtetra
.19939 .50201 .20608 .50793 .21578 .50473 .20911 .49879 Mtetra
.20911 .49879 .21578 .50473 .22552 .50151 .21887 .49555 Mtetra
.21887 .49555 .22552 .50151 .23529 .49829 .22866 .4923 Mtetra
.22866 .4923 .23529 .49829 .2451 .49505 .23849 .48904 Mtetra
.23849 .48904 .2451 .49505 .25494 .4918 .24836 .48577 Mtetra
.24836 .48577 .25494 .4918 .26483 .48854 .25827 .48249 Mtetra
.25827 .48249 .26483 .48854 .27475 .48527 .26821 .47919 Mtetra
.26821 .47919 .27475 .48527 .28471 .48198 .27819 .47588 Mtetra
.27819 .47588 .28471 .48198 .2947 .47868 .28821 .47256 Mtetra
.28821 .47256 .2947 .47868 .30474 .47537 .29827 .46922 Mtetra
.29827 .46922 .30474 .47537 .31481 .47205 .30837 .46587 Mtetra
.30837 .46587 .31481 .47205 .32492 .46871 .3185 .46251 Mtetra
.3185 .46251 .32492 .46871 .33507 .46536 .32867 .45914 Mtetra
.32867 .45914 .33507 .46536 .34526 .462 .33889 .45575 Mtetra
.33889 .45575 .34526 .462 .35549 .45862 .34914 .45235 Mtetra
.34914 .45235 .35549 .45862 .36576 .45523 .35943 .44894 Mtetra
.35943 .44894 .36576 .45523 .37607 .45183 .36976 .44552 Mtetra
.36976 .44552 .37607 .45183 .38641 .44842 .38013 .44208 Mtetra
.38013 .44208 .38641 .44842 .3968 .44499 .39055 .43862 Mtetra
.39055 .43862 .3968 .44499 .40723 .44155 .401 .43516 Mtetra
.401 .43516 .40723 .44155 .41769 .43809 .41149 .43168 Mtetra
.41149 .43168 .41769 .43809 .4282 .43462 .42203 .42819 Mtetra
.42203 .42819 .4282 .43462 .43875 .43114 .4326 .42468 Mtetra
.4326 .42468 .43875 .43114 .44934 .42765 .44322 .42116 Mtetra
.44322 .42116 .44934 .42765 .45998 .42414 .45388 .41762 Mtetra
.45388 .41762 .45998 .42414 .47065 .42062 .46458 .41408 Mtetra
.46458 .41408 .47065 .42062 .48137 .41708 .47533 .41051 Mtetra
.47533 .41051 .48137 .41708 .49213 .41353 .48611 .40694 Mtetra
.48611 .40694 .49213 .41353 .50293 .40996 .49694 .40335 Mtetra
.49694 .40335 .50293 .40996 .51377 .40639 .50781 .39974 Mtetra
.50781 .39974 .51377 .40639 .52466 .40279 .51873 .39612 Mtetra
.51873 .39612 .52466 .40279 .53559 .39919 .52969 .39249 Mtetra
.52969 .39249 .53559 .39919 .54656 .39556 .54069 .38884 Mtetra
.54069 .38884 .54656 .39556 .55758 .39193 .55174 .38518 Mtetra
.55174 .38518 .55758 .39193 .56864 .38828 .56283 .3815 Mtetra
.56283 .3815 .56864 .38828 .57975 .38461 .57396 .37781 Mtetra
.57396 .37781 .57975 .38461 .5909 .38093 .58514 .3741 Mtetra
.58514 .3741 .5909 .38093 .6021 .37724 .59637 .37038 Mtetra
.59637 .37038 .6021 .37724 .61334 .37353 .60764 .36664 Mtetra
.60764 .36664 .61334 .37353 .62462 .3698 .61896 .36289 Mtetra
.61896 .36289 .62462 .3698 .63595 .36606 .63032 .35912 Mtetra
.63032 .35912 .63595 .36606 .64733 .36231 .64173 .35534 Mtetra
.64173 .35534 .64733 .36231 .65875 .35854 .65318 .35154 Mtetra
.65318 .35154 .65875 .35854 .67023 .35475 .66469 .34773 Mtetra
.66469 .34773 .67023 .35475 .68174 .35095 .67623 .3439 Mtetra
.67623 .3439 .68174 .35095 .69331 .34714 .68783 .34005 Mtetra
.68783 .34005 .69331 .34714 .70492 .34331 .69948 .33619 Mtetra
.69948 .33619 .70492 .34331 .71658 .33946 .71117 .33231 Mtetra
.71117 .33231 .71658 .33946 .72829 .33559 .72291 .32842 Mtetra
.72291 .32842 .72829 .33559 .74004 .33171 .7347 .32451 Mtetra
.7347 .32451 .74004 .33171 .75184 .32782 .74654 .32059 Mtetra
.74654 .32059 .75184 .32782 .7637 .32391 .75842 .31664 Mtetra
.75842 .31664 .7637 .32391 .7756 .31998 .77036 .31269 Mtetra
.77036 .31269 .7756 .31998 .78755 .31604 .78235 .30871 Mtetra
.78235 .30871 .78755 .31604 .79955 .31208 .79438 .30472 Mtetra
.79438 .30472 .79955 .31208 .8116 .3081 .80647 .30071 Mtetra
.80647 .30071 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.17328 .5025 .18006 .50842 .18971 .50522 .18295 .49928 Mtetra
.18295 .49928 .18971 .50522 .19939 .50201 .19266 .49605 Mtetra
.19266 .49605 .19939 .50201 .20911 .49879 .2024 .4928 Mtetra
.2024 .4928 .20911 .49879 .21887 .49555 .21218 .48955 Mtetra
.21218 .48955 .21887 .49555 .22866 .4923 .22199 .48627 Mtetra
.22199 .48627 .22866 .4923 .23849 .48904 .23184 .48299 Mtetra
.23184 .48299 .23849 .48904 .24836 .48577 .24173 .4797 Mtetra
.24173 .4797 .24836 .48577 .25827 .48249 .25166 .47639 Mtetra
.25166 .47639 .25827 .48249 .26821 .47919 .26163 .47307 Mtetra
.26163 .47307 .26821 .47919 .27819 .47588 .27163 .46974 Mtetra
.27163 .46974 .27819 .47588 .28821 .47256 .28167 .46639 Mtetra
.28167 .46639 .28821 .47256 .29827 .46922 .29175 .46303 Mtetra
.29175 .46303 .29827 .46922 .30837 .46587 .30187 .45966 Mtetra
.30187 .45966 .30837 .46587 .3185 .46251 .31203 .45628 Mtetra
.31203 .45628 .3185 .46251 .32867 .45914 .32223 .45288 Mtetra
.32223 .45288 .32867 .45914 .33889 .45575 .33247 .44947 Mtetra
.33247 .44947 .33889 .45575 .34914 .45235 .34274 .44604 Mtetra
.34274 .44604 .34914 .45235 .35943 .44894 .35306 .44261 Mtetra
.35306 .44261 .35943 .44894 .36976 .44552 .36342 .43916 Mtetra
.36342 .43916 .36976 .44552 .38013 .44208 .37381 .43569 Mtetra
.37381 .43569 .38013 .44208 .39055 .43862 .38425 .43222 Mtetra
.38425 .43222 .39055 .43862 .401 .43516 .39473 .42872 Mtetra
.39473 .42872 .401 .43516 .41149 .43168 .40525 .42522 Mtetra
.40525 .42522 .41149 .43168 .42203 .42819 .41581 .4217 Mtetra
.41581 .4217 .42203 .42819 .4326 .42468 .42641 .41817 Mtetra
.42641 .41817 .4326 .42468 .44322 .42116 .43705 .41462 Mtetra
.43705 .41462 .44322 .42116 .45388 .41762 .44774 .41106 Mtetra
.44774 .41106 .45388 .41762 .46458 .41408 .45847 .40749 Mtetra
.45847 .40749 .46458 .41408 .47533 .41051 .46924 .4039 Mtetra
.46924 .4039 .47533 .41051 .48611 .40694 .48005 .4003 Mtetra
.48005 .4003 .48611 .40694 .49694 .40335 .49091 .39668 Mtetra
.49091 .39668 .49694 .40335 .50781 .39974 .50181 .39305 Mtetra
.50181 .39305 .50781 .39974 .51873 .39612 .51275 .3894 Mtetra
.51275 .3894 .51873 .39612 .52969 .39249 .52374 .38574 Mtetra
.52374 .38574 .52969 .39249 .54069 .38884 .53477 .38207 Mtetra
.53477 .38207 .54069 .38884 .55174 .38518 .54585 .37838 Mtetra
.54585 .37838 .55174 .38518 .56283 .3815 .55697 .37467 Mtetra
.55697 .37467 .56283 .3815 .57396 .37781 .56813 .37095 Mtetra
.56813 .37095 .57396 .37781 .58514 .3741 .57934 .36722 Mtetra
.57934 .36722 .58514 .3741 .59637 .37038 .5906 .36347 Mtetra
.5906 .36347 .59637 .37038 .60764 .36664 .6019 .3597 Mtetra
.6019 .3597 .60764 .36664 .61896 .36289 .61325 .35592 Mtetra
.61325 .35592 .61896 .36289 .63032 .35912 .62464 .35213 Mtetra
.62464 .35213 .63032 .35912 .64173 .35534 .63608 .34831 Mtetra
.63608 .34831 .64173 .35534 .65318 .35154 .64757 .34449 Mtetra
.64757 .34449 .65318 .35154 .66469 .34773 .6591 .34064 Mtetra
.6591 .34064 .66469 .34773 .67623 .3439 .67069 .33678 Mtetra
.67069 .33678 .67623 .3439 .68783 .34005 .68231 .33291 Mtetra
.68231 .33291 .68783 .34005 .69948 .33619 .69399 .32902 Mtetra
.69399 .32902 .69948 .33619 .71117 .33231 .70572 .32511 Mtetra
.70572 .32511 .71117 .33231 .72291 .32842 .71749 .32119 Mtetra
.71749 .32119 .72291 .32842 .7347 .32451 .72932 .31725 Mtetra
.72932 .31725 .7347 .32451 .74654 .32059 .74119 .3133 Mtetra
.74119 .3133 .74654 .32059 .75842 .31664 .75311 .30932 Mtetra
.75311 .30932 .75842 .31664 .77036 .31269 .76508 .30533 Mtetra
.76508 .30533 .77036 .31269 .78235 .30871 .7771 .30133 Mtetra
.7771 .30133 .78235 .30871 .79438 .30472 .78918 .29731 Mtetra
.78918 .29731 .79438 .30472 .80647 .30071 .8013 .29327 Mtetra
.8013 .29327 .80647 .30071 .81861 .29669 .81347 .28921 Mtetra
.16646 .49655 .17328 .5025 .18295 .49928 .17615 .4933 Mtetra
.17615 .4933 .18295 .49928 .19266 .49605 .18587 .49005 Mtetra
.18587 .49005 .19266 .49605 .2024 .4928 .19564 .48678 Mtetra
.19564 .48678 .2024 .4928 .21218 .48955 .20544 .4835 Mtetra
.20544 .4835 .21218 .48955 .22199 .48627 .21527 .4802 Mtetra
.21527 .4802 .22199 .48627 .23184 .48299 .22515 .4769 Mtetra
.22515 .4769 .23184 .48299 .24173 .4797 .23506 .47358 Mtetra
.23506 .47358 .24173 .4797 .25166 .47639 .24501 .47025 Mtetra
.24501 .47025 .25166 .47639 .26163 .47307 .255 .46691 Mtetra
.255 .46691 .26163 .47307 .27163 .46974 .26502 .46355 Mtetra
.26502 .46355 .27163 .46974 .28167 .46639 .27509 .46018 Mtetra
.27509 .46018 .28167 .46639 .29175 .46303 .28519 .4568 Mtetra
.28519 .4568 .29175 .46303 .30187 .45966 .29534 .4534 Mtetra
.29534 .4534 .30187 .45966 .31203 .45628 .30552 .44999 Mtetra
.30552 .44999 .31203 .45628 .32223 .45288 .31574 .44657 Mtetra
.31574 .44657 .32223 .45288 .33247 .44947 .326 .44314 Mtetra
.326 .44314 .33247 .44947 .34274 .44604 .3363 .43969 Mtetra
.3363 .43969 .34274 .44604 .35306 .44261 .34664 .43623 Mtetra
.34664 .43623 .35306 .44261 .36342 .43916 .35702 .43275 Mtetra
.35702 .43275 .36342 .43916 .37381 .43569 .36744 .42926 Mtetra
.36744 .42926 .37381 .43569 .38425 .43222 .37791 .42576 Mtetra
.37791 .42576 .38425 .43222 .39473 .42872 .38841 .42224 Mtetra
.38841 .42224 .39473 .42872 .40525 .42522 .39896 .41871 Mtetra
.39896 .41871 .40525 .42522 .41581 .4217 .40954 .41517 Mtetra
.40954 .41517 .41581 .4217 .42641 .41817 .42017 .41161 Mtetra
.42017 .41161 .42641 .41817 .43705 .41462 .43084 .40804 Mtetra
.43084 .40804 .43705 .41462 .44774 .41106 .44155 .40445 Mtetra
.44155 .40445 .44774 .41106 .45847 .40749 .45231 .40085 Mtetra
.45231 .40085 .45847 .40749 .46924 .4039 .46311 .39724 Mtetra
.46311 .39724 .46924 .4039 .48005 .4003 .47395 .39361 Mtetra
.47395 .39361 .48005 .4003 .49091 .39668 .48483 .38996 Mtetra
.48483 .38996 .49091 .39668 .50181 .39305 .49576 .38631 Mtetra
.49576 .38631 .50181 .39305 .51275 .3894 .50673 .38263 Mtetra
.50673 .38263 .51275 .3894 .52374 .38574 .51775 .37895 Mtetra
.51775 .37895 .52374 .38574 .53477 .38207 .52881 .37524 Mtetra
.52881 .37524 .53477 .38207 .54585 .37838 .53991 .37153 Mtetra
.53991 .37153 .54585 .37838 .55697 .37467 .55106 .36779 Mtetra
.55106 .36779 .55697 .37467 .56813 .37095 .56226 .36404 Mtetra
.56226 .36404 .56813 .37095 .57934 .36722 .5735 .36028 Mtetra
.5735 .36028 .57934 .36722 .5906 .36347 .58479 .3565 Mtetra
.58479 .3565 .5906 .36347 .6019 .3597 .59612 .35271 Mtetra
.59612 .35271 .6019 .3597 .61325 .35592 .6075 .3489 Mtetra
.6075 .3489 .61325 .35592 .62464 .35213 .61892 .34508 Mtetra
.61892 .34508 .62464 .35213 .63608 .34831 .63039 .34124 Mtetra
.63039 .34124 .63608 .34831 .64757 .34449 .64191 .33738 Mtetra
.64191 .33738 .64757 .34449 .6591 .34064 .65348 .33351 Mtetra
.65348 .33351 .6591 .34064 .67069 .33678 .66509 .32962 Mtetra
.66509 .32962 .67069 .33678 .68231 .33291 .67676 .32572 Mtetra
.67676 .32572 .68231 .33291 .69399 .32902 .68847 .32179 Mtetra
.68847 .32179 .69399 .32902 .70572 .32511 .70023 .31786 Mtetra
.70023 .31786 .70572 .32511 .71749 .32119 .71203 .31391 Mtetra
.71203 .31391 .71749 .32119 .72932 .31725 .72389 .30994 Mtetra
.72389 .30994 .72932 .31725 .74119 .3133 .7358 .30595 Mtetra
.7358 .30595 .74119 .3133 .75311 .30932 .74775 .30195 Mtetra
.74775 .30195 .75311 .30932 .76508 .30533 .75976 .29793 Mtetra
.75976 .29793 .76508 .30533 .7771 .30133 .77182 .29389 Mtetra
.77182 .29389 .7771 .30133 .78918 .29731 .78393 .28984 Mtetra
.78393 .28984 .78918 .29731 .8013 .29327 .79609 .28577 Mtetra
.79609 .28577 .8013 .29327 .81347 .28921 .8083 .28168 Mtetra
.15958 .49055 .16646 .49655 .17615 .4933 .16929 .48728 Mtetra
.16929 .48728 .17615 .4933 .18587 .49005 .17904 .484 Mtetra
.17904 .484 .18587 .49005 .19564 .48678 .18883 .48071 Mtetra
.18883 .48071 .19564 .48678 .20544 .4835 .19865 .47741 Mtetra
.19865 .47741 .20544 .4835 .21527 .4802 .20851 .47409 Mtetra
.20851 .47409 .21527 .4802 .22515 .4769 .2184 .47076 Mtetra
.2184 .47076 .22515 .4769 .23506 .47358 .22834 .46742 Mtetra
.22834 .46742 .23506 .47358 .24501 .47025 .23831 .46407 Mtetra
.23831 .46407 .24501 .47025 .255 .46691 .24832 .4607 Mtetra
.24832 .4607 .255 .46691 .26502 .46355 .25837 .45732 Mtetra
.25837 .45732 .26502 .46355 .27509 .46018 .26846 .45393 Mtetra
.26846 .45393 .27509 .46018 .28519 .4568 .27858 .45052 Mtetra
.27858 .45052 .28519 .4568 .29534 .4534 .28875 .4471 Mtetra
.28875 .4471 .29534 .4534 .30552 .44999 .29896 .44367 Mtetra
.29896 .44367 .30552 .44999 .31574 .44657 .3092 .44022 Mtetra
.3092 .44022 .31574 .44657 .326 .44314 .31949 .43676 Mtetra
.31949 .43676 .326 .44314 .3363 .43969 .32981 .43329 Mtetra
.32981 .43329 .3363 .43969 .34664 .43623 .34018 .4298 Mtetra
.34018 .4298 .34664 .43623 .35702 .43275 .35058 .4263 Mtetra
.35058 .4263 .35702 .43275 .36744 .42926 .36103 .42279 Mtetra
.36103 .42279 .36744 .42926 .37791 .42576 .37152 .41926 Mtetra
.37152 .41926 .37791 .42576 .38841 .42224 .38205 .41572 Mtetra
.38205 .41572 .38841 .42224 .39896 .41871 .39262 .41216 Mtetra
.39262 .41216 .39896 .41871 .40954 .41517 .40323 .40859 Mtetra
.40323 .40859 .40954 .41517 .42017 .41161 .41389 .40501 Mtetra
.41389 .40501 .42017 .41161 .43084 .40804 .42458 .40141 Mtetra
.42458 .40141 .43084 .40804 .44155 .40445 .43532 .39779 Mtetra
.43532 .39779 .44155 .40445 .45231 .40085 .44611 .39417 Mtetra
.44611 .39417 .45231 .40085 .46311 .39724 .45693 .39053 Mtetra
.45693 .39053 .46311 .39724 .47395 .39361 .4678 .38687 Mtetra
.4678 .38687 .47395 .39361 .48483 .38996 .47871 .3832 Mtetra
.47871 .3832 .48483 .38996 .49576 .38631 .48967 .37951 Mtetra
.48967 .37951 .49576 .38631 .50673 .38263 .50067 .37581 Mtetra
.50067 .37581 .50673 .38263 .51775 .37895 .51171 .3721 Mtetra
.51171 .3721 .51775 .37895 .52881 .37524 .5228 .36837 Mtetra
.5228 .36837 .52881 .37524 .53991 .37153 .53394 .36462 Mtetra
.53394 .36462 .53991 .37153 .55106 .36779 .54512 .36086 Mtetra
.54512 .36086 .55106 .36779 .56226 .36404 .55634 .35709 Mtetra
.55634 .35709 .56226 .36404 .5735 .36028 .56761 .35329 Mtetra
.56761 .35329 .5735 .36028 .58479 .3565 .57893 .34949 Mtetra
.57893 .34949 .58479 .3565 .59612 .35271 .59029 .34567 Mtetra
.59029 .34567 .59612 .35271 .6075 .3489 .6017 .34183 Mtetra
.6017 .34183 .6075 .3489 .61892 .34508 .61316 .33797 Mtetra
.61316 .33797 .61892 .34508 .63039 .34124 .62466 .3341 Mtetra
.62466 .3341 .63039 .34124 .64191 .33738 .63621 .33022 Mtetra
.63621 .33022 .64191 .33738 .65348 .33351 .64781 .32632 Mtetra
.64781 .32632 .65348 .33351 .66509 .32962 .65946 .3224 Mtetra
.65946 .3224 .66509 .32962 .67676 .32572 .67115 .31846 Mtetra
.67115 .31846 .67676 .32572 .68847 .32179 .6829 .31451 Mtetra
.6829 .31451 .68847 .32179 .70023 .31786 .69469 .31055 Mtetra
.69469 .31055 .70023 .31786 .71203 .31391 .70653 .30656 Mtetra
.70653 .30656 .71203 .31391 .72389 .30994 .71842 .30256 Mtetra
.71842 .30256 .72389 .30994 .7358 .30595 .73037 .29855 Mtetra
.73037 .29855 .7358 .30595 .74775 .30195 .74236 .29451 Mtetra
.74236 .29451 .74775 .30195 .75976 .29793 .7544 .29046 Mtetra
.7544 .29046 .75976 .29793 .77182 .29389 .76649 .28639 Mtetra
.76649 .28639 .77182 .29389 .78393 .28984 .77864 .28231 Mtetra
.77864 .28231 .78393 .28984 .79609 .28577 .79083 .27821 Mtetra
.79083 .27821 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.15266 .48451 .15958 .49055 .16929 .48728 .16239 .48122 Mtetra
.16239 .48122 .16929 .48728 .17904 .484 .17216 .47792 Mtetra
.17216 .47792 .17904 .484 .18883 .48071 .18197 .4746 Mtetra
.18197 .4746 .18883 .48071 .19865 .47741 .19181 .47128 Mtetra
.19181 .47128 .19865 .47741 .20851 .47409 .20169 .46794 Mtetra
.20169 .46794 .20851 .47409 .2184 .47076 .21161 .46458 Mtetra
.21161 .46458 .2184 .47076 .22834 .46742 .22157 .46122 Mtetra
.22157 .46122 .22834 .46742 .23831 .46407 .23156 .45784 Mtetra
.23156 .45784 .23831 .46407 .24832 .4607 .2416 .45445 Mtetra
.2416 .45445 .24832 .4607 .25837 .45732 .25167 .45104 Mtetra
.25167 .45104 .25837 .45732 .26846 .45393 .26178 .44763 Mtetra
.26178 .44763 .26846 .45393 .27858 .45052 .27193 .4442 Mtetra
.27193 .4442 .27858 .45052 .28875 .4471 .28212 .44075 Mtetra
.28212 .44075 .28875 .4471 .29896 .44367 .29235 .43729 Mtetra
.29235 .43729 .29896 .44367 .3092 .44022 .30262 .43382 Mtetra
.30262 .43382 .3092 .44022 .31949 .43676 .31293 .43034 Mtetra
.31293 .43034 .31949 .43676 .32981 .43329 .32328 .42684 Mtetra
.32328 .42684 .32981 .43329 .34018 .4298 .33367 .42333 Mtetra
.33367 .42333 .34018 .4298 .35058 .4263 .3441 .4198 Mtetra
.3441 .4198 .35058 .4263 .36103 .42279 .35457 .41626 Mtetra
.35457 .41626 .36103 .42279 .37152 .41926 .36508 .41271 Mtetra
.36508 .41271 .37152 .41926 .38205 .41572 .37564 .40914 Mtetra
.37564 .40914 .38205 .41572 .39262 .41216 .38623 .40556 Mtetra
.38623 .40556 .39262 .41216 .40323 .40859 .39687 .40196 Mtetra
.39687 .40196 .40323 .40859 .41389 .40501 .40756 .39835 Mtetra
.40756 .39835 .41389 .40501 .42458 .40141 .41828 .39473 Mtetra
.41828 .39473 .42458 .40141 .43532 .39779 .42905 .39109 Mtetra
.42905 .39109 .43532 .39779 .44611 .39417 .43986 .38743 Mtetra
.43986 .38743 .44611 .39417 .45693 .39053 .45071 .38376 Mtetra
.45071 .38376 .45693 .39053 .4678 .38687 .4616 .38008 Mtetra
.4616 .38008 .4678 .38687 .47871 .3832 .47255 .37638 Mtetra
.47255 .37638 .47871 .3832 .48967 .37951 .48353 .37267 Mtetra
.48353 .37267 .48967 .37951 .50067 .37581 .49456 .36894 Mtetra
.49456 .36894 .50067 .37581 .51171 .3721 .50563 .3652 Mtetra
.50563 .3652 .51171 .3721 .5228 .36837 .51675 .36144 Mtetra
.51675 .36144 .5228 .36837 .53394 .36462 .52791 .35767 Mtetra
.52791 .35767 .53394 .36462 .54512 .36086 .53912 .35388 Mtetra
.53912 .35388 .54512 .36086 .55634 .35709 .55038 .35007 Mtetra
.55038 .35007 .55634 .35709 .56761 .35329 .56168 .34625 Mtetra
.56168 .34625 .56761 .35329 .57893 .34949 .57303 .34242 Mtetra
.57303 .34242 .57893 .34949 .59029 .34567 .58442 .33857 Mtetra
.58442 .33857 .59029 .34567 .6017 .34183 .59586 .3347 Mtetra
.59586 .3347 .6017 .34183 .61316 .33797 .60735 .33082 Mtetra
.60735 .33082 .61316 .33797 .62466 .3341 .61889 .32692 Mtetra
.61889 .32692 .62466 .3341 .63621 .33022 .63047 .323 Mtetra
.63047 .323 .63621 .33022 .64781 .32632 .6421 .31907 Mtetra
.6421 .31907 .64781 .32632 .65946 .3224 .65378 .31512 Mtetra
.65378 .31512 .65946 .3224 .67115 .31846 .66551 .31116 Mtetra
.66551 .31116 .67115 .31846 .6829 .31451 .67729 .30718 Mtetra
.67729 .30718 .6829 .31451 .69469 .31055 .68911 .30318 Mtetra
.68911 .30318 .69469 .31055 .70653 .30656 .70099 .29917 Mtetra
.70099 .29917 .70653 .30656 .71842 .30256 .71292 .29513 Mtetra
.71292 .29513 .71842 .30256 .73037 .29855 .72489 .29109 Mtetra
.72489 .29109 .73037 .29855 .74236 .29451 .73692 .28702 Mtetra
.73692 .28702 .74236 .29451 .7544 .29046 .749 .28294 Mtetra
.749 .28294 .7544 .29046 .76649 .28639 .76113 .27884 Mtetra
.76113 .27884 .76649 .28639 .77864 .28231 .77331 .27472 Mtetra
.77331 .27472 .77864 .28231 .79083 .27821 .78554 .27059 Mtetra
.78554 .27059 .79083 .27821 .80308 .27409 .79782 .26643 Mtetra
.14569 .47843 .15266 .48451 .16239 .48122 .15545 .47511 Mtetra
.15545 .47511 .16239 .48122 .17216 .47792 .16524 .47179 Mtetra
.16524 .47179 .17216 .47792 .18197 .4746 .17506 .46845 Mtetra
.17506 .46845 .18197 .4746 .19181 .47128 .18493 .4651 Mtetra
.18493 .4651 .19181 .47128 .20169 .46794 .19483 .46174 Mtetra
.19483 .46174 .20169 .46794 .21161 .46458 .20477 .45836 Mtetra
.20477 .45836 .21161 .46458 .22157 .46122 .21475 .45497 Mtetra
.21475 .45497 .22157 .46122 .23156 .45784 .22477 .45157 Mtetra
.22477 .45157 .23156 .45784 .2416 .45445 .23482 .44815 Mtetra
.23482 .44815 .2416 .45445 .25167 .45104 .24492 .44472 Mtetra
.24492 .44472 .25167 .45104 .26178 .44763 .25505 .44128 Mtetra
.25505 .44128 .26178 .44763 .27193 .4442 .26523 .43783 Mtetra
.26523 .43783 .27193 .4442 .28212 .44075 .27544 .43436 Mtetra
.27544 .43436 .28212 .44075 .29235 .43729 .28569 .43087 Mtetra
.28569 .43087 .29235 .43729 .30262 .43382 .29598 .42738 Mtetra
.29598 .42738 .30262 .43382 .31293 .43034 .30632 .42387 Mtetra
.30632 .42387 .31293 .43034 .32328 .42684 .31669 .42034 Mtetra
.31669 .42034 .32328 .42684 .33367 .42333 .32711 .41681 Mtetra
.32711 .41681 .33367 .42333 .3441 .4198 .33756 .41326 Mtetra
.33756 .41326 .3441 .4198 .35457 .41626 .34806 .40969 Mtetra
.34806 .40969 .35457 .41626 .36508 .41271 .3586 .40611 Mtetra
.3586 .40611 .36508 .41271 .37564 .40914 .36918 .40252 Mtetra
.36918 .40252 .37564 .40914 .38623 .40556 .3798 .39891 Mtetra
.3798 .39891 .38623 .40556 .39687 .40196 .39047 .39529 Mtetra
.39047 .39529 .39687 .40196 .40756 .39835 .40118 .39165 Mtetra
.40118 .39165 .40756 .39835 .41828 .39473 .41193 .388 Mtetra
.41193 .388 .41828 .39473 .42905 .39109 .42272 .38433 Mtetra
.42272 .38433 .42905 .39109 .43986 .38743 .43356 .38065 Mtetra
.43356 .38065 .43986 .38743 .45071 .38376 .44444 .37695 Mtetra
.44444 .37695 .45071 .38376 .4616 .38008 .45536 .37324 Mtetra
.45536 .37324 .4616 .38008 .47255 .37638 .46633 .36952 Mtetra
.46633 .36952 .47255 .37638 .48353 .37267 .47735 .36578 Mtetra
.47735 .36578 .48353 .37267 .49456 .36894 .4884 .36202 Mtetra
.4884 .36202 .49456 .36894 .50563 .3652 .49951 .35825 Mtetra
.49951 .35825 .50563 .3652 .51675 .36144 .51065 .35446 Mtetra
.51065 .35446 .51675 .36144 .52791 .35767 .52185 .35066 Mtetra
.52185 .35066 .52791 .35767 .53912 .35388 .53309 .34684 Mtetra
.53309 .34684 .53912 .35388 .55038 .35007 .54437 .34301 Mtetra
.54437 .34301 .55038 .35007 .56168 .34625 .5557 .33916 Mtetra
.5557 .33916 .56168 .34625 .57303 .34242 .56708 .3353 Mtetra
.56708 .3353 .57303 .34242 .58442 .33857 .57851 .33142 Mtetra
.57851 .33142 .58442 .33857 .59586 .3347 .58998 .32752 Mtetra
.58998 .32752 .59586 .3347 .60735 .33082 .6015 .32361 Mtetra
.6015 .32361 .60735 .33082 .61889 .32692 .61307 .31968 Mtetra
.61307 .31968 .61889 .32692 .63047 .323 .62468 .31573 Mtetra
.62468 .31573 .63047 .323 .6421 .31907 .63635 .31177 Mtetra
.63635 .31177 .6421 .31907 .65378 .31512 .64806 .30779 Mtetra
.64806 .30779 .65378 .31512 .66551 .31116 .65982 .3038 Mtetra
.65982 .3038 .66551 .31116 .67729 .30718 .67163 .29978 Mtetra
.67163 .29978 .67729 .30718 .68911 .30318 .68349 .29576 Mtetra
.68349 .29576 .68911 .30318 .70099 .29917 .6954 .29171 Mtetra
.6954 .29171 .70099 .29917 .71292 .29513 .70736 .28765 Mtetra
.70736 .28765 .71292 .29513 .72489 .29109 .71938 .28357 Mtetra
.71938 .28357 .72489 .29109 .73692 .28702 .73144 .27947 Mtetra
.73144 .27947 .73692 .28702 .749 .28294 .74355 .27536 Mtetra
.74355 .27536 .749 .28294 .76113 .27884 .75572 .27122 Mtetra
.75572 .27122 .76113 .27884 .77331 .27472 .76793 .26707 Mtetra
.76793 .26707 .77331 .27472 .78554 .27059 .7802 .26291 Mtetra
.7802 .26291 .78554 .27059 .79782 .26643 .79252 .25872 Mtetra
.13868 .4723 .14569 .47843 .15545 .47511 .14845 .46897 Mtetra
.14845 .46897 .15545 .47511 .16524 .47179 .15826 .46562 Mtetra
.15826 .46562 .16524 .47179 .17506 .46845 .16811 .46226 Mtetra
.16811 .46226 .17506 .46845 .18493 .4651 .17799 .45888 Mtetra
.17799 .45888 .18493 .4651 .19483 .46174 .18792 .45549 Mtetra
.18792 .45549 .19483 .46174 .20477 .45836 .19788 .45209 Mtetra
.19788 .45209 .20477 .45836 .21475 .45497 .20788 .44868 Mtetra
.20788 .44868 .21475 .45497 .22477 .45157 .21792 .44525 Mtetra
.21792 .44525 .22477 .45157 .23482 .44815 .228 .44181 Mtetra
.228 .44181 .23482 .44815 .24492 .44472 .23812 .43836 Mtetra
.23812 .43836 .24492 .44472 .25505 .44128 .24828 .43489 Mtetra
.24828 .43489 .25505 .44128 .26523 .43783 .25847 .43141 Mtetra
.25847 .43141 .26523 .43783 .27544 .43436 .26871 .42792 Mtetra
.26871 .42792 .27544 .43436 .28569 .43087 .27899 .42441 Mtetra
.27899 .42441 .28569 .43087 .29598 .42738 .2893 .42089 Mtetra
.2893 .42089 .29598 .42738 .30632 .42387 .29966 .41735 Mtetra
.29966 .41735 .30632 .42387 .31669 .42034 .31006 .4138 Mtetra
.31006 .4138 .31669 .42034 .32711 .41681 .3205 .41024 Mtetra
.3205 .41024 .32711 .41681 .33756 .41326 .33098 .40666 Mtetra
.33098 .40666 .33756 .41326 .34806 .40969 .34151 .40307 Mtetra
.34151 .40307 .34806 .40969 .3586 .40611 .35207 .39946 Mtetra
.35207 .39946 .3586 .40611 .36918 .40252 .36268 .39584 Mtetra
.36268 .39584 .36918 .40252 .3798 .39891 .37333 .39221 Mtetra
.37333 .39221 .3798 .39891 .39047 .39529 .38402 .38856 Mtetra
.38402 .38856 .39047 .39529 .40118 .39165 .39475 .3849 Mtetra
.39475 .3849 .40118 .39165 .41193 .388 .40553 .38122 Mtetra
.40553 .38122 .41193 .388 .42272 .38433 .41635 .37752 Mtetra
.41635 .37752 .42272 .38433 .43356 .38065 .42722 .37381 Mtetra
.42722 .37381 .43356 .38065 .44444 .37695 .43812 .37009 Mtetra
.43812 .37009 .44444 .37695 .45536 .37324 .44908 .36635 Mtetra
.44908 .36635 .45536 .37324 .46633 .36952 .46007 .3626 Mtetra
.46007 .3626 .46633 .36952 .47735 .36578 .47112 .35883 Mtetra
.47112 .35883 .47735 .36578 .4884 .36202 .4822 .35505 Mtetra
.4822 .35505 .4884 .36202 .49951 .35825 .49333 .35125 Mtetra
.49333 .35125 .49951 .35825 .51065 .35446 .50451 .34743 Mtetra
.50451 .34743 .51065 .35446 .52185 .35066 .51573 .3436 Mtetra
.51573 .3436 .52185 .35066 .53309 .34684 .527 .33975 Mtetra
.527 .33975 .53309 .34684 .54437 .34301 .53832 .33589 Mtetra
.53832 .33589 .54437 .34301 .5557 .33916 .54968 .33201 Mtetra
.54968 .33201 .5557 .33916 .56708 .3353 .56109 .32812 Mtetra
.56109 .32812 .56708 .3353 .57851 .33142 .57255 .32421 Mtetra
.57255 .32421 .57851 .33142 .58998 .32752 .58405 .32028 Mtetra
.58405 .32028 .58998 .32752 .6015 .32361 .5956 .31634 Mtetra
.5956 .31634 .6015 .32361 .61307 .31968 .6072 .31238 Mtetra
.6072 .31238 .61307 .31968 .62468 .31573 .61885 .3084 Mtetra
.61885 .3084 .62468 .31573 .63635 .31177 .63055 .30441 Mtetra
.63055 .30441 .63635 .31177 .64806 .30779 .64229 .3004 Mtetra
.64229 .3004 .64806 .30779 .65982 .3038 .65409 .29638 Mtetra
.65409 .29638 .65982 .3038 .67163 .29978 .66593 .29233 Mtetra
.66593 .29233 .67163 .29978 .68349 .29576 .67783 .28827 Mtetra
.67783 .28827 .68349 .29576 .6954 .29171 .68977 .2842 Mtetra
.68977 .2842 .6954 .29171 .70736 .28765 .70177 .2801 Mtetra
.70177 .2801 .70736 .28765 .71938 .28357 .71382 .27599 Mtetra
.71382 .27599 .71938 .28357 .73144 .27947 .72591 .27186 Mtetra
.72591 .27186 .73144 .27947 .74355 .27536 .73806 .26771 Mtetra
.73806 .26771 .74355 .27536 .75572 .27122 .75026 .26355 Mtetra
.75026 .26355 .75572 .27122 .76793 .26707 .76252 .25937 Mtetra
.76252 .25937 .76793 .26707 .7802 .26291 .77482 .25517 Mtetra
.77482 .25517 .7802 .26291 .79252 .25872 .78718 .25095 Mtetra
.13161 .46613 .13868 .4723 .14845 .46897 .1414 .46277 Mtetra
.1414 .46277 .14845 .46897 .15826 .46562 .15123 .4594 Mtetra
.15123 .4594 .15826 .46562 .16811 .46226 .1611 .45602 Mtetra
.1611 .45602 .16811 .46226 .17799 .45888 .17101 .45262 Mtetra
.17101 .45262 .17799 .45888 .18792 .45549 .18096 .44921 Mtetra
.18096 .44921 .18792 .45549 .19788 .45209 .19094 .44578 Mtetra
.19094 .44578 .19788 .45209 .20788 .44868 .20097 .44234 Mtetra
.20097 .44234 .20788 .44868 .21792 .44525 .21103 .43889 Mtetra
.21103 .43889 .21792 .44525 .228 .44181 .22113 .43543 Mtetra
.22113 .43543 .228 .44181 .23812 .43836 .23127 .43195 Mtetra
.23127 .43195 .23812 .43836 .24828 .43489 .24145 .42846 Mtetra
.24145 .42846 .24828 .43489 .25847 .43141 .25167 .42495 Mtetra
.25167 .42495 .25847 .43141 .26871 .42792 .26193 .42143 Mtetra
.26193 .42143 .26871 .42792 .27899 .42441 .27223 .4179 Mtetra
.27223 .4179 .27899 .42441 .2893 .42089 .28258 .41435 Mtetra
.28258 .41435 .2893 .42089 .29966 .41735 .29296 .41079 Mtetra
.29296 .41079 .29966 .41735 .31006 .4138 .30338 .40721 Mtetra
.30338 .40721 .31006 .4138 .3205 .41024 .31385 .40362 Mtetra
.31385 .40362 .3205 .41024 .33098 .40666 .32435 .40002 Mtetra
.32435 .40002 .33098 .40666 .34151 .40307 .3349 .3964 Mtetra
.3349 .3964 .34151 .40307 .35207 .39946 .34549 .39277 Mtetra
.34549 .39277 .35207 .39946 .36268 .39584 .35613 .38912 Mtetra
.35613 .38912 .36268 .39584 .37333 .39221 .3668 .38546 Mtetra
.3668 .38546 .37333 .39221 .38402 .38856 .37752 .38178 Mtetra
.37752 .38178 .38402 .38856 .39475 .3849 .38828 .37809 Mtetra
.38828 .37809 .39475 .3849 .40553 .38122 .39908 .37439 Mtetra
.39908 .37439 .40553 .38122 .41635 .37752 .40993 .37067 Mtetra
.40993 .37067 .41635 .37752 .42722 .37381 .42083 .36693 Mtetra
.42083 .36693 .42722 .37381 .43812 .37009 .43176 .36318 Mtetra
.43176 .36318 .43812 .37009 .44908 .36635 .44274 .35941 Mtetra
.44274 .35941 .44908 .36635 .46007 .3626 .45377 .35563 Mtetra
.45377 .35563 .46007 .3626 .47112 .35883 .46484 .35183 Mtetra
.46484 .35183 .47112 .35883 .4822 .35505 .47595 .34802 Mtetra
.47595 .34802 .4822 .35505 .49333 .35125 .48711 .34419 Mtetra
.48711 .34419 .49333 .35125 .50451 .34743 .49832 .34035 Mtetra
.49832 .34035 .50451 .34743 .51573 .3436 .50957 .33649 Mtetra
.50957 .33649 .51573 .3436 .527 .33975 .52087 .33261 Mtetra
.52087 .33261 .527 .33975 .53832 .33589 .53222 .32872 Mtetra
.53222 .32872 .53832 .33589 .54968 .33201 .54361 .32481 Mtetra
.54361 .32481 .54968 .33201 .56109 .32812 .55505 .32089 Mtetra
.55505 .32089 .56109 .32812 .57255 .32421 .56654 .31695 Mtetra
.56654 .31695 .57255 .32421 .58405 .32028 .57808 .31299 Mtetra
.57808 .31299 .58405 .32028 .5956 .31634 .58966 .30902 Mtetra
.58966 .30902 .5956 .31634 .6072 .31238 .60129 .30503 Mtetra
.60129 .30503 .6072 .31238 .61885 .3084 .61297 .30102 Mtetra
.61297 .30102 .61885 .3084 .63055 .30441 .6247 .297 Mtetra
.6247 .297 .63055 .30441 .64229 .3004 .63648 .29296 Mtetra
.63648 .29296 .64229 .3004 .65409 .29638 .64831 .2889 Mtetra
.64831 .2889 .65409 .29638 .66593 .29233 .66019 .28483 Mtetra
.66019 .28483 .66593 .29233 .67783 .28827 .67212 .28073 Mtetra
.67212 .28073 .67783 .28827 .68977 .2842 .6841 .27662 Mtetra
.6841 .27662 .68977 .2842 .70177 .2801 .69613 .2725 Mtetra
.69613 .2725 .70177 .2801 .71382 .27599 .70821 .26835 Mtetra
.70821 .26835 .71382 .27599 .72591 .27186 .72035 .26419 Mtetra
.72035 .26419 .72591 .27186 .73806 .26771 .73253 .26001 Mtetra
.73253 .26001 .73806 .26771 .75026 .26355 .74477 .25581 Mtetra
.74477 .25581 .75026 .26355 .76252 .25937 .75706 .2516 Mtetra
.75706 .2516 .76252 .25937 .77482 .25517 .7694 .24736 Mtetra
.7694 .24736 .77482 .25517 .78718 .25095 .7818 .24311 Mtetra
.12449 .45992 .13161 .46613 .1414 .46277 .13431 .45654 Mtetra
.13431 .45654 .1414 .46277 .15123 .4594 .14416 .45314 Mtetra
.14416 .45314 .15123 .4594 .1611 .45602 .15405 .44973 Mtetra
.15405 .44973 .1611 .45602 .17101 .45262 .16398 .44631 Mtetra
.16398 .44631 .17101 .45262 .18096 .44921 .17395 .44287 Mtetra
.17395 .44287 .18096 .44921 .19094 .44578 .18396 .43942 Mtetra
.18396 .43942 .19094 .44578 .20097 .44234 .194 .43596 Mtetra
.194 .43596 .20097 .44234 .21103 .43889 .20409 .43248 Mtetra
.20409 .43248 .21103 .43889 .22113 .43543 .21421 .42899 Mtetra
.21421 .42899 .22113 .43543 .23127 .43195 .22437 .42549 Mtetra
.22437 .42549 .23127 .43195 .24145 .42846 .23458 .42197 Mtetra
.23458 .42197 .24145 .42846 .25167 .42495 .24482 .41844 Mtetra
.24482 .41844 .25167 .42495 .26193 .42143 .25511 .4149 Mtetra
.25511 .4149 .26193 .42143 .27223 .4179 .26543 .41134 Mtetra
.26543 .41134 .27223 .4179 .28258 .41435 .2758 .40776 Mtetra
.2758 .40776 .28258 .41435 .29296 .41079 .28621 .40418 Mtetra
.28621 .40418 .29296 .41079 .30338 .40721 .29665 .40057 Mtetra
.29665 .40057 .30338 .40721 .31385 .40362 .30714 .39696 Mtetra
.30714 .39696 .31385 .40362 .32435 .40002 .31768 .39333 Mtetra
.31768 .39333 .32435 .40002 .3349 .3964 .32825 .38968 Mtetra
.32825 .38968 .3349 .3964 .34549 .39277 .33887 .38602 Mtetra
.33887 .38602 .34549 .39277 .35613 .38912 .34952 .38235 Mtetra
.34952 .38235 .35613 .38912 .3668 .38546 .36023 .37866 Mtetra
.36023 .37866 .3668 .38546 .37752 .38178 .37097 .37496 Mtetra
.37097 .37496 .37752 .38178 .38828 .37809 .38176 .37124 Mtetra
.38176 .37124 .38828 .37809 .39908 .37439 .39259 .3675 Mtetra
.39259 .3675 .39908 .37439 .40993 .37067 .40347 .36376 Mtetra
.40347 .36376 .40993 .37067 .42083 .36693 .41439 .35999 Mtetra
.41439 .35999 .42083 .36693 .43176 .36318 .42535 .35621 Mtetra
.42535 .35621 .43176 .36318 .44274 .35941 .43636 .35242 Mtetra
.43636 .35242 .44274 .35941 .45377 .35563 .44741 .34861 Mtetra
.44741 .34861 .45377 .35563 .46484 .35183 .45851 .34478 Mtetra
.45851 .34478 .46484 .35183 .47595 .34802 .46966 .34094 Mtetra
.46966 .34094 .47595 .34802 .48711 .34419 .48085 .33708 Mtetra
.48085 .33708 .48711 .34419 .49832 .34035 .49208 .33321 Mtetra
.49208 .33321 .49832 .34035 .50957 .33649 .50337 .32932 Mtetra
.50337 .32932 .50957 .33649 .52087 .33261 .5147 .32541 Mtetra
.5147 .32541 .52087 .33261 .53222 .32872 .52607 .32149 Mtetra
.52607 .32149 .53222 .32872 .54361 .32481 .5375 .31755 Mtetra
.5375 .31755 .54361 .32481 .55505 .32089 .54897 .3136 Mtetra
.54897 .3136 .55505 .32089 .56654 .31695 .56049 .30963 Mtetra
.56049 .30963 .56654 .31695 .57808 .31299 .57206 .30564 Mtetra
.57206 .30564 .57808 .31299 .58966 .30902 .58367 .30164 Mtetra
.58367 .30164 .58966 .30902 .60129 .30503 .59534 .29762 Mtetra
.59534 .29762 .60129 .30503 .61297 .30102 .60705 .29358 Mtetra
.60705 .29358 .61297 .30102 .6247 .297 .61881 .28952 Mtetra
.61881 .28952 .6247 .297 .63648 .29296 .63063 .28545 Mtetra
.63063 .28545 .63648 .29296 .64831 .2889 .64249 .28136 Mtetra
.64249 .28136 .64831 .2889 .66019 .28483 .6544 .27726 Mtetra
.6544 .27726 .66019 .28483 .67212 .28073 .66637 .27313 Mtetra
.66637 .27313 .67212 .28073 .6841 .27662 .67838 .26899 Mtetra
.67838 .26899 .6841 .27662 .69613 .2725 .69045 .26483 Mtetra
.69045 .26483 .69613 .2725 .70821 .26835 .70256 .26066 Mtetra
.70256 .26066 .70821 .26835 .72035 .26419 .71473 .25646 Mtetra
.71473 .25646 .72035 .26419 .73253 .26001 .72695 .25225 Mtetra
.72695 .25225 .73253 .26001 .74477 .25581 .73923 .24802 Mtetra
.73923 .24802 .74477 .25581 .75706 .2516 .75156 .24377 Mtetra
.75156 .24377 .75706 .2516 .7694 .24736 .76394 .2395 Mtetra
.76394 .2395 .7694 .24736 .7818 .24311 .77637 .23521 Mtetra
.11732 .45366 .12449 .45992 .13431 .45654 .12716 .45026 Mtetra
.12716 .45026 .13431 .45654 .14416 .45314 .13703 .44684 Mtetra
.13703 .44684 .14416 .45314 .15405 .44973 .14695 .4434 Mtetra
.14695 .4434 .15405 .44973 .16398 .44631 .1569 .43995 Mtetra
.1569 .43995 .16398 .44631 .17395 .44287 .16689 .43649 Mtetra
.16689 .43649 .17395 .44287 .18396 .43942 .17692 .43302 Mtetra
.17692 .43302 .18396 .43942 .194 .43596 .18699 .42953 Mtetra
.18699 .42953 .194 .43596 .20409 .43248 .19709 .42603 Mtetra
.19709 .42603 .20409 .43248 .21421 .42899 .20724 .42251 Mtetra
.20724 .42251 .21421 .42899 .22437 .42549 .21743 .41899 Mtetra
.21743 .41899 .22437 .42549 .23458 .42197 .22766 .41544 Mtetra
.22766 .41544 .23458 .42197 .24482 .41844 .23792 .41189 Mtetra
.23792 .41189 .24482 .41844 .25511 .4149 .24823 .40831 Mtetra
.24823 .40831 .25511 .4149 .26543 .41134 .25858 .40473 Mtetra
.25858 .40473 .26543 .41134 .2758 .40776 .26897 .40113 Mtetra
.26897 .40113 .2758 .40776 .28621 .40418 .2794 .39752 Mtetra
.2794 .39752 .28621 .40418 .29665 .40057 .28988 .39389 Mtetra
.28988 .39389 .29665 .40057 .30714 .39696 .30039 .39025 Mtetra
.30039 .39025 .30714 .39696 .31768 .39333 .31095 .38659 Mtetra
.31095 .38659 .31768 .39333 .32825 .38968 .32155 .38292 Mtetra
.32155 .38292 .32825 .38968 .33887 .38602 .33219 .37923 Mtetra
.33219 .37923 .33887 .38602 .34952 .38235 .34288 .37553 Mtetra
.34288 .37553 .34952 .38235 .36023 .37866 .3536 .37181 Mtetra
.3536 .37181 .36023 .37866 .37097 .37496 .36437 .36808 Mtetra
.36437 .36808 .37097 .37496 .38176 .37124 .37519 .36433 Mtetra
.37519 .36433 .38176 .37124 .39259 .3675 .38605 .36057 Mtetra
.38605 .36057 .39259 .3675 .40347 .36376 .39695 .35679 Mtetra
.39695 .35679 .40347 .36376 .41439 .35999 .4079 .353 Mtetra
.4079 .353 .41439 .35999 .42535 .35621 .41889 .34919 Mtetra
.41889 .34919 .42535 .35621 .43636 .35242 .42993 .34537 Mtetra
.42993 .34537 .43636 .35242 .44741 .34861 .44101 .34153 Mtetra
.44101 .34153 .44741 .34861 .45851 .34478 .45214 .33768 Mtetra
.45214 .33768 .45851 .34478 .46966 .34094 .46331 .33381 Mtetra
.46331 .33381 .46966 .34094 .48085 .33708 .47453 .32992 Mtetra
.47453 .32992 .48085 .33708 .49208 .33321 .4858 .32602 Mtetra
.4858 .32602 .49208 .33321 .50337 .32932 .49711 .3221 Mtetra
.49711 .3221 .50337 .32932 .5147 .32541 .50847 .31816 Mtetra
.50847 .31816 .5147 .32541 .52607 .32149 .51988 .31421 Mtetra
.51988 .31421 .52607 .32149 .5375 .31755 .53134 .31024 Mtetra
.53134 .31024 .5375 .31755 .54897 .3136 .54284 .30626 Mtetra
.54284 .30626 .54897 .3136 .56049 .30963 .55439 .30226 Mtetra
.55439 .30226 .56049 .30963 .57206 .30564 .56599 .29824 Mtetra
.56599 .29824 .57206 .30564 .58367 .30164 .57764 .2942 Mtetra
.57764 .2942 .58367 .30164 .59534 .29762 .58933 .29015 Mtetra
.58933 .29015 .59534 .29762 .60705 .29358 .60108 .28608 Mtetra
.60108 .28608 .60705 .29358 .61881 .28952 .61288 .28199 Mtetra
.61288 .28199 .61881 .28952 .63063 .28545 .62472 .27789 Mtetra
.62472 .27789 .63063 .28545 .64249 .28136 .63662 .27377 Mtetra
.63662 .27377 .64249 .28136 .6544 .27726 .64857 .26963 Mtetra
.64857 .26963 .6544 .27726 .66637 .27313 .66057 .26547 Mtetra
.66057 .26547 .66637 .27313 .67838 .26899 .67262 .2613 Mtetra
.67262 .2613 .67838 .26899 .69045 .26483 .68472 .25711 Mtetra
.68472 .25711 .69045 .26483 .70256 .26066 .69687 .2529 Mtetra
.69687 .2529 .70256 .26066 .71473 .25646 .70908 .24867 Mtetra
.70908 .24867 .71473 .25646 .72695 .25225 .72133 .24442 Mtetra
.72133 .24442 .72695 .25225 .73923 .24802 .73365 .24016 Mtetra
.73365 .24016 .73923 .24802 .75156 .24377 .74601 .23587 Mtetra
.74601 .23587 .75156 .24377 .76394 .2395 .75843 .23157 Mtetra
.75843 .23157 .76394 .2395 .77637 .23521 .7709 .22725 Mtetra
.1101 .44736 .11732 .45366 .12716 .45026 .11996 .44393 Mtetra
.11996 .44393 .12716 .45026 .13703 .44684 .12986 .44049 Mtetra
.12986 .44049 .13703 .44684 .14695 .4434 .13979 .43703 Mtetra
.13979 .43703 .14695 .4434 .1569 .43995 .14976 .43355 Mtetra
.14976 .43355 .1569 .43995 .16689 .43649 .15978 .43007 Mtetra
.15978 .43007 .16689 .43649 .17692 .43302 .16983 .42657 Mtetra
.16983 .42657 .17692 .43302 .18699 .42953 .17992 .42306 Mtetra
.17992 .42306 .18699 .42953 .19709 .42603 .19005 .41953 Mtetra
.19005 .41953 .19709 .42603 .20724 .42251 .20022 .41599 Mtetra
.20022 .41599 .20724 .42251 .21743 .41899 .21043 .41243 Mtetra
.21043 .41243 .21743 .41899 .22766 .41544 .22068 .40886 Mtetra
.22068 .40886 .22766 .41544 .23792 .41189 .23097 .40528 Mtetra
.23097 .40528 .23792 .41189 .24823 .40831 .24131 .40168 Mtetra
.24131 .40168 .24823 .40831 .25858 .40473 .25168 .39807 Mtetra
.25168 .39807 .25858 .40473 .26897 .40113 .26209 .39445 Mtetra
.26209 .39445 .26897 .40113 .2794 .39752 .27255 .39081 Mtetra
.27255 .39081 .2794 .39752 .28988 .39389 .28305 .38715 Mtetra
.28305 .38715 .28988 .39389 .30039 .39025 .29359 .38348 Mtetra
.29359 .38348 .30039 .39025 .31095 .38659 .30417 .3798 Mtetra
.30417 .3798 .31095 .38659 .32155 .38292 .3148 .3761 Mtetra
.3148 .3761 .32155 .38292 .33219 .37923 .32546 .37238 Mtetra
.32546 .37238 .33219 .37923 .34288 .37553 .33618 .36866 Mtetra
.33618 .36866 .34288 .37553 .3536 .37181 .34693 .36491 Mtetra
.34693 .36491 .3536 .37181 .36437 .36808 .35773 .36115 Mtetra
.35773 .36115 .36437 .36808 .37519 .36433 .36857 .35738 Mtetra
.36857 .35738 .37519 .36433 .38605 .36057 .37946 .35359 Mtetra
.37946 .35359 .38605 .36057 .39695 .35679 .39039 .34978 Mtetra
.39039 .34978 .39695 .35679 .4079 .353 .40136 .34596 Mtetra
.40136 .34596 .4079 .353 .41889 .34919 .41238 .34212 Mtetra
.41238 .34212 .41889 .34919 .42993 .34537 .42345 .33827 Mtetra
.42345 .33827 .42993 .34537 .44101 .34153 .43456 .3344 Mtetra
.43456 .3344 .44101 .34153 .45214 .33768 .44572 .33052 Mtetra
.44572 .33052 .45214 .33768 .46331 .33381 .45692 .32662 Mtetra
.45692 .32662 .46331 .33381 .47453 .32992 .46817 .3227 Mtetra
.46817 .3227 .47453 .32992 .4858 .32602 .47947 .31877 Mtetra
.47947 .31877 .4858 .32602 .49711 .3221 .49081 .31482 Mtetra
.49081 .31482 .49711 .3221 .50847 .31816 .5022 .31085 Mtetra
.5022 .31085 .50847 .31816 .51988 .31421 .51364 .30687 Mtetra
.51364 .30687 .51988 .31421 .53134 .31024 .52513 .30287 Mtetra
.52513 .30287 .53134 .31024 .54284 .30626 .53666 .29886 Mtetra
.53666 .29886 .54284 .30626 .55439 .30226 .54824 .29482 Mtetra
.54824 .29482 .55439 .30226 .56599 .29824 .55988 .29077 Mtetra
.55988 .29077 .56599 .29824 .57764 .2942 .57156 .28671 Mtetra
.57156 .28671 .57764 .2942 .58933 .29015 .58329 .28262 Mtetra
.58329 .28262 .58933 .29015 .60108 .28608 .59507 .27852 Mtetra
.59507 .27852 .60108 .28608 .61288 .28199 .6069 .2744 Mtetra
.6069 .2744 .61288 .28199 .62472 .27789 .61878 .27027 Mtetra
.61878 .27027 .62472 .27789 .63662 .27377 .63071 .26611 Mtetra
.63071 .26611 .63662 .27377 .64857 .26963 .64269 .26194 Mtetra
.64269 .26194 .64857 .26963 .66057 .26547 .65472 .25775 Mtetra
.65472 .25775 .66057 .26547 .67262 .2613 .66681 .25355 Mtetra
.66681 .25355 .67262 .2613 .68472 .25711 .67894 .24932 Mtetra
.67894 .24932 .68472 .25711 .69687 .2529 .69113 .24508 Mtetra
.69113 .24508 .69687 .2529 .70908 .24867 .70337 .24082 Mtetra
.70337 .24082 .70908 .24867 .72133 .24442 .71567 .23653 Mtetra
.71567 .23653 .72133 .24442 .73365 .24016 .72802 .23224 Mtetra
.72802 .23224 .73365 .24016 .74601 .23587 .74042 .22792 Mtetra
.74042 .22792 .74601 .23587 .75843 .23157 .75288 .22358 Mtetra
.75288 .22358 .75843 .23157 .7709 .22725 .76539 .21923 Mtetra
.10283 .44102 .1101 .44736 .11996 .44393 .11271 .43756 Mtetra
.11271 .43756 .11996 .44393 .12986 .44049 .12263 .43409 Mtetra
.12263 .43409 .12986 .44049 .13979 .43703 .13258 .43061 Mtetra
.13258 .43061 .13979 .43703 .14976 .43355 .14258 .42711 Mtetra
.14258 .42711 .14976 .43355 .15978 .43007 .15261 .4236 Mtetra
.15261 .4236 .15978 .43007 .16983 .42657 .16269 .42007 Mtetra
.16269 .42007 .16983 .42657 .17992 .42306 .1728 .41653 Mtetra
.1728 .41653 .17992 .42306 .19005 .41953 .18295 .41298 Mtetra
.18295 .41298 .19005 .41953 .20022 .41599 .19315 .40941 Mtetra
.19315 .40941 .20022 .41599 .21043 .41243 .20338 .40583 Mtetra
.20338 .40583 .21043 .41243 .22068 .40886 .21366 .40224 Mtetra
.21366 .40224 .22068 .40886 .23097 .40528 .22397 .39863 Mtetra
.22397 .39863 .23097 .40528 .24131 .40168 .23433 .39501 Mtetra
.23433 .39501 .24131 .40168 .25168 .39807 .24473 .39137 Mtetra
.24473 .39137 .25168 .39807 .26209 .39445 .25516 .38772 Mtetra
.25516 .38772 .26209 .39445 .27255 .39081 .26565 .38405 Mtetra
.26565 .38405 .27255 .39081 .28305 .38715 .27617 .38037 Mtetra
.27617 .38037 .28305 .38715 .29359 .38348 .28674 .37667 Mtetra
.28674 .37667 .29359 .38348 .30417 .3798 .29734 .37296 Mtetra
.29734 .37296 .30417 .3798 .3148 .3761 .30799 .36923 Mtetra
.30799 .36923 .3148 .3761 .32546 .37238 .31869 .36549 Mtetra
.31869 .36549 .32546 .37238 .33618 .36866 .32943 .36173 Mtetra
.32943 .36173 .33618 .36866 .34693 .36491 .34021 .35796 Mtetra
.34021 .35796 .34693 .36491 .35773 .36115 .35103 .35417 Mtetra
.35103 .35417 .35773 .36115 .36857 .35738 .3619 .35037 Mtetra
.3619 .35037 .36857 .35738 .37946 .35359 .37282 .34655 Mtetra
.37282 .34655 .37946 .35359 .39039 .34978 .38377 .34271 Mtetra
.38377 .34271 .39039 .34978 .40136 .34596 .39478 .33886 Mtetra
.39478 .33886 .40136 .34596 .41238 .34212 .40583 .335 Mtetra
.40583 .335 .41238 .34212 .42345 .33827 .41692 .33112 Mtetra
.41692 .33112 .42345 .33827 .43456 .3344 .42806 .32722 Mtetra
.42806 .32722 .43456 .3344 .44572 .33052 .43925 .3233 Mtetra
.43925 .3233 .44572 .33052 .45692 .32662 .45048 .31937 Mtetra
.45048 .31937 .45692 .32662 .46817 .3227 .46176 .31543 Mtetra
.46176 .31543 .46817 .3227 .47947 .31877 .47309 .31146 Mtetra
.47309 .31146 .47947 .31877 .49081 .31482 .48446 .30748 Mtetra
.48446 .30748 .49081 .31482 .5022 .31085 .49588 .30349 Mtetra
.49588 .30349 .5022 .31085 .51364 .30687 .50735 .29948 Mtetra
.50735 .29948 .51364 .30687 .52513 .30287 .51887 .29545 Mtetra
.51887 .29545 .52513 .30287 .53666 .29886 .53043 .2914 Mtetra
.53043 .2914 .53666 .29886 .54824 .29482 .54205 .28733 Mtetra
.54205 .28733 .54824 .29482 .55988 .29077 .55371 .28325 Mtetra
.55371 .28325 .55988 .29077 .57156 .28671 .56543 .27915 Mtetra
.56543 .27915 .57156 .28671 .58329 .28262 .57719 .27504 Mtetra
.57719 .27504 .58329 .28262 .59507 .27852 .589 .27091 Mtetra
.589 .27091 .59507 .27852 .6069 .2744 .60087 .26675 Mtetra
.60087 .26675 .6069 .2744 .61878 .27027 .61278 .26259 Mtetra
.61278 .26259 .61878 .27027 .63071 .26611 .62475 .2584 Mtetra
.62475 .2584 .63071 .26611 .64269 .26194 .63676 .25419 Mtetra
.63676 .25419 .64269 .26194 .65472 .25775 .64883 .24997 Mtetra
.64883 .24997 .65472 .25775 .66681 .25355 .66095 .24573 Mtetra
.66095 .24573 .66681 .25355 .67894 .24932 .67312 .24147 Mtetra
.67312 .24147 .67894 .24932 .69113 .24508 .68535 .23719 Mtetra
.68535 .23719 .69113 .24508 .70337 .24082 .69763 .2329 Mtetra
.69763 .2329 .70337 .24082 .71567 .23653 .70996 .22858 Mtetra
.70996 .22858 .71567 .23653 .72802 .23224 .72234 .22425 Mtetra
.72234 .22425 .72802 .23224 .74042 .22792 .73478 .2199 Mtetra
.73478 .2199 .74042 .22792 .75288 .22358 .74728 .21553 Mtetra
.74728 .21553 .75288 .22358 .76539 .21923 .75983 .21113 Mtetra
.09551 .43462 .10283 .44102 .11271 .43756 .10541 .43114 Mtetra
.10541 .43114 .11271 .43756 .12263 .43409 .11535 .42765 Mtetra
.11535 .42765 .12263 .43409 .13258 .43061 .12532 .42414 Mtetra
.12532 .42414 .13258 .43061 .14258 .42711 .13534 .42062 Mtetra
.13534 .42062 .14258 .42711 .15261 .4236 .1454 .41708 Mtetra
.1454 .41708 .15261 .4236 .16269 .42007 .15549 .41353 Mtetra
.15549 .41353 .16269 .42007 .1728 .41653 .16563 .40996 Mtetra
.16563 .40996 .1728 .41653 .18295 .41298 .17581 .40639 Mtetra
.17581 .40639 .18295 .41298 .19315 .40941 .18602 .40279 Mtetra
.18602 .40279 .19315 .40941 .20338 .40583 .19628 .39919 Mtetra
.19628 .39919 .20338 .40583 .21366 .40224 .20658 .39556 Mtetra
.20658 .39556 .21366 .40224 .22397 .39863 .21692 .39193 Mtetra
.21692 .39193 .22397 .39863 .23433 .39501 .2273 .38828 Mtetra
.2273 .38828 .23433 .39501 .24473 .39137 .23772 .38461 Mtetra
.23772 .38461 .24473 .39137 .25516 .38772 .24819 .38093 Mtetra
.24819 .38093 .25516 .38772 .26565 .38405 .25869 .37724 Mtetra
.25869 .37724 .26565 .38405 .27617 .38037 .26924 .37353 Mtetra
.26924 .37353 .27617 .38037 .28674 .37667 .27983 .3698 Mtetra
.27983 .3698 .28674 .37667 .29734 .37296 .29046 .36606 Mtetra
.29046 .36606 .29734 .37296 .30799 .36923 .30114 .36231 Mtetra
.30114 .36231 .30799 .36923 .31869 .36549 .31186 .35854 Mtetra
.31186 .35854 .31869 .36549 .32943 .36173 .32263 .35475 Mtetra
.32263 .35475 .32943 .36173 .34021 .35796 .33343 .35095 Mtetra
.33343 .35095 .34021 .35796 .35103 .35417 .34429 .34714 Mtetra
.34429 .34714 .35103 .35417 .3619 .35037 .35518 .34331 Mtetra
.35518 .34331 .3619 .35037 .37282 .34655 .36612 .33946 Mtetra
.36612 .33946 .37282 .34655 .38377 .34271 .37711 .33559 Mtetra
.37711 .33559 .38377 .34271 .39478 .33886 .38814 .33171 Mtetra
.38814 .33171 .39478 .33886 .40583 .335 .39922 .32782 Mtetra
.39922 .32782 .40583 .335 .41692 .33112 .41034 .32391 Mtetra
.41034 .32391 .41692 .33112 .42806 .32722 .42151 .31998 Mtetra
.42151 .31998 .42806 .32722 .43925 .3233 .43273 .31604 Mtetra
.43273 .31604 .43925 .3233 .45048 .31937 .44399 .31208 Mtetra
.44399 .31208 .45048 .31937 .46176 .31543 .4553 .3081 Mtetra
.4553 .3081 .46176 .31543 .47309 .31146 .46666 .3041 Mtetra
.46666 .3041 .47309 .31146 .48446 .30748 .47806 .30009 Mtetra
.47806 .30009 .48446 .30748 .49588 .30349 .48951 .29607 Mtetra
.48951 .29607 .49588 .30349 .50735 .29948 .50101 .29202 Mtetra
.50101 .29202 .50735 .29948 .51887 .29545 .51256 .28796 Mtetra
.51256 .28796 .51887 .29545 .53043 .2914 .52416 .28388 Mtetra
.52416 .28388 .53043 .2914 .54205 .28733 .53581 .27979 Mtetra
.53581 .27979 .54205 .28733 .55371 .28325 .5475 .27567 Mtetra
.5475 .27567 .55371 .28325 .56543 .27915 .55925 .27154 Mtetra
.55925 .27154 .56543 .27915 .57719 .27504 .57105 .26739 Mtetra
.57105 .26739 .57719 .27504 .589 .27091 .58289 .26323 Mtetra
.58289 .26323 .589 .27091 .60087 .26675 .59479 .25904 Mtetra
.59479 .25904 .60087 .26675 .61278 .26259 .60674 .25484 Mtetra
.60674 .25484 .61278 .26259 .62475 .2584 .61874 .25062 Mtetra
.61874 .25062 .62475 .2584 .63676 .25419 .63079 .24638 Mtetra
.63079 .24638 .63676 .25419 .64883 .24997 .64289 .24213 Mtetra
.64289 .24213 .64883 .24997 .66095 .24573 .65505 .23785 Mtetra
.65505 .23785 .66095 .24573 .67312 .24147 .66726 .23356 Mtetra
.66726 .23356 .67312 .24147 .68535 .23719 .67952 .22925 Mtetra
.67952 .22925 .68535 .23719 .69763 .2329 .69183 .22492 Mtetra
.69183 .22492 .69763 .2329 .70996 .22858 .7042 .22057 Mtetra
.7042 .22057 .70996 .22858 .72234 .22425 .71663 .2162 Mtetra
.71663 .2162 .72234 .22425 .73478 .2199 .7291 .21181 Mtetra
.7291 .21181 .73478 .2199 .74728 .21553 .74163 .2074 Mtetra
.74163 .2074 .74728 .21553 .75983 .21113 .75422 .20298 Mtetra
.08813 .42819 .09551 .43462 .10541 .43114 .09805 .42468 Mtetra
.09805 .42468 .10541 .43114 .11535 .42765 .10801 .42116 Mtetra
.10801 .42116 .11535 .42765 .12532 .42414 .11801 .41762 Mtetra
.11801 .41762 .12532 .42414 .13534 .42062 .12805 .41408 Mtetra
.12805 .41408 .13534 .42062 .1454 .41708 .13813 .41051 Mtetra
.13813 .41051 .1454 .41708 .15549 .41353 .14825 .40694 Mtetra
.14825 .40694 .15549 .41353 .16563 .40996 .15841 .40335 Mtetra
.15841 .40335 .16563 .40996 .17581 .40639 .16861 .39974 Mtetra
.16861 .39974 .17581 .40639 .18602 .40279 .17885 .39612 Mtetra
.17885 .39612 .18602 .40279 .19628 .39919 .18913 .39249 Mtetra
.18913 .39249 .19628 .39919 .20658 .39556 .19945 .38884 Mtetra
.19945 .38884 .20658 .39556 .21692 .39193 .20981 .38518 Mtetra
.20981 .38518 .21692 .39193 .2273 .38828 .22022 .3815 Mtetra
.22022 .3815 .2273 .38828 .23772 .38461 .23066 .37781 Mtetra
.23066 .37781 .23772 .38461 .24819 .38093 .24115 .3741 Mtetra
.24115 .3741 .24819 .38093 .25869 .37724 .25168 .37038 Mtetra
.25168 .37038 .25869 .37724 .26924 .37353 .26226 .36664 Mtetra
.26226 .36664 .26924 .37353 .27983 .3698 .27287 .36289 Mtetra
.27287 .36289 .27983 .3698 .29046 .36606 .28353 .35912 Mtetra
.28353 .35912 .29046 .36606 .30114 .36231 .29424 .35534 Mtetra
.29424 .35534 .30114 .36231 .31186 .35854 .30498 .35154 Mtetra
.30498 .35154 .31186 .35854 .32263 .35475 .31577 .34773 Mtetra
.31577 .34773 .32263 .35475 .33343 .35095 .32661 .3439 Mtetra
.32661 .3439 .33343 .35095 .34429 .34714 .33749 .34005 Mtetra
.33749 .34005 .34429 .34714 .35518 .34331 .34841 .33619 Mtetra
.34841 .33619 .35518 .34331 .36612 .33946 .35938 .33231 Mtetra
.35938 .33231 .36612 .33946 .37711 .33559 .3704 .32842 Mtetra
.3704 .32842 .37711 .33559 .38814 .33171 .38146 .32451 Mtetra
.38146 .32451 .38814 .33171 .39922 .32782 .39256 .32059 Mtetra
.39256 .32059 .39922 .32782 .41034 .32391 .40371 .31664 Mtetra
.40371 .31664 .41034 .32391 .42151 .31998 .41491 .31269 Mtetra
.41491 .31269 .42151 .31998 .43273 .31604 .42616 .30871 Mtetra
.42616 .30871 .43273 .31604 .44399 .31208 .43745 .30472 Mtetra
.43745 .30472 .44399 .31208 .4553 .3081 .44879 .30071 Mtetra
.44879 .30071 .4553 .3081 .46666 .3041 .46018 .29669 Mtetra
.46018 .29669 .46666 .3041 .47806 .30009 .47161 .29265 Mtetra
.47161 .29265 .47806 .30009 .48951 .29607 .48309 .28859 Mtetra
.48309 .28859 .48951 .29607 .50101 .29202 .49463 .28451 Mtetra
.49463 .28451 .50101 .29202 .51256 .28796 .50621 .28042 Mtetra
.50621 .28042 .51256 .28796 .52416 .28388 .51784 .27631 Mtetra
.51784 .27631 .52416 .28388 .53581 .27979 .52952 .27218 Mtetra
.52952 .27218 .53581 .27979 .5475 .27567 .54124 .26803 Mtetra
.54124 .26803 .5475 .27567 .55925 .27154 .55302 .26387 Mtetra
.55302 .26387 .55925 .27154 .57105 .26739 .56485 .25969 Mtetra
.56485 .25969 .57105 .26739 .58289 .26323 .57673 .25549 Mtetra
.57673 .25549 .58289 .26323 .59479 .25904 .58866 .25127 Mtetra
.58866 .25127 .59479 .25904 .60674 .25484 .60065 .24704 Mtetra
.60065 .24704 .60674 .25484 .61874 .25062 .61268 .24278 Mtetra
.61268 .24278 .61874 .25062 .63079 .24638 .62477 .23851 Mtetra
.62477 .23851 .63079 .24638 .64289 .24213 .63691 .23422 Mtetra
.63691 .23422 .64289 .24213 .65505 .23785 .6491 .22991 Mtetra
.6491 .22991 .65505 .23785 .66726 .23356 .66134 .22559 Mtetra
.66134 .22559 .66726 .23356 .67952 .22925 .67364 .22124 Mtetra
.67364 .22124 .67952 .22925 .69183 .22492 .68599 .21687 Mtetra
.68599 .21687 .69183 .22492 .7042 .22057 .6984 .21249 Mtetra
.6984 .21249 .7042 .22057 .71663 .2162 .71086 .20808 Mtetra
.71086 .20808 .71663 .2162 .7291 .21181 .72338 .20366 Mtetra
.72338 .20366 .7291 .21181 .74163 .2074 .73595 .19922 Mtetra
.73595 .19922 .74163 .2074 .75422 .20298 .74857 .19475 Mtetra
.0807 .4217 .08813 .42819 .09805 .42468 .09064 .41817 Mtetra
.09064 .41817 .09805 .42468 .10801 .42116 .10063 .41462 Mtetra
.10063 .41462 .10801 .42116 .11801 .41762 .11065 .41106 Mtetra
.11065 .41106 .11801 .41762 .12805 .41408 .12071 .40749 Mtetra
.12071 .40749 .12805 .41408 .13813 .41051 .13081 .4039 Mtetra
.13081 .4039 .13813 .41051 .14825 .40694 .14095 .4003 Mtetra
.14095 .4003 .14825 .40694 .15841 .40335 .15113 .39668 Mtetra
.15113 .39668 .15841 .40335 .16861 .39974 .16136 .39305 Mtetra
.16136 .39305 .16861 .39974 .17885 .39612 .17162 .3894 Mtetra
.17162 .3894 .17885 .39612 .18913 .39249 .18192 .38574 Mtetra
.18192 .38574 .18913 .39249 .19945 .38884 .19227 .38207 Mtetra
.19227 .38207 .19945 .38884 .20981 .38518 .20266 .37838 Mtetra
.20266 .37838 .20981 .38518 .22022 .3815 .21308 .37467 Mtetra
.21308 .37467 .22022 .3815 .23066 .37781 .22356 .37095 Mtetra
.22356 .37095 .23066 .37781 .24115 .3741 .23407 .36722 Mtetra
.23407 .36722 .24115 .3741 .25168 .37038 .24463 .36347 Mtetra
.24463 .36347 .25168 .37038 .26226 .36664 .25522 .3597 Mtetra
.25522 .3597 .26226 .36664 .27287 .36289 .26587 .35592 Mtetra
.26587 .35592 .27287 .36289 .28353 .35912 .27655 .35213 Mtetra
.27655 .35213 .28353 .35912 .29424 .35534 .28728 .34831 Mtetra
.28728 .34831 .29424 .35534 .30498 .35154 .29805 .34449 Mtetra
.29805 .34449 .30498 .35154 .31577 .34773 .30887 .34064 Mtetra
.30887 .34064 .31577 .34773 .32661 .3439 .31973 .33678 Mtetra
.31973 .33678 .32661 .3439 .33749 .34005 .33064 .33291 Mtetra
.33064 .33291 .33749 .34005 .34841 .33619 .34159 .32902 Mtetra
.34159 .32902 .34841 .33619 .35938 .33231 .35259 .32511 Mtetra
.35259 .32511 .35938 .33231 .3704 .32842 .36363 .32119 Mtetra
.36363 .32119 .3704 .32842 .38146 .32451 .37472 .31725 Mtetra
.37472 .31725 .38146 .32451 .39256 .32059 .38585 .3133 Mtetra
.38585 .3133 .39256 .32059 .40371 .31664 .39703 .30932 Mtetra
.39703 .30932 .40371 .31664 .41491 .31269 .40826 .30533 Mtetra
.40826 .30533 .41491 .31269 .42616 .30871 .41954 .30133 Mtetra
.41954 .30133 .42616 .30871 .43745 .30472 .43086 .29731 Mtetra
.43086 .29731 .43745 .30472 .44879 .30071 .44223 .29327 Mtetra
.44223 .29327 .44879 .30071 .46018 .29669 .45365 .28921 Mtetra
.45365 .28921 .46018 .29669 .47161 .29265 .46511 .28514 Mtetra
.46511 .28514 .47161 .29265 .48309 .28859 .47663 .28105 Mtetra
.47663 .28105 .48309 .28859 .49463 .28451 .48819 .27694 Mtetra
.48819 .27694 .49463 .28451 .50621 .28042 .4998 .27282 Mtetra
.4998 .27282 .50621 .28042 .51784 .27631 .51146 .26867 Mtetra
.51146 .26867 .51784 .27631 .52952 .27218 .52317 .26451 Mtetra
.52317 .26451 .52952 .27218 .54124 .26803 .53494 .26033 Mtetra
.53494 .26033 .54124 .26803 .55302 .26387 .54675 .25614 Mtetra
.54675 .25614 .55302 .26387 .56485 .25969 .55861 .25192 Mtetra
.55861 .25192 .56485 .25969 .57673 .25549 .57053 .24769 Mtetra
.57053 .24769 .57673 .25549 .58866 .25127 .58249 .24344 Mtetra
.58249 .24344 .58866 .25127 .60065 .24704 .59451 .23917 Mtetra
.59451 .23917 .60065 .24704 .61268 .24278 .60658 .23488 Mtetra
.60658 .23488 .61268 .24278 .62477 .23851 .6187 .23058 Mtetra
.6187 .23058 .62477 .23851 .63691 .23422 .63087 .22625 Mtetra
.63087 .22625 .63691 .23422 .6491 .22991 .6431 .22191 Mtetra
.6431 .22191 .6491 .22991 .66134 .22559 .65538 .21755 Mtetra
.65538 .21755 .66134 .22559 .67364 .22124 .66772 .21316 Mtetra
.66772 .21316 .67364 .22124 .68599 .21687 .68011 .20876 Mtetra
.68011 .20876 .68599 .21687 .6984 .21249 .69255 .20434 Mtetra
.69255 .20434 .6984 .21249 .71086 .20808 .70505 .1999 Mtetra
.70505 .1999 .71086 .20808 .72338 .20366 .7176 .19544 Mtetra
.7176 .19544 .72338 .20366 .73595 .19922 .73021 .19096 Mtetra
.73021 .19096 .73595 .19922 .74857 .19475 .74288 .18646 Mtetra
.07322 .41517 .0807 .4217 .09064 .41817 .08318 .41161 Mtetra
.08318 .41161 .09064 .41817 .10063 .41462 .09318 .40804 Mtetra
.09318 .40804 .10063 .41462 .11065 .41106 .10323 .40445 Mtetra
.10323 .40445 .11065 .41106 .12071 .40749 .11331 .40085 Mtetra
.11331 .40085 .12071 .40749 .13081 .4039 .12343 .39724 Mtetra
.12343 .39724 .13081 .4039 .14095 .4003 .1336 .39361 Mtetra
.1336 .39361 .14095 .4003 .15113 .39668 .1438 .38996 Mtetra
.1438 .38996 .15113 .39668 .16136 .39305 .15405 .38631 Mtetra
.15405 .38631 .16136 .39305 .17162 .3894 .16434 .38263 Mtetra
.16434 .38263 .17162 .3894 .18192 .38574 .17466 .37895 Mtetra
.17466 .37895 .18192 .38574 .19227 .38207 .18503 .37524 Mtetra
.18503 .37524 .19227 .38207 .20266 .37838 .19544 .37153 Mtetra
.19544 .37153 .20266 .37838 .21308 .37467 .2059 .36779 Mtetra
.2059 .36779 .21308 .37467 .22356 .37095 .21639 .36404 Mtetra
.21639 .36404 .22356 .37095 .23407 .36722 .22693 .36028 Mtetra
.22693 .36028 .23407 .36722 .24463 .36347 .23751 .3565 Mtetra
.23751 .3565 .24463 .36347 .25522 .3597 .24814 .35271 Mtetra
.24814 .35271 .25522 .3597 .26587 .35592 .2588 .3489 Mtetra
.2588 .3489 .26587 .35592 .27655 .35213 .26952 .34508 Mtetra
.26952 .34508 .27655 .35213 .28728 .34831 .28027 .34124 Mtetra
.28027 .34124 .28728 .34831 .29805 .34449 .29107 .33738 Mtetra
.29107 .33738 .29805 .34449 .30887 .34064 .30192 .33351 Mtetra
.30192 .33351 .30887 .34064 .31973 .33678 .3128 .32962 Mtetra
.3128 .32962 .31973 .33678 .33064 .33291 .32374 .32572 Mtetra
.32374 .32572 .33064 .33291 .34159 .32902 .33472 .32179 Mtetra
.33472 .32179 .34159 .32902 .35259 .32511 .34574 .31786 Mtetra
.34574 .31786 .35259 .32511 .36363 .32119 .35681 .31391 Mtetra
.35681 .31391 .36363 .32119 .37472 .31725 .36793 .30994 Mtetra
.36793 .30994 .37472 .31725 .38585 .3133 .37909 .30595 Mtetra
.37909 .30595 .38585 .3133 .39703 .30932 .3903 .30195 Mtetra
.3903 .30195 .39703 .30932 .40826 .30533 .40156 .29793 Mtetra
.40156 .29793 .40826 .30533 .41954 .30133 .41286 .29389 Mtetra
.41286 .29389 .41954 .30133 .43086 .29731 .42422 .28984 Mtetra
.42422 .28984 .43086 .29731 .44223 .29327 .43562 .28577 Mtetra
.43562 .28577 .44223 .29327 .45365 .28921 .44706 .28168 Mtetra
.44706 .28168 .45365 .28921 .46511 .28514 .45856 .27757 Mtetra
.45856 .27757 .46511 .28514 .47663 .28105 .47011 .27345 Mtetra
.47011 .27345 .47663 .28105 .48819 .27694 .4817 .26931 Mtetra
.4817 .26931 .48819 .27694 .4998 .27282 .49335 .26515 Mtetra
.49335 .26515 .4998 .27282 .51146 .26867 .50504 .26098 Mtetra
.50504 .26098 .51146 .26867 .52317 .26451 .51678 .25678 Mtetra
.51678 .25678 .52317 .26451 .53494 .26033 .52858 .25257 Mtetra
.52858 .25257 .53494 .26033 .54675 .25614 .54042 .24834 Mtetra
.54042 .24834 .54675 .25614 .55861 .25192 .55232 .2441 Mtetra
.55232 .2441 .55861 .25192 .57053 .24769 .56427 .23983 Mtetra
.56427 .23983 .57053 .24769 .58249 .24344 .57627 .23554 Mtetra
.57627 .23554 .58249 .24344 .59451 .23917 .58832 .23124 Mtetra
.58832 .23124 .59451 .23917 .60658 .23488 .60042 .22692 Mtetra
.60042 .22692 .60658 .23488 .6187 .23058 .61258 .22258 Mtetra
.61258 .22258 .6187 .23058 .63087 .22625 .62479 .21822 Mtetra
.62479 .21822 .63087 .22625 .6431 .22191 .63705 .21384 Mtetra
.63705 .21384 .6431 .22191 .65538 .21755 .64937 .20944 Mtetra
.64937 .20944 .65538 .21755 .66772 .21316 .66174 .20502 Mtetra
.66174 .20502 .66772 .21316 .68011 .20876 .67417 .20059 Mtetra
.67417 .20059 .68011 .20876 .69255 .20434 .68665 .19613 Mtetra
.68665 .19613 .69255 .20434 .70505 .1999 .69919 .19165 Mtetra
.69919 .19165 .70505 .1999 .7176 .19544 .71178 .18716 Mtetra
.71178 .18716 .7176 .19544 .73021 .19096 .72443 .18264 Mtetra
.72443 .18264 .73021 .19096 .74288 .18646 .73713 .1781 Mtetra
.06568 .40859 .07322 .41517 .08318 .41161 .07566 .40501 Mtetra
.07566 .40501 .08318 .41161 .09318 .40804 .08569 .40141 Mtetra
.08569 .40141 .09318 .40804 .10323 .40445 .09575 .39779 Mtetra
.09575 .39779 .10323 .40445 .11331 .40085 .10586 .39417 Mtetra
.10586 .39417 .11331 .40085 .12343 .39724 .11601 .39053 Mtetra
.11601 .39053 .12343 .39724 .1336 .39361 .12619 .38687 Mtetra
.12619 .38687 .1336 .39361 .1438 .38996 .13642 .3832 Mtetra
.13642 .3832 .1438 .38996 .15405 .38631 .14669 .37951 Mtetra
.14669 .37951 .15405 .38631 .16434 .38263 .157 .37581 Mtetra
.157 .37581 .16434 .38263 .17466 .37895 .16735 .3721 Mtetra
.16735 .3721 .17466 .37895 .18503 .37524 .17774 .36837 Mtetra
.17774 .36837 .18503 .37524 .19544 .37153 .18818 .36462 Mtetra
.18818 .36462 .19544 .37153 .2059 .36779 .19866 .36086 Mtetra
.19866 .36086 .2059 .36779 .21639 .36404 .20918 .35709 Mtetra
.20918 .35709 .21639 .36404 .22693 .36028 .21974 .35329 Mtetra
.21974 .35329 .22693 .36028 .23751 .3565 .23035 .34949 Mtetra
.23035 .34949 .23751 .3565 .24814 .35271 .241 .34567 Mtetra
.241 .34567 .24814 .35271 .2588 .3489 .25169 .34183 Mtetra
.25169 .34183 .2588 .3489 .26952 .34508 .26243 .33797 Mtetra
.26243 .33797 .26952 .34508 .28027 .34124 .27321 .3341 Mtetra
.27321 .3341 .28027 .34124 .29107 .33738 .28404 .33022 Mtetra
.28404 .33022 .29107 .33738 .30192 .33351 .29491 .32632 Mtetra
.29491 .32632 .30192 .33351 .3128 .32962 .30582 .3224 Mtetra
.30582 .3224 .3128 .32962 .32374 .32572 .31678 .31846 Mtetra
.31678 .31846 .32374 .32572 .33472 .32179 .32779 .31451 Mtetra
.32779 .31451 .33472 .32179 .34574 .31786 .33884 .31055 Mtetra
.33884 .31055 .34574 .31786 .35681 .31391 .34994 .30656 Mtetra
.34994 .30656 .35681 .31391 .36793 .30994 .36109 .30256 Mtetra
.36109 .30256 .36793 .30994 .37909 .30595 .37228 .29855 Mtetra
.37228 .29855 .37909 .30595 .3903 .30195 .38352 .29451 Mtetra
.38352 .29451 .3903 .30195 .40156 .29793 .39481 .29046 Mtetra
.39481 .29046 .40156 .29793 .41286 .29389 .40614 .28639 Mtetra
.40614 .28639 .41286 .29389 .42422 .28984 .41752 .28231 Mtetra
.41752 .28231 .42422 .28984 .43562 .28577 .42895 .27821 Mtetra
.42895 .27821 .43562 .28577 .44706 .28168 .44043 .27409 Mtetra
.44043 .27409 .44706 .28168 .45856 .27757 .45196 .26995 Mtetra
.45196 .26995 .45856 .27757 .47011 .27345 .46354 .26579 Mtetra
.46354 .26579 .47011 .27345 .4817 .26931 .47516 .26162 Mtetra
.47516 .26162 .4817 .26931 .49335 .26515 .48684 .25743 Mtetra
.48684 .25743 .49335 .26515 .50504 .26098 .49856 .25322 Mtetra
.49856 .25322 .50504 .26098 .51678 .25678 .51034 .24899 Mtetra
.51034 .24899 .51678 .25678 .52858 .25257 .52217 .24475 Mtetra
.52217 .24475 .52858 .25257 .54042 .24834 .53405 .24049 Mtetra
.53405 .24049 .54042 .24834 .55232 .2441 .54598 .2362 Mtetra
.54598 .2362 .55232 .2441 .56427 .23983 .55796 .2319 Mtetra
.55796 .2319 .56427 .23983 .57627 .23554 .56999 .22758 Mtetra
.56999 .22758 .57627 .23554 .58832 .23124 .58208 .22325 Mtetra
.58208 .22325 .58832 .23124 .60042 .22692 .59422 .21889 Mtetra
.59422 .21889 .60042 .22692 .61258 .22258 .60641 .21451 Mtetra
.60641 .21451 .61258 .22258 .62479 .21822 .61866 .21012 Mtetra
.61866 .21012 .62479 .21822 .63705 .21384 .63096 .2057 Mtetra
.63096 .2057 .63705 .21384 .64937 .20944 .64331 .20127 Mtetra
.64331 .20127 .64937 .20944 .66174 .20502 .65572 .19682 Mtetra
.65572 .19682 .66174 .20502 .67417 .20059 .66819 .19234 Mtetra
.66819 .19234 .67417 .20059 .68665 .19613 .6807 .18785 Mtetra
.6807 .18785 .68665 .19613 .69919 .19165 .69328 .18334 Mtetra
.69328 .18334 .69919 .19165 .71178 .18716 .70591 .1788 Mtetra
.70591 .1788 .71178 .18716 .72443 .18264 .7186 .17425 Mtetra
.7186 .17425 .72443 .18264 .73713 .1781 .73134 .16968 Mtetra
.05808 .40196 .06568 .40859 .07566 .40501 .06809 .39835 Mtetra
.06809 .39835 .07566 .40501 .08569 .40141 .07814 .39473 Mtetra
.07814 .39473 .08569 .40141 .09575 .39779 .08823 .39109 Mtetra
.08823 .39109 .09575 .39779 .10586 .39417 .09835 .38743 Mtetra
.09835 .38743 .10586 .39417 .11601 .39053 .10852 .38376 Mtetra
.10852 .38376 .11601 .39053 .12619 .38687 .11873 .38008 Mtetra
.11873 .38008 .12619 .38687 .13642 .3832 .12898 .37638 Mtetra
.12898 .37638 .13642 .3832 .14669 .37951 .13927 .37267 Mtetra
.13927 .37267 .14669 .37951 .157 .37581 .14961 .36894 Mtetra
.14961 .36894 .157 .37581 .16735 .3721 .15998 .3652 Mtetra
.15998 .3652 .16735 .3721 .17774 .36837 .1704 .36144 Mtetra
.1704 .36144 .17774 .36837 .18818 .36462 .18086 .35767 Mtetra
.18086 .35767 .18818 .36462 .19866 .36086 .19136 .35388 Mtetra
.19136 .35388 .19866 .36086 .20918 .35709 .20191 .35007 Mtetra
.20191 .35007 .20918 .35709 .21974 .35329 .2125 .34625 Mtetra
.2125 .34625 .21974 .35329 .23035 .34949 .22313 .34242 Mtetra
.22313 .34242 .23035 .34949 .241 .34567 .2338 .33857 Mtetra
.2338 .33857 .241 .34567 .25169 .34183 .24452 .3347 Mtetra
.24452 .3347 .25169 .34183 .26243 .33797 .25529 .33082 Mtetra
.25529 .33082 .26243 .33797 .27321 .3341 .26609 .32692 Mtetra
.26609 .32692 .27321 .3341 .28404 .33022 .27695 .323 Mtetra
.27695 .323 .28404 .33022 .29491 .32632 .28784 .31907 Mtetra
.28784 .31907 .29491 .32632 .30582 .3224 .29879 .31512 Mtetra
.29879 .31512 .30582 .3224 .31678 .31846 .30978 .31116 Mtetra
.30978 .31116 .31678 .31846 .32779 .31451 .32081 .30718 Mtetra
.32081 .30718 .32779 .31451 .33884 .31055 .33189 .30318 Mtetra
.33189 .30318 .33884 .31055 .34994 .30656 .34302 .29917 Mtetra
.34302 .29917 .34994 .30656 .36109 .30256 .35419 .29513 Mtetra
.35419 .29513 .36109 .30256 .37228 .29855 .36541 .29109 Mtetra
.36541 .29109 .37228 .29855 .38352 .29451 .37668 .28702 Mtetra
.37668 .28702 .38352 .29451 .39481 .29046 .388 .28294 Mtetra
.388 .28294 .39481 .29046 .40614 .28639 .39936 .27884 Mtetra
.39936 .27884 .40614 .28639 .41752 .28231 .41077 .27472 Mtetra
.41077 .27472 .41752 .28231 .42895 .27821 .42224 .27059 Mtetra
.42224 .27059 .42895 .27821 .44043 .27409 .43375 .26643 Mtetra
.43375 .26643 .44043 .27409 .45196 .26995 .4453 .26226 Mtetra
.4453 .26226 .45196 .26995 .46354 .26579 .45691 .25808 Mtetra
.45691 .25808 .46354 .26579 .47516 .26162 .46857 .25387 Mtetra
.46857 .25387 .47516 .26162 .48684 .25743 .48028 .24965 Mtetra
.48028 .24965 .48684 .25743 .49856 .25322 .49204 .2454 Mtetra
.49204 .2454 .49856 .25322 .51034 .24899 .50385 .24114 Mtetra
.50385 .24114 .51034 .24899 .52217 .24475 .51571 .23686 Mtetra
.51571 .23686 .52217 .24475 .53405 .24049 .52762 .23257 Mtetra
.52762 .23257 .53405 .24049 .54598 .2362 .53959 .22825 Mtetra
.53959 .22825 .54598 .2362 .55796 .2319 .5516 .22392 Mtetra
.5516 .22392 .55796 .2319 .56999 .22758 .56367 .21956 Mtetra
.56367 .21956 .56999 .22758 .58208 .22325 .57579 .21519 Mtetra
.57579 .21519 .58208 .22325 .59422 .21889 .58797 .2108 Mtetra
.58797 .2108 .59422 .21889 .60641 .21451 .6002 .20638 Mtetra
.6002 .20638 .60641 .21451 .61866 .21012 .61248 .20195 Mtetra
.61248 .20195 .61866 .21012 .63096 .2057 .62481 .1975 Mtetra
.62481 .1975 .63096 .2057 .64331 .20127 .6372 .19303 Mtetra
.6372 .19303 .64331 .20127 .65572 .19682 .64965 .18854 Mtetra
.64965 .18854 .65572 .19682 .66819 .19234 .66215 .18403 Mtetra
.66215 .18403 .66819 .19234 .6807 .18785 .67471 .1795 Mtetra
.67471 .1795 .6807 .18785 .69328 .18334 .68732 .17495 Mtetra
.68732 .17495 .69328 .18334 .70591 .1788 .69999 .17038 Mtetra
.69999 .17038 .70591 .1788 .7186 .17425 .71272 .16579 Mtetra
.71272 .16579 .7186 .17425 .73134 .16968 .7255 .16118 Mtetra
.05043 .39529 .05808 .40196 .06809 .39835 .06046 .39165 Mtetra
.06046 .39165 .06809 .39835 .07814 .39473 .07053 .388 Mtetra
.07053 .388 .07814 .39473 .08823 .39109 .08064 .38433 Mtetra
.08064 .38433 .08823 .39109 .09835 .38743 .09079 .38065 Mtetra
.09079 .38065 .09835 .38743 .10852 .38376 .10098 .37695 Mtetra
.10098 .37695 .10852 .38376 .11873 .38008 .11121 .37324 Mtetra
.11121 .37324 .11873 .38008 .12898 .37638 .12149 .36952 Mtetra
.12149 .36952 .12898 .37638 .13927 .37267 .1318 .36578 Mtetra
.1318 .36578 .13927 .37267 .14961 .36894 .14216 .36202 Mtetra
.14216 .36202 .14961 .36894 .15998 .3652 .15256 .35825 Mtetra
.15256 .35825 .15998 .3652 .1704 .36144 .163 .35446 Mtetra
.163 .35446 .1704 .36144 .18086 .35767 .17348 .35066 Mtetra
.17348 .35066 .18086 .35767 .19136 .35388 .18401 .34684 Mtetra
.18401 .34684 .19136 .35388 .20191 .35007 .19458 .34301 Mtetra
.19458 .34301 .20191 .35007 .2125 .34625 .20519 .33916 Mtetra
.20519 .33916 .2125 .34625 .22313 .34242 .21585 .3353 Mtetra
.21585 .3353 .22313 .34242 .2338 .33857 .22655 .33142 Mtetra
.22655 .33142 .2338 .33857 .24452 .3347 .2373 .32752 Mtetra
.2373 .32752 .24452 .3347 .25529 .33082 .24809 .32361 Mtetra
.24809 .32361 .25529 .33082 .26609 .32692 .25892 .31968 Mtetra
.25892 .31968 .26609 .32692 .27695 .323 .2698 .31573 Mtetra
.2698 .31573 .27695 .323 .28784 .31907 .28073 .31177 Mtetra
.28073 .31177 .28784 .31907 .29879 .31512 .2917 .30779 Mtetra
.2917 .30779 .29879 .31512 .30978 .31116 .30271 .3038 Mtetra
.30271 .3038 .30978 .31116 .32081 .30718 .31378 .29978 Mtetra
.31378 .29978 .32081 .30718 .33189 .30318 .32489 .29576 Mtetra
.32489 .29576 .33189 .30318 .34302 .29917 .33604 .29171 Mtetra
.33604 .29171 .34302 .29917 .35419 .29513 .34724 .28765 Mtetra
.34724 .28765 .35419 .29513 .36541 .29109 .35849 .28357 Mtetra
.35849 .28357 .36541 .29109 .37668 .28702 .36979 .27947 Mtetra
.36979 .27947 .37668 .28702 .388 .28294 .38114 .27536 Mtetra
.38114 .27536 .388 .28294 .39936 .27884 .39253 .27122 Mtetra
.39253 .27122 .39936 .27884 .41077 .27472 .40397 .26707 Mtetra
.40397 .26707 .41077 .27472 .42224 .27059 .41547 .26291 Mtetra
.41547 .26291 .42224 .27059 .43375 .26643 .42701 .25872 Mtetra
.42701 .25872 .43375 .26643 .4453 .26226 .4386 .25452 Mtetra
.4386 .25452 .4453 .26226 .45691 .25808 .45024 .2503 Mtetra
.45024 .2503 .45691 .25808 .46857 .25387 .46193 .24606 Mtetra
.46193 .24606 .46857 .25387 .48028 .24965 .47367 .2418 Mtetra
.47367 .2418 .48028 .24965 .49204 .2454 .48546 .23752 Mtetra
.48546 .23752 .49204 .2454 .50385 .24114 .4973 .23323 Mtetra
.4973 .23323 .50385 .24114 .51571 .23686 .5092 .22892 Mtetra
.5092 .22892 .51571 .23686 .52762 .23257 .52114 .22458 Mtetra
.52114 .22458 .52762 .23257 .53959 .22825 .53314 .22023 Mtetra
.53314 .22023 .53959 .22825 .5516 .22392 .54519 .21586 Mtetra
.54519 .21586 .5516 .22392 .56367 .21956 .5573 .21147 Mtetra
.5573 .21147 .56367 .21956 .57579 .21519 .56945 .20706 Mtetra
.56945 .20706 .57579 .21519 .58797 .2108 .58166 .20264 Mtetra
.58166 .20264 .58797 .2108 .6002 .20638 .59393 .19819 Mtetra
.59393 .19819 .6002 .20638 .61248 .20195 .60625 .19372 Mtetra
.60625 .19372 .61248 .20195 .62481 .1975 .61862 .18923 Mtetra
.61862 .18923 .62481 .1975 .6372 .19303 .63105 .18473 Mtetra
.63105 .18473 .6372 .19303 .64965 .18854 .64353 .1802 Mtetra
.64353 .1802 .64965 .18854 .66215 .18403 .65607 .17565 Mtetra
.65607 .17565 .66215 .18403 .67471 .1795 .66866 .17109 Mtetra
.66866 .17109 .67471 .1795 .68732 .17495 .68132 .1665 Mtetra
.68132 .1665 .68732 .17495 .69999 .17038 .69402 .16189 Mtetra
.69402 .16189 .69999 .17038 .71272 .16579 .70679 .15726 Mtetra
.70679 .15726 .71272 .16579 .7255 .16118 .71961 .15261 Mtetra
.04273 .38856 .05043 .39529 .06046 .39165 .05278 .3849 Mtetra
.05278 .3849 .06046 .39165 .07053 .388 .06287 .38122 Mtetra
.06287 .38122 .07053 .388 .08064 .38433 .073 .37752 Mtetra
.073 .37752 .08064 .38433 .09079 .38065 .08317 .37381 Mtetra
.08317 .37381 .09079 .38065 .10098 .37695 .09339 .37009 Mtetra
.09339 .37009 .10098 .37695 .11121 .37324 .10364 .36635 Mtetra
.10364 .36635 .11121 .37324 .12149 .36952 .11394 .3626 Mtetra
.11394 .3626 .12149 .36952 .1318 .36578 .12428 .35883 Mtetra
.12428 .35883 .1318 .36578 .14216 .36202 .13466 .35505 Mtetra
.13466 .35505 .14216 .36202 .15256 .35825 .14508 .35125 Mtetra
.14508 .35125 .15256 .35825 .163 .35446 .15555 .34743 Mtetra
.15555 .34743 .163 .35446 .17348 .35066 .16605 .3436 Mtetra
.16605 .3436 .17348 .35066 .18401 .34684 .17661 .33975 Mtetra
.17661 .33975 .18401 .34684 .19458 .34301 .1872 .33589 Mtetra
.1872 .33589 .19458 .34301 .20519 .33916 .19784 .33201 Mtetra
.19784 .33201 .20519 .33916 .21585 .3353 .20852 .32812 Mtetra
.20852 .32812 .21585 .3353 .22655 .33142 .21925 .32421 Mtetra
.21925 .32421 .22655 .33142 .2373 .32752 .23002 .32028 Mtetra
.23002 .32028 .2373 .32752 .24809 .32361 .24084 .31634 Mtetra
.24084 .31634 .24809 .32361 .25892 .31968 .2517 .31238 Mtetra
.2517 .31238 .25892 .31968 .2698 .31573 .2626 .3084 Mtetra
.2626 .3084 .2698 .31573 .28073 .31177 .27355 .30441 Mtetra
.27355 .30441 .28073 .31177 .2917 .30779 .28455 .3004 Mtetra
.28455 .3004 .2917 .30779 .30271 .3038 .2956 .29638 Mtetra
.2956 .29638 .30271 .3038 .31378 .29978 .30669 .29233 Mtetra
.30669 .29233 .31378 .29978 .32489 .29576 .31782 .28827 Mtetra
.31782 .28827 .32489 .29576 .33604 .29171 .32901 .2842 Mtetra
.32901 .2842 .33604 .29171 .34724 .28765 .34024 .2801 Mtetra
.34024 .2801 .34724 .28765 .35849 .28357 .35152 .27599 Mtetra
.35152 .27599 .35849 .28357 .36979 .27947 .36285 .27186 Mtetra
.36285 .27186 .36979 .27947 .38114 .27536 .37422 .26771 Mtetra
.37422 .26771 .38114 .27536 .39253 .27122 .38565 .26355 Mtetra
.38565 .26355 .39253 .27122 .40397 .26707 .39712 .25937 Mtetra
.39712 .25937 .40397 .26707 .41547 .26291 .40864 .25517 Mtetra
.40864 .25517 .41547 .26291 .42701 .25872 .42021 .25095 Mtetra
.42021 .25095 .42701 .25872 .4386 .25452 .43184 .24671 Mtetra
.43184 .24671 .4386 .25452 .45024 .2503 .44351 .24246 Mtetra
.44351 .24246 .45024 .2503 .46193 .24606 .45523 .23818 Mtetra
.45523 .23818 .46193 .24606 .47367 .2418 .467 .23389 Mtetra
.467 .23389 .47367 .2418 .48546 .23752 .47883 .22958 Mtetra
.47883 .22958 .48546 .23752 .4973 .23323 .4907 .22525 Mtetra
.4907 .22525 .4973 .23323 .5092 .22892 .50263 .2209 Mtetra
.50263 .2209 .5092 .22892 .52114 .22458 .51461 .21654 Mtetra
.51461 .21654 .52114 .22458 .53314 .22023 .52664 .21215 Mtetra
.52664 .21215 .53314 .22023 .54519 .21586 .53873 .20774 Mtetra
.53873 .20774 .54519 .21586 .5573 .21147 .55087 .20332 Mtetra
.55087 .20332 .5573 .21147 .56945 .20706 .56306 .19887 Mtetra
.56306 .19887 .56945 .20706 .58166 .20264 .57531 .19441 Mtetra
.57531 .19441 .58166 .20264 .59393 .19819 .58761 .18993 Mtetra
.58761 .18993 .59393 .19819 .60625 .19372 .59996 .18542 Mtetra
.59996 .18542 .60625 .19372 .61862 .18923 .61237 .1809 Mtetra
.61237 .1809 .61862 .18923 .63105 .18473 .62484 .17635 Mtetra
.62484 .17635 .63105 .18473 .64353 .1802 .63736 .17179 Mtetra
.63736 .17179 .64353 .1802 .65607 .17565 .64994 .1672 Mtetra
.64994 .1672 .65607 .17565 .66866 .17109 .66257 .1626 Mtetra
.66257 .1626 .66866 .17109 .68132 .1665 .67526 .15797 Mtetra
.67526 .15797 .68132 .1665 .69402 .16189 .68801 .15333 Mtetra
.68801 .15333 .69402 .16189 .70679 .15726 .70081 .14866 Mtetra
.70081 .14866 .70679 .15726 .71961 .15261 .71368 .14397 Mtetra
.03496 .38178 .04273 .38856 .05278 .3849 .04504 .37809 Mtetra
.04504 .37809 .05278 .3849 .06287 .38122 .05515 .37439 Mtetra
.05515 .37439 .06287 .38122 .073 .37752 .0653 .37067 Mtetra
.0653 .37067 .073 .37752 .08317 .37381 .0755 .36693 Mtetra
.0755 .36693 .08317 .37381 .09339 .37009 .08573 .36318 Mtetra
.08573 .36318 .09339 .37009 .10364 .36635 .09601 .35941 Mtetra
.09601 .35941 .10364 .36635 .11394 .3626 .10633 .35563 Mtetra
.10633 .35563 .11394 .3626 .12428 .35883 .11669 .35183 Mtetra
.11669 .35183 .12428 .35883 .13466 .35505 .1271 .34802 Mtetra
.1271 .34802 .13466 .35505 .14508 .35125 .13754 .34419 Mtetra
.13754 .34419 .14508 .35125 .15555 .34743 .14803 .34035 Mtetra
.14803 .34035 .15555 .34743 .16605 .3436 .15857 .33649 Mtetra
.15857 .33649 .16605 .3436 .17661 .33975 .16914 .33261 Mtetra
.16914 .33261 .17661 .33975 .1872 .33589 .17976 .32872 Mtetra
.17976 .32872 .1872 .33589 .19784 .33201 .19043 .32481 Mtetra
.19043 .32481 .19784 .33201 .20852 .32812 .20113 .32089 Mtetra
.20113 .32089 .20852 .32812 .21925 .32421 .21189 .31695 Mtetra
.21189 .31695 .21925 .32421 .23002 .32028 .22268 .31299 Mtetra
.22268 .31299 .23002 .32028 .24084 .31634 .23353 .30902 Mtetra
.23353 .30902 .24084 .31634 .2517 .31238 .24441 .30503 Mtetra
.24441 .30503 .2517 .31238 .2626 .3084 .25535 .30102 Mtetra
.25535 .30102 .2626 .3084 .27355 .30441 .26633 .297 Mtetra
.26633 .297 .27355 .30441 .28455 .3004 .27735 .29296 Mtetra
.27735 .29296 .28455 .3004 .2956 .29638 .28842 .2889 Mtetra
.28842 .2889 .2956 .29638 .30669 .29233 .29954 .28483 Mtetra
.29954 .28483 .30669 .29233 .31782 .28827 .31071 .28073 Mtetra
.31071 .28073 .31782 .28827 .32901 .2842 .32192 .27662 Mtetra
.32192 .27662 .32901 .2842 .34024 .2801 .33318 .2725 Mtetra
.33318 .2725 .34024 .2801 .35152 .27599 .34449 .26835 Mtetra
.34449 .26835 .35152 .27599 .36285 .27186 .35585 .26419 Mtetra
.35585 .26419 .36285 .27186 .37422 .26771 .36725 .26001 Mtetra
.36725 .26001 .37422 .26771 .38565 .26355 .37871 .25581 Mtetra
.37871 .25581 .38565 .26355 .39712 .25937 .39021 .2516 Mtetra
.39021 .2516 .39712 .25937 .40864 .25517 .40177 .24736 Mtetra
.40177 .24736 .40864 .25517 .42021 .25095 .41337 .24311 Mtetra
.41337 .24311 .42021 .25095 .43184 .24671 .42502 .23884 Mtetra
.42502 .23884 .43184 .24671 .44351 .24246 .43673 .23455 Mtetra
.43673 .23455 .44351 .24246 .45523 .23818 .44848 .23025 Mtetra
.44848 .23025 .45523 .23818 .467 .23389 .46029 .22592 Mtetra
.46029 .22592 .467 .23389 .47883 .22958 .47214 .22157 Mtetra
.47214 .22157 .47883 .22958 .4907 .22525 .48405 .21721 Mtetra
.48405 .21721 .4907 .22525 .50263 .2209 .49601 .21283 Mtetra
.49601 .21283 .50263 .2209 .51461 .21654 .50803 .20842 Mtetra
.50803 .20842 .51461 .21654 .52664 .21215 .5201 .204 Mtetra
.5201 .204 .52664 .21215 .53873 .20774 .53222 .19956 Mtetra
.53222 .19956 .53873 .20774 .55087 .20332 .54439 .1951 Mtetra
.54439 .1951 .55087 .20332 .56306 .19887 .55662 .19062 Mtetra
.55662 .19062 .56306 .19887 .57531 .19441 .5689 .18612 Mtetra
.5689 .18612 .57531 .19441 .58761 .18993 .58124 .1816 Mtetra
.58124 .1816 .58761 .18993 .59996 .18542 .59363 .17705 Mtetra
.59363 .17705 .59996 .18542 .61237 .1809 .60607 .17249 Mtetra
.60607 .17249 .61237 .1809 .62484 .17635 .61858 .16791 Mtetra
.61858 .16791 .62484 .17635 .63736 .17179 .63114 .16331 Mtetra
.63114 .16331 .63736 .17179 .64994 .1672 .64375 .15869 Mtetra
.64375 .15869 .64994 .1672 .66257 .1626 .65642 .15404 Mtetra
.65642 .15404 .66257 .1626 .67526 .15797 .66915 .14938 Mtetra
.66915 .14938 .67526 .15797 .68801 .15333 .68194 .14469 Mtetra
.68194 .14469 .68801 .15333 .70081 .14866 .69479 .13998 Mtetra
.69479 .13998 .70081 .14866 .71368 .14397 .70769 .13525 Mtetra
.02714 .37496 .03496 .38178 .04504 .37809 .03724 .37124 Mtetra
.03724 .37124 .04504 .37809 .05515 .37439 .04737 .3675 Mtetra
.04737 .3675 .05515 .37439 .0653 .37067 .05755 .36376 Mtetra
.05755 .36376 .0653 .37067 .0755 .36693 .06776 .35999 Mtetra
.06776 .35999 .0755 .36693 .08573 .36318 .07802 .35621 Mtetra
.07802 .35621 .08573 .36318 .09601 .35941 .08832 .35242 Mtetra
.08832 .35242 .09601 .35941 .10633 .35563 .09867 .34861 Mtetra
.09867 .34861 .10633 .35563 .11669 .35183 .10905 .34478 Mtetra
.10905 .34478 .11669 .35183 .1271 .34802 .11948 .34094 Mtetra
.11948 .34094 .1271 .34802 .13754 .34419 .12995 .33708 Mtetra
.12995 .33708 .13754 .34419 .14803 .34035 .14047 .33321 Mtetra
.14047 .33321 .14803 .34035 .15857 .33649 .15102 .32932 Mtetra
.15102 .32932 .15857 .33649 .16914 .33261 .16162 .32541 Mtetra
.16162 .32541 .16914 .33261 .17976 .32872 .17227 .32149 Mtetra
.17227 .32149 .17976 .32872 .19043 .32481 .18296 .31755 Mtetra
.18296 .31755 .19043 .32481 .20113 .32089 .19369 .3136 Mtetra
.19369 .3136 .20113 .32089 .21189 .31695 .20447 .30963 Mtetra
.20447 .30963 .21189 .31695 .22268 .31299 .21529 .30564 Mtetra
.21529 .30564 .22268 .31299 .23353 .30902 .22616 .30164 Mtetra
.22616 .30164 .23353 .30902 .24441 .30503 .23708 .29762 Mtetra
.23708 .29762 .24441 .30503 .25535 .30102 .24804 .29358 Mtetra
.24804 .29358 .25535 .30102 .26633 .297 .25904 .28952 Mtetra
.25904 .28952 .26633 .297 .27735 .29296 .2701 .28545 Mtetra
.2701 .28545 .27735 .29296 .28842 .2889 .2812 .28136 Mtetra
.2812 .28136 .28842 .2889 .29954 .28483 .29234 .27726 Mtetra
.29234 .27726 .29954 .28483 .31071 .28073 .30354 .27313 Mtetra
.30354 .27313 .31071 .28073 .32192 .27662 .31478 .26899 Mtetra
.31478 .26899 .32192 .27662 .33318 .2725 .32607 .26483 Mtetra
.32607 .26483 .33318 .2725 .34449 .26835 .33741 .26066 Mtetra
.33741 .26066 .34449 .26835 .35585 .26419 .34879 .25646 Mtetra
.34879 .25646 .35585 .26419 .36725 .26001 .36023 .25225 Mtetra
.36023 .25225 .36725 .26001 .37871 .25581 .37171 .24802 Mtetra
.37171 .24802 .37871 .25581 .39021 .2516 .38325 .24377 Mtetra
.38325 .24377 .39021 .2516 .40177 .24736 .39483 .2395 Mtetra
.39483 .2395 .40177 .24736 .41337 .24311 .40647 .23521 Mtetra
.40647 .23521 .41337 .24311 .42502 .23884 .41815 .23091 Mtetra
.41815 .23091 .42502 .23884 .43673 .23455 .42989 .22659 Mtetra
.42989 .22659 .43673 .23455 .44848 .23025 .44168 .22224 Mtetra
.44168 .22224 .44848 .23025 .46029 .22592 .45351 .21788 Mtetra
.45351 .21788 .46029 .22592 .47214 .22157 .46541 .2135 Mtetra
.46541 .2135 .47214 .22157 .48405 .21721 .47735 .2091 Mtetra
.47735 .2091 .48405 .21721 .49601 .21283 .48934 .20468 Mtetra
.48934 .20468 .49601 .21283 .50803 .20842 .50139 .20024 Mtetra
.50139 .20024 .50803 .20842 .5201 .204 .51349 .19579 Mtetra
.51349 .19579 .5201 .204 .53222 .19956 .52565 .19131 Mtetra
.52565 .19131 .53222 .19956 .54439 .1951 .53786 .18681 Mtetra
.53786 .18681 .54439 .1951 .55662 .19062 .55012 .18229 Mtetra
.55012 .18229 .55662 .19062 .5689 .18612 .56244 .17775 Mtetra
.56244 .17775 .5689 .18612 .58124 .1816 .57481 .1732 Mtetra
.57481 .1732 .58124 .1816 .59363 .17705 .58724 .16862 Mtetra
.58724 .16862 .59363 .17705 .60607 .17249 .59972 .16402 Mtetra
.59972 .16402 .60607 .17249 .61858 .16791 .61226 .1594 Mtetra
.61226 .1594 .61858 .16791 .63114 .16331 .62486 .15476 Mtetra
.62486 .15476 .63114 .16331 .64375 .15869 .63752 .1501 Mtetra
.63752 .1501 .64375 .15869 .65642 .15404 .65023 .14541 Mtetra
.65023 .14541 .65642 .15404 .66915 .14938 .663 .14071 Mtetra
.663 .14071 .66915 .14938 .68194 .14469 .67582 .13598 Mtetra
.67582 .13598 .68194 .14469 .69479 .13998 .68871 .13124 Mtetra
.68871 .13124 .69479 .13998 .70769 .13525 .70165 .12647 Mtetra
.01926 .36808 .02714 .37496 .03724 .37124 .02938 .36433 Mtetra
.02938 .36433 .03724 .37124 .04737 .3675 .03954 .36057 Mtetra
.03954 .36057 .04737 .3675 .05755 .36376 .04973 .35679 Mtetra
.04973 .35679 .05755 .36376 .06776 .35999 .05997 .353 Mtetra
.05997 .353 .06776 .35999 .07802 .35621 .07026 .34919 Mtetra
.07026 .34919 .07802 .35621 .08832 .35242 .08058 .34537 Mtetra
.08058 .34537 .08832 .35242 .09867 .34861 .09095 .34153 Mtetra
.09095 .34153 .09867 .34861 .10905 .34478 .10135 .33768 Mtetra
.10135 .33768 .10905 .34478 .11948 .34094 .11181 .33381 Mtetra
.11181 .33381 .11948 .34094 .12995 .33708 .1223 .32992 Mtetra
.1223 .32992 .12995 .33708 .14047 .33321 .13284 .32602 Mtetra
.13284 .32602 .14047 .33321 .15102 .32932 .14342 .3221 Mtetra
.14342 .3221 .15102 .32932 .16162 .32541 .15405 .31816 Mtetra
.15405 .31816 .16162 .32541 .17227 .32149 .16472 .31421 Mtetra
.16472 .31421 .17227 .32149 .18296 .31755 .17543 .31024 Mtetra
.17543 .31024 .18296 .31755 .19369 .3136 .18619 .30626 Mtetra
.18619 .30626 .19369 .3136 .20447 .30963 .197 .30226 Mtetra
.197 .30226 .20447 .30963 .21529 .30564 .20785 .29824 Mtetra
.20785 .29824 .21529 .30564 .22616 .30164 .21874 .2942 Mtetra
.21874 .2942 .22616 .30164 .23708 .29762 .22968 .29015 Mtetra
.22968 .29015 .23708 .29762 .24804 .29358 .24067 .28608 Mtetra
.24067 .28608 .24804 .29358 .25904 .28952 .2517 .28199 Mtetra
.2517 .28199 .25904 .28952 .2701 .28545 .26278 .27789 Mtetra
.26278 .27789 .2701 .28545 .2812 .28136 .27391 .27377 Mtetra
.27391 .27377 .2812 .28136 .29234 .27726 .28509 .26963 Mtetra
.28509 .26963 .29234 .27726 .30354 .27313 .29631 .26547 Mtetra
.29631 .26547 .30354 .27313 .31478 .26899 .30758 .2613 Mtetra
.30758 .2613 .31478 .26899 .32607 .26483 .3189 .25711 Mtetra
.3189 .25711 .32607 .26483 .33741 .26066 .33027 .2529 Mtetra
.33027 .2529 .33741 .26066 .34879 .25646 .34168 .24867 Mtetra
.34168 .24867 .34879 .25646 .36023 .25225 .35315 .24442 Mtetra
.35315 .24442 .36023 .25225 .37171 .24802 .36466 .24016 Mtetra
.36466 .24016 .37171 .24802 .38325 .24377 .37623 .23587 Mtetra
.37623 .23587 .38325 .24377 .39483 .2395 .38785 .23157 Mtetra
.38785 .23157 .39483 .2395 .40647 .23521 .39951 .22725 Mtetra
.39951 .22725 .40647 .23521 .41815 .23091 .41123 .22291 Mtetra
.41123 .22291 .41815 .23091 .42989 .22659 .423 .21855 Mtetra
.423 .21855 .42989 .22659 .44168 .22224 .43482 .21418 Mtetra
.43482 .21418 .44168 .22224 .45351 .21788 .44669 .20978 Mtetra
.44669 .20978 .45351 .21788 .46541 .2135 .45861 .20536 Mtetra
.45861 .20536 .46541 .2135 .47735 .2091 .47059 .20093 Mtetra
.47059 .20093 .47735 .2091 .48934 .20468 .48262 .19647 Mtetra
.48262 .19647 .48934 .20468 .50139 .20024 .4947 .192 Mtetra
.4947 .192 .50139 .20024 .51349 .19579 .50684 .1875 Mtetra
.50684 .1875 .51349 .19579 .52565 .19131 .51903 .18299 Mtetra
.51903 .18299 .52565 .19131 .53786 .18681 .53127 .17845 Mtetra
.53127 .17845 .53786 .18681 .55012 .18229 .54357 .1739 Mtetra
.54357 .1739 .55012 .18229 .56244 .17775 .55592 .16932 Mtetra
.55592 .16932 .56244 .17775 .57481 .1732 .56833 .16473 Mtetra
.56833 .16473 .57481 .1732 .58724 .16862 .5808 .16011 Mtetra
.5808 .16011 .58724 .16862 .59972 .16402 .59332 .15547 Mtetra
.59332 .15547 .59972 .16402 .61226 .1594 .6059 .15081 Mtetra
.6059 .15081 .61226 .1594 .62486 .15476 .61853 .14614 Mtetra
.61853 .14614 .62486 .15476 .63752 .1501 .63123 .14143 Mtetra
.63123 .14143 .63752 .1501 .65023 .14541 .64398 .13671 Mtetra
.64398 .13671 .65023 .14541 .663 .14071 .65679 .13197 Mtetra
.65679 .13197 .663 .14071 .67582 .13598 .66965 .1272 Mtetra
.66965 .1272 .67582 .13598 .68871 .13124 .68258 .12242 Mtetra
.68258 .12242 .68871 .13124 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oYl3[00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05gooooo1OnW
`>/00ol0003oYl3[ooooo`0Eooooo`03o`000?oooooooooo053ooooo001Pooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0001cooooo0_l0001Sooooo`OoYl3[00?o0000ojO0joooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006;ooooo2_nW`>/00ol0003oYl3[ojO0j`0Fooooo`03o`00
0?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool0000Hooooo`;o0000H_ooool=ojO0j`04o`000?nW`>_oYl3[ojO0jaKooooo00?o0000oooo
ooooool0C_ooool0063ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
01Gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo4?nW`>/01?l0003oYl3[ojO0jonW`>/F
ooooo`03o`000?oooooooooo04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000Cooooo`;o0000HOoooolCojO0j`03o`000?nW`>_oYl3[00;oYl3[5_ooool0
0ol0003oooooooooo`1=ooooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool03oooool3o`00063ooooo5_nW`>/00ol0003oYl3[ojO0j`03ojO0jaKooooo00?o0000
ooooooooool0C?ooool008;ooooo0_l0001QoooooaSoYl3[00?o0000ojO0jonW`>/00onW`>/Foooo
o`03o`000?oooooooooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Koooooa_o
Yl3[00?o0000ojO0jonW`>/01?nW`>/Dooooo`?o0000COooool007cooooo0ol0001PoooooakoYl3[
00?o0000ojO0jonW`>/01?nW`>/Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000HOoo
oolQojO0j`03o`000?nW`>_oYl3[00CoYl3[5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3
o`00063ooooo9?nW`>/00ol0003oYl3[ojO0j`05ojO0jaKooooo00?o0000ooooooooool0BOooool0
07Gooooo0_l00002ooooo`03o`000?oooooooooo05_ooooo9onW`>/00ol0003oYl3[ojO0j`05ojO0
jaOooooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo05So
oooo:OnW`>/00ol0003oYl3[ojO0j`06ojO0jaKooooo00?o0000ooooooooool0B?ooool0073ooooo
0_l0001Qooooob_oYl3[00?o0000ojO0jonW`>/01onW`>/Fooooo`03o`000?oooooooooo04Oooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000
Goooool_ojO0j`03o`000?nW`>_oYl3[00OoYl3[5Oooool3o`0004Sooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o
00000oooool00ol0003oooooooooo`1Ioooooc;oYl3[00?o0000ojO0jonW`>/02?nW`>/Fooooo`03
o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP0Looooo`?o0000GoooooldojO0j`03o`000?nW`>_oYl3[00WoYl3[5_ooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:_ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^01Sooooo0ol0001OooooocOoYl3[00?o0000ojO0jonW`>/02_nW`>/Fooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Gooooo0ol0001Noooooc[oYl3[00?o
0000ojO0jonW`>/02onW`>/Eooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Iooooocco
Yl3[00?o0000ojO0jonW`>/02onW`>/Fooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001OooooocooYl3[00?o
0000ojO0jonW`>/03?nW`>/Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000002cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00kooooo0ol0001Noooood;oYl3[00?o0000ojO0jonW
`>/03OnW`>/Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l00000;?ooool005Wooooo0ol0001NooooodCoYl3[00?o0000ojO0jonW`>/03OnW`>/Cooooo`04
o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo02_ooooo001Fooooo`?o00000oooool00ol0003oooooooooo`1HooooodOoYl3[00?o0000ojO0
jonW`>/03_nW`>/Fooooo`03o`000?oooooooooo043ooooo001Dooooo`;o0000G_oooom:ojO0j`03
o`000?nW`>_oYl3[00koYl3[5_ooool00ol0003oooooooooo`10ooooo`00DOooool3o`0005gooooo
COnW`>/00ol0003oYl3[ojO0j`0?ojO0jaKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0
001LooooodooYl3[00?o0000ojO0jonW`>/04?nW`>/Fooooo`03o`000?oooooooooo03kooooo001<
ooooo`;o00001Oooool00ol0003oooooooooo`1Foooooe;oYl3[00?o0000ojO0jonW`>/04?nW`>/F
ooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000GOoooomFojO0j`03o`000?nW`>_oYl3[
013oYl3[5?ooool3o`0003oooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`00
05koooooF?nW`>/00ol0003oYl3[ojO0j`0AojO0jaGooooo00?o0000ooooooooool0?Oooool002;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Ioooo
oe[oYl3[00?o0000ojO0jonW`>/04_nW`>/Eooooo`03o`000?oooooooooo03cooooo000Rooooo`05
oa0@4?ooooooooooooooool@41006oooool2o`0005goooooG_nW`>/00ol0003oYl3[ojO0j`0CojO0
jaGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00000Hoooo
o`?o0000G?oooomQojO0j`03o`000?nW`>_oYl3[01?oYl3[5Oooool00ol0003oooooooooo`0koooo
o`008_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol0001Looooof?oYl3[00?o0000ojO0
jonW`>/05?nW`>/Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oooooooooooooo
ool@41004oooool3o`0000;ooooo00?o0000ooooooooool0F?oooomUojO0j`03o`000?nW`>_oYl3[
01CoYl3[5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
013ooooo0ol0001LooooofWoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`;o0000>oooool002;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000G?oooom/ojO0j`03o`000?nW`>_oYl3[
01KoYl3[5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`0005[oooooKOnW`>/2o`0001So
Yl3[5_ooool00ol0003oooooooooo`0gooooo`00<?ooool2o`0005goooooK?nW`>/3o`000003ojO0
jol0003oYl3[01SoYl3[5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0005_oooooKOnW
`>/3o`0000GoYl3[00?o0000ojO0jonW`>/05onW`>/Eooooo`03o`000?oooooooooo03Kooooo000/
ooooo`;o0000F_oooom]ojO0j`?o00002OnW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000
ooooooooool0=Oooool002cooooo0ol0001GooooofcoYl3[0ol0000=ojO0j`03o`000?nW`>_oYl3[
01OoYl3[5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0003oooooo`000?l0001Doooo
of_oYl3[0ol0000@ojO0j`03o`000?nW`>_oYl3[01OoYl3[4oooool00ol0003oooooo`000008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c00Iooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool0COoooom/ojO0j`?o00005?nW`>/0
0ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool002_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`19ooooofgoYl3[0_l0000HojO0j`03o`000?nW
`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Aooooom[ojO0j`?o00006_nW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool0@ooooom[ojO0j`?o
00007_nW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03ooooooJonW`>/3o`0002;oYl3[00?o0000ojO0
jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo01_ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>ooooom[ojO0j`?o00009_nW`>/00ol0003oYl3[ojO0j`0FojO0ja?ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Kooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03SoooooJ_nW`>/3o`0002WoYl3[00?o0000
ojO0jonW`>/05onW`>/Eooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003oooooooooo`0eoooo
ofWoYl3[0ol0000]ojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003oooooooooo`0_oooo
o`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo033oooooJonW`>/2o`00037oYl3[00?o0000ojO0
jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02kooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;?oooom[ojO0j`?o0000<onW`>/00ol0003oYl3[ojO0j`0GojO0jaGooooo00?o0000
ooooooooool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0ZooooofWoYl3[0ol0
000gojO0j`03o`000?nW`>_oYl3[01OoYl3[5?ooool00ol0003oooooooooo`0]ooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0000oooooo0_l0
000WooooofWoYl3[0ol0000kojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooooooo
o`0/ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027oooooJOnW`>/3o`0003ooYl3[00?o
0000ojO0jonW`>/05_nW`>/Cooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Looooof[oYl3[0ol00012ojO0j`03o`000?nW`>_oYl3[01KoYl3[5Oooool00ol0003ooooooooo
o`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool06?oooomZojO0j`?o0000A_nW`>/0
0ol0003oYl3[ojO0j`0FojO0jaGooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0FooooofWoYl3[0_l0001:ojO0j`03o`000?nW`>_oYl3[
01KoYl3[5?ooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01;oooooJOnW`>/3o`0004goYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03
o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3_oooomYojO0j`?o0000D?nW`>/00ol0003oYl3[ojO0j`0GojO0jaCooooo00?o0000ooooooooool0
:?ooool002Wooooo0ol0000Gooooo`03o`000?oooooooooo00[oooooJOnW`>/3o`0005CoYl3[00?o
0000ojO0jonW`>/05_nW`>/Cooooo`;o0000:_ooool002Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`06ooooofWoYl3[0ol0001HojO0j`03o`000?nW`>_oYl3[01KoYl3[5?ooool0
0ol0003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?oooooJ?nW`>/3
o`0005_oYl3[00?o0000ojO0jonW`>/05_nW`>/Eooooo`03o`000?oooooooooo02Kooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IonW`>/3o`0005ooYl3[00?o
0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001coooooJ?nW
`>/2o`0006?oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`03o`000?oooooooooo02Gooooo000>
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oo
oooooooo01OoooooJOnW`>/3o`0006KoYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oo
oooooooo02Cooooo000>ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`04ooooo`03o`000?oooooooooo01CoooooJOnW`>/3o`0006WoYl3[00?o0000ojO0jonW`>/05_nW
`>/Cooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`02Oooool000kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo0_l0000DooooofOoYl3[0ol0001]ojO0j`03o`000?nW`>_oYl3[01Ko
Yl3[5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00004ooooomVojO0j`?o0000LOnW
`>/00ol0003oYl3[ojO0j`0FojO0jaCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo
00ooooooI_nW`>/3o`0007GoYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Ooo
ool002Oooooo00?o0000ooooooooool02ooooomWojO0j`?o0000N?nW`>/00ol0003oYl3[ojO0j`0F
ojO0jaCooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c009ooooo`009oooool2o`0000WoooooJ?nW`>/2o`0007coYl3[00?o
0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool002Oooooo00?o0000ooooooooool0
1OoooomXojO0j`?o0000OonW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo0ol00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`03
o`000?oooooooooo00CoooooI_nW`>/3o`0008;oYl3[00?o0000ojO0jonW`>/05_nW`>/Dooooo`09
o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@09ooooo`009_ooool3o`0000?oooooIOnW`>/3o`0008KoYl3[00?o0000ojO0jonW`>/05OnW
`>/Eooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`000?ooooooYl3[06GoYl3[0ol0002:
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Nooooo`006oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonW`>/0H_nW`>/3o`0008koYl3[00?o0000
ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo01gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`1OojO0j`?o0000TOnW`>/00ol0003oYl3[ojO0j`0F
ojO0ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002
oooooe_oYl3[0ol0002EojO0j`03o`000?nW`>_oYl3[01GoYl3[4_ooool00ol0003oooooo`00000N
ooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oooomH
ojO0j`;o0000VOnW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool06oooool0
01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?oooooE?nW`>/3
o`0009_oYl3[00?o0000ojO0jonW`>/05OnW`>/Eooooo`03o`000?oooooooooo01[ooooo000Koooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`05oooooe3oYl3[0ol0002O
ojO0j`03o`000?nW`>_oYl3[01GoYl3[5?ooool00ol0003oooooooooo`0Jooooo`006oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007ooooodcoYl3[0ol0002SojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5?ooool00ol0003oooooooooo`0Iooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool01ooooom8ojO0j`?o0000YonW`>/00ol0003oYl3[ojO0j`0D
ojO0jaCooooo00?o0000ooooooooool06Oooool002Gooooo00?o0000ooooooooool02?oooom4ojO0
j`?o0000Z_nW`>/00ol0003oYl3[ojO0j`0EojO0ja;ooooo00?o0000ooooool000006_ooool002Go
oooo00?o0000ooooooooool02_ooooloojO0j`?o0000[_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCo
oooo00?o0000ooooooooool05oooool002Gooooo0_l0000<oooooccoYl3[0_l0002bojO0j`03o`00
0?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003ooooooooo
o`0=ooooocSoYl3[0ol0002eojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003ooooooooo
o`0Fooooo`009?ooool00ol0003oooooooooo`0>ooooocCoYl3[0ol0002hojO0j`03o`000?nW`>_o
Yl3[01GoYl3[5?ooool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo<?nW`>/3o`00
0;coYl3[00?o0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo
00Oooooo000Tooooo`03o`000?oooooooooo013ooooo;?nW`>/3o`000<3oYl3[00?o0000ojO0jonW
`>/05OnW`>/Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooooooo
ool04_oooolWojO0j`?o0000`onW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Coooo
ob?oYl3[0ol00037ojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo8?nW`>/2o`000<_oYl3[00?o0000ojO0
jonW`>/05OnW`>/Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Foooo
oacoYl3[0ol0003>ojO0j`03o`000?nW`>_oYl3[01GoYl3[4Oooool3o`0000Oooooo00?o0000oooo
ooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Cooooo00?o0000ooooooooool06?oooolGojO0j`?o0000dOnW`>/00ol0003oYl3[ojO0j`0EojO0
j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo4onW`>/3o`000=GoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`?o00001Oooool00ol0
003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_ooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo0_l0000Kooooo`ooYl3[0ol0003I
ojO0j`03o`000?nW`>_oYl3[01CoYl3[1_ooool4o`0000Sooooo00?o0000ooooooooool04Oooool0
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Ooo
ool00ol0003oooooooooo`0Kooooo`_oYl3[0ol0003LojO0j`03o`000?nW`>_oYl3[01GoYl3[0_oo
ool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool7
ojO0j`?o0000h?nW`>/00ol0003oYl3[ojO0j`0EojO0j`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool4ojO0j`;o0000i?nW`>/00ol0
003oYl3[ojO0j`0EojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o
0000ionW`>/00ol0003oYl3[ojO0j`0DojO0ja3ooooo00?o0000ooooooooool04?ooool002;ooooo
00?o0000ooooooooool07?ooool3o`000003oooooonW`>_oYl3[0>OoYl3[00?o0000ojO0jonW`>/0
5OnW`>/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01Wooooo0ol0
0006ooooonSoYl3[00?o0000ojO0jonW`>/05?nW`>/?ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooonSoYl3[00?o0000ojO0jonW`>/05?nW`>/>
ooooo`03o`000?oooooooooo013ooooo000Rooooo`;o00005?ooool3o`0000koooooj?nW`>/00ol0
003oYl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o
00004_oooooWojO0j`03o`000?nW`>_oYl3[01GoYl3[3?ooool00ol0003oooooooooo`0@ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`;o00005_oooooWojO0j`03o`000?nW`>_oYl3[01Co
Yl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wo
ooooionW`>/00ol0003oYl3[ojO0j`0DojO0j`cooooo00?o0000ooooooooool03oooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool2o`0000[ooooo0ol0000MooooonKo
Yl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo
00Kooooo0ol0000QooooonKoYl3[00?o0000ojO0jonW`>/05OnW`>/:ooooo`03o`000?oooooooooo
00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo00?ooooo0ol0000VooooonGoYl3[00?o0000ojO0jonW`>/05?nW`>/:
ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000:_oooooUojO0j`03o`000?nW
`>_oYl3[01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool4o`0002koooooi?nW`>/00ol0003oYl3[ojO0
j`0DojO0j`Wooooo00?o0000ooooooooool03oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo0_l0000aooooonCoYl3[00?o0000ojO0jonW`>/05?nW
`>/8ooooo`03o`000?oooooooooo00oooooo000Rooooo`03o`000?oooooooooo02ooooooi?nW`>/0
0ol0003oYl3[ojO0j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000oooo
ooooool0;ooooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0>oooo
o`009?ooool00ol0003oooooooooo`0_ooooon?oYl3[00?o0000ojO0jonW`>/05?nW`>/7ooooo`03
o`000?oooooooooo00kooooo000Uooooo`;o0000<?oooooSojO0j`03o`000?nW`>_oYl3[01CoYl3[
1_ooool00ol0003oooooooooo`0>ooooo`009oooool00ol0003oooooooooo`0^ooooon?oYl3[00?o
0000ojO0jonW`>/04onW`>/6ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooo
oooo02koooooh_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Gooooo00?o0000ooooooooool03_ooool0
02Wooooo00?o0000ooooooooool0;ooooooQojO0j`03o`000?nW`>_oYl3[01CoYl3[1?ooool00ol0
003oooooooooo`0>ooooo`00:_ooool2o`00037oooooh?nW`>/00ol0003oYl3[ojO0j`0DojO0j`?o
oooo00?o0000ooooooooool03_ooool002cooooo00?o0000ooooooooool0;ooooooPojO0j`03o`00
0?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003ooooooooo
o`0_ooooomooYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo00gooooo000^
ooooo`03o`000?oooooooooo02oooooogonW`>/00ol0003oYl3[ojO0j`0DojO0j`;ooooo00?o0000
ooooooooool03Oooool002oooooo00?o0000ooooooooool0;ooooooOojO0j`03o`000?nW`>_oYl3[
01?oYl3[0_ooool00ol0003oooooooooo`0=ooooo`00<?ooool2o`00033ooooog_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo
g_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03ooooool0003ooooo00kooooo000cooooo`03o`000?oo
oooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0CojO0j`03o`000?oooooooooo00gooooo000d
ooooo`03o`000?oooooooooo02kooooog_nW`>/00ol0003oYl3[ojO0j`0AojO0j`03ooooool0003o
oooo00kooooo000eooooo`;o0000;ooooooMojO0j`03o`000?nW`>_oYl3[00goYl3[1_ooool00ol0
003oooooooooo`0<ooooo`00=oooool00ol0003oooooooooo`0^ooooomcoYl3[00?o0000ojO0jonW
`>/02OnW`>/9ooooo`03o`000?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo
g?nW`>/00ol0003oYl3[ojO0j`05ojO0j`cooooo00?o0000ooooooooool03?ooool003Wooooo00?o
0000ooooooooool0;_oooooLojO0j`03o`000?nW`>_oYl3[013ooooo00?o0000ooooooooool03?oo
ool003[ooooo0_l0000_ooooom_oYl3[00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<
ooooo`00??ooool00ol0003oooooooooo`0]ooooomKoYl3[1Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooooooo02goooood_nW`>/9ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003kooooo00?o0000ooooooooool0
;Oooooo:ojO0ja3ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?ooo
ool2o`0002ooooooaOnW`>/Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02ooo
ool0047ooooo00?o0000ooooooooool0;Oooooo1ojO0jaSooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`00@_ooool00ol0003oooooooooo`0]oooookcoYl3[7Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0013ooooo`03o`000?oooooooooo02go
oooo^?nW`>/Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool004Cooooo
00?o0000ooooooooool0;OoooondojO0jbCooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`00AOooool2o`0002oooooo[_nW`>/Yooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool004Oooooo00?o0000ooooooooool0;OoooonZojO0jbcooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00B?ooool00ol0003oooooooooo`0]oooo
ojKoYl3[<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0019ooooo`03
o`000?oooooooooo02goooooX_nW`>/dooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool004[ooooo0_l0000^oooooigoYl3[>Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo001<ooooo`03o`000?oooooooooo02coooooVOnW`>/looooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?oooonB
ojO0jd?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0
003oooooooooo`0]ooooohgoYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo001?ooooo`;o0000;_oooon8ojO0jdcooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`00DOooool00ol0003oooooooooo`0/ooooohCoYl3[Coooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo001Booooo`03o`000?oooooooooo02_oooooPOnW
`>]Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool005?ooooo00?o0000
ooooooooool0:ooooommojO0jeOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09
ooooo`00E?ooool2o`0002goooooN?nW`>]Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool005Kooooo00?o0000ooooooooool0:ooooomdojO0jekooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooofcoYl3[
I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001Hooooo`03o`000?oo
oooooooo02coooooIonW`>]Zooooo`05o`000?ooooooooooooooool000002oooool005Wooooo00?o
0000ooooooooool0;?oooomSojO0jfgooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_oo
ool2o`0002goooooGonW`>]aooooo`04o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oo
oooooooo02_oooooFonW`>]eooooo`03o`000?oooooo000000_ooooo001Mooooo`03o`000?oooooo
oooo02_oooooEonW`>]hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oooooo
oooo02_oooooDonW`>]looooo`03o`000?oooooo000000[ooooo001Oooooo`;o0000;?oooom<ojO0
jh?ooooo0_l0000:ooooo`00HOooool00ol0003oooooooooo`0ZooooodSoYl3[QOooool3o`0000[o
oooo001Rooooo`03o`000?oooooooooo02_ooooo@onW`>^4ooooo`Co00003Oooool006?ooooo00?o
0000ooooooooool0:oooooloojO0jh?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo>onW`>^3
ooooo`?o00005Oooool006Kooooo00?o0000ooooooooool0:ooooolcojO0jhGooooo1?l0000Hoooo
o`00Ioooool00ol0003oooooooooo`0Zoooooc3oYl3[Q?ooool4o`0001cooooo001Xooooo`03o`00
0?oooooooooo02[ooooo;?nW`>^3ooooo`Co00008?ooool006Wooooo0_l0000/ooooobOoYl3[P_oo
ool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo8onW`>^2ooooo`?o0000:?ooool0
06cooooo00?o0000ooooooooool0:_oooolMojO0jh?ooooo1?l0000[ooooo`00KOooool00ol0003o
ooooooooo`0[oooooaSoYl3[P_ooool4o`0002oooooo001^ooooo`03o`000?oooooooooo02[ooooo
5OnW`>^1ooooo`Co0000<oooool006oooooo0_l0000[oooooa7oYl3[P?ooool4o`0003Oooooo001a
ooooo`03o`000?oooooooooo02[ooooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000oooo
ooooool0:_ooool5ojO0jh;ooooo0ol0000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03
ojO0jooooooooooo07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0
Noooool4o`0004Kooooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?oo
ool4o`0004[ooooo001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4
o`0004kooooo001hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`00
05;ooooo001iooooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Ooooo
o`03o`000?oooooooooo05gooooo1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05[ooooo0ol0001Yooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Kooooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05;ooooo1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04kooooo1?l0001dooooo`00Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00
07Sooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007co
oooo0027ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo
0028ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029
ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oo
oooooooo02cooooo1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02Sooooo1?l0002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Cooooo1?l0002Nooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l0002Rooooo`00Toooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo
002Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:[ooooo002F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:gooooo002Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000oooooooooooo0000
2Oooool3o`000;gooooo002Looooo`03o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2
o`000003ooooool0003o000000;o0000a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00]_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP2Oooooo`00]_ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg09oooooo002fooooo`03o`000?oooooooooo00_ooooo00Go410@oooo
oooooooooooooa0@402Oooooo`00]_ooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000009oooooo002fooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00002Oooooo`00]?ooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooo
oooooooooooooa0@402Oooooo`00]_ooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0Woooool00;Kooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^09oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -14 0 ]
[.5 .82364 14 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69467 Mtetra
.4053 .69467 .41061 .69934 .41957 .69681 .41427 .69213 Mtetra
.41427 .69213 .41957 .69681 .42855 .69428 .42327 .68958 Mtetra
.42327 .68958 .42855 .69428 .43756 .69174 .43231 .68703 Mtetra
.43231 .68703 .43756 .69174 .4466 .68919 .44137 .68446 Mtetra
.44137 .68446 .4466 .68919 .45567 .68663 .45046 .68189 Mtetra
.45046 .68189 .45567 .68663 .46478 .68407 .45958 .67931 Mtetra
.45958 .67931 .46478 .68407 .47391 .68149 .46873 .67671 Mtetra
.46873 .67671 .47391 .68149 .48307 .67891 .47792 .67412 Mtetra
.47792 .67412 .48307 .67891 .49227 .67632 .48713 .67151 Mtetra
.48713 .67151 .49227 .67632 .50149 .67371 .49638 .66889 Mtetra
.49638 .66889 .50149 .67371 .51075 .6711 .50565 .66626 Mtetra
.50565 .66626 .51075 .6711 .52004 .66849 .51496 .66363 Mtetra
.51496 .66363 .52004 .66849 .52936 .66586 .5243 .66098 Mtetra
.5243 .66098 .52936 .66586 .53871 .66322 .53367 .65833 Mtetra
.53367 .65833 .53871 .66322 .54809 .66058 .54308 .65567 Mtetra
.54308 .65567 .54809 .66058 .55751 .65792 .55251 .653 Mtetra
.55251 .653 .55751 .65792 .56695 .65526 .56198 .65032 Mtetra
.56198 .65032 .56695 .65526 .57643 .65259 .57148 .64763 Mtetra
.57148 .64763 .57643 .65259 .58595 .6499 .58102 .64493 Mtetra
.58102 .64493 .58595 .6499 .59549 .64721 .59058 .64222 Mtetra
.59058 .64222 .59549 .64721 .60507 .64451 .60018 .6395 Mtetra
.60018 .6395 .60507 .64451 .61468 .6418 .60982 .63678 Mtetra
.60982 .63678 .61468 .6418 .62432 .63908 .61948 .63404 Mtetra
.61948 .63404 .62432 .63908 .634 .63636 .62918 .63129 Mtetra
.62918 .63129 .634 .63636 .64371 .63362 .63892 .62854 Mtetra
.63892 .62854 .64371 .63362 .65345 .63087 .64868 .62577 Mtetra
.64868 .62577 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62021 Mtetra
.66832 .62021 .67304 .62535 .68289 .62257 .67819 .61742 Mtetra
.67819 .61742 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .6118 Mtetra
.69803 .6118 .70269 .61699 .71264 .61418 .70801 .60898 Mtetra
.70801 .60898 .71264 .61418 .72262 .61137 .71802 .60615 Mtetra
.71802 .60615 .72262 .61137 .73264 .60854 .72806 .6033 Mtetra
.72806 .6033 .73264 .60854 .7427 .60571 .73814 .60045 Mtetra
.73814 .60045 .7427 .60571 .75279 .60286 .74826 .59759 Mtetra
.74826 .59759 .75279 .60286 .76291 .60001 .75841 .59471 Mtetra
.75841 .59471 .76291 .60001 .77308 .59714 .7686 .59183 Mtetra
.7686 .59183 .77308 .59714 .78328 .59427 .77882 .58893 Mtetra
.77882 .58893 .78328 .59427 .79351 .59138 .78908 .58603 Mtetra
.78908 .58603 .79351 .59138 .80378 .58849 .79938 .58311 Mtetra
.79938 .58311 .80378 .58849 .81409 .58558 .80971 .58019 Mtetra
.80971 .58019 .81409 .58558 .82443 .58267 .82008 .57725 Mtetra
.82008 .57725 .82443 .58267 .83482 .57974 .83049 .57431 Mtetra
.83049 .57431 .83482 .57974 .84523 .5768 .84094 .57135 Mtetra
.84094 .57135 .84523 .5768 .85569 .57385 .85142 .56838 Mtetra
.85142 .56838 .85569 .57385 .86618 .57089 .86194 .5654 Mtetra
.86194 .5654 .86618 .57089 .87672 .56792 .8725 .56241 Mtetra
.8725 .56241 .87672 .56792 .88729 .56494 .8831 .55941 Mtetra
.8831 .55941 .88729 .56494 .89789 .56195 .89374 .5564 Mtetra
.89374 .5564 .89789 .56195 .90854 .55895 .90441 .55338 Mtetra
.90441 .55338 .90854 .55895 .91923 .55594 .91512 .55035 Mtetra
.91512 .55035 .91923 .55594 .92995 .55292 .92588 .5473 Mtetra
.92588 .5473 .92995 .55292 .94071 .54988 .93667 .54425 Mtetra
.93667 .54425 .94071 .54988 .95152 .54684 .9475 .54118 Mtetra
.9475 .54118 .95152 .54684 .96236 .54378 .95837 .53811 Mtetra
.95837 .53811 .96236 .54378 .97324 .54071 .96928 .53502 Mtetra
.96928 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.391 .69252 .39636 .6972 .4053 .69467 .39996 .68998 Mtetra
.39996 .68998 .4053 .69467 .41427 .69213 .40895 .68742 Mtetra
.40895 .68742 .41427 .69213 .42327 .68958 .41797 .68486 Mtetra
.41797 .68486 .42327 .68958 .43231 .68703 .42702 .68228 Mtetra
.42702 .68228 .43231 .68703 .44137 .68446 .4361 .6797 Mtetra
.4361 .6797 .44137 .68446 .45046 .68189 .44521 .67711 Mtetra
.44521 .67711 .45046 .68189 .45958 .67931 .45435 .67452 Mtetra
.45435 .67452 .45958 .67931 .46873 .67671 .46352 .67191 Mtetra
.46352 .67191 .46873 .67671 .47792 .67412 .47273 .66929 Mtetra
.47273 .66929 .47792 .67412 .48713 .67151 .48196 .66667 Mtetra
.48196 .66667 .48713 .67151 .49638 .66889 .49123 .66403 Mtetra
.49123 .66403 .49638 .66889 .50565 .66626 .50053 .66139 Mtetra
.50053 .66139 .50565 .66626 .51496 .66363 .50985 .65874 Mtetra
.50985 .65874 .51496 .66363 .5243 .66098 .51922 .65608 Mtetra
.51922 .65608 .5243 .66098 .53367 .65833 .52861 .65341 Mtetra
.52861 .65341 .53367 .65833 .54308 .65567 .53803 .65073 Mtetra
.53803 .65073 .54308 .65567 .55251 .653 .54749 .64804 Mtetra
.54749 .64804 .55251 .653 .56198 .65032 .55698 .64534 Mtetra
.55698 .64534 .56198 .65032 .57148 .64763 .5665 .64264 Mtetra
.5665 .64264 .57148 .64763 .58102 .64493 .57606 .63992 Mtetra
.57606 .63992 .58102 .64493 .59058 .64222 .58565 .6372 Mtetra
.58565 .6372 .59058 .64222 .60018 .6395 .59527 .63446 Mtetra
.59527 .63446 .60018 .6395 .60982 .63678 .60493 .63172 Mtetra
.60493 .63172 .60982 .63678 .61948 .63404 .61461 .62896 Mtetra
.61461 .62896 .61948 .63404 .62918 .63129 .62434 .6262 Mtetra
.62434 .6262 .62918 .63129 .63892 .62854 .63409 .62343 Mtetra
.63409 .62343 .63892 .62854 .64868 .62577 .64388 .62064 Mtetra
.64388 .62064 .64868 .62577 .65848 .623 .65371 .61785 Mtetra
.65371 .61785 .65848 .623 .66832 .62021 .66357 .61505 Mtetra
.66357 .61505 .66832 .62021 .67819 .61742 .67346 .61224 Mtetra
.67346 .61224 .67819 .61742 .68809 .61462 .68339 .60942 Mtetra
.68339 .60942 .68809 .61462 .69803 .6118 .69335 .60658 Mtetra
.69335 .60658 .69803 .6118 .70801 .60898 .70335 .60374 Mtetra
.70335 .60374 .70801 .60898 .71802 .60615 .71338 .60089 Mtetra
.71338 .60089 .71802 .60615 .72806 .6033 .72345 .59803 Mtetra
.72345 .59803 .72806 .6033 .73814 .60045 .73356 .59516 Mtetra
.73356 .59516 .73814 .60045 .74826 .59759 .7437 .59227 Mtetra
.7437 .59227 .74826 .59759 .75841 .59471 .75387 .58938 Mtetra
.75387 .58938 .75841 .59471 .7686 .59183 .76409 .58648 Mtetra
.76409 .58648 .7686 .59183 .77882 .58893 .77434 .58356 Mtetra
.77434 .58356 .77882 .58893 .78908 .58603 .78462 .58064 Mtetra
.78462 .58064 .78908 .58603 .79938 .58311 .79495 .57771 Mtetra
.79495 .57771 .79938 .58311 .80971 .58019 .80531 .57476 Mtetra
.80531 .57476 .80971 .58019 .82008 .57725 .81571 .57181 Mtetra
.81571 .57181 .82008 .57725 .83049 .57431 .82614 .56884 Mtetra
.82614 .56884 .83049 .57431 .84094 .57135 .83661 .56586 Mtetra
.83661 .56586 .84094 .57135 .85142 .56838 .84712 .56288 Mtetra
.84712 .56288 .85142 .56838 .86194 .5654 .85767 .55988 Mtetra
.85767 .55988 .86194 .5654 .8725 .56241 .86826 .55687 Mtetra
.86826 .55687 .8725 .56241 .8831 .55941 .87889 .55385 Mtetra
.87889 .55385 .8831 .55941 .89374 .5564 .88955 .55082 Mtetra
.88955 .55082 .89374 .5564 .90441 .55338 .90025 .54777 Mtetra
.90025 .54777 .90441 .55338 .91512 .55035 .911 .54472 Mtetra
.911 .54472 .91512 .55035 .92588 .5473 .92178 .54166 Mtetra
.92178 .54166 .92588 .5473 .93667 .54425 .9326 .53858 Mtetra
.9326 .53858 .93667 .54425 .9475 .54118 .94346 .53549 Mtetra
.94346 .53549 .9475 .54118 .95837 .53811 .95436 .53239 Mtetra
.95436 .53239 .95837 .53811 .96928 .53502 .9653 .52928 Mtetra
.9653 .52928 .96928 .53502 .98024 .53192 .97628 .52616 Mtetra
.38561 .68781 .391 .69252 .39996 .68998 .39459 .68525 Mtetra
.39459 .68525 .39996 .68998 .40895 .68742 .40359 .68268 Mtetra
.40359 .68268 .40895 .68742 .41797 .68486 .41263 .6801 Mtetra
.41263 .6801 .41797 .68486 .42702 .68228 .4217 .67751 Mtetra
.4217 .67751 .42702 .68228 .4361 .6797 .4308 .67492 Mtetra
.4308 .67492 .4361 .6797 .44521 .67711 .43993 .67231 Mtetra
.43993 .67231 .44521 .67711 .45435 .67452 .44909 .6697 Mtetra
.44909 .6697 .45435 .67452 .46352 .67191 .45828 .66707 Mtetra
.45828 .66707 .46352 .67191 .47273 .66929 .46751 .66444 Mtetra
.46751 .66444 .47273 .66929 .48196 .66667 .47676 .6618 Mtetra
.47676 .6618 .48196 .66667 .49123 .66403 .48605 .65915 Mtetra
.48605 .65915 .49123 .66403 .50053 .66139 .49537 .65649 Mtetra
.49537 .65649 .50053 .66139 .50985 .65874 .50472 .65382 Mtetra
.50472 .65382 .50985 .65874 .51922 .65608 .5141 .65114 Mtetra
.5141 .65114 .51922 .65608 .52861 .65341 .52351 .64846 Mtetra
.52351 .64846 .52861 .65341 .53803 .65073 .53296 .64576 Mtetra
.53296 .64576 .53803 .65073 .54749 .64804 .54244 .64305 Mtetra
.54244 .64305 .54749 .64804 .55698 .64534 .55195 .64034 Mtetra
.55195 .64034 .55698 .64534 .5665 .64264 .56149 .63762 Mtetra
.56149 .63762 .5665 .64264 .57606 .63992 .57107 .63488 Mtetra
.57107 .63488 .57606 .63992 .58565 .6372 .58068 .63214 Mtetra
.58068 .63214 .58565 .6372 .59527 .63446 .59032 .62939 Mtetra
.59032 .62939 .59527 .63446 .60493 .63172 .6 .62663 Mtetra
.6 .62663 .60493 .63172 .61461 .62896 .60971 .62385 Mtetra
.60971 .62385 .61461 .62896 .62434 .6262 .61946 .62107 Mtetra
.61946 .62107 .62434 .6262 .63409 .62343 .62924 .61828 Mtetra
.62924 .61828 .63409 .62343 .64388 .62064 .63905 .61548 Mtetra
.63905 .61548 .64388 .62064 .65371 .61785 .6489 .61267 Mtetra
.6489 .61267 .65371 .61785 .66357 .61505 .65878 .60985 Mtetra
.65878 .60985 .66357 .61505 .67346 .61224 .6687 .60702 Mtetra
.6687 .60702 .67346 .61224 .68339 .60942 .67865 .60418 Mtetra
.67865 .60418 .68339 .60942 .69335 .60658 .68864 .60133 Mtetra
.68864 .60133 .69335 .60658 .70335 .60374 .69866 .59847 Mtetra
.69866 .59847 .70335 .60374 .71338 .60089 .70872 .5956 Mtetra
.70872 .5956 .71338 .60089 .72345 .59803 .71881 .59272 Mtetra
.71881 .59272 .72345 .59803 .73356 .59516 .72894 .58983 Mtetra
.72894 .58983 .73356 .59516 .7437 .59227 .73911 .58692 Mtetra
.73911 .58692 .7437 .59227 .75387 .58938 .74931 .58401 Mtetra
.74931 .58401 .75387 .58938 .76409 .58648 .75955 .58109 Mtetra
.75955 .58109 .76409 .58648 .77434 .58356 .76982 .57816 Mtetra
.76982 .57816 .77434 .58356 .78462 .58064 .78014 .57521 Mtetra
.78014 .57521 .78462 .58064 .79495 .57771 .79049 .57226 Mtetra
.79049 .57226 .79495 .57771 .80531 .57476 .80087 .5693 Mtetra
.80087 .5693 .80531 .57476 .81571 .57181 .8113 .56632 Mtetra
.8113 .56632 .81571 .57181 .82614 .56884 .82176 .56334 Mtetra
.82176 .56334 .82614 .56884 .83661 .56586 .83226 .56034 Mtetra
.83226 .56034 .83661 .56586 .84712 .56288 .8428 .55733 Mtetra
.8428 .55733 .84712 .56288 .85767 .55988 .85337 .55431 Mtetra
.85337 .55431 .85767 .55988 .86826 .55687 .86399 .55128 Mtetra
.86399 .55128 .86826 .55687 .87889 .55385 .87464 .54824 Mtetra
.87464 .54824 .87889 .55385 .88955 .55082 .88533 .54519 Mtetra
.88533 .54519 .88955 .55082 .90025 .54777 .89607 .54213 Mtetra
.89607 .54213 .90025 .54777 .911 .54472 .90684 .53905 Mtetra
.90684 .53905 .911 .54472 .92178 .54166 .91765 .53597 Mtetra
.91765 .53597 .92178 .54166 .9326 .53858 .9285 .53287 Mtetra
.9285 .53287 .9326 .53858 .94346 .53549 .93939 .52976 Mtetra
.93939 .52976 .94346 .53549 .95436 .53239 .95032 .52664 Mtetra
.95032 .52664 .95436 .53239 .9653 .52928 .96129 .52351 Mtetra
.96129 .52351 .9653 .52928 .97628 .52616 .9723 .52037 Mtetra
.38018 .68308 .38561 .68781 .39459 .68525 .38918 .6805 Mtetra
.38918 .6805 .39459 .68525 .40359 .68268 .3982 .67791 Mtetra
.3982 .67791 .40359 .68268 .41263 .6801 .40726 .67532 Mtetra
.40726 .67532 .41263 .6801 .4217 .67751 .41635 .67271 Mtetra
.41635 .67271 .4217 .67751 .4308 .67492 .42547 .6701 Mtetra
.42547 .6701 .4308 .67492 .43993 .67231 .43462 .66748 Mtetra
.43462 .66748 .43993 .67231 .44909 .6697 .4438 .66485 Mtetra
.4438 .66485 .44909 .6697 .45828 .66707 .45301 .66221 Mtetra
.45301 .66221 .45828 .66707 .46751 .66444 .46225 .65956 Mtetra
.46225 .65956 .46751 .66444 .47676 .6618 .47153 .6569 Mtetra
.47153 .6569 .47676 .6618 .48605 .65915 .48083 .65423 Mtetra
.48083 .65423 .48605 .65915 .49537 .65649 .49017 .65156 Mtetra
.49017 .65156 .49537 .65649 .50472 .65382 .49954 .64887 Mtetra
.49954 .64887 .50472 .65382 .5141 .65114 .50895 .64618 Mtetra
.50895 .64618 .5141 .65114 .52351 .64846 .51838 .64347 Mtetra
.51838 .64347 .52351 .64846 .53296 .64576 .52785 .64076 Mtetra
.52785 .64076 .53296 .64576 .54244 .64305 .53735 .63804 Mtetra
.53735 .63804 .54244 .64305 .55195 .64034 .54688 .6353 Mtetra
.54688 .6353 .55195 .64034 .56149 .63762 .55645 .63256 Mtetra
.55645 .63256 .56149 .63762 .57107 .63488 .56605 .62981 Mtetra
.56605 .62981 .57107 .63488 .58068 .63214 .57568 .62705 Mtetra
.57568 .62705 .58068 .63214 .59032 .62939 .58535 .62428 Mtetra
.58535 .62428 .59032 .62939 .6 .62663 .59505 .6215 Mtetra
.59505 .6215 .6 .62663 .60971 .62385 .60478 .61871 Mtetra
.60478 .61871 .60971 .62385 .61946 .62107 .61455 .61591 Mtetra
.61455 .61591 .61946 .62107 .62924 .61828 .62435 .6131 Mtetra
.62435 .6131 .62924 .61828 .63905 .61548 .63419 .61028 Mtetra
.63419 .61028 .63905 .61548 .6489 .61267 .64406 .60746 Mtetra
.64406 .60746 .6489 .61267 .65878 .60985 .65396 .60462 Mtetra
.65396 .60462 .65878 .60985 .6687 .60702 .66391 .60177 Mtetra
.66391 .60177 .6687 .60702 .67865 .60418 .67388 .59891 Mtetra
.67388 .59891 .67865 .60418 .68864 .60133 .68389 .59604 Mtetra
.68389 .59604 .68864 .60133 .69866 .59847 .69394 .59316 Mtetra
.69394 .59316 .69866 .59847 .70872 .5956 .70402 .59027 Mtetra
.70402 .59027 .70872 .5956 .71881 .59272 .71414 .58737 Mtetra
.71414 .58737 .71881 .59272 .72894 .58983 .7243 .58446 Mtetra
.7243 .58446 .72894 .58983 .73911 .58692 .73449 .58154 Mtetra
.73449 .58154 .73911 .58692 .74931 .58401 .74472 .57861 Mtetra
.74472 .57861 .74931 .58401 .75955 .58109 .75498 .57567 Mtetra
.75498 .57567 .75955 .58109 .76982 .57816 .76528 .57272 Mtetra
.76528 .57272 .76982 .57816 .78014 .57521 .77562 .56975 Mtetra
.77562 .56975 .78014 .57521 .79049 .57226 .786 .56678 Mtetra
.786 .56678 .79049 .57226 .80087 .5693 .79641 .5638 Mtetra
.79641 .5638 .80087 .5693 .8113 .56632 .80686 .5608 Mtetra
.80686 .5608 .8113 .56632 .82176 .56334 .81735 .55779 Mtetra
.81735 .55779 .82176 .56334 .83226 .56034 .82788 .55478 Mtetra
.82788 .55478 .83226 .56034 .8428 .55733 .83844 .55175 Mtetra
.83844 .55175 .8428 .55733 .85337 .55431 .84905 .54871 Mtetra
.84905 .54871 .85337 .55431 .86399 .55128 .85969 .54566 Mtetra
.85969 .54566 .86399 .55128 .87464 .54824 .87037 .5426 Mtetra
.87037 .5426 .87464 .54824 .88533 .54519 .88109 .53953 Mtetra
.88109 .53953 .88533 .54519 .89607 .54213 .89185 .53644 Mtetra
.89185 .53644 .89607 .54213 .90684 .53905 .90265 .53335 Mtetra
.90265 .53335 .90684 .53905 .91765 .53597 .91349 .53024 Mtetra
.91349 .53024 .91765 .53597 .9285 .53287 .92437 .52712 Mtetra
.92437 .52712 .9285 .53287 .93939 .52976 .93529 .524 Mtetra
.93529 .524 .93939 .52976 .95032 .52664 .94625 .52085 Mtetra
.94625 .52085 .95032 .52664 .96129 .52351 .95725 .5177 Mtetra
.95725 .5177 .96129 .52351 .9723 .52037 .96829 .51454 Mtetra
.37472 .67831 .38018 .68308 .38918 .6805 .38373 .67572 Mtetra
.38373 .67572 .38918 .6805 .3982 .67791 .39278 .67311 Mtetra
.39278 .67311 .3982 .67791 .40726 .67532 .40186 .6705 Mtetra
.40186 .6705 .40726 .67532 .41635 .67271 .41096 .66788 Mtetra
.41096 .66788 .41635 .67271 .42547 .6701 .4201 .66525 Mtetra
.4201 .66525 .42547 .6701 .43462 .66748 .42927 .66261 Mtetra
.42927 .66261 .43462 .66748 .4438 .66485 .43847 .65996 Mtetra
.43847 .65996 .4438 .66485 .45301 .66221 .4477 .65731 Mtetra
.4477 .65731 .45301 .66221 .46225 .65956 .45697 .65464 Mtetra
.45697 .65464 .46225 .65956 .47153 .6569 .46626 .65197 Mtetra
.46626 .65197 .47153 .6569 .48083 .65423 .47559 .64928 Mtetra
.47559 .64928 .48083 .65423 .49017 .65156 .48495 .64659 Mtetra
.48495 .64659 .49017 .65156 .49954 .64887 .49434 .64389 Mtetra
.49434 .64389 .49954 .64887 .50895 .64618 .50376 .64118 Mtetra
.50376 .64118 .50895 .64618 .51838 .64347 .51322 .63846 Mtetra
.51322 .63846 .51838 .64347 .52785 .64076 .52271 .63572 Mtetra
.52271 .63572 .52785 .64076 .53735 .63804 .53223 .63298 Mtetra
.53223 .63298 .53735 .63804 .54688 .6353 .54178 .63024 Mtetra
.54178 .63024 .54688 .6353 .55645 .63256 .55137 .62748 Mtetra
.55137 .62748 .55645 .63256 .56605 .62981 .56099 .62471 Mtetra
.56099 .62471 .56605 .62981 .57568 .62705 .57065 .62193 Mtetra
.57065 .62193 .57568 .62705 .58535 .62428 .58034 .61914 Mtetra
.58034 .61914 .58535 .62428 .59505 .6215 .59006 .61634 Mtetra
.59006 .61634 .59505 .6215 .60478 .61871 .59982 .61354 Mtetra
.59982 .61354 .60478 .61871 .61455 .61591 .60961 .61072 Mtetra
.60961 .61072 .61455 .61591 .62435 .6131 .61943 .60789 Mtetra
.61943 .60789 .62435 .6131 .63419 .61028 .62929 .60505 Mtetra
.62929 .60505 .63419 .61028 .64406 .60746 .63919 .60221 Mtetra
.63919 .60221 .64406 .60746 .65396 .60462 .64912 .59935 Mtetra
.64912 .59935 .65396 .60462 .66391 .60177 .65908 .59648 Mtetra
.65908 .59648 .66391 .60177 .67388 .59891 .66908 .5936 Mtetra
.66908 .5936 .67388 .59891 .68389 .59604 .67912 .59072 Mtetra
.67912 .59072 .68389 .59604 .69394 .59316 .68919 .58782 Mtetra
.68919 .58782 .69394 .59316 .70402 .59027 .6993 .58491 Mtetra
.6993 .58491 .70402 .59027 .71414 .58737 .70944 .58199 Mtetra
.70944 .58199 .71414 .58737 .7243 .58446 .71962 .57906 Mtetra
.71962 .57906 .7243 .58446 .73449 .58154 .72984 .57612 Mtetra
.72984 .57612 .73449 .58154 .74472 .57861 .74009 .57317 Mtetra
.74009 .57317 .74472 .57861 .75498 .57567 .75038 .57021 Mtetra
.75038 .57021 .75498 .57567 .76528 .57272 .76071 .56724 Mtetra
.76071 .56724 .76528 .57272 .77562 .56975 .77107 .56426 Mtetra
.77107 .56426 .77562 .56975 .786 .56678 .78148 .56126 Mtetra
.78148 .56126 .786 .56678 .79641 .5638 .79192 .55826 Mtetra
.79192 .55826 .79641 .5638 .80686 .5608 .80239 .55524 Mtetra
.80239 .55524 .80686 .5608 .81735 .55779 .81291 .55222 Mtetra
.81291 .55222 .81735 .55779 .82788 .55478 .82346 .54918 Mtetra
.82346 .54918 .82788 .55478 .83844 .55175 .83406 .54613 Mtetra
.83406 .54613 .83844 .55175 .84905 .54871 .84469 .54307 Mtetra
.84469 .54307 .84905 .54871 .85969 .54566 .85536 .54 Mtetra
.85536 .54 .85969 .54566 .87037 .5426 .86607 .53692 Mtetra
.86607 .53692 .87037 .5426 .88109 .53953 .87682 .53383 Mtetra
.87682 .53383 .88109 .53953 .89185 .53644 .88761 .53072 Mtetra
.88761 .53072 .89185 .53644 .90265 .53335 .89844 .52761 Mtetra
.89844 .52761 .90265 .53335 .91349 .53024 .90931 .52448 Mtetra
.90931 .52448 .91349 .53024 .92437 .52712 .92022 .52134 Mtetra
.92022 .52134 .92437 .52712 .93529 .524 .93116 .51819 Mtetra
.93116 .51819 .93529 .524 .94625 .52085 .94216 .51503 Mtetra
.94216 .51503 .94625 .52085 .95725 .5177 .95319 .51185 Mtetra
.95319 .51185 .95725 .5177 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .6709 Mtetra
.37826 .6709 .38373 .67572 .39278 .67311 .38732 .66828 Mtetra
.38732 .66828 .39278 .67311 .40186 .6705 .39642 .66566 Mtetra
.39642 .66566 .40186 .6705 .41096 .66788 .40554 .66302 Mtetra
.40554 .66302 .41096 .66788 .4201 .66525 .4147 .66037 Mtetra
.4147 .66037 .4201 .66525 .42927 .66261 .42389 .65772 Mtetra
.42389 .65772 .42927 .66261 .43847 .65996 .43311 .65505 Mtetra
.43311 .65505 .43847 .65996 .4477 .65731 .44236 .65238 Mtetra
.44236 .65238 .4477 .65731 .45697 .65464 .45165 .6497 Mtetra
.45165 .6497 .45697 .65464 .46626 .65197 .46096 .64701 Mtetra
.46096 .64701 .46626 .65197 .47559 .64928 .47031 .6443 Mtetra
.47031 .6443 .47559 .64928 .48495 .64659 .47969 .64159 Mtetra
.47969 .64159 .48495 .64659 .49434 .64389 .4891 .63887 Mtetra
.4891 .63887 .49434 .64389 .50376 .64118 .49855 .63615 Mtetra
.49855 .63615 .50376 .64118 .51322 .63846 .50802 .63341 Mtetra
.50802 .63341 .51322 .63846 .52271 .63572 .51753 .63066 Mtetra
.51753 .63066 .52271 .63572 .53223 .63298 .52708 .6279 Mtetra
.52708 .6279 .53223 .63298 .54178 .63024 .53665 .62513 Mtetra
.53665 .62513 .54178 .63024 .55137 .62748 .54626 .62236 Mtetra
.54626 .62236 .55137 .62748 .56099 .62471 .55591 .61957 Mtetra
.55591 .61957 .56099 .62471 .57065 .62193 .56558 .61677 Mtetra
.56558 .61677 .57065 .62193 .58034 .61914 .57529 .61397 Mtetra
.57529 .61397 .58034 .61914 .59006 .61634 .58504 .61115 Mtetra
.58504 .61115 .59006 .61634 .59982 .61354 .59482 .60833 Mtetra
.59482 .60833 .59982 .61354 .60961 .61072 .60463 .60549 Mtetra
.60463 .60549 .60961 .61072 .61943 .60789 .61448 .60265 Mtetra
.61448 .60265 .61943 .60789 .62929 .60505 .62437 .59979 Mtetra
.62437 .59979 .62929 .60505 .63919 .60221 .63428 .59692 Mtetra
.63428 .59692 .63919 .60221 .64912 .59935 .64424 .59405 Mtetra
.64424 .59405 .64912 .59935 .65908 .59648 .65423 .59116 Mtetra
.65423 .59116 .65908 .59648 .66908 .5936 .66425 .58826 Mtetra
.66425 .58826 .66908 .5936 .67912 .59072 .67431 .58536 Mtetra
.67431 .58536 .67912 .59072 .68919 .58782 .68441 .58244 Mtetra
.68441 .58244 .68919 .58782 .6993 .58491 .69454 .57951 Mtetra
.69454 .57951 .6993 .58491 .70944 .58199 .70471 .57657 Mtetra
.70471 .57657 .70944 .58199 .71962 .57906 .71491 .57363 Mtetra
.71491 .57363 .71962 .57906 .72984 .57612 .72516 .57067 Mtetra
.72516 .57067 .72984 .57612 .74009 .57317 .73544 .5677 Mtetra
.73544 .5677 .74009 .57317 .75038 .57021 .74575 .56471 Mtetra
.74575 .56471 .75038 .57021 .76071 .56724 .75611 .56172 Mtetra
.75611 .56172 .76071 .56724 .77107 .56426 .7665 .55872 Mtetra
.7665 .55872 .77107 .56426 .78148 .56126 .77693 .55571 Mtetra
.77693 .55571 .78148 .56126 .79192 .55826 .78739 .55268 Mtetra
.78739 .55268 .79192 .55826 .80239 .55524 .7979 .54965 Mtetra
.7979 .54965 .80239 .55524 .81291 .55222 .80844 .5466 Mtetra
.80844 .5466 .81291 .55222 .82346 .54918 .81902 .54354 Mtetra
.81902 .54354 .82346 .54918 .83406 .54613 .82964 .54047 Mtetra
.82964 .54047 .83406 .54613 .84469 .54307 .8403 .53739 Mtetra
.8403 .53739 .84469 .54307 .85536 .54 .851 .5343 Mtetra
.851 .5343 .85536 .54 .86607 .53692 .86174 .5312 Mtetra
.86174 .5312 .86607 .53692 .87682 .53383 .87252 .52809 Mtetra
.87252 .52809 .87682 .53383 .88761 .53072 .88334 .52496 Mtetra
.88334 .52496 .88761 .53072 .89844 .52761 .89419 .52182 Mtetra
.89419 .52182 .89844 .52761 .90931 .52448 .90509 .51867 Mtetra
.90509 .51867 .90931 .52448 .92022 .52134 .91603 .51551 Mtetra
.91603 .51551 .92022 .52134 .93116 .51819 .92701 .51234 Mtetra
.92701 .51234 .93116 .51819 .94216 .51503 .93803 .50916 Mtetra
.93803 .50916 .94216 .51503 .95319 .51185 .94909 .50596 Mtetra
.94909 .50596 .95319 .51185 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .6709 .37275 .66606 Mtetra
.37275 .66606 .37826 .6709 .38732 .66828 .38183 .66342 Mtetra
.38183 .66342 .38732 .66828 .39642 .66566 .39094 .66078 Mtetra
.39094 .66078 .39642 .66566 .40554 .66302 .40009 .65813 Mtetra
.40009 .65813 .40554 .66302 .4147 .66037 .40927 .65546 Mtetra
.40927 .65546 .4147 .66037 .42389 .65772 .41848 .65279 Mtetra
.41848 .65279 .42389 .65772 .43311 .65505 .42772 .65011 Mtetra
.42772 .65011 .43311 .65505 .44236 .65238 .43699 .64742 Mtetra
.43699 .64742 .44236 .65238 .45165 .6497 .44629 .64472 Mtetra
.44629 .64472 .45165 .6497 .46096 .64701 .45563 .64201 Mtetra
.45563 .64201 .46096 .64701 .47031 .6443 .465 .63929 Mtetra
.465 .63929 .47031 .6443 .47969 .64159 .4744 .63657 Mtetra
.4744 .63657 .47969 .64159 .4891 .63887 .48383 .63383 Mtetra
.48383 .63383 .4891 .63887 .49855 .63615 .4933 .63108 Mtetra
.4933 .63108 .49855 .63615 .50802 .63341 .50279 .62833 Mtetra
.50279 .62833 .50802 .63341 .51753 .63066 .51233 .62556 Mtetra
.51233 .62556 .51753 .63066 .52708 .6279 .52189 .62279 Mtetra
.52189 .62279 .52708 .6279 .53665 .62513 .53149 .62 Mtetra
.53149 .62 .53665 .62513 .54626 .62236 .54112 .61721 Mtetra
.54112 .61721 .54626 .62236 .55591 .61957 .55079 .6144 Mtetra
.55079 .6144 .55591 .61957 .56558 .61677 .56049 .61159 Mtetra
.56049 .61159 .56558 .61677 .57529 .61397 .57022 .60876 Mtetra
.57022 .60876 .57529 .61397 .58504 .61115 .57999 .60593 Mtetra
.57999 .60593 .58504 .61115 .59482 .60833 .58979 .60308 Mtetra
.58979 .60308 .59482 .60833 .60463 .60549 .59963 .60023 Mtetra
.59963 .60023 .60463 .60549 .61448 .60265 .6095 .59737 Mtetra
.6095 .59737 .61448 .60265 .62437 .59979 .61941 .59449 Mtetra
.61941 .59449 .62437 .59979 .63428 .59692 .62935 .59161 Mtetra
.62935 .59161 .63428 .59692 .64424 .59405 .63933 .58871 Mtetra
.63933 .58871 .64424 .59405 .65423 .59116 .64934 .58581 Mtetra
.64934 .58581 .65423 .59116 .66425 .58826 .65939 .58289 Mtetra
.65939 .58289 .66425 .58826 .67431 .58536 .66947 .57996 Mtetra
.66947 .57996 .67431 .58536 .68441 .58244 .67959 .57703 Mtetra
.67959 .57703 .68441 .58244 .69454 .57951 .68975 .57408 Mtetra
.68975 .57408 .69454 .57951 .70471 .57657 .69995 .57112 Mtetra
.69995 .57112 .70471 .57657 .71491 .57363 .71018 .56815 Mtetra
.71018 .56815 .71491 .57363 .72516 .57067 .72044 .56517 Mtetra
.72044 .56517 .72516 .57067 .73544 .5677 .73075 .56218 Mtetra
.73075 .56218 .73544 .5677 .74575 .56471 .74109 .55918 Mtetra
.74109 .55918 .74575 .56471 .75611 .56172 .75147 .55617 Mtetra
.75147 .55617 .75611 .56172 .7665 .55872 .76189 .55315 Mtetra
.76189 .55315 .7665 .55872 .77693 .55571 .77234 .55012 Mtetra
.77234 .55012 .77693 .55571 .78739 .55268 .78284 .54707 Mtetra
.78284 .54707 .78739 .55268 .7979 .54965 .79337 .54401 Mtetra
.79337 .54401 .7979 .54965 .80844 .5466 .80394 .54095 Mtetra
.80394 .54095 .80844 .5466 .81902 .54354 .81455 .53787 Mtetra
.81455 .53787 .81902 .54354 .82964 .54047 .8252 .53478 Mtetra
.8252 .53478 .82964 .54047 .8403 .53739 .83589 .53168 Mtetra
.83589 .53168 .8403 .53739 .851 .5343 .84661 .52857 Mtetra
.84661 .52857 .851 .5343 .86174 .5312 .85738 .52544 Mtetra
.85738 .52544 .86174 .5312 .87252 .52809 .86819 .52231 Mtetra
.86819 .52231 .87252 .52809 .88334 .52496 .87903 .51916 Mtetra
.87903 .51916 .88334 .52496 .89419 .52182 .88992 .516 Mtetra
.88992 .516 .89419 .52182 .90509 .51867 .90085 .51283 Mtetra
.90085 .51283 .90509 .51867 .91603 .51551 .91182 .50965 Mtetra
.91182 .50965 .91603 .51551 .92701 .51234 .92283 .50645 Mtetra
.92283 .50645 .92701 .51234 .93803 .50916 .93388 .50324 Mtetra
.93388 .50324 .93803 .50916 .94909 .50596 .94497 .50003 Mtetra
.94497 .50003 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.35813 .66383 .36369 .66869 .37275 .66606 .3672 .66119 Mtetra
.3672 .66119 .37275 .66606 .38183 .66342 .3763 .65854 Mtetra
.3763 .65854 .38183 .66342 .39094 .66078 .38544 .65587 Mtetra
.38544 .65587 .39094 .66078 .40009 .65813 .3946 .6532 Mtetra
.3946 .6532 .40009 .65813 .40927 .65546 .4038 .65052 Mtetra
.4038 .65052 .40927 .65546 .41848 .65279 .41303 .64783 Mtetra
.41303 .64783 .41848 .65279 .42772 .65011 .42229 .64514 Mtetra
.42229 .64514 .42772 .65011 .43699 .64742 .43158 .64243 Mtetra
.43158 .64243 .43699 .64742 .44629 .64472 .4409 .63971 Mtetra
.4409 .63971 .44629 .64472 .45563 .64201 .45026 .63699 Mtetra
.45026 .63699 .45563 .64201 .465 .63929 .45965 .63425 Mtetra
.45965 .63425 .465 .63929 .4744 .63657 .46907 .63151 Mtetra
.46907 .63151 .4744 .63657 .48383 .63383 .47853 .62875 Mtetra
.47853 .62875 .48383 .63383 .4933 .63108 .48801 .62599 Mtetra
.48801 .62599 .4933 .63108 .50279 .62833 .49753 .62321 Mtetra
.49753 .62321 .50279 .62833 .51233 .62556 .50709 .62043 Mtetra
.50709 .62043 .51233 .62556 .52189 .62279 .51667 .61764 Mtetra
.51667 .61764 .52189 .62279 .53149 .62 .52629 .61483 Mtetra
.52629 .61483 .53149 .62 .54112 .61721 .53595 .61202 Mtetra
.53595 .61202 .54112 .61721 .55079 .6144 .54563 .6092 Mtetra
.54563 .6092 .55079 .6144 .56049 .61159 .55536 .60636 Mtetra
.55536 .60636 .56049 .61159 .57022 .60876 .56511 .60352 Mtetra
.56511 .60352 .57022 .60876 .57999 .60593 .5749 .60067 Mtetra
.5749 .60067 .57999 .60593 .58979 .60308 .58473 .59781 Mtetra
.58473 .59781 .58979 .60308 .59963 .60023 .59459 .59493 Mtetra
.59459 .59493 .59963 .60023 .6095 .59737 .60448 .59205 Mtetra
.60448 .59205 .6095 .59737 .61941 .59449 .61441 .58916 Mtetra
.61441 .58916 .61941 .59449 .62935 .59161 .62438 .58625 Mtetra
.62438 .58625 .62935 .59161 .63933 .58871 .63438 .58334 Mtetra
.63438 .58334 .63933 .58871 .64934 .58581 .64442 .58041 Mtetra
.64442 .58041 .64934 .58581 .65939 .58289 .65449 .57748 Mtetra
.65449 .57748 .65939 .58289 .66947 .57996 .6646 .57453 Mtetra
.6646 .57453 .66947 .57996 .67959 .57703 .67475 .57158 Mtetra
.67475 .57158 .67959 .57703 .68975 .57408 .68493 .56861 Mtetra
.68493 .56861 .68975 .57408 .69995 .57112 .69515 .56563 Mtetra
.69515 .56563 .69995 .57112 .71018 .56815 .70541 .56264 Mtetra
.70541 .56264 .71018 .56815 .72044 .56517 .7157 .55965 Mtetra
.7157 .55965 .72044 .56517 .73075 .56218 .72603 .55664 Mtetra
.72603 .55664 .73075 .56218 .74109 .55918 .7364 .55361 Mtetra
.7364 .55361 .74109 .55918 .75147 .55617 .7468 .55058 Mtetra
.7468 .55058 .75147 .55617 .76189 .55315 .75725 .54754 Mtetra
.75725 .54754 .76189 .55315 .77234 .55012 .76773 .54449 Mtetra
.76773 .54449 .77234 .55012 .78284 .54707 .77825 .54142 Mtetra
.77825 .54142 .78284 .54707 .79337 .54401 .78881 .53834 Mtetra
.78881 .53834 .79337 .54401 .80394 .54095 .79941 .53526 Mtetra
.79941 .53526 .80394 .54095 .81455 .53787 .81005 .53216 Mtetra
.81005 .53216 .81455 .53787 .8252 .53478 .82072 .52905 Mtetra
.82072 .52905 .8252 .53478 .83589 .53168 .83144 .52592 Mtetra
.83144 .52592 .83589 .53168 .84661 .52857 .84219 .52279 Mtetra
.84219 .52279 .84661 .52857 .85738 .52544 .85299 .51964 Mtetra
.85299 .51964 .85738 .52544 .86819 .52231 .86383 .51649 Mtetra
.86383 .51649 .86819 .52231 .87903 .51916 .8747 .51332 Mtetra
.8747 .51332 .87903 .51916 .88992 .516 .88562 .51014 Mtetra
.88562 .51014 .88992 .516 .90085 .51283 .89658 .50694 Mtetra
.89658 .50694 .90085 .51283 .91182 .50965 .90758 .50374 Mtetra
.90758 .50374 .91182 .50965 .92283 .50645 .91862 .50052 Mtetra
.91862 .50052 .92283 .50645 .93388 .50324 .9297 .49729 Mtetra
.9297 .49729 .93388 .50324 .94497 .50003 .94082 .49405 Mtetra
.94082 .49405 .94497 .50003 .9561 .4968 .95198 .4908 Mtetra
.35253 .65894 .35813 .66383 .3672 .66119 .36162 .65628 Mtetra
.36162 .65628 .3672 .66119 .3763 .65854 .37074 .65361 Mtetra
.37074 .65361 .3763 .65854 .38544 .65587 .3799 .65094 Mtetra
.3799 .65094 .38544 .65587 .3946 .6532 .38908 .64825 Mtetra
.38908 .64825 .3946 .6532 .4038 .65052 .3983 .64555 Mtetra
.3983 .64555 .4038 .65052 .41303 .64783 .40755 .64285 Mtetra
.40755 .64285 .41303 .64783 .42229 .64514 .41683 .64013 Mtetra
.41683 .64013 .42229 .64514 .43158 .64243 .42614 .63741 Mtetra
.42614 .63741 .43158 .64243 .4409 .63971 .43548 .63467 Mtetra
.43548 .63467 .4409 .63971 .45026 .63699 .44486 .63193 Mtetra
.44486 .63193 .45026 .63699 .45965 .63425 .45427 .62918 Mtetra
.45427 .62918 .45965 .63425 .46907 .63151 .46371 .62641 Mtetra
.46371 .62641 .46907 .63151 .47853 .62875 .47319 .62364 Mtetra
.47319 .62364 .47853 .62875 .48801 .62599 .48269 .62086 Mtetra
.48269 .62086 .48801 .62599 .49753 .62321 .49224 .61807 Mtetra
.49224 .61807 .49753 .62321 .50709 .62043 .50181 .61527 Mtetra
.50181 .61527 .50709 .62043 .51667 .61764 .51142 .61245 Mtetra
.51142 .61245 .51667 .61764 .52629 .61483 .52106 .60963 Mtetra
.52106 .60963 .52629 .61483 .53595 .61202 .53074 .6068 Mtetra
.53074 .6068 .53595 .61202 .54563 .6092 .54045 .60396 Mtetra
.54045 .60396 .54563 .6092 .55536 .60636 .55019 .60111 Mtetra
.55019 .60111 .55536 .60636 .56511 .60352 .55997 .59825 Mtetra
.55997 .59825 .56511 .60352 .5749 .60067 .56978 .59538 Mtetra
.56978 .59538 .5749 .60067 .58473 .59781 .57963 .59249 Mtetra
.57963 .59249 .58473 .59781 .59459 .59493 .58952 .5896 Mtetra
.58952 .5896 .59459 .59493 .60448 .59205 .59944 .5867 Mtetra
.59944 .5867 .60448 .59205 .61441 .58916 .60939 .58379 Mtetra
.60939 .58379 .61441 .58916 .62438 .58625 .61938 .58087 Mtetra
.61938 .58087 .62438 .58625 .63438 .58334 .62941 .57793 Mtetra
.62941 .57793 .63438 .58334 .64442 .58041 .63947 .57499 Mtetra
.63947 .57499 .64442 .58041 .65449 .57748 .64957 .57203 Mtetra
.64957 .57203 .65449 .57748 .6646 .57453 .6597 .56907 Mtetra
.6597 .56907 .6646 .57453 .67475 .57158 .66987 .56609 Mtetra
.66987 .56609 .67475 .57158 .68493 .56861 .68008 .56311 Mtetra
.68008 .56311 .68493 .56861 .69515 .56563 .69032 .56011 Mtetra
.69032 .56011 .69515 .56563 .70541 .56264 .7006 .5571 Mtetra
.7006 .5571 .70541 .56264 .7157 .55965 .71092 .55408 Mtetra
.71092 .55408 .7157 .55965 .72603 .55664 .72128 .55105 Mtetra
.72128 .55105 .72603 .55664 .7364 .55361 .73168 .54801 Mtetra
.73168 .54801 .7364 .55361 .7468 .55058 .74211 .54496 Mtetra
.74211 .54496 .7468 .55058 .75725 .54754 .75258 .54189 Mtetra
.75258 .54189 .75725 .54754 .76773 .54449 .76309 .53882 Mtetra
.76309 .53882 .76773 .54449 .77825 .54142 .77364 .53573 Mtetra
.77364 .53573 .77825 .54142 .78881 .53834 .78422 .53263 Mtetra
.78422 .53263 .78881 .53834 .79941 .53526 .79485 .52952 Mtetra
.79485 .52952 .79941 .53526 .81005 .53216 .80551 .5264 Mtetra
.80551 .5264 .81005 .53216 .82072 .52905 .81622 .52327 Mtetra
.81622 .52327 .82072 .52905 .83144 .52592 .82696 .52013 Mtetra
.82696 .52013 .83144 .52592 .84219 .52279 .83775 .51697 Mtetra
.83775 .51697 .84219 .52279 .85299 .51964 .84857 .51381 Mtetra
.84857 .51381 .85299 .51964 .86383 .51649 .85944 .51063 Mtetra
.85944 .51063 .86383 .51649 .8747 .51332 .87034 .50744 Mtetra
.87034 .50744 .8747 .51332 .88562 .51014 .88129 .50423 Mtetra
.88129 .50423 .88562 .51014 .89658 .50694 .89227 .50102 Mtetra
.89227 .50102 .89658 .50694 .90758 .50374 .9033 .49779 Mtetra
.9033 .49779 .90758 .50374 .91862 .50052 .91437 .49455 Mtetra
.91437 .49455 .91862 .50052 .9297 .49729 .92549 .4913 Mtetra
.92549 .4913 .9297 .49729 .94082 .49405 .93664 .48804 Mtetra
.93664 .48804 .94082 .49405 .95198 .4908 .94784 .48476 Mtetra
.34689 .65403 .35253 .65894 .36162 .65628 .356 .65135 Mtetra
.356 .65135 .36162 .65628 .37074 .65361 .36515 .64866 Mtetra
.36515 .64866 .37074 .65361 .3799 .65094 .37432 .64597 Mtetra
.37432 .64597 .3799 .65094 .38908 .64825 .38352 .64326 Mtetra
.38352 .64326 .38908 .64825 .3983 .64555 .39276 .64055 Mtetra
.39276 .64055 .3983 .64555 .40755 .64285 .40203 .63783 Mtetra
.40203 .63783 .40755 .64285 .41683 .64013 .41133 .63509 Mtetra
.41133 .63509 .41683 .64013 .42614 .63741 .42066 .63235 Mtetra
.42066 .63235 .42614 .63741 .43548 .63467 .43003 .6296 Mtetra
.43003 .6296 .43548 .63467 .44486 .63193 .43942 .62684 Mtetra
.43942 .62684 .44486 .63193 .45427 .62918 .44885 .62407 Mtetra
.44885 .62407 .45427 .62918 .46371 .62641 .45832 .62129 Mtetra
.45832 .62129 .46371 .62641 .47319 .62364 .46781 .6185 Mtetra
.46781 .6185 .47319 .62364 .48269 .62086 .47734 .6157 Mtetra
.47734 .6157 .48269 .62086 .49224 .61807 .4869 .61289 Mtetra
.4869 .61289 .49224 .61807 .50181 .61527 .4965 .61007 Mtetra
.4965 .61007 .50181 .61527 .51142 .61245 .50613 .60724 Mtetra
.50613 .60724 .51142 .61245 .52106 .60963 .5158 .6044 Mtetra
.5158 .6044 .52106 .60963 .53074 .6068 .52549 .60155 Mtetra
.52549 .60155 .53074 .6068 .54045 .60396 .53523 .59869 Mtetra
.53523 .59869 .54045 .60396 .55019 .60111 .54499 .59582 Mtetra
.54499 .59582 .55019 .60111 .55997 .59825 .5548 .59294 Mtetra
.5548 .59294 .55997 .59825 .56978 .59538 .56463 .59005 Mtetra
.56463 .59005 .56978 .59538 .57963 .59249 .5745 .58715 Mtetra
.5745 .58715 .57963 .59249 .58952 .5896 .58441 .58424 Mtetra
.58441 .58424 .58952 .5896 .59944 .5867 .59435 .58132 Mtetra
.59435 .58132 .59944 .5867 .60939 .58379 .60433 .57838 Mtetra
.60433 .57838 .60939 .58379 .61938 .58087 .61435 .57544 Mtetra
.61435 .57544 .61938 .58087 .62941 .57793 .6244 .57249 Mtetra
.6244 .57249 .62941 .57793 .63947 .57499 .63448 .56952 Mtetra
.63448 .56952 .63947 .57499 .64957 .57203 .6446 .56655 Mtetra
.6446 .56655 .64957 .57203 .6597 .56907 .65476 .56357 Mtetra
.65476 .56357 .6597 .56907 .66987 .56609 .66496 .56057 Mtetra
.66496 .56057 .66987 .56609 .68008 .56311 .67519 .55756 Mtetra
.67519 .55756 .68008 .56311 .69032 .56011 .68546 .55455 Mtetra
.68546 .55455 .69032 .56011 .7006 .5571 .69577 .55152 Mtetra
.69577 .55152 .7006 .5571 .71092 .55408 .70612 .54848 Mtetra
.70612 .54848 .71092 .55408 .72128 .55105 .7165 .54543 Mtetra
.7165 .54543 .72128 .55105 .73168 .54801 .72692 .54236 Mtetra
.72692 .54236 .73168 .54801 .74211 .54496 .73738 .53929 Mtetra
.73738 .53929 .74211 .54496 .75258 .54189 .74788 .53621 Mtetra
.74788 .53621 .75258 .54189 .76309 .53882 .75841 .53311 Mtetra
.75841 .53311 .76309 .53882 .77364 .53573 .76899 .53 Mtetra
.76899 .53 .77364 .53573 .78422 .53263 .7796 .52688 Mtetra
.7796 .52688 .78422 .53263 .79485 .52952 .79026 .52375 Mtetra
.79026 .52375 .79485 .52952 .80551 .5264 .80095 .52061 Mtetra
.80095 .52061 .80551 .5264 .81622 .52327 .81168 .51746 Mtetra
.81168 .51746 .81622 .52327 .82696 .52013 .82245 .51429 Mtetra
.82245 .51429 .82696 .52013 .83775 .51697 .83327 .51112 Mtetra
.83327 .51112 .83775 .51697 .84857 .51381 .84412 .50793 Mtetra
.84412 .50793 .84857 .51381 .85944 .51063 .85501 .50473 Mtetra
.85501 .50473 .85944 .51063 .87034 .50744 .86595 .50151 Mtetra
.86595 .50151 .87034 .50744 .88129 .50423 .87693 .49829 Mtetra
.87693 .49829 .88129 .50423 .89227 .50102 .88794 .49505 Mtetra
.88794 .49505 .89227 .50102 .9033 .49779 .899 .4918 Mtetra
.899 .4918 .9033 .49779 .91437 .49455 .9101 .48854 Mtetra
.9101 .48854 .91437 .49455 .92549 .4913 .92125 .48527 Mtetra
.92125 .48527 .92549 .4913 .93664 .48804 .93243 .48198 Mtetra
.93243 .48198 .93664 .48804 .94784 .48476 .94366 .47868 Mtetra
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64638 Mtetra
.35035 .64638 .356 .65135 .36515 .64866 .35951 .64368 Mtetra
.35951 .64368 .36515 .64866 .37432 .64597 .36871 .64097 Mtetra
.36871 .64097 .37432 .64597 .38352 .64326 .37793 .63825 Mtetra
.37793 .63825 .38352 .64326 .39276 .64055 .38719 .63551 Mtetra
.38719 .63551 .39276 .64055 .40203 .63783 .39647 .63277 Mtetra
.39647 .63277 .40203 .63783 .41133 .63509 .40579 .63002 Mtetra
.40579 .63002 .41133 .63509 .42066 .63235 .41515 .62726 Mtetra
.41515 .62726 .42066 .63235 .43003 .6296 .42453 .62449 Mtetra
.42453 .62449 .43003 .6296 .43942 .62684 .43395 .62172 Mtetra
.43395 .62172 .43942 .62684 .44885 .62407 .4434 .61893 Mtetra
.4434 .61893 .44885 .62407 .45832 .62129 .45289 .61613 Mtetra
.45289 .61613 .45832 .62129 .46781 .6185 .4624 .61332 Mtetra
.4624 .61332 .46781 .6185 .47734 .6157 .47195 .6105 Mtetra
.47195 .6105 .47734 .6157 .4869 .61289 .48154 .60767 Mtetra
.48154 .60767 .4869 .61289 .4965 .61007 .49116 .60484 Mtetra
.49116 .60484 .4965 .61007 .50613 .60724 .50081 .60199 Mtetra
.50081 .60199 .50613 .60724 .5158 .6044 .5105 .59913 Mtetra
.5105 .59913 .5158 .6044 .52549 .60155 .52022 .59626 Mtetra
.52022 .59626 .52549 .60155 .53523 .59869 .52997 .59338 Mtetra
.52997 .59338 .53523 .59869 .54499 .59582 .53976 .59049 Mtetra
.53976 .59049 .54499 .59582 .5548 .59294 .54959 .58759 Mtetra
.54959 .58759 .5548 .59294 .56463 .59005 .55945 .58469 Mtetra
.55945 .58469 .56463 .59005 .5745 .58715 .56934 .58177 Mtetra
.56934 .58177 .5745 .58715 .58441 .58424 .57927 .57884 Mtetra
.57927 .57884 .58441 .58424 .59435 .58132 .58924 .57589 Mtetra
.58924 .57589 .59435 .58132 .60433 .57838 .59924 .57294 Mtetra
.59924 .57294 .60433 .57838 .61435 .57544 .60928 .56998 Mtetra
.60928 .56998 .61435 .57544 .6244 .57249 .61935 .56701 Mtetra
.61935 .56701 .6244 .57249 .63448 .56952 .62946 .56403 Mtetra
.62946 .56403 .63448 .56952 .6446 .56655 .63961 .56103 Mtetra
.63961 .56103 .6446 .56655 .65476 .56357 .64979 .55803 Mtetra
.64979 .55803 .65476 .56357 .66496 .56057 .66002 .55501 Mtetra
.66002 .55501 .66496 .56057 .67519 .55756 .67027 .55198 Mtetra
.67027 .55198 .67519 .55756 .68546 .55455 .68057 .54895 Mtetra
.68057 .54895 .68546 .55455 .69577 .55152 .6909 .5459 Mtetra
.6909 .5459 .69577 .55152 .70612 .54848 .70127 .54284 Mtetra
.70127 .54284 .70612 .54848 .7165 .54543 .71168 .53976 Mtetra
.71168 .53976 .7165 .54543 .72692 .54236 .72213 .53668 Mtetra
.72213 .53668 .72692 .54236 .73738 .53929 .73262 .53359 Mtetra
.73262 .53359 .73738 .53929 .74788 .53621 .74314 .53048 Mtetra
.74314 .53048 .74788 .53621 .75841 .53311 .75371 .52737 Mtetra
.75371 .52737 .75841 .53311 .76899 .53 .76431 .52424 Mtetra
.76431 .52424 .76899 .53 .7796 .52688 .77495 .5211 Mtetra
.77495 .5211 .7796 .52688 .79026 .52375 .78563 .51794 Mtetra
.78563 .51794 .79026 .52375 .80095 .52061 .79635 .51478 Mtetra
.79635 .51478 .80095 .52061 .81168 .51746 .80711 .51161 Mtetra
.80711 .51161 .81168 .51746 .82245 .51429 .81792 .50842 Mtetra
.81792 .50842 .82245 .51429 .83327 .51112 .82876 .50522 Mtetra
.82876 .50522 .83327 .51112 .84412 .50793 .83964 .50201 Mtetra
.83964 .50201 .84412 .50793 .85501 .50473 .85056 .49879 Mtetra
.85056 .49879 .85501 .50473 .86595 .50151 .86153 .49555 Mtetra
.86153 .49555 .86595 .50151 .87693 .49829 .87253 .4923 Mtetra
.87253 .4923 .87693 .49829 .88794 .49505 .88358 .48904 Mtetra
.88358 .48904 .88794 .49505 .899 .4918 .89467 .48577 Mtetra
.89467 .48577 .899 .4918 .9101 .48854 .9058 .48249 Mtetra
.9058 .48249 .9101 .48854 .92125 .48527 .91698 .47919 Mtetra
.91698 .47919 .92125 .48527 .93243 .48198 .92819 .47588 Mtetra
.92819 .47588 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.33552 .6441 .34122 .64908 .35035 .64638 .34467 .64139 Mtetra
.34467 .64139 .35035 .64638 .35951 .64368 .35385 .63866 Mtetra
.35385 .63866 .35951 .64368 .36871 .64097 .36306 .63594 Mtetra
.36306 .63594 .36871 .64097 .37793 .63825 .3723 .6332 Mtetra
.3723 .6332 .37793 .63825 .38719 .63551 .38158 .63045 Mtetra
.38158 .63045 .38719 .63551 .39647 .63277 .39089 .62769 Mtetra
.39089 .62769 .39647 .63277 .40579 .63002 .40023 .62492 Mtetra
.40023 .62492 .40579 .63002 .41515 .62726 .4096 .62214 Mtetra
.4096 .62214 .41515 .62726 .42453 .62449 .41901 .61936 Mtetra
.41901 .61936 .42453 .62449 .43395 .62172 .42844 .61656 Mtetra
.42844 .61656 .43395 .62172 .4434 .61893 .43792 .61375 Mtetra
.43792 .61375 .4434 .61893 .45289 .61613 .44742 .61094 Mtetra
.44742 .61094 .45289 .61613 .4624 .61332 .45696 .60811 Mtetra
.45696 .60811 .4624 .61332 .47195 .6105 .46653 .60527 Mtetra
.46653 .60527 .47195 .6105 .48154 .60767 .47614 .60243 Mtetra
.47614 .60243 .48154 .60767 .49116 .60484 .48578 .59957 Mtetra
.48578 .59957 .49116 .60484 .50081 .60199 .49545 .5967 Mtetra
.49545 .5967 .50081 .60199 .5105 .59913 .50516 .59383 Mtetra
.50516 .59383 .5105 .59913 .52022 .59626 .5149 .59094 Mtetra
.5149 .59094 .52022 .59626 .52997 .59338 .52468 .58804 Mtetra
.52468 .58804 .52997 .59338 .53976 .59049 .5345 .58513 Mtetra
.5345 .58513 .53976 .59049 .54959 .58759 .54434 .58222 Mtetra
.54434 .58222 .54959 .58759 .55945 .58469 .55423 .57929 Mtetra
.55423 .57929 .55945 .58469 .56934 .58177 .56414 .57635 Mtetra
.56414 .57635 .56934 .58177 .57927 .57884 .5741 .5734 Mtetra
.5741 .5734 .57927 .57884 .58924 .57589 .58409 .57044 Mtetra
.58409 .57044 .58924 .57589 .59924 .57294 .59412 .56747 Mtetra
.59412 .56747 .59924 .57294 .60928 .56998 .60418 .56449 Mtetra
.60418 .56449 .60928 .56998 .61935 .56701 .61428 .56149 Mtetra
.61428 .56149 .61935 .56701 .62946 .56403 .62441 .55849 Mtetra
.62441 .55849 .62946 .56403 .63961 .56103 .63458 .55547 Mtetra
.63458 .55547 .63961 .56103 .64979 .55803 .64479 .55245 Mtetra
.64479 .55245 .64979 .55803 .66002 .55501 .65504 .54941 Mtetra
.65504 .54941 .66002 .55501 .67027 .55198 .66532 .54637 Mtetra
.66532 .54637 .67027 .55198 .68057 .54895 .67564 .54331 Mtetra
.67564 .54331 .68057 .54895 .6909 .5459 .686 .54024 Mtetra
.686 .54024 .6909 .5459 .70127 .54284 .6964 .53716 Mtetra
.6964 .53716 .70127 .54284 .71168 .53976 .70684 .53406 Mtetra
.70684 .53406 .71168 .53976 .72213 .53668 .71731 .53096 Mtetra
.71731 .53096 .72213 .53668 .73262 .53359 .72782 .52785 Mtetra
.72782 .52785 .73262 .53359 .74314 .53048 .73838 .52472 Mtetra
.73838 .52472 .74314 .53048 .75371 .52737 .74897 .52158 Mtetra
.74897 .52158 .75371 .52737 .76431 .52424 .7596 .51843 Mtetra
.7596 .51843 .76431 .52424 .77495 .5211 .77027 .51527 Mtetra
.77027 .51527 .77495 .5211 .78563 .51794 .78098 .5121 Mtetra
.78098 .5121 .78563 .51794 .79635 .51478 .79173 .50891 Mtetra
.79173 .50891 .79635 .51478 .80711 .51161 .80251 .50571 Mtetra
.80251 .50571 .80711 .51161 .81792 .50842 .81335 .5025 Mtetra
.81335 .5025 .81792 .50842 .82876 .50522 .82422 .49928 Mtetra
.82422 .49928 .82876 .50522 .83964 .50201 .83513 .49605 Mtetra
.83513 .49605 .83964 .50201 .85056 .49879 .84608 .4928 Mtetra
.84608 .4928 .85056 .49879 .86153 .49555 .85707 .48955 Mtetra
.85707 .48955 .86153 .49555 .87253 .4923 .86811 .48627 Mtetra
.86811 .48627 .87253 .4923 .88358 .48904 .87919 .48299 Mtetra
.87919 .48299 .88358 .48904 .89467 .48577 .89031 .4797 Mtetra
.89031 .4797 .89467 .48577 .9058 .48249 .90147 .47639 Mtetra
.90147 .47639 .9058 .48249 .91698 .47919 .91268 .47307 Mtetra
.91268 .47307 .91698 .47919 .92819 .47588 .92392 .46974 Mtetra
.92392 .46974 .92819 .47588 .93945 .47256 .93521 .46639 Mtetra
.32977 .63908 .33552 .6441 .34467 .64139 .33894 .63636 Mtetra
.33894 .63636 .34467 .64139 .35385 .63866 .34814 .63362 Mtetra
.34814 .63362 .35385 .63866 .36306 .63594 .35737 .63087 Mtetra
.35737 .63087 .36306 .63594 .3723 .6332 .36664 .62811 Mtetra
.36664 .62811 .3723 .6332 .38158 .63045 .37593 .62535 Mtetra
.37593 .62535 .38158 .63045 .39089 .62769 .38526 .62257 Mtetra
.38526 .62257 .39089 .62769 .40023 .62492 .39462 .61979 Mtetra
.39462 .61979 .40023 .62492 .4096 .62214 .40402 .61699 Mtetra
.40402 .61699 .4096 .62214 .41901 .61936 .41344 .61418 Mtetra
.41344 .61418 .41901 .61936 .42844 .61656 .4229 .61137 Mtetra
.4229 .61137 .42844 .61656 .43792 .61375 .43239 .60854 Mtetra
.43239 .60854 .43792 .61375 .44742 .61094 .44192 .60571 Mtetra
.44192 .60571 .44742 .61094 .45696 .60811 .45148 .60286 Mtetra
.45148 .60286 .45696 .60811 .46653 .60527 .46108 .60001 Mtetra
.46108 .60001 .46653 .60527 .47614 .60243 .4707 .59714 Mtetra
.4707 .59714 .47614 .60243 .48578 .59957 .48037 .59427 Mtetra
.48037 .59427 .48578 .59957 .49545 .5967 .49006 .59138 Mtetra
.49006 .59138 .49545 .5967 .50516 .59383 .49979 .58849 Mtetra
.49979 .58849 .50516 .59383 .5149 .59094 .50956 .58558 Mtetra
.50956 .58558 .5149 .59094 .52468 .58804 .51936 .58267 Mtetra
.51936 .58267 .52468 .58804 .5345 .58513 .52919 .57974 Mtetra
.52919 .57974 .5345 .58513 .54434 .58222 .53907 .5768 Mtetra
.53907 .5768 .54434 .58222 .55423 .57929 .54897 .57385 Mtetra
.54897 .57385 .55423 .57929 .56414 .57635 .55891 .57089 Mtetra
.55891 .57089 .56414 .57635 .5741 .5734 .56889 .56792 Mtetra
.56889 .56792 .5741 .5734 .58409 .57044 .57891 .56494 Mtetra
.57891 .56494 .58409 .57044 .59412 .56747 .58896 .56195 Mtetra
.58896 .56195 .59412 .56747 .60418 .56449 .59904 .55895 Mtetra
.59904 .55895 .60418 .56449 .61428 .56149 .60917 .55594 Mtetra
.60917 .55594 .61428 .56149 .62441 .55849 .61933 .55292 Mtetra
.61933 .55292 .62441 .55849 .63458 .55547 .62952 .54988 Mtetra
.62952 .54988 .63458 .55547 .64479 .55245 .63976 .54684 Mtetra
.63976 .54684 .64479 .55245 .65504 .54941 .65003 .54378 Mtetra
.65003 .54378 .65504 .54941 .66532 .54637 .66034 .54071 Mtetra
.66034 .54071 .66532 .54637 .67564 .54331 .67069 .53763 Mtetra
.67069 .53763 .67564 .54331 .686 .54024 .68107 .53454 Mtetra
.68107 .53454 .686 .54024 .6964 .53716 .69149 .53144 Mtetra
.69149 .53144 .6964 .53716 .70684 .53406 .70196 .52833 Mtetra
.70196 .52833 .70684 .53406 .71731 .53096 .71246 .5252 Mtetra
.71246 .5252 .71731 .53096 .72782 .52785 .723 .52206 Mtetra
.723 .52206 .72782 .52785 .73838 .52472 .73358 .51892 Mtetra
.73358 .51892 .73838 .52472 .74897 .52158 .74419 .51576 Mtetra
.74419 .51576 .74897 .52158 .7596 .51843 .75485 .51258 Mtetra
.75485 .51258 .7596 .51843 .77027 .51527 .76555 .5094 Mtetra
.76555 .5094 .77027 .51527 .78098 .5121 .77629 .50621 Mtetra
.77629 .50621 .78098 .5121 .79173 .50891 .78707 .503 Mtetra
.78707 .503 .79173 .50891 .80251 .50571 .79788 .49978 Mtetra
.79788 .49978 .80251 .50571 .81335 .5025 .80874 .49655 Mtetra
.80874 .49655 .81335 .5025 .82422 .49928 .81964 .4933 Mtetra
.81964 .4933 .82422 .49928 .83513 .49605 .83058 .49005 Mtetra
.83058 .49005 .83513 .49605 .84608 .4928 .84157 .48678 Mtetra
.84157 .48678 .84608 .4928 .85707 .48955 .85259 .4835 Mtetra
.85259 .4835 .85707 .48955 .86811 .48627 .86366 .4802 Mtetra
.86366 .4802 .86811 .48627 .87919 .48299 .87477 .4769 Mtetra
.87477 .4769 .87919 .48299 .89031 .4797 .88592 .47358 Mtetra
.88592 .47358 .89031 .4797 .90147 .47639 .89711 .47025 Mtetra
.89711 .47025 .90147 .47639 .91268 .47307 .90834 .46691 Mtetra
.90834 .46691 .91268 .47307 .92392 .46974 .91962 .46355 Mtetra
.91962 .46355 .92392 .46974 .93521 .46639 .93095 .46018 Mtetra
.32399 .63404 .32977 .63908 .33894 .63636 .33318 .63129 Mtetra
.33318 .63129 .33894 .63636 .34814 .63362 .3424 .62854 Mtetra
.3424 .62854 .34814 .63362 .35737 .63087 .35165 .62577 Mtetra
.35165 .62577 .35737 .63087 .36664 .62811 .36094 .623 Mtetra
.36094 .623 .36664 .62811 .37593 .62535 .37025 .62021 Mtetra
.37025 .62021 .37593 .62535 .38526 .62257 .3796 .61742 Mtetra
.3796 .61742 .38526 .62257 .39462 .61979 .38898 .61462 Mtetra
.38898 .61462 .39462 .61979 .40402 .61699 .3984 .6118 Mtetra
.3984 .6118 .40402 .61699 .41344 .61418 .40784 .60898 Mtetra
.40784 .60898 .41344 .61418 .4229 .61137 .41732 .60615 Mtetra
.41732 .60615 .4229 .61137 .43239 .60854 .42684 .6033 Mtetra
.42684 .6033 .43239 .60854 .44192 .60571 .43639 .60045 Mtetra
.43639 .60045 .44192 .60571 .45148 .60286 .44597 .59759 Mtetra
.44597 .59759 .45148 .60286 .46108 .60001 .45558 .59471 Mtetra
.45558 .59471 .46108 .60001 .4707 .59714 .46523 .59183 Mtetra
.46523 .59183 .4707 .59714 .48037 .59427 .47492 .58893 Mtetra
.47492 .58893 .48037 .59427 .49006 .59138 .48463 .58603 Mtetra
.48463 .58603 .49006 .59138 .49979 .58849 .49439 .58311 Mtetra
.49439 .58311 .49979 .58849 .50956 .58558 .50418 .58019 Mtetra
.50418 .58019 .50956 .58558 .51936 .58267 .514 .57725 Mtetra
.514 .57725 .51936 .58267 .52919 .57974 .52386 .57431 Mtetra
.52386 .57431 .52919 .57974 .53907 .5768 .53375 .57135 Mtetra
.53375 .57135 .53907 .5768 .54897 .57385 .54368 .56838 Mtetra
.54368 .56838 .54897 .57385 .55891 .57089 .55365 .5654 Mtetra
.55365 .5654 .55891 .57089 .56889 .56792 .56365 .56241 Mtetra
.56365 .56241 .56889 .56792 .57891 .56494 .57369 .55941 Mtetra
.57369 .55941 .57891 .56494 .58896 .56195 .58376 .5564 Mtetra
.58376 .5564 .58896 .56195 .59904 .55895 .59387 .55338 Mtetra
.59387 .55338 .59904 .55895 .60917 .55594 .60402 .55035 Mtetra
.60402 .55035 .60917 .55594 .61933 .55292 .61421 .5473 Mtetra
.61421 .5473 .61933 .55292 .62952 .54988 .62443 .54425 Mtetra
.62443 .54425 .62952 .54988 .63976 .54684 .63469 .54118 Mtetra
.63469 .54118 .63976 .54684 .65003 .54378 .64498 .53811 Mtetra
.64498 .53811 .65003 .54378 .66034 .54071 .65532 .53502 Mtetra
.65532 .53502 .66034 .54071 .67069 .53763 .66569 .53192 Mtetra
.66569 .53192 .67069 .53763 .68107 .53454 .6761 .52881 Mtetra
.6761 .52881 .68107 .53454 .69149 .53144 .68655 .52568 Mtetra
.68655 .52568 .69149 .53144 .70196 .52833 .69704 .52255 Mtetra
.69704 .52255 .70196 .52833 .71246 .5252 .70757 .5194 Mtetra
.70757 .5194 .71246 .5252 .723 .52206 .71814 .51624 Mtetra
.71814 .51624 .723 .52206 .73358 .51892 .72874 .51307 Mtetra
.72874 .51307 .73358 .51892 .74419 .51576 .73939 .50989 Mtetra
.73939 .50989 .74419 .51576 .75485 .51258 .75008 .5067 Mtetra
.75008 .5067 .75485 .51258 .76555 .5094 .7608 .50349 Mtetra
.7608 .50349 .76555 .5094 .77629 .50621 .77157 .50027 Mtetra
.77157 .50027 .77629 .50621 .78707 .503 .78237 .49704 Mtetra
.78237 .49704 .78707 .503 .79788 .49978 .79322 .4938 Mtetra
.79322 .4938 .79788 .49978 .80874 .49655 .80411 .49055 Mtetra
.80411 .49055 .80874 .49655 .81964 .4933 .81504 .48728 Mtetra
.81504 .48728 .81964 .4933 .83058 .49005 .82601 .484 Mtetra
.82601 .484 .83058 .49005 .84157 .48678 .83702 .48071 Mtetra
.83702 .48071 .84157 .48678 .85259 .4835 .84808 .47741 Mtetra
.84808 .47741 .85259 .4835 .86366 .4802 .85917 .47409 Mtetra
.85917 .47409 .86366 .4802 .87477 .4769 .87031 .47076 Mtetra
.87031 .47076 .87477 .4769 .88592 .47358 .88149 .46742 Mtetra
.88149 .46742 .88592 .47358 .89711 .47025 .89272 .46407 Mtetra
.89272 .46407 .89711 .47025 .90834 .46691 .90398 .4607 Mtetra
.90398 .4607 .90834 .46691 .91962 .46355 .91529 .45732 Mtetra
.91529 .45732 .91962 .46355 .93095 .46018 .92665 .45393 Mtetra
.31818 .62896 .32399 .63404 .33318 .63129 .32738 .6262 Mtetra
.32738 .6262 .33318 .63129 .3424 .62854 .33662 .62343 Mtetra
.33662 .62343 .3424 .62854 .35165 .62577 .34589 .62064 Mtetra
.34589 .62064 .35165 .62577 .36094 .623 .3552 .61785 Mtetra
.3552 .61785 .36094 .623 .37025 .62021 .36453 .61505 Mtetra
.36453 .61505 .37025 .62021 .3796 .61742 .3739 .61224 Mtetra
.3739 .61224 .3796 .61742 .38898 .61462 .3833 .60942 Mtetra
.3833 .60942 .38898 .61462 .3984 .6118 .39274 .60658 Mtetra
.39274 .60658 .3984 .6118 .40784 .60898 .40221 .60374 Mtetra
.40221 .60374 .40784 .60898 .41732 .60615 .41171 .60089 Mtetra
.41171 .60089 .41732 .60615 .42684 .6033 .42124 .59803 Mtetra
.42124 .59803 .42684 .6033 .43639 .60045 .43081 .59516 Mtetra
.43081 .59516 .43639 .60045 .44597 .59759 .44042 .59227 Mtetra
.44042 .59227 .44597 .59759 .45558 .59471 .45005 .58938 Mtetra
.45005 .58938 .45558 .59471 .46523 .59183 .45972 .58648 Mtetra
.45972 .58648 .46523 .59183 .47492 .58893 .46943 .58356 Mtetra
.46943 .58356 .47492 .58893 .48463 .58603 .47917 .58064 Mtetra
.47917 .58064 .48463 .58603 .49439 .58311 .48895 .57771 Mtetra
.48895 .57771 .49439 .58311 .50418 .58019 .49876 .57476 Mtetra
.49876 .57476 .50418 .58019 .514 .57725 .5086 .57181 Mtetra
.5086 .57181 .514 .57725 .52386 .57431 .51849 .56884 Mtetra
.51849 .56884 .52386 .57431 .53375 .57135 .5284 .56586 Mtetra
.5284 .56586 .53375 .57135 .54368 .56838 .53836 .56288 Mtetra
.53836 .56288 .54368 .56838 .55365 .5654 .54835 .55988 Mtetra
.54835 .55988 .55365 .5654 .56365 .56241 .55837 .55687 Mtetra
.55837 .55687 .56365 .56241 .57369 .55941 .56843 .55385 Mtetra
.56843 .55385 .57369 .55941 .58376 .5564 .57853 .55082 Mtetra
.57853 .55082 .58376 .5564 .59387 .55338 .58867 .54777 Mtetra
.58867 .54777 .59387 .55338 .60402 .55035 .59884 .54472 Mtetra
.59884 .54472 .60402 .55035 .61421 .5473 .60905 .54166 Mtetra
.60905 .54166 .61421 .5473 .62443 .54425 .6193 .53858 Mtetra
.6193 .53858 .62443 .54425 .63469 .54118 .62958 .53549 Mtetra
.62958 .53549 .63469 .54118 .64498 .53811 .63991 .53239 Mtetra
.63991 .53239 .64498 .53811 .65532 .53502 .65027 .52928 Mtetra
.65027 .52928 .65532 .53502 .66569 .53192 .66067 .52616 Mtetra
.66067 .52616 .66569 .53192 .6761 .52881 .6711 .52303 Mtetra
.6711 .52303 .6761 .52881 .68655 .52568 .68158 .51989 Mtetra
.68158 .51989 .68655 .52568 .69704 .52255 .6921 .51673 Mtetra
.6921 .51673 .69704 .52255 .70757 .5194 .70265 .51356 Mtetra
.70265 .51356 .70757 .5194 .71814 .51624 .71324 .51038 Mtetra
.71324 .51038 .71814 .51624 .72874 .51307 .72388 .50719 Mtetra
.72388 .50719 .72874 .51307 .73939 .50989 .73455 .50399 Mtetra
.73455 .50399 .73939 .50989 .75008 .5067 .74527 .50077 Mtetra
.74527 .50077 .75008 .5067 .7608 .50349 .75602 .49754 Mtetra
.75602 .49754 .7608 .50349 .77157 .50027 .76681 .4943 Mtetra
.76681 .4943 .77157 .50027 .78237 .49704 .77765 .49105 Mtetra
.77765 .49105 .78237 .49704 .79322 .4938 .78852 .48779 Mtetra
.78852 .48779 .79322 .4938 .80411 .49055 .79944 .48451 Mtetra
.79944 .48451 .80411 .49055 .81504 .48728 .8104 .48122 Mtetra
.8104 .48122 .81504 .48728 .82601 .484 .8214 .47792 Mtetra
.8214 .47792 .82601 .484 .83702 .48071 .83244 .4746 Mtetra
.83244 .4746 .83702 .48071 .84808 .47741 .84353 .47128 Mtetra
.84353 .47128 .84808 .47741 .85917 .47409 .85465 .46794 Mtetra
.85465 .46794 .85917 .47409 .87031 .47076 .86582 .46458 Mtetra
.86582 .46458 .87031 .47076 .88149 .46742 .87704 .46122 Mtetra
.87704 .46122 .88149 .46742 .89272 .46407 .88829 .45784 Mtetra
.88829 .45784 .89272 .46407 .90398 .4607 .89959 .45445 Mtetra
.89959 .45445 .90398 .4607 .91529 .45732 .91093 .45104 Mtetra
.91093 .45104 .91529 .45732 .92665 .45393 .92232 .44763 Mtetra
.31232 .62385 .31818 .62896 .32738 .6262 .32155 .62107 Mtetra
.32155 .62107 .32738 .6262 .33662 .62343 .33081 .61828 Mtetra
.33081 .61828 .33662 .62343 .34589 .62064 .3401 .61548 Mtetra
.3401 .61548 .34589 .62064 .3552 .61785 .34942 .61267 Mtetra
.34942 .61267 .3552 .61785 .36453 .61505 .35878 .60985 Mtetra
.35878 .60985 .36453 .61505 .3739 .61224 .36817 .60702 Mtetra
.36817 .60702 .3739 .61224 .3833 .60942 .37759 .60418 Mtetra
.37759 .60418 .3833 .60942 .39274 .60658 .38704 .60133 Mtetra
.38704 .60133 .39274 .60658 .40221 .60374 .39653 .59847 Mtetra
.39653 .59847 .40221 .60374 .41171 .60089 .40606 .5956 Mtetra
.40606 .5956 .41171 .60089 .42124 .59803 .41561 .59272 Mtetra
.41561 .59272 .42124 .59803 .43081 .59516 .4252 .58983 Mtetra
.4252 .58983 .43081 .59516 .44042 .59227 .43483 .58692 Mtetra
.43483 .58692 .44042 .59227 .45005 .58938 .44449 .58401 Mtetra
.44449 .58401 .45005 .58938 .45972 .58648 .45418 .58109 Mtetra
.45418 .58109 .45972 .58648 .46943 .58356 .46391 .57816 Mtetra
.46391 .57816 .46943 .58356 .47917 .58064 .47367 .57521 Mtetra
.47367 .57521 .47917 .58064 .48895 .57771 .48347 .57226 Mtetra
.48347 .57226 .48895 .57771 .49876 .57476 .4933 .5693 Mtetra
.4933 .5693 .49876 .57476 .5086 .57181 .50317 .56632 Mtetra
.50317 .56632 .5086 .57181 .51849 .56884 .51308 .56334 Mtetra
.51308 .56334 .51849 .56884 .5284 .56586 .52302 .56034 Mtetra
.52302 .56034 .5284 .56586 .53836 .56288 .533 .55733 Mtetra
.533 .55733 .53836 .56288 .54835 .55988 .54301 .55431 Mtetra
.54301 .55431 .54835 .55988 .55837 .55687 .55306 .55128 Mtetra
.55306 .55128 .55837 .55687 .56843 .55385 .56314 .54824 Mtetra
.56314 .54824 .56843 .55385 .57853 .55082 .57327 .54519 Mtetra
.57327 .54519 .57853 .55082 .58867 .54777 .58343 .54213 Mtetra
.58343 .54213 .58867 .54777 .59884 .54472 .59363 .53905 Mtetra
.59363 .53905 .59884 .54472 .60905 .54166 .60386 .53597 Mtetra
.60386 .53597 .60905 .54166 .6193 .53858 .61413 .53287 Mtetra
.61413 .53287 .6193 .53858 .62958 .53549 .62444 .52976 Mtetra
.62444 .52976 .62958 .53549 .63991 .53239 .63479 .52664 Mtetra
.63479 .52664 .63991 .53239 .65027 .52928 .64518 .52351 Mtetra
.64518 .52351 .65027 .52928 .66067 .52616 .6556 .52037 Mtetra
.6556 .52037 .66067 .52616 .6711 .52303 .66607 .51722 Mtetra
.66607 .51722 .6711 .52303 .68158 .51989 .67657 .51405 Mtetra
.67657 .51405 .68158 .51989 .6921 .51673 .68711 .51087 Mtetra
.68711 .51087 .6921 .51673 .70265 .51356 .6977 .50768 Mtetra
.6977 .50768 .70265 .51356 .71324 .51038 .70832 .50448 Mtetra
.70832 .50448 .71324 .51038 .72388 .50719 .71898 .50127 Mtetra
.71898 .50127 .72388 .50719 .73455 .50399 .72968 .49804 Mtetra
.72968 .49804 .73455 .50399 .74527 .50077 .74042 .4948 Mtetra
.74042 .4948 .74527 .50077 .75602 .49754 .7512 .49155 Mtetra
.7512 .49155 .75602 .49754 .76681 .4943 .76203 .48829 Mtetra
.76203 .48829 .76681 .4943 .77765 .49105 .77289 .48501 Mtetra
.77289 .48501 .77765 .49105 .78852 .48779 .7838 .48173 Mtetra
.7838 .48173 .78852 .48779 .79944 .48451 .79474 .47843 Mtetra
.79474 .47843 .79944 .48451 .8104 .48122 .80573 .47511 Mtetra
.80573 .47511 .8104 .48122 .8214 .47792 .81676 .47179 Mtetra
.81676 .47179 .8214 .47792 .83244 .4746 .82783 .46845 Mtetra
.82783 .46845 .83244 .4746 .84353 .47128 .83895 .4651 Mtetra
.83895 .4651 .84353 .47128 .85465 .46794 .85011 .46174 Mtetra
.85011 .46174 .85465 .46794 .86582 .46458 .86131 .45836 Mtetra
.86131 .45836 .86582 .46458 .87704 .46122 .87255 .45497 Mtetra
.87255 .45497 .87704 .46122 .88829 .45784 .88384 .45157 Mtetra
.88384 .45157 .88829 .45784 .89959 .45445 .89517 .44815 Mtetra
.89517 .44815 .89959 .45445 .91093 .45104 .90654 .44472 Mtetra
.90654 .44472 .91093 .45104 .92232 .44763 .91796 .44128 Mtetra
.30643 .61871 .31232 .62385 .32155 .62107 .31568 .61591 Mtetra
.31568 .61591 .32155 .62107 .33081 .61828 .32495 .6131 Mtetra
.32495 .6131 .33081 .61828 .3401 .61548 .33427 .61028 Mtetra
.33427 .61028 .3401 .61548 .34942 .61267 .34361 .60746 Mtetra
.34361 .60746 .34942 .61267 .35878 .60985 .35299 .60462 Mtetra
.35299 .60462 .35878 .60985 .36817 .60702 .36239 .60177 Mtetra
.36239 .60177 .36817 .60702 .37759 .60418 .37184 .59891 Mtetra
.37184 .59891 .37759 .60418 .38704 .60133 .38131 .59604 Mtetra
.38131 .59604 .38704 .60133 .39653 .59847 .39082 .59316 Mtetra
.39082 .59316 .39653 .59847 .40606 .5956 .40037 .59027 Mtetra
.40037 .59027 .40606 .5956 .41561 .59272 .40995 .58737 Mtetra
.40995 .58737 .41561 .59272 .4252 .58983 .41956 .58446 Mtetra
.41956 .58446 .4252 .58983 .43483 .58692 .4292 .58154 Mtetra
.4292 .58154 .43483 .58692 .44449 .58401 .43888 .57861 Mtetra
.43888 .57861 .44449 .58401 .45418 .58109 .4486 .57567 Mtetra
.4486 .57567 .45418 .58109 .46391 .57816 .45835 .57272 Mtetra
.45835 .57272 .46391 .57816 .47367 .57521 .46814 .56975 Mtetra
.46814 .56975 .47367 .57521 .48347 .57226 .47796 .56678 Mtetra
.47796 .56678 .48347 .57226 .4933 .5693 .48781 .5638 Mtetra
.48781 .5638 .4933 .5693 .50317 .56632 .49771 .5608 Mtetra
.49771 .5608 .50317 .56632 .51308 .56334 .50763 .55779 Mtetra
.50763 .55779 .51308 .56334 .52302 .56034 .5176 .55478 Mtetra
.5176 .55478 .52302 .56034 .533 .55733 .5276 .55175 Mtetra
.5276 .55175 .533 .55733 .54301 .55431 .53764 .54871 Mtetra
.53764 .54871 .54301 .55431 .55306 .55128 .54771 .54566 Mtetra
.54771 .54566 .55306 .55128 .56314 .54824 .55782 .5426 Mtetra
.55782 .5426 .56314 .54824 .57327 .54519 .56797 .53953 Mtetra
.56797 .53953 .57327 .54519 .58343 .54213 .57815 .53644 Mtetra
.57815 .53644 .58343 .54213 .59363 .53905 .58837 .53335 Mtetra
.58837 .53335 .59363 .53905 .60386 .53597 .59864 .53024 Mtetra
.59864 .53024 .60386 .53597 .61413 .53287 .60893 .52712 Mtetra
.60893 .52712 .61413 .53287 .62444 .52976 .61927 .524 Mtetra
.61927 .524 .62444 .52976 .63479 .52664 .62964 .52085 Mtetra
.62964 .52085 .63479 .52664 .64518 .52351 .64006 .5177 Mtetra
.64006 .5177 .64518 .52351 .6556 .52037 .65051 .51454 Mtetra
.65051 .51454 .6556 .52037 .66607 .51722 .661 .51136 Mtetra
.661 .51136 .66607 .51722 .67657 .51405 .67153 .50817 Mtetra
.67153 .50817 .67657 .51405 .68711 .51087 .6821 .50497 Mtetra
.6821 .50497 .68711 .51087 .6977 .50768 .69271 .50176 Mtetra
.69271 .50176 .6977 .50768 .70832 .50448 .70336 .49854 Mtetra
.70336 .49854 .70832 .50448 .71898 .50127 .71405 .4953 Mtetra
.71405 .4953 .71898 .50127 .72968 .49804 .72477 .49205 Mtetra
.72477 .49205 .72968 .49804 .74042 .4948 .73554 .48879 Mtetra
.73554 .48879 .74042 .4948 .7512 .49155 .74636 .48552 Mtetra
.74636 .48552 .7512 .49155 .76203 .48829 .75721 .48223 Mtetra
.75721 .48223 .76203 .48829 .77289 .48501 .7681 .47893 Mtetra
.7681 .47893 .77289 .48501 .7838 .48173 .77903 .47562 Mtetra
.77903 .47562 .7838 .48173 .79474 .47843 .79001 .4723 Mtetra
.79001 .4723 .79474 .47843 .80573 .47511 .80103 .46897 Mtetra
.80103 .46897 .80573 .47511 .81676 .47179 .81209 .46562 Mtetra
.81209 .46562 .81676 .47179 .82783 .46845 .82319 .46226 Mtetra
.82319 .46226 .82783 .46845 .83895 .4651 .83434 .45888 Mtetra
.83434 .45888 .83895 .4651 .85011 .46174 .84552 .45549 Mtetra
.84552 .45549 .85011 .46174 .86131 .45836 .85676 .45209 Mtetra
.85676 .45209 .86131 .45836 .87255 .45497 .86803 .44868 Mtetra
.86803 .44868 .87255 .45497 .88384 .45157 .87935 .44525 Mtetra
.87935 .44525 .88384 .45157 .89517 .44815 .89071 .44181 Mtetra
.89071 .44181 .89517 .44815 .90654 .44472 .90212 .43836 Mtetra
.90212 .43836 .90654 .44472 .91796 .44128 .91357 .43489 Mtetra
.3005 .61354 .30643 .61871 .31568 .61591 .30977 .61072 Mtetra
.30977 .61072 .31568 .61591 .32495 .6131 .31906 .60789 Mtetra
.31906 .60789 .32495 .6131 .33427 .61028 .32839 .60505 Mtetra
.32839 .60505 .33427 .61028 .34361 .60746 .33776 .60221 Mtetra
.33776 .60221 .34361 .60746 .35299 .60462 .34715 .59935 Mtetra
.34715 .59935 .35299 .60462 .36239 .60177 .35658 .59648 Mtetra
.35658 .59648 .36239 .60177 .37184 .59891 .36605 .5936 Mtetra
.36605 .5936 .37184 .59891 .38131 .59604 .37555 .59072 Mtetra
.37555 .59072 .38131 .59604 .39082 .59316 .38508 .58782 Mtetra
.38508 .58782 .39082 .59316 .40037 .59027 .39464 .58491 Mtetra
.39464 .58491 .40037 .59027 .40995 .58737 .40424 .58199 Mtetra
.40424 .58199 .40995 .58737 .41956 .58446 .41387 .57906 Mtetra
.41387 .57906 .41956 .58446 .4292 .58154 .42354 .57612 Mtetra
.42354 .57612 .4292 .58154 .43888 .57861 .43324 .57317 Mtetra
.43324 .57317 .43888 .57861 .4486 .57567 .44298 .57021 Mtetra
.44298 .57021 .4486 .57567 .45835 .57272 .45276 .56724 Mtetra
.45276 .56724 .45835 .57272 .46814 .56975 .46256 .56426 Mtetra
.46256 .56426 .46814 .56975 .47796 .56678 .47241 .56126 Mtetra
.47241 .56126 .47796 .56678 .48781 .5638 .48229 .55826 Mtetra
.48229 .55826 .48781 .5638 .49771 .5608 .4922 .55524 Mtetra
.4922 .55524 .49771 .5608 .50763 .55779 .50215 .55222 Mtetra
.50215 .55222 .50763 .55779 .5176 .55478 .51214 .54918 Mtetra
.51214 .54918 .5176 .55478 .5276 .55175 .52217 .54613 Mtetra
.52217 .54613 .5276 .55175 .53764 .54871 .53223 .54307 Mtetra
.53223 .54307 .53764 .54871 .54771 .54566 .54232 .54 Mtetra
.54232 .54 .54771 .54566 .55782 .5426 .55246 .53692 Mtetra
.55246 .53692 .55782 .5426 .56797 .53953 .56263 .53383 Mtetra
.56263 .53383 .56797 .53953 .57815 .53644 .57284 .53072 Mtetra
.57284 .53072 .57815 .53644 .58837 .53335 .58309 .52761 Mtetra
.58309 .52761 .58837 .53335 .59864 .53024 .59337 .52448 Mtetra
.59337 .52448 .59864 .53024 .60893 .52712 .6037 .52134 Mtetra
.6037 .52134 .60893 .52712 .61927 .524 .61406 .51819 Mtetra
.61406 .51819 .61927 .524 .62964 .52085 .62446 .51503 Mtetra
.62446 .51503 .62964 .52085 .64006 .5177 .6349 .51185 Mtetra
.6349 .51185 .64006 .5177 .65051 .51454 .64538 .50866 Mtetra
.64538 .50866 .65051 .51454 .661 .51136 .65589 .50547 Mtetra
.65589 .50547 .661 .51136 .67153 .50817 .66645 .50226 Mtetra
.66645 .50226 .67153 .50817 .6821 .50497 .67705 .49903 Mtetra
.67705 .49903 .6821 .50497 .69271 .50176 .68768 .4958 Mtetra
.68768 .4958 .69271 .50176 .70336 .49854 .69836 .49255 Mtetra
.69836 .49255 .70336 .49854 .71405 .4953 .70908 .48929 Mtetra
.70908 .48929 .71405 .4953 .72477 .49205 .71984 .48602 Mtetra
.71984 .48602 .72477 .49205 .73554 .48879 .73063 .48274 Mtetra
.73063 .48274 .73554 .48879 .74636 .48552 .74147 .47944 Mtetra
.74147 .47944 .74636 .48552 .75721 .48223 .75235 .47613 Mtetra
.75235 .47613 .75721 .48223 .7681 .47893 .76328 .47281 Mtetra
.76328 .47281 .7681 .47893 .77903 .47562 .77424 .46948 Mtetra
.77424 .46948 .77903 .47562 .79001 .4723 .78524 .46613 Mtetra
.78524 .46613 .79001 .4723 .80103 .46897 .79629 .46277 Mtetra
.79629 .46277 .80103 .46897 .81209 .46562 .80738 .4594 Mtetra
.80738 .4594 .81209 .46562 .82319 .46226 .81852 .45602 Mtetra
.81852 .45602 .82319 .46226 .83434 .45888 .82969 .45262 Mtetra
.82969 .45262 .83434 .45888 .84552 .45549 .84091 .44921 Mtetra
.84091 .44921 .84552 .45549 .85676 .45209 .85217 .44578 Mtetra
.85217 .44578 .85676 .45209 .86803 .44868 .86348 .44234 Mtetra
.86348 .44234 .86803 .44868 .87935 .44525 .87483 .43889 Mtetra
.87483 .43889 .87935 .44525 .89071 .44181 .88623 .43543 Mtetra
.88623 .43543 .89071 .44181 .90212 .43836 .89766 .43195 Mtetra
.89766 .43195 .90212 .43836 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61072 .30382 .60549 Mtetra
.30382 .60549 .30977 .61072 .31906 .60789 .31314 .60265 Mtetra
.31314 .60265 .31906 .60789 .32839 .60505 .32249 .59979 Mtetra
.32249 .59979 .32839 .60505 .33776 .60221 .33187 .59692 Mtetra
.33187 .59692 .33776 .60221 .34715 .59935 .34129 .59405 Mtetra
.34129 .59405 .34715 .59935 .35658 .59648 .35074 .59116 Mtetra
.35074 .59116 .35658 .59648 .36605 .5936 .36022 .58826 Mtetra
.36022 .58826 .36605 .5936 .37555 .59072 .36974 .58536 Mtetra
.36974 .58536 .37555 .59072 .38508 .58782 .37929 .58244 Mtetra
.37929 .58244 .38508 .58782 .39464 .58491 .38888 .57951 Mtetra
.38888 .57951 .39464 .58491 .40424 .58199 .3985 .57657 Mtetra
.3985 .57657 .40424 .58199 .41387 .57906 .40815 .57363 Mtetra
.40815 .57363 .41387 .57906 .42354 .57612 .41784 .57067 Mtetra
.41784 .57067 .42354 .57612 .43324 .57317 .42757 .5677 Mtetra
.42757 .5677 .43324 .57317 .44298 .57021 .43733 .56471 Mtetra
.43733 .56471 .44298 .57021 .45276 .56724 .44712 .56172 Mtetra
.44712 .56172 .45276 .56724 .46256 .56426 .45695 .55872 Mtetra
.45695 .55872 .46256 .56426 .47241 .56126 .46682 .55571 Mtetra
.46682 .55571 .47241 .56126 .48229 .55826 .47672 .55268 Mtetra
.47672 .55268 .48229 .55826 .4922 .55524 .48666 .54965 Mtetra
.48666 .54965 .4922 .55524 .50215 .55222 .49664 .5466 Mtetra
.49664 .5466 .50215 .55222 .51214 .54918 .50665 .54354 Mtetra
.50665 .54354 .51214 .54918 .52217 .54613 .5167 .54047 Mtetra
.5167 .54047 .52217 .54613 .53223 .54307 .52678 .53739 Mtetra
.52678 .53739 .53223 .54307 .54232 .54 .5369 .5343 Mtetra
.5369 .5343 .54232 .54 .55246 .53692 .54706 .5312 Mtetra
.54706 .5312 .55246 .53692 .56263 .53383 .55726 .52809 Mtetra
.55726 .52809 .56263 .53383 .57284 .53072 .56749 .52496 Mtetra
.56749 .52496 .57284 .53072 .58309 .52761 .57777 .52182 Mtetra
.57777 .52182 .58309 .52761 .59337 .52448 .58808 .51867 Mtetra
.58808 .51867 .59337 .52448 .6037 .52134 .59843 .51551 Mtetra
.59843 .51551 .6037 .52134 .61406 .51819 .60881 .51234 Mtetra
.60881 .51234 .61406 .51819 .62446 .51503 .61924 .50916 Mtetra
.61924 .50916 .62446 .51503 .6349 .51185 .62971 .50596 Mtetra
.62971 .50596 .6349 .51185 .64538 .50866 .64021 .50275 Mtetra
.64021 .50275 .64538 .50866 .65589 .50547 .65075 .49953 Mtetra
.65075 .49953 .65589 .50547 .66645 .50226 .66134 .4963 Mtetra
.66134 .4963 .66645 .50226 .67705 .49903 .67196 .49305 Mtetra
.67196 .49305 .67705 .49903 .68768 .4958 .68263 .4898 Mtetra
.68263 .4898 .68768 .4958 .69836 .49255 .69333 .48653 Mtetra
.69333 .48653 .69836 .49255 .70908 .48929 .70408 .48325 Mtetra
.70408 .48325 .70908 .48929 .71984 .48602 .71486 .47995 Mtetra
.71486 .47995 .71984 .48602 .73063 .48274 .72569 .47664 Mtetra
.72569 .47664 .73063 .48274 .74147 .47944 .73656 .47333 Mtetra
.73656 .47333 .74147 .47944 .75235 .47613 .74746 .46999 Mtetra
.74746 .46999 .75235 .47613 .76328 .47281 .75842 .46665 Mtetra
.75842 .46665 .76328 .47281 .77424 .46948 .76941 .46329 Mtetra
.76941 .46329 .77424 .46948 .78524 .46613 .78044 .45992 Mtetra
.78044 .45992 .78524 .46613 .79629 .46277 .79152 .45654 Mtetra
.79152 .45654 .79629 .46277 .80738 .4594 .80264 .45314 Mtetra
.80264 .45314 .80738 .4594 .81852 .45602 .81381 .44973 Mtetra
.81381 .44973 .81852 .45602 .82969 .45262 .82501 .44631 Mtetra
.82501 .44631 .82969 .45262 .84091 .44921 .83626 .44287 Mtetra
.83626 .44287 .84091 .44921 .85217 .44578 .84756 .43942 Mtetra
.84756 .43942 .85217 .44578 .86348 .44234 .8589 .43596 Mtetra
.8589 .43596 .86348 .44234 .87483 .43889 .87028 .43248 Mtetra
.87028 .43248 .87483 .43889 .88623 .43543 .88171 .42899 Mtetra
.88171 .42899 .88623 .43543 .89766 .43195 .89318 .42549 Mtetra
.89318 .42549 .89766 .43195 .90915 .42846 .90469 .42197 Mtetra
.28853 .60308 .29453 .60833 .30382 .60549 .29783 .60023 Mtetra
.29783 .60023 .30382 .60549 .31314 .60265 .30717 .59737 Mtetra
.30717 .59737 .31314 .60265 .32249 .59979 .31654 .59449 Mtetra
.31654 .59449 .32249 .59979 .33187 .59692 .32594 .59161 Mtetra
.32594 .59161 .33187 .59692 .34129 .59405 .33538 .58871 Mtetra
.33538 .58871 .34129 .59405 .35074 .59116 .34485 .58581 Mtetra
.34485 .58581 .35074 .59116 .36022 .58826 .35435 .58289 Mtetra
.35435 .58289 .36022 .58826 .36974 .58536 .36389 .57996 Mtetra
.36389 .57996 .36974 .58536 .37929 .58244 .37347 .57703 Mtetra
.37347 .57703 .37929 .58244 .38888 .57951 .38307 .57408 Mtetra
.38307 .57408 .38888 .57951 .3985 .57657 .39272 .57112 Mtetra
.39272 .57112 .3985 .57657 .40815 .57363 .40239 .56815 Mtetra
.40239 .56815 .40815 .57363 .41784 .57067 .41211 .56517 Mtetra
.41211 .56517 .41784 .57067 .42757 .5677 .42185 .56218 Mtetra
.42185 .56218 .42757 .5677 .43733 .56471 .43163 .55918 Mtetra
.43163 .55918 .43733 .56471 .44712 .56172 .44145 .55617 Mtetra
.44145 .55617 .44712 .56172 .45695 .55872 .45131 .55315 Mtetra
.45131 .55315 .45695 .55872 .46682 .55571 .4612 .55012 Mtetra
.4612 .55012 .46682 .55571 .47672 .55268 .47112 .54707 Mtetra
.47112 .54707 .47672 .55268 .48666 .54965 .48108 .54401 Mtetra
.48108 .54401 .48666 .54965 .49664 .5466 .49108 .54095 Mtetra
.49108 .54095 .49664 .5466 .50665 .54354 .50112 .53787 Mtetra
.50112 .53787 .50665 .54354 .5167 .54047 .51119 .53478 Mtetra
.51119 .53478 .5167 .54047 .52678 .53739 .5213 .53168 Mtetra
.5213 .53168 .52678 .53739 .5369 .5343 .53144 .52857 Mtetra
.53144 .52857 .5369 .5343 .54706 .5312 .54163 .52544 Mtetra
.54163 .52544 .54706 .5312 .55726 .52809 .55185 .52231 Mtetra
.55185 .52231 .55726 .52809 .56749 .52496 .56211 .51916 Mtetra
.56211 .51916 .56749 .52496 .57777 .52182 .57241 .516 Mtetra
.57241 .516 .57777 .52182 .58808 .51867 .58274 .51283 Mtetra
.58274 .51283 .58808 .51867 .59843 .51551 .59312 .50965 Mtetra
.59312 .50965 .59843 .51551 .60881 .51234 .60353 .50645 Mtetra
.60353 .50645 .60881 .51234 .61924 .50916 .61398 .50324 Mtetra
.61398 .50324 .61924 .50916 .62971 .50596 .62448 .50003 Mtetra
.62448 .50003 .62971 .50596 .64021 .50275 .63501 .4968 Mtetra
.63501 .4968 .64021 .50275 .65075 .49953 .64558 .49355 Mtetra
.64558 .49355 .65075 .49953 .66134 .4963 .65619 .4903 Mtetra
.65619 .4903 .66134 .4963 .67196 .49305 .66684 .48703 Mtetra
.66684 .48703 .67196 .49305 .68263 .4898 .67753 .48375 Mtetra
.67753 .48375 .68263 .4898 .69333 .48653 .68826 .48046 Mtetra
.68826 .48046 .69333 .48653 .70408 .48325 .69904 .47715 Mtetra
.69904 .47715 .70408 .48325 .71486 .47995 .70985 .47384 Mtetra
.70985 .47384 .71486 .47995 .72569 .47664 .72071 .47051 Mtetra
.72071 .47051 .72569 .47664 .73656 .47333 .7316 .46716 Mtetra
.7316 .46716 .73656 .47333 .74746 .46999 .74254 .46381 Mtetra
.74254 .46381 .74746 .46999 .75842 .46665 .75352 .46044 Mtetra
.75352 .46044 .75842 .46665 .76941 .46329 .76455 .45706 Mtetra
.76455 .45706 .76941 .46329 .78044 .45992 .77561 .45366 Mtetra
.77561 .45366 .78044 .45992 .79152 .45654 .78672 .45026 Mtetra
.78672 .45026 .79152 .45654 .80264 .45314 .79787 .44684 Mtetra
.79787 .44684 .80264 .45314 .81381 .44973 .80906 .4434 Mtetra
.80906 .4434 .81381 .44973 .82501 .44631 .8203 .43995 Mtetra
.8203 .43995 .82501 .44631 .83626 .44287 .83158 .43649 Mtetra
.83158 .43649 .83626 .44287 .84756 .43942 .84291 .43302 Mtetra
.84291 .43302 .84756 .43942 .8589 .43596 .85428 .42953 Mtetra
.85428 .42953 .8589 .43596 .87028 .43248 .86569 .42603 Mtetra
.86569 .42603 .87028 .43248 .88171 .42899 .87715 .42252 Mtetra
.87715 .42252 .88171 .42899 .89318 .42549 .88866 .41899 Mtetra
.88866 .41899 .89318 .42549 .90469 .42197 .90021 .41544 Mtetra
.28248 .59781 .28853 .60308 .29783 .60023 .2918 .59493 Mtetra
.2918 .59493 .29783 .60023 .30717 .59737 .30116 .59205 Mtetra
.30116 .59205 .30717 .59737 .31654 .59449 .31055 .58916 Mtetra
.31055 .58916 .31654 .59449 .32594 .59161 .31997 .58625 Mtetra
.31997 .58625 .32594 .59161 .33538 .58871 .32943 .58334 Mtetra
.32943 .58334 .33538 .58871 .34485 .58581 .33892 .58042 Mtetra
.33892 .58042 .34485 .58581 .35435 .58289 .34845 .57748 Mtetra
.34845 .57748 .35435 .58289 .36389 .57996 .35801 .57453 Mtetra
.35801 .57453 .36389 .57996 .37347 .57703 .3676 .57158 Mtetra
.3676 .57158 .37347 .57703 .38307 .57408 .37723 .56861 Mtetra
.37723 .56861 .38307 .57408 .39272 .57112 .3869 .56563 Mtetra
.3869 .56563 .39272 .57112 .40239 .56815 .3966 .56264 Mtetra
.3966 .56264 .40239 .56815 .41211 .56517 .40633 .55965 Mtetra
.40633 .55965 .41211 .56517 .42185 .56218 .4161 .55664 Mtetra
.4161 .55664 .42185 .56218 .43163 .55918 .4259 .55361 Mtetra
.4259 .55361 .43163 .55918 .44145 .55617 .43574 .55058 Mtetra
.43574 .55058 .44145 .55617 .45131 .55315 .44562 .54754 Mtetra
.44562 .54754 .45131 .55315 .4612 .55012 .45553 .54449 Mtetra
.45553 .54449 .4612 .55012 .47112 .54707 .46548 .54142 Mtetra
.46548 .54142 .47112 .54707 .48108 .54401 .47547 .53834 Mtetra
.47547 .53834 .48108 .54401 .49108 .54095 .48549 .53526 Mtetra
.48549 .53526 .49108 .54095 .50112 .53787 .49555 .53216 Mtetra
.49555 .53216 .50112 .53787 .51119 .53478 .50564 .52905 Mtetra
.50564 .52905 .51119 .53478 .5213 .53168 .51578 .52592 Mtetra
.51578 .52592 .5213 .53168 .53144 .52857 .52595 .52279 Mtetra
.52595 .52279 .53144 .52857 .54163 .52544 .53616 .51964 Mtetra
.53616 .51964 .54163 .52544 .55185 .52231 .5464 .51649 Mtetra
.5464 .51649 .55185 .52231 .56211 .51916 .55669 .51332 Mtetra
.55669 .51332 .56211 .51916 .57241 .516 .56701 .51014 Mtetra
.56701 .51014 .57241 .516 .58274 .51283 .57737 .50694 Mtetra
.57737 .50694 .58274 .51283 .59312 .50965 .58777 .50374 Mtetra
.58777 .50374 .59312 .50965 .60353 .50645 .59821 .50052 Mtetra
.59821 .50052 .60353 .50645 .61398 .50324 .60869 .49729 Mtetra
.60869 .49729 .61398 .50324 .62448 .50003 .61921 .49405 Mtetra
.61921 .49405 .62448 .50003 .63501 .4968 .62977 .4908 Mtetra
.62977 .4908 .63501 .4968 .64558 .49355 .64037 .48753 Mtetra
.64037 .48753 .64558 .49355 .65619 .4903 .65101 .48426 Mtetra
.65101 .48426 .65619 .4903 .66684 .48703 .66168 .48097 Mtetra
.66168 .48097 .66684 .48703 .67753 .48375 .6724 .47766 Mtetra
.6724 .47766 .67753 .48375 .68826 .48046 .68316 .47435 Mtetra
.68316 .47435 .68826 .48046 .69904 .47715 .69396 .47102 Mtetra
.69396 .47102 .69904 .47715 .70985 .47384 .70481 .46768 Mtetra
.70481 .46768 .70985 .47384 .72071 .47051 .71569 .46433 Mtetra
.71569 .46433 .72071 .47051 .7316 .46716 .72662 .46096 Mtetra
.72662 .46096 .7316 .46716 .74254 .46381 .73758 .45758 Mtetra
.73758 .45758 .74254 .46381 .75352 .46044 .74859 .45419 Mtetra
.74859 .45419 .75352 .46044 .76455 .45706 .75965 .45078 Mtetra
.75965 .45078 .76455 .45706 .77561 .45366 .77074 .44736 Mtetra
.77074 .44736 .77561 .45366 .78672 .45026 .78188 .44393 Mtetra
.78188 .44393 .78672 .45026 .79787 .44684 .79306 .44049 Mtetra
.79306 .44049 .79787 .44684 .80906 .4434 .80429 .43703 Mtetra
.80429 .43703 .80906 .4434 .8203 .43995 .81556 .43356 Mtetra
.81556 .43356 .8203 .43995 .83158 .43649 .82687 .43007 Mtetra
.82687 .43007 .83158 .43649 .84291 .43302 .83823 .42657 Mtetra
.83823 .42657 .84291 .43302 .85428 .42953 .84963 .42306 Mtetra
.84963 .42306 .85428 .42953 .86569 .42603 .86108 .41953 Mtetra
.86108 .41953 .86569 .42603 .87715 .42252 .87257 .41599 Mtetra
.87257 .41599 .87715 .42252 .88866 .41899 .8841 .41243 Mtetra
.8841 .41243 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.27639 .59249 .28248 .59781 .2918 .59493 .28574 .5896 Mtetra
.28574 .5896 .2918 .59493 .30116 .59205 .29511 .5867 Mtetra
.29511 .5867 .30116 .59205 .31055 .58916 .30452 .58379 Mtetra
.30452 .58379 .31055 .58916 .31997 .58625 .31397 .58087 Mtetra
.31397 .58087 .31997 .58625 .32943 .58334 .32345 .57793 Mtetra
.32345 .57793 .32943 .58334 .33892 .58042 .33296 .57499 Mtetra
.33296 .57499 .33892 .58042 .34845 .57748 .34251 .57203 Mtetra
.34251 .57203 .34845 .57748 .35801 .57453 .35209 .56907 Mtetra
.35209 .56907 .35801 .57453 .3676 .57158 .3617 .56609 Mtetra
.3617 .56609 .3676 .57158 .37723 .56861 .37135 .56311 Mtetra
.37135 .56311 .37723 .56861 .3869 .56563 .38104 .56011 Mtetra
.38104 .56011 .3869 .56563 .3966 .56264 .39076 .5571 Mtetra
.39076 .5571 .3966 .56264 .40633 .55965 .40052 .55408 Mtetra
.40052 .55408 .40633 .55965 .4161 .55664 .41031 .55105 Mtetra
.41031 .55105 .4161 .55664 .4259 .55361 .42013 .54801 Mtetra
.42013 .54801 .4259 .55361 .43574 .55058 .43 .54496 Mtetra
.43 .54496 .43574 .55058 .44562 .54754 .4399 .54189 Mtetra
.4399 .54189 .44562 .54754 .45553 .54449 .44983 .53882 Mtetra
.44983 .53882 .45553 .54449 .46548 .54142 .4598 .53573 Mtetra
.4598 .53573 .46548 .54142 .47547 .53834 .46981 .53263 Mtetra
.46981 .53263 .47547 .53834 .48549 .53526 .47986 .52952 Mtetra
.47986 .52952 .48549 .53526 .49555 .53216 .48994 .5264 Mtetra
.48994 .5264 .49555 .53216 .50564 .52905 .50006 .52327 Mtetra
.50006 .52327 .50564 .52905 .51578 .52592 .51022 .52013 Mtetra
.51022 .52013 .51578 .52592 .52595 .52279 .52041 .51697 Mtetra
.52041 .51697 .52595 .52279 .53616 .51964 .53065 .51381 Mtetra
.53065 .51381 .53616 .51964 .5464 .51649 .54092 .51063 Mtetra
.54092 .51063 .5464 .51649 .55669 .51332 .55123 .50744 Mtetra
.55123 .50744 .55669 .51332 .56701 .51014 .56158 .50423 Mtetra
.56158 .50423 .56701 .51014 .57737 .50694 .57197 .50102 Mtetra
.57197 .50102 .57737 .50694 .58777 .50374 .58239 .49779 Mtetra
.58239 .49779 .58777 .50374 .59821 .50052 .59286 .49455 Mtetra
.59286 .49455 .59821 .50052 .60869 .49729 .60336 .4913 Mtetra
.60336 .4913 .60869 .49729 .61921 .49405 .61391 .48804 Mtetra
.61391 .48804 .61921 .49405 .62977 .4908 .62449 .48476 Mtetra
.62449 .48476 .62977 .4908 .64037 .48753 .63512 .48147 Mtetra
.63512 .48147 .64037 .48753 .65101 .48426 .64578 .47817 Mtetra
.64578 .47817 .65101 .48426 .66168 .48097 .65649 .47486 Mtetra
.65649 .47486 .66168 .48097 .6724 .47766 .66724 .47153 Mtetra
.66724 .47153 .6724 .47766 .68316 .47435 .67803 .46819 Mtetra
.67803 .46819 .68316 .47435 .69396 .47102 .68886 .46484 Mtetra
.68886 .46484 .69396 .47102 .70481 .46768 .69973 .46148 Mtetra
.69973 .46148 .70481 .46768 .71569 .46433 .71064 .4581 Mtetra
.71064 .4581 .71569 .46433 .72662 .46096 .72159 .45471 Mtetra
.72159 .45471 .72662 .46096 .73758 .45758 .73259 .45131 Mtetra
.73259 .45131 .73758 .45758 .74859 .45419 .74363 .44789 Mtetra
.74363 .44789 .74859 .45419 .75965 .45078 .75471 .44446 Mtetra
.75471 .44446 .75965 .45078 .77074 .44736 .76584 .44102 Mtetra
.76584 .44102 .77074 .44736 .78188 .44393 .77701 .43756 Mtetra
.77701 .43756 .78188 .44393 .79306 .44049 .78822 .43409 Mtetra
.78822 .43409 .79306 .44049 .80429 .43703 .79948 .43061 Mtetra
.79948 .43061 .80429 .43703 .81556 .43356 .81078 .42711 Mtetra
.81078 .42711 .81556 .43356 .82687 .43007 .82212 .4236 Mtetra
.82212 .4236 .82687 .43007 .83823 .42657 .83351 .42008 Mtetra
.83351 .42008 .83823 .42657 .84963 .42306 .84495 .41654 Mtetra
.84495 .41654 .84963 .42306 .86108 .41953 .85642 .41299 Mtetra
.85642 .41299 .86108 .41953 .87257 .41599 .86795 .40942 Mtetra
.86795 .40942 .87257 .41599 .8841 .41243 .87952 .40584 Mtetra
.87952 .40584 .8841 .41243 .89569 .40886 .89113 .40224 Mtetra
.27027 .58715 .27639 .59249 .28574 .5896 .27963 .58424 Mtetra
.27963 .58424 .28574 .5896 .29511 .5867 .28903 .58132 Mtetra
.656 .752 .92 r
.28903 .58132 .29511 .5867 .30452 .58379 .29846 .57839 Mtetra
.29846 .57839 .30452 .58379 .31397 .58087 .30792 .57545 Mtetra
.30792 .57545 .31397 .58087 .32345 .57793 .31742 .5725 Mtetra
.31742 .5725 .32345 .57793 .33296 .57499 .32695 .56953 Mtetra
.32695 .56953 .33296 .57499 .34251 .57203 .33652 .56656 Mtetra
.33652 .56656 .34251 .57203 .35209 .56907 .34612 .56357 Mtetra
.34612 .56357 .35209 .56907 .3617 .56609 .35576 .56057 Mtetra
.656 .751 .92 r
.35576 .56057 .3617 .56609 .37135 .56311 .36543 .55756 Mtetra
.36543 .55756 .37135 .56311 .38104 .56011 .37514 .55455 Mtetra
.37514 .55455 .38104 .56011 .39076 .5571 .38488 .55152 Mtetra
.38488 .55152 .39076 .5571 .40052 .55408 .39466 .54848 Mtetra
.39466 .54848 .40052 .55408 .41031 .55105 .40448 .54543 Mtetra
.40448 .54543 .41031 .55105 .42013 .54801 .41432 .54236 Mtetra
.41432 .54236 .42013 .54801 .43 .54496 .42421 .53929 Mtetra
.42421 .53929 .43 .54496 .4399 .54189 .43413 .53621 Mtetra
.43413 .53621 .4399 .54189 .44983 .53882 .44409 .53311 Mtetra
.44409 .53311 .44983 .53882 .4598 .53573 .45409 .53 Mtetra
.45409 .53 .4598 .53573 .46981 .53263 .46412 .52688 Mtetra
.46412 .52688 .46981 .53263 .47986 .52952 .47419 .52375 Mtetra
.47419 .52375 .47986 .52952 .48994 .5264 .4843 .52061 Mtetra
.4843 .52061 .48994 .5264 .50006 .52327 .49444 .51746 Mtetra
.49444 .51746 .50006 .52327 .51022 .52013 .50462 .51429 Mtetra
.50462 .51429 .51022 .52013 .52041 .51697 .51484 .51112 Mtetra
.51484 .51112 .52041 .51697 .53065 .51381 .5251 .50793 Mtetra
.5251 .50793 .53065 .51381 .54092 .51063 .5354 .50473 Mtetra
.5354 .50473 .54092 .51063 .55123 .50744 .54573 .50151 Mtetra
.54573 .50151 .55123 .50744 .56158 .50423 .55611 .49829 Mtetra
.55611 .49829 .56158 .50423 .57197 .50102 .56652 .49505 Mtetra
.56652 .49505 .57197 .50102 .58239 .49779 .57697 .4918 Mtetra
.57697 .4918 .58239 .49779 .59286 .49455 .58747 .48854 Mtetra
.58747 .48854 .59286 .49455 .60336 .4913 .598 .48527 Mtetra
.598 .48527 .60336 .4913 .61391 .48804 .60857 .48198 Mtetra
.60857 .48198 .61391 .48804 .62449 .48476 .61918 .47868 Mtetra
.61918 .47868 .62449 .48476 .63512 .48147 .62983 .47537 Mtetra
.62983 .47537 .63512 .48147 .64578 .47817 .64053 .47205 Mtetra
.64053 .47205 .64578 .47817 .65649 .47486 .65126 .46871 Mtetra
.65126 .46871 .65649 .47486 .66724 .47153 .66204 .46536 Mtetra
.66204 .46536 .66724 .47153 .67803 .46819 .67285 .462 Mtetra
.67285 .462 .67803 .46819 .68886 .46484 .68371 .45862 Mtetra
.68371 .45862 .68886 .46484 .69973 .46148 .69461 .45523 Mtetra
.69461 .45523 .69973 .46148 .71064 .4581 .70555 .45183 Mtetra
.70555 .45183 .71064 .4581 .72159 .45471 .71654 .44842 Mtetra
.71654 .44842 .72159 .45471 .73259 .45131 .72756 .44499 Mtetra
.72756 .44499 .73259 .45131 .74363 .44789 .73863 .44155 Mtetra
.73863 .44155 .74363 .44789 .75471 .44446 .74974 .43809 Mtetra
.74974 .43809 .75471 .44446 .76584 .44102 .7609 .43463 Mtetra
.7609 .43463 .76584 .44102 .77701 .43756 .7721 .43114 Mtetra
.7721 .43114 .77701 .43756 .78822 .43409 .78334 .42765 Mtetra
.78334 .42765 .78822 .43409 .79948 .43061 .79463 .42414 Mtetra
.79463 .42414 .79948 .43061 .81078 .42711 .80596 .42062 Mtetra
.656 .752 .92 r
.80596 .42062 .81078 .42711 .82212 .4236 .81734 .41709 Mtetra
.81734 .41709 .82212 .4236 .83351 .42008 .82876 .41354 Mtetra
.82876 .41354 .83351 .42008 .84495 .41654 .84023 .40997 Mtetra
.84023 .40997 .84495 .41654 .85642 .41299 .85174 .4064 Mtetra
.85174 .4064 .85642 .41299 .86795 .40942 .8633 .4028 Mtetra
.8633 .4028 .86795 .40942 .87952 .40584 .8749 .39919 Mtetra
.8749 .39919 .87952 .40584 .89113 .40224 .88655 .39556 Mtetra
.655 .751 .92 r
.2641 .58177 .27027 .58715 .27963 .58424 .27348 .57885 Mtetra
.655 .752 .921 r
.27348 .57885 .27963 .58424 .28903 .58132 .2829 .57591 Mtetra
.656 .752 .921 r
.2829 .57591 .28903 .58132 .29846 .57839 .29235 .57297 Mtetra
.29235 .57297 .29846 .57839 .30792 .57545 .30184 .57001 Mtetra
.30184 .57001 .30792 .57545 .31742 .5725 .31136 .56703 Mtetra
.31136 .56703 .31742 .5725 .32695 .56953 .32091 .56404 Mtetra
.32091 .56404 .32695 .56953 .33652 .56656 .3305 .56105 Mtetra
.656 .752 .92 r
.3305 .56105 .33652 .56656 .34612 .56357 .34012 .55804 Mtetra
.34012 .55804 .34612 .56357 .35576 .56057 .34978 .55502 Mtetra
.34978 .55502 .35576 .56057 .36543 .55756 .35947 .55199 Mtetra
.35947 .55199 .36543 .55756 .37514 .55455 .3692 .54895 Mtetra
.656 .751 .92 r
.3692 .54895 .37514 .55455 .38488 .55152 .37897 .5459 Mtetra
.37897 .5459 .38488 .55152 .39466 .54848 .38877 .54284 Mtetra
.38877 .54284 .39466 .54848 .40448 .54543 .3986 .53976 Mtetra
.3986 .53976 .40448 .54543 .41432 .54236 .40848 .53668 Mtetra
.40848 .53668 .41432 .54236 .42421 .53929 .41839 .53359 Mtetra
.41839 .53359 .42421 .53929 .43413 .53621 .42833 .53048 Mtetra
.42833 .53048 .43413 .53621 .44409 .53311 .43831 .52737 Mtetra
.43831 .52737 .44409 .53311 .45409 .53 .44833 .52424 Mtetra
.44833 .52424 .45409 .53 .46412 .52688 .45839 .5211 Mtetra
.45839 .5211 .46412 .52688 .47419 .52375 .46848 .51794 Mtetra
.46848 .51794 .47419 .52375 .4843 .52061 .47861 .51478 Mtetra
.47861 .51478 .4843 .52061 .49444 .51746 .48878 .51161 Mtetra
.48878 .51161 .49444 .51746 .50462 .51429 .49899 .50842 Mtetra
.49899 .50842 .50462 .51429 .51484 .51112 .50923 .50522 Mtetra
.50923 .50522 .51484 .51112 .5251 .50793 .51952 .50201 Mtetra
.51952 .50201 .5251 .50793 .5354 .50473 .52984 .49879 Mtetra
.52984 .49879 .5354 .50473 .54573 .50151 .5402 .49555 Mtetra
.5402 .49555 .54573 .50151 .55611 .49829 .5506 .4923 Mtetra
.5506 .4923 .55611 .49829 .56652 .49505 .56104 .48904 Mtetra
.56104 .48904 .56652 .49505 .57697 .4918 .57152 .48577 Mtetra
.57152 .48577 .57697 .4918 .58747 .48854 .58203 .48249 Mtetra
.58203 .48249 .58747 .48854 .598 .48527 .59259 .47919 Mtetra
.59259 .47919 .598 .48527 .60857 .48198 .60319 .47588 Mtetra
.60319 .47588 .60857 .48198 .61918 .47868 .61383 .47256 Mtetra
.61383 .47256 .61918 .47868 .62983 .47537 .62451 .46922 Mtetra
.62451 .46922 .62983 .47537 .64053 .47205 .63523 .46587 Mtetra
.63523 .46587 .64053 .47205 .65126 .46871 .64599 .46251 Mtetra
.64599 .46251 .65126 .46871 .66204 .46536 .6568 .45914 Mtetra
.6568 .45914 .66204 .46536 .67285 .462 .66764 .45575 Mtetra
.66764 .45575 .67285 .462 .68371 .45862 .67853 .45235 Mtetra
.67853 .45235 .68371 .45862 .69461 .45523 .68946 .44894 Mtetra
.68946 .44894 .69461 .45523 .70555 .45183 .70043 .44552 Mtetra
.70043 .44552 .70555 .45183 .71654 .44842 .71144 .44208 Mtetra
.71144 .44208 .71654 .44842 .72756 .44499 .7225 .43863 Mtetra
.7225 .43863 .72756 .44499 .73863 .44155 .7336 .43516 Mtetra
.7336 .43516 .73863 .44155 .74974 .43809 .74474 .43168 Mtetra
.74474 .43168 .74974 .43809 .7609 .43463 .75593 .42819 Mtetra
.75593 .42819 .7609 .43463 .7721 .43114 .76716 .42468 Mtetra
.76716 .42468 .7721 .43114 .78334 .42765 .77843 .42117 Mtetra
.656 .752 .92 r
.77843 .42117 .78334 .42765 .79463 .42414 .78975 .41764 Mtetra
.656 .752 .921 r
.78975 .41764 .79463 .42414 .80596 .42062 .80111 .41409 Mtetra
.80111 .41409 .80596 .42062 .81734 .41709 .81252 .41053 Mtetra
.81252 .41053 .81734 .41709 .82876 .41354 .82398 .40696 Mtetra
.82398 .40696 .82876 .41354 .84023 .40997 .83548 .40337 Mtetra
.83548 .40337 .84023 .40997 .85174 .4064 .84702 .39977 Mtetra
.84702 .39977 .85174 .4064 .8633 .4028 .85861 .39614 Mtetra
.656 .752 .92 r
.85861 .39614 .8633 .4028 .8749 .39919 .87025 .3925 Mtetra
.87025 .3925 .8749 .39919 .88655 .39556 .88193 .38884 Mtetra
.655 .751 .921 r
.25789 .57635 .2641 .58177 .27348 .57885 .26729 .57342 Mtetra
.655 .752 .921 r
.26729 .57342 .27348 .57885 .2829 .57591 .27673 .57048 Mtetra
.27673 .57048 .2829 .57591 .29235 .57297 .2862 .56752 Mtetra
.2862 .56752 .29235 .57297 .30184 .57001 .29571 .56454 Mtetra
.656 .753 .921 r
.29571 .56454 .30184 .57001 .31136 .56703 .30525 .56155 Mtetra
.30525 .56155 .31136 .56703 .32091 .56404 .31482 .55854 Mtetra
.31482 .55854 .32091 .56404 .3305 .56105 .32443 .55552 Mtetra
.656 .752 .921 r
.32443 .55552 .3305 .56105 .34012 .55804 .33408 .55248 Mtetra
.33408 .55248 .34012 .55804 .34978 .55502 .34376 .54944 Mtetra
.34376 .54944 .34978 .55502 .35947 .55199 .35347 .54638 Mtetra
.656 .752 .92 r
.35347 .54638 .35947 .55199 .3692 .54895 .36323 .54332 Mtetra
.36323 .54332 .3692 .54895 .37897 .5459 .37301 .54024 Mtetra
.37301 .54024 .37897 .5459 .38877 .54284 .38283 .53716 Mtetra
.38283 .53716 .38877 .54284 .3986 .53976 .39269 .53407 Mtetra
.656 .751 .92 r
.39269 .53407 .3986 .53976 .40848 .53668 .40259 .53096 Mtetra
.40259 .53096 .40848 .53668 .41839 .53359 .41252 .52785 Mtetra
.41252 .52785 .41839 .53359 .42833 .53048 .42249 .52472 Mtetra
.42249 .52472 .42833 .53048 .43831 .52737 .43249 .52158 Mtetra
.43249 .52158 .43831 .52737 .44833 .52424 .44254 .51843 Mtetra
.44254 .51843 .44833 .52424 .45839 .5211 .45262 .51527 Mtetra
.45262 .51527 .45839 .5211 .46848 .51794 .46273 .5121 Mtetra
.46273 .5121 .46848 .51794 .47861 .51478 .47289 .50891 Mtetra
.47289 .50891 .47861 .51478 .48878 .51161 .48308 .50571 Mtetra
.48308 .50571 .48878 .51161 .49899 .50842 .49331 .5025 Mtetra
.49331 .5025 .49899 .50842 .50923 .50522 .50358 .49928 Mtetra
.50358 .49928 .50923 .50522 .51952 .50201 .51389 .49605 Mtetra
.51389 .49605 .51952 .50201 .52984 .49879 .52424 .4928 Mtetra
.52424 .4928 .52984 .49879 .5402 .49555 .53463 .48955 Mtetra
.53463 .48955 .5402 .49555 .5506 .4923 .54505 .48627 Mtetra
.54505 .48627 .5506 .4923 .56104 .48904 .55552 .48299 Mtetra
.55552 .48299 .56104 .48904 .57152 .48577 .56602 .4797 Mtetra
.56602 .4797 .57152 .48577 .58203 .48249 .57657 .47639 Mtetra
.57657 .47639 .58203 .48249 .59259 .47919 .58715 .47307 Mtetra
.58715 .47307 .59259 .47919 .60319 .47588 .59778 .46974 Mtetra
.59778 .46974 .60319 .47588 .61383 .47256 .60844 .46639 Mtetra
.60844 .46639 .61383 .47256 .62451 .46922 .61915 .46303 Mtetra
.61915 .46303 .62451 .46922 .63523 .46587 .6299 .45966 Mtetra
.6299 .45966 .63523 .46587 .64599 .46251 .64069 .45628 Mtetra
.64069 .45628 .64599 .46251 .6568 .45914 .65152 .45288 Mtetra
.65152 .45288 .6568 .45914 .66764 .45575 .66239 .44947 Mtetra
.66239 .44947 .66764 .45575 .67853 .45235 .67331 .44604 Mtetra
.67331 .44604 .67853 .45235 .68946 .44894 .68427 .44261 Mtetra
.68427 .44261 .68946 .44894 .70043 .44552 .69527 .43916 Mtetra
.69527 .43916 .70043 .44552 .71144 .44208 .70631 .43569 Mtetra
.70631 .43569 .71144 .44208 .7225 .43863 .7174 .43222 Mtetra
.7174 .43222 .7225 .43863 .7336 .43516 .72853 .42873 Mtetra
.72853 .42873 .7336 .43516 .74474 .43168 .7397 .42523 Mtetra
.656 .752 .92 r
.7397 .42523 .74474 .43168 .75593 .42819 .75092 .42171 Mtetra
.656 .752 .921 r
.75092 .42171 .75593 .42819 .76716 .42468 .76218 .41819 Mtetra
.655 .752 .921 r
.76218 .41819 .76716 .42468 .77843 .42117 .77348 .41465 Mtetra
.77348 .41465 .77843 .42117 .78975 .41764 .78484 .4111 Mtetra
.78484 .4111 .78975 .41764 .80111 .41409 .79623 .40753 Mtetra
.79623 .40753 .80111 .41409 .81252 .41053 .80767 .40395 Mtetra
.80767 .40395 .81252 .41053 .82398 .40696 .81916 .40036 Mtetra
.656 .753 .921 r
.81916 .40036 .82398 .40696 .83548 .40337 .83069 .39674 Mtetra
.83069 .39674 .83548 .40337 .84702 .39977 .84227 .3931 Mtetra
.84227 .3931 .84702 .39977 .85861 .39614 .85389 .38945 Mtetra
.656 .752 .921 r
.85389 .38945 .85861 .39614 .87025 .3925 .86556 .38577 Mtetra
.657 .752 .92 r
.86556 .38577 .87025 .3925 .88193 .38884 .87727 .38207 Mtetra
.654 .751 .921 r
.25164 .57089 .25789 .57635 .26729 .57342 .26106 .56797 Mtetra
.654 .752 .922 r
.26106 .56797 .26729 .57342 .27673 .57048 .27052 .56503 Mtetra
.654 .753 .922 r
.27052 .56503 .27673 .57048 .2862 .56752 .28001 .56207 Mtetra
.655 .754 .922 r
.28001 .56207 .2862 .56752 .29571 .56454 .28953 .55909 Mtetra
.656 .754 .922 r
.28953 .55909 .29571 .56454 .30525 .56155 .29909 .55607 Mtetra
.29909 .55607 .30525 .56155 .31482 .55854 .30869 .55304 Mtetra
.30869 .55304 .31482 .55854 .32443 .55552 .31832 .54999 Mtetra
.657 .754 .922 r
.31832 .54999 .32443 .55552 .33408 .55248 .32799 .54692 Mtetra
.657 .753 .921 r
.32799 .54692 .33408 .55248 .34376 .54944 .33769 .54384 Mtetra
.656 .753 .921 r
.33769 .54384 .34376 .54944 .35347 .54638 .34743 .54076 Mtetra
.34743 .54076 .35347 .54638 .36323 .54332 .35721 .53766 Mtetra
.656 .752 .921 r
.35721 .53766 .36323 .54332 .37301 .54024 .36702 .53456 Mtetra
.656 .752 .92 r
.36702 .53456 .37301 .54024 .38283 .53716 .37686 .53145 Mtetra
.37686 .53145 .38283 .53716 .39269 .53407 .38674 .52833 Mtetra
.38674 .52833 .39269 .53407 .40259 .53096 .39666 .5252 Mtetra
.656 .751 .92 r
.39666 .5252 .40259 .53096 .41252 .52785 .40662 .52207 Mtetra
.40662 .52207 .41252 .52785 .42249 .52472 .41661 .51892 Mtetra
.41661 .51892 .42249 .52472 .43249 .52158 .42664 .51576 Mtetra
.42664 .51576 .43249 .52158 .44254 .51843 .4367 .51258 Mtetra
.4367 .51258 .44254 .51843 .45262 .51527 .44681 .5094 Mtetra
.44681 .5094 .45262 .51527 .46273 .5121 .45695 .5062 Mtetra
.45695 .5062 .46273 .5121 .47289 .50891 .46713 .503 Mtetra
.46713 .503 .47289 .50891 .48308 .50571 .47734 .49978 Mtetra
.47734 .49978 .48308 .50571 .49331 .5025 .4876 .49655 Mtetra
.4876 .49655 .49331 .5025 .50358 .49928 .49789 .4933 Mtetra
.49789 .4933 .50358 .49928 .51389 .49605 .50823 .49005 Mtetra
.50823 .49005 .51389 .49605 .52424 .4928 .5186 .48678 Mtetra
.5186 .48678 .52424 .4928 .53463 .48955 .52901 .4835 Mtetra
.52901 .4835 .53463 .48955 .54505 .48627 .53946 .4802 Mtetra
.53946 .4802 .54505 .48627 .55552 .48299 .54996 .4769 Mtetra
.54996 .4769 .55552 .48299 .56602 .4797 .56049 .47358 Mtetra
.56049 .47358 .56602 .4797 .57657 .47639 .57106 .47025 Mtetra
.57106 .47025 .57657 .47639 .58715 .47307 .58167 .46691 Mtetra
.58167 .46691 .58715 .47307 .59778 .46974 .59232 .46355 Mtetra
.59232 .46355 .59778 .46974 .60844 .46639 .60302 .46018 Mtetra
.60302 .46018 .60844 .46639 .61915 .46303 .61375 .4568 Mtetra
.61375 .4568 .61915 .46303 .6299 .45966 .62453 .4534 Mtetra
.62453 .4534 .6299 .45966 .64069 .45628 .63535 .44999 Mtetra
.63535 .44999 .64069 .45628 .65152 .45288 .64621 .44657 Mtetra
.64621 .44657 .65152 .45288 .66239 .44947 .65711 .44314 Mtetra
.65711 .44314 .66239 .44947 .67331 .44604 .66805 .43969 Mtetra
.66805 .43969 .67331 .44604 .68427 .44261 .67904 .43623 Mtetra
.67904 .43623 .68427 .44261 .69527 .43916 .69007 .43275 Mtetra
.69007 .43275 .69527 .43916 .70631 .43569 .70114 .42927 Mtetra
.70114 .42927 .70631 .43569 .7174 .43222 .71226 .42577 Mtetra
.71226 .42577 .7174 .43222 .72853 .42873 .72342 .42226 Mtetra
.655 .752 .921 r
.72342 .42226 .72853 .42873 .7397 .42523 .73462 .41873 Mtetra
.73462 .41873 .7397 .42523 .75092 .42171 .74587 .4152 Mtetra
.74587 .4152 .75092 .42171 .76218 .41819 .75716 .41166 Mtetra
.75716 .41166 .76218 .41819 .77348 .41465 .7685 .40811 Mtetra
.655 .753 .922 r
.7685 .40811 .77348 .41465 .78484 .4111 .77989 .40454 Mtetra
.77989 .40454 .78484 .4111 .79623 .40753 .79132 .40096 Mtetra
.79132 .40096 .79623 .40753 .80767 .40395 .80279 .39737 Mtetra
.655 .754 .922 r
.80279 .39737 .80767 .40395 .81916 .40036 .81431 .39375 Mtetra
.656 .754 .922 r
.81431 .39375 .81916 .40036 .83069 .39674 .82588 .3901 Mtetra
.82588 .3901 .83069 .39674 .84227 .3931 .83749 .38643 Mtetra
.657 .754 .922 r
.83749 .38643 .84227 .3931 .85389 .38945 .84914 .38273 Mtetra
.657 .754 .921 r
.84914 .38273 .85389 .38945 .86556 .38577 .86084 .379 Mtetra
.658 .753 .92 r
.86084 .379 .86556 .38577 .87727 .38207 .87259 .37524 Mtetra
.652 .75 .922 r
.24535 .5654 .25164 .57089 .26106 .56797 .25479 .56251 Mtetra
.652 .752 .923 r
.25479 .56251 .26106 .56797 .27052 .56503 .26426 .55959 Mtetra
.653 .754 .924 r
.26426 .55959 .27052 .56503 .28001 .56207 .27377 .55664 Mtetra
.654 .755 .924 r
.27377 .55664 .28001 .56207 .28953 .55909 .28331 .55366 Mtetra
.655 .756 .924 r
.28331 .55366 .28953 .55909 .29909 .55607 .2929 .55064 Mtetra
.656 .757 .924 r
.2929 .55064 .29909 .55607 .30869 .55304 .30251 .54758 Mtetra
.657 .757 .924 r
.30251 .54758 .30869 .55304 .31832 .54999 .31217 .5445 Mtetra
.657 .757 .923 r
.31217 .5445 .31832 .54999 .32799 .54692 .32186 .54139 Mtetra
.657 .756 .923 r
.32186 .54139 .32799 .54692 .33769 .54384 .33159 .53828 Mtetra
.657 .756 .922 r
.33159 .53828 .33769 .54384 .34743 .54076 .34135 .53515 Mtetra
.657 .755 .922 r
.34135 .53515 .34743 .54076 .35721 .53766 .35114 .53201 Mtetra
.657 .754 .922 r
.35114 .53201 .35721 .53766 .36702 .53456 .36098 .52887 Mtetra
.657 .753 .921 r
.36098 .52887 .36702 .53456 .37686 .53145 .37085 .52573 Mtetra
.656 .753 .921 r
.37085 .52573 .37686 .53145 .38674 .52833 .38075 .52258 Mtetra
.656 .752 .921 r
.38075 .52258 .38674 .52833 .39666 .5252 .39069 .51942 Mtetra
.39069 .51942 .39666 .5252 .40662 .52207 .40067 .51626 Mtetra
.656 .752 .92 r
.40067 .51626 .40662 .52207 .41661 .51892 .41068 .51308 Mtetra
.41068 .51308 .41661 .51892 .42664 .51576 .42074 .5099 Mtetra
.42074 .5099 .42664 .51576 .4367 .51258 .43083 .5067 Mtetra
.43083 .5067 .4367 .51258 .44681 .5094 .44095 .50349 Mtetra
.656 .751 .92 r
.44095 .50349 .44681 .5094 .45695 .5062 .45112 .50028 Mtetra
.45112 .50028 .45695 .5062 .46713 .503 .46132 .49705 Mtetra
.46132 .49705 .46713 .503 .47734 .49978 .47157 .4938 Mtetra
.47157 .4938 .47734 .49978 .4876 .49655 .48185 .49055 Mtetra
.48185 .49055 .4876 .49655 .49789 .4933 .49217 .48728 Mtetra
.49217 .48728 .49789 .4933 .50823 .49005 .50253 .484 Mtetra
.50253 .484 .50823 .49005 .5186 .48678 .51292 .48071 Mtetra
.51292 .48071 .5186 .48678 .52901 .4835 .52336 .47741 Mtetra
.52336 .47741 .52901 .4835 .53946 .4802 .53384 .47409 Mtetra
.53384 .47409 .53946 .4802 .54996 .4769 .54436 .47076 Mtetra
.54436 .47076 .54996 .4769 .56049 .47358 .55491 .46742 Mtetra
.55491 .46742 .56049 .47358 .57106 .47025 .56551 .46407 Mtetra
.56551 .46407 .57106 .47025 .58167 .46691 .57615 .4607 Mtetra
.57615 .4607 .58167 .46691 .59232 .46355 .58683 .45732 Mtetra
.58683 .45732 .59232 .46355 .60302 .46018 .59755 .45393 Mtetra
.59755 .45393 .60302 .46018 .61375 .4568 .60832 .45052 Mtetra
.60832 .45052 .61375 .4568 .62453 .4534 .61912 .4471 Mtetra
.61912 .4471 .62453 .4534 .63535 .44999 .62997 .44367 Mtetra
.62997 .44367 .63535 .44999 .64621 .44657 .64085 .44022 Mtetra
.64085 .44022 .64621 .44657 .65711 .44314 .65178 .43676 Mtetra
.65178 .43676 .65711 .44314 .66805 .43969 .66276 .43329 Mtetra
.656 .752 .92 r
.66276 .43329 .66805 .43969 .67904 .43623 .67377 .42981 Mtetra
.656 .752 .921 r
.67377 .42981 .67904 .43623 .69007 .43275 .68483 .42631 Mtetra
.655 .752 .921 r
.68483 .42631 .69007 .43275 .70114 .42927 .69594 .42281 Mtetra
.69594 .42281 .70114 .42927 .71226 .42577 .70708 .41929 Mtetra
.70708 .41929 .71226 .42577 .72342 .42226 .71828 .41576 Mtetra
.71828 .41576 .72342 .42226 .73462 .41873 .72951 .41223 Mtetra
.655 .753 .922 r
.72951 .41223 .73462 .41873 .74587 .4152 .74079 .40869 Mtetra
.654 .753 .922 r
.74079 .40869 .74587 .4152 .75716 .41166 .75212 .40514 Mtetra
.654 .754 .923 r
.75212 .40514 .75716 .41166 .7685 .40811 .76349 .40158 Mtetra
.654 .755 .924 r
.76349 .40158 .7685 .40811 .77989 .40454 .77491 .39801 Mtetra
.77491 .39801 .77989 .40454 .79132 .40096 .78637 .39443 Mtetra
.654 .756 .924 r
.78637 .39443 .79132 .40096 .80279 .39737 .79788 .39082 Mtetra
.655 .757 .925 r
.79788 .39082 .80279 .39737 .81431 .39375 .80943 .38717 Mtetra
.656 .757 .924 r
.80943 .38717 .81431 .39375 .82588 .3901 .82103 .38349 Mtetra
.657 .757 .924 r
.82103 .38349 .82588 .3901 .83749 .38643 .83267 .37976 Mtetra
.658 .757 .923 r
.83267 .37976 .83749 .38643 .84914 .38273 .84436 .376 Mtetra
.659 .756 .922 r
.84436 .376 .84914 .38273 .86084 .379 .85609 .3722 Mtetra
.659 .755 .92 r
.85609 .3722 .86084 .379 .87259 .37524 .86786 .36837 Mtetra
.648 .749 .923 r
.23902 .55988 .24535 .5654 .25479 .56251 .24847 .55705 Mtetra
.649 .753 .925 r
.24847 .55705 .25479 .56251 .26426 .55959 .25796 .55418 Mtetra
.65 .756 .927 r
.25796 .55418 .26426 .55959 .27377 .55664 .26748 .55128 Mtetra
.651 .758 .928 r
.26748 .55128 .27377 .55664 .28331 .55366 .27704 .54833 Mtetra
.653 .761 .929 r
.27704 .54833 .28331 .55366 .2929 .55064 .28664 .54532 Mtetra
.655 .763 .929 r
.28664 .54532 .2929 .55064 .30251 .54758 .29628 .54226 Mtetra
.657 .763 .928 r
.29628 .54226 .30251 .54758 .31217 .5445 .30596 .53915 Mtetra
.658 .763 .928 r
.30596 .53915 .31217 .5445 .32186 .54139 .31567 .53599 Mtetra
.659 .763 .927 r
.31567 .53599 .32186 .54139 .33159 .53828 .32543 .53281 Mtetra
.659 .761 .925 r
.32543 .53281 .33159 .53828 .34135 .53515 .33521 .52962 Mtetra
.659 .76 .924 r
.33521 .52962 .34135 .53515 .35114 .53201 .34503 .52642 Mtetra
.658 .758 .923 r
.34503 .52642 .35114 .53201 .36098 .52887 .35489 .52322 Mtetra
.658 .756 .923 r
.35489 .52322 .36098 .52887 .37085 .52573 .36479 .52002 Mtetra
.657 .755 .922 r
.36479 .52002 .37085 .52573 .38075 .52258 .37471 .51682 Mtetra
.657 .754 .921 r
.37471 .51682 .38075 .52258 .39069 .51942 .38468 .51362 Mtetra
.657 .753 .921 r
.38468 .51362 .39069 .51942 .40067 .51626 .39468 .51042 Mtetra
.656 .752 .921 r
.39468 .51042 .40067 .51626 .41068 .51308 .40472 .50721 Mtetra
.40472 .50721 .41068 .51308 .42074 .5099 .4148 .504 Mtetra
.656 .752 .92 r
.4148 .504 .42074 .5099 .43083 .5067 .42491 .50078 Mtetra
.42491 .50078 .43083 .5067 .44095 .50349 .43506 .49755 Mtetra
.656 .751 .92 r
.43506 .49755 .44095 .50349 .45112 .50028 .44525 .4943 Mtetra
.44525 .4943 .45112 .50028 .46132 .49705 .45548 .49105 Mtetra
.45548 .49105 .46132 .49705 .47157 .4938 .46575 .48778 Mtetra
.46575 .48778 .47157 .4938 .48185 .49055 .47605 .48451 Mtetra
.47605 .48451 .48185 .49055 .49217 .48728 .4864 .48122 Mtetra
.4864 .48122 .49217 .48728 .50253 .484 .49678 .47792 Mtetra
.49678 .47792 .50253 .484 .51292 .48071 .50721 .4746 Mtetra
.50721 .4746 .51292 .48071 .52336 .47741 .51767 .47127 Mtetra
.51767 .47127 .52336 .47741 .53384 .47409 .52817 .46793 Mtetra
.52817 .46793 .53384 .47409 .54436 .47076 .53872 .46458 Mtetra
.53872 .46458 .54436 .47076 .55491 .46742 .5493 .46122 Mtetra
.5493 .46122 .55491 .46742 .56551 .46407 .55993 .45784 Mtetra
.55993 .45784 .56551 .46407 .57615 .4607 .57059 .45445 Mtetra
.57059 .45445 .57615 .4607 .58683 .45732 .5813 .45104 Mtetra
.5813 .45104 .58683 .45732 .59755 .45393 .59205 .44762 Mtetra
.59205 .44762 .59755 .45393 .60832 .45052 .60284 .44419 Mtetra
.60284 .44419 .60832 .45052 .61912 .4471 .61367 .44075 Mtetra
.61367 .44075 .61912 .4471 .62997 .44367 .62455 .43729 Mtetra
.62455 .43729 .62997 .44367 .64085 .44022 .63546 .43383 Mtetra
.63546 .43383 .64085 .44022 .65178 .43676 .64642 .43034 Mtetra
.64642 .43034 .65178 .43676 .66276 .43329 .65743 .42685 Mtetra
.655 .752 .921 r
.65743 .42685 .66276 .43329 .67377 .42981 .66847 .42335 Mtetra
.66847 .42335 .67377 .42981 .68483 .42631 .67956 .41984 Mtetra
.67956 .41984 .68483 .42631 .69594 .42281 .6907 .41632 Mtetra
.655 .752 .922 r
.6907 .41632 .69594 .42281 .70708 .41929 .70187 .4128 Mtetra
.654 .753 .922 r
.70187 .4128 .70708 .41929 .71828 .41576 .7131 .40928 Mtetra
.653 .754 .923 r
.7131 .40928 .71828 .41576 .72951 .41223 .72437 .40575 Mtetra
.653 .755 .924 r
.72437 .40575 .72951 .41223 .74079 .40869 .73568 .40223 Mtetra
.652 .756 .926 r
.73568 .40223 .74079 .40869 .75212 .40514 .74704 .3987 Mtetra
.652 .757 .927 r
.74704 .3987 .75212 .40514 .76349 .40158 .75845 .39516 Mtetra
.652 .759 .928 r
.75845 .39516 .76349 .40158 .77491 .39801 .76991 .39161 Mtetra
.653 .761 .929 r
.76991 .39161 .77491 .39801 .78637 .39443 .7814 .38802 Mtetra
.654 .762 .929 r
.7814 .38802 .78637 .39443 .79788 .39082 .79295 .3844 Mtetra
.655 .763 .929 r
.79295 .3844 .79788 .39082 .80943 .38717 .80453 .38071 Mtetra
.657 .763 .928 r
.80453 .38071 .80943 .38717 .82103 .38349 .81616 .37697 Mtetra
.659 .763 .927 r
.81616 .37697 .82103 .38349 .83267 .37976 .82783 .37316 Mtetra
.66 .762 .925 r
.82783 .37316 .83267 .37976 .84436 .376 .83955 .3693 Mtetra
.662 .76 .923 r
.83955 .3693 .84436 .376 .85609 .3722 .8513 .36539 Mtetra
.662 .757 .92 r
.8513 .36539 .85609 .3722 .86786 .36837 .8631 .36144 Mtetra
.643 .748 .925 r
.23264 .55431 .23902 .55988 .24847 .55705 .2421 .55158 Mtetra
.643 .752 .928 r
.2421 .55158 .24847 .55705 .25796 .55418 .2516 .54881 Mtetra
.645 .757 .931 r
.2516 .54881 .25796 .55418 .26748 .55128 .26114 .54599 Mtetra
.647 .761 .933 r
.26114 .54599 .26748 .55128 .27704 .54833 .27071 .54312 Mtetra
.65 .766 .934 r
.27071 .54312 .27704 .54833 .28664 .54532 .28033 .54016 Mtetra
.652 .769 .935 r
.28033 .54016 .28664 .54532 .29628 .54226 .28999 .53712 Mtetra
.656 .771 .934 r
.28999 .53712 .29628 .54226 .30596 .53915 .29969 .534 Mtetra
.658 .772 .934 r
.29969 .534 .30596 .53915 .31567 .53599 .30943 .53081 Mtetra
.66 .772 .932 r
.30943 .53081 .31567 .53599 .32543 .53281 .31921 .52756 Mtetra
.661 .771 .931 r
.31921 .52756 .32543 .53281 .33521 .52962 .32902 .52429 Mtetra
.661 .769 .929 r
.32902 .52429 .33521 .52962 .34503 .52642 .33887 .521 Mtetra
.661 .766 .928 r
.33887 .521 .34503 .52642 .35489 .52322 .34876 .51771 Mtetra
.66 .764 .926 r
.34876 .51771 .35489 .52322 .36479 .52002 .35868 .51443 Mtetra
.659 .761 .925 r
.35868 .51443 .36479 .52002 .37471 .51682 .36863 .51115 Mtetra
.659 .759 .924 r
.36863 .51115 .37471 .51682 .38468 .51362 .37862 .50789 Mtetra
.658 .757 .923 r
.37862 .50789 .38468 .51362 .39468 .51042 .38865 .50463 Mtetra
.657 .756 .922 r
.38865 .50463 .39468 .51042 .40472 .50721 .39871 .50137 Mtetra
.657 .755 .922 r
.39871 .50137 .40472 .50721 .4148 .504 .40881 .49812 Mtetra
.657 .754 .922 r
.40881 .49812 .4148 .504 .42491 .50078 .41895 .49486 Mtetra
.656 .753 .921 r
.41895 .49486 .42491 .50078 .43506 .49755 .42913 .49159 Mtetra
.42913 .49159 .43506 .49755 .44525 .4943 .43934 .48832 Mtetra
.656 .752 .921 r
.43934 .48832 .44525 .4943 .45548 .49105 .4496 .48503 Mtetra
.4496 .48503 .45548 .49105 .46575 .48778 .45989 .48174 Mtetra
.45989 .48174 .46575 .48778 .47605 .48451 .47022 .47844 Mtetra
.47022 .47844 .47605 .48451 .4864 .48122 .48059 .47512 Mtetra
.48059 .47512 .4864 .48122 .49678 .47792 .491 .4718 Mtetra
.491 .4718 .49678 .47792 .50721 .4746 .50145 .46846 Mtetra
.656 .752 .92 r
.50145 .46846 .50721 .4746 .51767 .47127 .51194 .46511 Mtetra
.51194 .46511 .51767 .47127 .52817 .46793 .52247 .46174 Mtetra
.52247 .46174 .52817 .46793 .53872 .46458 .53304 .45837 Mtetra
.53304 .45837 .53872 .46458 .5493 .46122 .54365 .45498 Mtetra
.656 .752 .921 r
.54365 .45498 .5493 .46122 .55993 .45784 .5543 .45158 Mtetra
.5543 .45158 .55993 .45784 .57059 .45445 .565 .44816 Mtetra
.565 .44816 .57059 .45445 .5813 .45104 .57573 .44473 Mtetra
.57573 .44473 .5813 .45104 .59205 .44762 .58651 .44129 Mtetra
.58651 .44129 .59205 .44762 .60284 .44419 .59733 .43784 Mtetra
.59733 .43784 .60284 .44419 .61367 .44075 .60819 .43438 Mtetra
.655 .752 .921 r
.60819 .43438 .61367 .44075 .62455 .43729 .61909 .4309 Mtetra
.61909 .4309 .62455 .43729 .63546 .43383 .63004 .42742 Mtetra
.63004 .42742 .63546 .43383 .64642 .43034 .64102 .42392 Mtetra
.655 .753 .922 r
.64102 .42392 .64642 .43034 .65743 .42685 .65206 .42042 Mtetra
.654 .753 .922 r
.65206 .42042 .65743 .42685 .66847 .42335 .66313 .41692 Mtetra
.654 .754 .923 r
.66313 .41692 .66847 .42335 .67956 .41984 .67426 .41341 Mtetra
.653 .754 .924 r
.67426 .41341 .67956 .41984 .6907 .41632 .68542 .4099 Mtetra
.653 .755 .925 r
.68542 .4099 .6907 .41632 .70187 .4128 .69663 .4064 Mtetra
.652 .757 .926 r
.69663 .4064 .70187 .4128 .7131 .40928 .70789 .4029 Mtetra
.651 .758 .928 r
.70789 .4029 .7131 .40928 .72437 .40575 .7192 .39942 Mtetra
.65 .76 .93 r
.7192 .39942 .72437 .40575 .73568 .40223 .73055 .39594 Mtetra
.649 .762 .932 r
.73055 .39594 .73568 .40223 .74704 .3987 .74195 .39245 Mtetra
.649 .765 .934 r
.74195 .39245 .74704 .3987 .75845 .39516 .75339 .38895 Mtetra
.649 .767 .935 r
.75339 .38895 .75845 .39516 .76991 .39161 .76488 .38541 Mtetra
.651 .77 .936 r
.76488 .38541 .76991 .39161 .7814 .38802 .77642 .38182 Mtetra
.653 .771 .935 r
.77642 .38182 .7814 .38802 .79295 .3844 .788 .37815 Mtetra
.656 .772 .934 r
.788 .37815 .79295 .3844 .80453 .38071 .79961 .3744 Mtetra
.659 .771 .932 r
.79961 .3744 .80453 .38071 .81616 .37697 .81127 .37055 Mtetra
.662 .77 .93 r
.81127 .37055 .81616 .37697 .82783 .37316 .82297 .36662 Mtetra
.664 .767 .927 r
.82297 .36662 .82783 .37316 .83955 .3693 .8347 .36261 Mtetra
.666 .764 .923 r
.8347 .36261 .83955 .3693 .8513 .36539 .84648 .35856 Mtetra
.667 .76 .92 r
.84648 .35856 .8513 .36539 .8631 .36144 .85831 .35446 Mtetra
.636 .746 .928 r
.22623 .54871 .23264 .55431 .2421 .55158 .23569 .5461 Mtetra
.636 .752 .932 r
.23569 .5461 .2421 .55158 .2516 .54881 .2452 .54347 Mtetra
.637 .758 .935 r
.2452 .54347 .2516 .54881 .26114 .54599 .25474 .54079 Mtetra
.639 .764 .939 r
.25474 .54079 .26114 .54599 .27071 .54312 .26433 .53806 Mtetra
.641 .771 .942 r
.26433 .53806 .27071 .54312 .28033 .54016 .27396 .53523 Mtetra
.645 .777 .944 r
.27396 .53523 .28033 .54016 .28999 .53712 .28363 .53229 Mtetra
.65 .783 .945 r
.28363 .53229 .28999 .53712 .29969 .534 .29335 .52923 Mtetra
.654 .788 .945 r
.29335 .52923 .29969 .534 .30943 .53081 .30311 .52606 Mtetra
.659 .79 .945 r
.30311 .52606 .30943 .53081 .31921 .52756 .31291 .52278 Mtetra
.662 .79 .943 r
.31291 .52278 .31921 .52756 .32902 .52429 .32276 .51942 Mtetra
.664 .788 .941 r
.32276 .51942 .32902 .52429 .33887 .521 .33264 .51601 Mtetra
.665 .785 .938 r
.33264 .51601 .33887 .521 .34876 .51771 .34255 .51258 Mtetra
.664 .78 .935 r
.34255 .51258 .34876 .51771 .35868 .51443 .3525 .50916 Mtetra
.664 .775 .933 r
.3525 .50916 .35868 .51443 .36863 .51115 .36249 .50574 Mtetra
.662 .771 .93 r
.36249 .50574 .36863 .51115 .37862 .50789 .37251 .50235 Mtetra
.661 .767 .928 r
.37251 .50235 .37862 .50789 .38865 .50463 .38257 .49898 Mtetra
.66 .763 .926 r
.38257 .49898 .38865 .50463 .39871 .50137 .39266 .49563 Mtetra
.659 .76 .925 r
.39266 .49563 .39871 .50137 .40881 .49812 .40278 .49229 Mtetra
.658 .758 .924 r
.40278 .49229 .40881 .49812 .41895 .49486 .41295 .48897 Mtetra
.658 .756 .923 r
.41295 .48897 .41895 .49486 .42913 .49159 .42315 .48565 Mtetra
.657 .755 .922 r
.42315 .48565 .42913 .49159 .43934 .48832 .43339 .48233 Mtetra
.657 .754 .922 r
.43339 .48233 .43934 .48832 .4496 .48503 .44367 .479 Mtetra
.656 .753 .921 r
.44367 .479 .4496 .48503 .45989 .48174 .45399 .47567 Mtetra
.45399 .47567 .45989 .48174 .47022 .47844 .46434 .47234 Mtetra
.656 .752 .921 r
.46434 .47234 .47022 .47844 .48059 .47512 .47474 .46899 Mtetra
.47474 .46899 .48059 .47512 .491 .4718 .48517 .46564 Mtetra
.48517 .46564 .491 .4718 .50145 .46846 .49565 .46227 Mtetra
.656 .752 .92 r
.49565 .46227 .50145 .46846 .51194 .46511 .50617 .4589 Mtetra
.50617 .4589 .51194 .46511 .52247 .46174 .51672 .45551 Mtetra
.51672 .45551 .52247 .46174 .53304 .45837 .52732 .45211 Mtetra
.52732 .45211 .53304 .45837 .54365 .45498 .53796 .44869 Mtetra
.656 .752 .921 r
.53796 .44869 .54365 .45498 .5543 .45158 .54864 .44527 Mtetra
.54864 .44527 .5543 .45158 .565 .44816 .55936 .44183 Mtetra
.55936 .44183 .565 .44816 .57573 .44473 .57012 .43839 Mtetra
.655 .752 .921 r
.57012 .43839 .57573 .44473 .58651 .44129 .58092 .43493 Mtetra
.58092 .43493 .58651 .44129 .59733 .43784 .59177 .43146 Mtetra
.59177 .43146 .59733 .43784 .60819 .43438 .60266 .42799 Mtetra
.655 .753 .922 r
.60266 .42799 .60819 .43438 .61909 .4309 .61359 .4245 Mtetra
.654 .753 .922 r
.61359 .4245 .61909 .4309 .63004 .42742 .62457 .42102 Mtetra
.654 .754 .923 r
.62457 .42102 .63004 .42742 .64102 .42392 .63559 .41753 Mtetra
.653 .755 .924 r
.63559 .41753 .64102 .42392 .65206 .42042 .64665 .41405 Mtetra
.652 .756 .926 r
.64665 .41405 .65206 .42042 .66313 .41692 .65776 .41058 Mtetra
.651 .758 .928 r
.65776 .41058 .66313 .41692 .67426 .41341 .66892 .40712 Mtetra
.649 .76 .93 r
.66892 .40712 .67426 .41341 .68542 .4099 .68012 .40368 Mtetra
.648 .762 .933 r
.68012 .40368 .68542 .4099 .69663 .4064 .69137 .40026 Mtetra
.646 .765 .936 r
.69137 .40026 .69663 .4064 .70789 .4029 .70267 .39686 Mtetra
.644 .769 .939 r
.70267 .39686 .70789 .4029 .7192 .39942 .71401 .39347 Mtetra
.643 .773 .943 r
.71401 .39347 .7192 .39942 .73055 .39594 .72541 .39009 Mtetra
.642 .778 .946 r
.72541 .39009 .73055 .39594 .74195 .39245 .73685 .38668 Mtetra
.643 .782 .948 r
.73685 .38668 .74195 .39245 .75339 .38895 .74833 .38321 Mtetra
.646 .785 .949 r
.74833 .38321 .75339 .38895 .76488 .38541 .75986 .37967 Mtetra
.65 .788 .948 r
.75986 .37967 .76488 .38541 .77642 .38182 .77143 .37601 Mtetra
.655 .788 .946 r
.77143 .37601 .77642 .38182 .788 .37815 .78303 .37223 Mtetra
.66 .787 .942 r
.78303 .37223 .788 .37815 .79961 .3744 .79468 .36831 Mtetra
.664 .784 .938 r
.79468 .36831 .79961 .3744 .81127 .37055 .80636 .36429 Mtetra
.668 .779 .933 r
.80636 .36429 .81127 .37055 .82297 .36662 .81808 .36016 Mtetra
.67 .774 .928 r
.81808 .36016 .82297 .36662 .8347 .36261 .82983 .35595 Mtetra
.672 .769 .923 r
.82983 .35595 .8347 .36261 .84648 .35856 .84163 .35171 Mtetra
.672 .763 .919 r
.84163 .35171 .84648 .35856 .85831 .35446 .85348 .34743 Mtetra
.63 .745 .93 r
.21976 .54307 .22623 .54871 .23569 .5461 .22924 .54057 Mtetra
.629 .749 .934 r
.22924 .54057 .23569 .5461 .2452 .54347 .23875 .53807 Mtetra
.628 .755 .938 r
.23875 .53807 .2452 .54347 .25474 .54079 .2483 .53556 Mtetra
.629 .762 .942 r
.2483 .53556 .25474 .54079 .26433 .53806 .25789 .533 Mtetra
.63 .77 .947 r
.25789 .533 .26433 .53806 .27396 .53523 .26753 .53037 Mtetra
.634 .779 .951 r
.26753 .53037 .27396 .53523 .28363 .53229 .27721 .52763 Mtetra
.639 .789 .954 r
.27721 .52763 .28363 .53229 .29335 .52923 .28694 .52474 Mtetra
.645 .797 .956 r
.28694 .52474 .29335 .52923 .30311 .52606 .29672 .52168 Mtetra
.653 .804 .956 r
.29672 .52168 .30311 .52606 .31291 .52278 .30654 .51844 Mtetra
.659 .808 .955 r
.30654 .51844 .31291 .52278 .32276 .51942 .31641 .51506 Mtetra
.664 .809 .953 r
.31641 .51506 .32276 .51942 .33264 .51601 .32632 .51157 Mtetra
.667 .807 .95 r
.32632 .51157 .33264 .51601 .34255 .51258 .33627 .50801 Mtetra
.668 .803 .947 r
.33627 .50801 .34255 .51258 .3525 .50916 .34626 .50441 Mtetra
.668 .798 .944 r
.34626 .50441 .3525 .50916 .36249 .50574 .35628 .50082 Mtetra
.667 .792 .941 r
.35628 .50082 .36249 .50574 .37251 .50235 .36633 .49726 Mtetra
.666 .786 .938 r
.36633 .49726 .37251 .50235 .38257 .49898 .37642 .49372 Mtetra
.664 .78 .935 r
.37642 .49372 .38257 .49898 .39266 .49563 .38654 .49022 Mtetra
.663 .775 .933 r
.38654 .49022 .39266 .49563 .40278 .49229 .3967 .48676 Mtetra
.661 .77 .931 r
.3967 .48676 .40278 .49229 .41295 .48897 .40689 .48332 Mtetra
.66 .767 .929 r
.40689 .48332 .41295 .48897 .42315 .48565 .41712 .4799 Mtetra
.659 .764 .927 r
.41712 .4799 .42315 .48565 .43339 .48233 .42739 .4765 Mtetra
.658 .762 .926 r
.42739 .4765 .43339 .48233 .44367 .479 .4377 .47311 Mtetra
.658 .76 .925 r
.4377 .47311 .44367 .479 .45399 .47567 .44804 .46973 Mtetra
.657 .759 .925 r
.44804 .46973 .45399 .47567 .46434 .47234 .45842 .46634 Mtetra
.657 .758 .924 r
.45842 .46634 .46434 .47234 .47474 .46899 .46884 .46295 Mtetra
.656 .757 .924 r
.46884 .46295 .47474 .46899 .48517 .46564 .47931 .45956 Mtetra
.656 .756 .924 r
.47931 .45956 .48517 .46564 .49565 .46227 .48981 .45616 Mtetra
.656 .756 .923 r
.48981 .45616 .49565 .46227 .50617 .4589 .50035 .45275 Mtetra
.50035 .45275 .50617 .4589 .51672 .45551 .51093 .44933 Mtetra
.656 .755 .923 r
.51093 .44933 .51672 .45551 .52732 .45211 .52156 .44591 Mtetra
.655 .755 .923 r
.52156 .44591 .52732 .45211 .53796 .44869 .53222 .44248 Mtetra
.53222 .44248 .53796 .44869 .54864 .44527 .54293 .43903 Mtetra
.655 .755 .924 r
.54293 .43903 .54864 .44527 .55936 .44183 .55368 .43558 Mtetra
.655 .756 .924 r
.55368 .43558 .55936 .44183 .57012 .43839 .56447 .43213 Mtetra
.654 .756 .925 r
.56447 .43213 .57012 .43839 .58092 .43493 .5753 .42866 Mtetra
.654 .757 .925 r
.5753 .42866 .58092 .43493 .59177 .43146 .58618 .4252 Mtetra
.653 .757 .926 r
.58618 .4252 .59177 .43146 .60266 .42799 .5971 .42173 Mtetra
.653 .758 .927 r
.5971 .42173 .60266 .42799 .61359 .4245 .60806 .41827 Mtetra
.652 .76 .929 r
.60806 .41827 .61359 .4245 .62457 .42102 .61907 .41482 Mtetra
.65 .761 .93 r
.61907 .41482 .62457 .42102 .63559 .41753 .63012 .41138 Mtetra
.649 .763 .933 r
.63012 .41138 .63559 .41753 .64665 .41405 .64122 .40796 Mtetra
.647 .766 .936 r
.64122 .40796 .64665 .41405 .65776 .41058 .65237 .40457 Mtetra
.644 .769 .939 r
.65237 .40457 .65776 .41058 .66892 .40712 .66356 .40121 Mtetra
.641 .773 .943 r
.66356 .40121 .66892 .40712 .68012 .40368 .6748 .3979 Mtetra
.638 .777 .947 r
.6748 .3979 .68012 .40368 .69137 .40026 .68609 .39461 Mtetra
.635 .782 .952 r
.68609 .39461 .69137 .40026 .70267 .39686 .69743 .39134 Mtetra
.634 .787 .956 r
.69743 .39134 .70267 .39686 .71401 .39347 .70882 .38808 Mtetra
.633 .793 .959 r
.70882 .38808 .71401 .39347 .72541 .39009 .72026 .38479 Mtetra
.634 .798 .961 r
.72026 .38479 .72541 .39009 .73685 .38668 .73174 .38142 Mtetra
.639 .802 .961 r
.73174 .38142 .73685 .38668 .74833 .38321 .74326 .37793 Mtetra
.645 .805 .96 r
.74326 .37793 .74833 .38321 .75986 .37967 .75482 .37429 Mtetra
.653 .805 .956 r
.75482 .37429 .75986 .37967 .77143 .37601 .76642 .37047 Mtetra
.661 .802 .951 r
.76642 .37047 .77143 .37601 .78303 .37223 .77805 .36647 Mtetra
.668 .798 .944 r
.77805 .36647 .78303 .37223 .79468 .36831 .78971 .3623 Mtetra
.673 .791 .938 r
.78971 .3623 .79468 .36831 .80636 .36429 .80141 .35802 Mtetra
.675 .784 .931 r
.80141 .35802 .80636 .36429 .81808 .36016 .81315 .35365 Mtetra
.677 .777 .926 r
.81315 .35365 .81808 .36016 .82983 .35595 .82492 .34923 Mtetra
.677 .771 .921 r
.82492 .34923 .82983 .35595 .84163 .35171 .83674 .34479 Mtetra
.677 .765 .917 r
.83674 .34479 .84163 .35171 .85348 .34743 .84861 .34035 Mtetra
.629 .745 .931 r
.21326 .53739 .21976 .54307 .22924 .54057 .22275 .53489 Mtetra
.626 .744 .932 r
.22275 .53489 .22924 .54057 .23875 .53807 .23228 .53244 Mtetra
.624 .746 .935 r
.23228 .53244 .23875 .53807 .2483 .53556 .24184 .53002 Mtetra
.621 .749 .938 r
.24184 .53002 .2483 .53556 .25789 .533 .25143 .52762 Mtetra
.619 .755 .943 r
.25143 .52762 .25789 .533 .26753 .53037 .26107 .52524 Mtetra
.619 .766 .95 r
.26107 .52524 .26753 .53037 .27721 .52763 .27075 .5228 Mtetra
.621 .779 .957 r
.27075 .5228 .27721 .52763 .28694 .52474 .28047 .52025 Mtetra
.625 .794 .963 r
.28047 .52025 .28694 .52474 .29672 .52168 .29025 .51754 Mtetra
.633 .811 .968 r
.29025 .51754 .29672 .52168 .30654 .51844 .30008 .5146 Mtetra
.64 .825 .971 r
.30008 .5146 .30654 .51844 .31641 .51506 .30997 .51144 Mtetra
.649 .837 .972 r
.30997 .51144 .31641 .51506 .32632 .51157 .3199 .50805 Mtetra
.656 .844 .972 r
.3199 .50805 .32632 .51157 .33627 .50801 .32988 .50449 Mtetra
.663 .846 .97 r
.32988 .50449 .33627 .50801 .34626 .50441 .3399 .50079 Mtetra
.667 .843 .967 r
.3399 .50079 .34626 .50441 .35628 .50082 .34996 .49702 Mtetra
.669 .837 .964 r
.34996 .49702 .35628 .50082 .36633 .49726 .36005 .49323 Mtetra
.67 .829 .96 r
.36005 .49323 .36633 .49726 .37642 .49372 .37018 .48944 Mtetra
.669 .82 .956 r
.37018 .48944 .37642 .49372 .38654 .49022 .38034 .48569 Mtetra
.668 .811 .952 r
.38034 .48569 .38654 .49022 .3967 .48676 .39054 .48199 Mtetra
.667 .802 .947 r
.39054 .48199 .3967 .48676 .40689 .48332 .40077 .47833 Mtetra
.665 .794 .944 r
.40077 .47833 .40689 .48332 .41712 .4799 .41103 .47472 Mtetra
.663 .787 .94 r
.41103 .47472 .41712 .4799 .42739 .4765 .42133 .47115 Mtetra
.662 .782 .938 r
.42133 .47115 .42739 .4765 .4377 .47311 .43167 .46762 Mtetra
.66 .777 .935 r
.43167 .46762 .4377 .47311 .44804 .46973 .44204 .46411 Mtetra
.659 .773 .933 r
.44204 .46411 .44804 .46973 .45842 .46634 .45245 .46063 Mtetra
.658 .77 .932 r
.45245 .46063 .45842 .46634 .46884 .46295 .4629 .45716 Mtetra
.658 .768 .931 r
.4629 .45716 .46884 .46295 .47931 .45956 .47339 .4537 Mtetra
.657 .766 .93 r
.47339 .4537 .47931 .45956 .48981 .45616 .48392 .45024 Mtetra
.656 .764 .929 r
.48392 .45024 .48981 .45616 .50035 .45275 .49449 .44679 Mtetra
.49449 .44679 .50035 .45275 .51093 .44933 .5051 .44334 Mtetra
.655 .763 .929 r
.5051 .44334 .51093 .44933 .52156 .44591 .51576 .43989 Mtetra
.51576 .43989 .52156 .44591 .53222 .44248 .52645 .43644 Mtetra
.654 .763 .93 r
.52645 .43644 .53222 .44248 .54293 .43903 .53718 .433 Mtetra
.653 .763 .93 r
.53718 .433 .54293 .43903 .55368 .43558 .54796 .42955 Mtetra
.652 .764 .931 r
.54796 .42955 .55368 .43558 .56447 .43213 .55878 .42612 Mtetra
.651 .766 .933 r
.55878 .42612 .56447 .43213 .5753 .42866 .56965 .42269 Mtetra
.65 .767 .935 r
.56965 .42269 .5753 .42866 .58618 .4252 .58055 .41927 Mtetra
.648 .769 .937 r
.58055 .41927 .58618 .4252 .5971 .42173 .59151 .41588 Mtetra
.646 .772 .94 r
.59151 .41588 .5971 .42173 .60806 .41827 .6025 .41252 Mtetra
.643 .776 .944 r
.6025 .41252 .60806 .41827 .61907 .41482 .61355 .40918 Mtetra
.64 .78 .948 r
.61355 .40918 .61907 .41482 .63012 .41138 .62464 .40589 Mtetra
.636 .785 .953 r
.62464 .40589 .63012 .41138 .64122 .40796 .63578 .40265 Mtetra
.631 .791 .959 r
.63578 .40265 .64122 .40796 .65237 .40457 .64696 .39946 Mtetra
.626 .798 .965 r
.64696 .39946 .65237 .40457 .66356 .40121 .6582 .39631 Mtetra
.62 .806 .971 r
.6582 .39631 .66356 .40121 .6748 .3979 .66949 .39321 Mtetra
.615 .813 .976 r
.66949 .39321 .6748 .3979 .68609 .39461 .68083 .3901 Mtetra
.612 .821 .98 r
.68083 .3901 .68609 .39461 .69743 .39134 .69222 .38698 Mtetra
.612 .828 .983 r
.69222 .38698 .69743 .39134 .70882 .38808 .70365 .38378 Mtetra
.617 .833 .983 r
.70365 .38378 .70882 .38808 .72026 .38479 .71513 .38043 Mtetra
.626 .835 .981 r
.71513 .38043 .72026 .38479 .73174 .38142 .72664 .37691 Mtetra
.64 .835 .975 r
.72664 .37691 .73174 .38142 .74326 .37793 .73819 .37315 Mtetra
.654 .83 .968 r
.73819 .37315 .74326 .37793 .75482 .37429 .74977 .36916 Mtetra
.667 .821 .958 r
.74977 .36916 .75482 .37429 .76642 .37047 .76137 .36493 Mtetra
.676 .81 .947 r
.76137 .36493 .76642 .37047 .77805 .36647 .77301 .36052 Mtetra
.681 .797 .937 r
.77301 .36052 .77805 .36647 .78971 .3623 .78469 .35599 Mtetra
.683 .786 .928 r
.78469 .35599 .78971 .3623 .80141 .35802 .7964 .35139 Mtetra
.682 .776 .922 r
.7964 .35139 .80141 .35802 .81315 .35365 .80815 .34681 Mtetra
.681 .769 .917 r
.80815 .34681 .81315 .35365 .82492 .34923 .81996 .34224 Mtetra
.679 .764 .915 r
.81996 .34224 .82492 .34923 .83674 .34479 .8318 .3377 Mtetra
.677 .761 .914 r
.8318 .3377 .83674 .34479 .84861 .34035 .8437 .33321 Mtetra
.636 .746 .928 r
.20671 .53168 .21326 .53739 .22275 .53489 .21623 .52901 Mtetra
.632 .74 .926 r
.21623 .52901 .22275 .53489 .23228 .53244 .22579 .52643 Mtetra
.627 .735 .925 r
.22579 .52643 .23228 .53244 .24184 .53002 .23537 .52395 Mtetra
.621 .732 .926 r
.23537 .52395 .24184 .53002 .25143 .52762 .24498 .5216 Mtetra
.613 .732 .93 r
.24498 .5216 .25143 .52762 .26107 .52524 .25462 .51939 Mtetra
.608 .737 .937 r
.25462 .51939 .26107 .52524 .27075 .5228 .26429 .51725 Mtetra
.604 .747 .946 r
.26429 .51725 .27075 .5228 .28047 .52025 .27401 .51512 Mtetra
.604 .764 .956 r
.27401 .51512 .28047 .52025 .29025 .51754 .28377 .5129 Mtetra
.608 .786 .966 r
.28377 .5129 .29025 .51754 .30008 .5146 .29359 .51048 Mtetra
.615 .809 .975 r
.29359 .51048 .30008 .5146 .30997 .51144 .30347 .5078 Mtetra
.626 .832 .979 r
.30347 .5078 .30997 .51144 .3199 .50805 .3134 .50478 Mtetra
.636 .85 .982 r
.3134 .50478 .3199 .50805 .32988 .50449 .3234 .50147 Mtetra
.647 .863 .981 r
.3234 .50147 .32988 .50449 .3399 .50079 .33344 .49788 Mtetra
.655 .87 .98 r
.33344 .49788 .3399 .50079 .34996 .49702 .34354 .49409 Mtetra
.662 .872 .978 r
.34354 .49409 .34996 .49702 .36005 .49323 .35367 .49017 Mtetra
.667 .868 .975 r
.35367 .49017 .36005 .49323 .37018 .48944 .36384 .48618 Mtetra
.669 .862 .973 r
.36384 .48618 .37018 .48944 .38034 .48569 .37405 .48219 Mtetra
.67 .853 .97 r
.37405 .48219 .38034 .48569 .39054 .48199 .38428 .47822 Mtetra
.67 .844 .967 r
.38428 .47822 .39054 .48199 .40077 .47833 .39455 .47431 Mtetra
.668 .834 .963 r
.39455 .47431 .40077 .47833 .41103 .47472 .40486 .47046 Mtetra
.667 .825 .96 r
.40486 .47046 .41103 .47472 .42133 .47115 .4152 .46667 Mtetra
.665 .817 .956 r
.4152 .46667 .42133 .47115 .43167 .46762 .42557 .46294 Mtetra
.663 .81 .954 r
.42557 .46294 .43167 .46762 .44204 .46411 .43597 .45926 Mtetra
.661 .803 .951 r
.43597 .45926 .44204 .46411 .45245 .46063 .44642 .45563 Mtetra
.66 .798 .949 r
.44642 .45563 .45245 .46063 .4629 .45716 .4569 .45203 Mtetra
.658 .794 .947 r
.4569 .45203 .4629 .45716 .47339 .4537 .46742 .44847 Mtetra
.657 .791 .946 r
.46742 .44847 .47339 .4537 .48392 .45024 .47798 .44494 Mtetra
.655 .788 .945 r
.47798 .44494 .48392 .45024 .49449 .44679 .48858 .44143 Mtetra
.654 .787 .945 r
.48858 .44143 .49449 .44679 .5051 .44334 .49922 .43794 Mtetra
.653 .786 .945 r
.49922 .43794 .5051 .44334 .51576 .43989 .50991 .43446 Mtetra
.651 .785 .945 r
.50991 .43446 .51576 .43989 .52645 .43644 .52063 .43101 Mtetra
.65 .785 .946 r
.52063 .43101 .52645 .43644 .53718 .433 .5314 .42758 Mtetra
.648 .786 .948 r
.5314 .42758 .53718 .433 .54796 .42955 .54221 .42416 Mtetra
.646 .788 .95 r
.54221 .42416 .54796 .42955 .55878 .42612 .55306 .42078 Mtetra
.643 .79 .952 r
.55306 .42078 .55878 .42612 .56965 .42269 .56395 .41743 Mtetra
.64 .792 .955 r
.56395 .41743 .56965 .42269 .58055 .41927 .5749 .41411 Mtetra
.636 .796 .959 r
.5749 .41411 .58055 .41927 .59151 .41588 .58588 .41084 Mtetra
.631 .8 .964 r
.58588 .41084 .59151 .41588 .6025 .41252 .59692 .40763 Mtetra
.625 .805 .969 r
.59692 .40763 .6025 .41252 .61355 .40918 .608 .40448 Mtetra
.618 .811 .974 r
.608 .40448 .61355 .40918 .62464 .40589 .61914 .40139 Mtetra
.61 .817 .98 r
.61914 .40139 .62464 .40589 .63578 .40265 .63032 .39836 Mtetra
.602 .824 .985 r
.63032 .39836 .63578 .40265 .64696 .39946 .64155 .39539 Mtetra
.594 .831 .989 r
.64155 .39539 .64696 .39946 .6582 .39631 .65284 .39245 Mtetra
.587 .837 .992 r
.65284 .39245 .6582 .39631 .66949 .39321 .66418 .3895 Mtetra
.585 .844 .994 r
.66418 .3895 .66949 .39321 .68083 .3901 .67556 .38648 Mtetra
.589 .85 .994 r
.67556 .38648 .68083 .3901 .69222 .38698 .68699 .38333 Mtetra
.601 .854 .992 r
.68699 .38333 .69222 .38698 .70365 .38378 .69846 .37998 Mtetra
.621 .857 .988 r
.69846 .37998 .70365 .38378 .71513 .38043 .70996 .37633 Mtetra
.642 .853 .98 r
.70996 .37633 .71513 .38043 .72664 .37691 .7215 .37238 Mtetra
.665 .844 .969 r
.7215 .37238 .72664 .37691 .73819 .37315 .73305 .36808 Mtetra
.681 .829 .955 r
.73305 .36808 .73819 .37315 .74977 .36916 .74463 .3635 Mtetra
.691 .811 .939 r
.74463 .3635 .74977 .36916 .76137 .36493 .75624 .3587 Mtetra
.694 .793 .926 r
.75624 .3587 .76137 .36493 .77301 .36052 .76788 .3538 Mtetra
.693 .776 .915 r
.76788 .3538 .77301 .36052 .78469 .35599 .77956 .34891 Mtetra
.689 .764 .909 r
.77956 .34891 .78469 .35599 .7964 .35139 .79129 .34408 Mtetra
.684 .755 .906 r
.79129 .34408 .7964 .35139 .80815 .34681 .80308 .3394 Mtetra
.679 .751 .906 r
.80308 .3394 .80815 .34681 .81996 .34224 .81492 .33484 Mtetra
.675 .751 .908 r
.81492 .33484 .81996 .34224 .8318 .3377 .82681 .33038 Mtetra
.672 .753 .912 r
.82681 .33038 .8318 .3377 .8437 .33321 .83876 .32602 Mtetra
.655 .751 .921 r
.20012 .52592 .20671 .53168 .21623 .52901 .2097 .52281 Mtetra
.651 .736 .911 r
.2097 .52281 .21623 .52901 .22579 .52643 .21931 .51978 Mtetra
.645 .72 .903 r
.21931 .51978 .22579 .52643 .23537 .52395 .22894 .5169 Mtetra
.636 .706 .896 r
.22894 .5169 .23537 .52395 .24498 .5216 .2386 .51422 Mtetra
.625 .693 .893 r
.2386 .51422 .24498 .5216 .25462 .51939 .24826 .51182 Mtetra
.615 .684 .892 r
.24826 .51182 .25462 .51939 .26429 .51725 .25795 .50966 Mtetra
.603 .68 .896 r
.25795 .50966 .26429 .51725 .27401 .51512 .26766 .50776 Mtetra
.597 .685 .904 r
.26766 .50776 .27401 .51512 .28377 .5129 .27741 .50599 Mtetra
.592 .699 .917 r
.27741 .50599 .28377 .5129 .29359 .51048 .28719 .50425 Mtetra
.593 .723 .934 r
.28719 .50425 .29359 .51048 .30347 .5078 .29703 .50239 Mtetra
.598 .755 .953 r
.29703 .50239 .30347 .5078 .3134 .50478 .30693 .50027 Mtetra
.603 .793 .972 r
.30693 .50027 .3134 .50478 .3234 .50147 .3169 .49783 Mtetra
.611 .831 .984 r
.3169 .49783 .3234 .50147 .33344 .49788 .32693 .49498 Mtetra
.615 .862 .99 r
.32693 .49498 .33344 .49788 .34354 .49409 .33702 .49179 Mtetra
.618 .886 .989 r
.33702 .49179 .34354 .49409 .35367 .49017 .34717 .48826 Mtetra
.62 .901 .986 r
.34717 .48826 .35367 .49017 .36384 .48618 .35736 .48449 Mtetra
.622 .909 .983 r
.35736 .48449 .36384 .48618 .37405 .48219 .3676 .48055 Mtetra
.626 .912 .981 r
.3676 .48055 .37405 .48219 .38428 .47822 .37788 .47651 Mtetra
.629 .912 .982 r
.37788 .47651 .38428 .47822 .39455 .47431 .3882 .47243 Mtetra
.634 .908 .983 r
.3882 .47243 .39455 .47431 .40486 .47046 .39855 .46835 Mtetra
.637 .902 .984 r
.39855 .46835 .40486 .47046 .4152 .46667 .40893 .46431 Mtetra
.64 .895 .985 r
.40893 .46431 .4152 .46667 .42557 .46294 .41935 .46032 Mtetra
.642 .887 .985 r
.41935 .46032 .42557 .46294 .43597 .45926 .4298 .4564 Mtetra
.643 .879 .985 r
.4298 .4564 .43597 .45926 .44642 .45563 .44029 .45255 Mtetra
.643 .871 .984 r
.44029 .45255 .44642 .45563 .4569 .45203 .45081 .44876 Mtetra
.642 .864 .983 r
.45081 .44876 .4569 .45203 .46742 .44847 .46137 .44503 Mtetra
.64 .858 .982 r
.46137 .44503 .46742 .44847 .47798 .44494 .47197 .44137 Mtetra
.639 .853 .982 r
.47197 .44137 .47798 .44494 .48858 .44143 .48261 .43777 Mtetra
.636 .85 .982 r
.48261 .43777 .48858 .44143 .49922 .43794 .49328 .43422 Mtetra
.633 .848 .982 r
.49328 .43422 .49922 .43794 .50991 .43446 .504 .43072 Mtetra
.629 .846 .983 r
.504 .43072 .50991 .43446 .52063 .43101 .51476 .42728 Mtetra
.624 .846 .984 r
.51476 .42728 .52063 .43101 .5314 .42758 .52556 .42389 Mtetra
.618 .847 .986 r
.52556 .42389 .5314 .42758 .54221 .42416 .53641 .42057 Mtetra
.611 .849 .989 r
.53641 .42057 .54221 .42416 .55306 .42078 .5473 .4173 Mtetra
.603 .852 .991 r
.5473 .4173 .55306 .42078 .56395 .41743 .55824 .4141 Mtetra
.592 .855 .994 r
.55824 .4141 .56395 .41743 .5749 .41411 .56922 .41097 Mtetra
.58 .859 .996 r
.56922 .41097 .5749 .41411 .58588 .41084 .58025 .4079 Mtetra
.565 .862 .996 r
.58025 .4079 .58588 .41084 .59692 .40763 .59134 .40491 Mtetra
.55 .865 .996 r
.59134 .40491 .59692 .40763 .608 .40448 .60247 .40196 Mtetra
.535 .867 .993 r
.60247 .40196 .608 .40448 .61914 .40139 .61365 .39906 Mtetra
.522 .869 .99 r
.61365 .39906 .61914 .40139 .63032 .39836 .62488 .39616 Mtetra
.516 .871 .987 r
.62488 .39616 .63032 .39836 .64155 .39539 .63616 .39323 Mtetra
.52 .874 .986 r
.63616 .39323 .64155 .39539 .65284 .39245 .64749 .39019 Mtetra
.537 .879 .988 r
.64749 .39019 .65284 .39245 .66418 .3895 .65887 .38697 Mtetra
.567 .884 .991 r
.65887 .38697 .66418 .3895 .67556 .38648 .67028 .38351 Mtetra
.606 .883 .991 r
.67028 .38351 .67556 .38648 .68699 .38333 .68172 .3797 Mtetra
.645 .872 .983 r
.68172 .3797 .68699 .38333 .69846 .37998 .69319 .37553 Mtetra
.677 .851 .966 r
.69319 .37553 .69846 .37998 .70996 .37633 .70468 .37093 Mtetra
.696 .821 .942 r
.70468 .37093 .70996 .37633 .7215 .37238 .7162 .366 Mtetra
.705 .789 .917 r
.7162 .366 .7215 .37238 .73305 .36808 .72773 .3608 Mtetra
.705 .761 .895 r
.72773 .3608 .73305 .36808 .74463 .3635 .7393 .35546 Mtetra
.7 .738 .88 r
.7393 .35546 .74463 .3635 .75624 .3587 .7509 .35015 Mtetra
.694 .722 .871 r
.7509 .35015 .75624 .3587 .76788 .3538 .76255 .34495 Mtetra
.685 .711 .868 r
.76255 .34495 .76788 .3538 .77956 .34891 .77426 .34002 Mtetra
.678 .708 .871 r
.77426 .34002 .77956 .34891 .79129 .34408 .78604 .33534 Mtetra
.67 .709 .877 r
.78604 .33534 .79129 .34408 .80308 .3394 .79788 .33095 Mtetra
.664 .715 .887 r
.79788 .33095 .80308 .3394 .81492 .33484 .80978 .32676 Mtetra
.66 .725 .898 r
.80978 .32676 .81492 .33484 .82681 .33038 .82175 .32272 Mtetra
.657 .737 .909 r
.82175 .32272 .82681 .33038 .83876 .32602 .83378 .31877 Mtetra
.679 .757 .91 r
.19348 .52013 .20012 .52592 .2097 .52281 .20314 .5164 Mtetra
.675 .736 .896 r
.20314 .5164 .2097 .52281 .21931 .51978 .21283 .5127 Mtetra
.668 .715 .883 r
.21283 .5127 .21931 .51978 .22894 .5169 .22254 .50914 Mtetra
.658 .693 .872 r
.22254 .50914 .22894 .5169 .2386 .51422 .23226 .50581 Mtetra
.644 .672 .862 r
.23226 .50581 .2386 .51422 .24826 .51182 .24199 .50283 Mtetra
.629 .653 .855 r
.24199 .50283 .24826 .51182 .25795 .50966 .25172 .50024 Mtetra
.611 .636 .851 r
.25172 .50024 .25795 .50966 .26766 .50776 .26145 .49817 Mtetra
.596 .626 .852 r
.26145 .49817 .26766 .50776 .27741 .50599 .27119 .4965 Mtetra
.58 .623 .859 r
.27119 .4965 .27741 .50599 .28719 .50425 .28095 .49524 Mtetra
.571 .631 .872 r
.28095 .49524 .28719 .50425 .29703 .50239 .29075 .49415 Mtetra
.567 .651 .892 r
.29075 .49415 .29703 .50239 .30693 .50027 .30059 .49307 Mtetra
.568 .684 .918 r
.30059 .49307 .30693 .50027 .3169 .49783 .31049 .4918 Mtetra
.576 .728 .946 r
.31049 .4918 .3169 .49783 .32693 .49498 .32047 .49015 Mtetra
.584 .777 .971 r
.32047 .49015 .32693 .49498 .33702 .49179 .33053 .48805 Mtetra
.593 .825 .987 r
.33053 .48805 .33702 .49179 .34717 .48826 .34065 .48545 Mtetra
.597 .862 .993 r
.34065 .48545 .34717 .48826 .35736 .48449 .35084 .4824 Mtetra
.598 .89 .99 r
.35084 .4824 .35736 .48449 .3676 .48055 .3611 .47896 Mtetra
.597 .906 .983 r
.3611 .47896 .3676 .48055 .37788 .47651 .3714 .47523 Mtetra
.596 .915 .976 r
.3714 .47523 .37788 .47651 .3882 .47243 .38175 .47129 Mtetra
.596 .92 .972 r
.38175 .47129 .3882 .47243 .39855 .46835 .39214 .46724 Mtetra
.597 .921 .971 r
.39214 .46724 .39855 .46835 .40893 .46431 .40257 .46313 Mtetra
.598 .92 .972 r
.40257 .46313 .40893 .46431 .41935 .46032 .41303 .45902 Mtetra
.6 .918 .974 r
.41303 .45902 .41935 .46032 .4298 .4564 .42353 .45494 Mtetra
.601 .915 .977 r
.42353 .45494 .4298 .4564 .44029 .45255 .43406 .45093 Mtetra
.601 .911 .98 r
.43406 .45093 .44029 .45255 .45081 .44876 .44463 .44698 Mtetra
.6 .907 .983 r
.44463 .44698 .45081 .44876 .46137 .44503 .45523 .44312 Mtetra
.598 .902 .985 r
.45523 .44312 .46137 .44503 .47197 .44137 .46587 .43934 Mtetra
.594 .898 .987 r
.46587 .43934 .47197 .44137 .48261 .43777 .47655 .43565 Mtetra
.589 .894 .988 r
.47655 .43565 .48261 .43777 .49328 .43422 .48727 .43204 Mtetra
.583 .891 .989 r
.48727 .43204 .49328 .43422 .504 .43072 .49803 .42852 Mtetra
.576 .888 .99 r
.49803 .42852 .504 .43072 .51476 .42728 .50883 .42509 Mtetra
.566 .886 .99 r
.50883 .42509 .51476 .42728 .52556 .42389 .51967 .42175 Mtetra
.555 .884 .989 r
.51967 .42175 .52556 .42389 .53641 .42057 .53056 .4185 Mtetra
.542 .882 .987 r
.53056 .4185 .53641 .42057 .5473 .4173 .5415 .41533 Mtetra
.527 .879 .985 r
.5415 .41533 .5473 .4173 .55824 .4141 .55248 .41224 Mtetra
.511 .877 .981 r
.55248 .41224 .55824 .4141 .56922 .41097 .56351 .40924 Mtetra
.496 .874 .976 r
.56351 .40924 .56922 .41097 .58025 .4079 .57459 .40628 Mtetra
.482 .871 .971 r
.57459 .40628 .58025 .4079 .59134 .40491 .58572 .40337 Mtetra
.474 .87 .966 r
.58572 .40337 .59134 .40491 .60247 .40196 .5969 .40045 Mtetra
.474 .871 .965 r
.5969 .40045 .60247 .40196 .61365 .39906 .60813 .39749 Mtetra
.487 .876 .968 r
.60813 .39749 .61365 .39906 .62488 .39616 .6194 .3944 Mtetra
.515 .884 .975 r
.6194 .3944 .62488 .39616 .63616 .39323 .63072 .3911 Mtetra
.558 .892 .984 r
.63072 .3911 .63616 .39323 .64749 .39019 .64208 .38751 Mtetra
.609 .894 .988 r
.64208 .38751 .64749 .39019 .65887 .38697 .65347 .38351 Mtetra
.657 .881 .981 r
.65347 .38351 .65887 .38697 .67028 .38351 .66488 .37905 Mtetra
.695 .855 .959 r
.66488 .37905 .67028 .38351 .68172 .3797 .67631 .37406 Mtetra
.715 .817 .928 r
.67631 .37406 .68172 .3797 .69319 .37553 .68775 .36861 Mtetra
.723 .777 .895 r
.68775 .36861 .69319 .37553 .70468 .37093 .69921 .36276 Mtetra
.72 .74 .867 r
.69921 .36276 .70468 .37093 .7162 .366 .71069 .3567 Mtetra
.711 .709 .846 r
.71069 .3567 .7162 .366 .72773 .3608 .7222 .35063 Mtetra
.701 .686 .833 r
.7222 .35063 .72773 .3608 .7393 .35546 .73375 .34474 Mtetra
.688 .669 .827 r
.73375 .34474 .7393 .35546 .7509 .35015 .74537 .33925 Mtetra
.677 .662 .828 r
.74537 .33925 .7509 .35015 .76255 .34495 .75705 .33419 Mtetra
.664 .659 .835 r
.75705 .33419 .76255 .34495 .77426 .34002 .76882 .32965 Mtetra
.655 .664 .846 r
.76882 .32965 .77426 .34002 .78604 .33534 .78066 .32552 Mtetra
.647 .673 .861 r
.78066 .32552 .78604 .33534 .79788 .33095 .79258 .32175 Mtetra
.641 .686 .877 r
.79258 .32175 .79788 .33095 .80978 .32676 .80458 .31821 Mtetra
.637 .703 .894 r
.80458 .31821 .80978 .32676 .82175 .32272 .81664 .31482 Mtetra
.635 .722 .911 r
.81664 .31482 .82175 .32272 .83378 .31877 .82876 .31146 Mtetra
.697 .76 .901 r
.18679 .51429 .19348 .52013 .20314 .5164 .19653 .51003 Mtetra
.696 .744 .888 r
.19653 .51003 .20314 .5164 .21283 .5127 .20629 .5057 Mtetra
.692 .725 .875 r
.20629 .5057 .21283 .5127 .22254 .50914 .21609 .50139 Mtetra
.684 .703 .861 r
.21609 .50139 .22254 .50914 .23226 .50581 .2259 .49721 Mtetra
.674 .679 .847 r
.2259 .49721 .23226 .50581 .24199 .50283 .23573 .49321 Mtetra
.659 .651 .832 r
.23573 .49321 .24199 .50283 .25172 .50024 .24556 .48955 Mtetra
.64 .623 .817 r
.24556 .48955 .25172 .50024 .26145 .49817 .25539 .48638 Mtetra
.621 .596 .803 r
.25539 .48638 .26145 .49817 .27119 .4965 .2652 .48376 Mtetra
.601 .571 .793 r
.2652 .48376 .27119 .4965 .28095 .49524 .27501 .48181 Mtetra
.584 .553 .786 r
.27501 .48181 .28095 .49524 .29075 .49415 .28482 .48041 Mtetra
.57 .541 .784 r
.28482 .48041 .29075 .49415 .30059 .49307 .29465 .47952 Mtetra
.562 .54 .788 r
.29465 .47952 .30059 .49307 .31049 .4918 .3045 .47888 Mtetra
.559 .549 .8 r
.3045 .47888 .31049 .4918 .32047 .49015 .31441 .47832 Mtetra
.562 .569 .819 r
.31441 .47832 .32047 .49015 .33053 .48805 .32438 .47762 Mtetra
.571 .602 .845 r
.32438 .47762 .33053 .48805 .34065 .48545 .33443 .47658 Mtetra
.582 .645 .878 r
.33443 .47658 .34065 .48545 .35084 .4824 .34454 .47515 Mtetra
.596 .698 .914 r
.34454 .47515 .35084 .4824 .3611 .47896 .35474 .47324 Mtetra
.605 .754 .949 r
.35474 .47324 .3611 .47896 .3714 .47523 .365 .47089 Mtetra
.609 .81 .977 r
.365 .47089 .3714 .47523 .38175 .47129 .37532 .46813 Mtetra
.603 .855 .992 r
.37532 .46813 .38175 .47129 .39214 .46724 .38571 .46503 Mtetra
.587 .886 .991 r
.38571 .46503 .39214 .46724 .40257 .46313 .39615 .46168 Mtetra
.563 .901 .979 r
.39615 .46168 .40257 .46313 .41303 .45902 .40663 .45813 Mtetra
.537 .906 .96 r
.40663 .45813 .41303 .45902 .42353 .45494 .41716 .45447 Mtetra
.511 .903 .94 r
.41716 .45447 .42353 .45494 .43406 .45093 .42773 .45074 Mtetra
.487 .896 .921 r
.42773 .45074 .43406 .45093 .44463 .44698 .43833 .44698 Mtetra
.467 .888 .906 r
.43833 .44698 .44463 .44698 .45523 .44312 .44898 .44324 Mtetra
.449 .881 .894 r
.44898 .44324 .45523 .44312 .46587 .43934 .45967 .43952 Mtetra
.435 .873 .885 r
.45967 .43952 .46587 .43934 .47655 .43565 .4704 .43586 Mtetra
.422 .867 .879 r
.4704 .43586 .47655 .43565 .48727 .43204 .48116 .43225 Mtetra
.411 .861 .875 r
.48116 .43225 .48727 .43204 .49803 .42852 .49197 .42872 Mtetra
.402 .856 .872 r
.49197 .42872 .49803 .42852 .50883 .42509 .50282 .42525 Mtetra
.396 .853 .872 r
.50282 .42525 .50883 .42509 .51967 .42175 .51372 .42184 Mtetra
.394 .851 .875 r
.51372 .42184 .51967 .42175 .53056 .4185 .52466 .41848 Mtetra
.397 .853 .881 r
.52466 .41848 .53056 .4185 .5415 .41533 .53564 .41515 Mtetra
.408 .858 .892 r
.53564 .41515 .5415 .41533 .55248 .41224 .54667 .41184 Mtetra
.429 .867 .909 r
.54667 .41184 .55248 .41224 .56351 .40924 .55775 .4085 Mtetra
.461 .879 .932 r
.55775 .4085 .56351 .40924 .57459 .40628 .56887 .40509 Mtetra
.505 .892 .957 r
.56887 .40509 .57459 .40628 .58572 .40337 .58004 .40155 Mtetra
.558 .9 .979 r
.58004 .40155 .58572 .40337 .5969 .40045 .59125 .39783 Mtetra
.612 .894 .988 r
.59125 .39783 .5969 .40045 .60813 .39749 .6025 .39384 Mtetra
.658 .872 .979 r
.6025 .39384 .60813 .39749 .6194 .3944 .61378 .38951 Mtetra
.69 .834 .952 r
.61378 .38951 .6194 .3944 .63072 .3911 .62509 .38475 Mtetra
.707 .787 .914 r
.62509 .38475 .63072 .3911 .64208 .38751 .63642 .37954 Mtetra
.713 .74 .873 r
.63642 .37954 .64208 .38751 .65347 .38351 .64777 .37383 Mtetra
.71 .697 .836 r
.64777 .37383 .65347 .38351 .66488 .37905 .65914 .3677 Mtetra
.705 .663 .806 r
.65914 .3677 .66488 .37905 .67631 .37406 .67052 .36121 Mtetra
.696 .635 .784 r
.67052 .36121 .67631 .37406 .68775 .36861 .68192 .35458 Mtetra
.687 .615 .77 r
.68192 .35458 .68775 .36861 .69921 .36276 .69335 .348 Mtetra
.678 .601 .763 r
.69335 .348 .69921 .36276 .71069 .3567 .70483 .34168 Mtetra
.667 .593 .763 r
.70483 .34168 .71069 .3567 .7222 .35063 .71636 .33588 Mtetra
.659 .592 .769 r
.71636 .33588 .7222 .35063 .73375 .34474 .72797 .33063 Mtetra
.648 .595 .781 r
.72797 .33063 .73375 .34474 .74537 .33925 .73966 .32607 Mtetra
.64 .605 .798 r
.73966 .32607 .74537 .33925 .75705 .33419 .75143 .32209 Mtetra
.632 .619 .819 r
.75143 .32209 .75705 .33419 .76882 .32965 .7633 .3186 Mtetra
.626 .636 .841 r
.7633 .3186 .76882 .32965 .78066 .32552 .77524 .31548 Mtetra
.621 .657 .864 r
.77524 .31548 .78066 .32552 .79258 .32175 .78726 .31255 Mtetra
.617 .677 .884 r
.78726 .31255 .79258 .32175 .80458 .31821 .79935 .30974 Mtetra
.615 .696 .902 r
.79935 .30974 .80458 .31821 .81664 .31482 .8115 .30695 Mtetra
.615 .716 .917 r
.8115 .30695 .81664 .31482 .82876 .31146 .82371 .3041 Mtetra
.704 .761 .896 r
.18006 .50842 .18679 .51429 .19653 .51003 .18984 .5039 Mtetra
.708 .755 .889 r
.18984 .5039 .19653 .51003 .20629 .5057 .19967 .4992 Mtetra
.71 .745 .879 r
.19967 .4992 .20629 .5057 .21609 .50139 .20953 .49438 Mtetra
.709 .73 .867 r
.20953 .49438 .21609 .50139 .2259 .49721 .21943 .48944 Mtetra
.707 .71 .851 r
.21943 .48944 .2259 .49721 .23573 .49321 .22937 .48439 Mtetra
.697 .683 .833 r
.22937 .48439 .23573 .49321 .24556 .48955 .23933 .47943 Mtetra
.682 .652 .814 r
.23933 .47943 .24556 .48955 .25539 .48638 .24929 .47469 Mtetra
.662 .617 .793 r
.24929 .47469 .25539 .48638 .2652 .48376 .25924 .47041 Mtetra
.638 .582 .775 r
.25924 .47041 .2652 .48376 .27501 .48181 .26917 .46684 Mtetra
.614 .55 .759 r
.26917 .46684 .27501 .48181 .28482 .48041 .27908 .46408 Mtetra
.589 .522 .747 r
.27908 .46408 .28482 .48041 .29465 .47952 .28895 .46228 Mtetra
.569 .502 .74 r
.28895 .46228 .29465 .47952 .3045 .47888 .29882 .4613 Mtetra
.552 .489 .738 r
.29882 .4613 .3045 .47888 .31441 .47832 .30868 .46104 Mtetra
.542 .486 .743 r
.30868 .46104 .31441 .47832 .32438 .47762 .31858 .46118 Mtetra
.537 .492 .753 r
.31858 .46118 .32438 .47762 .33443 .47658 .32853 .46148 Mtetra
.538 .508 .771 r
.32853 .46148 .33443 .47658 .34454 .47515 .33855 .46167 Mtetra
.545 .535 .795 r
.33855 .46167 .34454 .47515 .35474 .47324 .34865 .46152 Mtetra
.555 .571 .825 r
.34865 .46152 .35474 .47324 .365 .47089 .35882 .46095 Mtetra
.569 .616 .859 r
.35882 .46095 .365 .47089 .37532 .46813 .36908 .45985 Mtetra
.583 .665 .895 r
.36908 .45985 .37532 .46813 .38571 .46503 .37942 .45827 Mtetra
.596 .718 .929 r
.37942 .45827 .38571 .46503 .39615 .46168 .38982 .45621 Mtetra
.603 .768 .958 r
.38982 .45621 .39615 .46168 .40663 .45813 .40029 .45376 Mtetra
.605 .812 .979 r
.40029 .45376 .40663 .45813 .41716 .45447 .41082 .45097 Mtetra
.6 .846 .991 r
.41082 .45097 .41716 .45447 .42773 .45074 .4214 .44794 Mtetra
.59 .87 .994 r
.4214 .44794 .42773 .45074 .43833 .44698 .43203 .44472 Mtetra
.578 .885 .991 r
.43203 .44472 .43833 .44698 .44898 .44324 .44271 .44136 Mtetra
.564 .893 .986 r
.44271 .44136 .44898 .44324 .45967 .43952 .45344 .43791 Mtetra
.552 .897 .979 r
.45344 .43791 .45967 .43952 .4704 .43586 .4642 .43441 Mtetra
.543 .898 .974 r
.4642 .43441 .4704 .43586 .48116 .43225 .47501 .43087 Mtetra
.538 .898 .971 r
.47501 .43087 .48116 .43225 .49197 .42872 .48587 .42732 Mtetra
.539 .899 .971 r
.48587 .42732 .49197 .42872 .50282 .42525 .49676 .42373 Mtetra
.546 .899 .974 r
.49676 .42373 .50282 .42525 .51372 .42184 .5077 .42012 Mtetra
.56 .9 .979 r
.5077 .42012 .51372 .42184 .52466 .41848 .51869 .41645 Mtetra
.581 .899 .985 r
.51869 .41645 .52466 .41848 .53564 .41515 .52972 .41268 Mtetra
.607 .895 .988 r
.52972 .41268 .53564 .41515 .54667 .41184 .54079 .40879 Mtetra
.636 .884 .986 r
.54079 .40879 .54667 .41184 .55775 .4085 .5519 .4047 Mtetra
.665 .865 .975 r
.5519 .4047 .55775 .4085 .56887 .40509 .56305 .40034 Mtetra
.689 .836 .954 r
.56305 .40034 .56887 .40509 .58004 .40155 .57424 .39566 Mtetra
.705 .799 .923 r
.57424 .39566 .58004 .40155 .59125 .39783 .58545 .39056 Mtetra
.714 .758 .887 r
.58545 .39056 .59125 .39783 .6025 .39384 .5967 .38498 Mtetra
.716 .717 .85 r
.5967 .38498 .6025 .39384 .61378 .38951 .60796 .37889 Mtetra
.714 .679 .814 r
.60796 .37889 .61378 .38951 .62509 .38475 .61923 .37225 Mtetra
.707 .644 .784 r
.61923 .37225 .62509 .38475 .63642 .37954 .63052 .36517 Mtetra
.7 .616 .76 r
.63052 .36517 .63642 .37954 .64777 .37383 .64182 .35773 Mtetra
.69 .592 .742 r
.64182 .35773 .64777 .37383 .65914 .3677 .65313 .35017 Mtetra
.679 .573 .729 r
.65313 .35017 .65914 .3677 .67052 .36121 .66447 .34275 Mtetra
.668 .559 .723 r
.66447 .34275 .67052 .36121 .68192 .35458 .67584 .33573 Mtetra
.655 .549 .723 r
.67584 .33573 .68192 .35458 .69335 .348 .68729 .32945 Mtetra
.644 .546 .728 r
.68729 .32945 .69335 .348 .70483 .34168 .6988 .32398 Mtetra
.631 .546 .74 r
.6988 .32398 .70483 .34168 .71636 .33588 .71041 .31952 Mtetra
.621 .553 .757 r
.71041 .31952 .71636 .33588 .72797 .33063 .72212 .31589 Mtetra
.611 .567 .781 r
.72212 .31589 .72797 .33063 .73966 .32607 .73393 .31299 Mtetra
.602 .587 .808 r
.73393 .31299 .73966 .32607 .75143 .32209 .74583 .31058 Mtetra
.598 .613 .838 r
.74583 .31058 .75143 .32209 .7633 .3186 .75781 .30839 Mtetra
.594 .64 .866 r
.75781 .30839 .7633 .3186 .77524 .31548 .76986 .3063 Mtetra
.596 .668 .89 r
.76986 .3063 .77524 .31548 .78726 .31255 .78197 .3041 Mtetra
.597 .69 .907 r
.78197 .3041 .78726 .31255 .79935 .30974 .79413 .30178 Mtetra
.6 .707 .919 r
.79413 .30178 .79935 .30974 .8115 .30695 .80635 .29932 Mtetra
.604 .72 .927 r
.80635 .29932 .8115 .30695 .82371 .3041 .81861 .29669 Mtetra
.69 .759 .904 r
.17328 .5025 .18006 .50842 .18984 .5039 .18304 .49838 Mtetra
.698 .774 .911 r
.18304 .49838 .18984 .5039 .19967 .4992 .19285 .49407 Mtetra
.707 .79 .916 r
.19285 .49407 .19967 .4992 .20953 .49438 .20272 .48953 Mtetra
.717 .802 .917 r
.20272 .48953 .20953 .49438 .21943 .48944 .21263 .48469 Mtetra
.73 .807 .913 r
.21263 .48469 .21943 .48944 .22937 .48439 .22261 .47947 Mtetra
.737 .803 .905 r
.22261 .47947 .22937 .48439 .23933 .47943 .23264 .47398 Mtetra
.741 .787 .89 r
.23264 .47398 .23933 .47943 .24929 .47469 .24272 .46825 Mtetra
.733 .756 .871 r
.24272 .46825 .24929 .47469 .25924 .47041 .25281 .46252 Mtetra
.717 .714 .846 r
.25281 .46252 .25924 .47041 .26917 .46684 .26291 .45698 Mtetra
.691 .663 .817 r
.26291 .45698 .26917 .46684 .27908 .46408 .273 .4519 Mtetra
.66 .611 .788 r
.273 .4519 .27908 .46408 .28895 .46228 .28307 .44755 Mtetra
.631 .563 .76 r
.28307 .44755 .28895 .46228 .29882 .4613 .2931 .44402 Mtetra
.602 .521 .736 r
.2931 .44402 .29882 .4613 .30868 .46104 .30311 .44145 Mtetra
.581 .49 .716 r
.30311 .44145 .30868 .46104 .31858 .46118 .31311 .43971 Mtetra
.565 .467 .703 r
.31311 .43971 .31858 .46118 .32853 .46148 .32311 .43872 Mtetra
.555 .454 .694 r
.32311 .43872 .32853 .46148 .33855 .46167 .33313 .43822 Mtetra
.55 .447 .69 r
.33313 .43822 .33855 .46167 .34865 .46152 .34319 .43802 Mtetra
.548 .446 .69 r
.34319 .43802 .34865 .46152 .35882 .46095 .35331 .43788 Mtetra
.55 .45 .694 r
.35331 .43788 .35882 .46095 .36908 .45985 .36349 .43762 Mtetra
.555 .458 .7 r
.36349 .43762 .36908 .45985 .37942 .45827 .37375 .43714 Mtetra
.561 .47 .708 r
.37375 .43714 .37942 .45827 .38982 .45621 .38407 .43633 Mtetra
.569 .484 .719 r
.38407 .43633 .38982 .45621 .40029 .45376 .39447 .43516 Mtetra
.578 .5 .73 r
.39447 .43516 .40029 .45376 .41082 .45097 .40494 .43362 Mtetra
.587 .516 .743 r
.40494 .43362 .41082 .45097 .4214 .44794 .41547 .43172 Mtetra
.596 .534 .755 r
.41547 .43172 .4214 .44794 .43203 .44472 .42607 .42948 Mtetra
.605 .55 .766 r
.42607 .42948 .43203 .44472 .44271 .44136 .43672 .42693 Mtetra
.614 .565 .776 r
.43672 .42693 .44271 .44136 .45344 .43791 .44743 .42409 Mtetra
.621 .577 .783 r
.44743 .42409 .45344 .43791 .4642 .43441 .45819 .42098 Mtetra
.628 .587 .788 r
.45819 .42098 .4642 .43441 .47501 .43087 .469 .41763 Mtetra
.634 .593 .79 r
.469 .41763 .47501 .43087 .48587 .42732 .47986 .41404 Mtetra
.639 .595 .789 r
.47986 .41404 .48587 .42732 .49676 .42373 .49077 .41021 Mtetra
.644 .594 .784 r
.49077 .41021 .49676 .42373 .5077 .42012 .50172 .40613 Mtetra
.647 .59 .777 r
.50172 .40613 .5077 .42012 .51869 .41645 .51271 .40178 Mtetra
.649 .583 .767 r
.51271 .40178 .51869 .41645 .52972 .41268 .52374 .39714 Mtetra
.651 .575 .756 r
.52374 .39714 .52972 .41268 .54079 .40879 .5348 .39218 Mtetra
.652 .565 .744 r
.5348 .39218 .54079 .40879 .5519 .4047 .5459 .38687 Mtetra
.652 .554 .731 r
.5459 .38687 .5519 .4047 .56305 .40034 .55703 .3812 Mtetra
.652 .543 .719 r
.55703 .3812 .56305 .40034 .57424 .39566 .56819 .37513 Mtetra
.651 .533 .707 r
.56819 .37513 .57424 .39566 .58545 .39056 .57937 .36869 Mtetra
.65 .525 .697 r
.57937 .36869 .58545 .39056 .5967 .38498 .59057 .36191 Mtetra
.648 .517 .69 r
.59057 .36191 .5967 .38498 .60796 .37889 .60178 .35488 Mtetra
.646 .511 .684 r
.60178 .35488 .60796 .37889 .61923 .37225 .61302 .34772 Mtetra
.643 .507 .681 r
.61302 .34772 .61923 .37225 .63052 .36517 .62428 .34062 Mtetra
.64 .505 .682 r
.62428 .34062 .63052 .36517 .64182 .35773 .63557 .3338 Mtetra
.636 .505 .686 r
.63557 .3338 .64182 .35773 .65313 .35017 .64691 .32747 Mtetra
.63 .508 .696 r
.64691 .32747 .65313 .35017 .66447 .34275 .65831 .32191 Mtetra
.624 .516 .711 r
.65831 .32191 .66447 .34275 .67584 .33573 .66978 .31719 Mtetra
.616 .529 .733 r
.66978 .31719 .67584 .33573 .68729 .32945 .68134 .31346 Mtetra
.607 .549 .764 r
.68134 .31346 .68729 .32945 .6988 .32398 .693 .31058 Mtetra
.595 .577 .804 r
.693 .31058 .6988 .32398 .71041 .31952 .70476 .30845 Mtetra
.581 .613 .849 r
.70476 .30845 .71041 .31952 .72212 .31589 .71661 .3068 Mtetra
.568 .655 .895 r
.71661 .3068 .72212 .31589 .73393 .31299 .72854 .30535 Mtetra
.556 .694 .931 r
.72854 .30535 .73393 .31299 .74583 .31058 .74054 .30391 Mtetra
.555 .728 .955 r
.74054 .30391 .74583 .31058 .75781 .30839 .75259 .30223 Mtetra
.561 .75 .966 r
.75259 .30223 .75781 .30839 .76986 .3063 .76469 .30026 Mtetra
.577 .763 .967 r
.76469 .30026 .76986 .3063 .78197 .3041 .77683 .2979 Mtetra
.593 .766 .962 r
.77683 .2979 .78197 .3041 .79413 .30178 .789 .29524 Mtetra
.607 .76 .952 r
.789 .29524 .79413 .30178 .80635 .29932 .80122 .29232 Mtetra
.618 .75 .94 r
.80122 .29232 .80635 .29932 .81861 .29669 .81347 .28921 Mtetra
.655 .751 .92 r
.16646 .49655 .17328 .5025 .18304 .49838 .17615 .49331 Mtetra
.659 .784 .941 r
.17615 .49331 .18304 .49838 .19285 .49407 .18588 .48994 Mtetra
.665 .821 .958 r
.18588 .48994 .19285 .49407 .20272 .48953 .19568 .48632 Mtetra
.675 .859 .97 r
.19568 .48632 .20272 .48953 .21263 .48469 .20555 .48232 Mtetra
.69 .893 .971 r
.20555 .48232 .21263 .48469 .22261 .47947 .2155 .4778 Mtetra
.708 .92 .965 r
.2155 .4778 .22261 .47947 .23264 .47398 .22553 .4727 Mtetra
.735 .935 .953 r
.22553 .4727 .23264 .47398 .24272 .46825 .23565 .46689 Mtetra
.762 .934 .941 r
.23565 .46689 .24272 .46825 .25281 .46252 .24584 .46049 Mtetra
.788 .91 .925 r
.24584 .46049 .25281 .46252 .26291 .45698 .2561 .4535 Mtetra
.791 .859 .9 r
.2561 .4535 .26291 .45698 .273 .4519 .26639 .44625 Mtetra
.775 .788 .864 r
.26639 .44625 .273 .4519 .28307 .44755 .2767 .43898 Mtetra
.739 .707 .821 r
.2767 .43898 .28307 .44755 .2931 .44402 .287 .43209 Mtetra
.698 .632 .78 r
.287 .43209 .2931 .44402 .30311 .44145 .29726 .42593 Mtetra
.659 .57 .744 r
.29726 .42593 .30311 .44145 .31311 .43971 .30748 .42071 Mtetra
.624 .521 .716 r
.30748 .42071 .31311 .43971 .32311 .43872 .31765 .41663 Mtetra
.598 .485 .696 r
.31765 .41663 .32311 .43872 .33313 .43822 .3278 .41361 Mtetra
.578 .459 .681 r
.3278 .41361 .33313 .43822 .34319 .43802 .33793 .41159 Mtetra
.565 .442 .672 r
.33793 .41159 .34319 .43802 .35331 .43788 .34806 .41029 Mtetra
.556 .432 .666 r
.34806 .41029 .35331 .43788 .36349 .43762 .35822 .40952 Mtetra
.552 .427 .664 r
.35822 .40952 .36349 .43762 .37375 .43714 .36842 .40903 Mtetra
.551 .427 .664 r
.36842 .40903 .37375 .43714 .38407 .43633 .37868 .40859 Mtetra
.552 .43 .667 r
.37868 .40859 .38407 .43633 .39447 .43516 .38901 .40806 Mtetra
.556 .435 .67 r
.38901 .40806 .39447 .43516 .40494 .43362 .3994 .40729 Mtetra
.561 .442 .675 r
.3994 .40729 .40494 .43362 .41547 .43172 .40986 .4062 Mtetra
.568 .45 .679 r
.40986 .4062 .41547 .43172 .42607 .42948 .42039 .40474 Mtetra
.575 .459 .684 r
.42039 .40474 .42607 .42948 .43672 .42693 .43099 .40286 Mtetra
.582 .467 .688 r
.43099 .40286 .43672 .42693 .44743 .42409 .44165 .40055 Mtetra
.59 .475 .691 r
.44165 .40055 .44743 .42409 .45819 .42098 .45238 .39781 Mtetra
.597 .482 .693 r
.45238 .39781 .45819 .42098 .469 .41763 .46316 .39462 Mtetra
.604 .488 .694 r
.46316 .39462 .469 .41763 .47986 .41404 .47399 .39099 Mtetra
.61 .491 .693 r
.47399 .39099 .47986 .41404 .49077 .41021 .48487 .38691 Mtetra
.615 .494 .691 r
.48487 .38691 .49077 .41021 .50172 .40613 .4958 .38239 Mtetra
.62 .495 .688 r
.4958 .38239 .50172 .40613 .51271 .40178 .50676 .37742 Mtetra
.624 .494 .684 r
.50676 .37742 .51271 .40178 .52374 .39714 .51776 .37202 Mtetra
.627 .492 .679 r
.51776 .37202 .52374 .39714 .5348 .39218 .5288 .36619 Mtetra
.629 .49 .674 r
.5288 .36619 .5348 .39218 .5459 .38687 .53986 .35997 Mtetra
.63 .487 .669 r
.53986 .35997 .5459 .38687 .55703 .3812 .55095 .35342 Mtetra
.63 .484 .665 r
.55095 .35342 .55703 .3812 .56819 .37513 .56205 .34662 Mtetra
.629 .481 .662 r
.56205 .34662 .56819 .37513 .57937 .36869 .57319 .33972 Mtetra
.627 .478 .66 r
.57319 .33972 .57937 .36869 .59057 .36191 .58434 .33286 Mtetra
.624 .475 .66 r
.58434 .33286 .59057 .36191 .60178 .35488 .59552 .32627 Mtetra
.619 .474 .663 r
.59552 .32627 .60178 .35488 .61302 .34772 .60675 .3202 Mtetra
.613 .474 .669 r
.60675 .3202 .61302 .34772 .62428 .34062 .61802 .31487 Mtetra
.605 .477 .679 r
.61802 .31487 .62428 .34062 .63557 .3338 .62937 .31056 Mtetra
.596 .484 .696 r
.62937 .31056 .63557 .3338 .64691 .32747 .6408 .30731 Mtetra
.582 .496 .722 r
.6408 .30731 .64691 .32747 .65831 .32191 .65233 .30526 Mtetra
.567 .519 .761 r
.65233 .30526 .65831 .32191 .66978 .31719 .66396 .30417 Mtetra
.544 .555 .817 r
.66396 .30417 .66978 .31719 .68134 .31346 .6757 .30384 Mtetra
.51 .61 .888 r
.6757 .30384 .68134 .31346 .693 .31058 .68754 .30391 Mtetra
.461 .679 .959 r
.68754 .30391 .693 .31058 .70476 .30845 .69945 .30397 Mtetra
.395 .733 .991 r
.69945 .30397 .70476 .30845 .71661 .3068 .71143 .30378 Mtetra
.356 .768 .98 r
.71143 .30378 .71661 .3068 .72854 .30535 .72345 .30298 Mtetra
.361 .794 .967 r
.72345 .30298 .72854 .30535 .74054 .30391 .7355 .30158 Mtetra
.42 .829 .975 r
.7355 .30158 .74054 .30391 .75259 .30223 .74758 .29944 Mtetra
.495 .853 .991 r
.74758 .29944 .75259 .30223 .76469 .30026 .75967 .2967 Mtetra
.566 .859 .997 r
.75967 .2967 .76469 .30026 .77683 .2979 .77178 .29341 Mtetra
.614 .844 .987 r
.77178 .29341 .77683 .2979 .789 .29524 .78392 .28973 Mtetra
.642 .816 .967 r
.78392 .28973 .789 .29524 .80122 .29232 .79609 .28577 Mtetra
.654 .783 .943 r
.79609 .28577 .80122 .29232 .81347 .28921 .8083 .28168 Mtetra
.61 .739 .937 r
.15958 .49055 .16646 .49655 .17615 .49331 .16919 .48827 Mtetra
.602 .773 .962 r
.16919 .48827 .17615 .49331 .18588 .48994 .17884 .48595 Mtetra
.595 .812 .983 r
.17884 .48595 .18588 .48994 .19568 .48632 .18854 .48348 Mtetra
.583 .853 .995 r
.18854 .48348 .19568 .48632 .20555 .48232 .19832 .48075 Mtetra
.563 .89 .987 r
.19832 .48075 .20555 .48232 .2155 .4778 .20817 .47763 Mtetra
.528 .909 .945 r
.20817 .47763 .2155 .4778 .22553 .4727 .2181 .47398 Mtetra
.483 .9 .863 r
.2181 .47398 .22553 .4727 .23565 .46689 .22814 .46965 Mtetra
.426 .86 .751 r
.22814 .46965 .23565 .46689 .24584 .46049 .23827 .46457 Mtetra
.388 .816 .647 r
.23827 .46457 .24584 .46049 .2561 .4535 .24849 .45864 Mtetra
0 0 0 r
.24849 .45864 .2561 .4535 .26639 .44625 .2588 .45198 Mtetra
.2588 .45198 .26639 .44625 .2767 .43898 .26918 .44465 Mtetra
.26918 .44465 .2767 .43898 .287 .43209 .27961 .43695 Mtetra
.493 .863 .637 r
.27961 .43695 .287 .43209 .29726 .42593 .29005 .42914 Mtetra
.616 .948 .774 r
.29005 .42914 .29726 .42593 .30748 .42071 .30049 .42153 Mtetra
.726 .984 .902 r
.30049 .42153 .30748 .42071 .31765 .41663 .31091 .41443 Mtetra
.764 .915 .94 r
.31091 .41443 .31765 .41663 .3278 .41361 .3213 .40798 Mtetra
.733 .792 .899 r
.3213 .40798 .3278 .41361 .33793 .41159 .33167 .40234 Mtetra
.689 .681 .838 r
.33167 .40234 .33793 .41159 .34806 .41029 .34201 .39745 Mtetra
.65 .601 .786 r
.34201 .39745 .34806 .41029 .35822 .40952 .35235 .3933 Mtetra
.623 .546 .747 r
.35235 .3933 .35822 .40952 .36842 .40903 .3627 .38974 Mtetra
.605 .509 .719 r
.3627 .38974 .36842 .40903 .37868 .40859 .37306 .38663 Mtetra
.593 .484 .699 r
.37306 .38663 .37868 .40859 .38901 .40806 .38345 .38383 Mtetra
.586 .468 .685 r
.38345 .38383 .38901 .40806 .3994 .40729 .39388 .38119 Mtetra
.582 .457 .674 r
.39388 .38119 .3994 .40729 .40986 .4062 .40436 .37862 Mtetra
.581 .45 .667 r
.40436 .37862 .40986 .4062 .42039 .40474 .41488 .376 Mtetra
.58 .445 .662 r
.41488 .376 .42039 .40474 .43099 .40286 .42546 .37326 Mtetra
.582 .443 .658 r
.42546 .37326 .43099 .40286 .44165 .40055 .43609 .37034 Mtetra
.583 .443 .656 r
.43609 .37034 .44165 .40055 .45238 .39781 .44677 .36719 Mtetra
.586 .443 .654 r
.44677 .36719 .45238 .39781 .46316 .39462 .4575 .36378 Mtetra
.588 .445 .653 r
.4575 .36378 .46316 .39462 .47399 .39099 .46828 .3601 Mtetra
.591 .447 .653 r
.46828 .3601 .47399 .39099 .48487 .38691 .4791 .35615 Mtetra
.594 .449 .654 r
.4791 .35615 .48487 .38691 .4958 .38239 .48997 .35194 Mtetra
.597 .452 .655 r
.48997 .35194 .4958 .38239 .50676 .37742 .50088 .3475 Mtetra
.601 .456 .657 r
.50088 .3475 .50676 .37742 .51776 .37202 .51183 .34287 Mtetra
.603 .461 .66 r
.51183 .34287 .51776 .37202 .5288 .36619 .52282 .33812 Mtetra
.606 .467 .665 r
.52282 .33812 .5288 .36619 .53986 .35997 .53385 .33332 Mtetra
.609 .474 .672 r
.53385 .33332 .53986 .35997 .55095 .35342 .54491 .32857 Mtetra
.611 .483 .682 r
.54491 .32857 .55095 .35342 .56205 .34662 .55601 .32399 Mtetra
.612 .496 .697 r
.55601 .32399 .56205 .34662 .57319 .33972 .56716 .31971 Mtetra
.612 .514 .718 r
.56716 .31971 .57319 .33972 .58434 .33286 .57836 .31591 Mtetra
.611 .539 .749 r
.57836 .31591 .58434 .33286 .59552 .32627 .58961 .31269 Mtetra
.603 .576 .797 r
.58961 .31269 .59552 .32627 .60675 .3202 .60093 .31022 Mtetra
.581 .635 .869 r
.60093 .31022 .60675 .3202 .61802 .31487 .61234 .30853 Mtetra
.508 .713 .964 r
.61234 .30853 .61802 .31487 .62937 .31056 .62383 .30767 Mtetra
.292 .733 .964 r
.62383 .30767 .62937 .31056 .6408 .30731 .63541 .30749 Mtetra
.053 0 0 r
.63541 .30749 .6408 .30731 .65233 .30526 .64709 .30784 Mtetra
.253 0 0 r
.64709 .30784 .65233 .30526 .66396 .30417 .65886 .30842 Mtetra
.323 0 0 r
.65886 .30842 .66396 .30417 .6757 .30384 .67071 .30889 Mtetra
.33 0 0 r
.67071 .30889 .6757 .30384 .68754 .30391 .68262 .309 Mtetra
.291 0 0 r
.68262 .309 .68754 .30391 .69945 .30397 .69458 .30842 Mtetra
.216 0 0 r
.69458 .30842 .69945 .30397 .71143 .30378 .70656 .30709 Mtetra
.083 0 0 r
.70656 .30709 .71143 .30378 .72345 .30298 .71857 .30488 Mtetra
0 0 0 r
.71857 .30488 .72345 .30298 .7355 .30158 .73059 .3019 Mtetra
.327 .812 .81 r
.73059 .3019 .7355 .30158 .74758 .29944 .74262 .2982 Mtetra
.509 .902 .939 r
.74262 .2982 .74758 .29944 .75967 .2967 .75466 .29395 Mtetra
.617 .91 .982 r
.75466 .29395 .75967 .2967 .77178 .29341 .76672 .2893 Mtetra
.668 .88 .977 r
.76672 .2893 .77178 .29341 .78392 .28973 .7788 .28435 Mtetra
.688 .84 .956 r
.7788 .28435 .78392 .28973 .79609 .28577 .79092 .27924 Mtetra
.692 .8 .932 r
.79092 .27924 .79609 .28577 .8083 .28168 .80308 .27409 Mtetra
.567 .725 .948 r
.15266 .48451 .15958 .49055 .16919 .48827 .1622 .48298 Mtetra
.551 .748 .969 r
.1622 .48298 .16919 .48827 .17884 .48595 .17178 .4815 Mtetra
.529 .775 .987 r
.17178 .4815 .17884 .48595 .18854 .48348 .1814 .48004 Mtetra
.497 .803 .999 r
.1814 .48004 .18854 .48348 .19832 .48075 .19108 .47854 Mtetra
.436 .821 .988 r
.19108 .47854 .19832 .48075 .20817 .47763 .20081 .47696 Mtetra
.338 .808 .917 r
.20081 .47696 .20817 .47763 .2181 .47398 .2106 .47517 Mtetra
.191 .72 .744 r
.2106 .47517 .2181 .47398 .22814 .46965 .22047 .47307 Mtetra
0 0 0 r
.22047 .47307 .22814 .46965 .23827 .46457 .23043 .47047 Mtetra
.08 0 0 r
.23043 .47047 .23827 .46457 .24849 .45864 .24049 .46719 Mtetra
.151 0 0 r
.24049 .46719 .24849 .45864 .2588 .45198 .25066 .46307 Mtetra
.18 0 0 r
.25066 .46307 .2588 .45198 .26918 .44465 .26095 .45792 Mtetra
.191 0 .054 r
.26095 .45792 .26918 .44465 .27961 .43695 .27135 .45172 Mtetra
.177 0 .078 r
.27135 .45172 .27961 .43695 .29005 .42914 .28185 .44442 Mtetra
.151 0 .074 r
.28185 .44442 .29005 .42914 .30049 .42153 .29242 .43627 Mtetra
.1 0 .039 r
.29242 .43627 .30049 .42153 .31091 .41443 .30305 .42744 Mtetra
.017 0 0 r
.30305 .42744 .31091 .41443 .3213 .40798 .31371 .41833 Mtetra
0 0 0 r
.31371 .41833 .3213 .40798 .33167 .40234 .32437 .40925 Mtetra
.32437 .40925 .33167 .40234 .34201 .39745 .33501 .40048 Mtetra
.654 .963 .781 r
.33501 .40048 .34201 .39745 .35235 .3933 .34563 .39225 Mtetra
.79 .955 .923 r
.34563 .39225 .35235 .3933 .3627 .38974 .35623 .38465 Mtetra
.77 .82 .892 r
.35623 .38465 .3627 .38974 .37306 .38663 .36681 .37774 Mtetra
.723 .705 .833 r
.36681 .37774 .37306 .38663 .38345 .38383 .37738 .37147 Mtetra
.684 .626 .785 r
.37738 .37147 .38345 .38383 .39388 .38119 .38794 .36581 Mtetra
.656 .574 .751 r
.38794 .36581 .39388 .38119 .40436 .37862 .39851 .36065 Mtetra
.636 .539 .728 r
.39851 .36065 .40436 .37862 .41488 .376 .4091 .35592 Mtetra
.623 .516 .711 r
.4091 .35592 .41488 .376 .42546 .37326 .41971 .35151 Mtetra
.614 .499 .699 r
.41971 .35151 .42546 .37326 .43609 .37034 .43035 .34736 Mtetra
.608 .489 .692 r
.43035 .34736 .43609 .37034 .44677 .36719 .44102 .34338 Mtetra
.603 .482 .687 r
.44102 .34338 .44677 .36719 .4575 .36378 .45173 .33955 Mtetra
.601 .478 .685 r
.45173 .33955 .4575 .36378 .46828 .3601 .46248 .33583 Mtetra
.599 .477 .685 r
.46248 .33583 .46828 .3601 .4791 .35615 .47327 .33222 Mtetra
.597 .478 .688 r
.47327 .33222 .4791 .35615 .48997 .35194 .4841 .32876 Mtetra
.596 .481 .693 r
.4841 .32876 .48997 .35194 .50088 .3475 .49497 .32548 Mtetra
.595 .488 .702 r
.49497 .32548 .50088 .3475 .51183 .34287 .50589 .32245 Mtetra
.592 .497 .715 r
.50589 .32245 .51183 .34287 .52282 .33812 .51686 .31976 Mtetra
.589 .511 .735 r
.51686 .31976 .52282 .33812 .53385 .33332 .52788 .31749 Mtetra
.582 .534 .766 r
.52788 .31749 .53385 .33332 .54491 .32857 .53895 .31574 Mtetra
.567 .568 .814 r
.53895 .31574 .54491 .32857 .55601 .32399 .55009 .31461 Mtetra
.53 .624 .889 r
.55009 .31461 .55601 .32399 .56716 .31971 .56131 .31413 Mtetra
.411 .693 .978 r
.56131 .31413 .56716 .31971 .57836 .31591 .5726 .31438 Mtetra
.05 .603 .824 r
.5726 .31438 .57836 .31591 .58961 .31269 .58398 .31527 Mtetra
.321 0 0 r
.58398 .31527 .58961 .31269 .60093 .31022 .59546 .31674 Mtetra
.448 0 0 r
.59546 .31674 .60093 .31022 .61234 .30853 .60703 .31853 Mtetra
.484 .046 .129 r
.60703 .31853 .61234 .30853 .62383 .30767 .61869 .32038 Mtetra
.491 .083 .194 r
.61869 .32038 .62383 .30767 .63541 .30749 .63043 .32195 Mtetra
.481 .09 .221 r
.63043 .32195 .63541 .30749 .64709 .30784 .64224 .32285 Mtetra
.463 .078 .222 r
.64224 .32285 .64709 .30784 .65886 .30842 .6541 .32288 Mtetra
.432 .044 .201 r
.6541 .32288 .65886 .30842 .67071 .30889 .66599 .32178 Mtetra
.387 0 .154 r
.66599 .32178 .67071 .30889 .68262 .309 .67789 .31961 Mtetra
.314 0 .068 r
.67789 .31961 .68262 .309 .69458 .30842 .68981 .31638 Mtetra
.2 0 0 r
.68981 .31638 .69458 .30842 .70656 .30709 .70173 .31227 Mtetra
.012 0 0 r
.70173 .31227 .70656 .30709 .71857 .30488 .71366 .30746 Mtetra
0 0 0 r
.71366 .30746 .71857 .30488 .73059 .3019 .7256 .30211 Mtetra
.505 .911 .851 r
.7256 .30211 .73059 .3019 .74262 .2982 .73756 .29643 Mtetra
.649 .948 .953 r
.73756 .29643 .74262 .2982 .75466 .29395 .74954 .29052 Mtetra
.703 .916 .967 r
.74954 .29052 .75466 .29395 .76672 .2893 .76156 .28453 Mtetra
.72 .873 .953 r
.76156 .28453 .76672 .2893 .7788 .28435 .77361 .27848 Mtetra
.722 .835 .934 r
.77361 .27848 .7788 .28435 .79092 .27924 .78569 .27243 Mtetra
.718 .802 .917 r
.78569 .27243 .79092 .27924 .80308 .27409 .79782 .26643 Mtetra
.559 .723 .95 r
.14569 .47843 .15266 .48451 .1622 .48298 .15524 .477 Mtetra
.549 .724 .955 r
.15524 .477 .1622 .48298 .17178 .4815 .16481 .47569 Mtetra
.538 .727 .961 r
.16481 .47569 .17178 .4815 .1814 .48004 .17442 .4745 Mtetra
.524 .732 .969 r
.17442 .4745 .1814 .48004 .19108 .47854 .18407 .47342 Mtetra
.502 .741 .98 r
.18407 .47342 .19108 .47854 .20081 .47696 .19375 .47249 Mtetra
.476 .757 .992 r
.19375 .47249 .20081 .47696 .2106 .47517 .20348 .4716 Mtetra
.434 .775 .997 r
.20348 .4716 .2106 .47517 .22047 .47307 .21326 .47072 Mtetra
.375 .79 .979 r
.21326 .47072 .22047 .47307 .23043 .47047 .22311 .46967 Mtetra
.279 .772 .898 r
.22311 .46967 .23043 .47047 .24049 .46719 .23303 .46834 Mtetra
.149 .69 .723 r
.23303 .46834 .24049 .46719 .25066 .46307 .24305 .46651 Mtetra
0 0 0 r
.24305 .46651 .25066 .46307 .26095 .45792 .25317 .464 Mtetra
.089 0 0 r
.25317 .464 .26095 .45792 .27135 .45172 .26341 .46068 Mtetra
.156 0 0 r
.26341 .46068 .27135 .45172 .28185 .44442 .27375 .45638 Mtetra
.206 0 .029 r
.27375 .45638 .28185 .44442 .29242 .43627 .2842 .45117 Mtetra
.237 0 .109 r
.2842 .45117 .29242 .43627 .30305 .42744 .29474 .44504 Mtetra
.263 0 .166 r
.29474 .44504 .30305 .42744 .31371 .41833 .30535 .43823 Mtetra
.283 0 .204 r
.30535 .43823 .31371 .41833 .32437 .40925 .31602 .4309 Mtetra
.3 0 .23 r
.31602 .4309 .32437 .40925 .33501 .40048 .32671 .4233 Mtetra
.313 0 .248 r
.32671 .4233 .33501 .40048 .34563 .39225 .33742 .41566 Mtetra
.324 .004 .258 r
.33742 .41566 .34563 .39225 .35623 .38465 .34815 .40814 Mtetra
.333 .013 .263 r
.34815 .40814 .35623 .38465 .36681 .37774 .35887 .40088 Mtetra
.339 .017 .264 r
.35887 .40088 .36681 .37774 .37738 .37147 .36959 .39396 Mtetra
.344 .019 .261 r
.36959 .39396 .37738 .37147 .38794 .36581 .38032 .38744 Mtetra
.348 .018 .255 r
.38032 .38744 .38794 .36581 .39851 .36065 .39105 .38132 Mtetra
.351 .015 .248 r
.39105 .38132 .39851 .36065 .4091 .35592 .40179 .37563 Mtetra
.354 .012 .24 r
.40179 .37563 .4091 .35592 .41971 .35151 .41255 .37034 Mtetra
.357 .01 .232 r
.41255 .37034 .41971 .35151 .43035 .34736 .42332 .36547 Mtetra
.362 .009 .226 r
.42332 .36547 .43035 .34736 .44102 .34338 .43412 .36098 Mtetra
.368 .012 .222 r
.43412 .36098 .44102 .34338 .45173 .33955 .44494 .35687 Mtetra
.377 .018 .223 r
.44494 .35687 .45173 .33955 .46248 .33583 .4558 .35315 Mtetra
.388 .028 .228 r
.4558 .35315 .46248 .33583 .47327 .33222 .46669 .3498 Mtetra
.401 .042 .236 r
.46669 .3498 .47327 .33222 .4841 .32876 .47763 .34683 Mtetra
.416 .059 .248 r
.47763 .34683 .4841 .32876 .49497 .32548 .48861 .34426 Mtetra
.43 .076 .262 r
.48861 .34426 .49497 .32548 .50589 .32245 .49963 .34211 Mtetra
.444 .094 .276 r
.49963 .34211 .50589 .32245 .51686 .31976 .51072 .34037 Mtetra
.457 .111 .29 r
.51072 .34037 .51686 .31976 .52788 .31749 .52186 .33906 Mtetra
.469 .127 .302 r
.52186 .33906 .52788 .31749 .53895 .31574 .53306 .33818 Mtetra
.479 .139 .312 r
.53306 .33818 .53895 .31574 .55009 .31461 .54434 .33771 Mtetra
.486 .148 .319 r
.54434 .33771 .55009 .31461 .56131 .31413 .55569 .33759 Mtetra
.491 .154 .323 r
.55569 .33759 .56131 .31413 .5726 .31438 .56711 .33775 Mtetra
.493 .155 .322 r
.56711 .33775 .5726 .31438 .58398 .31527 .57862 .33804 Mtetra
.491 .151 .317 r
.57862 .33804 .58398 .31527 .59546 .31674 .5902 .3383 Mtetra
.484 .138 .304 r
.5902 .3383 .59546 .31674 .60703 .31853 .60186 .3383 Mtetra
.469 .115 .282 r
.60186 .3383 .60703 .31853 .61869 .32038 .61357 .33779 Mtetra
.445 .078 .246 r
.61357 .33779 .61869 .32038 .63043 .32195 .62534 .33658 Mtetra
.402 .016 .189 r
.62534 .33658 .63043 .32195 .64224 .32285 .63715 .33443 Mtetra
.333 0 .097 r
.63715 .33443 .64224 .32285 .6541 .32288 .64899 .33135 Mtetra
.211 0 0 r
.64899 .33135 .6541 .32288 .66599 .32178 .66083 .32726 Mtetra
.01 0 0 r
.66083 .32726 .66599 .32178 .67789 .31961 .67269 .32232 Mtetra
0 0 0 r
.67269 .32232 .67789 .31961 .68981 .31638 .68456 .31667 Mtetra
.548 .93 .857 r
.68456 .31667 .68981 .31638 .70173 .31227 .69643 .3105 Mtetra
.686 .957 .948 r
.69643 .3105 .70173 .31227 .71366 .30746 .70832 .30402 Mtetra
.734 .921 .955 r
.70832 .30402 .71366 .30746 .7256 .30211 .72024 .29736 Mtetra
.744 .877 .941 r
.72024 .29736 .7256 .30211 .73756 .29643 .73218 .29068 Mtetra
.742 .843 .926 r
.73218 .29068 .73756 .29643 .74954 .29052 .74416 .28405 Mtetra
.735 .817 .915 r
.74416 .28405 .74954 .29052 .76156 .28453 .75619 .27755 Mtetra
.729 .8 .908 r
.75619 .27755 .76156 .28453 .77361 .27848 .76826 .27117 Mtetra
.724 .789 .903 r
.76826 .27117 .77361 .27848 .78569 .27243 .78037 .26489 Mtetra
.72 .781 .901 r
.78037 .26489 .78569 .27243 .79782 .26643 .79252 .25872 Mtetra
.586 .732 .944 r
.13868 .4723 .14569 .47843 .15524 .477 .14829 .4704 Mtetra
.583 .715 .934 r
.14829 .4704 .15524 .477 .16481 .47569 .15793 .46862 Mtetra
.577 .698 .924 r
.15793 .46862 .16481 .47569 .17442 .4745 .16759 .467 Mtetra
.569 .682 .916 r
.16759 .467 .17442 .4745 .18407 .47342 .17729 .46558 Mtetra
.558 .668 .911 r
.17729 .46558 .18407 .47342 .19375 .47249 .187 .46441 Mtetra
.548 .658 .908 r
.187 .46441 .19375 .47249 .20348 .4716 .19675 .46347 Mtetra
.536 .652 .909 r
.19675 .46347 .20348 .4716 .21326 .47072 .20652 .46275 Mtetra
.525 .653 .916 r
.20652 .46275 .21326 .47072 .22311 .46967 .21633 .46219 Mtetra
.51 .663 .93 r
.21633 .46219 .22311 .46967 .23303 .46834 .22619 .46177 Mtetra
.489 .686 .954 r
.22619 .46177 .23303 .46834 .24305 .46651 .23609 .46141 Mtetra
.444 .723 .985 r
.23609 .46141 .24305 .46651 .25317 .464 .24605 .46107 Mtetra
.333 .751 .977 r
.24605 .46107 .25317 .464 .26341 .46068 .25608 .46065 Mtetra
.086 .645 .761 r
.25608 .46065 .26341 .46068 .27375 .45638 .26618 .46007 Mtetra
.184 0 0 r
.26618 .46007 .27375 .45638 .2842 .45117 .27635 .45917 Mtetra
.32 0 0 r
.27635 .45917 .2842 .45117 .29474 .44504 .28662 .45782 Mtetra
.378 0 .142 r
.28662 .45782 .29474 .44504 .30535 .43823 .29698 .45588 Mtetra
.402 .04 .231 r
.29698 .45588 .30535 .43823 .31602 .4309 .30745 .45322 Mtetra
.415 .079 .284 r
.30745 .45322 .31602 .4309 .32671 .4233 .318 .44987 Mtetra
.421 .102 .316 r
.318 .44987 .32671 .4233 .33742 .41566 .32863 .44583 Mtetra
.426 .118 .338 r
.32863 .44583 .33742 .41566 .34815 .40814 .33934 .44123 Mtetra
.429 .128 .352 r
.33934 .44123 .34815 .40814 .35887 .40088 .3501 .43617 Mtetra
.432 .136 .361 r
.3501 .43617 .35887 .40088 .36959 .39396 .36091 .43081 Mtetra
.434 .142 .367 r
.36091 .43081 .36959 .39396 .38032 .38744 .37177 .42529 Mtetra
.437 .146 .372 r
.37177 .42529 .38032 .38744 .39105 .38132 .38265 .41975 Mtetra
.44 .15 .375 r
.38265 .41975 .39105 .38132 .40179 .37563 .39356 .41431 Mtetra
.443 .154 .377 r
.39356 .41431 .40179 .37563 .41255 .37034 .40449 .40907 Mtetra
.448 .157 .378 r
.40449 .40907 .41255 .37034 .42332 .36547 .41545 .40414 Mtetra
.452 .161 .38 r
.41545 .40414 .42332 .36547 .43412 .36098 .42643 .39957 Mtetra
.457 .166 .381 r
.42643 .39957 .43412 .36098 .44494 .35687 .43744 .39542 Mtetra
.463 .17 .382 r
.43744 .39542 .44494 .35687 .4558 .35315 .44847 .3917 Mtetra
.468 .175 .384 r
.44847 .3917 .4558 .35315 .46669 .3498 .45955 .38842 Mtetra
.473 .179 .386 r
.45955 .38842 .46669 .3498 .47763 .34683 .47066 .38556 Mtetra
.477 .183 .387 r
.47066 .38556 .47763 .34683 .48861 .34426 .48183 .38307 Mtetra
.481 .186 .388 r
.48183 .38307 .48861 .34426 .49963 .34211 .49304 .38089 Mtetra
.483 .188 .388 r
.49304 .38089 .49963 .34211 .51072 .34037 .50431 .37892 Mtetra
.484 .188 .388 r
.50431 .37892 .51072 .34037 .52186 .33906 .51564 .37706 Mtetra
.483 .187 .386 r
.51564 .37706 .52186 .33906 .53306 .33818 .52703 .37518 Mtetra
.48 .182 .382 r
.52703 .37518 .53306 .33818 .54434 .33771 .53848 .37315 Mtetra
.475 .174 .375 r
.53848 .37315 .54434 .33771 .55569 .33759 .54999 .37081 Mtetra
.465 .16 .364 r
.54999 .37081 .55569 .33759 .56711 .33775 .56155 .36801 Mtetra
.451 .14 .346 r
.56155 .36801 .56711 .33775 .57862 .33804 .57316 .36465 Mtetra
.428 .108 .319 r
.57316 .36465 .57862 .33804 .5902 .3383 .58481 .36057 Mtetra
.393 .059 .276 r
.58481 .36057 .5902 .3383 .60186 .3383 .59649 .35578 Mtetra
.333 0 .203 r
.59649 .35578 .60186 .3383 .61357 .33779 .6082 .35026 Mtetra
.225 0 .068 r
.6082 .35026 .61357 .33779 .62534 .33658 .61992 .34412 Mtetra
.008 0 0 r
.61992 .34412 .62534 .33658 .63715 .33443 .63167 .3375 Mtetra
.377 .805 .627 r
.63167 .3375 .63715 .33443 .64899 .33135 .64343 .33054 Mtetra
.689 .973 .918 r
.64343 .33054 .64899 .33135 .66083 .32726 .65521 .32341 Mtetra
.762 .907 .94 r
.65521 .32341 .66083 .32726 .67269 .32232 .66701 .31617 Mtetra
.759 .828 .906 r
.66701 .31617 .67269 .32232 .68456 .31667 .67884 .30894 Mtetra
.747 .777 .878 r
.67884 .30894 .68456 .31667 .69643 .3105 .69071 .30177 Mtetra
.736 .747 .862 r
.69071 .30177 .69643 .3105 .70832 .30402 .7026 .29472 Mtetra
.727 .731 .854 r
.7026 .29472 .70832 .30402 .72024 .29736 .71454 .28783 Mtetra
.72 .724 .853 r
.71454 .28783 .72024 .29736 .73218 .29068 .72652 .28116 Mtetra
.715 .722 .856 r
.72652 .28116 .73218 .29068 .74416 .28405 .73855 .27471 Mtetra
.709 .726 .863 r
.73855 .27471 .74416 .28405 .75619 .27755 .75063 .26851 Mtetra
.706 .733 .872 r
.75063 .26851 .75619 .27755 .76826 .27117 .76276 .26251 Mtetra
.704 .743 .882 r
.76276 .26251 .76826 .27117 .78037 .26489 .77495 .25667 Mtetra
.703 .756 .893 r
.77495 .25667 .78037 .26489 .79252 .25872 .78718 .25095 Mtetra
.636 .746 .928 r
.13161 .46613 .13868 .4723 .14829 .4704 .14135 .46322 Mtetra
.633 .714 .906 r
.14135 .46322 .14829 .4704 .15793 .46862 .15112 .46041 Mtetra
.625 .682 .884 r
.15112 .46041 .15793 .46862 .16759 .467 .16091 .45778 Mtetra
.615 .653 .864 r
.16091 .45778 .16759 .467 .17729 .46558 .17071 .45537 Mtetra
.602 .626 .847 r
.17071 .45537 .17729 .46558 .187 .46441 .18053 .45328 Mtetra
.589 .602 .832 r
.18053 .45328 .187 .46441 .19675 .46347 .19036 .45153 Mtetra
.576 .58 .82 r
.19036 .45153 .19675 .46347 .20652 .46275 .20019 .45014 Mtetra
.564 .563 .811 r
.20019 .45014 .20652 .46275 .21633 .46219 .21005 .44911 Mtetra
.552 .55 .805 r
.21005 .44911 .21633 .46219 .22619 .46177 .21992 .44844 Mtetra
.542 .541 .803 r
.21992 .44844 .22619 .46177 .23609 .46141 .22982 .44808 Mtetra
.532 .537 .805 r
.22982 .44808 .23609 .46141 .24605 .46107 .23975 .44798 Mtetra
.525 .538 .811 r
.23975 .44798 .24605 .46107 .25608 .46065 .24973 .44807 Mtetra
.52 .544 .821 r
.24973 .44807 .25608 .46065 .26618 .46007 .25976 .44824 Mtetra
.518 .558 .836 r
.25976 .44824 .26618 .46007 .27635 .45917 .26986 .44836 Mtetra
.52 .582 .857 r
.26986 .44836 .27635 .45917 .28662 .45782 .28004 .44829 Mtetra
.526 .616 .885 r
.28004 .44829 .28662 .45782 .29698 .45588 .2903 .4479 Mtetra
.534 .665 .92 r
.2903 .4479 .29698 .45588 .30745 .45322 .30065 .44706 Mtetra
.537 .728 .962 r
.30065 .44706 .30745 .45322 .318 .44987 .31109 .44573 Mtetra
.524 .8 .996 r
.31109 .44573 .318 .44987 .32863 .44583 .32162 .44388 Mtetra
.463 .849 .982 r
.32162 .44388 .32863 .44583 .33934 .44123 .33224 .44155 Mtetra
.329 .813 .853 r
.33224 .44155 .33934 .44123 .3501 .43617 .34293 .43878 Mtetra
0 0 0 r
.34293 .43878 .3501 .43617 .36091 .43081 .35368 .43565 Mtetra
.014 0 0 r
.35368 .43565 .36091 .43081 .37177 .42529 .3645 .43224 Mtetra
.126 0 0 r
.3645 .43224 .37177 .42529 .38265 .41975 .37536 .42862 Mtetra
.201 0 0 r
.37536 .42862 .38265 .41975 .39356 .41431 .38628 .42486 Mtetra
.25 0 .012 r
.38628 .42486 .39356 .41431 .40449 .40907 .39725 .42101 Mtetra
.284 0 .068 r
.39725 .42101 .40449 .40907 .41545 .40414 .40826 .41715 Mtetra
.307 0 .104 r
.40826 .41715 .41545 .40414 .42643 .39957 .41931 .41331 Mtetra
.322 0 .127 r
.41931 .41331 .42643 .39957 .43744 .39542 .43041 .40951 Mtetra
.331 0 .138 r
.43041 .40951 .43744 .39542 .44847 .3917 .44154 .40579 Mtetra
.334 0 .14 r
.44154 .40579 .44847 .3917 .45955 .38842 .45273 .40213 Mtetra
.331 0 .131 r
.45273 .40213 .45955 .38842 .47066 .38556 .46395 .39852 Mtetra
.32 0 .111 r
.46395 .39852 .47066 .38556 .48183 .38307 .47523 .39493 Mtetra
.3 0 .076 r
.47523 .39493 .48183 .38307 .49304 .38089 .48655 .39132 Mtetra
.265 0 .02 r
.48655 .39132 .49304 .38089 .50431 .37892 .49792 .38764 Mtetra
.207 0 0 r
.49792 .38764 .50431 .37892 .51564 .37706 .50935 .3838 Mtetra
.11 0 0 r
.50935 .3838 .51564 .37706 .52703 .37518 .52081 .37976 Mtetra
0 0 0 r
.52081 .37976 .52703 .37518 .53848 .37315 .53233 .37542 Mtetra
.289 .771 .681 r
.53233 .37542 .53848 .37315 .54999 .37081 .54389 .37071 Mtetra
.538 .924 .903 r
.54389 .37071 .54999 .37081 .56155 .36801 .55548 .36556 Mtetra
.682 .928 .97 r
.55548 .36556 .56155 .36801 .57316 .36465 .56711 .35991 Mtetra
.733 .863 .942 r
.56711 .35991 .57316 .36465 .58481 .36057 .57877 .35371 Mtetra
.742 .795 .895 r
.57877 .35371 .58481 .36057 .59649 .35578 .59045 .34701 Mtetra
.738 .741 .854 r
.59045 .34701 .59649 .35578 .6082 .35026 .60214 .33983 Mtetra
.731 .703 .823 r
.60214 .33983 .6082 .35026 .61992 .34412 .61386 .33231 Mtetra
.723 .674 .802 r
.61386 .33231 .61992 .34412 .63167 .3375 .62559 .32458 Mtetra
.715 .653 .787 r
.62559 .32458 .63167 .3375 .64343 .33054 .63734 .31678 Mtetra
.707 .638 .777 r
.63734 .31678 .64343 .33054 .65521 .32341 .64911 .30906 Mtetra
.7 .627 .771 r
.64911 .30906 .65521 .32341 .66701 .31617 .66092 .3015 Mtetra
.693 .619 .769 r
.66092 .3015 .66701 .31617 .67884 .30894 .67276 .29421 Mtetra
.687 .616 .771 r
.67276 .29421 .67884 .30894 .69071 .30177 .68464 .28723 Mtetra
.682 .616 .776 r
.68464 .28723 .69071 .30177 .7026 .29472 .69658 .2806 Mtetra
.678 .62 .784 r
.69658 .2806 .7026 .29472 .71454 .28783 .70857 .27433 Mtetra
.674 .628 .795 r
.70857 .27433 .71454 .28783 .72652 .28116 .72061 .26844 Mtetra
.672 .64 .81 r
.72061 .26844 .72652 .28116 .73855 .27471 .73272 .26289 Mtetra
.67 .656 .827 r
.73272 .26289 .73855 .27471 .75063 .26851 .7449 .25765 Mtetra
.669 .675 .847 r
.7449 .25765 .75063 .26851 .76276 .26251 .75714 .25266 Mtetra
.669 .699 .869 r
.75714 .25266 .76276 .26251 .77495 .25667 .76944 .24784 Mtetra
.67 .727 .892 r
.76944 .24784 .77495 .25667 .78718 .25095 .7818 .24311 Mtetra
.685 .758 .907 r
.12449 .45992 .13161 .46613 .14135 .46322 .1344 .45577 Mtetra
.678 .72 .881 r
.1344 .45577 .14135 .46322 .15112 .46041 .14433 .45167 Mtetra
.667 .684 .856 r
.14433 .45167 .15112 .46041 .16091 .45778 .15428 .44772 Mtetra
.654 .65 .834 r
.15428 .44772 .16091 .45778 .17071 .45537 .16424 .44399 Mtetra
.639 .619 .814 r
.16424 .44399 .17071 .45537 .18053 .45328 .1742 .44056 Mtetra
.624 .591 .796 r
.1742 .44056 .18053 .45328 .19036 .45153 .18416 .4375 Mtetra
.608 .564 .78 r
.18416 .4375 .19036 .45153 .20019 .45014 .19411 .43487 Mtetra
.594 .542 .765 r
.19411 .43487 .20019 .45014 .21005 .44911 .20407 .43265 Mtetra
.581 .521 .753 r
.20407 .43265 .21005 .44911 .21992 .44844 .21403 .43084 Mtetra
.572 .505 .741 r
.21403 .43084 .21992 .44844 .22982 .44808 .22402 .42936 Mtetra
.565 .491 .73 r
.22402 .42936 .22982 .44808 .23975 .44798 .23403 .42812 Mtetra
.561 .479 .72 r
.23403 .42812 .23975 .44798 .24973 .44807 .24408 .42701 Mtetra
.559 .47 .71 r
.24408 .42701 .24973 .44807 .25976 .44824 .25419 .42592 Mtetra
.558 .461 .701 r
.25419 .42592 .25976 .44824 .26986 .44836 .26435 .42481 Mtetra
.558 .454 .692 r
.26435 .42481 .26986 .44836 .28004 .44829 .27457 .42365 Mtetra
.558 .448 .685 r
.27457 .42365 .28004 .44829 .2903 .4479 .28485 .42245 Mtetra
.557 .444 .681 r
.28485 .42245 .2903 .4479 .30065 .44706 .29519 .42125 Mtetra
.557 .442 .679 r
.29519 .42125 .30065 .44706 .31109 .44573 .30558 .42007 Mtetra
.556 .443 .68 r
.30558 .42007 .31109 .44573 .32162 .44388 .31603 .4189 Mtetra
.557 .447 .685 r
.31603 .4189 .32162 .44388 .33224 .44155 .32653 .41772 Mtetra
.559 .455 .693 r
.32653 .41772 .33224 .44155 .34293 .43878 .3371 .41651 Mtetra
.561 .467 .704 r
.3371 .41651 .34293 .43878 .35368 .43565 .34773 .41522 Mtetra
.566 .483 .72 r
.34773 .41522 .35368 .43565 .3645 .43224 .35842 .41379 Mtetra
.572 .503 .739 r
.35842 .41379 .3645 .43224 .37536 .42862 .36918 .41217 Mtetra
.581 .529 .762 r
.36918 .41217 .37536 .42862 .38628 .42486 .38001 .4103 Mtetra
.591 .559 .787 r
.38001 .4103 .38628 .42486 .39725 .42101 .39091 .40811 Mtetra
.604 .591 .811 r
.39091 .40811 .39725 .42101 .40826 .41715 .40187 .40557 Mtetra
.618 .622 .832 r
.40187 .40557 .40826 .41715 .41931 .41331 .41291 .40265 Mtetra
.632 .647 .847 r
.41291 .40265 .41931 .41331 .43041 .40951 .424 .39931 Mtetra
.645 .663 .853 r
.424 .39931 .43041 .40951 .44154 .40579 .43516 .39555 Mtetra
.657 .668 .849 r
.43516 .39555 .44154 .40579 .45273 .40213 .44637 .39137 Mtetra
.665 .661 .836 r
.44637 .39137 .45273 .40213 .46395 .39852 .45763 .38678 Mtetra
.669 .645 .817 r
.45763 .38678 .46395 .39852 .47523 .39493 .46894 .38179 Mtetra
.668 .622 .794 r
.46894 .38179 .47523 .39493 .48655 .39132 .4803 .37644 Mtetra
.664 .597 .77 r
.4803 .37644 .48655 .39132 .49792 .38764 .49169 .37078 Mtetra
.658 .572 .747 r
.49169 .37078 .49792 .38764 .50935 .3838 .50313 .36485 Mtetra
.651 .549 .726 r
.50313 .36485 .50935 .3838 .52081 .37976 .51459 .35871 Mtetra
.644 .53 .709 r
.51459 .35871 .52081 .37976 .53233 .37542 .52609 .35243 Mtetra
.637 .514 .696 r
.52609 .35243 .53233 .37542 .54389 .37071 .53761 .34605 Mtetra
.632 .502 .686 r
.53761 .34605 .54389 .37071 .55548 .36556 .54917 .33963 Mtetra
.628 .493 .679 r
.54917 .33963 .55548 .36556 .56711 .35991 .56076 .3332 Mtetra
.625 .488 .675 r
.56076 .3332 .56711 .35991 .57877 .35371 .57237 .32677 Mtetra
.624 .486 .674 r
.57237 .32677 .57877 .35371 .59045 .34701 .58402 .32034 Mtetra
.625 .488 .675 r
.58402 .32034 .59045 .34701 .60214 .33983 .5957 .3139 Mtetra
.628 .493 .679 r
.5957 .3139 .60214 .33983 .61386 .33231 .60742 .30742 Mtetra
.632 .501 .685 r
.60742 .30742 .61386 .33231 .62559 .32458 .61916 .30086 Mtetra
.636 .51 .692 r
.61916 .30086 .62559 .32458 .63734 .31678 .63093 .29428 Mtetra
.641 .52 .701 r
.63093 .29428 .63734 .31678 .64911 .30906 .64273 .2877 Mtetra
.643 .529 .709 r
.64273 .2877 .64911 .30906 .66092 .3015 .65457 .28125 Mtetra
.644 .538 .719 r
.65457 .28125 .66092 .3015 .67276 .29421 .66645 .27505 Mtetra
.644 .547 .73 r
.66645 .27505 .67276 .29421 .68464 .28723 .67839 .26916 Mtetra
.642 .556 .742 r
.67839 .26916 .68464 .28723 .69658 .2806 .69039 .2637 Mtetra
.64 .566 .756 r
.69039 .2637 .69658 .2806 .70857 .27433 .70245 .25866 Mtetra
.637 .579 .773 r
.70245 .25866 .70857 .27433 .72061 .26844 .71458 .25406 Mtetra
.634 .596 .793 r
.71458 .25406 .72061 .26844 .73272 .26289 .7268 .24982 Mtetra
.632 .615 .816 r
.7268 .24982 .73272 .26289 .7449 .25765 .73908 .24591 Mtetra
.63 .64 .841 r
.73908 .24591 .7449 .25765 .75714 .25266 .75144 .24223 Mtetra
.629 .668 .869 r
.75144 .24223 .75714 .25266 .76944 .24784 .76387 .23869 Mtetra
.628 .701 .898 r
.76387 .23869 .76944 .24784 .7818 .24311 .77637 .23521 Mtetra
.72 .764 .887 r
.11732 .45366 .12449 .45992 .1344 .45577 .12739 .44839 Mtetra
.712 .731 .866 r
.12739 .44839 .1344 .45577 .14433 .45167 .13748 .44311 Mtetra
.702 .7 .845 r
.13748 .44311 .14433 .45167 .15428 .44772 .14758 .4379 Mtetra
.69 .669 .825 r
.14758 .4379 .15428 .44772 .16424 .44399 .1577 .4328 Mtetra
.676 .639 .805 r
.1577 .4328 .16424 .44399 .1742 .44056 .16783 .42789 Mtetra
.662 .61 .786 r
.16783 .42789 .1742 .44056 .18416 .4375 .17796 .42323 Mtetra
.646 .581 .767 r
.17796 .42323 .18416 .4375 .19411 .43487 .18809 .41889 Mtetra
.631 .554 .749 r
.18809 .41889 .19411 .43487 .20407 .43265 .19822 .41488 Mtetra
.617 .529 .733 r
.19822 .41488 .20407 .43265 .21403 .43084 .20834 .41126 Mtetra
.604 .507 .717 r
.20834 .41126 .21403 .43084 .22402 .42936 .21847 .40798 Mtetra
.593 .488 .704 r
.21847 .40798 .22402 .42936 .23403 .42812 .22861 .40505 Mtetra
.584 .472 .692 r
.22861 .40505 .23403 .42812 .24408 .42701 .23876 .40241 Mtetra
.577 .46 .683 r
.23876 .40241 .24408 .42701 .25419 .42592 .24894 .40001 Mtetra
.572 .45 .675 r
.24894 .40001 .25419 .42592 .26435 .42481 .25915 .39783 Mtetra
.567 .442 .67 r
.25915 .39783 .26435 .42481 .27457 .42365 .26939 .39584 Mtetra
.563 .437 .666 r
.26939 .39584 .27457 .42365 .28485 .42245 .27967 .39402 Mtetra
.56 .433 .663 r
.27967 .39402 .28485 .42245 .29519 .42125 .28999 .39235 Mtetra
.558 .429 .661 r
.28999 .39235 .29519 .42125 .30558 .42007 .30035 .3908 Mtetra
.557 .427 .66 r
.30035 .3908 .30558 .42007 .31603 .4189 .31077 .38932 Mtetra
.556 .426 .659 r
.31077 .38932 .31603 .4189 .32653 .41772 .32123 .38786 Mtetra
.556 .425 .658 r
.32123 .38786 .32653 .41772 .3371 .41651 .33176 .38638 Mtetra
.557 .425 .657 r
.33176 .38638 .3371 .41651 .34773 .41522 .34235 .38482 Mtetra
.559 .426 .656 r
.34235 .38482 .34773 .41522 .35842 .41379 .353 .38312 Mtetra
.561 .426 .655 r
.353 .38312 .35842 .41379 .36918 .41217 .36371 .38125 Mtetra
.564 .428 .654 r
.36371 .38125 .36918 .41217 .38001 .4103 .37449 .37914 Mtetra
.567 .429 .653 r
.37449 .37914 .38001 .4103 .39091 .40811 .38534 .37675 Mtetra
.571 .431 .653 r
.38534 .37675 .39091 .40811 .40187 .40557 .39626 .37404 Mtetra
.575 .434 .652 r
.39626 .37404 .40187 .40557 .41291 .40265 .40724 .37098 Mtetra
.579 .437 .652 r
.40724 .37098 .41291 .40265 .424 .39931 .41828 .36755 Mtetra
.583 .439 .651 r
.41828 .36755 .424 .39931 .43516 .39555 .42938 .36375 Mtetra
.587 .442 .651 r
.42938 .36375 .43516 .39555 .44637 .39137 .44053 .35956 Mtetra
.592 .445 .651 r
.44053 .35956 .44637 .39137 .45763 .38678 .45174 .35499 Mtetra
.596 .448 .651 r
.45174 .35499 .45763 .38678 .46894 .38179 .463 .35008 Mtetra
.599 .451 .651 r
.463 .35008 .46894 .38179 .4803 .37644 .4743 .34483 Mtetra
.602 .453 .652 r
.4743 .34483 .4803 .37644 .49169 .37078 .48564 .3393 Mtetra
.605 .456 .652 r
.48564 .3393 .49169 .37078 .50313 .36485 .49701 .33353 Mtetra
.608 .458 .653 r
.49701 .33353 .50313 .36485 .51459 .35871 .50842 .32757 Mtetra
.609 .46 .654 r
.50842 .32757 .51459 .35871 .52609 .35243 .51987 .32146 Mtetra
.611 .461 .654 r
.51987 .32146 .52609 .35243 .53761 .34605 .53135 .31527 Mtetra
.611 .462 .655 r
.53135 .31527 .53761 .34605 .54917 .33963 .54285 .30904 Mtetra
.612 .463 .656 r
.54285 .30904 .54917 .33963 .56076 .3332 .5544 .30282 Mtetra
.611 .464 .657 r
.5544 .30282 .56076 .3332 .57237 .32677 .56597 .29667 Mtetra
.611 .465 .659 r
.56597 .29667 .57237 .32677 .58402 .32034 .57758 .29063 Mtetra
.61 .465 .66 r
.57758 .29063 .58402 .32034 .5957 .3139 .58922 .28473 Mtetra
.609 .467 .663 r
.58922 .28473 .5957 .3139 .60742 .30742 .60091 .279 Mtetra
.609 .47 .667 r
.60091 .279 .60742 .30742 .61916 .30086 .61264 .27346 Mtetra
.608 .474 .673 r
.61264 .27346 .61916 .30086 .63093 .29428 .62441 .26813 Mtetra
.608 .48 .68 r
.62441 .26813 .63093 .29428 .64273 .2877 .63623 .26305 Mtetra
.608 .488 .69 r
.63623 .26305 .64273 .2877 .65457 .28125 .64811 .25827 Mtetra
.608 .497 .702 r
.64811 .25827 .65457 .28125 .66645 .27505 .66005 .25383 Mtetra
.607 .509 .717 r
.66005 .25383 .66645 .27505 .67839 .26916 .67206 .24975 Mtetra
.606 .523 .734 r
.67206 .24975 .67839 .26916 .69039 .2637 .68414 .24606 Mtetra
.604 .539 .754 r
.68414 .24606 .69039 .2637 .70245 .25866 .6963 .24272 Mtetra
.602 .557 .777 r
.6963 .24272 .70245 .25866 .71458 .25406 .70854 .23971 Mtetra
.599 .578 .801 r
.70854 .23971 .71458 .25406 .7268 .24982 .72086 .23696 Mtetra
.596 .602 .827 r
.72086 .23696 .7268 .24982 .73908 .24591 .73325 .2344 Mtetra
.593 .627 .854 r
.73325 .2344 .73908 .24591 .75144 .24223 .74573 .23198 Mtetra
.59 .655 .882 r
.74573 .23198 .75144 .24223 .76387 .23869 .75828 .22961 Mtetra
.587 .685 .909 r
.75828 .22961 .76387 .23869 .77637 .23521 .7709 .22725 Mtetra
.74 .766 .874 r
.1101 .44736 .11732 .45366 .12739 .44839 .12028 .44132 Mtetra
.735 .745 .86 r
.12028 .44132 .12739 .44839 .13748 .44311 .13049 .43521 Mtetra
.729 .723 .845 r
.13049 .43521 .13748 .44311 .14758 .4379 .14073 .42907 Mtetra
.721 .701 .83 r
.14073 .42907 .14758 .4379 .1577 .4328 .15099 .42292 Mtetra
.712 .677 .814 r
.15099 .42292 .1577 .4328 .16783 .42789 .16127 .41678 Mtetra
.701 .651 .797 r
.16127 .41678 .16783 .42789 .17796 .42323 .17156 .41072 Mtetra
.688 .625 .78 r
.17156 .41072 .17796 .42323 .18809 .41889 .18186 .40477 Mtetra
.674 .598 .762 r
.18186 .40477 .18809 .41889 .19822 .41488 .19217 .39904 Mtetra
.659 .571 .745 r
.19217 .39904 .19822 .41488 .20834 .41126 .20247 .39358 Mtetra
.643 .545 .729 r
.20247 .39358 .20834 .41126 .21847 .40798 .21276 .38848 Mtetra
.628 .522 .715 r
.21276 .38848 .21847 .40798 .22861 .40505 .22304 .38381 Mtetra
.614 .502 .702 r
.22304 .38381 .22861 .40505 .23876 .40241 .23331 .37961 Mtetra
.601 .485 .693 r
.23331 .37961 .23876 .40241 .24894 .40001 .24357 .37593 Mtetra
.591 .471 .685 r
.24357 .37593 .24894 .40001 .25915 .39783 .25383 .3727 Mtetra
.582 .46 .679 r
.25383 .3727 .25915 .39783 .26939 .39584 .2641 .36988 Mtetra
.576 .453 .675 r
.2641 .36988 .26939 .39584 .27967 .39402 .2744 .36731 Mtetra
.573 .448 .671 r
.2744 .36731 .27967 .39402 .28999 .39235 .28473 .36487 Mtetra
.572 .444 .667 r
.28473 .36487 .28999 .39235 .30035 .3908 .29511 .36246 Mtetra
.571 .44 .663 r
.29511 .36246 .30035 .3908 .31077 .38932 .30554 .35995 Mtetra
.572 .437 .658 r
.30554 .35995 .31077 .38932 .32123 .38786 .31603 .35731 Mtetra
.572 .433 .653 r
.31603 .35731 .32123 .38786 .33176 .38638 .32658 .3545 Mtetra
.573 .429 .648 r
.32658 .3545 .33176 .38638 .34235 .38482 .33719 .35151 Mtetra
.573 .425 .643 r
.33719 .35151 .34235 .38482 .353 .38312 .34785 .34836 Mtetra
.572 .421 .638 r
.34785 .34836 .353 .38312 .36371 .38125 .35857 .34507 Mtetra
.572 .417 .633 r
.35857 .34507 .36371 .38125 .37449 .37914 .36934 .34166 Mtetra
.571 .414 .629 r
.36934 .34166 .37449 .37914 .38534 .37675 .38016 .33814 Mtetra
.571 .411 .626 r
.38016 .33814 .38534 .37675 .39626 .37404 .39104 .33452 Mtetra
.571 .409 .624 r
.39104 .33452 .39626 .37404 .40724 .37098 .40195 .33082 Mtetra
.571 .408 .622 r
.40195 .33082 .40724 .37098 .41828 .36755 .41292 .32704 Mtetra
.571 .408 .621 r
.41292 .32704 .41828 .36755 .42938 .36375 .42393 .32318 Mtetra
.572 .408 .621 r
.42393 .32318 .42938 .36375 .44053 .35956 .435 .31923 Mtetra
.573 .41 .622 r
.435 .31923 .44053 .35956 .45174 .35499 .4461 .3152 Mtetra
.574 .412 .624 r
.4461 .3152 .45174 .35499 .463 .35008 .45726 .31108 Mtetra
.576 .415 .626 r
.45726 .31108 .463 .35008 .4743 .34483 .46846 .30686 Mtetra
.578 .419 .629 r
.46846 .30686 .4743 .34483 .48564 .3393 .4797 .30254 Mtetra
.581 .424 .633 r
.4797 .30254 .48564 .3393 .49701 .33353 .49099 .29809 Mtetra
.584 .429 .637 r
.49099 .29809 .49701 .33353 .50842 .32757 .50233 .2935 Mtetra
.588 .436 .642 r
.50233 .2935 .50842 .32757 .51987 .32146 .51371 .28873 Mtetra
.592 .443 .647 r
.51371 .28873 .51987 .32146 .53135 .31527 .52513 .28379 Mtetra
.597 .45 .652 r
.52513 .28379 .53135 .31527 .54285 .30904 .53658 .27866 Mtetra
.601 .456 .657 r
.53658 .27866 .54285 .30904 .5544 .30282 .54808 .2734 Mtetra
.604 .462 .661 r
.54808 .2734 .5544 .30282 .56597 .29667 .55962 .26804 Mtetra
.605 .466 .665 r
.55962 .26804 .56597 .29667 .57758 .29063 .5712 .26268 Mtetra
.605 .469 .669 r
.5712 .26268 .57758 .29063 .58922 .28473 .58281 .25746 Mtetra
.604 .471 .673 r
.58281 .25746 .58922 .28473 .60091 .279 .59448 .2525 Mtetra
.6 .472 .678 r
.59448 .2525 .60091 .279 .61264 .27346 .6062 .24795 Mtetra
.596 .475 .685 r
.6062 .24795 .61264 .27346 .62441 .26813 .61797 .24386 Mtetra
.591 .478 .694 r
.61797 .24386 .62441 .26813 .63623 .26305 .62982 .24029 Mtetra
.587 .485 .706 r
.62982 .24029 .63623 .26305 .64811 .25827 .64174 .23721 Mtetra
.582 .495 .721 r
.64174 .23721 .64811 .25827 .66005 .25383 .65375 .23458 Mtetra
.579 .508 .739 r
.65375 .23458 .66005 .25383 .67206 .24975 .66583 .23232 Mtetra
.575 .525 .761 r
.66583 .23232 .67206 .24975 .68414 .24606 .67799 .23035 Mtetra
.572 .544 .785 r
.67799 .23035 .68414 .24606 .6963 .24272 .69024 .2286 Mtetra
.569 .566 .81 r
.69024 .2286 .6963 .24272 .70854 .23971 .70257 .22698 Mtetra
.566 .588 .835 r
.70257 .22698 .70854 .23971 .72086 .23696 .71498 .22545 Mtetra
.564 .612 .859 r
.71498 .22545 .72086 .23696 .73325 .2344 .72747 .22393 Mtetra
.561 .635 .882 r
.72747 .22393 .73325 .2344 .74573 .23198 .74003 .2224 Mtetra
.557 .657 .903 r
.74003 .2224 .74573 .23198 .75828 .22961 .75267 .22084 Mtetra
.554 .68 .922 r
.75267 .22084 .75828 .22961 .7709 .22725 .76539 .21923 Mtetra
.74 .766 .874 r
.10283 .44102 .1101 .44736 .12028 .44132 .11304 .43492 Mtetra
.742 .766 .872 r
.11304 .43492 .12028 .44132 .13049 .43521 .12329 .42873 Mtetra
.743 .764 .87 r
.12329 .42873 .13049 .43521 .14073 .42907 .13357 .42245 Mtetra
.744 .761 .867 r
.13357 .42245 .14073 .42907 .15099 .42292 .14388 .41608 Mtetra
.744 .756 .862 r
.14388 .41608 .15099 .42292 .16127 .41678 .15422 .40962 Mtetra
.743 .748 .857 r
.15422 .40962 .16127 .41678 .17156 .41072 .16458 .40313 Mtetra
.739 .737 .85 r
.16458 .40313 .17156 .41072 .18186 .40477 .17496 .39663 Mtetra
.732 .723 .842 r
.17496 .39663 .18186 .40477 .19217 .39904 .18536 .3902 Mtetra
.724 .705 .833 r
.18536 .3902 .19217 .39904 .20247 .39358 .19577 .3839 Mtetra
.712 .685 .822 r
.19577 .3839 .20247 .39358 .21276 .38848 .20617 .37781 Mtetra
.699 .662 .81 r
.20617 .37781 .21276 .38848 .22304 .38381 .21657 .37199 Mtetra
.684 .636 .796 r
.21657 .37199 .22304 .38381 .23331 .37961 .22697 .36648 Mtetra
.668 .61 .781 r
.22697 .36648 .23331 .37961 .24357 .37593 .23737 .3613 Mtetra
.653 .584 .764 r
.23737 .3613 .24357 .37593 .25383 .3727 .24777 .35642 Mtetra
.64 .558 .747 r
.24777 .35642 .25383 .3727 .2641 .36988 .25818 .35179 Mtetra
.629 .535 .73 r
.25818 .35179 .2641 .36988 .2744 .36731 .26861 .34734 Mtetra
.619 .515 .714 r
.26861 .34734 .2744 .36731 .28473 .36487 .27907 .343 Mtetra
.612 .498 .699 r
.27907 .343 .28473 .36487 .29511 .36246 .28956 .33872 Mtetra
.606 .484 .687 r
.28956 .33872 .29511 .36246 .30554 .35995 .30009 .33445 Mtetra
.601 .472 .677 r
.30009 .33445 .30554 .35995 .31603 .35731 .31065 .33019 Mtetra
.597 .462 .668 r
.31065 .33019 .31603 .35731 .32658 .3545 .32125 .32593 Mtetra
.594 .454 .661 r
.32125 .32593 .32658 .3545 .33719 .35151 .33189 .32167 Mtetra
.591 .448 .656 r
.33189 .32167 .33719 .35151 .34785 .34836 .34256 .31743 Mtetra
.588 .443 .651 r
.34256 .31743 .34785 .34836 .35857 .34507 .35327 .31323 Mtetra
.586 .438 .647 r
.35327 .31323 .35857 .34507 .36934 .34166 .36402 .30907 Mtetra
.584 .435 .645 r
.36402 .30907 .36934 .34166 .38016 .33814 .37481 .30496 Mtetra
.582 .432 .643 r
.37481 .30496 .38016 .33814 .39104 .33452 .38564 .3009 Mtetra
.581 .43 .641 r
.38564 .3009 .39104 .33452 .40195 .33082 .39651 .29689 Mtetra
.58 .428 .64 r
.39651 .29689 .40195 .33082 .41292 .32704 .40741 .29293 Mtetra
.579 .427 .64 r
.40741 .29293 .41292 .32704 .42393 .32318 .41836 .28901 Mtetra
.578 .427 .64 r
.41836 .28901 .42393 .32318 .435 .31923 .42936 .28514 Mtetra
.577 .427 .64 r
.42936 .28514 .435 .31923 .4461 .3152 .44039 .28132 Mtetra
.577 .427 .641 r
.44039 .28132 .4461 .3152 .45726 .31108 .45147 .27755 Mtetra
.577 .428 .643 r
.45147 .27755 .45726 .31108 .46846 .30686 .4626 .27383 Mtetra
.577 .43 .645 r
.4626 .27383 .46846 .30686 .4797 .30254 .47377 .27016 Mtetra
.577 .432 .648 r
.47377 .27016 .4797 .30254 .49099 .29809 .48499 .26654 Mtetra
.578 .436 .651 r
.48499 .26654 .49099 .29809 .50233 .2935 .49626 .26295 Mtetra
.579 .44 .656 r
.49626 .26295 .50233 .2935 .51371 .28873 .50758 .25937 Mtetra
.581 .446 .662 r
.50758 .25937 .51371 .28873 .52513 .28379 .51895 .25581 Mtetra
.584 .453 .669 r
.51895 .25581 .52513 .28379 .53658 .27866 .53037 .25224 Mtetra
.586 .462 .678 r
.53037 .25224 .53658 .27866 .54808 .2734 .54184 .24868 Mtetra
.59 .473 .689 r
.54184 .24868 .54808 .2734 .55962 .26804 .55336 .24513 Mtetra
.593 .486 .702 r
.55336 .24513 .55962 .26804 .5712 .26268 .56494 .24164 Mtetra
.595 .501 .717 r
.56494 .24164 .5712 .26268 .58281 .25746 .57657 .23827 Mtetra
.597 .517 .735 r
.57657 .23827 .58281 .25746 .59448 .2525 .58826 .23507 Mtetra
.596 .534 .755 r
.58826 .23507 .59448 .2525 .6062 .24795 .60002 .23214 Mtetra
.593 .551 .777 r
.60002 .23214 .6062 .24795 .61797 .24386 .61184 .22951 Mtetra
.587 .569 .8 r
.61184 .22951 .61797 .24386 .62982 .24029 .62374 .22724 Mtetra
.58 .586 .824 r
.62374 .22724 .62982 .24029 .64174 .23721 .63571 .22527 Mtetra
.57 .603 .847 r
.63571 .22527 .64174 .23721 .65375 .23458 .64777 .2236 Mtetra
.561 .62 .868 r
.64777 .2236 .65375 .23458 .66583 .23232 .6599 .22214 Mtetra
.552 .635 .887 r
.6599 .22214 .66583 .23232 .67799 .23035 .67212 .22082 Mtetra
.545 .65 .903 r
.67212 .22082 .67799 .23035 .69024 .2286 .68443 .21959 Mtetra
.54 .663 .916 r
.68443 .21959 .69024 .2286 .70257 .22698 .6968 .21835 Mtetra
.538 .674 .926 r
.6968 .21835 .70257 .22698 .71498 .22545 .70926 .21709 Mtetra
.539 .684 .932 r
.70926 .21709 .71498 .22545 .72747 .22393 .72179 .21573 Mtetra
.54 .69 .937 r
.72179 .21573 .72747 .22393 .74003 .2224 .7344 .21429 Mtetra
.542 .695 .939 r
.7344 .21429 .74003 .2224 .75267 .22084 .74708 .21276 Mtetra
.545 .699 .94 r
.74708 .21276 .75267 .22084 .76539 .21923 .75983 .21113 Mtetra
.726 .765 .884 r
.09551 .43462 .10283 .44102 .11304 .43492 .10567 .42907 Mtetra
.732 .783 .893 r
.10567 .42907 .11304 .43492 .12329 .42873 .11588 .42341 Mtetra
.738 .801 .902 r
.11588 .42341 .12329 .42873 .13357 .42245 .12613 .41763 Mtetra
.744 .819 .91 r
.12613 .41763 .13357 .42245 .14388 .41608 .13641 .41173 Mtetra
.75 .835 .917 r
.13641 .41173 .14388 .41608 .15422 .40962 .14673 .40568 Mtetra
.755 .85 .922 r
.14673 .40568 .15422 .40962 .16458 .40313 .15709 .39951 Mtetra
.758 .863 .926 r
.15709 .39951 .16458 .40313 .17496 .39663 .16749 .39325 Mtetra
.76 .872 .929 r
.16749 .39325 .17496 .39663 .18536 .3902 .17791 .38693 Mtetra
.76 .877 .931 r
.17791 .38693 .18536 .3902 .19577 .3839 .18836 .38058 Mtetra
.76 .876 .931 r
.18836 .38058 .19577 .3839 .20617 .37781 .19883 .37424 Mtetra
.759 .869 .929 r
.19883 .37424 .20617 .37781 .21657 .37199 .20931 .36791 Mtetra
.757 .852 .921 r
.20931 .36791 .21657 .37199 .22697 .36648 .21983 .36158 Mtetra
.754 .826 .908 r
.21983 .36158 .22697 .36648 .23737 .3613 .23036 .35525 Mtetra
.746 .789 .887 r
.23036 .35525 .23737 .3613 .24777 .35642 .24092 .34892 Mtetra
.735 .747 .861 r
.24092 .34892 .24777 .35642 .25818 .35179 .2515 .34259 Mtetra
.719 .702 .833 r
.2515 .34259 .25818 .35179 .26861 .34734 .2621 .33631 Mtetra
.703 .661 .806 r
.2621 .33631 .26861 .34734 .27907 .343 .27271 .33013 Mtetra
.686 .625 .782 r
.27271 .33013 .27907 .343 .28956 .33872 .28334 .32411 Mtetra
.67 .595 .762 r
.28334 .32411 .28956 .33872 .30009 .33445 .29398 .31829 Mtetra
.657 .571 .746 r
.29398 .31829 .30009 .33445 .31065 .33019 .30463 .31269 Mtetra
.646 .552 .734 r
.30463 .31269 .31065 .33019 .32125 .32593 .31529 .30734 Mtetra
.637 .537 .725 r
.31529 .30734 .32125 .32593 .33189 .32167 .32597 .30222 Mtetra
.629 .526 .719 r
.32597 .30222 .33189 .32167 .34256 .31743 .33667 .29733 Mtetra
.623 .518 .714 r
.33667 .29733 .34256 .31743 .35327 .31323 .34739 .29265 Mtetra
.618 .512 .711 r
.34739 .29265 .35327 .31323 .36402 .30907 .35814 .28815 Mtetra
.614 .507 .709 r
.35814 .28815 .36402 .30907 .37481 .30496 .36892 .2838 Mtetra
.611 .504 .708 r
.36892 .2838 .37481 .30496 .38564 .3009 .37973 .27958 Mtetra
.609 .502 .707 r
.37973 .27958 .38564 .3009 .39651 .29689 .39058 .27547 Mtetra
.607 .5 .707 r
.39058 .27547 .39651 .29689 .40741 .29293 .40147 .27144 Mtetra
.605 .499 .706 r
.40147 .27144 .40741 .29293 .41836 .28901 .4124 .26748 Mtetra
.604 .498 .707 r
.4124 .26748 .41836 .28901 .42936 .28514 .42337 .2636 Mtetra
.602 .497 .707 r
.42337 .2636 .42936 .28514 .44039 .28132 .43438 .2598 Mtetra
.6 .497 .708 r
.43438 .2598 .44039 .28132 .45147 .27755 .44543 .25611 Mtetra
.598 .496 .709 r
.44543 .25611 .45147 .27755 .4626 .27383 .45653 .25255 Mtetra
.596 .496 .711 r
.45653 .25255 .4626 .27383 .47377 .27016 .46768 .24914 Mtetra
.593 .497 .714 r
.46768 .24914 .47377 .27016 .48499 .26654 .47887 .24592 Mtetra
.59 .498 .718 r
.47887 .24592 .48499 .26654 .49626 .26295 .49012 .24291 Mtetra
.587 .501 .725 r
.49012 .24291 .49626 .26295 .50758 .25937 .50141 .24013 Mtetra
.584 .506 .733 r
.50141 .24013 .50758 .25937 .51895 .25581 .51276 .23759 Mtetra
.581 .514 .745 r
.51276 .23759 .51895 .25581 .53037 .25224 .52417 .2353 Mtetra
.578 .527 .762 r
.52417 .2353 .53037 .25224 .54184 .24868 .53564 .23325 Mtetra
.575 .544 .783 r
.53564 .23325 .54184 .24868 .55336 .24513 .54718 .23141 Mtetra
.571 .568 .811 r
.54718 .23141 .55336 .24513 .56494 .24164 .55879 .22973 Mtetra
.568 .599 .845 r
.55879 .22973 .56494 .24164 .57657 .23827 .57046 .22815 Mtetra
.561 .637 .884 r
.57046 .22815 .57657 .23827 .58826 .23507 .5822 .22664 Mtetra
.551 .68 .924 r
.5822 .22664 .58826 .23507 .60002 .23214 .59402 .22513 Mtetra
.534 .72 .959 r
.59402 .22513 .60002 .23214 .61184 .22951 .60591 .22363 Mtetra
.511 .751 .982 r
.60591 .22363 .61184 .22951 .62374 .22724 .61787 .22213 Mtetra
.488 .77 .994 r
.61787 .22213 .62374 .22724 .63571 .22527 .6299 .22064 Mtetra
.468 .78 .998 r
.6299 .22064 .63571 .22527 .64777 .2236 .64201 .21917 Mtetra
.458 .783 .998 r
.64201 .21917 .64777 .2236 .6599 .22214 .65419 .2177 Mtetra
.458 .784 .999 r
.65419 .2177 .6599 .22214 .67212 .22082 .66645 .21622 Mtetra
.467 .783 .998 r
.66645 .21622 .67212 .22082 .68443 .21959 .67878 .21469 Mtetra
.483 .78 .997 r
.67878 .21469 .68443 .21959 .6968 .21835 .69118 .21305 Mtetra
.502 .775 .993 r
.69118 .21305 .6968 .21835 .70926 .21709 .70366 .21131 Mtetra
.522 .768 .987 r
.70366 .21131 .70926 .21709 .72179 .21573 .7162 .20941 Mtetra
.54 .757 .977 r
.7162 .20941 .72179 .21573 .7344 .21429 .7288 .20738 Mtetra
.554 .744 .965 r
.7288 .20738 .7344 .21429 .74708 .21276 .74148 .20523 Mtetra
.566 .729 .951 r
.74148 .20523 .74708 .21276 .75983 .21113 .75422 .20298 Mtetra
.692 .759 .903 r
.08813 .42819 .09551 .43462 .10567 .42907 .09818 .42371 Mtetra
.698 .796 .925 r
.09818 .42371 .10567 .42907 .11588 .42341 .10827 .41913 Mtetra
.703 .834 .946 r
.10827 .41913 .11588 .42341 .12613 .41763 .11841 .41443 Mtetra
.704 .873 .961 r
.11841 .41443 .12613 .41763 .13641 .41173 .12861 .40956 Mtetra
.701 .908 .968 r
.12861 .40956 .13641 .41173 .14673 .40568 .13885 .40449 Mtetra
.691 .935 .965 r
.13885 .40449 .14673 .40568 .15709 .39951 .14915 .39922 Mtetra
.674 .953 .951 r
.14915 .39922 .15709 .39951 .16749 .39325 .1595 .39375 Mtetra
.65 .96 .928 r
.1595 .39375 .16749 .39325 .17791 .38693 .16989 .38811 Mtetra
.623 .958 .899 r
.16989 .38811 .17791 .38693 .18836 .38058 .18033 .38231 Mtetra
.597 .951 .87 r
.18033 .38231 .18836 .38058 .19883 .37424 .19081 .37637 Mtetra
.574 .941 .843 r
.19081 .37637 .19883 .37424 .20931 .36791 .20133 .37034 Mtetra
.555 .931 .821 r
.20133 .37034 .20931 .36791 .21983 .36158 .21187 .36423 Mtetra
.538 .922 .803 r
.21187 .36423 .21983 .36158 .23036 .35525 .22245 .35807 Mtetra
.52 .911 .786 r
.22245 .35807 .23036 .35525 .24092 .34892 .23305 .35191 Mtetra
.497 .897 .767 r
.23305 .35191 .24092 .34892 .2515 .34259 .24367 .34579 Mtetra
.464 .877 .74 r
.24367 .34579 .2515 .34259 .2621 .33631 .2543 .33977 Mtetra
.421 .848 .706 r
.2543 .33977 .2621 .33631 .27271 .33013 .26495 .3339 Mtetra
.371 .812 .664 r
.26495 .3339 .27271 .33013 .28334 .32411 .27562 .32819 Mtetra
0 0 0 r
.27562 .32819 .28334 .32411 .29398 .31829 .2863 .32267 Mtetra
.2863 .32267 .29398 .31829 .30463 .31269 .297 .31734 Mtetra
.297 .31734 .30463 .31269 .31529 .30734 .30771 .31218 Mtetra
.30771 .31218 .31529 .30734 .32597 .30222 .31845 .3072 Mtetra
.31845 .3072 .32597 .30222 .33667 .29733 .32921 .30237 Mtetra
.32921 .30237 .33667 .29733 .34739 .29265 .34 .29769 Mtetra
.34 .29769 .34739 .29265 .35814 .28815 .35082 .29315 Mtetra
.35082 .29315 .35814 .28815 .36892 .2838 .36167 .28873 Mtetra
.36167 .28873 .36892 .2838 .37973 .27958 .37255 .28443 Mtetra
.37255 .28443 .37973 .27958 .39058 .27547 .38347 .28024 Mtetra
.38347 .28024 .39058 .27547 .40147 .27144 .39443 .27616 Mtetra
.39443 .27616 .40147 .27144 .4124 .26748 .40543 .27219 Mtetra
.40543 .27219 .4124 .26748 .42337 .2636 .41647 .26831 Mtetra
.41647 .26831 .42337 .2636 .43438 .2598 .42755 .26455 Mtetra
.42755 .26455 .43438 .2598 .44543 .25611 .43868 .2609 Mtetra
.005 0 0 r
.43868 .2609 .44543 .25611 .45653 .25255 .44985 .25736 Mtetra
.022 0 0 r
.44985 .25736 .45653 .25255 .46768 .24914 .46106 .25396 Mtetra
.036 0 0 r
.46106 .25396 .46768 .24914 .47887 .24592 .47233 .25069 Mtetra
.049 0 0 r
.47233 .25069 .47887 .24592 .49012 .24291 .48365 .24757 Mtetra
.058 0 0 r
.48365 .24757 .49012 .24291 .50141 .24013 .49501 .24462 Mtetra
.064 0 0 r
.49501 .24462 .50141 .24013 .51276 .23759 .50644 .24184 Mtetra
.066 0 0 r
.50644 .24184 .51276 .23759 .52417 .2353 .51792 .23924 Mtetra
.064 0 0 r
.51792 .23924 .52417 .2353 .53564 .23325 .52946 .23684 Mtetra
.06 0 0 r
.52946 .23684 .53564 .23325 .54718 .23141 .54107 .23463 Mtetra
.052 0 0 r
.54107 .23463 .54718 .23141 .55879 .22973 .55274 .2326 Mtetra
.042 0 0 r
.55274 .2326 .55879 .22973 .57046 .22815 .56448 .23072 Mtetra
.031 0 0 r
.56448 .23072 .57046 .22815 .5822 .22664 .57629 .22894 Mtetra
.017 0 0 r
.57629 .22894 .5822 .22664 .59402 .22513 .58817 .22721 Mtetra
.002 0 0 r
.58817 .22721 .59402 .22513 .60591 .22363 .60012 .22549 Mtetra
0 0 0 r
.60012 .22549 .60591 .22363 .61787 .22213 .61214 .22372 Mtetra
.61214 .22372 .61787 .22213 .6299 .22064 .62423 .22188 Mtetra
.62423 .22188 .6299 .22064 .64201 .21917 .63638 .21994 Mtetra
.134 .679 .717 r
.63638 .21994 .64201 .21917 .65419 .2177 .64861 .21787 Mtetra
.201 .73 .786 r
.64861 .21787 .65419 .2177 .66645 .21622 .6609 .21564 Mtetra
.282 .782 .859 r
.6609 .21564 .66645 .21622 .67878 .21469 .67325 .21322 Mtetra
.37 .826 .927 r
.67325 .21322 .67878 .21469 .69118 .21305 .68566 .2106 Mtetra
.451 .85 .974 r
.68566 .2106 .69118 .21305 .70366 .21131 .69813 .20778 Mtetra
.519 .852 .996 r
.69813 .20778 .70366 .21131 .7162 .20941 .71065 .20475 Mtetra
.566 .834 .996 r
.71065 .20475 .7162 .20941 .7288 .20738 .72324 .20154 Mtetra
.596 .804 .98 r
.72324 .20154 .7288 .20738 .74148 .20523 .73587 .1982 Mtetra
.613 .77 .956 r
.73587 .1982 .74148 .20523 .75422 .20298 .74857 .19475 Mtetra
.639 .747 .927 r
.0807 .4217 .08813 .42819 .09818 .42371 .09059 .41856 Mtetra
.637 .793 .957 r
.09059 .41856 .09818 .42371 .10827 .41913 .10053 .41534 Mtetra
.629 .84 .981 r
.10053 .41534 .10827 .41913 .11841 .41443 .11053 .41199 Mtetra
.61 .882 .991 r
.11053 .41199 .11841 .41443 .12861 .40956 .12059 .40846 Mtetra
.576 .91 .975 r
.12059 .40846 .12861 .40956 .13885 .40449 .13071 .4047 Mtetra
.523 .912 .928 r
.13071 .4047 .13885 .40449 .14915 .39922 .1409 .4007 Mtetra
.456 .886 .851 r
.1409 .4007 .14915 .39922 .1595 .39375 .15116 .39642 Mtetra
.38 .836 .755 r
.15116 .39642 .1595 .39375 .16989 .38811 .16149 .39188 Mtetra
.306 .775 .654 r
.16149 .39188 .16989 .38811 .18033 .38231 .17187 .38709 Mtetra
0 0 0 r
.17187 .38709 .18033 .38231 .19081 .37637 .18231 .38211 Mtetra
.18231 .38211 .19081 .37637 .20133 .37034 .1928 .37698 Mtetra
.1928 .37698 .20133 .37034 .21187 .36423 .20332 .3718 Mtetra
.20332 .3718 .21187 .36423 .22245 .35807 .21387 .36663 Mtetra
.035 0 0 r
.21387 .36663 .22245 .35807 .23305 .35191 .22444 .36155 Mtetra
.101 0 0 r
.22444 .36155 .23305 .35191 .24367 .34579 .23503 .35663 Mtetra
.16 0 0 r
.23503 .35663 .24367 .34579 .2543 .33977 .24565 .35187 Mtetra
.209 0 .004 r
.24565 .35187 .2543 .33977 .26495 .3339 .25628 .34727 Mtetra
.247 0 .055 r
.25628 .34727 .26495 .3339 .27562 .32819 .26694 .34277 Mtetra
.275 0 .095 r
.26694 .34277 .27562 .32819 .2863 .32267 .27763 .33834 Mtetra
.295 0 .125 r
.27763 .33834 .2863 .32267 .297 .31734 .28836 .33394 Mtetra
.309 0 .147 r
.28836 .33394 .297 .31734 .30771 .31218 .29913 .32952 Mtetra
.319 0 .163 r
.29913 .32952 .30771 .31218 .31845 .3072 .30993 .3251 Mtetra
.326 0 .174 r
.30993 .3251 .31845 .3072 .32921 .30237 .32078 .32066 Mtetra
.331 0 .181 r
.32078 .32066 .32921 .30237 .34 .29769 .33167 .31621 Mtetra
.335 0 .186 r
.33167 .31621 .34 .29769 .35082 .29315 .34259 .31178 Mtetra
.338 0 .19 r
.34259 .31178 .35082 .29315 .36167 .28873 .35356 .3074 Mtetra
.341 0 .192 r
.35356 .3074 .36167 .28873 .37255 .28443 .36456 .30309 Mtetra
.345 0 .193 r
.36456 .30309 .37255 .28443 .38347 .28024 .3756 .29888 Mtetra
.348 0 .195 r
.3756 .29888 .38347 .28024 .39443 .27616 .38667 .29477 Mtetra
.352 0 .196 r
.38667 .29477 .39443 .27616 .40543 .27219 .39779 .29078 Mtetra
.356 0 .198 r
.39779 .29078 .40543 .27219 .41647 .26831 .40895 .28692 Mtetra
.36 0 .2 r
.40895 .28692 .41647 .26831 .42755 .26455 .42015 .28316 Mtetra
.363 0 .202 r
.42015 .28316 .42755 .26455 .43868 .2609 .4314 .2795 Mtetra
.366 0 .203 r
.4314 .2795 .43868 .2609 .44985 .25736 .44269 .27591 Mtetra
.367 0 .202 r
.44269 .27591 .44985 .25736 .46106 .25396 .45403 .27236 Mtetra
.367 0 .201 r
.45403 .27236 .46106 .25396 .47233 .25069 .46543 .26884 Mtetra
.365 0 .197 r
.46543 .26884 .47233 .25069 .48365 .24757 .47687 .26532 Mtetra
.361 0 .19 r
.47687 .26532 .48365 .24757 .49501 .24462 .48837 .26177 Mtetra
.356 0 .179 r
.48837 .26177 .49501 .24462 .50644 .24184 .49992 .25822 Mtetra
.348 0 .165 r
.49992 .25822 .50644 .24184 .51792 .23924 .51152 .25465 Mtetra
.339 0 .145 r
.51152 .25465 .51792 .23924 .52946 .23684 .52318 .25111 Mtetra
.327 0 .12 r
.52318 .25111 .52946 .23684 .54107 .23463 .5349 .24765 Mtetra
.313 0 .088 r
.5349 .24765 .54107 .23463 .55274 .2326 .54666 .24428 Mtetra
.297 0 .049 r
.54666 .24428 .55274 .2326 .56448 .23072 .55849 .24109 Mtetra
.278 0 .004 r
.55849 .24109 .56448 .23072 .57629 .22894 .57038 .23805 Mtetra
.256 0 0 r
.57038 .23805 .57629 .22894 .58817 .22721 .58234 .23518 Mtetra
.229 0 0 r
.58234 .23518 .58817 .22721 .60012 .22549 .59435 .23241 Mtetra
.194 0 0 r
.59435 .23241 .60012 .22549 .61214 .22372 .60644 .22965 Mtetra
.15 0 0 r
.60644 .22965 .61214 .22372 .62423 .22188 .61858 .22683 Mtetra
.092 0 0 r
.61858 .22683 .62423 .22188 .63638 .21994 .63079 .22386 Mtetra
.017 0 0 r
.63079 .22386 .63638 .21994 .64861 .21787 .64305 .2207 Mtetra
0 0 0 r
.64305 .2207 .64861 .21787 .6609 .21564 .65537 .21727 Mtetra
.203 .719 .679 r
.65537 .21727 .6609 .21564 .67325 .21322 .66774 .21358 Mtetra
.339 .819 .813 r
.66774 .21358 .67325 .21322 .68566 .2106 .68015 .2096 Mtetra
.466 .885 .918 r
.68015 .2096 .68566 .2106 .69813 .20778 .69261 .20536 Mtetra
.564 .906 .975 r
.69261 .20536 .69813 .20778 .71065 .20475 .7051 .20087 Mtetra
.625 .888 .988 r
.7051 .20087 .71065 .20475 .72324 .20154 .71765 .19619 Mtetra
.657 .849 .974 r
.71765 .19619 .72324 .20154 .73587 .1982 .73024 .19137 Mtetra
.669 .803 .946 r
.73024 .19137 .73587 .1982 .74857 .19475 .74288 .18646 Mtetra
.571 .727 .947 r
.07322 .41517 .0807 .4217 .09059 .41856 .08295 .41333 Mtetra
.557 .769 .977 r
.08295 .41333 .09059 .41856 .10053 .41534 .09273 .41143 Mtetra
.532 .809 .997 r
.09273 .41143 .10053 .41534 .11053 .41199 .10258 .40944 Mtetra
.491 .84 .996 r
.10258 .40944 .11053 .41199 .12059 .40846 .11249 .4073 Mtetra
.429 .849 .958 r
.11249 .4073 .12059 .40846 .13071 .4047 .12247 .40497 Mtetra
.343 .82 .873 r
.12247 .40497 .13071 .4047 .1409 .4007 .13253 .40243 Mtetra
.242 .754 .747 r
.13253 .40243 .1409 .4007 .15116 .39642 .14266 .39964 Mtetra
0 0 0 r
.14266 .39964 .15116 .39642 .16149 .39188 .15286 .39662 Mtetra
.15286 .39662 .16149 .39188 .17187 .38709 .16313 .39336 Mtetra
.042 0 0 r
.16313 .39336 .17187 .38709 .18231 .38211 .17346 .38991 Mtetra
.11 0 0 r
.17346 .38991 .18231 .38211 .1928 .37698 .18386 .3863 Mtetra
.165 0 0 r
.18386 .3863 .1928 .37698 .20332 .3718 .1943 .38257 Mtetra
.21 0 0 r
.1943 .38257 .20332 .3718 .21387 .36663 .2048 .37878 Mtetra
.244 0 .019 r
.2048 .37878 .21387 .36663 .22444 .36155 .21534 .37495 Mtetra
.272 0 .063 r
.21534 .37495 .22444 .36155 .23503 .35663 .22592 .37111 Mtetra
.29 0 .095 r
.22592 .37111 .23503 .35663 .24565 .35187 .23654 .36724 Mtetra
.303 0 .118 r
.23654 .36724 .24565 .35187 .25628 .34727 .24721 .36333 Mtetra
.311 0 .133 r
.24721 .36333 .25628 .34727 .26694 .34277 .25793 .35934 Mtetra
.315 0 .143 r
.25793 .35934 .26694 .34277 .27763 .33834 .2687 .35526 Mtetra
.317 0 .15 r
.2687 .35526 .27763 .33834 .28836 .33394 .27951 .35109 Mtetra
.318 0 .154 r
.27951 .35109 .28836 .33394 .29913 .32952 .29037 .34683 Mtetra
.318 0 .156 r
.29037 .34683 .29913 .32952 .30993 .3251 .30128 .3425 Mtetra
.318 0 .158 r
.30128 .3425 .30993 .3251 .32078 .32066 .31223 .33812 Mtetra
.319 0 .159 r
.31223 .33812 .32078 .32066 .33167 .31621 .32323 .33371 Mtetra
.32 0 .161 r
.32323 .33371 .33167 .31621 .34259 .31178 .33426 .32931 Mtetra
.322 0 .162 r
.33426 .32931 .34259 .31178 .35356 .3074 .34534 .32495 Mtetra
.326 0 .164 r
.34534 .32495 .35356 .3074 .36456 .30309 .35645 .32066 Mtetra
.329 0 .167 r
.35645 .32066 .36456 .30309 .3756 .29888 .3676 .31645 Mtetra
.333 0 .169 r
.3676 .31645 .3756 .29888 .38667 .29477 .37879 .31234 Mtetra
.338 0 .171 r
.37879 .31234 .38667 .29477 .39779 .29078 .39003 .30835 Mtetra
.341 0 .173 r
.39003 .30835 .39779 .29078 .40895 .28692 .4013 .30446 Mtetra
.345 0 .174 r
.4013 .30446 .40895 .28692 .42015 .28316 .41262 .30067 Mtetra
.348 0 .175 r
.41262 .30067 .42015 .28316 .4314 .2795 .42399 .29697 Mtetra
.35 0 .176 r
.42399 .29697 .4314 .2795 .44269 .27591 .4354 .29334 Mtetra
.351 0 .176 r
.4354 .29334 .44269 .27591 .45403 .27236 .44686 .28975 Mtetra
.352 0 .175 r
.44686 .28975 .45403 .27236 .46543 .26884 .45838 .28616 Mtetra
.351 0 .174 r
.45838 .28616 .46543 .26884 .47687 .26532 .46995 .28256 Mtetra
.349 0 .172 r
.46995 .28256 .47687 .26532 .48837 .26177 .48157 .2789 Mtetra
.346 0 .169 r
.48157 .2789 .48837 .26177 .49992 .25822 .49324 .27516 Mtetra
.342 0 .165 r
.49324 .27516 .49992 .25822 .51152 .25465 .50497 .27134 Mtetra
.337 0 .159 r
.50497 .27134 .51152 .25465 .52318 .25111 .51676 .26742 Mtetra
.331 0 .151 r
.51676 .26742 .52318 .25111 .5349 .24765 .52859 .26341 Mtetra
.322 0 .139 r
.52859 .26341 .5349 .24765 .54666 .24428 .54048 .25932 Mtetra
.312 0 .122 r
.54048 .25932 .54666 .24428 .55849 .24109 .55242 .25519 Mtetra
.298 0 .099 r
.55242 .25519 .55849 .24109 .57038 .23805 .56441 .25102 Mtetra
.279 0 .067 r
.56441 .25102 .57038 .23805 .58234 .23518 .57646 .24683 Mtetra
.252 0 .023 r
.57646 .24683 .58234 .23518 .59435 .23241 .58856 .24261 Mtetra
.215 0 0 r
.58856 .24261 .59435 .23241 .60644 .22965 .60071 .23831 Mtetra
.162 0 0 r
.60071 .23831 .60644 .22965 .61858 .22683 .61291 .2339 Mtetra
.088 0 0 r
.61291 .2339 .61858 .22683 .63079 .22386 .62516 .22931 Mtetra
0 0 0 r
.62516 .22931 .63079 .22386 .64305 .2207 .63745 .22452 Mtetra
.63745 .22452 .64305 .2207 .65537 .21727 .64978 .21948 Mtetra
.294 .771 .668 r
.64978 .21948 .65537 .21727 .66774 .21358 .66216 .21419 Mtetra
.448 .88 .819 r
.66216 .21419 .66774 .21358 .68015 .2096 .67457 .20863 Mtetra
.573 .936 .92 r
.67457 .20863 .68015 .2096 .69261 .20536 .68701 .20285 Mtetra
.655 .939 .965 r
.68701 .20285 .69261 .20536 .7051 .20087 .69949 .19686 Mtetra
.697 .909 .969 r
.69949 .19686 .7051 .20087 .71765 .19619 .712 .1907 Mtetra
.715 .865 .953 r
.712 .1907 .71765 .19619 .73024 .19137 .72455 .18444 Mtetra
.718 .819 .928 r
.72455 .18444 .73024 .19137 .74288 .18646 .73713 .1781 Mtetra
.5 .701 .959 r
.06568 .40859 .07322 .41517 .08295 .41333 .07527 .4078 Mtetra
.477 .731 .982 r
.07527 .4078 .08295 .41333 .09273 .41143 .08493 .40699 Mtetra
.445 .758 .995 r
.08493 .40699 .09273 .41143 .10258 .40944 .09464 .40613 Mtetra
.4 .778 .992 r
.09464 .40613 .10258 .40944 .11249 .4073 .10443 .40517 Mtetra
.34 .782 .962 r
.10443 .40517 .11249 .4073 .12247 .40497 .11428 .40408 Mtetra
.26 .759 .893 r
.11428 .40408 .12247 .40497 .13253 .40243 .12421 .40285 Mtetra
.167 .705 .783 r
.12421 .40285 .13253 .40243 .14266 .39964 .13421 .40145 Mtetra
0 0 0 r
.13421 .40145 .14266 .39964 .15286 .39662 .14428 .39987 Mtetra
.025 0 0 r
.14428 .39987 .15286 .39662 .16313 .39336 .15443 .39811 Mtetra
.104 0 0 r
.15443 .39811 .16313 .39336 .17346 .38991 .16466 .39618 Mtetra
.166 0 0 r
.16466 .39618 .17346 .38991 .18386 .3863 .17495 .39408 Mtetra
.213 0 0 r
.17495 .39408 .18386 .3863 .1943 .38257 .18531 .3918 Mtetra
.246 0 0 r
.18531 .3918 .1943 .38257 .2048 .37878 .19574 .38934 Mtetra
.268 0 0 r
.19574 .38934 .2048 .37878 .21534 .37495 .20624 .38667 Mtetra
.28 0 .025 r
.20624 .38667 .21534 .37495 .22592 .37111 .21681 .38376 Mtetra
.286 0 .05 r
.21681 .38376 .22592 .37111 .23654 .36724 .22746 .3806 Mtetra
.287 0 .066 r
.22746 .3806 .23654 .36724 .24721 .36333 .23817 .37716 Mtetra
.286 0 .075 r
.23817 .37716 .24721 .36333 .25793 .35934 .24896 .3735 Mtetra
.283 0 .08 r
.24896 .3735 .25793 .35934 .2687 .35526 .2598 .36963 Mtetra
.281 0 .083 r
.2598 .36963 .2687 .35526 .27951 .35109 .2707 .3656 Mtetra
.279 0 .084 r
.2707 .3656 .27951 .35109 .29037 .34683 .28165 .36145 Mtetra
.279 0 .087 r
.28165 .36145 .29037 .34683 .30128 .3425 .29265 .35724 Mtetra
.28 0 .09 r
.29265 .35724 .30128 .3425 .31223 .33812 .30369 .35298 Mtetra
.283 0 .094 r
.30369 .35298 .31223 .33812 .32323 .33371 .31478 .34871 Mtetra
.286 0 .099 r
.31478 .34871 .32323 .33371 .33426 .32931 .32591 .34446 Mtetra
.291 0 .104 r
.32591 .34446 .33426 .32931 .34534 .32495 .33708 .34025 Mtetra
.296 0 .109 r
.33708 .34025 .34534 .32495 .35645 .32066 .34829 .33607 Mtetra
.3 0 .114 r
.34829 .33607 .35645 .32066 .3676 .31645 .35955 .33195 Mtetra
.305 0 .118 r
.35955 .33195 .3676 .31645 .37879 .31234 .37085 .32788 Mtetra
.308 0 .12 r
.37085 .32788 .37879 .31234 .39003 .30835 .38219 .32387 Mtetra
.311 0 .121 r
.38219 .32387 .39003 .30835 .4013 .30446 .39357 .31992 Mtetra
.313 0 .121 r
.39357 .31992 .4013 .30446 .41262 .30067 .40501 .31602 Mtetra
.314 0 .12 r
.40501 .31602 .41262 .30067 .42399 .29697 .41649 .31218 Mtetra
.314 0 .118 r
.41649 .31218 .42399 .29697 .4354 .29334 .42802 .30838 Mtetra
.314 0 .115 r
.42802 .30838 .4354 .29334 .44686 .28975 .4396 .30461 Mtetra
.313 0 .111 r
.4396 .30461 .44686 .28975 .45838 .28616 .45123 .30086 Mtetra
.311 0 .108 r
.45123 .30086 .45838 .28616 .46995 .28256 .46291 .2971 Mtetra
.308 0 .104 r
.46291 .2971 .46995 .28256 .48157 .2789 .47465 .2933 Mtetra
.304 0 .099 r
.47465 .2933 .48157 .2789 .49324 .27516 .48644 .28942 Mtetra
.298 0 .094 r
.48644 .28942 .49324 .27516 .50497 .27134 .49829 .28543 Mtetra
.29 0 .088 r
.49829 .28543 .50497 .27134 .51676 .26742 .51019 .28127 Mtetra
.279 0 .078 r
.51019 .28127 .51676 .26742 .52859 .26341 .52214 .27691 Mtetra
.265 0 .065 r
.52214 .27691 .52859 .26341 .54048 .25932 .53414 .2723 Mtetra
.245 0 .045 r
.53414 .2723 .54048 .25932 .55242 .25519 .54619 .26741 Mtetra
.218 0 .016 r
.54619 .26741 .55242 .25519 .56441 .25102 .55829 .26225 Mtetra
.183 0 0 r
.55829 .26225 .56441 .25102 .57646 .24683 .57043 .25685 Mtetra
.136 0 0 r
.57043 .25685 .57646 .24683 .58856 .24261 .58261 .25122 Mtetra
.073 0 0 r
.58261 .25122 .58856 .24261 .60071 .23831 .59482 .24539 Mtetra
0 0 0 r
.59482 .24539 .60071 .23831 .61291 .2339 .60708 .23937 Mtetra
.60708 .23937 .61291 .2339 .62516 .22931 .61937 .23317 Mtetra
.61937 .23317 .62516 .22931 .63745 .22452 .6317 .22679 Mtetra
.4 .836 .699 r
.6317 .22679 .63745 .22452 .64978 .21948 .64405 .2202 Mtetra
.534 .922 .826 r
.64405 .2202 .64978 .21948 .66216 .21419 .65644 .21342 Mtetra
.637 .962 .908 r
.65644 .21342 .66216 .21419 .67457 .20863 .66886 .20645 Mtetra
.702 .96 .946 r
.66886 .20645 .67457 .20863 .68701 .20285 .6813 .19931 Mtetra
.736 .934 .953 r
.6813 .19931 .68701 .20285 .69949 .19686 .69377 .19203 Mtetra
.751 .898 .944 r
.69377 .19203 .69949 .19686 .712 .1907 .70626 .18464 Mtetra
.754 .859 .927 r
.70626 .18464 .712 .1907 .72455 .18444 .71879 .17718 Mtetra
.75 .821 .907 r
.71879 .17718 .72455 .18444 .73713 .1781 .73134 .16968 Mtetra
.458 .684 .963 r
.05808 .40196 .06568 .40859 .07527 .4078 .06762 .4017 Mtetra
.444 .697 .973 r
.06762 .4017 .07527 .4078 .08493 .40699 .07721 .40143 Mtetra
.429 .711 .983 r
.07721 .40143 .08493 .40699 .09464 .40613 .08686 .40113 Mtetra
.412 .726 .989 r
.08686 .40113 .09464 .40613 .10443 .40517 .09658 .40077 Mtetra
.395 .74 .992 r
.09658 .40077 .10443 .40517 .11428 .40408 .10637 .40032 Mtetra
.375 .753 .99 r
.10637 .40032 .11428 .40408 .12421 .40285 .11624 .39975 Mtetra
.353 .764 .981 r
.11624 .39975 .12421 .40285 .13421 .40145 .12618 .39902 Mtetra
.328 .77 .964 r
.12618 .39902 .13421 .40145 .14428 .39987 .1362 .39813 Mtetra
.301 .771 .937 r
.1362 .39813 .14428 .39987 .15443 .39811 .1463 .39704 Mtetra
.272 .765 .903 r
.1463 .39704 .15443 .39811 .16466 .39618 .15648 .39576 Mtetra
.244 .755 .863 r
.15648 .39576 .16466 .39618 .17495 .39408 .16674 .39427 Mtetra
.218 .741 .82 r
.16674 .39427 .17495 .39408 .18531 .3918 .17708 .39257 Mtetra
.194 .725 .776 r
.17708 .39257 .18531 .3918 .19574 .38934 .1875 .39065 Mtetra
.174 .708 .733 r
.1875 .39065 .19574 .38934 .20624 .38667 .19799 .38852 Mtetra
0 0 0 r
.19799 .38852 .20624 .38667 .21681 .38376 .20856 .38616 Mtetra
.20856 .38616 .21681 .38376 .22746 .3806 .2192 .38361 Mtetra
.2192 .38361 .22746 .3806 .23817 .37716 .22991 .38089 Mtetra
.22991 .38089 .23817 .37716 .24896 .3735 .24067 .37802 Mtetra
.24067 .37802 .24896 .3735 .2598 .36963 .2515 .37504 Mtetra
.04 0 0 r
.2515 .37504 .2598 .36963 .2707 .3656 .26239 .37195 Mtetra
.086 0 0 r
.26239 .37195 .2707 .3656 .28165 .36145 .27334 .36878 Mtetra
.127 0 0 r
.27334 .36878 .28165 .36145 .29265 .35724 .28434 .36552 Mtetra
.162 0 0 r
.28434 .36552 .29265 .35724 .30369 .35298 .2954 .36219 Mtetra
.19 0 0 r
.2954 .36219 .30369 .35298 .31478 .34871 .30651 .35876 Mtetra
.212 0 0 r
.30651 .35876 .31478 .34871 .32591 .34446 .31768 .35525 Mtetra
.228 0 0 r
.31768 .35525 .32591 .34446 .33708 .34025 .3289 .35165 Mtetra
.239 0 0 r
.3289 .35165 .33708 .34025 .34829 .33607 .34018 .34794 Mtetra
.245 0 .006 r
.34018 .34794 .34829 .33607 .35955 .33195 .35151 .34414 Mtetra
.248 0 .015 r
.35151 .34414 .35955 .33195 .37085 .32788 .3629 .34022 Mtetra
.247 0 .019 r
.3629 .34022 .37085 .32788 .38219 .32387 .37434 .3362 Mtetra
.243 0 .017 r
.37434 .3362 .38219 .32387 .39357 .31992 .38583 .33206 Mtetra
.235 0 .008 r
.38583 .33206 .39357 .31992 .40501 .31602 .39738 .32782 Mtetra
.223 0 0 r
.39738 .32782 .40501 .31602 .41649 .31218 .40898 .32347 Mtetra
.207 0 0 r
.40898 .32347 .41649 .31218 .42802 .30838 .42063 .31902 Mtetra
.185 0 0 r
.42063 .31902 .42802 .30838 .4396 .30461 .43233 .31448 Mtetra
.157 0 0 r
.43233 .31448 .4396 .30461 .45123 .30086 .44408 .30984 Mtetra
.122 0 0 r
.44408 .30984 .45123 .30086 .46291 .2971 .45587 .30511 Mtetra
.079 0 0 r
.45587 .30511 .46291 .2971 .47465 .2933 .46772 .3003 Mtetra
.025 0 0 r
.46772 .3003 .47465 .2933 .48644 .28942 .47962 .2954 Mtetra
0 0 0 r
.47962 .2954 .48644 .28942 .49829 .28543 .49156 .2904 Mtetra
.49156 .2904 .49829 .28543 .51019 .28127 .50354 .2853 Mtetra
.50354 .2853 .51019 .28127 .52214 .27691 .51558 .28007 Mtetra
.51558 .28007 .52214 .27691 .53414 .2723 .52766 .27469 Mtetra
.344 .806 .699 r
.52766 .27469 .53414 .2723 .54619 .26741 .53978 .26913 Mtetra
.414 .856 .762 r
.53978 .26913 .54619 .26741 .55829 .26225 .55195 .26335 Mtetra
.478 .895 .814 r
.55195 .26335 .55829 .26225 .57043 .25685 .56415 .25735 Mtetra
.536 .925 .856 r
.56415 .25735 .57043 .25685 .58261 .25122 .57639 .25111 Mtetra
.588 .946 .89 r
.57639 .25111 .58261 .25122 .59482 .24539 .58867 .24464 Mtetra
.634 .959 .917 r
.58867 .24464 .59482 .24539 .60708 .23937 .60098 .23794 Mtetra
.675 .963 .936 r
.60098 .23794 .60708 .23937 .61937 .23317 .61332 .23101 Mtetra
.708 .958 .947 r
.61332 .23101 .61937 .23317 .6317 .22679 .62569 .22387 Mtetra
.733 .947 .95 r
.62569 .22387 .6317 .22679 .64405 .2202 .63808 .21652 Mtetra
.75 .929 .948 r
.63808 .21652 .64405 .2202 .65644 .21342 .6505 .20898 Mtetra
.761 .909 .941 r
.6505 .20898 .65644 .21342 .66886 .20645 .66294 .20126 Mtetra
.767 .887 .931 r
.66294 .20126 .66886 .20645 .6813 .19931 .6754 .1934 Mtetra
.769 .866 .92 r
.6754 .1934 .6813 .19931 .69377 .19203 .68789 .18544 Mtetra
.768 .845 .91 r
.68789 .18544 .69377 .19203 .70626 .18464 .7004 .17739 Mtetra
.766 .826 .899 r
.7004 .17739 .70626 .18464 .71879 .17718 .71294 .16929 Mtetra
.762 .807 .889 r
.71294 .16929 .71879 .17718 .73134 .16968 .7255 .16118 Mtetra
.457 .683 .963 r
.05043 .39529 .05808 .40196 .06762 .4017 .05998 .39501 Mtetra
.456 .683 .963 r
.05998 .39501 .06762 .4017 .07721 .40143 .06957 .39475 Mtetra
.456 .684 .964 r
.06957 .39475 .07721 .40143 .08686 .40113 .07924 .39448 Mtetra
.458 .687 .964 r
.07924 .39448 .08686 .40113 .09658 .40077 .08896 .39416 Mtetra
.462 .691 .965 r
.08896 .39416 .09658 .40077 .10637 .40032 .09875 .39377 Mtetra
.468 .696 .967 r
.09875 .39377 .10637 .40032 .11624 .39975 .10862 .39328 Mtetra
.476 .703 .968 r
.10862 .39328 .11624 .39975 .12618 .39902 .11856 .39265 Mtetra
.486 .712 .97 r
.11856 .39265 .12618 .39902 .1362 .39813 .12859 .39185 Mtetra
.498 .721 .971 r
.12859 .39185 .1362 .39813 .1463 .39704 .1387 .39085 Mtetra
.511 .729 .972 r
.1387 .39085 .1463 .39704 .15648 .39576 .14888 .38964 Mtetra
.524 .738 .972 r
.14888 .38964 .15648 .39576 .16674 .39427 .15916 .3882 Mtetra
.536 .745 .972 r
.15916 .3882 .16674 .39427 .17708 .39257 .16951 .38656 Mtetra
.547 .752 .972 r
.16951 .38656 .17708 .39257 .1875 .39065 .17994 .38471 Mtetra
.555 .758 .972 r
.17994 .38471 .1875 .39065 .19799 .38852 .19044 .38272 Mtetra
.559 .765 .975 r
.19044 .38272 .19799 .38852 .20856 .38616 .201 .38061 Mtetra
.557 .774 .979 r
.201 .38061 .20856 .38616 .2192 .38361 .21163 .37845 Mtetra
.549 .786 .986 r
.21163 .37845 .2192 .38361 .22991 .38089 .22231 .37628 Mtetra
.536 .801 .994 r
.22231 .37628 .22991 .38089 .24067 .37802 .23305 .3741 Mtetra
.513 .817 1 r
.23305 .3741 .24067 .37802 .2515 .37504 .24384 .37194 Mtetra
.482 .831 .997 r
.24384 .37194 .2515 .37504 .26239 .37195 .25468 .36974 Mtetra
.441 .838 .979 r
.25468 .36974 .26239 .37195 .27334 .36878 .26559 .36749 Mtetra
.391 .832 .943 r
.26559 .36749 .27334 .36878 .28434 .36552 .27657 .36514 Mtetra
.336 .814 .89 r
.27657 .36514 .28434 .36552 .2954 .36219 .28761 .36266 Mtetra
.283 .785 .826 r
.28761 .36266 .2954 .36219 .30651 .35876 .29872 .36001 Mtetra
.238 .753 .762 r
.29872 .36001 .30651 .35876 .31768 .35525 .3099 .35716 Mtetra
.203 .724 .704 r
.3099 .35716 .31768 .35525 .3289 .35165 .32114 .3541 Mtetra
0 0 0 r
.32114 .3541 .3289 .35165 .34018 .34794 .33246 .35081 Mtetra
.33246 .35081 .34018 .34794 .35151 .34414 .34384 .34727 Mtetra
.34384 .34727 .35151 .34414 .3629 .34022 .35528 .34348 Mtetra
.35528 .34348 .3629 .34022 .37434 .3362 .36679 .33943 Mtetra
.36679 .33943 .37434 .3362 .38583 .33206 .37836 .33513 Mtetra
.37836 .33513 .38583 .33206 .39738 .32782 .38999 .33057 Mtetra
.294 .774 .683 r
.38999 .33057 .39738 .32782 .40898 .32347 .40168 .32576 Mtetra
.351 .817 .732 r
.40168 .32576 .40898 .32347 .42063 .31902 .41342 .32072 Mtetra
.417 .861 .788 r
.41342 .32072 .42063 .31902 .43233 .31448 .4252 .31545 Mtetra
.486 .901 .846 r
.4252 .31545 .43233 .31448 .44408 .30984 .43704 .30998 Mtetra
.553 .931 .898 r
.43704 .30998 .44408 .30984 .45587 .30511 .44892 .30434 Mtetra
.611 .945 .937 r
.44892 .30434 .45587 .30511 .46772 .3003 .46085 .29855 Mtetra
.655 .943 .961 r
.46085 .29855 .46772 .3003 .47962 .2954 .47282 .29266 Mtetra
.685 .928 .97 r
.47282 .29266 .47962 .2954 .49156 .2904 .48483 .28671 Mtetra
.702 .904 .968 r
.48483 .28671 .49156 .2904 .50354 .2853 .49687 .28071 Mtetra
.709 .879 .96 r
.49687 .28071 .50354 .2853 .51558 .28007 .50896 .27471 Mtetra
.713 .855 .95 r
.50896 .27471 .51558 .28007 .52766 .27469 .52109 .26871 Mtetra
.713 .836 .94 r
.52109 .26871 .52766 .27469 .53978 .26913 .53326 .26268 Mtetra
.715 .823 .932 r
.53326 .26268 .53978 .26913 .55195 .26335 .54546 .2566 Mtetra
.718 .815 .925 r
.54546 .2566 .55195 .26335 .56415 .25735 .55771 .25038 Mtetra
.722 .811 .92 r
.55771 .25038 .56415 .25735 .57639 .25111 .57 .244 Mtetra
.727 .809 .915 r
.57 .244 .57639 .25111 .58867 .24464 .58232 .23741 Mtetra
.733 .808 .911 r
.58232 .23741 .58867 .24464 .60098 .23794 .59467 .23059 Mtetra
.739 .807 .906 r
.59467 .23059 .60098 .23794 .61332 .23101 .60705 .22353 Mtetra
.744 .806 .901 r
.60705 .22353 .61332 .23101 .62569 .22387 .61946 .21623 Mtetra
.749 .804 .897 r
.61946 .21623 .62569 .22387 .63808 .21652 .63189 .20872 Mtetra
.752 .802 .892 r
.63189 .20872 .63808 .21652 .6505 .20898 .64435 .20102 Mtetra
.755 .799 .888 r
.64435 .20102 .6505 .20898 .66294 .20126 .65683 .19315 Mtetra
.757 .796 .885 r
.65683 .19315 .66294 .20126 .6754 .1934 .66934 .18516 Mtetra
.758 .794 .882 r
.66934 .18516 .6754 .1934 .68789 .18544 .68187 .17708 Mtetra
.759 .792 .881 r
.68187 .17708 .68789 .18544 .7004 .17739 .69442 .16895 Mtetra
.759 .791 .88 r
.69442 .16895 .7004 .17739 .71294 .16929 .70701 .16078 Mtetra
.758 .79 .879 r
.70701 .16078 .71294 .16929 .7255 .16118 .71961 .15261 Mtetra
.506 .703 .959 r
.04273 .38856 .05043 .39529 .05998 .39501 .05238 .38762 Mtetra
.515 .685 .944 r
.05238 .38762 .05998 .39501 .06957 .39475 .06208 .3867 Mtetra
.523 .668 .928 r
.06208 .3867 .06957 .39475 .07924 .39448 .07184 .38577 Mtetra
.529 .652 .913 r
.07184 .38577 .07924 .39448 .08896 .39416 .08165 .38482 Mtetra
.535 .637 .898 r
.08165 .38482 .08896 .39416 .09875 .39377 .09153 .38383 Mtetra
.541 .625 .884 r
.09153 .38383 .09875 .39377 .10862 .39328 .10147 .38278 Mtetra
.547 .614 .872 r
.10147 .38278 .10862 .39328 .11856 .39265 .11148 .38165 Mtetra
.553 .606 .861 r
.11148 .38165 .11856 .39265 .12859 .39185 .12156 .3804 Mtetra
.558 .6 .851 r
.12156 .3804 .12859 .39185 .1387 .39085 .13171 .37903 Mtetra
.563 .595 .843 r
.13171 .37903 .1387 .39085 .14888 .38964 .14194 .37753 Mtetra
.568 .592 .838 r
.14194 .37753 .14888 .38964 .15916 .3882 .15223 .37588 Mtetra
.572 .591 .833 r
.15223 .37588 .15916 .3882 .16951 .38656 .1626 .37411 Mtetra
.576 .591 .831 r
.1626 .37411 .16951 .38656 .17994 .38471 .17303 .37222 Mtetra
.579 .592 .83 r
.17303 .37222 .17994 .38471 .19044 .38272 .18353 .37022 Mtetra
.582 .594 .83 r
.18353 .37022 .19044 .38272 .201 .38061 .19409 .36815 Mtetra
.584 .597 .831 r
.19409 .36815 .201 .38061 .21163 .37845 .20472 .36601 Mtetra
.585 .598 .832 r
.20472 .36601 .21163 .37845 .22231 .37628 .2154 .36381 Mtetra
.587 .6 .832 r
.2154 .36381 .22231 .37628 .23305 .3741 .22615 .36153 Mtetra
.589 .599 .83 r
.22615 .36153 .23305 .3741 .24384 .37194 .23696 .35918 Mtetra
.592 .598 .827 r
.23696 .35918 .24384 .37194 .25468 .36974 .24783 .35672 Mtetra
.595 .595 .822 r
.24783 .35672 .25468 .36974 .26559 .36749 .25877 .35413 Mtetra
.598 .592 .816 r
.25877 .35413 .26559 .36749 .27657 .36514 .26978 .35141 Mtetra
.601 .588 .81 r
.26978 .35141 .27657 .36514 .28761 .36266 .28085 .34854 Mtetra
.604 .584 .804 r
.28085 .34854 .28761 .36266 .29872 .36001 .29199 .3455 Mtetra
.607 .58 .797 r
.29199 .3455 .29872 .36001 .3099 .35716 .30319 .34228 Mtetra
.61 .577 .792 r
.30319 .34228 .3099 .35716 .32114 .3541 .31446 .3389 Mtetra
.613 .574 .787 r
.31446 .3389 .32114 .3541 .33246 .35081 .32578 .33533 Mtetra
.616 .573 .783 r
.32578 .33533 .33246 .35081 .34384 .34727 .33718 .33159 Mtetra
.619 .572 .78 r
.33718 .33159 .34384 .34727 .35528 .34348 .34863 .32768 Mtetra
.622 .573 .778 r
.34863 .32768 .35528 .34348 .36679 .33943 .36014 .32359 Mtetra
.626 .575 .777 r
.36014 .32359 .36679 .33943 .37836 .33513 .37171 .31933 Mtetra
.63 .578 .778 r
.37171 .31933 .37836 .33513 .38999 .33057 .38333 .3149 Mtetra
.634 .582 .779 r
.38333 .3149 .38999 .33057 .40168 .32576 .39501 .31028 Mtetra
.638 .588 .781 r
.39501 .31028 .40168 .32576 .41342 .32072 .40674 .30549 Mtetra
.643 .594 .784 r
.40674 .30549 .41342 .32072 .4252 .31545 .41853 .30051 Mtetra
.648 .601 .788 r
.41853 .30051 .4252 .31545 .43704 .30998 .43036 .29536 Mtetra
.653 .608 .791 r
.43036 .29536 .43704 .30998 .44892 .30434 .44225 .29004 Mtetra
.658 .616 .796 r
.44225 .29004 .44892 .30434 .46085 .29855 .45418 .28456 Mtetra
.663 .623 .799 r
.45418 .28456 .46085 .29855 .47282 .29266 .46615 .27892 Mtetra
.667 .63 .803 r
.46615 .27892 .47282 .29266 .48483 .28671 .47817 .27316 Mtetra
.671 .635 .806 r
.47817 .27316 .48483 .28671 .49687 .28071 .49023 .26728 Mtetra
.673 .639 .807 r
.49023 .26728 .49687 .28071 .50896 .27471 .50234 .26132 Mtetra
.675 .641 .808 r
.50234 .26132 .50896 .27471 .52109 .26871 .51448 .25527 Mtetra
.676 .641 .807 r
.51448 .25527 .52109 .26871 .53326 .26268 .52667 .24915 Mtetra
.677 .641 .806 r
.52667 .24915 .53326 .26268 .54546 .2566 .53889 .24295 Mtetra
.678 .64 .805 r
.53889 .24295 .54546 .2566 .55771 .25038 .55116 .23666 Mtetra
.68 .64 .803 r
.55116 .23666 .55771 .25038 .57 .244 .56346 .23026 Mtetra
.682 .641 .803 r
.56346 .23026 .57 .244 .58232 .23741 .5758 .22372 Mtetra
.685 .644 .803 r
.5758 .22372 .58232 .23741 .59467 .23059 .58817 .21705 Mtetra
.689 .649 .805 r
.58817 .21705 .59467 .23059 .60705 .22353 .60058 .21021 Mtetra
.694 .656 .808 r
.60058 .21021 .60705 .22353 .61946 .21623 .61302 .20323 Mtetra
.699 .664 .812 r
.61302 .20323 .61946 .21623 .63189 .20872 .6255 .1961 Mtetra
.704 .674 .817 r
.6255 .1961 .63189 .20872 .64435 .20102 .638 .18885 Mtetra
.71 .685 .824 r
.638 .18885 .64435 .20102 .65683 .19315 .65053 .18149 Mtetra
.715 .698 .832 r
.65053 .18149 .65683 .19315 .66934 .18516 .6631 .17406 Mtetra
.721 .713 .842 r
.6631 .17406 .66934 .18516 .68187 .17708 .67569 .16657 Mtetra
.726 .729 .852 r
.67569 .16657 .68187 .17708 .69442 .16895 .68832 .15905 Mtetra
.732 .746 .863 r
.68832 .15905 .69442 .16895 .70701 .16078 .70098 .15151 Mtetra
.736 .764 .876 r
.70098 .15151 .70701 .16078 .71961 .15261 .71368 .14397 Mtetra
.576 .728 .946 r
.03496 .38178 .04273 .38856 .05238 .38762 .04479 .37975 Mtetra
.581 .696 .921 r
.04479 .37975 .05238 .38762 .06208 .3867 .05466 .37772 Mtetra
.583 .667 .896 r
.05466 .37772 .06208 .3867 .07184 .38577 .06458 .3757 Mtetra
.584 .64 .872 r
.06458 .3757 .07184 .38577 .08165 .38482 .07455 .37368 Mtetra
.584 .616 .85 r
.07455 .37368 .08165 .38482 .09153 .38383 .08457 .37166 Mtetra
.583 .595 .831 r
.08457 .37166 .09153 .38383 .10147 .38278 .09464 .36961 Mtetra
.582 .578 .813 r
.09464 .36961 .10147 .38278 .11148 .38165 .10476 .36753 Mtetra
.581 .563 .798 r
.10476 .36753 .11148 .38165 .12156 .3804 .11495 .36542 Mtetra
.58 .55 .786 r
.11495 .36542 .12156 .3804 .13171 .37903 .12518 .36327 Mtetra
.579 .54 .775 r
.12518 .36327 .13171 .37903 .14194 .37753 .13548 .36108 Mtetra
.579 .531 .766 r
.13548 .36108 .14194 .37753 .15223 .37588 .14583 .35886 Mtetra
.578 .525 .759 r
.14583 .35886 .15223 .37588 .1626 .37411 .15623 .3566 Mtetra
.578 .52 .754 r
.15623 .3566 .1626 .37411 .17303 .37222 .1667 .35431 Mtetra
.578 .516 .75 r
.1667 .35431 .17303 .37222 .18353 .37022 .17722 .35196 Mtetra
.578 .513 .746 r
.17722 .35196 .18353 .37022 .19409 .36815 .1878 .34956 Mtetra
.58 .511 .743 r
.1878 .34956 .19409 .36815 .20472 .36601 .19844 .34704 Mtetra
.582 .51 .739 r
.19844 .34704 .20472 .36601 .2154 .36381 .20915 .34439 Mtetra
.584 .507 .734 r
.20915 .34439 .2154 .36381 .22615 .36153 .21993 .34158 Mtetra
.586 .504 .729 r
.21993 .34158 .22615 .36153 .23696 .35918 .23078 .33857 Mtetra
.588 .5 .723 r
.23078 .33857 .23696 .35918 .24783 .35672 .24169 .33538 Mtetra
.589 .496 .716 r
.24169 .33538 .24783 .35672 .25877 .35413 .25267 .33202 Mtetra
.59 .491 .71 r
.25267 .33202 .25877 .35413 .26978 .35141 .26372 .3285 Mtetra
.59 .486 .704 r
.26372 .3285 .26978 .35141 .28085 .34854 .27482 .32484 Mtetra
.59 .481 .698 r
.27482 .32484 .28085 .34854 .29199 .3455 .28598 .32106 Mtetra
.589 .476 .693 r
.28598 .32106 .29199 .3455 .30319 .34228 .2972 .31718 Mtetra
.589 .472 .688 r
.2972 .31718 .30319 .34228 .31446 .3389 .30847 .31323 Mtetra
.588 .469 .685 r
.30847 .31323 .31446 .3389 .32578 .33533 .31979 .30921 Mtetra
.588 .467 .682 r
.31979 .30921 .32578 .33533 .33718 .33159 .33116 .30514 Mtetra
.587 .465 .68 r
.33116 .30514 .33718 .33159 .34863 .32768 .34258 .30104 Mtetra
.587 .464 .68 r
.34258 .30104 .34863 .32768 .36014 .32359 .35406 .2969 Mtetra
.587 .464 .679 r
.35406 .2969 .36014 .32359 .37171 .31933 .36558 .29273 Mtetra
.588 .465 .68 r
.36558 .29273 .37171 .31933 .38333 .3149 .37716 .28853 Mtetra
.589 .468 .682 r
.37716 .28853 .38333 .3149 .39501 .31028 .38878 .28427 Mtetra
.591 .471 .685 r
.38878 .28427 .39501 .31028 .40674 .30549 .40046 .27996 Mtetra
.593 .475 .688 r
.40046 .27996 .40674 .30549 .41853 .30051 .41219 .27556 Mtetra
.596 .481 .692 r
.41219 .27556 .41853 .30051 .43036 .29536 .42397 .27106 Mtetra
.6 .487 .697 r
.42397 .27106 .43036 .29536 .44225 .29004 .43581 .26644 Mtetra
.604 .494 .702 r
.43581 .26644 .44225 .29004 .45418 .28456 .44769 .26167 Mtetra
.609 .502 .707 r
.44769 .26167 .45418 .28456 .46615 .27892 .45963 .25674 Mtetra
.614 .511 .713 r
.45963 .25674 .46615 .27892 .47817 .27316 .47162 .25163 Mtetra
.619 .519 .718 r
.47162 .25163 .47817 .27316 .49023 .26728 .48366 .24633 Mtetra
.625 .527 .723 r
.48366 .24633 .49023 .26728 .50234 .26132 .49575 .24083 Mtetra
.63 .534 .727 r
.49575 .24083 .50234 .26132 .51448 .25527 .50788 .23515 Mtetra
.634 .54 .731 r
.50788 .23515 .51448 .25527 .52667 .24915 .52006 .22933 Mtetra
.637 .544 .733 r
.52006 .22933 .52667 .24915 .53889 .24295 .53227 .22339 Mtetra
.639 .548 .736 r
.53227 .22339 .53889 .24295 .55116 .23666 .54453 .21737 Mtetra
.641 .552 .739 r
.54453 .21737 .55116 .23666 .56346 .23026 .55683 .2113 Mtetra
.643 .557 .742 r
.55683 .2113 .56346 .23026 .5758 .22372 .56918 .20518 Mtetra
.646 .563 .747 r
.56918 .20518 .5758 .22372 .58817 .21705 .58156 .19901 Mtetra
.649 .57 .753 r
.58156 .19901 .58817 .21705 .60058 .21021 .59399 .19281 Mtetra
.653 .58 .76 r
.59399 .19281 .60058 .21021 .61302 .20323 .60646 .18655 Mtetra
.658 .591 .769 r
.60646 .18655 .61302 .20323 .6255 .1961 .61896 .18024 Mtetra
.664 .605 .779 r
.61896 .18024 .6255 .1961 .638 .18885 .63151 .17389 Mtetra
.67 .621 .791 r
.63151 .17389 .638 .18885 .65053 .18149 .6441 .1675 Mtetra
.676 .64 .806 r
.6441 .1675 .65053 .18149 .6631 .17406 .65673 .16107 Mtetra
.683 .661 .822 r
.65673 .16107 .6631 .17406 .67569 .16657 .66941 .15463 Mtetra
.691 .685 .839 r
.66941 .15463 .67569 .16657 .68832 .15905 .68212 .14817 Mtetra
.698 .711 .859 r
.68212 .14817 .68832 .15905 .70098 .15151 .69489 .14171 Mtetra
.704 .741 .88 r
.69489 .14171 .70098 .15151 .71368 .14397 .70769 .13525 Mtetra
.642 .748 .926 r
.02714 .37496 .03496 .38178 .04479 .37975 .03719 .37156 Mtetra
.64 .708 .896 r
.03719 .37156 .04479 .37975 .05466 .37772 .04727 .36817 Mtetra
.635 .672 .868 r
.04727 .36817 .05466 .37772 .06458 .3757 .05739 .3648 Mtetra
.63 .641 .843 r
.05739 .3648 .06458 .3757 .07455 .37368 .06756 .36144 Mtetra
.623 .613 .819 r
.06756 .36144 .07455 .37368 .08457 .37166 .07776 .35809 Mtetra
.617 .589 .799 r
.07776 .35809 .08457 .37166 .09464 .36961 .088 .35476 Mtetra
.612 .568 .781 r
.088 .35476 .09464 .36961 .10476 .36753 .09829 .35144 Mtetra
.606 .55 .765 r
.09829 .35144 .10476 .36753 .11495 .36542 .10861 .34814 Mtetra
.601 .534 .751 r
.10861 .34814 .11495 .36542 .12518 .36327 .11898 .34486 Mtetra
.597 .521 .739 r
.11898 .34486 .12518 .36327 .13548 .36108 .12939 .34161 Mtetra
.593 .509 .729 r
.12939 .34161 .13548 .36108 .14583 .35886 .13983 .3384 Mtetra
.589 .499 .72 r
.13983 .3384 .14583 .35886 .15623 .3566 .15032 .33521 Mtetra
.586 .49 .712 r
.15032 .33521 .15623 .3566 .1667 .35431 .16086 .33205 Mtetra
.583 .482 .705 r
.16086 .33205 .1667 .35431 .17722 .35196 .17144 .32888 Mtetra
.582 .476 .699 r
.17144 .32888 .17722 .35196 .1878 .34956 .18207 .32567 Mtetra
.581 .471 .693 r
.18207 .32567 .1878 .34956 .19844 .34704 .19277 .32237 Mtetra
.582 .467 .688 r
.19277 .32237 .19844 .34704 .20915 .34439 .20352 .31892 Mtetra
.582 .464 .683 r
.20352 .31892 .20915 .34439 .21993 .34158 .21434 .3153 Mtetra
.583 .46 .678 r
.21434 .3153 .21993 .34158 .23078 .33857 .22522 .3115 Mtetra
.584 .457 .673 r
.22522 .3115 .23078 .33857 .24169 .33538 .23616 .30753 Mtetra
.584 .454 .669 r
.23616 .30753 .24169 .33538 .25267 .33202 .24716 .30342 Mtetra
.584 .45 .665 r
.24716 .30342 .25267 .33202 .26372 .3285 .25822 .29919 Mtetra
.583 .447 .661 r
.25822 .29919 .26372 .3285 .27482 .32484 .26932 .29487 Mtetra
.583 .444 .658 r
.26932 .29487 .27482 .32484 .28598 .32106 .28048 .29051 Mtetra
.581 .441 .656 r
.28048 .29051 .28598 .32106 .2972 .31718 .29168 .28612 Mtetra
.58 .439 .653 r
.29168 .28612 .2972 .31718 .30847 .31323 .30292 .28174 Mtetra
.579 .436 .652 r
.30292 .28174 .30847 .31323 .31979 .30921 .31421 .27738 Mtetra
.577 .434 .65 r
.31421 .27738 .31979 .30921 .33116 .30514 .32554 .27307 Mtetra
.576 .433 .65 r
.32554 .27307 .33116 .30514 .34258 .30104 .33691 .26882 Mtetra
.575 .432 .649 r
.33691 .26882 .34258 .30104 .35406 .2969 .34833 .26463 Mtetra
.574 .431 .649 r
.34833 .26463 .35406 .2969 .36558 .29273 .35979 .26051 Mtetra
.573 .431 .65 r
.35979 .26051 .36558 .29273 .37716 .28853 .37129 .25644 Mtetra
.572 .431 .651 r
.37129 .25644 .37716 .28853 .38878 .28427 .38285 .25242 Mtetra
.572 .432 .652 r
.38285 .25242 .38878 .28427 .40046 .27996 .39445 .24842 Mtetra
.573 .434 .654 r
.39445 .24842 .40046 .27996 .41219 .27556 .40611 .24444 Mtetra
.574 .436 .656 r
.40611 .24444 .41219 .27556 .42397 .27106 .41782 .24043 Mtetra
.575 .439 .659 r
.41782 .24043 .42397 .27106 .43581 .26644 .42958 .23636 Mtetra
.577 .443 .662 r
.42958 .23636 .43581 .26644 .44769 .26167 .4414 .23221 Mtetra
.58 .448 .665 r
.4414 .23221 .44769 .26167 .45963 .25674 .45328 .22795 Mtetra
.584 .453 .669 r
.45328 .22795 .45963 .25674 .47162 .25163 .46521 .22353 Mtetra
.587 .459 .673 r
.46521 .22353 .47162 .25163 .48366 .24633 .47719 .21894 Mtetra
.592 .466 .677 r
.47719 .21894 .48366 .24633 .49575 .24083 .48923 .21416 Mtetra
.596 .472 .682 r
.48923 .21416 .49575 .24083 .50788 .23515 .50132 .2092 Mtetra
.6 .479 .686 r
.50132 .2092 .50788 .23515 .52006 .22933 .51346 .20409 Mtetra
.604 .485 .691 r
.51346 .20409 .52006 .22933 .53227 .22339 .52565 .19887 Mtetra
.606 .492 .697 r
.52565 .19887 .53227 .22339 .54453 .21737 .53789 .19362 Mtetra
.609 .498 .702 r
.53789 .19362 .54453 .21737 .55683 .2113 .55017 .18835 Mtetra
.611 .506 .709 r
.55017 .18835 .55683 .2113 .56918 .20518 .56251 .18309 Mtetra
.614 .514 .717 r
.56251 .18309 .56918 .20518 .58156 .19901 .57489 .17786 Mtetra
.617 .523 .725 r
.57489 .17786 .58156 .19901 .59399 .19281 .58732 .17267 Mtetra
.62 .534 .735 r
.58732 .17267 .59399 .19281 .60646 .18655 .59981 .16749 Mtetra
.624 .547 .747 r
.59981 .16749 .60646 .18655 .61896 .18024 .61235 .16233 Mtetra
.629 .562 .76 r
.61235 .16233 .61896 .18024 .63151 .17389 .62494 .15719 Mtetra
.634 .58 .776 r
.62494 .15719 .63151 .17389 .6441 .1675 .63759 .15205 Mtetra
.64 .6 .793 r
.63759 .15205 .6441 .1675 .65673 .16107 .65029 .14692 Mtetra
.646 .623 .813 r
.65029 .14692 .65673 .16107 .66941 .15463 .66305 .1418 Mtetra
.652 .65 .836 r
.66305 .1418 .66941 .15463 .68212 .14817 .67586 .13668 Mtetra
.658 .681 .861 r
.67586 .13668 .68212 .14817 .69489 .14171 .68873 .13157 Mtetra
.663 .717 .888 r
.68873 .13157 .69489 .14171 .70769 .13525 .70165 .12647 Mtetra
.697 .76 .901 r
.01926 .36808 .02714 .37496 .03719 .37156 .02955 .36321 Mtetra
.688 .719 .873 r
.02955 .36321 .03719 .37156 .04727 .36817 .03987 .35836 Mtetra
.678 .682 .847 r
.03987 .35836 .04727 .36817 .05739 .3648 .05022 .35354 Mtetra
.668 .65 .823 r
.05022 .35354 .05739 .3648 .06756 .36144 .0606 .34873 Mtetra
.658 .621 .801 r
.0606 .34873 .06756 .36144 .07776 .35809 .07101 .34395 Mtetra
.649 .596 .782 r
.07101 .34395 .07776 .35809 .088 .35476 .08145 .33919 Mtetra
.641 .574 .764 r
.08145 .33919 .088 .35476 .09829 .35144 .09192 .33446 Mtetra
.633 .555 .748 r
.09192 .33446 .09829 .35144 .10861 .34814 .10242 .32974 Mtetra
.626 .537 .734 r
.10242 .32974 .10861 .34814 .11898 .34486 .11295 .32505 Mtetra
.619 .521 .721 r
.11295 .32505 .11898 .34486 .12939 .34161 .12352 .32038 Mtetra
.613 .507 .709 r
.12352 .32038 .12939 .34161 .13983 .3384 .13412 .31573 Mtetra
.608 .494 .698 r
.13412 .31573 .13983 .3384 .15032 .33521 .14476 .3111 Mtetra
.602 .482 .688 r
.14476 .3111 .15032 .33521 .16086 .33205 .15542 .3065 Mtetra
.597 .471 .679 r
.15542 .3065 .16086 .33205 .17144 .32888 .16613 .30191 Mtetra
.593 .462 .671 r
.16613 .30191 .17144 .32888 .18207 .32567 .17687 .29735 Mtetra
.589 .453 .664 r
.17687 .29735 .18207 .32567 .19277 .32237 .18765 .29281 Mtetra
.586 .446 .658 r
.18765 .29281 .19277 .32237 .20352 .31892 .19846 .28829 Mtetra
.583 .44 .653 r
.19846 .28829 .20352 .31892 .21434 .3153 .20931 .2838 Mtetra
.58 .435 .649 r
.20931 .2838 .21434 .3153 .22522 .3115 .2202 .27932 Mtetra
.578 .432 .646 r
.2202 .27932 .22522 .3115 .23616 .30753 .23113 .27487 Mtetra
.577 .429 .644 r
.23113 .27487 .23616 .30753 .24716 .30342 .2421 .27043 Mtetra
.576 .428 .643 r
.2421 .27043 .24716 .30342 .25822 .29919 .25311 .26602 Mtetra
.575 .427 .642 r
.25311 .26602 .25822 .29919 .26932 .29487 .26416 .26163 Mtetra
.575 .426 .642 r
.26416 .26163 .26932 .29487 .28048 .29051 .27525 .25726 Mtetra
.574 .426 .642 r
.27525 .25726 .28048 .29051 .29168 .28612 .28638 .25292 Mtetra
.574 .426 .643 r
.28638 .25292 .29168 .28612 .30292 .28174 .29756 .24859 Mtetra
.29756 .24859 .30292 .28174 .31421 .27738 .30878 .24429 Mtetra
.573 .426 .644 r
.30878 .24429 .31421 .27738 .32554 .27307 .32004 .24 Mtetra
.32004 .24 .32554 .27307 .33691 .26882 .33135 .23574 Mtetra
.33135 .23574 .33691 .26882 .34833 .26463 .34271 .2315 Mtetra
.572 .426 .644 r
.34271 .2315 .34833 .26463 .35979 .26051 .35411 .22728 Mtetra
.572 .425 .644 r
.35411 .22728 .35979 .26051 .37129 .25644 .36556 .22308 Mtetra
.571 .425 .644 r
.36556 .22308 .37129 .25644 .38285 .25242 .37706 .2189 Mtetra
.57 .424 .643 r
.37706 .2189 .38285 .25242 .39445 .24842 .3886 .21474 Mtetra
.57 .423 .643 r
.3886 .21474 .39445 .24842 .40611 .24444 .4002 .21061 Mtetra
.569 .422 .642 r
.4002 .21061 .40611 .24444 .41782 .24043 .41184 .20649 Mtetra
.568 .422 .642 r
.41184 .20649 .41782 .24043 .42958 .23636 .42354 .2024 Mtetra
.42354 .2024 .42958 .23636 .4414 .23221 .43529 .19833 Mtetra
.568 .422 .643 r
.43529 .19833 .4414 .23221 .45328 .22795 .44709 .19427 Mtetra
.568 .423 .644 r
.44709 .19427 .45328 .22795 .46521 .22353 .45894 .19024 Mtetra
.568 .424 .646 r
.45894 .19024 .46521 .22353 .47719 .21894 .47085 .18623 Mtetra
.568 .427 .649 r
.47085 .18623 .47719 .21894 .48923 .21416 .48282 .18224 Mtetra
.57 .431 .653 r
.48282 .18224 .48923 .21416 .50132 .2092 .49484 .17827 Mtetra
.571 .436 .658 r
.49484 .17827 .50132 .2092 .51346 .20409 .50692 .17432 Mtetra
.573 .442 .665 r
.50692 .17432 .51346 .20409 .52565 .19887 .51905 .1704 Mtetra
.575 .45 .672 r
.51905 .1704 .52565 .19887 .53789 .19362 .53125 .16649 Mtetra
.577 .458 .681 r
.53125 .16649 .53789 .19362 .55017 .18835 .5435 .16261 Mtetra
.58 .468 .69 r
.5435 .16261 .55017 .18835 .56251 .18309 .55581 .15874 Mtetra
.583 .479 .701 r
.55581 .15874 .56251 .18309 .57489 .17786 .56819 .1549 Mtetra
.586 .491 .713 r
.56819 .1549 .57489 .17786 .58732 .17267 .58063 .15107 Mtetra
.59 .504 .725 r
.58063 .15107 .58732 .17267 .59981 .16749 .59313 .14727 Mtetra
.593 .518 .739 r
.59313 .14727 .59981 .16749 .61235 .16233 .6057 .14349 Mtetra
.597 .534 .755 r
.6057 .14349 .61235 .16233 .62494 .15719 .61833 .13973 Mtetra
.6 .552 .773 r
.61833 .13973 .62494 .15719 .63759 .15205 .63103 .13599 Mtetra
.604 .573 .792 r
.63103 .13599 .63759 .15205 .65029 .14692 .6438 .13227 Mtetra
.608 .597 .814 r
.6438 .13227 .65029 .14692 .66305 .1418 .65663 .12857 Mtetra
.611 .624 .839 r
.65663 .12857 .66305 .1418 .67586 .13668 .66954 .1249 Mtetra
.614 .656 .867 r
.66954 .1249 .67586 .13668 .68873 .13157 .68252 .12124 Mtetra
.614 .691 .898 r
.68252 .12124 .68873 .13157 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Rooooo`;oWK3U00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Aooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo05cooooo0_nM
Ymd4oif`i@03o`000?nM/>Gooooo01Gooooo00?o0000ooooooooool0D?ooool0063ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`00063ooooo0_nLWmH5oifWg@?oWK3U00?o
0000ojVghoooool05?ooool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0005gooooo0_nKV=06oibOePGoWJOM
00?oWK3UojVghol000000_nY]n<Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000G?ooool2oiZBbPGo
ViS@1OnLWmH4oifWg@04ojR^g?nY]n?oZKOSo`0000?oZKOS5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool3o`00
00;ooooo00?o0000ooooooooool0E_ooool00onISLGoVY;:oiZBbP03oiZBbPGoViS@1OnLWmH00onM
YmgoZ:kLojR^g002ojR^g005ojVghol0003oZKOSojVghond_N405_ooool00ol0003oooooooooo`1>
ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2
o`0005cooooo1?nISLD4oiZBbPKoViS@0_nLWmH2ojJVePKoZ:kL00?o0000okBmhOnd_N400_nd_N4F
ooooo`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0?ooooo`?o0000Foooool2oiR8`@GoVHg51?nJT/X5oi^Hd003ojFOd?nVY]Ko
YZKF00?oYZKF1?nX[]`00onb]]_o0000okBmh@04okBmhAKooooo00?o0000ooooooooool0C?ooool0
08;ooooo0_l0001Jooooo`;oUhBm1OnHR<44oiV=a@GoVY;:00?oViS@ojFOd?nUWm000onUWm05ojJV
eP05ojR^g?nb]]_o/[KKok:ffol000001?nd_N400onl`n3oooooooooo`0Dooooo`03o`000?oooooo
oooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Cooooo`;oUh6i1OnGQ;d4oiR8
`@GoVHg50onJT/X00onSVL_oYIo@ojFOd004ojFOd0CoYZKF00?o/:oFok:ffonb]]/00_nb]]/00ol0
003o/[KKokBmh@04okc3h1Cooooo0ol0001=ooooo`00O?ooool3o`0005Oooooo0_nFOKH5oiN1^@Co
UhBm1?nHR<45oiV=a@03oiZBb_nSVL_oXiW;00;oXiW;1_nUWm000onVY]Ko/:oFok2_eP02ok2_eP?o
/[KK00?o0000ok^ng?nl`n001?nl`n0Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000
Eoooool00onEN[?oUWffoiIm]P03oiIm]PCoUh6i1?nGQ;d5oiR8`@;oVHg50_nRU<H6oj>Ib`CoYIo@
00?o[ZWBok2_e_n`[mH00on`[mH3ok:ff`03ok^ng?l0003o^kkL00?o_<?P0_o2b^4Fooooo`03o`00
0?oooooooooo04[ooooo001gooooo`?o0000F?ooool3oiEj/`CoUWff1?nGPKT5oiN4_@?oV8S100?o
XHo2oj:Da_nRU<H00onRU<H6oj>Ib`03ojFOd?n^ZM;o[ZWB00;o[ZWB1On`[mH01_nb]]_o^kkLok^n
g?l0003o^kkLokc3h0Go`/[Q5_ooool00ol0003oooooooooo`19ooooo`00MOooool2o`0000;ooooo
00?o0000ooooooooool0Doooool2oiAg/0CoUGZc1OnFOKH4oiN1^@CoUhBm00?oV8S1oj6?`_nQSl80
0_nQSl85oj:DaPCoXiW;00?o[J?>ojjYd_n^ZM800on^ZM84ok2_eP05okVjf_nk_]co^kkLok^ng?l0
00001_o2b^400oo3c^?oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo001booooo`?o0000
1Oooool00ol0003oooooooooo`1>ooooo`;oTgF^1?nDMk04oiEj/`GoUWff1?nGPKT2oiN4_@;oWhbo
1_nQSl85oj:DaP03oj>Ibon]Xlko[J?>00;o[J?>1On^ZM800on`[mKo^K[JokVjfP02okVjfP;o^kkL
00?o0000ol;:hOo2b^400oo2b^43ol?>haKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0
001Eooooo`;oTg>/1?nCMJh5oiAg/0CoUGZc1?nFOKH3oiN1^@03oij8_?nOS;ooWhbo00?oWhbo1OnQ
Sl84oj:DaP03oj^Nb_n]Xlko[J?>00?o[J?>1?n^ZM800onh]]Oo^K[JokVjfP03okVjfP03ok^ng?o2
b^7o000000Co`/[Q1Oo3c^<Fooooo`03o`000?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Pooooo`?o0000E?ooool00onBLJ[oTg>/oi=c
[002oi=c[0GoTgF^1?nDMk04oiEj/`GoUWff00CoUh6ioij8_?nNR;coWXRl1OnOS;l5oj6?`P03oj:D
a_n[W/[oZik:00;oZik:1On]Xlh00on^ZM;o^;KGokRfe`02okRfe`?o^K[J0oo2b^400ol0003o`/[Q
ol;:h@02olCCiPCo`lkS00?o_m;Xooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o
00000oooool00ol0003oooooooooo`1?ooooo`?oTW6Z1OnCLj`4oi=e[PCoU7N`1?nEN[<4oiIm]P03
oif5^OnNR;coWXRl00;oWXRl1OnOS;l4oj6?`P03ojVJaon[W/[oZik:00?oZik:1?n]Xlh00ong/]Co
^;KGokRfe`04okRfe`03okVjf_o2b^7o`/[Q00;o`/[Q00?o0000ol;:hOo4dnH00oo4dnH00oo3c^?o
_m;XokoBj002okoBj1Kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0001Dooooo`;oTVnX1OnBLJX4oi=c
[0CoTgF^1OnDMk04oiEj/`03oiIm]_nMQKWoWHFi00;oWHFi1?nNR;`5oin<_`03oj6?`_nYV/OoZI[7
00;oZI[71?n[W/X3ojfScP?o]k;D1?nh]]L00oo2bn7o`/[Qol;:h@03ol;:h@03o`000?o4dnKoa=?V
00;oa=?V00?o`M_]okoBj?nod^P01?nod^PFooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0005?ooooo0_nAKZL4
oi9_Z0GoTW6Z1?nCLj`4oi=e[PGoU7N`0_nEN[<2oif3]`GoWHFi1?nNR;`4oin<_`03ojRGa?nYV/Oo
ZI[700?oZI[71On[W/X00on]Xlko]k;DokNbe002okNbe0?o^;KG0oo2bn43ol;:h@03olCHj?l0003o
a=?V00;oa=?V0oo1fnd4okoBj0;o]m7]5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0002_ooooo000hooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Eooooo`?o0000D_ooool00onAKJKoTFjWoi5^Y`02oi5^Y`GoTVnX1?nB
LJX4oi=c[0GoTgF^0onDMk000onLPKGoWH>goif3]`03oif3]`CoWHFi1OnNR;`00onOS;ooZ9O4ojRG
a002ojRGa0CoZI[71?n[W/X00one[m;o]k;DokNbe004okNbe003okRfeoo2bn7o`/_Q00;o`/_Q00Oo
`/[QolCHj?o4f>Soa=SXo`000?o4f>Soa=?V00Go`M_]00?o_m;XokOAkOngdNd00ongdNdEooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0A
ooooo`?o00000oooool00ol0003oooooooooo`1<ooooo`04oi5/YOnAKJKoTFfVoi5]YPGoTFjW1?nB
KjP4oi9aZPCoTg>/1OnCMJh01?nDMk3oW86eoib1]OnLPKD5oif3]`GoWHFi0onNR;`00onWU<;oZ9O4
ojRGa003ojRGa0GoZI[700?oZik:okF_d_ne[m800_ne[m84okNbe003ol7;h_o2bn7o`/_Q00;o`/_Q
0_o4gN/3olCHj003o`000?o0iO7o`>Ga00Co`M_]0_nggO<4okOAk@03oj_=l_oooooooooo01Cooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool2o`0005?ooooo0onAK:D4oi5]YPCoTFjW1?nBKjP4oi9aZPGoTg>/0onCMJh0
0onKOk?oW86eoib1]@03oib1]@CoWH>g1OnMQKT00onNR;coYiC2ojND`P02ojND`PCoZ9O41?nYV/L0
0ond[=7o]JoBokF_dP03okF_dP?o]k;D0oo1bn82ol;;h@Coa=g[00?oa=SXol3UlOl000000oo0iO40
0oo1fngo]mgcokOMl`03okOMl`03okOAkOn[cO;oZlgb00;oZlgb5_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o0000
D_ooool2oi5/Y0CoTFbU1?nAKJH4oi5^Y`CoTVnX1OnBLJX4oi=c[004oi=e[_nKOk?oVgncoi]o/`Go
W86e1OnMPkL3oif5^@03ojJA`?nWU<;oYiC200?oYiC21OnXUl@00onYV/Oo]:cAokB/d@02okB/d@Go
]JoB00?o]k;Dol7;h_o1bn800_o1bn800oo2bn7oa=g[olCMj`02olCMj`;o_>oc00Co`>Gao`000?o0
iO7o`>Ga0_nbj?P4okOMl`;oZ=Wi1On[cO8Dooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l00000;?ooool005Wooooo0ol0001@ooooo`KoTFbT1OnAK:D3oi5]
YPCoTFjW1?nBKjP5oi9aZP;oTg>/0_nKOK85oi]o/`CoW86e1OnMPkL00onMQKWoYY70ojJA`002ojJA
`0CoYiC21?nXUl@00onbZLoo]:cAokB/d@03okB/d@Co]JoB00?o`LcSol7;h_o1bn800_o1bn82olCS
kP?oa=g[1?nlko<00ol0003o/^Shok;Xn003ok;Xn003okOMlonXfOWoZ=Wi00?oZ=Wi0_n[cO82oic5
m1?ooooo00Co0000oooooooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool0:oooool005Kooooo0ol00003ooooo`03o`000?oooooooooo04[ooooo2_nAK:@4
oi5/Y@?oTFfV1?nAKZL5oi9_Z0?oTW6Z00?oVWb`oi]m/_nKOK800_nKOK85oi]o/`GoW86e0onMPkL0
0onUT;ooYY70ojJA`003ojJA`0GoYiC20_nXUl@3ok:Yc`Go]:cA00?o]JoBol7<hoo1c><00_o1c><0
0oo1bn;oa>?^olCSkP03olCSkP03olCMjonlko?o_>oc00;o_>oc00?oYo3go`000?nWl?L00_nbj?P4
oioSo0;oZ=Wi0_nHcOX5oic5m1Kooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0001@oooo
o`goTFbT1?nAK:D3oi5]YPGoTFjW1?nBKjP01?nBLJ[oVWb`oiYl/?nJO;05oi]m/PCoVgnc1OnLPKD0
0onMPkOoYI2oojF@_`02ojF@_`CoYY701OnWU<800onXUlCo/ZW?ok:Yc`02ok:Yc`Co]:cA00?o`<gT
ol7<hoo1c><00oo1c><00oo2j?3oa>?^olCSkP02olCSkP?o/oGb00Go_>ocojO`monWl?OoYo3go`00
0003oi3Wn@;oWn?l0_n@eOh5oiS=nPCoW<Gd5_ooool00ol0003oooooooooo`10ooooo`00DOooool3
o`00053ooooo3onAK:@4oi5/Y@CoTFfV1?nAKZL3oi9_Z003oiUj[onJO;3oVWb`00?oVWb`1?nKOK85
oi]o/`?oW86e00?oY8jmojF@_onUT;l00onUT;l5ojJA`0?oYiC200?o/JO>ok:YconbZLl01?nbZLl0
0ond[=7o`<gTol3=i002ol3=i0?o`LcS0oo2j?001?o4hnko/oGbok?el_ncmO83oi;_j`?oMn;[00Co
0000oi3WnOn4f_koQ=[n1On@eOh2oiS=nP;oSKkg1On@^_<Fooooo`03o`000?oooooooooo03oooooo
001>ooooo`Go0000C_oooolBoi5/Y0CoTFbU1?nAKJH4oi5^Y`04oi9_Z?nINZooVGZ_oiUj[`GoVWb`
1?nKOK85oi]o/`03oib1]OnTS[goY8jm00;oY8jm1?nUT;l5ojJA`003ojND`_naYlko/JO>00;o/JO>
1?nbZLl00onocNGo`<gTol3=i004ol3=i004ol7<hoo2j?3o`^S`ol;Xl0;oXoKX0ombhM401?nBkn_o
Mn;[ogORjomgh^/2og?In@03o`000?n4f_koQ=[n00;oQ=[n0_n@eOh3oh[1nPCoSKkg1On@^_<Foooo
o`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`17oooooaKo
TFbT1OnAK:D3oi5]YP;oTFjW0_nHN:h5oiUj[`CoVWb`1OnKOK83oi]o/`03ojB=_OnTS[goY8jm00?o
Y8jm1OnUT;l3ojJA`003ok2Vc_naYlko/JO>00?o/JO>0onbZLl3oko=i@Co`<gT0_nokO800oo2j?3o
XoKXoj?fj003og;Qd@;oE]7@0omNdnd2og?In@03oh36o_l0003oP<Kn00CoQLCl1On:`OX4ohfnm`;o
T;[c0_n;/_0Fooooo`03o`000?oooooooooo03kooooo0019ooooo`?o0000C_oooolJoi5/Y0CoTFbU
0_nAKJH00onGMjgoV7R^oiQh[P02oiQh[PGoVGZ_1?nJO;05oi]m/P03oi]o/onTSKgoY8fm00;oY8fm
1?nTS[d5ojF@_`03ojJA`?n`Y/ko/:K>00;o/:K>1OnaYlh00onbZLoo_lgUoko=i@03oko=i@04ol3=
i?nokO;o_ngboko]lP;oR>cC00?oBlF[oc>h[Olc^:d00_m8b=/2ogO8o`CoNlOo0on0a_h00ol0003o
P<KnohG4o003ohG4o0;oR/7j0_n:/>l5ohZal0CoRk;`5?ooool3o`0003oooooo000Rooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08?ooool2o`00053ooooo6onAK:@4oi5/Y@03oi5]Y_nGMjgoUgN]00Go
V7R^1?nINZl5oiYl/0?oVgfb00?oXhblojB=_OnTSKd00onTSKd5ojB>_@?oYI2o00?o[jC=ok2Vc_n`
Y/h00on`Y/h4ok6WcP;o_/kV1?nocND3ok_bl`03oko]l_n8k=?oMLSo00GoMLSo1?mgb?l4og_7o`;o
P<Kn00?o0000ohV/kOn9[nh01?n9[nh4ohZ`k`GoR[7`1?n;/_0Eooooo`03o`000?oooooooooo03go
oooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000oooooooo
ool0B_ooool2oi9/Y1coTFbT0_nAK:D2oiIe[0CoUgN]1?nHN:h4oiUj[`GoVWb`00?oVgfboj><_?nS
S;`00_nSS;`4ojB=_@GoY8jm00?oYI2oojnTcOn_Y<d00_n_Y<d5ok2VcP03ok6Wc_nnc^Ko_/kV00?o
_/kV00?o_lgUok_blonkl_<00_nkl_<2ogO7o`KoMLSo00?oSJ;Soh^Vion;Y^L00_n;Y^L5ohZYjP04
ohV/kOl0003oRJc]ohV/k@GoRJo^1?n:/>l2ohZal0;oSZSW1On=[^`Eooooo`03o`000?oooooooooo
03cooooo000Rooooo`05oa0@4?ooooooooooooooool@41006oooool2o`0004oooooo1OnBK:@Koi5/
Y003oiEcZonFMJcoUWF/00;oUWF/1?nGMjd4oiQh[PGoVGZ_0onJO;000onSRk_oXhbloj><_003oj><
_0GoY8fm0onTS[d00on^Y<go[jC=ojnTc@03ojnTc@Co/:K>00?o_LkWokk>i_nnc^H00onnc^H3okGe
lP03ok_blomgaoooMlOo00;oTI[H1?n?W]h4ohfRh`CoRjKW1On:ZNX01?l0003oRJc]ohV/kOn9[>d2
ohV_kP;oT9cK1?n?X^45ohjXi`GoSJk/5Oooool00ol0003oooooooooo`0kooooo`008_ooool01Ol0
003ooooooooooooooooo000001Sooooo0ol0001>ooooo`03oi9]Y?nBK:CoTVbT00KoTVbT6?nAK:@3
oiEcZ`GoUWF/0onGMjd4oiQh[PGoVGZ_00?oVWb`oj>;^onSRk/00_nSRk/4oj><_0GoY8fm00?oY8jm
ojjTcOn^Y<d00_n^Y<d5ojnTc@03ok2Vc_nmc^Oo_LkW00;o_LkW0onnc^H3okGelP;oU9KB1OnAV]P4
ohnNgPCoSJ;S1?n;Y^L2ohZYjP;oTI3?00Co0000oi2FeOn@U]GoT9KE1On@W=/4ohnRh@GoSZSW0_n=
[^`2oiJ_j1Gooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000ooooooooooooooooo`00
000Fooooo`?o0000C_ooool3oi9]Y0SoTVbT5OnAK:@2oiAbZPGoUG>[1?nFMJ`3oiMg[@GoV7R^0onI
NZl00onRR[_oXh^koj>;^`03oj>;^`GoXhbl0onTSKd00on^Xlgo[ZC=ojjTc@03ojjTc@Co[jC=00?o
^lkYokg>ionmc^L01?nmc^L01?nnc^Ko]OGbokGel_nFTL`4oiBFdPCoTI[H1?n?W]h2ohfRh`;oThK2
1?nBRlP4oi6@c`03o`000?n@U]GoT9KE00;oT9KE1?n@W=/5ohnRh@;oSZSW0_nGYn45oiJ_j1Gooooo
00?o0000ooooooooool0>_ooool002;ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o0000
0_ooool00ol0003oooooooooo`19ooooo`KoTVfT2?nBK:@Aoi5/Y0;oTg6Y1?nDLZX5oiEcZ`CoUWF/
0onGMjd5oiQh[P03oiUj[onRR[_oXXZk00;oXXZk1?nSRk/5oj><_003ojB=_On^Xlgo[Z?=00;o[Z?=
1?n^Y<d3ojnTc@?o^lkY1?nmc^L2ojcfk`?oUY7<1?nDU]85oi6Jf0;oSikN00?oU8:moi>6`_nCQ/80
0onCQ/84oi:;b0?oTI3?00?o0000oi2FeOn@U]D00on@U]D4oi2Lf`;oSj;Q0_nGX=X5oiNWh@CoUZoX
5_ooool00ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo
0ol0001>ooooo`WoTVfT2?nBK:@>oi5/Y003oi=`Z?nCLJWoTg6Y00;oTg6Y1OnDLZX4oiEcZ`CoUWF/
1?nGMjd3oiQh[P03oj68^_nRR[_oXXZk00?oXXZk1OnSRk/3oj><_003ojfSc_n^Xlgo[Z?=00?o[Z?=
1On^Y<d00on_Y<go^lkYok_>j@03ok_>j@04okg>ion/m^oo[?K_oiN=aPGoUY7<1?nDU]82oi6Jf0;o
U7jh1?nDP[d4oi>6`PCoTX_80onAT<l01?l0003oTI3?oi2FeOn@U]D2oiVCc@CoV9[C1OnGX=X5oiNW
h@;oUZoX0_nP/nDDooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>oooo
o`;o0000C_ooool<oi9]Y0SoTVbT3OnAK:@2oi=`Z0GoTg6Y1?nDLZX4oiEcZ`GoUWF/0onGMjd00onH
N:koXHRjoj68^P02oj68^PCoXXZk1OnSRk/00onSS;co[J?>ojfScP02ojfScPCo[Z?=1?n^Y<d2ok[?
jPCo^lkY0_nRmNX3oiN=aPCoUY7<00?oUgZaoiIl]?nFO;@00_nFO;@5oiAn^0?oU8:m1?nCQ/85oi:;
b0;oTI3?00?o0000oiZ>a_nITld01?nITld4oiRJd`GoUj3J0_nGYn42oj6[gPGoX;?U5Oooool00ol0
003oooooooooo`0hooooo`00<_ooool5o`0004cooooo3onBKJ@8oi9/Y0WoTFbT0_nBKjL4oi=`Z0Co
Tg6Y1?nDLZX4oiEcZ`GoUWF/0_nGMjd00onOQ[WoXHRjoj68^P03oj68^PGoXXZk0onSRk/00on]Y<ko
[J?>ojfScP03ojfScPGo[Z?=00?o[ZC=ok[?j_njcnX00onjcnX00onkc^WoX_GZoj;ejP02oiR8`@Co
Uhg600CoUY7<oiMj/OnGN[7oUgZa1OnFO;@4oiAn^0?oU8:m1OnCQ/82oi:;b0;oVXW100?oVXk6o`00
0?l000000_nJS/H4oiVCc@GoV9[C0_nGX=X2oj6Se`GoXJ_N0onP/nD00on[^^Coooooooooo`0Doooo
o`03o`000?oooooooooo03Oooooo000`ooooo`;o0000CooooolAoi9]Y0SoTVbT1OnAK:@6oi9_Y`Co
Tg2X1?nCLJT4oiAbZPGoUG>[0onFMJ`00onNQ;OoWhJioin6^@02oin6^@CoXHRj1OnRR[/00onSRk_o
[JC>ojfTcP02ojfTcPCo[J?>1?n^Xld2okS?j`Co^/oZ0_nFl^<5oiR8`@;oUhg600?oV7V_oiMj/OnG
N[400onGN[44oiIl]0CoU7jh1?nDP[d2oi>6`P;oVhFk0_nJRL43o`000004oiZ>a_l0003oVXk6oiZ>
aPCoVI?=1?nHV]<00onQWM3oXJ?Goj6Se`03oj6Se`CoXJ_N00?oX;?Uoj^ji?n[^^@00_n[^^@Eoooo
o`03o`000?oooooooooo03Oooooo000]ooooo`?o0000C_oooolDoi9]Y0SoTVbT0_nAK:@00onBKZKo
TVnWoi9_Y`07oi9_Y`?oTg2X1?nCLJT4oiAbZPGoUG>[00CoUWF/oij4]onNQ;OoWXBg1?nOQ[T5oj68
^P?oXXZk1_n]Y<h5ojfScP03ojjScOnhcn_o^<o[00?o^<o[00?o^/oZoiKbhonFl^<00onHQ;`2oiR8
`@;oVGR]0onHNJl5oiMj/@CoUWbd1OnDO[P2oiB2_@04oi^2]onKQK_oVhFkoi^5^`?o00000onJRL42
oiZ>aP03o`000?nJS/KoVI?=00CoVI?=00CoV9[Coj6Md?nQWM3oXIg@1OnQXmL2oj6[gP;oZk;N1_n[
^^@Eooooo`03o`000?oooooooooo03Kooooo000/ooooo`;o0000C_oooolFoi9]Y0OoTVbT1?nBKZH9
oi9_Y`?oTg2X1?nCLJT5oiAbZP?oUG>[00?oWH:foij4]onNQ;L00onNQ;L4oin6^@CoXHRj00?oXXZk
ojfTc_n]Y<h01_n]Y<h4ojfScP;o]m3/1?nhcn/2ohW/f`05oiR0]onHQ;coV8BloiR4_?nJN:`01?nI
N:d4oiQi[`CoUgZa1OnFO;@4oiAn^003oiB2_OnKP[OoVh:g00?o00000_nKQK/4oiZ9`@?oVXk600Co
0000oiZ>a_nITlgoVI?=0_nRV</5oj6Md0?oXJ?G00?oZjcHoj^bg_n[/]h00on[/]h4oj^ji0;o/l7T
5Oooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0004_ooooo6?nBKJ@5oi9/Y0OoTVjV2?nB
KjL3oi=`Z0GoTg6Y1?nDLZX01?nELj_oWH:foif2]_nMP[H5oij4]`CoWhJi0onQR;X00on/Y<ko[JC>
ojfTcP08ojfTcP03ojfSc_ngd>co]m3/00?o]m3/00?o^<o[ohW/fon9k=/00onHP;L01?nHQ;coVWR/
oiYh[?nJN:`5oiUh[@?oV7V_1?nGN[45oiIl]0;oU7jh0_nKOk<3o`000003oi^2]onKQK_oVhFk00;o
VhFk1OnJRL42oiZ>aP03oj>DaOl0003oXYS;00CoXYS;1?nQWM000onQXmOoZjcHoj^/f002oj^/f0Go
Zk;N00?oZk[Tok?1i?nc`N@00onc`N@Dooooo`03o`000?oooooooooo03Gooooo000/ooooo`04o`00
0?oooooo0000o`0004Kooooo0_nCKJ@Joi9]Y0;oTVbT2_nBKZH8oi9_Y`CoTg2X1?nCLJT2oiAbZP;o
Vh2d1OnMP[H4oij4]`GoWhJi00CoXHRjojbTc_n/Y<ko[:C>2?n]Y<h2okOBkPCo]m3/00?oN^G@oiMl
/onGO;<00onHP;L00onJN:_oVWR/oiYh[003oiYh[0CoVGR]0onHNJl5oiMj/@?oUWbd00?oVgb`oi]o
/ol000000_l00004oi^2]`GoVhFk0onJRL401_nST<7oXiC5oj>DaOnSU<Go0000oj>Da@CoXYS;0onQ
WM000on[Ym?oZjcHoj^/f003oj^/f0CoZk;N0_nd_^44ok?1i003okS7i_oooooooooo017ooooo00?o
0000ooooool000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo0_l00002ooooo`03o`000?oooooooooo043ooooo
1OnCKJ@Ioi9]Y0goTVjV2?nBKjL4oi=`Z0?oTg6Y00?oVWjcoi^0]?nKP;@00_nKP;@5oif2]PGoWXBg
0onOQ[T00on/Xlko[:C>ojbTcP03ojbTcPGo[JC>1Ongd^h00ongd>coUgV`oiMi/003oiMl/`04oiR0
]onJN:_oVWR[oiYhZ`GoVWR/1?nIN:d4oiQi[`CoUgZa00?oUWbdoi]l/?l000000_l00004oi]o/`?o
Vh:g1OnKQK/00onJRL7oXi31oj>@`@02oj>@`@?oXiC500?o0000oj:HbonRV</00onRV</01?nQWM3o
ZjOCoj^Wdon[Ym<5oj^/f003oj^bg_nd_^7o];kQ00?o];kQ00?o/l7TokS7i_nhanH00_nhanHEoooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0?_ooool6oi=]Y1KoTVfT00?oTfjVoi9^Y_nBKZH03OnBKZH9oi9_Y`?oTg2X00CoTg6Y
oiYn/onJO[?oVWjc1OnKP;@4oif2]PGoWXBg00?oWhJiojbSc_n/Xlh00_n/Xlh4ojbTcP?o[JC>0_nf
e_04okOBkPCoUgV`0_nGO;<00onJMj[oVWR[oiYhZ`03oiYhZ`CoVWR/1?nIN:d4oiQi[`;oUgZa0_nK
NZh2o`0000?oVgb`1?nKOk<4oi^2]`?oVhFk00?oY8jmoj>@`OnST<400onST<44oj>Da@03o`000?nR
V<_oXYS;00;o[:??1On[Ym<2oj^/f0?o];_O1?nd_^400onibNOo^<OVokS7iP03okS7iQGooooo00?o
0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Iooooo`00:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo
2OnCKJ@Doi9]Y0?oTfjV3onBKZH9oi9_Y`;oTg2X00?oVGbboiYn/onJO[<00onJO[<4oi^0]0GoWH:f
0onNQ;L00on[X/ko[:?>ojbScP03ojbScPGo[:C>00?o[JC>okKFl?nfe_000_nfe_000ongd^koUWJ]
oiIf[@03oiMi/004oiYfZOnJMj[oVWNZoiYgZPGoVWR[1?nJN:`5oiUh[@;oV7V_00?oVgV/oi]j[_l0
00000_l00005oi]l/0CoVgnc1?nKP[L00onKQK_oY8jmojB>_@02ojB>_@CoXi311?nSU<D00ol0003o
[:??ojbSc`03ojbSc`?oZjOC00?o]KWLokBkgond^ml01?nd^ml00ond_^7o^LWWokW9i`02okW9i`?o
^<OV0_ngcNXEooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B406Oooool002_ooooo0ol00005ooooo`03o`000?oooooooooo
03Kooooo3?nCKJ@Aoi9]Y0OoTfjV3onBKZH7oi9_Y`03oiQk/OnIO;;oVGbb00;oVGbb1?nJO[<4oi^0
]0GoWH:f00?oWXBgoj^Rc_n[X/h00_n[X/h5ojbScP;o[:C>1?nff_<2okKFl005oeS>/_nFMZgoUWJ]
oiIf[OnGNK000onJMZT4oiYgZPCoVWR[1?nJN:`5oiUh[@04oiQi[ol0003o0000o`0000CoVgZ^1?nK
O;05oi]o/`;oVh:g00?oY8bjojB>_OnTS[d00onTS[d5oj>@`@05oj>DaOn/X<_o[:3;ojbPbol00000
1?n/Xll00on[Ym?o]KWLokFig002okFig0Co];_O00?o^/cXokW9ionibNL00onibNL00onhanKo]lgZ
okO=jP03okO=jQGooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03;ooooo00?oTfjUoi=]Y?nCKJ@03OnCKJ@=oi9]Y003oi=_Y_nCKZKoTfjV00Oo
TfjV3onBKZH5oi9_Y`?oV7^a1?nIO;84oiYn/`GoVh2d0onMP[H00onZXLgoZj;>oj^RcP03oj^RcPCo
[:?>0_nehOD4okKJl`03o`000?nELj_oUG>[00?oUWJ]00?oVGBXoiYfZOnJMZT00onJMZT3oiYgZPCo
VWR[1OnJN:`2oiUh[@?o00000onKNJ`4oi]j[PGoVgb`1?nKOk<01?nKP[OoY8bjojB<^_nTS;X4ojB>
_@CoXi3100?o[Ik8ojbPbon/X</00on/X</01?l0003o[:??ojbScong^=/6okFig003okBkgonjc>So
^/cX00;o^/cX0onibNL2okSEk`Co]lgZ00?o/Lc^ooooooooool04oooool00ol0003oooooooooo`03
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo0onCKZD?oi=]Y0[oTVfT00CoU6nV
oi=_Y_nCKjKoTfnV2OnCKZH?oi9^YP;oTVnW0_nGNK05oiQk/@CoVGbb0onJO[<5oi^0]003oif2]_nZ
XLgoZZ7=00;oZZ7=1On[X/h00on/Xlko]N7eokGQm@03okGQm@03okKJlonDLZWoU7:Y00?oUG>[00Co
UWJ]oiUdZ?nIM:SoVGBX1OnJMZT3oiYgZPCoVWR[1?nJN:`3o`0000;oVgRZ1?nKNJ`4oi]j[PGoVgb`
0_nKOk<2ojB9^0CoY8bj1OnTS[d00onST<7o[Ik8ojfNb002ojfNb0Go[:3;00Co0000okNhfong^=_o
]kSK1?ne^M`00onldN[o^/cXok[<j004ok[<j003okW9ionheNoo^=G_00;o^=G_00?o]lgZok7<k_na
c>h00_nac>hCooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`03oiA_Y_nCKZGoTfjU00;oTfjU3onCKJ@8oi9]Y0?oU6nV1?nCKjH8oi=^YPkoTVjV00?oUgR_oiMi
/?nGNK000_nGNK05oiQk/@CoVGbb1?nJO[<3oi^0]003ojVOc?nZXLgoZZ7=00?oZZ7=1?n[X/h2ok?W
m`Co]N7e1?nDLZT2oiEcZ`03oiQcY_nIM:SoVGBX00?oVGBX1?nJMZT3oiYgZPGoVWR[0ol000000onK
MjWoVgRZoi]hZP03oi]hZP?oVgV/1?nKNZh4oi]l/003ojB7]OnTRKSoY8Vh00?oY8Vh0onTS;X4ojB>
_@03ojjMa_n]W/So[Ik800?o[Ik81?n/X</00onh^M[o0000okNhf`03okNhf`03okFig?nldN[o_=7Z
00;o_=7Z1?njc>P2okSOl`;o^=G_0on`eo@5ok7<kQGooooo00Wo0000ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Iooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`03
o`000?oooooooooo02Sooooo00CoUG2WoiA_Y_nDKjKoU6nV1?nCKZD?oi=]Y0KoTVfT00?oU72WoiA_
Y_nDKjH00onDKjH3oi=_YPSoTfjV2onBKZH01?nFMjkoUgR_oiMh[onGN:l5oiMi/0CoV7^a1?nIO;84
oiYn/`03oi^0]?nYWlcoZIo<00;oZIo<1OnZXLd00on[X/ko/nOgok?Wm`03ok?Wm`03okGQmOnDL:Oo
U72W00?oU7:Y00CoUg6UoiQcY_nHLjKoV7>V1OnIM:P4oiYfZ@CoVWNZ00GoVWR[o`000?l0003o0000
oiYh[003oi]gZ@GoVgRZ0onKNJ`5oi]j[P;oVgb`0_nTQkD5ojB9^0CoY8bj00?oY8jmojjMa_n^WLH0
0_n^WLH4ojfNb0?o[:3;0onh^MX00ol0003o]kSKokNhf`02okgGk@Go_=7Z00Co^/cXokSOlonhgo?o
^=oc0_n[hOX5ok3Gm0;o/Lc^0_nWb?4Eooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool09Oooool3oiE`Y`CoU6nV0onCKZD?oi=]Y0;oTVfT1OnDL:L5oiA_YP?o
TfnV2OnCKZH8oi9^YP?oUWN^1?nGN:l4oiMi/0CoV7^a1OnIO;82oiYn/`03ojRMbonYWlcoZIo<00?o
ZIo<1?nZXLd3ojo]n0;o/nOg0_nCKjH3oiA`Y`04oiAbZOnGLJGoUg6UoiMaY@CoV7>V1?nIM:P4oiYf
Z@?oVWNZ0_l000000onJN:_oW7NXoiagZ005oi]gZ@CoVgRZ0onKNJ`5oi]j[P03oi]l/?nTQkGoY8Ne
00;oY8Ne1?nTRKP4ojB<^PGo[Yg61On]W/P00on/X<_o^;WJokRifP02okRifP03okNhfol0003o_MO]
00?o_MO]0_nldNX3ok?Zm`03okSOlon[hO[oZn7j00?oZn7j0_n`eo@2ojC@m`GoYlSa5Oooool00ol0
003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo00?oUW:X
oiE`YonEL:L00_nEL:L4oiA_YPCoTfjU3OnCKJ@00onELJSoU72WoiA`Y`06oiA`Y`CoU6nV0onCKjH9
oi=^YPGoTVjV1onFMjh3oiMh[`CoUgV`1OnHNk43oiUl/P03ojNKb_nXWL_oZ9g;00;oZ9g;1OnYWl`0
0onZXLgo[nghojo]n002ojo]n003oi=^YOnCKjKoTfnV00;oTfnV0_nDL:L00onFKjCoUg6UoiMaY@03
oiMaY@?oV7>V1?nIM:P4oiYfZ@?o00001OnLMjP5oi]gZ@CoVgRZ1?nKNJ`3oi]j[P03ojB5/onTQkGo
Y8Ne00?oY8Ne1OnTRKP2ojB<^P;o[ig51?n^WLH4ojfNb003okZkf_nh^M[o^;WJ00?o^;WJ00?o_^3`
o`000?nmend00_nmend2ojKbl`?o/n[g0onMj?/2oj_QnP;oWMSl1OnTd?L2ojO8l@?oW[o`5Oooool0
0ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00Co
UW>YoiIbZ?nFLZSoUW:X1?nEL:L4oiA_YPCoTfjU3?nCKJ@2oiEaZ0SoU72W1?nDKjH3oi=_YPWoTfjV
0_nBKZH00onFMZgoUWN^oiIg[P07oiIg[P?oUgR_1?nGNK05oiQk/@03oiUl/_nWVl[oYi_:00;oYi_:
0onXWL/4ojVOc0?oYo7f00Co[nghoi=^YOnCKZGoTfjU0onCKjH01?nEKJ?oUVnToiI_Y?nFKj@5oiMa
Y@?oV7>V1?nIM:P01_nJMZWo0000o`000?l0003oVWJYoiYgZPOoW7NX1?nKMjT4oi]hZPCoVgV/00?o
VgZ^ojB5/onTQK<00_nTQK<4ojB7]@GoY8Vh00CoY8bjojnMaOn_WLGo[ig51On^WLH00on]W/So^[_J
okZkfP02okZkfP?o^;WJ0onnh?000ol0003oY_;cojKbl`03ojKbl`03ok?ZmonMj?_oWNSk00?oT=_o
1?nMf?`2ojC@m`?oVl;c1OnN_o0Dooooo`03o`000?oooooooooo02gooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003oooool2o`0001cooooo
0onFLjT4oiIbZ0?oUG2W1?nDKjH4oi=^Y@WoTffT0_nELZT4oiEaZ0OoU72W1?nDKjH4oi=_YPOoTfjV
00CoUWJ^oiIf[OnFMZgoUWJ]2OnFMjh3oiMh[`GoUgV`0onHNk400onUVLWoYi_:ojNKbP03ojNKbPCo
Z9g;00?oZIo<ojOam_nWlOH00_nWlOH5oi=^Y@04oi=_Y_nEKJ?oUFfSoiE]X`CoUVnT1?nGLJD3oiQc
YP;oVGBX0ol00003oiYfZ@03oiafZ?nLMjSoW7NX00KoW7NX1?nKMjT5oi]hZP;oVgV/00?oXX:aojB5
/onTQK<00onTQK<5ojB7]@?oY8Vh00?o/Ik4ojnMaOn_WLD00_n_WLD4ojjMaP03okbog?nj^m[o^[_J
00Co^[_J00Co^;WJokkPl?nnh?3o_^3`0_n1jMT01?l0003oY_;cojKblon2i_03ogkJo@GoT=_o0_nM
f?`2oiO4mPGoVl;c0_nN_o02oiZhkAGooooo00?o0000ooooooooool0;?ooool0013ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Gooooo`03oiMfZonFLjWoUW>Y00;oUW>Y1?nFLZP4oiE`Y`?oU6nV1?nC
KZD6oi=]Y003oiEcZ_nELZWoUG:Y00;oUG:Y1?nELJP7oiA`Y`GoU6nV0onCKjH5oi=^YP?oUWJ^1?nF
MZd8oiIg[PCoUgR_1?nGNK000onHNk7oYIW9ojFIb@02ojFIb@CoYi_:0onXWL/4oicak`03ojOam_nC
KZGoTfjU00;oTfjU0_nDK:84oiE]X`CoUVnT1?nGLJD2oiQcYP?o00000onIM:P01?nJMZWoW7JXoiaf
Z?nLMZP8oiagZ0CoVgNY1OnKN:X00onKNJcoXX:aoj:2/@05ojB5/`GoY8Ne00?oY8Vhok6Na?naW/@0
0_naW/@4ojnMa@03ojjMa_nl_mco_;oL00;o_;oL1?nj^mX2ok_[m004okkPl?n1jMWoPNWIoh7Yf@;o
Dlo?00?o0000of_DnOm[e?T01?mnf_d2oi3Ko`;oTl?g1OnGa?H2oi_2l`;oVKC[1OnJ^>dCooooo`;o
0000;_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`04oiQh[OnGMZ_oUgJ[oiMf
Z`CoUW>Y1?nFLZP4oiE`Y`CoU6nV0onCKZD5oi=]Y0;oUG>Z1?nELZT4oiEaZ0OoU72W1OnDKjH3oi=_
YP;oTfjV0_nFMjh4oiIf[PCoUWJ]2?nFMjh4oiMh[`;oUgV`0_nTV<P5ojFIb@GoYi_:00CoZ9g;oica
konLlNooW?7_0_nCKJ@2oi=^Y@03oi=[XOnDK:;oU6bR00;oU6bR1?nEKJ<4oiI_Y0?oUg6U0ol00002
oiQcYP?oVGBX00?oW7JWoiafZ?nLMZP00onLMZP7oiagZ0GoVgNY0onKN:X00onQP:ooXX:aoj:2/@02
oj:2/@GoY8Fc0onTQkD00oncX<Go/Ik4ok6Na003ok6Na0?o[ig500?o_lKPokbog?nl_m`01?nl_m`0
1_nj^m[o^n_dok_[m?nkjoCo0000oe_4nPCoG<_g00?oJmCio`000?n>^_@00_n>^_@4ohnom`CoTl?g
0_nGa?H2oiR`j0GoVKC[1?nJ^>dEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o00005?oo
ool00ol0003oooooooooo`0?ooooo`04oiYk/?nHN:goV7R]oiQh[@CoUgJ[0onFLjT4oiIbZ0CoUG2W
1?nDKjH3oi=^Y@;oTffT0_nEM:/4oiEcZP?oUG:Y1?nELJP8oiA`Y`CoU6nV0_nCKjH5oiIg[PCoUWJ^
1?nFMZd9oiIg[P;oUgR_00?oXiK7ojBHb?nTV<P00onTV<P4ojFIb@CoYi_:0_n=k^D5oi=]Y003oi=^
YOnCJj7oTf^Q00CoU6bR1?nEKJ<4oiI_Y0?o00000_nGLJD3oiQcYP04oiUdZ?nLMZOoW7JWoiafY`Go
W7JX1onLMjP5oi]gZ@04oi]hZ_nQP:ooXH2_oj60[`CoXX:a1OnTQK<00onTQkGo/j35ok>Pa@02ok>P
a@Go/Ik400Co[ig5oko6h?noa^3o_lKP1?nl_m`3ojodlP04ok_[m?mKa?[oFlCjoi6Wi@GoS[7^00?o
S[[do`000?n>^_@00_n>^_@2ohnom`03oiRSgOnHZn?oV:_S00?oV:_S1?nH/>P5oiVdj`;oV[S]0_nM
]nXEooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool03?ooool3oiYk/0CoV7R]0onGMZ/4oiIcZ@?oUW:X1?nEL:L4oiA_YP;oTfjU00?oUGB/
oiEdZonEM:/00_nEM:/4oiEcZPCoUG:Y0onELJP8oiA`Y`?oU6nV00?oUWR_oiIg[_nFMjh01_nFMjh4
oiIf[P?oUWJ]2OnFMjh01?nGN:ooXiK7oj>FaonSU/L4ojBHb0GoYIW900?oYi_:ohg^iOn=k^D01OnC
KJ@2oi=ZX0?oTf^Q1OnDK:84oiE]X`03oiI_Y?l0003o000000GoUg6U0_nHLjH6oiafY`CoW7JX2?nL
MjP3oi]gZ@03oj1n[OnQP:ooXH2_00?oXH2_0onRP[44ojB5/`03okBSa_ncX<Go/j3500?o/j351?na
W/@00oo2dnOo_lKPoko6h003oko6h004okbog?n_m?;o[oCbojodlP?oU9cI1?nAYnD5ohjakP04ohjj
m?l0003oVIcFoiVLePCoV:?M1OnHZn<4oiR`j0;oVKC[0_nM/^H5oifgjQCooooo00?o0000oooooooo
ool0:_ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03oi]n
/_nJNk3oVW^`00;oVW^`1?nHN:d3oiMfZ`CoUW>Y1?nFLZP3oiE`Y`;oU6nV0_nEMJd3oiEd[0CoUGB[
1?nELjX4oiEbZ@CoUG6X1onDL:L01?nDKjKoUWR_oiIh[onFN:l8oiIg[PCoUWJ^0onFMZd7oiIg[P;o
XYC71?nSU/L5ojBHb0;oYIW90_mli]P3oi=]X`;oTffT00?oTVVOoi=ZX?nCJZ000_nCJZ04oi=[X@Co
U6bR0_nEKJ<3o`0000?oUVnT1?nGLJD00onHLjKoW7JWoiafY`05oiafY`CoW7JX2?nLMjP01?nKMjWo
X7j]oj1n[OnPOZd5oj60[`CoXX:a0_nTQK<3okBSaPCo/j350onaW/@3ol;Ci`?o_lKP0_n<k]/3oiRC
c@CoU9cI1?nAYnD2ohjakP;oVYK>0_nIW=H00ol0003oVIcFoiVLeP04oiRSg@;oV:_S0_nNZ=d4oif]
hPGoWK;V0_nM]nX3oj:hjACooooo00?o0000ooooooooool0:Oooool002Wooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`05ooooo`04oib1]OnKO[;oVgjboi]n/PCoVW^`1?nHN:d3oiMf
Z`CoUW>Y1?nFLZP2oiE`Y`03oiAf[_nEMJgoUGF]00;oUGF]1?nEM:`3oiEdZ`CoUG>Z1?nELZT4oiEa
Z0KoU72W00?oUWR`oiIh[onFN:l00onFN:l7oiIg[PCoUWJ^1?nFMZd3oiIg[P03oj6CaonRU<OoXYC7
00?oXYC70onSU/L4ojBHb0;oJ]c91OnCKJ<01?nBJ9ooTVVOoi9YWonBJIl4oi=ZX0CoTf^Q0onDK:83
o`0000;oUFfS1?nFKj@3oiMaY@WoW7JW1?nLMZP7oiagZ003oiml[?nPOZgoX7j]00?oX7j]1?nQP:l4
oj:2/@03ojB5/ondXlKo]:?600;o]:?61OncX<D00onaW/Co`]?Wol;Ci`02ol;Ci`04oko6h?n<k]_o
S>kKoi^<``CoV9?=0onDW=T00onNSL7oW977oibAa`02oibAa`GoVYK>00CoVIcFo`000?nIW=KoVIcF
0_nHXmd2oj2Re`GoWZSM1?nM[N82oifbiP;oXk?T1_nR^>TDooooo`03o`000?oooooooooo02Sooooo
000Yooooo`?o00005oooool00ol0003oooooooooo`02ooooo`?oW86e1?nKO[84oiYk/0?oV7R]0onG
MZ/4oiIcZ@?oUW:X00CoU7N`oiAf[_nDMZkoU7J^1?nEMJd4oiEd[0CoUGB[0onELjX4oiEbZ@CoUG6X
0_nDL:L2oiIi/@?oUWR`1OnFN:l7oiIg[PCoUWJ^1?nFMZd00onFMjkoXI?7oj6Ca`02oj6Ca`CoXYC7
1?nSU/L01?nTV<SoJ]c9oiA]XonDKJ<4oi=]X`?oTVRO0onBJIl5oi=ZX0?oTf^Q0ol000000onDK:;o
UFfSoiE]X`02oiE]X`CoUVnT00?oUg6UoiafYonLMZL02OnLMZL5oiafZ0CoW7NX0onOO:`5oj1n[@Go
XH2_0_nRP[400ongYlWo]:?6okBSaP03okBSaPCo/j350_o3j?03ol;Ci`03o`000?nKS<?oVhc300;o
Vhc31OnHTld01?nDW=WoWXg1oij=`OnNSL44oibAa`GoVYK>00?oVIcFo`000?nQW]401OnPX]L5oijX
g@;oWJgR00?oY:oPoj>ci?nS/n@00onS/n@4oj:hj@03ojRlj?oooooooooo017ooooo0_l0000Zoooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?ooooooWXFh00GoW86e0onKO[84oiYk/0?o
V7R]1?nGMZ/3oiIcZ@04oiIbZ?nDMk3oU7N`oiAg/0CoU7J^0onEMJd4oiEd[0CoUGB[1?nELjX3oiEb
Z@;oUG6X0_nGNk84oiIi/@CoUWR`1?nFN:l8oiIg[P?oUWJ^0_nFMZd2oj2CaPGoXI?71?nRU<L3oj>F
a`03oeWA^onDKJ?oU6fS00;oU6fS0_nCKJ<00onBJ9koTVROoi9XW`02oi9XW`CoTVVO1?nCJZ03o`00
00CoU6bR1?nEKJ<3oiI_Y003oi]eYonLMZOoW7JW00[oW7JW1OnLMZP2oiagZ0KoWgb/1?nPOZd5oj60
[`04oj:2/OngYlWo]jO9okNWb@Go]:?600?o/j35ol?Xl?o3j?000oo3j?000oo2dnOoWHNkoif7^`05
oi^<``;oV9?=0_nQRkd4oij=`@CoW9771?nJU/h01OnSV/coXIkAoj6NdOl0003oXIkA00CoX:;G1?nN
Z=d00onU[=coY:oPojB_h002ojB_h0GoXk?T00?oX[SYojRlj?nX_>P00_nX_>PDooooo`03o`000?oo
oooooooo02Oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0005ooooo`03o`000?oooooooooo01Sooooo00CoX8Vkoij5^?nNQKSoWXFh1OnLPKD3oi]n/PCoVW^`
1?nHN:d3oiMfZ`;oUW>Y00?oU7RaoiAg/?nDMk000onDMk03oiAf[PCoUGF]0onEM:`4oiEdZ`CoUG>Z
0_nELZT00onGO;CoUg^boiMk/P02oiMk/PCoUWVa1?nFN;04oiIh[`SoUWN^0_nFMZh00onOT/OoX9?6
oj2CaP03oj2CaPCoXI?71OnRU<L00onSU/OoU6fSoiA]X`02oiA]X`GoTVRN1OnBJ9l3oi9YW`04oi=Z
X?l0003o0000o`0000?oTf^Q1OnDK:83oiE]X`04oiI_Y?nKMJOoVgFWoi]eY`goW7JW1?nLMZP00onL
MjSoWgb/oiml[005oiml[0CoX7j]1?nQP:l00oni[<go]jO9okNWb@02okNWb@Co]:?60on`nN/2ol?X
l0;oWhBf0onMQk/4oi^<``03ojB;^_nQRkgoXH^m00;oXH^m1?nNSL45oibAa`04oiZFc_nSV/coXi[<
oj>Jc0;oXIkA00?o0000oj6NdOnPX]L01?nPX]L00onNZ=goYJcLojF/g002ojF/g0CoY:oP0_nS/n@2
ojRii@GoZ;cX5Oooool00ol0003oooooooooo`0Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`0Gooooo`;oX8Vk1?nNQKP4oib1]@?oVgjb1?nJNk04oiQh[@;oUgJ[00CoU7VboiAh/OnDN;7oU7Ra
1OnDMk03oiAf[PCoUGF]0onEM:`4oiEdZ`?oUG>Z00CoUgfeoiMl]?nGO;CoUgbd1OnGNk83oiIi/@Co
UWR`1?nFN:l6oiIg[P;oWY;71?nOT/L4oj2CaPGoXI?70_nRU<L2oiA^Y0;oU6fS00?oTVROoi9XW_nB
J9h01OnBJ9h5oi9XW`04oi9YWol0003o0000o`0000?oTfZP0onCJj45oiA/XP;oUFfS1_nKMJL<oiaf
Y`?oW7JX2OnOO:`5oj1n[@;oXH2_0oni[<d4okNWb@04okBSa_n`nN_o/?W[ok3ij`;oXH:b1?nOQ;H4
oif7^`03oi^<`onTRk[oY8^j00;oY8^j1?nQRkd4oij=`@;oW9770_nUV<L5oj>Jc0;oXIkA00Co0000
oj6NdOnPX]OoX:;G0_nWZMP5ojF/g0;oY:oP0onY]n<4ojRii@;oZ;cX0on/`>TDooooo`03o`000?oo
oooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01_ooool2o`0001Gooooo0_nRS[l4oj29^`?oWXFh1?nLPKD4oi]n/P?oVW^`0_nH
N:d2oiEk]0?oU7Vb1?nDN;44oiAg/0?oU7J^1?nEMJd4oiEd[0?oUGB[00CoUG>ZoiMm]OnGOKGoUgfe
1?nGO;@4oiMk/PCoUWVa0onFN;05oiIh[`;oUWN^00?oWI;8oijBaonNT/L00onNT/L4oinBa`?oX9?6
1?nQTlL00ol0003oU6jToiA^Y005oi9XW`SoTVRN0onBJ9l2o`0000;oTVVO1?nCJZ04oi=[X@CoU6bR
00?oUFfSoi]eYonKMJL01OnKMJL<oiafY`03oiafZ?nOO:coWgb/00WoWgb/1OnPOZd00onQP:oo^Jc=
okV/c@02okV/c@?o]jO900?oH<jPoj:1[onQP[801?nQP[85oin4]P;oWHNk00?oYhbiojB;^_nTRkX0
0onTRkX4oj6;_@?oWXg100?oZ9O4ojFHaonUV<L00onUV<L4oj>Jc0;oXIkA00?oZJSEo`000?nWZMP0
1?nWZMP3ojF/g003oj^eh?nY]n?oZKOS00CoZKOS0_nX^ND2ojc0j0Go[<3Y5?ooool00ol0003ooooo
ooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1Oooool00ol0003oooooooooo`0Aooooo`03ojBB`onRS[ooXXjo00?oXXjo0onPRK/3oij5^0GoW86e
0onKO[82oiYk/003oiIm]_nENkCoUG^d00;oUG^d1?nDNK83oiAh/@CoU7N`0onDMZh4oiEe[@CoUGB/
0_nEM:/00onFO[OoUgfeoiMm]@03oiMm]@?oUgbd1?nGNk84oiIi/@CoUWR`1?nFN:l01?nFMjkoWI;8
oifBb?nMT/P4oijBa`CoWi;71?nPTlH01?nQTlOo0000oiA^Y?nBJJ07oi9XW`SoTVRN0ol000001?nB
J9ooTVVOoi9YWonBJIl4oi=ZX0CoTf^Q0onDK:800onJM:KoVgFWoi]eY`06oi]eY`_oW7JW00?oX7j]
oiml[?nOO:`02onOO:`3oj1n[@03ok^cd_ni[<go^Jc=00Co^Jc=00?o]jO9oj:1[onRPJl00_nRPJl4
oj62/PGoWhBf00CoWHNkojN<^OnWS;WoYhbi1?nTRkX4oj6;_@03oij=`OnXUlCoZ9O400;oZ9O41?nU
V<L3oj>Jc003ojfYdonYZ=GoZJSE00;oZJSE00?o0000ojNYf?nWZMP00onWZMP01?nU[=coZkGPoj^e
h?n[]N04ojVgh`03ojg0ion/`>So[<3X00?o[<3X0_n/`>T2ojg2jAGooooo00?o0000ooooooooool0
9?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool04?ooool3ojBB``CoXXjo0onPRK/4oij5^0CoW86e0_nKO[801?nFOkSoUWff
oiIm]_nFOKH4oiEk]0CoU7Vb0onDN;44oiAg/0CoU7J^0onEMJd2oiEd[0;oUWni0onFO[L5oiMm]@?o
Ugbd1?nGNk84oiIi/@CoUWR`0_nFN:l2oibBb@CoWI;81?nNT/L5oinBa`;oX9?60_nEKjD00onDKZCo
TVVPoi9YX008oi9XW`CoTVRN0ol00004oi9XW`?oTVVO1OnCJZ03oi=[X@04oiA/X_nJM:KoVWBVoiYd
YPSoVgFW2OnLMZL3oj1n[@goWgb/00?oX7j]ok^cd_nk/m800_nk/m84okV/c@;oXh6^1?nRPJl5oj62
/P?oWhBf00?oZhniojN<^OnWS;T00_nWS;T5ojB;^P;oXH^m00?oZYO3ojRGa?nXUl@00onXUl@5ojFH
a`04oj>Jc?n]ZM?o[JWCojfYd`?oZJSE00Co0000ojVXeOnWZMSoYjWH0_n]]Mh5oj^eh003ojVghon]
`>Oo[L3W00;o[L3W0on/`>P00on]`n[o[L;Yojg2j@03ojg2jA?ooooo0_l00008ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool2o`0000oo
oooo00?oYYS8ojBB`onTT/<00_nTT/<4oj:>_`CoX8Vk0onNQKP2oib1]@;oUh:j1?nFOkP3oiIm]PCo
UG^d0onDNK84oiAh/@CoU7N`0onDMZh2oiEe[@03oiJ1^_nFOkWoUWni00?oUWni0onFO[L4oiMm]@?o
Ugbd1OnGNk83oiIi/@;oUWR`0_nLTlX5oibBb@?oWI;81OnNT/L2oinBa`;oUW2U0_nEKjD2oi9YX@?o
TVVP2?nBJ9l01?nBJ9ko0000o`000?l00003oi9XWPCoTVRO1?nBJIl4oi=ZX0;oTf^Q00?oVW>VoiYd
Y_nJM:H00onJM:H7oi]eY`OoW7JW00?oXH2_oj1n[OnPOZd00onPOZd;oiml[003okbmf_nk/m;o^k?B
00Co^k?B00?o^Jc=oj>1[_nSPJh00onSPJh3oj:1[`GoXH:b00?oWhBfoj^?^On[SkT00_n[SkT3ojN<
^@GoY8^j00CoXH^mojZG`onZUl?oZYO31?nXUl@4ojFHa`03ok2[don]ZM?o[JWC00;o[JWC1?nYZ=D0
0ol0003o[KGNojfegP03ojfegP;oZkGP0on_`NL4ojg0i`03ojc0j?n]`n[o[L?Z00;o[L?Z0on]`^T2
ojg3jQCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000gooooo00?oZ9k=ojJHb?nV
V<P00_nVV<P3ojBB``GoXXjo0onPRK/2oij5^003oiR5_OnGP[[oUh:j00?oUh:j0onFOkP3oiIm]PCo
UG^d1?nDNK83oiAh/@CoU7N`0_nDMZh00onEPK_oUX6joiJ1^P02oiJ1^PCoUWni0onFO[L4oiMm]@Co
Ugbd1?nGNk82oiIi/@03oi^Dc?nLTl[oW9?:00?oW9?:1?nLT/T4oifBb0;oWY;70onFLJH2oiI`Y@03
oi9ZX_nBJJ7oTVVQ00;oTVVQ1?nBJJ05oi9XW`?o00001_nBJ9h4oi9XW`CoTVVO1?nCJZ000onCJj7o
VW>VoiYcYP05oiYdYPSoVgFW1OnLMZL2oj60[`GoX7j]2_nOO:`3okbmfPCo^k?B00?oW7V[ojB1[_nS
PJh01?nSPJh4oj:1[`?oXH:b00?o[I:joj^?^On[SkT00on[SkT4ojN<^@?oY8^j00?o[IW3ojZG`onZ
Ul<00_nZUl<5ojRGa003ojFHaon`Zm?o/:_C00;o/:_C1?n]ZM<01OnYZ=Go[kKNojnfg_n_]]ko0000
00?o[KGN00?o/<?Xojo1ion_`NL01?n_`NL2ojg0i`;o[/CZ1On]`nX00on]`^Wo[L?Zojg3jP02ojg3
jQCooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000009ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo00[ooooo1?nXW/d3ojJHb0CoY9;3
1?nRS[l2oj29^`03oiV8`?nHQKgoV8Fm00;oV8Fm1?nGP[X3oiIo^0?oUWff1?nENk@4oiAi/P;oU7Ra
00?oU8:noiB2_OnDP[d00_nDP[d4oiF1^`?oUX6j1?nFOkT3oiIn]`GoUgfe0onGO;@2oiMk/P;oVYG=
1?nKU<`4oibCbPCoW9;90onMT/P00ol0003oUg:WoiMbY`02oiIaYP04oi9[XonBJZ;oTVZRoi9ZXPCo
TVVQ1?nBJJ02oi9XW`?o00000_nBJ9l7oi9XWPGoTVRO0onBJIl2oi=ZX0;oVG>V1?nJLjH4oiYdYPSo
VgFW0onLMZL00onSPk;oXH2_oj60[`02oj60[`CoX7j]2?nOO:`00onmbnGo_;gJokbmfP03okbmfP03
ok^cd_nNNJWoW7V[00?oY86^1?nSPJh4oj:1[`03oj62/_n]T[[o[I:j00;o[I:j1?n[SkT4ojN<^@03
ojB;^_n]VL?o[IW300;o[IW31?nZUl<2ojRGa0;o/joE1On`Zm<2ojfYd`?o/KSN1?n_]]h00ol0003o
/<?Xok33j002ok33j0Co[l7W00?o[/K/ojk4j_n^a>X00on^a>X2ojg3jP;o[LG[1?n]`nX00on/`n_o
ooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;oooo
o`05oc8b<_nHV9SooooooiRHV?lb<S802Oooool002Oooooo00?o0000ooooooooool02?ooool00on[
Y];oZ9k=ojRNc@03ojRNc@?oYYS81?nTT/<2oj:>_`;oVhc31?nIR<03oiR5_@CoUh:j1?nFOkP3oiIm
]P?oUG^d0_nDNK82oi>3_PCoU8:n1?nDP[d3oiF1^`?oUX6j1OnFOkT3oiIn]`CoUgfe0_nGO;@00onI
U/ooVYG=oiZEc@03oiZEc@CoViC<0onLTlX5oibBb@03oifBb?nGLZOoUg:W00;oTVbT0onBJj<3oi9Z
XPCoTVVQ0onBJJ03o`0000GoTVRO2?nBJ9h4oi9XW`;oTVVO00?oV7:VoiUcY_nILjH00_nILjH4oiYc
YPCoVWBV2?nKMJL01?nLMZOoXh>boj>3/_nSPk84oj60[`CoX7j]1_nOO:`4okg;i@?o_;gJ0_nNNJT0
0onUPZooY86^ojB1[P02ojB1[PCoXh6^1?nRPJl5ojfB^PGoZhni0_nWS;T00on_WLGo[IW3ojfI``03
ojfI``?oZYO300?o][GHok>_eOnc[mD00onc[mD3ok2[d`03ok>lhOna^=ko/KSN00Co/KSN0_n_]]h0
0onaa^[o0000ok33j004ok33j003ojo1ion^a^co[/K/00;o[/K/0_n^a>X2ojg6k@Go[LG[00?o[L?Z
ojc3jon/`n/00_n/`n/Dooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`02Oooool002Oooooo0_l00006ooooo`03ojf^f?n[
Y];oZjKB00;oZjKB1?nXW/d4ojJHb0;oY9;300?oW977oi^<`onKS<<00onKS<<3oiV8`0?oV8Fm1OnG
P[X3oiIo^0?oUWff0_nENk@00onCQ;ooTh>noi>3_P03oi>3_P?oU8:n1?nDP[d3oiF1^`CoUX6j1?nF
OkT3oiIn]`;oUgfe0_nIUm04oiVFc`CoVYG=1?nKU<`4oibCbP;oW9;90_nHM:T00onBKJGoTVbToi9/
Y002oi9/Y0?oTV^S1?nBJZ83oi9YX@04oi9YX?l0003o0000oi9YX0OoTVRO2?nBJ9h4oi9XW`03oi9Y
WonHLZKoV7:V00GoVG>V0onJLjH4oiYdYPOoVgFW00?oY8Neoj>3/_nSPk800onSPk83oj60[`GoX7j]
0onOO:`00onkg?7o_L_Uokg;i@03okg;i@03okbmf_nONJSoWWVY00?oYH:_1?nTPJh5oj>1[P;oXX6_
0_n`Ukd4ojfB^PGoZhni00CoYhbiojnMaOn_WLGo[ig51On]VL<01?nZUl?o][GHokJef?nf]MP5ok>_
e@04ok2[donc_>7o/kcQok>lh@Co/KSN00?o/L_]ok76j_naa^X00_naa^X00ol0003o/<?Xok33j002
ojk9k@Co[/K/00?o[<S^ojg6kOn]a^d00on]a^d2ojg5j`?o[<C/1?n/`n/Eooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
2Oooool002Oooooo00?o0000ooooooooool01?ooool3ojf^f0CoZjKB1?nXW/d2ojJHb003oifFc?nL
TLOoW97700;oW9771?nKS<<3oiV8`0CoV8Fm1?nGP[X2oiIo^004oi>6`_nCQL7oThG1oi>5`@CoThBo
1?nCPkh3oiB2_PCoU8:m1?nEPK/3oiJ1^P;oUWni0_nGVM<3oiRHdPGoVIO@0onIU/l5oiZEc@CoViC<
0_nLTlX00onHMZ_oTVjWoi9^Y`03oi9]Y@CoTVbT1?nBJj<3oi9ZXP04oi9YXOl0003o0000o`0000?o
TVVP1onBJ9l8oi9XWP;oTVRO0_nGLJH4oiQbYPCoVG>V0onJLjH5oiYdYPCoVgFW0onTQkD5oj>3/P?o
XH2_1OnPOZd00onOO:co^mcaok_Ll@02ok_Ll@?o_L_U0_nONJP00onUQ;3oYH:_ojF2[`03ojF2[`?o
Y86^1OnSPJh01?nRPJoo/9Nmok2G_On`Ukd5ojfB^P?oZhni00?o/Z;8ojnMaOn_WLD00_n_WLD4ojfI
``03okRmgOnf]MSo][GH00;o][GH1?nc[mD00ond`^Go/kcQok>lh@03ok>lh@03ok6hg_nabngo/L_]
00;o/L_]0onaa^X00on^c>oo0000ojk9k@03ojk9k@03ojk6k?n/b>ko[<S^00;o[<S^0on]a^d2oj_6
k@Go[<C/0_n/`n/2oj[2ja;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Wooooo000Wooooo`03o`000?oooooooooo00;ooooo00?o/;SO
ojf^f?n][]P00_n][]P5oj^VdP;oZ9k=00?oWicAoifFc?nMU/`00_nMU/`3oibAa`CoVhc31?nIR<03
oiR5_@;oUh:j0_nDQl@4oi>6`P?oThG10onCQ;l4oi>3_PCoU8:n1?nDP[d3oiF1^`;oUX6j00?oUYWD
oiNIdonGVM<00onGVM<3oiRHdPCoVIO@1?nIU/l2oiZEc@?oB<SC00CoTW2Yoi9_Z?nBKjSoTVnX1?nB
KZL4oi9]Y@?oTVbT1?nBJj<01?nBJZ;o0000o`000?l00003oi9YX@?oTVVP2?nBJ9l6oi9XWP03oiIa
Y_nGLJKoUg6V00;oUg6V1?nHLZH4oiUcYP?oVW>V1OnJM:H2oi]eY`03ojJ<^OnTQkGoY8Ne00?oY8Ne
1?nSPk84oj60[`?oX7j]0_n^kOP5ok_Ll@03okg;iOnPNZSoWgVX00;oYHB`1OnUPZl4ojB1[P?oXh6^
00?o/ig2ok2G_On`Ukd00_n`Ukd5ojfB^P04oj^?^OnbX/So/Z;8ok:Rb0Go[ig500?o[IW3okRmgOnh
_Md00_nh_Md4okJef003ok>_eOnd`^Go]<;U00;o]<;U0onc_>42ok3?l0Co/L_]00Ko/LKZojk<kon^
c>oo[/c_o`000?n^c>l2ojk9k@;o[<[`1On/b>h00on]a^goZlK]oj_6k@02oj_6k@;o[<C/0_nZ`n`5
oj[2jaCooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00Wooooo000Vooooo`?o000000?o//;Vok2hgon`^=l00_n`^=l4ojf^f0;o
ZjKB0_nQY=L4oinLd@?oWIK<0onLTLL5oi^<``;oVHS000CoU8c9oiB:a_nDR/KoU8[61OnDQl@3oi>6
`P?oThG10onCQ;l5oi>3_P?oU8:n1?nDP[d2oiF1^`GoUYWD1?nGVM<3oiRHdPGoVIO@0_nIU/l2oeK@
h`03oiao/_nBLJ[oTW2Y00;oTW2Y0onBKjP4oi9^Y`CoTVfU0onBK:@2oi9[X`?o00000_nBJZ84oi9Y
X@?oTVVP2?nBJ9l4oi9XWP?oUW6V1?nGLJH4oiQbYPCoVG>V1?nJLjH4oiYdYP03oi]eYonVS;WoYXbi
00GoY8Ne1?nSPk84oj60[`03oj1n[On^kOSo[^gh00?o[^gh0_nkg?43oj1jZ003ojJ6/_nUQ;3oYHB`
00;oYHB`1?nUPZl4ojB1[P03oj>1[_ncWL;o/ig200;o/ig21?n`Ukd3ojfB^P03okBYc_nbX/So/Z;8
00?o/Z;80on_WLD00onia^Go^;gMokRmg@03okRmg@;o][GH0ondbNX4okC2i@03ok>lhOn`co3o/<o`
00?o/<o`0_nabnd2ojg?lPCo[/c_00?o0000ojc:l?n/b_000on/b_02ojc8kP;oZlO^1?n[a^d2ojW4
k@CoZ/?/0_nZ`^/2ojW1jaGooooo00?o0000ooooooooool07_ooool002Kooooo00?o0000ok;2i_nb
`^H00_nb`^H4ok2hg`;o[JkH0_nR[=h4oj6Te`?oWicA0onMU/`4oibAa`;oVhc30_nDT<`4oiB<b@?o
U8[61?nDQl@3oi>6`P?oThG11?nCQ;l4oi>3_P;oU8:n00?oUISDoiFIe?nEVM@00_nEVM@8oiJIe0?o
UiWC1?nHV=82oiVGd0?oI=Ca0_nBLZ/3oi9aZPCoTW2Y0onBKjP3oi9^Y`CoTVfU0_nBK:@3o`0000;o
TV^S0onBJZ84oi9YX@CoTVVP1onBJ9l2oi9XWP03oiE`Y_nFLJKoUW6V00?oUW6V0onGLJH4oiQbYPCo
VG>V1?nJLjH3oiYdYP03ojRB_onVS;WoYXbi00;oYXbi1?nTQkD5oj>3/P;oXH2_0on9k>L2ojk]n0Co
XG^Y00CoX7ZXojJ6/_nVQ[;oYXJb1?nUQ;05ojF2[`;oY86^00?o]:C8ok>M`_ncWL800oncWL84ok2G
_@03ojfB^_ndZLko]:W>00;o]:W>1?nbX/P00on_WLGo^LKUokW6i@02okW6i@?o^;gM0_nbd_45okC9
jP;o]<;U0on^e?@2ok3?l0;oZ];e1On]co801On^c>ooZlcaoj_<lOn[c?7o000000;o[<[`0onYb?04
oj_7kP03oj_6kOnYa>goZLC]00?oZLC]0_nZ`n`2ojW2k0CoZL7[5?ooool00ol0003oooooooooo`0N
ooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonb`^H00onb`^H2
ok2hg`;oXkGU1?nR[=h3oj6Te`CoWicA0onMU/`2oibAa`03oiBCd?nDT<coU93<00?oU93<0onDS<T3
oiB:aPCoU8O41?nCQ/83oi>5`@?oThBo0_nCPkh2oiBHe0CoUISD1?nEVM@8oiJIe0?oUiWC0_nHV=82
og3FnP03oj68^_nCLjcoTW:[00?oTW:[1?nBLJX3oi9`Z@?oTVnX0onBKZL3oi9]Y@?o00000_nBK:@3
oi9[X`?oTVZR1?nBJJ44oi9YX0GoTVRO0_nDKjH3oiE`YPGoUW6V0onGLJH4oiQbYPGoVG>V0onJLjH0
0onJM:KoZ9:oojRB_`02ojRB_`?oYXbi1OnTQkD4oj>3/P04oj60[on9k>OoRNcWohW/i`?oXG^Z0onQ
NjT00onVR;CoYXJbojJ6/P02ojJ6/PCoYHB`1OnUPZl01?nTPJko]:C8okBTb?ndY<P4ok>M`P?o/9Nm
00?o]K;FokBYc_ndZLh00ondZLh3ok:Rb0;o]m7]1Onia^D00onh_Mgo/];aok;Bl@02ok;Bl@;o]<WZ
0_nZf?P4ojkDm0;oYmCg1?nZd_D2ojg?lPCoZLgc0_n[c?400onXbO7o0000ojW8l004ojW8l0;oZlO^
0_nYaNh4ojW4k@03ojS3k?nY`^coZL;/00?oZL;/0_nY`N/2ojS1jaCooooo00?o0000ooooooooool0
7Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;o//;V
00?oY;o]oj>eiOnS]ND00onS]ND4oj:/gP?oXJCG0_nOW=401?nEWMWoUISDoiFHe?nEV=@4oiBCd0Co
U93<0onDS<T3oiB:aPGoU8O40onCQ/82oi>5`@04oi>Ge?nDUmCoU9ODoiBGe0GoU9SD0onEV=@4oiFI
e0KoUYWD1?n3dOl2og_Do`;oU7F]0onCLj`4oi9bZ`CoTW6Z0onBL:T3oi9_Z0?oTVjW0ol000000onB
KJGoTVbToi9/Y002oi9/Y0CoTV^S0onBJZ83oi9YX@CoTVVP0_nBJ9l00onCKjKoU6nVoiA_YP02oiA_
YPCoUG2V1?nFLJH4oiMaYPCoV7:V1?nILjH2oiYcYP03ojVHaOnXT[ooZ9:o00?oZ9:o0onVS;T5ojB7
]@;oXh>b0_m9aJh3oj5lZ`CoXG^Z00CoXG^YojJ8]?nVR;CoYXRd1OnVQ[84ojF4/0?oYH:_00?o]Zg@
okBTb?ndY<P00_ndY<P5ok>M`P04ok2G_One/]Ko]K;FokFbePGo]:W>00?o/Z;8okOAkOngdNd00_ng
dNd2okW6i@;o[MWg1?nbd_42ojCJnPCoZ]Sh00?o[]CdojODmonWe?L00onWe?L2oj[Bm@;oYlkd1?nY
cO<01_nWbO;oZ<WaojS9lOnXbO7o0000ojS9l@;oZLS`0_nXaNh5ojW5kP03ojW4kOnX`ncoZ<?/00;o
Z<?/0onY`^`00onX`NcoZ<7[ojS1j`03ojS1ja?ooooo0_l0000Nooooo`006oooool01Ol@413ooooo
oooooooooooo410@00Kooooo0_l00002ooooo`?oY;o]1OnS]ND2oj:/gP04oiFZiOnEXmooUJ?OoiFS
g`CoUIgI0onEV=@4oiBCd0?oU93<1?nDS<T3oiB:aP;oU8O40_nAUmH3oi:Ge@CoTiOD0onDUm@4oiBH
e0CoUISD1?nEVM@2oiJIe0CoRLgn0_n3dOl2oiMh[`?oU7F]1?nCLj`3oi9bZ`CoTW6Z0onBL:T3oi9_
Z0?o000000?oTVjWoi9]YOnBKJD00_nBKJD3oi9/Y0CoTV^S0onBJZ83oi9YX@;oTVVP0_nBKZL3oi=_
YPGoU6nV0onEL:H4oiIaYPCoUg6V1?nHLZH4oiUcYP04oiYcY_nYV<GoZIS5ojVHa@CoZ9:o1?nVS;T3
ojB7]@04oj1m[OnQOJcoXGf/oj5m[0GoXGb[0_nQNjX00onVRkSoYXRdojJ8]003ojJ8]0CoYXJb1?nU
Q;001?nUPZoo]Zg@okJ]d?nf[M04okBTb0Co/ig200?o][gOokFbe_ne/]H00_ne/]H4okBYcP03ok7J
mOngdNgo]m7]00;o]m7]0_nUgo/4ojgIm`03ok;BlOnTf_[oY=[j00?oY=[j0_nZf?P3oj?En@;oYmCg
0_nUc_D5ojO>m003ojW=lonWbO;oYlWb00;oYlWb0_nXbO400onWaNoo0000ojS5kP04ojS5kP;oZLG^
0_nX`nd5ojS3k003ojW2k?nX`NcoZ<7/00;oZ<7/0_nX`N/2ojS0ja;ooooo00?o0000ooooool00000
7_ooool001_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
0onT_nd2oj>ei@;oU;;[1?nEZ^D3oiFSg`?oUIgI0onEV=@5oiBCd0?oU93<0_nDS<T01?n>VMWoT9SG
oi2Heon@V=L5oi6GeP?oTYOE0onCUm@4oiBGe0CoU9SD0_nEV=@3ohk6nPCoS<Wl0_n9cOh00on[W<Oo
VGbaoiUl/@03oiMh[`CoU7F]0onCLj`4oi9bZ`?oTW6Z0onBL:T00onBKjSo0000o`000004oi9^Y`Co
TVfU0onBK:@4oi9[X`?oTVZR0_nBJJ400onAKJOoTVjWoi9^Y`02oi9^Y`CoTfnV1?nDKjH3oiE`YPCo
UW6V1?nGLJH4oiQbYP;oVG>V0_n[Wl/4ojVHa@GoZ9:o0onVS;T01?nTQkGoX7f]oj1m[OnPOJd3oj5m
[0GoXGb[00?oXG^ZojJ;^?nVRkP01OnVR;@4ojJ6/P?oYHB`00?o]kOIokJ]d?nf[M000onf[M04okBT
b003ok>M`_nf_Moo][gO00;o][gO1?ne/]H00ondZLko/M[eok7Jm@02ok7Jm@03okOAkOnUgo_oYMok
00?oYMok0_n]fOL3oikKo0;oY=[j0onPeO/2oj?En@?oXlgf1?nUc_D2ojO>m0?oY/Wb0_nWbO86ojO5
k`03o`000?nXaNkoZ<G^00OoZ<?]0_nX`n`6ojS1k003ojS1jonX`>_oZ<3[00?oZ<3[5?ooool00ol0
003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00oooool4oi>jlP?oU;;[0onEZ^D4oiFSg`?oUIgI0onEV=@2oiBCd0;oS9gO0on=Vm`4ohjI
f@?oT9SG1?nAUmH3oi:Ge@CoTiOD1?nDUm@2oiBHe0;oSl?i1On>a_X2ohc9o003ojnRbonMP;?oVGba
00?oVGba0onGN:l4oiAe[@?oTg>/1?nBLZ/3oi9aZP04oi9`ZOl0003o0000o`0000?oTVnX0onBKZL4
oi9]Y@?oTVbT0_nBJj<2ohm]Y`?oT6fW0onAKJL5oi9^Y`?oTfnV1?nDKjH3oiE`YPGoUW6V0onGLJH3
oiQbYP03oj^UdOn[Wl_oZio;00?oZio;0onYV<D5ojRB_`;oYXbi00?oWgj_oj1m[OnPOJd00_nPOJd4
oj5m[0?oXGb[00?oYXfkojJ;^?nVRkP00_nVRkP4ojJ8]0CoYXJb00?oYHB`okNgfOng]mT00_ng]mT4
okJ]d0;o]:C80ondbNT4okJmg`;o]K;F1?nXhO/2ok7Jm@?oVn;m0_nUgo/3oiWJo@;oW]_l1?nMeO/2
oj3En`;oX/cf1OnScOH2ojG>m@;oYLSb0onVbO82ojK5k`OoYlG_00?o0000ojO3kOnX`nd01_nX`nd8
ojS1k0?oZ<7[1?nX`>/Eooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`05ooooo`CoTk[b0onD/^/3oiFZi@;oUJ?O00?oQjKY
ohRSiOn8XnD00_n8XnD3ohZOhPCoS9gO0on=Vm`3ohjIf@?oT9SG1OnAUmH3oi:Ge@;oTiOD0on<`?P3
ohk2n0CoSl?i0_n>a_X2ok:Yc`04oj25]onMP;?oWH2coif0/`CoVGba1?nGN:l3oiAe[@?oTg>/1?nB
LZ/01?nBLJ[o0000o`000?l00003oi9`Z@?oTVnX0onBKZL2oi9]Y@;oSVbX1on?KJL3oi1]Y`CoTFfW
1?nBKZL3oi=_YPCoU6nV0onEL:H5oiIaYP?oUg6V00?oV7:Voj^UdOn[YM400_n[YM44oj^Ob`CoZIS5
0_nXT[l2oiin/0?oWgj_1?nPOJd4oj5m[003oj5lZonVSK_oYXfk00;oYXfk0onVRkP5ojJ8]0;oYXJb
00?o]/;SokNgfOng]mT00ong]mT3okJ]d0;o/=Gc1OndbNT2okJmg`?oVnCl0_nXhO/4oi7Ro@;oVn;m
0onFfOh2oiWJo@?oW=?k0_nMeO/2oj;;m@GoX/cf0_nScOH2ojC8lPGoYLSb00?oY/WbojK5konVaNl0
0_nVaNl2ojO5k`GoYl?]00Co0000ojO3kOnX`ngoZ<?]0_nW`N`9ojS1k0GoZ<7[1?nX`>/Dooooo`03
o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oo
oooo0_nC^_800on1/oGoPjoaoh>_l@02oh>_l@?oQJ_]0on7Y^T4ohRSi@?oRYoR0on<WMl3ohfKg0Co
SYWI0on@V=L2oi6GeP?oQ[ch0on9__P5ohc0n0?oS/;h0_n?`oT2okJ_dP04ojB;^_nPQKOoX8Fgoj25
]`CoWH2c1?nIO;43oiMh[`?oU7F]1?nCLj`01?nBLZ_o0000o`000?l00003oi9aZP?oTW2Y0_nBKjP0
0on>KJSoSVbXohi/Z005ohi/Z0OoSffW1?n@KJL3oi5]Y`CoTVjW0onCKjH4oiA_YPCoUG2V1?nFLJH2
oiMaYP03ojZYe_n[YM7oZjGA00?oZjGA1On[Wl/2ojVHa@GoWWj`0onOOZl5oj1m[@;oXGf/00?oYY2n
ojJ=^onVSK/00onVSK/3ojJ;^0GoYXRd00CoYXJbokK2honf`^?o]/;S1Ong]mT00onf[M3o/=Gcok3E
l`02ok3El`;o]<WY1?n>i?/2oi_To0?oRN7l0_nAh_d3oiGHoP;oU]Wn0onLd_X2oicCn`?oX/Wd1?nR
boD2oj;<mP?oY<Ob1?nTb?82ojG8lP?oY/C_0_nVaNl3ojO2k@KoYl?]00?oYl7/o`000?nW`N`01?nW
`N`2ojS1k0;oYl7/1OnX`N`2ojS1j`;oYl3[1OnX`>/Dooooo`03o`000?oooooooooo01Wooooo000K
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`?oPK?e1?n3
[o43ohF[k@?oQjKY1?n8XnD3ohZOhP?oS9gO0on=Vm`2ohjIf@?oOkSh0on2^_P4ohJln0?oRKkh0_n<
`?P3oc6iaP?o^KCE00Co]ZoBojB;^_nTRk[oY8^j1?nPQKL3oif0/`CoVGba0onGN:l4oiAe[@04oi=c
[?l0003o0000o`0000;oTW:[0_nBLJX2ohi]Z@KoSVfX2?n>K:P6ohm]Y`CoT6fW0onAKJL4oi9^Y`?o
TfnV1OnDKjH3oiE`YP?oUW6V00?oZ:_IojZYe_nZZMH00_nZZMH4oj^Ud@CoZio;1?nMO[04oiin/0Co
Wgj_1?nPOJd01?nQOJcoYY2nojJ@__nVT;h4ojJ=^`CoYX^h0onVR;@2okC<k0Co]/;S0_ng]mT4ojSO
nP;o/=Gc0on3h_T2ohkTn`?oQMol0_n9hO`4oiKFo@;oUMSn0onMd?T2oicBnP;oX/Sc1OnRbO@2oj;;
m@;oY<Ga1OnTao82ojC8lP;oY/?_0onVa>l00onV`^goYl;]ojO2k@04ojO2k@;oYl?]1OnW`N`00ol0
003oYl7/ojO1k007ojO1k0;oZ<7/1onW`>/2ojS0j`;oYl3[5?ooool00ol0003oooooooooo`0Ioooo
o`009Oooool00ol0003oooooooooo`08ooooo`?oPK?e0_n3[o42ogB^mP?oM:of1?me[oH3ogJ`m`?o
Mk;g0omi/oL3ogbfn0GoOkSh0on2^_P2ohJln0;o?/7L0_o2g>d01?o2gngo^kWGok^ieonk^ML3okVd
e@03ojRB__nTRk[oY8^j00?oY8^j0onPQKL3oif0/`CoVGba0onGN:l2oiAe[@?o000000?oTg>/oi1_
Z_n?KZT00_n?KZT4ohi]Z@OoSVfX1on>K:P6ohm]Y`CoT6fW0onAKJL4oi9^Y`CoTfnV1?nDKjH3oiE`
YP03oiIaY_nXZmWoZ:_I00;oZ:_I0onZZMH5oj^Ud@04oj^ObonLOK7oW7faoiam/@?oWGj`1?nNO[04
oimn[`;oX7f]0_nVTl44ojJ@_PGoYXfk0onVRkP00onVR;Co]<c/okC<k003okC<k0;o]/;S0onLi?`2
ojSOnP?oO>3g0_n3h_T4ohCNo0;oQMol0onHe?d2oiKFo@?oW/kh0_nMd?T3oj?6lPCoX/Sc0_nRbO@2
ojC4l0GoY<Ga0_nTao82ojK3kPGoY/?_00CoY/C_ojK2kOnV`^goY/;]1?nW`^d8ojO1k003o`000?nW
`NcoYl7/00KoYl7/3onW`>/Booooo`03o`000?oooooo000001[ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo1_md[_H3ogB_mPCoMJof0omf/?L3ogNbm`?oNK?g0oml]_P2ognhn0CoCLG_0_m5`nL4
ol;Lk@03okflfOnk^MOo^kWG00?o^kWG00Co^KCEojRB__nXT[koZ9:n1?nTRkX3oj25]`CoWH2c0onI
O;42oiMh[`?o00000_nALJ/3oi1_ZP?oSfjY1?n>KJT7ohi]Z0OoSVbX1on?KJL3oi1]Y`?oTFfW1OnB
KZL3oi=_YPCoU6nV0_nEL:H00onUZM[oZ:_IojR[f@03ojR[f@CoZZWF0_n[YM42oiYl/@CoW7fa0onM
O[05oiin/0;oWgj_00?oYYG4ojJC`OnVTl400onVTl43ojJ@_PGoYXfk0_nVRkP2ok3Fm0Co]<c/0on>
i_X2oicTo0?oNMkg0_mlh?L3ohGNo@;oQ=kl0onJd_`2oiSDo@?oX<cg0onNc_P2ojC5l@GoXlKb0_nR
b?<2ojG3k`CoY<C`0_nTaO43ojK2kPCoY/?^0_nV`nl2ojK1k@GoY/;]00?oYl;]ojO1k?nW`N`01?nW
`N`2ojO0k0?oYl7/00Co0000ojO1k?nW`NcoYl7/5?nW`>/Dooooo`03o`000?oooooooooo01Oooooo
000Uooooo`;o00003?ooool6ogB^mP?oM:of0_me[oH2ofVio@GoIKgm0omO`?d3oe[3n`;oDlGf0_n5
jNd2ok3_m`?o`MW/00?o`]c]okflfOnm_=T00_nm_=T3ok^ie`03ojbI`onXT[koZ9:n00;oZ9:n1?nT
RkX4oj25]`?oWH2c0_nIO;401?nCMJko0000o`000?nBLj`4oi5aZ`CoT6nZ0on?KZT3ohi]Z@OoSVfX
1on>K:P7ohm]Y`?oT6fW1?nAKJL4oi9^Y`?oTfnV0_nDKjH2oj6Uf0CoYJWJ1OnXZmT2ojZYeP;oV7^a
0onJO;44oiam/@CoWGj`1?nNO[001?nOOZooYYG4ojJEa?nVUL@4ojJC`@CoYY2n0onVSK/2oj[Mn@Co
/=Kd00Co]<c/ohkVn_n>i_[oS^Kj1Omig_L4ohSMoP;oQMkm0onLdOX2oi[Bo0;oXL[e1OnPc?L00onN
c_SoY<GaojC5l@02ojC5l@;oXlKb0_nU`nh5ojG3k`;oY<C`0_nV`^d5ojK2kP;oY/?^1_nV`Nd2ojK2
k@KoYl7/1_nW`>`2ojO1k003ojO0jol0003oYl3[01KoYl3[4oooool00ol0003oooooooooo`0Goooo
o`009?ooool00ol0003oooooooooo`0=ooooo`?oMJof1?ma/_T3offfn`?oJKWm0_mU_Od4oeO8mP;o
@/;T0_mGdMl2ohGYk@?o/>og0oo1fN`2okjof`Go_KcI00Co^kWGojbI`on/VL?o[9W30onXT[h5ojB;
^P?oX8Fg0_nMP;<01?nEN;7o0000o`000?l00004oi9c[0?oTG6[1?n@KjX3ohm^Z@?oSVfY1on>KJP7
ohi/Z0OoSffW1?n@KJL3oi5]Y`CoTVjW0_nCKjH00onNWmCoXJGHoj6Uf003oj6Uf0CoYJWJ0_nXZmT3
oiMi/0?oV7^a1?nJO;44oiam/@?oWGj`0_nNO[02ojFGaPCoYYG41?nVTl44ojJ@_P03ojJ=^onZgOWo
Z]gi00?oZ]gi0_n`e_@00on1i?CoNmkhog_Nn002og_Nn0;oNMkg0on<gOh2ohSMoP?oW/oi0_nLdOX3
oj;8l`CoXL[e0_nPc?L3ojC4l0;oY<Ga0onV`^h4ojG3kP;oYL?_0_nV`Nd5ojK2k@;oY/;^0_nW`N`7
ojK1k@SoYl7/1_nW`>`5ojO0j`03o`000?nW`>_oYl3[01CoYl3[5?ooool00ol0003oooooooooo`0F
ooooo`009?ooool00ol0003oooooooooo`0>ooooo`?oMJof0_ma/_T3ogZkn`CoLL;n0_mVaod4oggG
oP;oKMWe0_nCj?T3ok?Xm`?o_mGZ00?o`MW/okjofonn_m/00_nn_m/3okflf@03ok2Oaon/VL?o[9W3
00;o[9W31?nXT[h4ojB;^P;oX8Fg00CoUgbdo`000?l0003o00001?nCMJh3oi9c[0?oTG6[1?n@KjX3
ohm^Z@CoSVfY1_n>KJP8ohi/Z0KoSffW1?n@KJL3oi5]Y`;oTVjW0_nJUll4oijOe0GoXJGH0_nUZMX2
oiAg/0CoUgV`0onHNk44oiYl/@CoW7fa0_nMO[000onTV<SoYIO6ojFGaP03ojFGaP?oYYG41OnVTl42
ojJ@_P?oX^;l0_nZgOT2ogKQkP?oO]oi0_mkg_P4oi3LoP;oS=gn0onOc_P2oik?n@;oXlOb1OnRb?<2
oj7:m@;oYLC_0onTa?02ojK2k@GoY/;^0_nU`nh2ojO1k0CoY/7]0_nV`^d7ojO1k0;oY/7]0_nW`>`7
ojO1k0SoYl3/1_nW`>/00ol0003oYl3[ojO0j`0EojO0jaCooooo00?o0000ooooooooool05Oooool0
02Cooooo0ol0000?ooooo`GoOk?e0omj^o/2og72oP?oR<oo0_mmeoh3oicQo@Co]=of00Co/nSgokoE
j_noeN[o_mGZ0_nn`M`5okjof`04okflfOn`WlOo/9o7ok2Oa`?o[9W31?nXT[h2ojB;^P;oVX6g0ol0
0004oiEh/@?oTgF^0onBLj`4oi5aZ`?oT6nZ0on?KZT4ohi]Z@OoSVfX1on>K:P6ohm]Y`;oT6fW0_nD
Ql<3oiN?b@GoVYO?1?nNWm@2oj6Uf0?oTgF_0onDMk04oiMi/0?oV7^a1?nJO;43oiam/@03oj>HbOnT
V<SoY9S800;oY9S81?nUUlH4ojJEa0;oYY?11?nKiO`2oj;Ro003ofgMj?n2h?_oP^3k00;oP^3k0_mn
goT3oiCKoP;oT=cn0onQc?H2oio>n0?oY<Ka1?nSao82oj;8l`;oY/?^1OnUa>l00onTa?3oY/;]ojK2
k@02ojK2k@;oY/;^1onW`N`2ojK1k@;oYl3/1onW`N`6ojO0k0;oYl7/0onW`>/6ojO0k0[oYl3[00?o
0000ojO0jonW`>/05OnW`>/Booooo`;o00002Oooool4o`000003oa0@4?oooooooooo00Oooooo000T
ooooo`03o`000?oooooooooo013ooooo0_mo/oD3oi:jlPCoS/Cj0_n8col4oj7Gn`03oicQoOndgoKo
]=of00;o]=of0onndNP00onoeN[o_/7Lokk1g002okk1g0;o_[oK0_ncY/`4ok2Oa`Co[9W30_nXT[h0
0onMQk_oVX6go`000002o`0000?oUgbd1?nEN;43oi=e[P?oTW>/1?nALJ/3oi1_ZP?oSfjY1?n>KJT7
ohi]Z0OoSVbX1On?KJL00onBP;goU8O3oiB7``03oiB7``?oUho91?nJUll3oijOe0;oTG>]1?nCMJl3
oiAg/0CoUgV`1?nHNk43oiYl/@03oiam/OnSV<WoXiS900;oXiS90onTV<P5ojFGaP;oYYG40onDi_`2
oi_Uo0;oJ=_T0on6hO`2oh;Pn`CoUm[n0_nDfoh3oj;;m@;oXLcf0_nUaO05ojC6l@;oXlOb0_nV`^h4
ojK3kP;oYLC_0onV`Nd3ojK2k@SoYl7/1onW`>`2ojO1k0;oYl3[1onW`>`7ojO0j`;oYl3/3_nW`>/0
0ol0003oYl3[ojO0j`0EojO0ja?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`0Booooo`CoT[[b0_n>a?X4oj?;m0;oXMOk0onceO800ondgoKo_]7XokkAj002
okkAj0;o_/;M0onn`M`00onf[M3o/jK<ok>Vc003ok>Vc0Co/9o70_n/VL<00onQSKooWHNko`000002
o`0000?oVX6g1?nGO;@3oiEh/@?oTgF^0onBLj`4oi5aZ`CoT6nZ0on?KZT3ohi]Z@OoSVfX0_n>K:P0
0on?M;7oSgNdohmg]002ohmg]0?oT7^h1?nBP;d4oiB7``?oUho91OnJUll00onNWmCoTG>]oi5c[@02
oi5c[@?oTgF_0onDMk05oiMi/0?oV7^a0_nJO;400onRUl[oXiS9oj>Hb@03oj>Hb@?oY9S81?nUUlH3
ohoVnP;oU>Kl0_mUf^43oh[Qo0;oQ^7l0onJf_d2oiOJoP?oXl[d0_nRboD3ojG4k`CoYLG`0_nTa_42
ojK2k@GoY/;^0_nV`nh2ojO1k0GoY/7]00?oY/;]ojO1k?nW`N`01?nW`N`2ojO0j`KoYl3/1onW`>/2
ojO0k1_oYl3[00?o0000ojO0jonW`>/05OnW`>/Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2oi:jlP;oXko]1?nS
bo@2ok;;k0?o/mGb1?nlcNH00onndNSo_/;Mokk2g@02okk2g@04okk1g?nf[M3o]Zg@okJ]d0Co/jK<
0on`WlL00onUU<CoXHfoo`000002o`0000?oWHNk1?nJPKL3oiMl]0?oUGRa1?nCMJh3oi9c[0?oTG6[
1?n@KjX3ohm^Z@?oSVfY0_n>KJP00on>LJkoSW:_ohib[`02ohib[`?oSgBa1?n?Mk@4oi1k^0?oTX2m
1?nDQl<4oiN?b@;oVYO?0on?LJ`4oi5c[@?oTgF_1?nDMk04oiMi/0;oV7^a00?oX9K9oj:Gb_nRUlX0
0_nRUlX4oj>Hb@CoY9S800CoYIO6ohoVn_n?i_[oSnKj0_mTfMl3ohkRo@;oR^7l1?nLfOd2oi[Jo@?o
Y<[c0_nSb_@2ojK4k`GoYLC_0_nUaO02ojO2k@CoY/;]0_nV`^h7ojO1k0;oY/7]0_nW`>`4ojO1k0Ko
Yl3[0_nW`>`XojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo01Gooooo1?nS_nd00onSboCo//_/ok;;k003ok;;k003
ok?El_nlcNKo_<gV00;o_<gV0_nn`mh3okk2g@03okRce?nf[M3o]Zg@00;o]Zg@1OncY/`01?n`WlOo
YIC4o`000?l00003oj6=_`?oWHNk1?nJPKL3oiMl]0CoUGRa0onCMJh3oi9c[0?oTG6[0_n@KjX2ohib
[`?oSW6^0on>LJd3ohia[PCoSW:_1?n?M;43ohmg]0CoT7^h0onBP;d5oiB7``;oUho90on>Kj/3ohma
[0CoTG>]1?nCMJl3oiAg/0;oUgV`0_nNTlP4oj2Fb@?oXYO:1OnSV<T2ojBHb0;oRnKi0_mUf]l3oi3R
o@;oS^;m0onNf?`2oicIo@?oYLWc0_nTb_<3ojK4kPCoY/C_0_nUa>l2ojO1k@GoYl;]0_nV`^d2ojO0
k0OoYl7/1_nW`>`00onW`NcoYl3[ojO0j`0aojO0j`03o`000?nW`>_oYl3[01GoYl3[4oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool2oj>ok@Co/L;W0_nbbn`3ok_8
i003okc=i_nn`mko_/?N00?o_/?N00Co_/;MokRce?nh/mCo^;?D1?nf[M02ok>Vc004ojVLbOl0003o
0000o`0000;oYIC40onQSKl4oif7^`?oVX6g0onGO;@4oiEh/@;oTgF^00CoSgReohif/on>M[?oSWJc
0on>M;44ohib[`?oSW6^0on>LJd4ohia[PCoSW:_0on?M;44ohmg]0?oT7^h1?nBP;d2oiB7``CoSFjZ
0on>Kj/4ohma[0?oTG>]1?nCMJl2oiAg/003oif@a_nNTlSoWY?800;oWY?81?nPU/T4oj:GbP;oXiS9
0_n9i_P2ofKKg`CoTn?m0_n@h_d3oioHn`;oW]Sl0_nUbO83ojG9l`;oY/?^1OnVa>h2ojK4k`;oYl7/
1?nW`Nd2ojO2k@OoYl3/0_nW`N`2ojO0j`OoYl3/=_nW`>/00ol0003oYl3[ojO0j`0EojO0ja7ooooo
0ol00007ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo0ona`^L2okW3hP?o^lST
0onma=l3okk3gP03okZif?nh/mCo^;?D00;o^;?D0onf[M001?n]Xlko0000o`000?l00002ojVLb@?o
YIC41?nQSKl3oif7^`;oVX6g00CoTX6moi1m^_n@OK[oT7fj1?n?N[P3ohmh]@?oSWJc0on>M;44ohib
[`CoSW6^0on>LJd3ohia[PCoSW:_0on?M;44ohmg]0CoT7^h0_nBP;d3ohe]Z@CoSFjZ1?n>Kj/3ohma
[0;oTG>]00?oV8S1oiZ<a?nJS<@00_nJS<@4oif@aPCoWY?81?nPU/T2oj:GbP;oRNGh0_mYg=l3oiGT
o@;oTn?m0onQf?/2oioHn`?oY/Sb1?nUbO800onUbO?oY/?^ojK3kP02ojK3kP;oY/C^1onW`N`2ojO1
k@;oYl3[1onW`>`6ojO0j`;oYl3/>_nW`>/00ol0003oYl3[ojO0j`0EojO0j`kooooo1?l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o/L;WokW3
h_ni`n800_ni`n800onkb>Co_LCOokg4g`03okg4g`04okk3g_nj^MSo^[WHokZif0Co^;?D0ol00000
0on]XlkoZIc9ojVLb@02ojVLb@CoYIC40onQSKl2oif7^`03oiB5`?nBPKgoTX6m00;oTX6m0on@OKX3
ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3ohia[@?oSW6^1?n>LZl4ohmd/@?oSgNd0_n@NkP2
ohi^ZPKoSFfY0on=KZX4ohi_Z`;oSg6/00?oUXBnoiR8`OnHR<400_nHR<44oiZ<a0?oWI361?nNTlP2
oj2Fb@?oRnGi00?oK=gQoiKTo?nFi?`00_nFi?`2oiGTo@?oX]Wk0_nQf?/2ojK8l@GoY/Sb0_nUbO83
ojO3kP;oY/?^2?nW`N`7ojO0j`;oYl3/AonW`>/00ol0003oYl3[ojO0j`0EojO0j`[ooooo0ol00005
ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000002oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool2o`0001_ooooo0oni
`n86okg4g`03okbng?nj^MSo^[WH00?o^[WH0ol00005ojfScPCoZIc90_nUU<@01?nKT<OoV8[3oiR:
`onHR/<4oiB5`0?oTX6m0on@OKX3ohmj^0CoSgRe0on>M[<3ohid/@CoSW:_0on>LJh3ohia[@?oSW6^
1On>LZl3ohmd/@;oSgNd00?o0000ohi^Z_n>KZX00_n>KZX6ohe]Z@;oSFjZ00?oTG^hoi=o^_nCOkX0
0_nCOkX4oiJ4_P?oV8S11?nJS<@4oif@aP;oWY?80on=iOX01?n;iOWoV>GloiSUo?nHiO`2oiKTo0Ko
X]Wk0_nWbO44ojK8l@;oY/Sb1_nW`nh8ojO1k5CoYl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`Co
00002?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo00?o^L?Rokg4
gonma=l00onma=l4okbng004okZif?l0003o0000o`0000Co/:_C1On]Xlh2ojVLb@03oinGbonKT<Oo
Vi3700;oVi370onHR/<3oiB5`0?oTX6m0on@OKX4ohmj^0?oSgRe0on>M[<3ohid/@CoSW:_0on>LJh3
ohia[@CoSW6^1?n>LZl2ohmd/@;oE=3J0_n<L[04ohac/@?oSWFc0on?N;D4oi5k^0CoTgnj0onFQ;h3
oiR8`@GoVXc40_nMT<H3oi3To0;oSNGj00CoKmoRoiSUo?nHiOcoV>Gl0onSf_/2oj;In`OoYlWa0_nV
b?42ojO3k@GoYl?^1onW`NaGojO0j`03o`000?nW`>_oYl3[01GoYl3[0_ooool3o`0000cooooo00?o
0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool07Oooool6okg4g`05okbng?l0003o
0000o`000?nj^MP00onc/mP4ok2[d`;o[J?>0_nSW]04oinGb`?oVi370onHR/<3oiB5`0CoTX6m0on@
OKX3ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3ohia[@?oSW6^0_n>LZl3ogKIn`GoS7:`1?n<
Lk43ohie/`CoSgRe0onANkP4oi=o^P?oUXBn1?nHR<42oiZ<a0CoTn;m0_n@i?`2og;Qi0;oVNKl0onS
fo/2oj?Jn`SoYlWa1onW`nd2ojO3kPKoYl7/FonW`>/00ol0003oYl3[ojO0j`0EojO0j`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool4
okg4g`;o00000_nl_]`00onf^mgo/k?Hok>cf003ok>cf0;o/:_C00?oYjKEoj>Nd?nSW]000onSW]03
oinGb`?oVi370onHR/<4oiB5`0?oTX6m0on@OKX3ohmj^0CoSgRe0on>M[<3ohid/@?oSW:_1?n>LJh3
ohia[@;oSW6^0on6c?h00omffO_oSWBaohid/@06ohab/0?oS7>a1?n>MK<3ohmh]@?oTG^h1?nCOkX4
oiJ4_P;oV8S10onGg_h2oi?Ro@;oMn?W0onIj?/00onTgO_oXm_koj?Kn`02oj?Kn`;oZ<[b1_nWbO49
ojO3k@OoYl7/G_nW`>/00ol0003oYl3[ojO0j`0EojO0ja3ooooo00?o0000ooooooooool04?ooool0
02;ooooo0_l0000Pooooo`?o000000?o_LCOokS3honf^md00onf^md3ok>cf003ojZ_fonWY]GoYjKE
00;oYjKE1?nSW]04oinGb`?oVi370onHR/<3oiB5`0;oTX6m00CoRX[=ohR9c_n8RLkoR8W>0on6RLl4
ohF;dP?oQ8kF0on5U=/3ohJMhPGoR:[[1?n9^_H2ohK<oPCoSWBa1_n<L[04ohac/@?oSWFc0on?N;D4
oi5k^0CoTgnj0_nFQ;h3oiWHo@;oUmkn0_mliN/3oiWYnP03oiWXnonTgO_oY=gk00;oY=gk00?oXm_k
ojS:l_nXb_800onXb_82ojO9l@SoYl?]2OnW`NaQojO0j`03o`000?nW`>_oYl3[01CoYl3[4?ooool0
0ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Looooo`?o000000?ooooookg4
gonh`n<00onh`n<4okJkg@04ok>cf?nZ[m_oZZoKojZ_f`?oYjKE1OnSW]02oinGb`04oiJJe?nCU=7o
TiCAoi>Dd@?oT93?0on=S<h4ohZ:c@?oR8W>0on6RLl4ohF;dP?oQ8kF0on5U=/3ohJMhPGoR:[[0_n9
^_H01?nDOKOoT7Ncoi1g/on@Mk<3ohid/@KoS7:`1?n<Lk43ohie/`CoSgRe0onANkP2oi=o^PCoV/oj
0_nIf?d2oh;Wl0?oVN[j0_nIjOX3ojCNn`;oY=gk0onXbo82ojS:lP?oZ<C^1_nW`nd8ojO1k6GoYl3[
00?o0000ojO0jonW`>/05OnW`>/?ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oo
oooooooo01Wooooo0ol00006ooooo`Co^<?S0_nf^md2ojfhh@CoZZoK0onWY]D2oj>Nd0;oVZ3H1?nF
V]@3oi>Dd@?oT93?0on=S<h3ohZ:c@?oR8W>0on6RLl4ohF;dP?oQ8kF1?n5U=/3ohJMhP;oR:[[00?o
VXFloiAm]onDOKL00_nDOKL3oi1g/`?oSWBa1on<L[03ohac/@CoSWFc0on?N;D2oi5k^0;oV/Ce1?nJ
coX3ohWWm@04oh;Wl?nIj_[oVN[joiWZnP?oY>7l0_nTg_/3ojS<lP;oZ<_b1onXa>h2ojO3k@SoYl7/
JOnW`>/00ol0003oYl3[ojO0j`0DojO0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o
0000ooooooooool05_ooool3o`0000[ooooo0_nh`n<2ojo2j0Co[KSQ0_nZ[m/01?nO[^;oWJOMoifW
gOnMYmd5oiZPf0?oUY[D0onCU=43oi2@c`?oSHc>0on:R/d3ohR9cPCoQXW?1?n5Rm83ohB>eP;oQICK
00?oZ9c9oj6@`_nQT<800_nQT<83oiZ5_0?oU7fg0on@Mk<4ohid/@KoS7:`0on<Lk44ohie/`;oSgRe
0_nH]nd4oi[4m@04oi[?n_n9ioGoRNOeohWWm@;oVN_i1?nTho`2ojCQo0?oZLgc0_nXc?82ojS5kPKo
Z<C^2OnW`Na]ojO0j`03o`000?nW`>_oYl3[01CoYl3[3_ooool00ol0003oooooooooo`0@ooooo`00
8_ooool2o`0001Cooooo0ol0000>ooooo`Co[l;X0_n]^>400onR]^OoWjkRoin^hP02oin^hP?oWJOM
1?nJX=P4oiJJe0?oTiCA0on@T<l3ohf<cP?oRX[=0on8RLh2ohJ9c`?oEL3j0_ng]]P4ok2Yd@?oZ9c9
0onQT<83oiZ5_0?oU7fg0on@Mk<4ohid/@GoS7:`00CoSY;Coi6MfonAWM_oTIgK1OnEZ^D4oiRgk@;o
V/Ce0_n@i_X2oiW[n0?oXnGl0_nTho`3ojW?m0;oZLgc1onXaNh2ojS4kPSoYl7/L_nW`>/00ol0003o
Yl3[ojO0j`0DojO0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o0000
4_ooool2ojo2j0;oX[k]0onR]^L4oin^hP?oWJOM1?nJX=P2oiJJe004ohbXj?n9Y^SoRJKXohVVj0Co
QZOZ0on2ZNh4ogf_m0;oLKWl0_nk`Mh5okNff0;o/:WA00CoWHc2oiJ5_onFQKooUXFo0onAP;d3ohem
_0?oRWbn0on9OL04ohV2a@?oRhS;1?n>T]<3oi6Mf`GoUJ[U0_nH]nd2oiKRo@?oV>_h00CoVN_hoj?U
o?nSiOcoXnGl0_nZdO@3ojW?m0;oZ<K_1onXaNh2ojS2k0KoYl7/MOnW`>/00ol0003oYl3[ojO0j`0E
ojO0j`cooooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2
o`0001Kooooo1?nR_^d3oj:fi`;oWjkR0_nC/^`4oi6^jP?oSZ_Y0on<Z>P3ohVVj0CoQZOZ0on2ZNh2
ogf_m003okc_loo3ko3o^l7N00?o^l7N0_ng]]P2oj>DaPCoWHc20onFQKl3oi60_@?oSGfl0on:O;h3
ohUm`0CoRH;50on;R</3ohjBd`CoTIgK0_nEZ^D3oi[Jo@GoV>_h0_nSi_/2oj[Cm@CoZ]7d00?oZLod
ojS6konXa^l00_nXa^l2ojS5kPOoZ<;/0_nW`NaiojO0j`03o`000?nW`>_oYl3[01CoYl3[3Oooool0
0ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wooooo0_nR_^d0
0onF^o7oUKO_oiFgk`03oiFgk`?oTk;/1?nA[^X3ohj[j@?oS:SX0on9Y^P2ohJWjP;oGl[j00CoNnKL
okc_lonlko?o_>oc0_nmbN<3ok_1gP03ojVMbonSU<KoXiC600;oXiC61?nMS<83oiJ5_`?oTH2m0on=
OK`3ohYl_P?oRGg01?n9P/D4oh^8b`?oSY;C0_nAWM/3oi_?nP04oi[JoOnHjoSoV>_hoiS[n0?oX^Sk
0_n[eOH4oj[Cm@;oZ]7d0onYb?02ojS6k`WoZ<;/OOnW`>/00ol0003oYl3[ojO0j`0DojO0j`cooooo
00?o0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1Oooool2o`0000[ooooo0ol0000Mooooo`?oU[_a1OnE]nl3oi>bk0;oTJkZ0_n6^oP3oh2mnPCoNL7m
0_m_a_l00ol`^;koNnKLokG[m`02okG[m`03okc_lonmbN?o_LWS00;o_LWS00Co^l7NojVMbonYWL_o
ZIg;1?nSU<H3oif<`P?oUXFo0onAP;d3ohem_0?oRWbn1?n9OL04ohV2a@;oRhS;0_nH/^T4oi[1lP;o
Vloj0_nHj_T3oj7Yn`03oj;Xnon[eOKoZmGf00?oZmGf0_nZdoD3ojW9l0;oZLS`0_nX`nd6ojS2k87o
Yl3[00?o0000ojO0jonW`>/05OnW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo
00Kooooo0ol0000Qooooo`?oU[_a0_nE]nl3ohbim0?oRK[f1?n6^oP3oh2mnP;oNL7m0_mFc^X2ohOX
l@?o]N_g0onlcNL2okg9h`03ojjVd?nYWL_oZIg;00;oZIg;1?nSU<H4oif<`P?oUXFo0onAP;d3ohem
_0?oRWbn0_n9OL000onBV]SoU:GPoiBUh003oiBUh0CoV;;Y0_nJ`O82oiSWn`?oX>Wk0_nQjO/3oj_H
m`;oZmGf1?nZbo42ojW9l0KoZ<?]0_nX`^b5ojO0j`03o`000?nW`>_oYl3[01GoYl3[2_ooool00ol0
003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o00009_ooool4ohnil`?oS;Wd0on9^_H2
ohJkn0?oOlgo0_m_d_`2oi3So0?o/>Ch0_njc^T3okc=i`03ok:^eOn^Y]3o[ZK@00;o[ZK@0onYWL/4
oj>DaPCoWHc20_nFQKl01?nAR/SoSh[9ohn:bOn?R/T3ohn<c0?oSi7A1?nBV]P5oiBUh0;oV;;Y0onI
hod01?nHio_oX>Wkoj3YnonPjO/3oj_Jn0;oZmSg0_nZcO84oj[;l@03ojS4kOnX`ngoZ<?]00GoZ<?]
0_nX`Nb7ojO0j`03o`000?nW`>_oYl3[01CoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool01?l0003ooooo
ooooooooool3o`0002[ooooo0_n?^O<2oi6ilPCoSKoh0on7a_`2ogo=o`;oUM[n1?n/foP00on`i?So
^/kYok[>j@02ok[>j@04okc=ionb[]Go/ZkEok:^e@?o[ZK@1?nYWL/2oj>DaP03oiVBbonESLWoUHg9
00;oUHg91?nAR/P3ohn:b@?oShc<0on?TM44oi:Jf0;oU:GP1?nHg?h2oiWSo@;oWnSk0on[g?T2oj_J
n0;oZloc1?nZcO800onZbo7oZ<C]ojS4k@02ojS4k@;oZ<?]1onX`Nb7ojO0j`03o`000?nW`>_oYl3[
01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001Oooool4o`0002kooooo1?nA^O82ohfon0;oV/Gf1?nHco/00onE
f_ko[=_hojcKn002ojcKn0;o]lgZ0onjc^T00ond]MWo/ZkEok:^e@02ok:^e@Co[ZK@0_nYWL/00onN
V<goVI;;oiVBb`02oiVBb`?oUHg91?nAR/P3ohn:b@?oShc<1?n?TM42oi:Jf0?oUm?l0_nHg?h3oikV
o0;oZ]ki0on[g?T2oj_Am0CoZloc0_nZcO83ojW5kP;oZ<C]2OnX`Nb8ojO0j`03o`000?nW`>_oYl3[
01CoYl3[2Oooool00ol0003oooooooooo`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01?ooool2o`00037ooooo0_nA^O82oibmk`CoV/Gf0_nHco/4oj[B
m@03ojcKn?ngcN[o]lgZ00;o]lgZ00Co^/kYokBefOnd]MWo];GI1?nb[]D2ojjVd003oj>OdOnNV<go
WYS=00;oWYS=0onIT//4oiF=b@?oTH[81?n?R/T3ohn<c0;oSi7A0onEa_P2oiOCo0?oW^;m00?oW^Kl
oj[NnOnZg_T00onZg_T00on[g?WoZm7doj_Am002oj_Am0;oZloc0onYa^h2ojW5kP;oZ<;/1_nX`Nb=
ojO0j`03o`000?nW`>_oYl3[01CoYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0
003oooooooooo`0_ooooo`CoW;g_0_nJaOH3ojS8l0;oZ];e1?ndb^X2okO=jP;o]K[M1?nd]MT2ok:^
e@03ojRVe?nSWm7oXioA00;oXioA0onNV<d4oiVBb`?oUHg91?nAR/P2ohn:b@;oTJo[1?nC^_82oiG6
n0?oWMcm0_nNh_d3ojWOnP;oZ]ki1?n[e?D2oj_Am0?oZLO_0_nYa^h6ojS2k0;oZ<7/TOnW`>/00ol0
003oYl3[ojO0j`0CojO0j`Wooooo00?o0000ooooooooool03_ooool002?ooooo00?o0000oooooooo
ool0;oooool2oibmk`?oYl3[0_nXb?03ok;6j@?o]<[Z0_ne_^44okFjg@;o];GI00?o[:gHojRVe?nX
Y]@00_nXY]@4oj>Od@?oWYS=0_nIT//01?nDWm_oTZ7Ooi:QgonBXMl5oi6Vi0CoTJo[0_nC^_83oicD
n`;oWMcm0onWg_X2ojWOnP?oZmKf0_n[e?D3oj[9l0?oZLO_0_nX`nd6ojS2k0;oZ<7/T_nW`>/00ol0
003oYl3[ojO0j`0DojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000oooooooo
ool0;oooool3ojO0j`;o/<;W1Onba^T00ondb^[o]KkQokFnh@02okFnh@;o]K[M00?o[k?Lojb]f?n/
[MP00_n/[MP4ojRVe0;oXioA00CoW:;IoiRPf_nHX=[oV:3J1?nDWm/3oi:Qg`GoTJKT0_nA[n/3oi[;
n0;oW=Ck0onUg?/2ojONnP?oZ]Og0_n[e_H2oj[:l0GoZ/W`00?oZLO_ojS3kOnX`nd00_nX`nd2ojS2
k0KoZ<7/T_nW`>/00ol0003oYl3[ojO0j`0DojO0j`Oooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`03ojO0jon``^Oo/<;W00;o/<;W0_nba^T3okG1h`?o]KkQ00?o/KWOojncg?n_
/m`00_n_/m`4ojb]f0;oZ:KD00?oXJOJoibRfOnLX]T00_nLX]T3oiRPfPCoU9oK0onBXMl2oi6Vi0Co
VL7c0_nJboP3oj;In`;oYMck0onYf?P2oj[Gm`;oZlca1?nZb_02oj[9l0CoZLC]0_nX`nd8ojS1k9Co
Yl3[00?o0000ojO0jonW`>/05?nW`>/6ooooo`03o`000?oooooooooo00kooooo000Wooooo`03o`00
0?oooooooooo02kooooo0on``^L3okC2i@Co]L7S00Co]KkQok6igona^Moo/KWO1?n_/m`2ojb]f003
ojB/g?nQYm[oXJOJ00;oXJOJ1?nLX]T3oiRPfP;oU9oK0_nG/^X4oiNik`;oVL7c1?nPe?X2oj;In`?o
YmSh0_nYf?P2oj_=lPCoZlca0_nZb_03ojW5kP;oZLC]2OnX`NbHojO0j`03o`000?nW`>_oYl3[01?o
Yl3[1_ooool00ol0003oooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03ok32
iond`^Go]<;U00?o]<;U0_ne`N<2ok:nh`Co/KWO0_n_/m`2ojRag`?oY:cL1?nQYmX2oibRf@03oiZ^
iOnH[nOoV:oW00;oV:oW1?nG/^X2oiNik`CoWLoi0_nPe?X2ojKFn0?oYmSh0_nZc_<4oj_=lP;oZlca
0onYa^h2ojW5kP;oZ<;/1_nX`NbLojO0j`03o`000?nW`>_oYl3[01CoYl3[1Oooool00ol0003ooooo
ooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`;o]<;U0onb`^H4ok:nh`;o/KWO0_n[
]n84ojRag`?oY:cL0_nQYmX2oif_i0?oVZkU1?nH[nL2oiNbjP?oVlWg0_nMcoT3oj?Cn0CoY]Kh00?o
YmShoj[>lonZc_<00_nZc_<2oj_=lP?oZLO_0_nYa^h6ojS2k0;oZ<7/0_nX`>^NojO0j`03o`000?nW
`>_oYl3[01CoYl3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo1?nb`^H2
ok:nh`;o[;cU1?n[]n82ojRag`03oj:diOnO/NCoWk7T00;oWk7T1?nM[n@3oiZ^i@;oV:oW0onJ`o@2
oi_9m`;oX/og1OnSdoP2ojKFn0?oZLoc0_nZc_<3oj[8l0;oZLO_0_nX`nd6ojS2k0;oZ<7[1?nX`>^N
ojO0j`03o`000?nW`>_oYl3[01CoYl3[0oooool00ol0003oooooooooo`0>ooooo`00;?ooool00ol0
003oooooooooo`0_ooooo`;o//;V0_n]`NP4ojbli@;oZkOR0_nU^>L3oj:di@CoWk7T0_nM[n@2oi^l
k`CoV[ob0_nJ`o@2oio;mPCoX/og0_nSdoP4ojS>m0;oZLoc0_nYbO03oj[8l0;oZLC]1?nX`nd2ojS2
k0;oZ<7/1?nX`N/2ojS0jj3oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03o`000?oooooooooo
00gooooo000]ooooo`03o`000?oooooooooo02oooooo1?n]`NP2ojbli@;oY[cY1?nU^>L3oj:di@;o
Wk7T0_nL^nh4oi^lk`;oV[ob0_nNao@4oio;mP;oX/og0onWcO@2ojS>m0?oZL[a1?nYbO000onZb?3o
ZLC]ojW4k@02ojW4k@;oZ<?]1_nX`N`2ojS1jj?oYl3[00?o0000ojO0jonW`>/05?nW`>/3ooooo`03
o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_n]`NP2ojO0j`CoY[cY
0_nU^>L2oj2lk0?oW[_]1?nL^nh2oi^lk`;oW/Cc1?nNao@2oio;mP?oYLcd0_nWcO@2ojS:l@GoZL[a
0_nYbO05ojW4k@;oZ<;/1_nX`NbWojO0j`03o`000?nW`>_oYl3[01CoYl3[0_ooool00ol0003ooooo
ooooo`0=ooooo`00;oooool00ol0003oooooooooo`0_ooooo`CoYl3[0_nV_>T2oj6mk@CoX;c/0onN
^nd2oibkkP?oW/7a0onNa?<2oik7m0?oXlWd0_nUc?@2ojO9l@CoZ<[a0_nYb_44ojW5kP;oZLC]1_nX
`^`2ojS1k0;oZ<3[ZOnW`>/00ol0003oYl3[ojO0j`0CojO0j`;ooooo00?o0000ooooooooool03Ooo
ool0033ooooo0_l0000`ooooo`;oYl3[0_nR_^d4oj6mk@;oX;c/0_nO_^l4oijol0;oW/7a0_nQaO84
oj;7l`;oXlWd0_nVb?44ojO9l@;oZ<[a0onXaNh2ojW5kPWoZ<;/0_nX`N`4ojS0jjSoYl3[00?o0000
ojO0jonW`>/05?nW`>/00ooooooo0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^oooo
o`CoX[k]0_nQ_Nd2oj2nkPCoWkk_0_nN_o02oj73l@CoXLGb0_nRao<2ojG6l@CoY/Sa0_nWbO43ojS5
k`;oZ<G^0_nX`nd7ojS2k0KoZ<7/0_nX`>^ZojO0j`03o`000?nW`>_oYl3[01?oYl3[00?oooooo`00
0?ooool03_ooool003?ooooo00?o0000ooooooooool0;_ooool2oj:nk@;oXKk^1?nP_^h2oinnk`;o
X<7`1?nQ`o42oj75lP;oY<Ga1?nUa_42ojK8l@?oYlG_0_nXaNl6ojS3k@;oZ<;/2OnX`Nb^ojO0j`03
o`000?nW`>_oYl3[01?oYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0
;_ooool4oj6nkP;oX;k^0_nQ_nl4oj31l0;oXL?a0_nS`o04ojC5l@;oYLKa0onVa>l2ojO5k`SoZ<?]
2?nX`NbcojO0j`03o`000?nW`>_oYl3[017oYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0
000_ooooo`GoXKk^0onQ_nl2oj31l0?oXl;_0onS`o02ojC5l@GoY/C_0_nW`nd6ojS3k@SoZ<7/]_nW
`>/00ol0003oYl3[ojO0j`0=ojO0j`Kooooo00?o0000ooooooooool03?ooool003Oooooo00?o0000
ooooooooool0;_ooool2oj6nkP;oX[k]1?nR`>h2oj?2k`;oYL7^1?nU`^h2ojK4k`;oYl;]1?nW`nd2
ojS3k@SoZ<7/0_nX`>^hojO0j`03o`000?nW`>_oYl3[00WoYl3[2Oooool00ol0003oooooooooo`0<
ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`CoX[k]0_nR`>h2ojC0k@CoYL7^0_nU`^h2ojK2
k@CoYl;]0_nW`nd2ojO1k0SoZ<7/1?nX`>^hojO0j`03o`000?nW`>_oYl3[00GoYl3[3?ooool00ol0
003oooooooooo`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oX[k]0_nT_n`4ojC0k@;o
YL7^0_nV`Nd4ojK2k@;oYl;]1_nW`N`2ojS1k0?oYl7/0onX`N`2ojS0jk[oYl3[00?o0000ojO0jonW
`>/04?ooool00ol0003oooooooooo`0<ooooo`00>_ooool2o`0002oooooo1?nT_n`2ojC0k@;oY/3/
1?nV`Nd2ojK2k@goYl7/`?nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo
000looooo`03o`000?oooooooooo02gooooo0_nT_n`2ojFok0CoY/3/0_nV`Nd=ojO1k;ooYl3[1Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000mooooo`03o`000?oooooo
oooo02gooooo1?nU_n`5ojK0k0[oYl7/_onW`>/9ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03?ooool003kooooo00?o0000ooooooooool0;Oooool2ojFok0?oY[o/0_nV`>`6ojO0
k0;oYl7/^onW`>/@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool003oo
oooo0_l0000_ooooo`;oY[o/0_nW`>/6ojO0k;_oYl3[5?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00_ooooo0011ooooo`03o`000?oooooooooo02gooooo1?nW`>/2ojO0k;_oYl3[
6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0012ooooo`03o`000?oo
oooooooo02gooooo_?nW`>/Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool004?ooooo00?o0000ooooooooool0;OoooonhojO0jb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00A?ooool00ol0003oooooooooo`0]oooookCoYl3[9?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;ooooon^ojO0jbWo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00Aoooool00ol0003ooooo
ooooo`0]oooooj[oYl3[;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
0018ooooo`03o`000?oooooooooo02goooooY_nW`>/`ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool004Wooooo00?o0000ooooooooool0;OoooonRojO0jcCooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00B_ooool2o`0002koooooWOnW`>/ioooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000oooooooo
ool0;?oooonIojO0jccooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
COooool00ol0003oooooooooo`0/oooooi;oYl3[@oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02goooooSOnW`>]7ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool004oooooo0_l0000^ooooohSoYl3[C?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo
02coooooQ?nW`>]?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;o
oooo00?o0000ooooooooool0:ooooon1ojO0je?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[oooooggoYl3[Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;OoooomhojO0je[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E_ooool00ol0003oooooooooo`0[
ooooogCoYl3[G_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001Goooo
o`03o`000?oooooooooo02_oooooK?nW`>]Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool005Sooooo00?o0000ooooooooool0;?oooomWojO0jf[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooof?oYl3[KOooool01Ol0003o
oooooooooooooooo000000_ooooo001Jooooo`;o0000;OoooomOojO0jg7ooooo00Co0000oooooooo
oooo00002oooool005cooooo00?o0000ooooooooool0:ooooomKojO0jgGooooo00?o0000ooooool0
00002oooool005gooooo00?o0000ooooooooool0:ooooomGojO0jgSooooo00Co0000oooooooooooo
00002_ooool005kooooo00?o0000ooooooooool0:ooooomCojO0jgcooooo00?o0000ooooool00000
2_ooool005oooooo0_l0000/ooooodcoYl3[Poooool2o`0000[ooooo001Qooooo`03o`000?oooooo
oooo02[oooooB?nW`>^5ooooo`?o00002_ooool006;ooooo00?o0000ooooooooool0:ooooom3ojO0
jhCooooo1?l0000=ooooo`00Hoooool00ol0003oooooooooo`0[ooooocooYl3[Poooool4o`00017o
oooo001Tooooo`;o0000;?oooolkojO0jh?ooooo0ol0000Eooooo`00I_ooool00ol0003ooooooooo
o`0[oooooc?oYl3[QOooool4o`0001Sooooo001Wooooo`03o`000?oooooooooo02[ooooo<?nW`>^4
ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool/ojO0jh?ooooo1?l0000Poooo
o`00JOooool2o`0002cooooo9onW`>^2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0
:_oooolSojO0jh;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0ZoooooagoYl3[Pooo
ool4o`0002_ooooo001]ooooo`03o`000?oooooooooo02_ooooo6?nW`>^2ooooo`Co0000;oooool0
06kooooo00?o0000ooooooooool0:_oooolEojO0jh7ooooo1?l0000cooooo`00Koooool2o`0002_o
oooo4OnW`>^0ooooo`Co0000=oooool0077ooooo00?o0000ooooooooool0:_ooool9ojO0jh;ooooo
1?l0000kooooo`00L_ooool00ol0003oooooooooo`0Zooooo`GoYl3[P_ooool3o`0003oooooo001c
ooooo`03o`000?oooooooooo02[ooooo00?oYl3[ooooooooool0Ooooool4o`0004;ooooo001doooo
o`;o0000:_ooool00ol0003oooooooooo`1kooooo`Co0000A_ooool007Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1aooooo`?o0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooo
oooo06gooooo1?l0001Eooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
06Wooooo1?l0001Iooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Go
oooo1?l0001Mooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo
1?l0001Qooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0GOooool4o`0006Gooooo0020
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F_ooool3o`0006Wooooo0021oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool4o`0006cooooo0022ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool4o`00073ooooo0023ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool4o`0007Cooooo0024ooooo`;o00006Ooo
ool00ol0003oooooooooo`1:ooooo`Co0000N?ooool008Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`16ooooo`Co0000O?ooool008Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`13ooooo`?o0000P?ooool008Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0oooooo`Co0000Poooool008Wooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo
1?l00027ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Oooooo1?l0
002;ooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03?ooooo1?l0002?
ooooo`00SOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002Coooo
o`00S_ooool2o`0000oooooo00?o0000ooooooooool0;?ooool4o`0009Kooooo002@ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool4o`0009[ooooo002Aooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0009kooooo002Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08Oooool4o`000:;ooooo002Cooooo`;o00002Oooool00ol0
003oooooooooo`0Mooooo`Co0000Y_ooool009Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Jooooo`?o0000Z_ooool009Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Fooooo`Co0000[Oooool009Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Booooo`Co0000/Oooool009Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`Co0000]Oooool009Wooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002ioooo
o`00Voooool01?l0003oooooooooool00009ooooo`?o0000_Oooool009cooooo00?o0000ooooool0
00001Oooool4o`000<3ooooo002Mooooo`;o000000?oooooo`000?l000000_l00034ooooo`00W_oo
ool2o`000<Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002booooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo0_lQ8B6Looooo`00/_ooool01_l@
413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo
0_lQ8B6Looooo`00/_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
Xoooool00;;ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P2Sooooo`00/_ooool00ol0003oooooooooo`0;ooooo`05olc<c?l0003o0000o`000?o<c<`0
Xoooool00;3ooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
Xoooool00;;ooooo00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj^[[o00000:?ooooo
002booooo`03o`000?oooooooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Sooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69469 Mtetra
.655 .752 .921 r
.4053 .69469 .41061 .69934 .41957 .69681 .41427 .69217 Mtetra
.655 .753 .922 r
.41427 .69217 .41957 .69681 .42855 .69428 .42327 .68964 Mtetra
.42327 .68964 .42855 .69428 .43756 .69174 .4323 .6871 Mtetra
.655 .754 .923 r
.4323 .6871 .43756 .69174 .4466 .68919 .44136 .68456 Mtetra
.655 .755 .924 r
.44136 .68456 .4466 .68919 .45567 .68663 .45046 .682 Mtetra
.654 .756 .924 r
.45046 .682 .45567 .68663 .46478 .68407 .45958 .67944 Mtetra
.654 .757 .925 r
.45958 .67944 .46478 .68407 .47391 .68149 .46873 .67686 Mtetra
.46873 .67686 .47391 .68149 .48307 .67891 .47791 .67428 Mtetra
.655 .758 .926 r
.47791 .67428 .48307 .67891 .49227 .67632 .48713 .67168 Mtetra
.48713 .67168 .49227 .67632 .50149 .67371 .49637 .66907 Mtetra
.655 .759 .926 r
.49637 .66907 .50149 .67371 .51075 .6711 .50565 .66645 Mtetra
.50565 .66645 .51075 .6711 .52004 .66849 .51496 .66381 Mtetra
.51496 .66381 .52004 .66849 .52936 .66586 .5243 .66116 Mtetra
.656 .759 .926 r
.5243 .66116 .52936 .66586 .53871 .66322 .53367 .6585 Mtetra
.656 .758 .925 r
.53367 .6585 .53871 .66322 .54809 .66058 .54308 .65582 Mtetra
.54308 .65582 .54809 .66058 .55751 .65792 .55252 .65313 Mtetra
.656 .757 .924 r
.55252 .65313 .55751 .65792 .56695 .65526 .56198 .65043 Mtetra
.656 .756 .923 r
.56198 .65043 .56695 .65526 .57643 .65259 .57149 .64772 Mtetra
.656 .755 .923 r
.57149 .64772 .57643 .65259 .58595 .6499 .58102 .645 Mtetra
.656 .754 .922 r
.58102 .645 .58595 .6499 .59549 .64721 .59059 .64228 Mtetra
.59059 .64228 .59549 .64721 .60507 .64451 .60019 .63954 Mtetra
.656 .753 .921 r
.60019 .63954 .60507 .64451 .61468 .6418 .60982 .63681 Mtetra
.60982 .63681 .61468 .6418 .62432 .63908 .61948 .63406 Mtetra
.656 .752 .921 r
.61948 .63406 .62432 .63908 .634 .63636 .62918 .63131 Mtetra
.62918 .63131 .634 .63636 .64371 .63362 .63892 .62855 Mtetra
.63892 .62855 .64371 .63362 .65345 .63087 .64868 .62578 Mtetra
.656 .752 .92 r
.64868 .62578 .65345 .63087 .66323 .62811 .65848 .623 Mtetra
.65848 .623 .66323 .62811 .67304 .62535 .66832 .62022 Mtetra
.66832 .62022 .67304 .62535 .68289 .62257 .67819 .61743 Mtetra
.67819 .61743 .68289 .62257 .69277 .61979 .68809 .61462 Mtetra
.68809 .61462 .69277 .61979 .70269 .61699 .69803 .61181 Mtetra
.656 .752 .921 r
.69803 .61181 .70269 .61699 .71264 .61418 .70801 .60899 Mtetra
.70801 .60899 .71264 .61418 .72262 .61137 .71802 .60616 Mtetra
.655 .752 .921 r
.71802 .60616 .72262 .61137 .73264 .60854 .72806 .60332 Mtetra
.72806 .60332 .73264 .60854 .7427 .60571 .73814 .60048 Mtetra
.73814 .60048 .7427 .60571 .75279 .60286 .74826 .59763 Mtetra
.655 .753 .922 r
.74826 .59763 .75279 .60286 .76291 .60001 .75841 .59477 Mtetra
.75841 .59477 .76291 .60001 .77308 .59714 .7686 .5919 Mtetra
.655 .754 .923 r
.7686 .5919 .77308 .59714 .78328 .59427 .77883 .58903 Mtetra
.655 .755 .923 r
.77883 .58903 .78328 .59427 .79351 .59138 .78909 .58614 Mtetra
.654 .755 .924 r
.78909 .58614 .79351 .59138 .80378 .58849 .79939 .58325 Mtetra
.654 .756 .925 r
.79939 .58325 .80378 .58849 .81409 .58558 .80973 .58034 Mtetra
.654 .757 .925 r
.80973 .58034 .81409 .58558 .82443 .58267 .8201 .57742 Mtetra
.655 .758 .926 r
.8201 .57742 .82443 .58267 .83482 .57974 .83051 .57449 Mtetra
.83051 .57449 .83482 .57974 .84523 .5768 .84096 .57154 Mtetra
.655 .759 .926 r
.84096 .57154 .84523 .5768 .85569 .57385 .85144 .56858 Mtetra
.85144 .56858 .85569 .57385 .86618 .57089 .86196 .56559 Mtetra
.86196 .56559 .86618 .57089 .87672 .56792 .87252 .5626 Mtetra
.87252 .5626 .87672 .56792 .88729 .56494 .88312 .55959 Mtetra
.656 .758 .925 r
.88312 .55959 .88729 .56494 .89789 .56195 .89375 .55656 Mtetra
.89375 .55656 .89789 .56195 .90854 .55895 .90443 .55352 Mtetra
.656 .757 .924 r
.90443 .55352 .90854 .55895 .91923 .55594 .91514 .55047 Mtetra
.656 .756 .924 r
.91514 .55047 .91923 .55594 .92995 .55292 .92589 .5474 Mtetra
.656 .756 .923 r
.92589 .5474 .92995 .55292 .94071 .54988 .93668 .54433 Mtetra
.656 .755 .922 r
.93668 .54433 .94071 .54988 .95152 .54684 .94751 .54124 Mtetra
.656 .754 .922 r
.94751 .54124 .95152 .54684 .96236 .54378 .95838 .53814 Mtetra
.656 .753 .921 r
.95838 .53814 .96236 .54378 .97324 .54071 .96929 .53504 Mtetra
.656 .752 .921 r
.96929 .53504 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.654 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69469 .39996 .69001 Mtetra
.654 .752 .921 r
.39996 .69001 .4053 .69469 .41427 .69217 .40895 .68749 Mtetra
.654 .752 .922 r
.40895 .68749 .41427 .69217 .42327 .68964 .41797 .68497 Mtetra
.654 .753 .923 r
.41797 .68497 .42327 .68964 .4323 .6871 .42702 .68243 Mtetra
.654 .754 .923 r
.42702 .68243 .4323 .6871 .44136 .68456 .4361 .67989 Mtetra
.654 .755 .924 r
.4361 .67989 .44136 .68456 .45046 .682 .44521 .67734 Mtetra
.44521 .67734 .45046 .682 .45958 .67944 .45435 .67478 Mtetra
.654 .756 .925 r
.45435 .67478 .45958 .67944 .46873 .67686 .46352 .67221 Mtetra
.654 .757 .925 r
.46352 .67221 .46873 .67686 .47791 .67428 .47272 .66962 Mtetra
.654 .758 .926 r
.47272 .66962 .47791 .67428 .48713 .67168 .48196 .66702 Mtetra
.48196 .66702 .48713 .67168 .49637 .66907 .49122 .66441 Mtetra
.655 .759 .926 r
.49122 .66441 .49637 .66907 .50565 .66645 .50052 .66177 Mtetra
.50052 .66177 .50565 .66645 .51496 .66381 .50985 .65912 Mtetra
.656 .759 .926 r
.50985 .65912 .51496 .66381 .5243 .66116 .51922 .65644 Mtetra
.51922 .65644 .5243 .66116 .53367 .6585 .52861 .65375 Mtetra
.656 .759 .925 r
.52861 .65375 .53367 .6585 .54308 .65582 .53804 .65104 Mtetra
.657 .758 .925 r
.53804 .65104 .54308 .65582 .55252 .65313 .54749 .64831 Mtetra
.657 .757 .924 r
.54749 .64831 .55252 .65313 .56198 .65043 .55698 .64557 Mtetra
.657 .757 .923 r
.55698 .64557 .56198 .65043 .57149 .64772 .56651 .64283 Mtetra
.657 .756 .923 r
.56651 .64283 .57149 .64772 .58102 .645 .57606 .64007 Mtetra
.657 .755 .922 r
.57606 .64007 .58102 .645 .59059 .64228 .58565 .63731 Mtetra
.657 .754 .922 r
.58565 .63731 .59059 .64228 .60019 .63954 .59527 .63455 Mtetra
.657 .753 .921 r
.59527 .63455 .60019 .63954 .60982 .63681 .60493 .63178 Mtetra
.656 .753 .921 r
.60493 .63178 .60982 .63681 .61948 .63406 .61461 .62901 Mtetra
.656 .752 .921 r
.61461 .62901 .61948 .63406 .62918 .63131 .62434 .62623 Mtetra
.62434 .62623 .62918 .63131 .63892 .62855 .63409 .62345 Mtetra
.63409 .62345 .63892 .62855 .64868 .62578 .64388 .62066 Mtetra
.656 .752 .92 r
.64388 .62066 .64868 .62578 .65848 .623 .65371 .61786 Mtetra
.65371 .61786 .65848 .623 .66832 .62022 .66357 .61506 Mtetra
.66357 .61506 .66832 .62022 .67819 .61743 .67346 .61225 Mtetra
.67346 .61225 .67819 .61743 .68809 .61462 .68339 .60943 Mtetra
.68339 .60943 .68809 .61462 .69803 .61181 .69335 .6066 Mtetra
.655 .752 .921 r
.69335 .6066 .69803 .61181 .70801 .60899 .70335 .60376 Mtetra
.70335 .60376 .70801 .60899 .71802 .60616 .71338 .60092 Mtetra
.71338 .60092 .71802 .60616 .72806 .60332 .72345 .59807 Mtetra
.72345 .59807 .72806 .60332 .73814 .60048 .73356 .59522 Mtetra
.655 .752 .922 r
.73356 .59522 .73814 .60048 .74826 .59763 .7437 .59236 Mtetra
.654 .753 .922 r
.7437 .59236 .74826 .59763 .75841 .59477 .75388 .5895 Mtetra
.654 .753 .923 r
.75388 .5895 .75841 .59477 .7686 .5919 .7641 .58663 Mtetra
.654 .754 .923 r
.7641 .58663 .7686 .5919 .77883 .58903 .77435 .58376 Mtetra
.654 .755 .924 r
.77435 .58376 .77883 .58903 .78909 .58614 .78464 .58087 Mtetra
.78464 .58087 .78909 .58614 .79939 .58325 .79497 .57798 Mtetra
.654 .756 .925 r
.79497 .57798 .79939 .58325 .80973 .58034 .80533 .57508 Mtetra
.654 .757 .926 r
.80533 .57508 .80973 .58034 .8201 .57742 .81574 .57215 Mtetra
.654 .758 .926 r
.81574 .57215 .8201 .57742 .83051 .57449 .82617 .56921 Mtetra
.654 .759 .926 r
.82617 .56921 .83051 .57449 .84096 .57154 .83665 .56625 Mtetra
.655 .759 .926 r
.83665 .56625 .84096 .57154 .85144 .56858 .84716 .56327 Mtetra
.84716 .56327 .85144 .56858 .86196 .56559 .85771 .56026 Mtetra
.656 .759 .926 r
.85771 .56026 .86196 .56559 .87252 .5626 .8683 .55724 Mtetra
.8683 .55724 .87252 .5626 .88312 .55959 .87892 .55419 Mtetra
.656 .758 .925 r
.87892 .55419 .88312 .55959 .89375 .55656 .88958 .55113 Mtetra
.657 .758 .924 r
.88958 .55113 .89375 .55656 .90443 .55352 .90028 .54805 Mtetra
.657 .757 .924 r
.90028 .54805 .90443 .55352 .91514 .55047 .91102 .54496 Mtetra
.657 .756 .923 r
.91102 .54496 .91514 .55047 .92589 .5474 .9218 .54185 Mtetra
.9218 .54185 .92589 .5474 .93668 .54433 .93262 .53873 Mtetra
.657 .755 .922 r
.93262 .53873 .93668 .54433 .94751 .54124 .94347 .53561 Mtetra
.657 .754 .921 r
.94347 .53561 .94751 .54124 .95838 .53814 .95437 .53247 Mtetra
.657 .753 .921 r
.95437 .53247 .95838 .53814 .96929 .53504 .96531 .52932 Mtetra
.657 .753 .92 r
.96531 .52932 .96929 .53504 .98024 .53192 .97628 .52616 Mtetra
.654 .751 .921 r
.38561 .68781 .391 .69252 .39996 .69001 .39458 .6853 Mtetra
.653 .751 .922 r
.39458 .6853 .39996 .69001 .40895 .68749 .40359 .68278 Mtetra
.653 .752 .922 r
.40359 .68278 .40895 .68749 .41797 .68497 .41263 .68026 Mtetra
.653 .753 .923 r
.41263 .68026 .41797 .68497 .42702 .68243 .42169 .67772 Mtetra
.42169 .67772 .42702 .68243 .4361 .67989 .43079 .67518 Mtetra
.653 .754 .924 r
.43079 .67518 .4361 .67989 .44521 .67734 .43992 .67263 Mtetra
.653 .755 .924 r
.43992 .67263 .44521 .67734 .45435 .67478 .44908 .67008 Mtetra
.653 .756 .925 r
.44908 .67008 .45435 .67478 .46352 .67221 .45828 .66751 Mtetra
.653 .756 .926 r
.45828 .66751 .46352 .67221 .47272 .66962 .4675 .66493 Mtetra
.653 .757 .926 r
.4675 .66493 .47272 .66962 .48196 .66702 .47675 .66233 Mtetra
.654 .758 .926 r
.47675 .66233 .48196 .66702 .49122 .66441 .48604 .65971 Mtetra
.654 .759 .926 r
.48604 .65971 .49122 .66441 .50052 .66177 .49536 .65707 Mtetra
.655 .759 .926 r
.49536 .65707 .50052 .66177 .50985 .65912 .50471 .6544 Mtetra
.656 .76 .926 r
.50471 .6544 .50985 .65912 .51922 .65644 .5141 .6517 Mtetra
.5141 .6517 .51922 .65644 .52861 .65375 .52351 .64898 Mtetra
.657 .759 .925 r
.52351 .64898 .52861 .65375 .53804 .65104 .53296 .64624 Mtetra
.658 .759 .925 r
.53296 .64624 .53804 .65104 .54749 .64831 .54244 .64348 Mtetra
.658 .758 .924 r
.54244 .64348 .54749 .64831 .55698 .64557 .55195 .6407 Mtetra
.658 .757 .923 r
.55195 .6407 .55698 .64557 .56651 .64283 .5615 .63791 Mtetra
.658 .756 .923 r
.5615 .63791 .56651 .64283 .57606 .64007 .57107 .63512 Mtetra
.658 .756 .922 r
.57107 .63512 .57606 .64007 .58565 .63731 .58068 .63232 Mtetra
.657 .755 .922 r
.58068 .63232 .58565 .63731 .59527 .63455 .59033 .62953 Mtetra
.657 .754 .921 r
.59033 .62953 .59527 .63455 .60493 .63178 .6 .62673 Mtetra
.657 .753 .921 r
.6 .62673 .60493 .63178 .61461 .62901 .60971 .62392 Mtetra
.60971 .62392 .61461 .62901 .62434 .62623 .61946 .62112 Mtetra
.656 .752 .921 r
.61946 .62112 .62434 .62623 .63409 .62345 .62924 .61832 Mtetra
.62924 .61832 .63409 .62345 .64388 .62066 .63905 .6155 Mtetra
.656 .752 .92 r
.63905 .6155 .64388 .62066 .65371 .61786 .6489 .61269 Mtetra
.6489 .61269 .65371 .61786 .66357 .61506 .65878 .60986 Mtetra
.65878 .60986 .66357 .61506 .67346 .61225 .6687 .60703 Mtetra
.6687 .60703 .67346 .61225 .68339 .60943 .67865 .6042 Mtetra
.656 .752 .921 r
.67865 .6042 .68339 .60943 .69335 .6066 .68864 .60135 Mtetra
.655 .752 .921 r
.68864 .60135 .69335 .6066 .70335 .60376 .69866 .5985 Mtetra
.69866 .5985 .70335 .60376 .71338 .60092 .70872 .59565 Mtetra
.70872 .59565 .71338 .60092 .72345 .59807 .71882 .59279 Mtetra
.654 .752 .921 r
.71882 .59279 .72345 .59807 .73356 .59522 .72895 .58993 Mtetra
.654 .752 .922 r
.72895 .58993 .73356 .59522 .7437 .59236 .73912 .58706 Mtetra
.654 .753 .922 r
.73912 .58706 .7437 .59236 .75388 .5895 .74932 .5842 Mtetra
.653 .753 .923 r
.74932 .5842 .75388 .5895 .7641 .58663 .75957 .58133 Mtetra
.653 .754 .924 r
.75957 .58133 .7641 .58663 .77435 .58376 .76985 .57846 Mtetra
.653 .755 .925 r
.76985 .57846 .77435 .58376 .78464 .58087 .78017 .57558 Mtetra
.653 .756 .925 r
.78017 .57558 .78464 .58087 .79497 .57798 .79052 .5727 Mtetra
.653 .757 .926 r
.79052 .5727 .79497 .57798 .80533 .57508 .80091 .56979 Mtetra
.653 .758 .926 r
.80091 .56979 .80533 .57508 .81574 .57215 .81134 .56686 Mtetra
.654 .758 .927 r
.81134 .56686 .81574 .57215 .82617 .56921 .82181 .56391 Mtetra
.654 .759 .927 r
.82181 .56391 .82617 .56921 .83665 .56625 .83231 .56093 Mtetra
.655 .759 .926 r
.83231 .56093 .83665 .56625 .84716 .56327 .84285 .55793 Mtetra
.656 .759 .926 r
.84285 .55793 .84716 .56327 .85771 .56026 .85343 .55489 Mtetra
.85343 .55489 .85771 .56026 .8683 .55724 .86404 .55183 Mtetra
.657 .759 .925 r
.86404 .55183 .8683 .55724 .87892 .55419 .87469 .54875 Mtetra
.657 .758 .925 r
.87469 .54875 .87892 .55419 .88958 .55113 .88538 .54565 Mtetra
.657 .758 .924 r
.88538 .54565 .88958 .55113 .90028 .54805 .89611 .54253 Mtetra
.658 .757 .923 r
.89611 .54253 .90028 .54805 .91102 .54496 .90688 .53939 Mtetra
.658 .756 .923 r
.90688 .53939 .91102 .54496 .9218 .54185 .91768 .53625 Mtetra
.658 .756 .922 r
.91768 .53625 .9218 .54185 .93262 .53873 .92852 .53309 Mtetra
.658 .755 .922 r
.92852 .53309 .93262 .53873 .94347 .53561 .93941 .52993 Mtetra
.658 .754 .921 r
.93941 .52993 .94347 .53561 .95437 .53247 .95033 .52675 Mtetra
.658 .753 .921 r
.95033 .52675 .95437 .53247 .96531 .52932 .9613 .52357 Mtetra
.658 .753 .92 r
.9613 .52357 .96531 .52932 .97628 .52616 .9723 .52037 Mtetra
.653 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .6853 .38917 .68056 Mtetra
.653 .751 .922 r
.38917 .68056 .39458 .6853 .40359 .68278 .3982 .67804 Mtetra
.653 .752 .922 r
.3982 .67804 .40359 .68278 .41263 .68026 .40725 .67551 Mtetra
.653 .752 .923 r
.40725 .67551 .41263 .68026 .42169 .67772 .41634 .67297 Mtetra
.652 .753 .923 r
.41634 .67297 .42169 .67772 .43079 .67518 .42546 .67043 Mtetra
.652 .753 .924 r
.42546 .67043 .43079 .67518 .43992 .67263 .43461 .66788 Mtetra
.652 .754 .924 r
.43461 .66788 .43992 .67263 .44908 .67008 .44379 .66533 Mtetra
.652 .755 .925 r
.44379 .66533 .44908 .67008 .45828 .66751 .453 .66277 Mtetra
.453 .66277 .45828 .66751 .4675 .66493 .46224 .66019 Mtetra
.652 .756 .926 r
.46224 .66019 .4675 .66493 .47675 .66233 .47152 .65759 Mtetra
.653 .757 .926 r
.47152 .65759 .47675 .66233 .48604 .65971 .48083 .65498 Mtetra
.654 .758 .927 r
.48083 .65498 .48604 .65971 .49536 .65707 .49017 .65233 Mtetra
.655 .759 .927 r
.49017 .65233 .49536 .65707 .50471 .6544 .49954 .64966 Mtetra
.655 .76 .926 r
.49954 .64966 .50471 .6544 .5141 .6517 .50894 .64695 Mtetra
.657 .76 .926 r
.50894 .64695 .5141 .6517 .52351 .64898 .51838 .64421 Mtetra
.51838 .64421 .52351 .64898 .53296 .64624 .52785 .64144 Mtetra
.658 .76 .925 r
.52785 .64144 .53296 .64624 .54244 .64348 .53735 .63864 Mtetra
.659 .759 .924 r
.53735 .63864 .54244 .64348 .55195 .6407 .54689 .63582 Mtetra
.54689 .63582 .55195 .6407 .5615 .63791 .55645 .63299 Mtetra
.659 .758 .923 r
.55645 .63299 .5615 .63791 .57107 .63512 .56605 .63016 Mtetra
.659 .757 .922 r
.56605 .63016 .57107 .63512 .58068 .63232 .57568 .62732 Mtetra
.658 .756 .922 r
.57568 .62732 .58068 .63232 .59033 .62953 .58535 .62448 Mtetra
.658 .755 .921 r
.58535 .62448 .59033 .62953 .6 .62673 .59505 .62165 Mtetra
.657 .754 .921 r
.59505 .62165 .6 .62673 .60971 .62392 .60478 .61882 Mtetra
.657 .753 .921 r
.60478 .61882 .60971 .62392 .61946 .62112 .61455 .61599 Mtetra
.61455 .61599 .61946 .62112 .62924 .61832 .62435 .61315 Mtetra
.656 .752 .921 r
.62435 .61315 .62924 .61832 .63905 .6155 .63419 .61032 Mtetra
.656 .752 .92 r
.63419 .61032 .63905 .6155 .6489 .61269 .64406 .60748 Mtetra
.64406 .60748 .6489 .61269 .65878 .60986 .65397 .60464 Mtetra
.656 .752 .921 r
.65397 .60464 .65878 .60986 .6687 .60703 .66391 .60179 Mtetra
.66391 .60179 .6687 .60703 .67865 .6042 .67388 .59894 Mtetra
.655 .752 .921 r
.67388 .59894 .67865 .6042 .68864 .60135 .6839 .59608 Mtetra
.6839 .59608 .68864 .60135 .69866 .5985 .69394 .59321 Mtetra
.69394 .59321 .69866 .5985 .70872 .59565 .70403 .59035 Mtetra
.654 .752 .921 r
.70403 .59035 .70872 .59565 .71882 .59279 .71415 .58748 Mtetra
.654 .752 .922 r
.71415 .58748 .71882 .59279 .72895 .58993 .72431 .58461 Mtetra
.653 .752 .922 r
.72431 .58461 .72895 .58993 .73912 .58706 .7345 .58175 Mtetra
.653 .753 .923 r
.7345 .58175 .73912 .58706 .74932 .5842 .74473 .57888 Mtetra
.652 .754 .924 r
.74473 .57888 .74932 .5842 .75957 .58133 .755 .57602 Mtetra
.652 .754 .925 r
.755 .57602 .75957 .58133 .76985 .57846 .76531 .57316 Mtetra
.652 .755 .926 r
.76531 .57316 .76985 .57846 .78017 .57558 .77566 .57028 Mtetra
.652 .756 .926 r
.77566 .57028 .78017 .57558 .79052 .5727 .78604 .5674 Mtetra
.652 .757 .927 r
.78604 .5674 .79052 .5727 .80091 .56979 .79647 .56449 Mtetra
.652 .758 .927 r
.79647 .56449 .80091 .56979 .81134 .56686 .80692 .56156 Mtetra
.653 .759 .927 r
.80692 .56156 .81134 .56686 .82181 .56391 .81742 .55859 Mtetra
.654 .76 .927 r
.81742 .55859 .82181 .56391 .83231 .56093 .82795 .55559 Mtetra
.655 .76 .927 r
.82795 .55559 .83231 .56093 .84285 .55793 .83852 .55255 Mtetra
.656 .76 .926 r
.83852 .55255 .84285 .55793 .85343 .55489 .84912 .54948 Mtetra
.657 .759 .925 r
.84912 .54948 .85343 .55489 .86404 .55183 .85976 .54638 Mtetra
.658 .759 .925 r
.85976 .54638 .86404 .55183 .87469 .54875 .87044 .54326 Mtetra
.658 .758 .924 r
.87044 .54326 .87469 .54875 .88538 .54565 .88115 .54011 Mtetra
.658 .757 .923 r
.88115 .54011 .88538 .54565 .89611 .54253 .89191 .53695 Mtetra
.89191 .53695 .89611 .54253 .90688 .53939 .9027 .53377 Mtetra
.658 .756 .922 r
.9027 .53377 .90688 .53939 .91768 .53625 .91353 .53059 Mtetra
.658 .755 .921 r
.91353 .53059 .91768 .53625 .92852 .53309 .9244 .5274 Mtetra
.658 .754 .921 r
.9244 .5274 .92852 .53309 .93941 .52993 .93532 .52419 Mtetra
.93532 .52419 .93941 .52993 .95033 .52675 .94627 .52099 Mtetra
.658 .753 .92 r
.94627 .52099 .95033 .52675 .9613 .52357 .95726 .51777 Mtetra
.95726 .51777 .9613 .52357 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .922 r
.37472 .67831 .38018 .68308 .38917 .68056 .38373 .67578 Mtetra
.38373 .67578 .38917 .68056 .3982 .67804 .39277 .67325 Mtetra
.652 .751 .922 r
.39277 .67325 .3982 .67804 .40725 .67551 .40185 .67071 Mtetra
.40185 .67071 .40725 .67551 .41634 .67297 .41095 .66817 Mtetra
.652 .752 .923 r
.41095 .66817 .41634 .67297 .42546 .67043 .42009 .66562 Mtetra
.42009 .66562 .42546 .67043 .43461 .66788 .42926 .66308 Mtetra
.651 .753 .924 r
.42926 .66308 .43461 .66788 .44379 .66533 .43846 .66053 Mtetra
.43846 .66053 .44379 .66533 .453 .66277 .44769 .65797 Mtetra
.651 .754 .925 r
.44769 .65797 .453 .66277 .46224 .66019 .45695 .6554 Mtetra
.651 .755 .926 r
.45695 .6554 .46224 .66019 .47152 .65759 .46625 .65281 Mtetra
.652 .756 .926 r
.46625 .65281 .47152 .65759 .48083 .65498 .47558 .65021 Mtetra
.653 .758 .927 r
.47558 .65021 .48083 .65498 .49017 .65233 .48494 .64757 Mtetra
.654 .759 .927 r
.48494 .64757 .49017 .65233 .49954 .64966 .49433 .64489 Mtetra
.655 .76 .927 r
.49433 .64489 .49954 .64966 .50894 .64695 .50376 .64218 Mtetra
.656 .761 .927 r
.50376 .64218 .50894 .64695 .51838 .64421 .51322 .63942 Mtetra
.658 .761 .926 r
.51322 .63942 .51838 .64421 .52785 .64144 .52271 .63663 Mtetra
.659 .761 .926 r
.52271 .63663 .52785 .64144 .53735 .63864 .53223 .6338 Mtetra
.659 .761 .925 r
.53223 .6338 .53735 .63864 .54689 .63582 .54179 .63094 Mtetra
.66 .76 .924 r
.54179 .63094 .54689 .63582 .55645 .63299 .55138 .62807 Mtetra
.66 .759 .923 r
.55138 .62807 .55645 .63299 .56605 .63016 .561 .62519 Mtetra
.66 .758 .923 r
.561 .62519 .56605 .63016 .57568 .62732 .57065 .6223 Mtetra
.659 .757 .922 r
.57065 .6223 .57568 .62732 .58535 .62448 .58034 .61942 Mtetra
.659 .755 .922 r
.58034 .61942 .58535 .62448 .59505 .62165 .59006 .61655 Mtetra
.658 .754 .921 r
.59006 .61655 .59505 .62165 .60478 .61882 .59982 .61369 Mtetra
.657 .754 .921 r
.59982 .61369 .60478 .61882 .61455 .61599 .60961 .61082 Mtetra
.657 .753 .921 r
.60961 .61082 .61455 .61599 .62435 .61315 .61943 .60796 Mtetra
.61943 .60796 .62435 .61315 .63419 .61032 .62929 .60511 Mtetra
.656 .752 .921 r
.62929 .60511 .63419 .61032 .64406 .60748 .63919 .60225 Mtetra
.63919 .60225 .64406 .60748 .65397 .60464 .64912 .59938 Mtetra
.64912 .59938 .65397 .60464 .66391 .60179 .65908 .59652 Mtetra
.655 .752 .921 r
.65908 .59652 .66391 .60179 .67388 .59894 .66908 .59364 Mtetra
.66908 .59364 .67388 .59894 .6839 .59608 .67912 .59077 Mtetra
.67912 .59077 .6839 .59608 .69394 .59321 .68919 .58789 Mtetra
.654 .752 .921 r
.68919 .58789 .69394 .59321 .70403 .59035 .6993 .58502 Mtetra
.654 .752 .922 r
.6993 .58502 .70403 .59035 .71415 .58748 .70945 .58214 Mtetra
.653 .752 .922 r
.70945 .58214 .71415 .58748 .72431 .58461 .71963 .57927 Mtetra
.652 .753 .923 r
.71963 .57927 .72431 .58461 .7345 .58175 .72986 .57641 Mtetra
.652 .753 .924 r
.72986 .57641 .7345 .58175 .74473 .57888 .74012 .57355 Mtetra
.651 .754 .925 r
.74012 .57355 .74473 .57888 .755 .57602 .75041 .5707 Mtetra
.651 .755 .926 r
.75041 .5707 .755 .57602 .76531 .57316 .76075 .56784 Mtetra
.65 .756 .927 r
.76075 .56784 .76531 .57316 .77566 .57028 .77113 .56498 Mtetra
.651 .757 .927 r
.77113 .56498 .77566 .57028 .78604 .5674 .78154 .56209 Mtetra
.651 .758 .928 r
.78154 .56209 .78604 .5674 .79647 .56449 .79199 .55918 Mtetra
.652 .759 .928 r
.79199 .55918 .79647 .56449 .80692 .56156 .80248 .55624 Mtetra
.653 .76 .928 r
.80248 .55624 .80692 .56156 .81742 .55859 .813 .55325 Mtetra
.655 .76 .927 r
.813 .55325 .81742 .55859 .82795 .55559 .82356 .55022 Mtetra
.656 .76 .927 r
.82356 .55022 .82795 .55559 .83852 .55255 .83415 .54714 Mtetra
.657 .76 .926 r
.83415 .54714 .83852 .55255 .84912 .54948 .84478 .54403 Mtetra
.658 .76 .925 r
.84478 .54403 .84912 .54948 .85976 .54638 .85545 .54088 Mtetra
.659 .759 .924 r
.85545 .54088 .85976 .54638 .87044 .54326 .86615 .53771 Mtetra
.659 .758 .923 r
.86615 .53771 .87044 .54326 .88115 .54011 .87689 .53451 Mtetra
.659 .757 .922 r
.87689 .53451 .88115 .54011 .89191 .53695 .88767 .53131 Mtetra
.659 .756 .921 r
.88767 .53131 .89191 .53695 .9027 .53377 .89849 .52809 Mtetra
.659 .755 .921 r
.89849 .52809 .9027 .53377 .91353 .53059 .90935 .52487 Mtetra
.659 .754 .921 r
.90935 .52487 .91353 .53059 .9244 .5274 .92025 .52164 Mtetra
.659 .754 .92 r
.92025 .52164 .9244 .5274 .93532 .52419 .93119 .51841 Mtetra
.659 .753 .92 r
.93119 .51841 .93532 .52419 .94627 .52099 .94217 .51517 Mtetra
.658 .753 .92 r
.94217 .51517 .94627 .52099 .95726 .51777 .9532 .51192 Mtetra
.9532 .51192 .95726 .51777 .96829 .51454 .96426 .50866 Mtetra
.653 .751 .921 r
.36922 .67351 .37472 .67831 .38373 .67578 .37825 .67097 Mtetra
.653 .751 .922 r
.37825 .67097 .38373 .67578 .39277 .67325 .38732 .66842 Mtetra
.652 .751 .922 r
.38732 .66842 .39277 .67325 .40185 .67071 .39641 .66587 Mtetra
.39641 .66587 .40185 .67071 .41095 .66817 .40553 .66331 Mtetra
.40553 .66331 .41095 .66817 .42009 .66562 .41469 .66076 Mtetra
.651 .751 .923 r
.41469 .66076 .42009 .66562 .42926 .66308 .42388 .65821 Mtetra
.42388 .65821 .42926 .66308 .43846 .66053 .4331 .65566 Mtetra
.65 .752 .924 r
.4331 .65566 .43846 .66053 .44769 .65797 .44235 .6531 Mtetra
.44235 .6531 .44769 .65797 .45695 .6554 .45163 .65054 Mtetra
.65 .753 .925 r
.45163 .65054 .45695 .6554 .46625 .65281 .46094 .64797 Mtetra
.65 .755 .926 r
.46094 .64797 .46625 .65281 .47558 .65021 .47029 .64538 Mtetra
.651 .756 .927 r
.47029 .64538 .47558 .65021 .48494 .64757 .47967 .64276 Mtetra
.652 .758 .927 r
.47967 .64276 .48494 .64757 .49433 .64489 .48909 .6401 Mtetra
.654 .76 .927 r
.48909 .6401 .49433 .64489 .50376 .64218 .49854 .63739 Mtetra
.656 .761 .927 r
.49854 .63739 .50376 .64218 .51322 .63942 .50802 .63463 Mtetra
.657 .762 .927 r
.50802 .63463 .51322 .63942 .52271 .63663 .51753 .63182 Mtetra
.659 .763 .926 r
.51753 .63182 .52271 .63663 .53223 .6338 .52708 .62896 Mtetra
.66 .763 .926 r
.52708 .62896 .53223 .6338 .54179 .63094 .53666 .62607 Mtetra
.661 .762 .925 r
.53666 .62607 .54179 .63094 .55138 .62807 .54627 .62315 Mtetra
.661 .761 .924 r
.54627 .62315 .55138 .62807 .561 .62519 .55591 .62022 Mtetra
.661 .76 .923 r
.55591 .62022 .561 .62519 .57065 .6223 .56559 .61729 Mtetra
.66 .758 .922 r
.56559 .61729 .57065 .6223 .58034 .61942 .5753 .61436 Mtetra
.66 .757 .922 r
.5753 .61436 .58034 .61942 .59006 .61655 .58505 .61144 Mtetra
.659 .756 .921 r
.58505 .61144 .59006 .61655 .59982 .61369 .59482 .60854 Mtetra
.658 .754 .921 r
.59482 .60854 .59982 .61369 .60961 .61082 .60464 .60564 Mtetra
.657 .754 .921 r
.60464 .60564 .60961 .61082 .61943 .60796 .61448 .60275 Mtetra
.657 .753 .921 r
.61448 .60275 .61943 .60796 .62929 .60511 .62437 .59987 Mtetra
.656 .753 .921 r
.62437 .59987 .62929 .60511 .63919 .60225 .63429 .59698 Mtetra
.656 .752 .921 r
.63429 .59698 .63919 .60225 .64912 .59938 .64424 .5941 Mtetra
.64424 .5941 .64912 .59938 .65908 .59652 .65423 .59121 Mtetra
.655 .752 .921 r
.65423 .59121 .65908 .59652 .66908 .59364 .66425 .58832 Mtetra
.66425 .58832 .66908 .59364 .67912 .59077 .67431 .58543 Mtetra
.654 .752 .921 r
.67431 .58543 .67912 .59077 .68919 .58789 .68441 .58255 Mtetra
.654 .752 .922 r
.68441 .58255 .68919 .58789 .6993 .58502 .69455 .57966 Mtetra
.653 .752 .922 r
.69455 .57966 .6993 .58502 .70945 .58214 .70472 .57679 Mtetra
.652 .753 .923 r
.70472 .57679 .70945 .58214 .71963 .57927 .71493 .57392 Mtetra
.651 .753 .924 r
.71493 .57392 .71963 .57927 .72986 .57641 .72518 .57106 Mtetra
.65 .754 .925 r
.72518 .57106 .72986 .57641 .74012 .57355 .73547 .56822 Mtetra
.649 .755 .926 r
.73547 .56822 .74012 .57355 .75041 .5707 .74579 .56538 Mtetra
.649 .756 .927 r
.74579 .56538 .75041 .5707 .76075 .56784 .75616 .56253 Mtetra
.649 .757 .928 r
.75616 .56253 .76075 .56784 .77113 .56498 .76656 .55968 Mtetra
.649 .758 .929 r
.76656 .55968 .77113 .56498 .78154 .56209 .77701 .55679 Mtetra
.65 .76 .929 r
.77701 .55679 .78154 .56209 .79199 .55918 .78748 .55387 Mtetra
.652 .761 .929 r
.78748 .55387 .79199 .55918 .80248 .55624 .798 .5509 Mtetra
.654 .761 .928 r
.798 .5509 .80248 .55624 .813 .55325 .80855 .54788 Mtetra
.656 .761 .927 r
.80855 .54788 .813 .55325 .82356 .55022 .81913 .5448 Mtetra
.657 .761 .926 r
.81913 .5448 .82356 .55022 .83415 .54714 .82975 .54168 Mtetra
.659 .76 .925 r
.82975 .54168 .83415 .54714 .84478 .54403 .84041 .53851 Mtetra
.659 .759 .924 r
.84041 .53851 .84478 .54403 .85545 .54088 .8511 .53531 Mtetra
.66 .758 .922 r
.8511 .53531 .85545 .54088 .86615 .53771 .86183 .53208 Mtetra
.66 .757 .922 r
.86183 .53208 .86615 .53771 .87689 .53451 .8726 .52884 Mtetra
.66 .756 .921 r
.8726 .52884 .87689 .53451 .88767 .53131 .8834 .52559 Mtetra
.66 .755 .92 r
.8834 .52559 .88767 .53131 .89849 .52809 .89425 .52233 Mtetra
.66 .754 .92 r
.89425 .52233 .89849 .52809 .90935 .52487 .90514 .51908 Mtetra
.659 .753 .92 r
.90514 .51908 .90935 .52487 .92025 .52164 .91607 .51582 Mtetra
.659 .753 .919 r
.91607 .51582 .92025 .52164 .93119 .51841 .92704 .51256 Mtetra
.92704 .51256 .93119 .51841 .94217 .51517 .93805 .5093 Mtetra
.658 .753 .919 r
.93805 .5093 .94217 .51517 .9532 .51192 .9491 .50603 Mtetra
.658 .752 .92 r
.9491 .50603 .9532 .51192 .96426 .50866 .9602 .50275 Mtetra
.653 .751 .921 r
.36369 .66869 .36922 .67351 .37825 .67097 .37274 .66612 Mtetra
.653 .75 .921 r
.37274 .66612 .37825 .67097 .38732 .66842 .38183 .66354 Mtetra
.38183 .66354 .38732 .66842 .39641 .66587 .39094 .66097 Mtetra
.652 .75 .921 r
.39094 .66097 .39641 .66587 .40553 .66331 .40008 .65839 Mtetra
.652 .749 .921 r
.40008 .65839 .40553 .66331 .41469 .66076 .40926 .65583 Mtetra
.651 .749 .921 r
.40926 .65583 .41469 .66076 .42388 .65821 .41846 .65326 Mtetra
.65 .749 .922 r
.41846 .65326 .42388 .65821 .4331 .65566 .4277 .65071 Mtetra
.65 .75 .923 r
.4277 .65071 .4331 .65566 .44235 .6531 .43697 .64816 Mtetra
.649 .75 .923 r
.43697 .64816 .44235 .6531 .45163 .65054 .44627 .64561 Mtetra
.649 .751 .924 r
.44627 .64561 .45163 .65054 .46094 .64797 .45561 .64306 Mtetra
.649 .753 .925 r
.45561 .64306 .46094 .64797 .47029 .64538 .46498 .64049 Mtetra
.649 .755 .926 r
.46498 .64049 .47029 .64538 .47967 .64276 .47438 .6379 Mtetra
.65 .757 .927 r
.47438 .6379 .47967 .64276 .48909 .6401 .48381 .63527 Mtetra
.652 .759 .928 r
.48381 .63527 .48909 .6401 .49854 .63739 .49328 .63258 Mtetra
.654 .761 .928 r
.49328 .63258 .49854 .63739 .50802 .63463 .50278 .62983 Mtetra
.657 .763 .928 r
.50278 .62983 .50802 .63463 .51753 .63182 .51232 .62702 Mtetra
.659 .764 .928 r
.51232 .62702 .51753 .63182 .52708 .62896 .52189 .62414 Mtetra
.661 .765 .927 r
.52189 .62414 .52708 .62896 .53666 .62607 .53149 .62122 Mtetra
.662 .764 .926 r
.53149 .62122 .53666 .62607 .54627 .62315 .54113 .61825 Mtetra
.662 .763 .925 r
.54113 .61825 .54627 .62315 .55591 .62022 .55079 .61527 Mtetra
.662 .762 .924 r
.55079 .61527 .55591 .62022 .56559 .61729 .56049 .61228 Mtetra
.662 .76 .923 r
.56049 .61228 .56559 .61729 .5753 .61436 .57023 .60929 Mtetra
.661 .759 .922 r
.57023 .60929 .5753 .61436 .58505 .61144 .57999 .60633 Mtetra
.66 .757 .922 r
.57999 .60633 .58505 .61144 .59482 .60854 .5898 .60337 Mtetra
.659 .756 .921 r
.5898 .60337 .59482 .60854 .60464 .60564 .59963 .60044 Mtetra
.658 .754 .921 r
.59963 .60044 .60464 .60564 .61448 .60275 .6095 .59751 Mtetra
.657 .754 .921 r
.6095 .59751 .61448 .60275 .62437 .59987 .61941 .5946 Mtetra
.657 .753 .921 r
.61941 .5946 .62437 .59987 .63429 .59698 .62935 .59169 Mtetra
.656 .753 .921 r
.62935 .59169 .63429 .59698 .64424 .5941 .63933 .58878 Mtetra
.656 .752 .921 r
.63933 .58878 .64424 .5941 .65423 .59121 .64934 .58588 Mtetra
.655 .752 .921 r
.64934 .58588 .65423 .59121 .66425 .58832 .65939 .58297 Mtetra
.65939 .58297 .66425 .58832 .67431 .58543 .66948 .58007 Mtetra
.654 .752 .922 r
.66948 .58007 .67431 .58543 .68441 .58255 .6796 .57718 Mtetra
.653 .752 .922 r
.6796 .57718 .68441 .58255 .69455 .57966 .68976 .57429 Mtetra
.652 .752 .923 r
.68976 .57429 .69455 .57966 .70472 .57679 .69996 .57141 Mtetra
.651 .753 .924 r
.69996 .57141 .70472 .57679 .71493 .57392 .7102 .56856 Mtetra
.65 .754 .925 r
.7102 .56856 .71493 .57392 .72518 .57106 .72047 .56571 Mtetra
.649 .754 .927 r
.72047 .56571 .72518 .57106 .73547 .56822 .73079 .56289 Mtetra
.648 .756 .928 r
.73079 .56289 .73547 .56822 .74579 .56538 .74115 .56007 Mtetra
.647 .757 .929 r
.74115 .56007 .74579 .56538 .75616 .56253 .75154 .55724 Mtetra
.647 .759 .93 r
.75154 .55724 .75616 .56253 .76656 .55968 .76198 .55439 Mtetra
.649 .76 .931 r
.76198 .55439 .76656 .55968 .77701 .55679 .77245 .55151 Mtetra
.65 .761 .931 r
.77245 .55151 .77701 .55679 .78748 .55387 .78295 .54857 Mtetra
.652 .762 .93 r
.78295 .54857 .78748 .55387 .798 .5509 .79349 .54556 Mtetra
.655 .763 .929 r
.79349 .54556 .798 .5509 .80855 .54788 .80407 .54249 Mtetra
.657 .762 .927 r
.80407 .54249 .80855 .54788 .81913 .5448 .81468 .53935 Mtetra
.659 .761 .925 r
.81468 .53935 .81913 .5448 .82975 .54168 .82532 .53616 Mtetra
.66 .76 .924 r
.82532 .53616 .82975 .54168 .84041 .53851 .836 .53292 Mtetra
.661 .758 .922 r
.836 .53292 .84041 .53851 .8511 .53531 .84672 .52965 Mtetra
.662 .757 .921 r
.84672 .52965 .8511 .53531 .86183 .53208 .85747 .52636 Mtetra
.662 .755 .92 r
.85747 .52636 .86183 .53208 .8726 .52884 .86827 .52307 Mtetra
.661 .754 .919 r
.86827 .52307 .8726 .52884 .8834 .52559 .8791 .51978 Mtetra
.661 .753 .919 r
.8791 .51978 .8834 .52559 .89425 .52233 .88997 .51649 Mtetra
.66 .752 .918 r
.88997 .51649 .89425 .52233 .90514 .51908 .90089 .51321 Mtetra
.659 .752 .918 r
.90089 .51321 .90514 .51908 .91607 .51582 .91185 .50993 Mtetra
.659 .752 .919 r
.91185 .50993 .91607 .51582 .92704 .51256 .92285 .50665 Mtetra
.92285 .50665 .92704 .51256 .93805 .5093 .93389 .50337 Mtetra
.658 .752 .919 r
.93389 .50337 .93805 .5093 .9491 .50603 .94498 .50009 Mtetra
.94498 .50009 .9491 .50603 .9602 .50275 .9561 .4968 Mtetra
.654 .751 .921 r
.35813 .66383 .36369 .66869 .37274 .66612 .3672 .66123 Mtetra
.654 .75 .921 r
.3672 .66123 .37274 .66612 .38183 .66354 .3763 .65863 Mtetra
.653 .75 .92 r
.3763 .65863 .38183 .66354 .39094 .66097 .38543 .65602 Mtetra
.653 .749 .92 r
.38543 .65602 .39094 .66097 .40008 .65839 .3946 .65342 Mtetra
.652 .748 .92 r
.3946 .65342 .40008 .65839 .40926 .65583 .40379 .65082 Mtetra
.651 .748 .92 r
.40379 .65082 .40926 .65583 .41846 .65326 .41302 .64824 Mtetra
.65 .747 .921 r
.41302 .64824 .41846 .65326 .4277 .65071 .42227 .64567 Mtetra
.649 .747 .921 r
.42227 .64567 .4277 .65071 .43697 .64816 .43156 .64312 Mtetra
.648 .747 .922 r
.43156 .64312 .43697 .64816 .44627 .64561 .44088 .64058 Mtetra
.647 .748 .923 r
.44088 .64058 .44627 .64561 .45561 .64306 .45024 .63804 Mtetra
.647 .749 .924 r
.45024 .63804 .45561 .64306 .46498 .64049 .45963 .63551 Mtetra
.647 .751 .925 r
.45963 .63551 .46498 .64049 .47438 .6379 .46905 .63296 Mtetra
.648 .754 .927 r
.46905 .63296 .47438 .6379 .48381 .63527 .4785 .63037 Mtetra
.65 .757 .928 r
.4785 .63037 .48381 .63527 .49328 .63258 .48799 .62773 Mtetra
.652 .76 .929 r
.48799 .62773 .49328 .63258 .50278 .62983 .49752 .62501 Mtetra
.655 .763 .929 r
.49752 .62501 .50278 .62983 .51232 .62702 .50708 .62222 Mtetra
.658 .765 .929 r
.50708 .62222 .51232 .62702 .52189 .62414 .51667 .61934 Mtetra
.661 .767 .928 r
.51667 .61934 .52189 .62414 .53149 .62122 .52629 .61639 Mtetra
.663 .767 .927 r
.52629 .61639 .53149 .62122 .54113 .61825 .53595 .61338 Mtetra
.664 .766 .926 r
.53595 .61338 .54113 .61825 .55079 .61527 .54564 .61034 Mtetra
.664 .765 .925 r
.54564 .61034 .55079 .61527 .56049 .61228 .55536 .60729 Mtetra
.664 .763 .924 r
.55536 .60729 .56049 .61228 .57023 .60929 .56512 .60424 Mtetra
.662 .761 .923 r
.56512 .60424 .57023 .60929 .57999 .60633 .57491 .60121 Mtetra
.661 .759 .922 r
.57491 .60121 .57999 .60633 .5898 .60337 .58474 .59821 Mtetra
.66 .757 .922 r
.58474 .59821 .5898 .60337 .59963 .60044 .59459 .59522 Mtetra
.659 .756 .922 r
.59459 .59522 .59963 .60044 .6095 .59751 .60449 .59226 Mtetra
.658 .754 .921 r
.60449 .59226 .6095 .59751 .61941 .5946 .61442 .58931 Mtetra
.657 .754 .921 r
.61442 .58931 .61941 .5946 .62935 .59169 .62438 .58638 Mtetra
.656 .753 .921 r
.62438 .58638 .62935 .59169 .63933 .58878 .63439 .58345 Mtetra
.63439 .58345 .63933 .58878 .64934 .58588 .64442 .58052 Mtetra
.655 .752 .922 r
.64442 .58052 .64934 .58588 .65939 .58297 .6545 .5776 Mtetra
.654 .752 .922 r
.6545 .5776 .65939 .58297 .66948 .58007 .66461 .57469 Mtetra
.653 .752 .922 r
.66461 .57469 .66948 .58007 .6796 .57718 .67476 .57179 Mtetra
.652 .753 .923 r
.67476 .57179 .6796 .57718 .68976 .57429 .68494 .5689 Mtetra
.651 .753 .924 r
.68494 .5689 .68976 .57429 .69996 .57141 .69517 .56604 Mtetra
.649 .754 .926 r
.69517 .56604 .69996 .57141 .7102 .56856 .70544 .5632 Mtetra
.648 .754 .927 r
.70544 .5632 .7102 .56856 .72047 .56571 .71574 .56038 Mtetra
.646 .756 .929 r
.71574 .56038 .72047 .56571 .73079 .56289 .72609 .55758 Mtetra
.645 .757 .93 r
.72609 .55758 .73079 .56289 .74115 .56007 .73647 .55478 Mtetra
.645 .759 .932 r
.73647 .55478 .74115 .56007 .75154 .55724 .7469 .55197 Mtetra
.646 .761 .932 r
.7469 .55197 .75154 .55724 .76198 .55439 .75736 .54913 Mtetra
.648 .762 .932 r
.75736 .54913 .76198 .55439 .77245 .55151 .76786 .54623 Mtetra
.651 .763 .932 r
.76786 .54623 .77245 .55151 .78295 .54857 .77839 .54325 Mtetra
.654 .764 .93 r
.77839 .54325 .78295 .54857 .79349 .54556 .78896 .54019 Mtetra
.657 .764 .928 r
.78896 .54019 .79349 .54556 .80407 .54249 .79956 .53704 Mtetra
.66 .763 .926 r
.79956 .53704 .80407 .54249 .81468 .53935 .81019 .53382 Mtetra
.662 .761 .924 r
.81019 .53382 .81468 .53935 .82532 .53616 .82086 .53054 Mtetra
.663 .759 .921 r
.82086 .53054 .82532 .53616 .836 .53292 .83156 .52723 Mtetra
.663 .757 .92 r
.83156 .52723 .836 .53292 .84672 .52965 .8423 .52388 Mtetra
.663 .755 .918 r
.8423 .52388 .84672 .52965 .85747 .52636 .85308 .52054 Mtetra
.663 .753 .917 r
.85308 .52054 .85747 .52636 .86827 .52307 .8639 .5172 Mtetra
.662 .752 .917 r
.8639 .5172 .86827 .52307 .8791 .51978 .87476 .51387 Mtetra
.661 .751 .917 r
.87476 .51387 .8791 .51978 .88997 .51649 .88566 .51056 Mtetra
.66 .751 .917 r
.88566 .51056 .88997 .51649 .90089 .51321 .89661 .50726 Mtetra
.659 .75 .917 r
.89661 .50726 .90089 .51321 .91185 .50993 .9076 .50397 Mtetra
.659 .75 .918 r
.9076 .50397 .91185 .50993 .92285 .50665 .91863 .50068 Mtetra
.658 .751 .918 r
.91863 .50068 .92285 .50665 .93389 .50337 .92971 .49739 Mtetra
.658 .751 .919 r
.92971 .49739 .93389 .50337 .94498 .50009 .94083 .4941 Mtetra
.658 .752 .919 r
.94083 .4941 .94498 .50009 .9561 .4968 .95198 .4908 Mtetra
.655 .751 .921 r
.35253 .65894 .35813 .66383 .3672 .66123 .36162 .65631 Mtetra
.655 .75 .92 r
.36162 .65631 .3672 .66123 .3763 .65863 .37074 .65367 Mtetra
.654 .749 .92 r
.37074 .65367 .3763 .65863 .38543 .65602 .37989 .65102 Mtetra
.654 .749 .919 r
.37989 .65102 .38543 .65602 .3946 .65342 .38908 .64838 Mtetra
.653 .748 .919 r
.38908 .64838 .3946 .65342 .40379 .65082 .39829 .64575 Mtetra
.652 .747 .919 r
.39829 .64575 .40379 .65082 .41302 .64824 .40754 .64314 Mtetra
.651 .746 .919 r
.40754 .64314 .41302 .64824 .42227 .64567 .41681 .64054 Mtetra
.649 .745 .919 r
.41681 .64054 .42227 .64567 .43156 .64312 .42612 .63797 Mtetra
.648 .744 .92 r
.42612 .63797 .43156 .64312 .44088 .64058 .43546 .63543 Mtetra
.646 .745 .921 r
.43546 .63543 .44088 .64058 .45024 .63804 .44484 .63291 Mtetra
.645 .746 .922 r
.44484 .63291 .45024 .63804 .45963 .63551 .45424 .63041 Mtetra
.644 .747 .924 r
.45424 .63041 .45963 .63551 .46905 .63296 .46368 .62791 Mtetra
.645 .75 .926 r
.46368 .62791 .46905 .63296 .4785 .63037 .47316 .62538 Mtetra
.646 .754 .928 r
.47316 .62538 .4785 .63037 .48799 .62773 .48267 .62281 Mtetra
.649 .758 .929 r
.48267 .62281 .48799 .62773 .49752 .62501 .49222 .62015 Mtetra
.652 .762 .93 r
.49222 .62015 .49752 .62501 .50708 .62222 .5018 .61741 Mtetra
.656 .766 .93 r
.5018 .61741 .50708 .62222 .51667 .61934 .51141 .61455 Mtetra
.66 .768 .93 r
.51141 .61455 .51667 .61934 .52629 .61639 .52106 .61159 Mtetra
.663 .77 .929 r
.52106 .61159 .52629 .61639 .53595 .61338 .53074 .60855 Mtetra
.665 .77 .928 r
.53074 .60855 .53595 .61338 .54564 .61034 .54045 .60546 Mtetra
.666 .768 .926 r
.54045 .60546 .54564 .61034 .55536 .60729 .5502 .60234 Mtetra
.666 .766 .925 r
.5502 .60234 .55536 .60729 .56512 .60424 .55998 .59922 Mtetra
.664 .764 .924 r
.55998 .59922 .56512 .60424 .57491 .60121 .56979 .59612 Mtetra
.663 .761 .923 r
.56979 .59612 .57491 .60121 .58474 .59821 .57964 .59305 Mtetra
.661 .759 .922 r
.57964 .59305 .58474 .59821 .59459 .59522 .58952 .59001 Mtetra
.66 .757 .922 r
.58952 .59001 .59459 .59522 .60449 .59226 .59944 .587 Mtetra
.659 .756 .922 r
.59944 .587 .60449 .59226 .61442 .58931 .6094 .58401 Mtetra
.657 .755 .922 r
.6094 .58401 .61442 .58931 .62438 .58638 .61938 .58104 Mtetra
.656 .754 .922 r
.61938 .58104 .62438 .58638 .63439 .58345 .62941 .57809 Mtetra
.656 .753 .922 r
.62941 .57809 .63439 .58345 .64442 .58052 .63947 .57514 Mtetra
.655 .753 .922 r
.63947 .57514 .64442 .58052 .6545 .5776 .64957 .57221 Mtetra
.654 .753 .923 r
.64957 .57221 .6545 .5776 .66461 .57469 .65971 .56929 Mtetra
.653 .753 .923 r
.65971 .56929 .66461 .57469 .67476 .57179 .66988 .56639 Mtetra
.651 .753 .924 r
.66988 .56639 .67476 .57179 .68494 .5689 .6801 .56351 Mtetra
.649 .754 .926 r
.6801 .56351 .68494 .5689 .69517 .56604 .69035 .56066 Mtetra
.647 .754 .927 r
.69035 .56066 .69517 .56604 .70544 .5632 .70064 .55785 Mtetra
.645 .756 .929 r
.70064 .55785 .70544 .5632 .71574 .56038 .71098 .55506 Mtetra
.644 .757 .931 r
.71098 .55506 .71574 .56038 .72609 .55758 .72135 .5523 Mtetra
.643 .759 .933 r
.72135 .5523 .72609 .55758 .73647 .55478 .73177 .54953 Mtetra
.643 .761 .934 r
.73177 .54953 .73647 .55478 .7469 .55197 .74222 .54674 Mtetra
.645 .763 .935 r
.74222 .54674 .7469 .55197 .75736 .54913 .75271 .54389 Mtetra
.648 .765 .934 r
.75271 .54389 .75736 .54913 .76786 .54623 .76324 .54096 Mtetra
.652 .766 .933 r
.76324 .54096 .76786 .54623 .77839 .54325 .7738 .53793 Mtetra
.656 .766 .93 r
.7738 .53793 .77839 .54325 .78896 .54019 .78439 .53478 Mtetra
.66 .765 .927 r
.78439 .53478 .78896 .54019 .79956 .53704 .79501 .53153 Mtetra
.663 .763 .924 r
.79501 .53153 .79956 .53704 .81019 .53382 .80566 .5282 Mtetra
.665 .76 .921 r
.80566 .5282 .81019 .53382 .82086 .53054 .81635 .52482 Mtetra
.666 .757 .918 r
.81635 .52482 .82086 .53054 .83156 .52723 .82708 .52141 Mtetra
.666 .754 .916 r
.82708 .52141 .83156 .52723 .8423 .52388 .83784 .51799 Mtetra
.665 .752 .915 r
.83784 .51799 .8423 .52388 .85308 .52054 .84865 .51459 Mtetra
.663 .75 .915 r
.84865 .51459 .85308 .52054 .8639 .5172 .85949 .51121 Mtetra
.662 .749 .915 r
.85949 .51121 .8639 .5172 .87476 .51387 .87039 .50786 Mtetra
.661 .749 .915 r
.87039 .50786 .87476 .51387 .88566 .51056 .88132 .50454 Mtetra
.66 .748 .916 r
.88132 .50454 .88566 .51056 .89661 .50726 .8923 .50123 Mtetra
.659 .749 .917 r
.8923 .50123 .89661 .50726 .9076 .50397 .90332 .49793 Mtetra
.658 .749 .917 r
.90332 .49793 .9076 .50397 .91863 .50068 .91438 .49464 Mtetra
.657 .75 .918 r
.91438 .49464 .91863 .50068 .92971 .49739 .92549 .49136 Mtetra
.657 .75 .919 r
.92549 .49136 .92971 .49739 .94083 .4941 .93664 .48806 Mtetra
.657 .751 .919 r
.93664 .48806 .94083 .4941 .95198 .4908 .94784 .48476 Mtetra
.656 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .65631 .356 .65135 Mtetra
.356 .65135 .36162 .65631 .37074 .65367 .36515 .64867 Mtetra
.655 .75 .919 r
.36515 .64867 .37074 .65367 .37989 .65102 .37432 .64599 Mtetra
.655 .749 .919 r
.37432 .64599 .37989 .65102 .38908 .64838 .38352 .64331 Mtetra
.654 .747 .918 r
.38352 .64331 .38908 .64838 .39829 .64575 .39276 .64063 Mtetra
.653 .746 .918 r
.39276 .64063 .39829 .64575 .40754 .64314 .40202 .63797 Mtetra
.652 .745 .918 r
.40202 .63797 .40754 .64314 .41681 .64054 .41132 .63533 Mtetra
.65 .743 .918 r
.41132 .63533 .41681 .64054 .42612 .63797 .42065 .63273 Mtetra
.648 .742 .918 r
.42065 .63273 .42612 .63797 .43546 .63543 .43001 .63017 Mtetra
.646 .741 .919 r
.43001 .63017 .43546 .63543 .44484 .63291 .4394 .62765 Mtetra
.644 .741 .92 r
.4394 .62765 .44484 .63291 .45424 .63041 .44883 .62517 Mtetra
.642 .742 .922 r
.44883 .62517 .45424 .63041 .46368 .62791 .45829 .62272 Mtetra
.641 .745 .924 r
.45829 .62272 .46368 .62791 .47316 .62538 .46778 .62027 Mtetra
.642 .749 .926 r
.46778 .62027 .47316 .62538 .48267 .62281 .47731 .61778 Mtetra
.644 .753 .929 r
.47731 .61778 .48267 .62281 .49222 .62015 .48688 .61522 Mtetra
.648 .759 .93 r
.48688 .61522 .49222 .62015 .5018 .61741 .49648 .61255 Mtetra
.653 .764 .931 r
.49648 .61255 .5018 .61741 .51141 .61455 .50612 .60975 Mtetra
.658 .769 .931 r
.50612 .60975 .51141 .61455 .52106 .61159 .51579 .60682 Mtetra
.663 .772 .931 r
.51579 .60682 .52106 .61159 .53074 .60855 .52549 .60376 Mtetra
.666 .773 .929 r
.52549 .60376 .53074 .60855 .54045 .60546 .53523 .60063 Mtetra
.668 .772 .928 r
.53523 .60063 .54045 .60546 .5502 .60234 .545 .59744 Mtetra
.668 .77 .927 r
.545 .59744 .5502 .60234 .55998 .59922 .55481 .59424 Mtetra
.667 .768 .925 r
.55481 .59424 .55998 .59922 .56979 .59612 .56464 .59106 Mtetra
.665 .765 .924 r
.56464 .59106 .56979 .59612 .57964 .59305 .57452 .58791 Mtetra
.663 .762 .923 r
.57452 .58791 .57964 .59305 .58952 .59001 .58442 .58481 Mtetra
.661 .759 .923 r
.58442 .58481 .58952 .59001 .59944 .587 .59436 .58174 Mtetra
.659 .758 .923 r
.59436 .58174 .59944 .587 .6094 .58401 .60434 .57871 Mtetra
.658 .756 .922 r
.60434 .57871 .6094 .58401 .61938 .58104 .61435 .57571 Mtetra
.657 .755 .922 r
.61435 .57571 .61938 .58104 .62941 .57809 .6244 .57272 Mtetra
.656 .754 .923 r
.6244 .57272 .62941 .57809 .63947 .57514 .63449 .56976 Mtetra
.654 .754 .923 r
.63449 .56976 .63947 .57514 .64957 .57221 .64461 .56682 Mtetra
.653 .754 .924 r
.64461 .56682 .64957 .57221 .65971 .56929 .65478 .56389 Mtetra
.651 .754 .925 r
.65478 .56389 .65971 .56929 .66988 .56639 .66498 .561 Mtetra
.649 .754 .926 r
.66498 .561 .66988 .56639 .6801 .56351 .67522 .55814 Mtetra
.647 .755 .928 r
.67522 .55814 .6801 .56351 .69035 .56066 .6855 .55532 Mtetra
.644 .756 .93 r
.6855 .55532 .69035 .56066 .70064 .55785 .69582 .55254 Mtetra
.642 .757 .932 r
.69582 .55254 .70064 .55785 .71098 .55506 .70619 .54979 Mtetra
.641 .759 .935 r
.70619 .54979 .71098 .55506 .72135 .5523 .71659 .54707 Mtetra
.64 .762 .936 r
.71659 .54707 .72135 .5523 .73177 .54953 .72704 .54434 Mtetra
.642 .764 .937 r
.72704 .54434 .73177 .54953 .74222 .54674 .73752 .54155 Mtetra
.644 .766 .937 r
.73752 .54155 .74222 .54674 .75271 .54389 .74804 .53868 Mtetra
.65 .768 .935 r
.74804 .53868 .75271 .54389 .76324 .54096 .75859 .53568 Mtetra
.655 .768 .933 r
.75859 .53568 .76324 .54096 .7738 .53793 .76917 .53255 Mtetra
.66 .767 .929 r
.76917 .53255 .7738 .53793 .78439 .53478 .77978 .52928 Mtetra
.665 .765 .924 r
.77978 .52928 .78439 .53478 .79501 .53153 .79043 .5259 Mtetra
.668 .761 .92 r
.79043 .5259 .79501 .53153 .80566 .5282 .8011 .52244 Mtetra
.669 .757 .917 r
.8011 .52244 .80566 .5282 .81635 .52482 .81181 .51894 Mtetra
.668 .754 .914 r
.81181 .51894 .81635 .52482 .82708 .52141 .82256 .51544 Mtetra
.667 .751 .913 r
.82256 .51544 .82708 .52141 .83784 .51799 .83334 .51195 Mtetra
.665 .748 .912 r
.83334 .51195 .83784 .51799 .84865 .51459 .84418 .50852 Mtetra
.663 .747 .912 r
.84418 .50852 .84865 .51459 .85949 .51121 .85505 .50512 Mtetra
.662 .746 .913 r
.85505 .50512 .85949 .51121 .87039 .50786 .86598 .50176 Mtetra
.66 .746 .914 r
.86598 .50176 .87039 .50786 .88132 .50454 .87694 .49844 Mtetra
.659 .747 .915 r
.87694 .49844 .88132 .50454 .8923 .50123 .88795 .49513 Mtetra
.658 .747 .916 r
.88795 .49513 .8923 .50123 .90332 .49793 .89901 .49185 Mtetra
.657 .748 .917 r
.89901 .49185 .90332 .49793 .91438 .49464 .91011 .48856 Mtetra
.656 .749 .918 r
.91011 .48856 .91438 .49464 .92549 .49136 .92125 .48528 Mtetra
.656 .75 .919 r
.92125 .48528 .92549 .49136 .93664 .48806 .93243 .48198 Mtetra
.656 .751 .92 r
.93243 .48198 .93664 .48806 .94784 .48476 .94366 .47868 Mtetra
.656 .752 .92 r
.34122 .64908 .34689 .65403 .356 .65135 .35035 .64637 Mtetra
.657 .751 .919 r
.35035 .64637 .356 .65135 .36515 .64867 .35951 .64365 Mtetra
.656 .75 .919 r
.35951 .64365 .36515 .64867 .37432 .64599 .36871 .64093 Mtetra
.656 .749 .918 r
.36871 .64093 .37432 .64599 .38352 .64331 .37793 .6382 Mtetra
.656 .748 .918 r
.37793 .6382 .38352 .64331 .39276 .64063 .38719 .63547 Mtetra
.655 .746 .917 r
.38719 .63547 .39276 .64063 .40202 .63797 .39648 .63275 Mtetra
.654 .744 .916 r
.39648 .63275 .40202 .63797 .41132 .63533 .40579 .63005 Mtetra
.652 .742 .916 r
.40579 .63005 .41132 .63533 .42065 .63273 .41514 .62739 Mtetra
.65 .74 .916 r
.41514 .62739 .42065 .63273 .43001 .63017 .42452 .62478 Mtetra
.647 .738 .916 r
.42452 .62478 .43001 .63017 .4394 .62765 .43394 .62223 Mtetra
.643 .737 .917 r
.43394 .62223 .4394 .62765 .44883 .62517 .44338 .61976 Mtetra
.64 .737 .919 r
.44338 .61976 .44883 .62517 .45829 .62272 .45286 .61735 Mtetra
.637 .738 .921 r
.45286 .61735 .45829 .62272 .46778 .62027 .46237 .61498 Mtetra
.637 .742 .924 r
.46237 .61498 .46778 .62027 .47731 .61778 .47192 .6126 Mtetra
.638 .747 .927 r
.47192 .6126 .47731 .61778 .48688 .61522 .48151 .61018 Mtetra
.642 .754 .93 r
.48151 .61018 .48688 .61522 .49648 .61255 .49113 .60764 Mtetra
.648 .762 .932 r
.49113 .60764 .49648 .61255 .50612 .60975 .50079 .60494 Mtetra
.654 .768 .933 r
.50079 .60494 .50612 .60975 .51579 .60682 .51048 .60207 Mtetra
.661 .774 .933 r
.51048 .60207 .51579 .60682 .52549 .60376 .52021 .59903 Mtetra
.666 .776 .932 r
.52021 .59903 .52549 .60376 .53523 .60063 .52998 .59586 Mtetra
.669 .777 .93 r
.52998 .59586 .53523 .60063 .545 .59744 .53977 .59261 Mtetra
.67 .775 .929 r
.53977 .59261 .545 .59744 .55481 .59424 .5496 .58933 Mtetra
.669 .772 .927 r
.5496 .58933 .55481 .59424 .56464 .59106 .55946 .58605 Mtetra
.668 .769 .926 r
.55946 .58605 .56464 .59106 .57452 .58791 .56936 .58282 Mtetra
.665 .766 .925 r
.56936 .58282 .57452 .58791 .58442 .58481 .57929 .57963 Mtetra
.663 .762 .924 r
.57929 .57963 .58442 .58481 .59436 .58174 .58925 .5765 Mtetra
.661 .76 .924 r
.58925 .5765 .59436 .58174 .60434 .57871 .59925 .57342 Mtetra
.659 .758 .923 r
.59925 .57342 .60434 .57871 .61435 .57571 .60929 .57037 Mtetra
.657 .757 .923 r
.60929 .57037 .61435 .57571 .6244 .57272 .61936 .56736 Mtetra
.655 .756 .924 r
.61936 .56736 .6244 .57272 .63449 .56976 .62947 .56438 Mtetra
.654 .755 .924 r
.62947 .56438 .63449 .56976 .64461 .56682 .63962 .56142 Mtetra
.652 .755 .925 r
.63962 .56142 .64461 .56682 .65478 .56389 .64981 .5585 Mtetra
.65 .755 .926 r
.64981 .5585 .65478 .56389 .66498 .561 .66004 .55562 Mtetra
.647 .755 .928 r
.66004 .55562 .66498 .561 .67522 .55814 .67031 .55279 Mtetra
.644 .756 .931 r
.67031 .55279 .67522 .55814 .6855 .55532 .68062 .55001 Mtetra
.641 .758 .933 r
.68062 .55001 .6855 .55532 .69582 .55254 .69097 .54728 Mtetra
.638 .76 .936 r
.69097 .54728 .69582 .55254 .70619 .54979 .70137 .54459 Mtetra
.637 .762 .938 r
.70137 .54459 .70619 .54979 .71659 .54707 .7118 .54192 Mtetra
.637 .765 .94 r
.7118 .54192 .71659 .54707 .72704 .54434 .72228 .53921 Mtetra
.64 .768 .94 r
.72228 .53921 .72704 .54434 .73752 .54155 .73279 .53641 Mtetra
.645 .77 .939 r
.73279 .53641 .73752 .54155 .74804 .53868 .74334 .53349 Mtetra
.653 .771 .936 r
.74334 .53349 .74804 .53868 .75859 .53568 .75391 .53039 Mtetra
.66 .77 .931 r
.75391 .53039 .75859 .53568 .76917 .53255 .76451 .52711 Mtetra
.666 .768 .926 r
.76451 .52711 .76917 .53255 .77978 .52928 .77514 .52367 Mtetra
.671 .764 .92 r
.77514 .52367 .77978 .52928 .79043 .5259 .7858 .52011 Mtetra
.673 .758 .915 r
.7858 .52011 .79043 .5259 .8011 .52244 .79649 .51649 Mtetra
.673 .754 .912 r
.79649 .51649 .8011 .52244 .81181 .51894 .80722 .51287 Mtetra
.671 .749 .909 r
.80722 .51287 .81181 .51894 .82256 .51544 .81799 .50928 Mtetra
.668 .746 .909 r
.81799 .50928 .82256 .51544 .83334 .51195 .82881 .50576 Mtetra
.665 .744 .909 r
.82881 .50576 .83334 .51195 .84418 .50852 .83967 .50231 Mtetra
.662 .743 .91 r
.83967 .50231 .84418 .50852 .85505 .50512 .85058 .49891 Mtetra
.66 .743 .912 r
.85058 .49891 .85505 .50512 .86598 .50176 .86153 .49558 Mtetra
.658 .744 .913 r
.86153 .49558 .86598 .50176 .87694 .49844 .87253 .49227 Mtetra
.657 .745 .915 r
.87253 .49227 .87694 .49844 .88795 .49513 .88358 .48899 Mtetra
.656 .747 .916 r
.88358 .48899 .88795 .49513 .89901 .49185 .89466 .48572 Mtetra
.656 .748 .918 r
.89466 .48572 .89901 .49185 .91011 .48856 .9058 .48244 Mtetra
.655 .749 .919 r
.9058 .48244 .91011 .48856 .92125 .48528 .91697 .47916 Mtetra
.655 .75 .919 r
.91697 .47916 .92125 .48528 .93243 .48198 .92819 .47587 Mtetra
.655 .751 .92 r
.92819 .47587 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.657 .752 .92 r
.33552 .6441 .34122 .64908 .35035 .64637 .34467 .64136 Mtetra
.657 .751 .92 r
.34467 .64136 .35035 .64637 .35951 .64365 .35385 .63862 Mtetra
.657 .751 .919 r
.35385 .63862 .35951 .64365 .36871 .64093 .36306 .63586 Mtetra
.657 .75 .919 r
.36306 .63586 .36871 .64093 .37793 .6382 .37231 .63309 Mtetra
.657 .749 .918 r
.37231 .63309 .37793 .6382 .38719 .63547 .38158 .6303 Mtetra
.657 .748 .917 r
.38158 .6303 .38719 .63547 .39648 .63275 .39089 .62752 Mtetra
.656 .746 .916 r
.39089 .62752 .39648 .63275 .40579 .63005 .40023 .62475 Mtetra
.655 .743 .915 r
.40023 .62475 .40579 .63005 .41514 .62739 .4096 .622 Mtetra
.652 .74 .914 r
.4096 .622 .41514 .62739 .42452 .62478 .41901 .61932 Mtetra
.649 .737 .914 r
.41901 .61932 .42452 .62478 .43394 .62223 .42844 .61671 Mtetra
.644 .734 .914 r
.42844 .61671 .43394 .62223 .44338 .61976 .43791 .6142 Mtetra
.64 .732 .915 r
.43791 .6142 .44338 .61976 .45286 .61735 .4474 .61179 Mtetra
.635 .731 .918 r
.4474 .61179 .45286 .61735 .46237 .61498 .45693 .60948 Mtetra
.632 .733 .921 r
.45693 .60948 .46237 .61498 .47192 .6126 .4665 .60721 Mtetra
.631 .738 .925 r
.4665 .60721 .47192 .6126 .48151 .61018 .4761 .60494 Mtetra
.634 .746 .929 r
.4761 .60494 .48151 .61018 .49113 .60764 .48574 .60258 Mtetra
.64 .755 .932 r
.48574 .60258 .49113 .60764 .50079 .60494 .49542 .60004 Mtetra
.648 .765 .934 r
.49542 .60004 .50079 .60494 .51048 .60207 .50514 .5973 Mtetra
.657 .773 .935 r
.50514 .5973 .51048 .60207 .52021 .59903 .5149 .59433 Mtetra
.664 .779 .934 r
.5149 .59433 .52021 .59903 .52998 .59586 .52468 .59117 Mtetra
.67 .781 .933 r
.52468 .59117 .52998 .59586 .53977 .59261 .5345 .58787 Mtetra
.672 .781 .931 r
.5345 .58787 .53977 .59261 .5496 .58933 .54436 .58451 Mtetra
.672 .778 .929 r
.54436 .58451 .5496 .58933 .55946 .58605 .55424 .58114 Mtetra
.671 .775 .928 r
.55424 .58114 .55946 .58605 .56936 .58282 .56416 .5778 Mtetra
.668 .771 .927 r
.56416 .5778 .56936 .58282 .57929 .57963 .57412 .57452 Mtetra
.665 .767 .926 r
.57412 .57452 .57929 .57963 .58925 .5765 .5841 .57131 Mtetra
.662 .764 .925 r
.5841 .57131 .58925 .5765 .59925 .57342 .59413 .56816 Mtetra
.66 .761 .925 r
.59413 .56816 .59925 .57342 .60929 .57037 .60419 .56507 Mtetra
.657 .759 .925 r
.60419 .56507 .60929 .57037 .61936 .56736 .61429 .56202 Mtetra
.655 .758 .925 r
.61429 .56202 .61936 .56736 .62947 .56438 .62443 .55902 Mtetra
.653 .757 .926 r
.62443 .55902 .62947 .56438 .63962 .56142 .6346 .55606 Mtetra
.65 .757 .927 r
.6346 .55606 .63962 .56142 .64981 .5585 .64482 .55315 Mtetra
.647 .757 .929 r
.64482 .55315 .64981 .5585 .66004 .55562 .65507 .55029 Mtetra
.644 .758 .932 r
.65507 .55029 .66004 .55562 .67031 .55279 .66537 .5475 Mtetra
.64 .759 .934 r
.66537 .5475 .67031 .55279 .68062 .55001 .67571 .54477 Mtetra
.636 .761 .938 r
.67571 .54477 .68062 .55001 .69097 .54728 .68609 .54211 Mtetra
.634 .763 .941 r
.68609 .54211 .69097 .54728 .70137 .54459 .69652 .53948 Mtetra
.633 .766 .943 r
.69652 .53948 .70137 .54459 .7118 .54192 .70699 .53685 Mtetra
.635 .769 .944 r
.70699 .53685 .7118 .54192 .72228 .53921 .71749 .53415 Mtetra
.641 .772 .943 r
.71749 .53415 .72228 .53921 .73279 .53641 .72803 .5313 Mtetra
.649 .774 .94 r
.72803 .5313 .73279 .53641 .74334 .53349 .7386 .52827 Mtetra
.659 .774 .934 r
.7386 .52827 .74334 .53349 .75391 .53039 .7492 .525 Mtetra
.668 .771 .927 r
.7492 .525 .75391 .53039 .76451 .52711 .75981 .52151 Mtetra
.674 .766 .92 r
.75981 .52151 .76451 .52711 .77514 .52367 .77046 .51785 Mtetra
.677 .76 .913 r
.77046 .51785 .77514 .52367 .7858 .52011 .78113 .51409 Mtetra
.677 .753 .908 r
.78113 .51409 .7858 .52011 .79649 .51649 .79184 .51032 Mtetra
.675 .748 .906 r
.79184 .51032 .79649 .51649 .80722 .51287 .80259 .50659 Mtetra
.671 .744 .905 r
.80259 .50659 .80722 .51287 .81799 .50928 .81339 .50296 Mtetra
.668 .741 .905 r
.81339 .50296 .81799 .50928 .82881 .50576 .82423 .49943 Mtetra
.663 .74 .907 r
.82423 .49943 .82881 .50576 .83967 .50231 .83512 .49601 Mtetra
.66 .741 .91 r
.83512 .49601 .83967 .50231 .85058 .49891 .84607 .49266 Mtetra
.658 .742 .912 r
.84607 .49266 .85058 .49891 .86153 .49558 .85706 .48936 Mtetra
.656 .744 .914 r
.85706 .48936 .86153 .49558 .87253 .49227 .86809 .4861 Mtetra
.655 .746 .916 r
.86809 .4861 .87253 .49227 .88358 .48899 .87917 .48284 Mtetra
.655 .747 .918 r
.87917 .48284 .88358 .48899 .89466 .48572 .8903 .47958 Mtetra
.655 .749 .919 r
.8903 .47958 .89466 .48572 .9058 .48244 .90146 .47631 Mtetra
.655 .75 .92 r
.90146 .47631 .9058 .48244 .91697 .47916 .91267 .47302 Mtetra
.91267 .47302 .91697 .47916 .92819 .47587 .92392 .46971 Mtetra
.655 .751 .92 r
.92392 .46971 .92819 .47587 .93945 .47256 .93521 .46639 Mtetra
.656 .752 .92 r
.32977 .63908 .33552 .6441 .34467 .64136 .33894 .63634 Mtetra
.657 .752 .92 r
.33894 .63634 .34467 .64136 .35385 .63862 .34814 .63358 Mtetra
.34814 .63358 .35385 .63862 .36306 .63586 .35738 .6308 Mtetra
.658 .752 .92 r
.35738 .6308 .36306 .63586 .37231 .63309 .36664 .628 Mtetra
.659 .752 .919 r
.36664 .628 .37231 .63309 .38158 .6303 .37594 .62517 Mtetra
.659 .751 .918 r
.37594 .62517 .38158 .6303 .39089 .62752 .38527 .62232 Mtetra
.659 .749 .917 r
.38527 .62232 .39089 .62752 .40023 .62475 .39463 .61946 Mtetra
.658 .746 .915 r
.39463 .61946 .40023 .62475 .4096 .622 .40403 .61662 Mtetra
.656 .743 .913 r
.40403 .61662 .4096 .622 .41901 .61932 .41345 .61381 Mtetra
.653 .738 .912 r
.41345 .61381 .41901 .61932 .42844 .61671 .42291 .61108 Mtetra
.648 .733 .911 r
.42291 .61108 .42844 .61671 .43791 .6142 .4324 .60848 Mtetra
.641 .728 .911 r
.4324 .60848 .43791 .6142 .4474 .61179 .44191 .60602 Mtetra
.634 .725 .913 r
.44191 .60602 .4474 .61179 .45693 .60948 .45146 .60373 Mtetra
.628 .724 .916 r
.45146 .60373 .45693 .60948 .4665 .60721 .46105 .60155 Mtetra
.624 .727 .921 r
.46105 .60155 .4665 .60721 .4761 .60494 .47067 .59946 Mtetra
.624 .734 .926 r
.47067 .59946 .4761 .60494 .48574 .60258 .48033 .59731 Mtetra
.629 .745 .931 r
.48033 .59731 .48574 .60258 .49542 .60004 .49002 .59501 Mtetra
.638 .758 .935 r
.49002 .59501 .49542 .60004 .50514 .5973 .49976 .59248 Mtetra
.65 .77 .937 r
.49976 .59248 .50514 .5973 .5149 .59433 .50954 .58965 Mtetra
.66 .78 .937 r
.50954 .58965 .5149 .59433 .52468 .59117 .51935 .58656 Mtetra
.669 .786 .936 r
.51935 .58656 .52468 .59117 .5345 .58787 .5292 .58325 Mtetra
.674 .787 .934 r
.5292 .58325 .5345 .58787 .54436 .58451 .53908 .57981 Mtetra
.675 .785 .932 r
.53908 .57981 .54436 .58451 .55424 .58114 .54899 .57634 Mtetra
.674 .782 .931 r
.54899 .57634 .55424 .58114 .56416 .5778 .55893 .57289 Mtetra
.671 .777 .929 r
.55893 .57289 .56416 .5778 .57412 .57452 .56891 .5695 Mtetra
.668 .773 .928 r
.56891 .5695 .57412 .57452 .5841 .57131 .57893 .56619 Mtetra
.664 .769 .928 r
.57893 .56619 .5841 .57131 .59413 .56816 .58897 .56297 Mtetra
.661 .765 .927 r
.58897 .56297 .59413 .56816 .60419 .56507 .59906 .55981 Mtetra
.658 .763 .927 r
.59906 .55981 .60419 .56507 .61429 .56202 .60919 .55673 Mtetra
.655 .761 .928 r
.60919 .55673 .61429 .56202 .62443 .55902 .61935 .55371 Mtetra
.652 .76 .929 r
.61935 .55371 .62443 .55902 .6346 .55606 .62955 .55075 Mtetra
.648 .76 .931 r
.62955 .55075 .6346 .55606 .64482 .55315 .63979 .54785 Mtetra
.645 .76 .933 r
.63979 .54785 .64482 .55315 .65507 .55029 .65008 .54503 Mtetra
.64 .761 .936 r
.65008 .54503 .65507 .55029 .66537 .5475 .6604 .5423 Mtetra
.635 .762 .939 r
.6604 .5423 .66537 .5475 .67571 .54477 .67077 .53964 Mtetra
.631 .764 .943 r
.67077 .53964 .67571 .54477 .68609 .54211 .68119 .53706 Mtetra
.628 .767 .946 r
.68119 .53706 .68609 .54211 .69652 .53948 .69165 .53449 Mtetra
.629 .771 .948 r
.69165 .53449 .69652 .53948 .70699 .53685 .70214 .53189 Mtetra
.634 .775 .948 r
.70214 .53189 .70699 .53685 .71749 .53415 .71268 .52916 Mtetra
.644 .778 .945 r
.71268 .52916 .71749 .53415 .72803 .5313 .72324 .52621 Mtetra
.655 .779 .939 r
.72324 .52621 .72803 .5313 .7386 .52827 .73383 .523 Mtetra
.668 .776 .93 r
.73383 .523 .7386 .52827 .7492 .525 .74444 .51947 Mtetra
.678 .771 .921 r
.74444 .51947 .7492 .525 .75981 .52151 .75507 .5157 Mtetra
.683 .763 .912 r
.75507 .5157 .75981 .52151 .77046 .51785 .76572 .51177 Mtetra
.684 .754 .905 r
.76572 .51177 .77046 .51785 .78113 .51409 .77641 .50779 Mtetra
.681 .746 .9 r
.77641 .50779 .78113 .51409 .79184 .51032 .78714 .50389 Mtetra
.676 .74 .899 r
.78714 .50389 .79184 .51032 .80259 .50659 .79791 .50009 Mtetra
.67 .737 .9 r
.79791 .50009 .80259 .50659 .81339 .50296 .80874 .49648 Mtetra
.665 .736 .903 r
.80874 .49648 .81339 .50296 .82423 .49943 .81962 .493 Mtetra
.66 .737 .907 r
.81962 .493 .82423 .49943 .83512 .49601 .83055 .48966 Mtetra
.656 .739 .911 r
.83055 .48966 .83512 .49601 .84607 .49266 .84153 .48639 Mtetra
.654 .742 .914 r
.84153 .48639 .84607 .49266 .85706 .48936 .85256 .48316 Mtetra
.653 .745 .917 r
.85256 .48316 .85706 .48936 .86809 .4861 .86363 .47994 Mtetra
.653 .747 .919 r
.86363 .47994 .86809 .4861 .87917 .48284 .87475 .47671 Mtetra
.653 .749 .92 r
.87475 .47671 .87917 .48284 .8903 .47958 .8859 .47346 Mtetra
.654 .75 .921 r
.8859 .47346 .8903 .47958 .90146 .47631 .8971 .47018 Mtetra
.654 .751 .921 r
.8971 .47018 .90146 .47631 .91267 .47302 .90834 .46687 Mtetra
.655 .751 .921 r
.90834 .46687 .91267 .47302 .92392 .46971 .91962 .46354 Mtetra
.91962 .46354 .92392 .46971 .93521 .46639 .93095 .46018 Mtetra
.655 .751 .92 r
.32399 .63404 .32977 .63908 .33894 .63634 .33318 .6313 Mtetra
.656 .752 .921 r
.33318 .6313 .33894 .63634 .34814 .63358 .3424 .62855 Mtetra
.656 .753 .921 r
.3424 .62855 .34814 .63358 .35738 .6308 .35165 .62577 Mtetra
.657 .754 .921 r
.35165 .62577 .35738 .6308 .36664 .628 .36094 .62295 Mtetra
.659 .755 .921 r
.36094 .62295 .36664 .628 .37594 .62517 .37026 .6201 Mtetra
.66 .755 .92 r
.37026 .6201 .37594 .62517 .38527 .62232 .37961 .6172 Mtetra
.661 .754 .919 r
.37961 .6172 .38527 .62232 .39463 .61946 .38899 .61427 Mtetra
.662 .752 .917 r
.38899 .61427 .39463 .61946 .40403 .61662 .39841 .61131 Mtetra
.661 .748 .915 r
.39841 .61131 .40403 .61662 .41345 .61381 .40786 .60836 Mtetra
.659 .743 .912 r
.40786 .60836 .41345 .61381 .42291 .61108 .41734 .60547 Mtetra
.654 .737 .91 r
.41734 .60547 .42291 .61108 .4324 .60848 .42685 .6027 Mtetra
.646 .729 .909 r
.42685 .6027 .4324 .60848 .44191 .60602 .43639 .6001 Mtetra
.636 .722 .909 r
.43639 .6001 .44191 .60602 .45146 .60373 .44596 .59774 Mtetra
.627 .717 .911 r
.44596 .59774 .45146 .60373 .46105 .60155 .45556 .59559 Mtetra
.618 .715 .915 r
.45556 .59559 .46105 .60155 .47067 .59946 .4652 .59363 Mtetra
.615 .72 .92 r
.4652 .59363 .47067 .59946 .48033 .59731 .47488 .59172 Mtetra
.616 .73 .927 r
.47488 .59172 .48033 .59731 .49002 .59501 .48459 .58972 Mtetra
.625 .745 .933 r
.48459 .58972 .49002 .59501 .49976 .59248 .49435 .58749 Mtetra
.639 .762 .937 r
.49435 .58749 .49976 .59248 .50954 .58965 .50415 .5849 Mtetra
.652 .776 .939 r
.50415 .5849 .50954 .58965 .51935 .58656 .51398 .58197 Mtetra
.666 .787 .939 r
.51398 .58197 .51935 .58656 .5292 .58325 .52386 .57871 Mtetra
.674 .792 .938 r
.52386 .57871 .5292 .58325 .53908 .57981 .53376 .57526 Mtetra
.678 .793 .936 r
.53376 .57526 .53908 .57981 .54899 .57634 .5437 .5717 Mtetra
.678 .79 .934 r
.5437 .5717 .54899 .57634 .55893 .57289 .55367 .56813 Mtetra
.675 .786 .933 r
.55367 .56813 .55893 .57289 .56891 .5695 .56367 .56462 Mtetra
.671 .781 .932 r
.56367 .56462 .56891 .5695 .57893 .56619 .57371 .5612 Mtetra
.667 .776 .931 r
.57371 .5612 .57893 .56619 .58897 .56297 .58379 .55789 Mtetra
.662 .772 .931 r
.58379 .55789 .58897 .56297 .59906 .55981 .5939 .55467 Mtetra
.658 .769 .931 r
.5939 .55467 .59906 .55981 .60919 .55673 .60405 .55154 Mtetra
.654 .766 .932 r
.60405 .55154 .60919 .55673 .61935 .55371 .61424 .5485 Mtetra
.65 .765 .933 r
.61424 .5485 .61935 .55371 .62955 .55075 .62447 .54554 Mtetra
.645 .765 .935 r
.62447 .54554 .62955 .55075 .63979 .54785 .63474 .54268 Mtetra
.64 .765 .938 r
.63474 .54268 .63979 .54785 .65008 .54503 .64505 .53991 Mtetra
.635 .766 .942 r
.64505 .53991 .65008 .54503 .6604 .5423 .65541 .53724 Mtetra
.629 .767 .946 r
.65541 .53724 .6604 .5423 .67077 .53964 .66581 .53467 Mtetra
.624 .77 .95 r
.66581 .53467 .67077 .53964 .68119 .53706 .67626 .53216 Mtetra
.623 .774 .953 r
.67626 .53216 .68119 .53706 .69165 .53449 .68675 .52964 Mtetra
.627 .778 .953 r
.68675 .52964 .69165 .53449 .70214 .53189 .69727 .52702 Mtetra
.636 .781 .951 r
.69727 .52702 .70214 .53189 .71268 .52916 .70783 .5242 Mtetra
.651 .783 .944 r
.70783 .5242 .71268 .52916 .72324 .52621 .71842 .52105 Mtetra
.667 .781 .934 r
.71842 .52105 .72324 .52621 .73383 .523 .72902 .51754 Mtetra
.681 .775 .922 r
.72902 .51754 .73383 .523 .74444 .51947 .73963 .51367 Mtetra
.689 .766 .91 r
.73963 .51367 .74444 .51947 .75507 .5157 .75027 .50955 Mtetra
.691 .755 .9 r
.75027 .50955 .75507 .5157 .76572 .51177 .76093 .50535 Mtetra
.689 .745 .894 r
.76093 .50535 .76572 .51177 .77641 .50779 .77163 .50118 Mtetra
.682 .737 .893 r
.77163 .50118 .77641 .50779 .78714 .50389 .78239 .4972 Mtetra
.674 .733 .894 r
.78239 .4972 .78714 .50389 .79791 .50009 .79319 .49345 Mtetra
.666 .732 .899 r
.79319 .49345 .79791 .50009 .80874 .49648 .80406 .48993 Mtetra
.659 .733 .904 r
.80406 .48993 .80874 .49648 .81962 .493 .81498 .48659 Mtetra
.655 .737 .91 r
.81498 .48659 .81962 .493 .83055 .48966 .82595 .48336 Mtetra
.651 .741 .915 r
.82595 .48336 .83055 .48966 .84153 .48639 .83697 .4802 Mtetra
.651 .745 .918 r
.83697 .4802 .84153 .48639 .85256 .48316 .84804 .47704 Mtetra
.651 .748 .921 r
.84804 .47704 .85256 .48316 .86363 .47994 .85915 .47387 Mtetra
.652 .751 .922 r
.85915 .47387 .86363 .47994 .87475 .47671 .8703 .47064 Mtetra
.653 .753 .923 r
.8703 .47064 .87475 .47671 .8859 .47346 .88149 .46737 Mtetra
.654 .753 .923 r
.88149 .46737 .8859 .47346 .8971 .47018 .89272 .46406 Mtetra
.655 .753 .922 r
.89272 .46406 .8971 .47018 .90834 .46687 .90398 .46071 Mtetra
.656 .753 .922 r
.90398 .46071 .90834 .46687 .91962 .46354 .9153 .45733 Mtetra
.656 .752 .921 r
.9153 .45733 .91962 .46354 .93095 .46018 .92665 .45393 Mtetra
.654 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .6313 .32738 .62625 Mtetra
.654 .752 .922 r
.32738 .62625 .33318 .6313 .3424 .62855 .33662 .62352 Mtetra
.654 .754 .923 r
.33662 .62352 .3424 .62855 .35165 .62577 .34589 .62076 Mtetra
.656 .756 .924 r
.34589 .62076 .35165 .62577 .36094 .62295 .35519 .61796 Mtetra
.657 .758 .924 r
.35519 .61796 .36094 .62295 .37026 .6201 .36453 .61512 Mtetra
.66 .759 .924 r
.36453 .61512 .37026 .6201 .37961 .6172 .3739 .61221 Mtetra
.662 .76 .923 r
.3739 .61221 .37961 .6172 .38899 .61427 .38331 .60922 Mtetra
.665 .76 .921 r
.38331 .60922 .38899 .61427 .39841 .61131 .39275 .60617 Mtetra
.667 .757 .918 r
.39275 .60617 .39841 .61131 .40786 .60836 .40223 .60307 Mtetra
.666 .752 .914 r
.40223 .60307 .40786 .60836 .41734 .60547 .41174 .59997 Mtetra
.663 .744 .911 r
.41174 .59997 .41734 .60547 .42685 .6027 .42128 .59695 Mtetra
.655 .734 .907 r
.42128 .59695 .42685 .6027 .43639 .6001 .43084 .59411 Mtetra
.644 .722 .905 r
.43084 .59411 .43639 .6001 .44596 .59774 .44043 .59155 Mtetra
.631 .712 .905 r
.44043 .59155 .44596 .59774 .45556 .59559 .45005 .5893 Mtetra
.616 .704 .908 r
.45005 .5893 .45556 .59559 .4652 .59363 .45971 .58741 Mtetra
.607 .704 .913 r
.45971 .58741 .4652 .59363 .47488 .59172 .4694 .5857 Mtetra
.602 .71 .92 r
.4694 .5857 .47488 .59172 .48459 .58972 .47913 .58406 Mtetra
.608 .726 .929 r
.47913 .58406 .48459 .58972 .49435 .58749 .4889 .58222 Mtetra
.622 .747 .936 r
.4889 .58222 .49435 .58749 .50415 .5849 .49872 .58001 Mtetra
.639 .768 .941 r
.49872 .58001 .50415 .5849 .51398 .58197 .50858 .57737 Mtetra
.658 .786 .942 r
.50858 .57737 .51398 .58197 .52386 .57871 .51848 .57426 Mtetra
.67 .796 .942 r
.51848 .57426 .52386 .57871 .53376 .57526 .52841 .57086 Mtetra
.678 .801 .941 r
.52841 .57086 .53376 .57526 .5437 .5717 .53837 .56724 Mtetra
.68 .8 .939 r
.53837 .56724 .5437 .5717 .55367 .56813 .54837 .56357 Mtetra
.678 .796 .937 r
.54837 .56357 .55367 .56813 .56367 .56462 .5584 .55994 Mtetra
.675 .791 .936 r
.5584 .55994 .56367 .56462 .57371 .5612 .56847 .55639 Mtetra
.669 .785 .936 r
.56847 .55639 .57371 .5612 .58379 .55789 .57857 .55298 Mtetra
.664 .78 .936 r
.57857 .55298 .58379 .55789 .5939 .55467 .5887 .54968 Mtetra
.659 .776 .936 r
.5887 .54968 .5939 .55467 .60405 .55154 .59888 .5465 Mtetra
.653 .774 .937 r
.59888 .5465 .60405 .55154 .61424 .5485 .60909 .54344 Mtetra
.648 .772 .939 r
.60909 .54344 .61424 .5485 .62447 .54554 .61935 .54049 Mtetra
.641 .771 .942 r
.61935 .54049 .62447 .54554 .63474 .54268 .62965 .53766 Mtetra
.635 .771 .945 r
.62965 .53766 .63474 .54268 .64505 .53991 .63999 .53496 Mtetra
.628 .772 .95 r
.63999 .53496 .64505 .53991 .65541 .53724 .65038 .53238 Mtetra
.621 .774 .954 r
.65038 .53238 .65541 .53724 .66581 .53467 .66082 .52989 Mtetra
.617 .777 .958 r
.66082 .52989 .66581 .53467 .67626 .53216 .6713 .52745 Mtetra
.619 .781 .959 r
.6713 .52745 .67626 .53216 .68675 .52964 .68182 .52495 Mtetra
.628 .786 .958 r
.68182 .52495 .68675 .52964 .69727 .52702 .69237 .52224 Mtetra
.643 .789 .952 r
.69237 .52224 .69727 .52702 .70783 .5242 .70295 .51922 Mtetra
.665 .788 .94 r
.70295 .51922 .70783 .5242 .71842 .52105 .71355 .51573 Mtetra
.683 .782 .925 r
.71355 .51573 .71842 .52105 .72902 .51754 .72415 .5118 Mtetra
.696 .771 .909 r
.72415 .5118 .72902 .51754 .73963 .51367 .73477 .50748 Mtetra
.701 .757 .896 r
.73477 .50748 .73963 .51367 .75027 .50955 .74541 .50296 Mtetra
.697 .743 .887 r
.74541 .50296 .75027 .50955 .76093 .50535 .75609 .4985 Mtetra
.69 .733 .884 r
.75609 .4985 .76093 .50535 .77163 .50118 .76681 .49422 Mtetra
.678 .726 .886 r
.76681 .49422 .77163 .50118 .78239 .4972 .77759 .4903 Mtetra
.668 .725 .892 r
.77759 .4903 .78239 .4972 .79319 .49345 .78844 .48671 Mtetra
.658 .727 .9 r
.78844 .48671 .79319 .49345 .80406 .48993 .79935 .4834 Mtetra
.651 .732 .909 r
.79935 .4834 .80406 .48993 .81498 .48659 .81032 .48027 Mtetra
.647 .739 .916 r
.81032 .48027 .81498 .48659 .82595 .48336 .82134 .47722 Mtetra
.646 .745 .922 r
.82134 .47722 .82595 .48336 .83697 .4802 .8324 .47417 Mtetra
.647 .751 .925 r
.8324 .47417 .83697 .4802 .84804 .47704 .84351 .47107 Mtetra
.649 .755 .927 r
.84351 .47107 .84804 .47704 .85915 .47387 .85465 .4679 Mtetra
.651 .757 .927 r
.85465 .4679 .85915 .47387 .8703 .47064 .86583 .46465 Mtetra
.653 .758 .926 r
.86583 .46465 .8703 .47064 .88149 .46737 .87705 .46134 Mtetra
.655 .757 .925 r
.87705 .46134 .88149 .46737 .89272 .46406 .88831 .45796 Mtetra
.656 .756 .924 r
.88831 .45796 .89272 .46406 .90398 .46071 .8996 .45454 Mtetra
.657 .755 .922 r
.8996 .45454 .90398 .46071 .9153 .45733 .91094 .4511 Mtetra
.658 .754 .921 r
.91094 .4511 .9153 .45733 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .62625 .32154 .62116 Mtetra
.652 .752 .923 r
.32154 .62116 .32738 .62625 .33662 .62352 .3308 .61846 Mtetra
.652 .754 .924 r
.3308 .61846 .33662 .62352 .34589 .62076 .34008 .61574 Mtetra
.653 .756 .925 r
.34008 .61574 .34589 .62076 .35519 .61796 .34941 .61298 Mtetra
.655 .759 .926 r
.34941 .61298 .35519 .61796 .36453 .61512 .35876 .61018 Mtetra
.657 .762 .927 r
.35876 .61018 .36453 .61512 .3739 .61221 .36815 .6073 Mtetra
.661 .765 .927 r
.36815 .6073 .3739 .61221 .38331 .60922 .37758 .60432 Mtetra
.665 .767 .926 r
.37758 .60432 .38331 .60922 .39275 .60617 .38705 .60123 Mtetra
.67 .767 .923 r
.38705 .60123 .39275 .60617 .40223 .60307 .39655 .59802 Mtetra
.672 .764 .919 r
.39655 .59802 .40223 .60307 .41174 .59997 .40609 .59474 Mtetra
.673 .758 .914 r
.40609 .59474 .41174 .59997 .42128 .59695 .41565 .59143 Mtetra
.668 .747 .91 r
.41565 .59143 .42128 .59695 .43084 .59411 .42525 .58826 Mtetra
.657 .733 .905 r
.42525 .58826 .43084 .59411 .44043 .59155 .43487 .58534 Mtetra
.642 .716 .902 r
.43487 .58534 .44043 .59155 .45005 .5893 .44452 .58282 Mtetra
.621 .701 .902 r
.44452 .58282 .45005 .5893 .45971 .58741 .45419 .58081 Mtetra
.604 .691 .904 r
.45419 .58081 .45971 .58741 .4694 .5857 .46389 .57918 Mtetra
.59 .689 .911 r
.46389 .57918 .4694 .5857 .47913 .58406 .47363 .57786 Mtetra
.59 .701 .92 r
.47363 .57786 .47913 .58406 .4889 .58222 .48342 .57646 Mtetra
.601 .722 .93 r
.48342 .57646 .4889 .58222 .49872 .58001 .49325 .57475 Mtetra
.619 .748 .939 r
.49325 .57475 .49872 .58001 .50858 .57737 .50313 .57256 Mtetra
.643 .775 .943 r
.50313 .57256 .50858 .57737 .51848 .57426 .51306 .56978 Mtetra
.661 .794 .945 r
.51306 .56978 .51848 .57426 .52841 .57086 .52302 .56655 Mtetra
.675 .805 .945 r
.52302 .56655 .52841 .57086 .53837 .56724 .53301 .56297 Mtetra
.681 .809 .944 r
.53301 .56297 .53837 .56724 .54837 .56357 .54304 .55924 Mtetra
.681 .808 .943 r
.54304 .55924 .54837 .56357 .5584 .55994 .55309 .55551 Mtetra
.678 .804 .942 r
.55309 .55551 .5584 .55994 .56847 .55639 .56319 .55184 Mtetra
.672 .798 .942 r
.56319 .55184 .56847 .55639 .57857 .55298 .57331 .54832 Mtetra
.665 .792 .942 r
.57331 .54832 .57857 .55298 .5887 .54968 .58348 .54493 Mtetra
.658 .788 .943 r
.58348 .54493 .5887 .54968 .59888 .5465 .59368 .5417 Mtetra
.651 .784 .945 r
.59368 .5417 .59888 .5465 .60909 .54344 .60392 .53862 Mtetra
.644 .782 .947 r
.60392 .53862 .60909 .54344 .61935 .54049 .61421 .53568 Mtetra
.636 .781 .951 r
.61421 .53568 .61935 .54049 .62965 .53766 .62454 .5329 Mtetra
.628 .781 .955 r
.62454 .5329 .62965 .53766 .63999 .53496 .63491 .53027 Mtetra
.619 .781 .959 r
.63491 .53027 .63999 .53496 .65038 .53238 .64533 .52777 Mtetra
.613 .784 .963 r
.64533 .52777 .65038 .53238 .66082 .52989 .6558 .52535 Mtetra
.611 .787 .965 r
.6558 .52535 .66082 .52989 .6713 .52745 .66631 .52292 Mtetra
.618 .791 .964 r
.66631 .52292 .6713 .52745 .68182 .52495 .67686 .52034 Mtetra
.636 .795 .958 r
.67686 .52034 .68182 .52495 .69237 .52224 .68743 .51742 Mtetra
.659 .793 .947 r
.68743 .51742 .69237 .52224 .70295 .51922 .69803 .51404 Mtetra
.685 .788 .929 r
.69803 .51404 .70295 .51922 .71355 .51573 .70862 .51004 Mtetra
.701 .775 .909 r
.70862 .51004 .71355 .51573 .72415 .5118 .71923 .50556 Mtetra
.709 .759 .891 r
.71923 .50556 .72415 .5118 .73477 .50748 .72985 .50074 Mtetra
.708 .743 .879 r
.72985 .50074 .73477 .50748 .74541 .50296 .74049 .49585 Mtetra
.698 .729 .874 r
.74049 .49585 .74541 .50296 .75609 .4985 .75118 .49126 Mtetra
.686 .721 .877 r
.75118 .49126 .75609 .4985 .76681 .49422 .76194 .48706 Mtetra
.669 .718 .885 r
.76194 .48706 .76681 .49422 .77759 .4903 .77277 .48338 Mtetra
.656 .721 .896 r
.77277 .48338 .77759 .4903 .78844 .48671 .78367 .48011 Mtetra
.646 .728 .909 r
.78367 .48011 .78844 .48671 .79935 .4834 .79463 .4771 Mtetra
.64 .737 .919 r
.79463 .4771 .79935 .4834 .81032 .48027 .80566 .47422 Mtetra
.639 .747 .927 r
.80566 .47422 .81032 .48027 .82134 .47722 .81672 .47132 Mtetra
.641 .754 .931 r
.81672 .47132 .82134 .47722 .8324 .47417 .82782 .46835 Mtetra
.645 .759 .932 r
.82782 .46835 .8324 .47417 .84351 .47107 .83896 .46524 Mtetra
.649 .762 .932 r
.83896 .46524 .84351 .47107 .85465 .4679 .85013 .46203 Mtetra
.653 .762 .93 r
.85013 .46203 .85465 .4679 .86583 .46465 .86134 .4587 Mtetra
.655 .761 .928 r
.86134 .4587 .86583 .46465 .87705 .46134 .87259 .4553 Mtetra
.657 .76 .925 r
.87259 .4553 .87705 .46134 .88831 .45796 .88387 .45184 Mtetra
.658 .758 .924 r
.88387 .45184 .88831 .45796 .8996 .45454 .89519 .44834 Mtetra
.659 .756 .922 r
.89519 .44834 .8996 .45454 .91094 .4511 .90655 .44482 Mtetra
.659 .754 .92 r
.90655 .44482 .91094 .4511 .92232 .44763 .91796 .44128 Mtetra
.65 .75 .923 r
.30643 .61871 .31232 .62385 .32154 .62116 .31567 .61604 Mtetra
.65 .751 .924 r
.31567 .61604 .32154 .62116 .3308 .61846 .32494 .61336 Mtetra
.65 .753 .925 r
.32494 .61336 .3308 .61846 .34008 .61574 .33424 .61068 Mtetra
.65 .755 .926 r
.33424 .61068 .34008 .61574 .34941 .61298 .34358 .60798 Mtetra
.65 .758 .928 r
.34358 .60798 .34941 .61298 .35876 .61018 .35295 .60525 Mtetra
.652 .762 .93 r
.35295 .60525 .35876 .61018 .36815 .6073 .36236 .60245 Mtetra
.656 .767 .931 r
.36236 .60245 .36815 .6073 .37758 .60432 .37181 .59955 Mtetra
.662 .772 .932 r
.37181 .59955 .37758 .60432 .38705 .60123 .38129 .59652 Mtetra
.669 .777 .93 r
.38129 .59652 .38705 .60123 .39655 .59802 .39082 .59329 Mtetra
.676 .779 .927 r
.39082 .59329 .39655 .59802 .40609 .59474 .40038 .58988 Mtetra
.683 .776 .921 r
.40038 .58988 .40609 .59474 .41565 .59143 .40998 .5863 Mtetra
.682 .766 .915 r
.40998 .5863 .41565 .59143 .42525 .58826 .41961 .58273 Mtetra
.676 .751 .907 r
.41961 .58273 .42525 .58826 .43487 .58534 .42927 .57929 Mtetra
.66 .729 .9 r
.42927 .57929 .43487 .58534 .44452 .58282 .43894 .57627 Mtetra
.635 .705 .896 r
.43894 .57627 .44452 .58282 .45419 .58081 .44864 .57388 Mtetra
.611 .684 .895 r
.44864 .57388 .45419 .58081 .46389 .57918 .45836 .57212 Mtetra
.584 .67 .899 r
.45836 .57212 .46389 .57918 .47363 .57786 .46812 .57099 Mtetra
.573 .673 .907 r
.46812 .57099 .47363 .57786 .48342 .57646 .47791 .57004 Mtetra
.575 .689 .919 r
.47791 .57004 .48342 .57646 .49325 .57475 .48776 .56895 Mtetra
.592 .719 .932 r
.48776 .56895 .49325 .57475 .50313 .57256 .49765 .5674 Mtetra
.62 .754 .942 r
.49765 .5674 .50313 .57256 .51306 .56978 .5076 .56513 Mtetra
.644 .784 .948 r
.5076 .56513 .51306 .56978 .52302 .56655 .51758 .56226 Mtetra
.666 .806 .95 r
.51758 .56226 .52302 .56655 .53301 .56297 .5276 .55885 Mtetra
.677 .816 .95 r
.5276 .55885 .53301 .56297 .54304 .55924 .53766 .55517 Mtetra
.681 .82 .95 r
.53766 .55517 .54304 .55924 .55309 .55551 .54775 .55137 Mtetra
.679 .818 .95 r
.54775 .55137 .55309 .55551 .56319 .55184 .55787 .5476 Mtetra
.673 .813 .95 r
.55787 .5476 .56319 .55184 .57331 .54832 .56802 .54397 Mtetra
.666 .807 .951 r
.56802 .54397 .57331 .54832 .58348 .54493 .57822 .5405 Mtetra
.657 .802 .952 r
.57822 .5405 .58348 .54493 .59368 .5417 .58845 .53721 Mtetra
.648 .798 .954 r
.58845 .53721 .59368 .5417 .60392 .53862 .59872 .53411 Mtetra
.639 .795 .957 r
.59872 .53411 .60392 .53862 .61421 .53568 .60904 .53119 Mtetra
.628 .793 .961 r
.60904 .53119 .61421 .53568 .62454 .5329 .6194 .52846 Mtetra
.618 .793 .965 r
.6194 .52846 .62454 .5329 .63491 .53027 .6298 .52589 Mtetra
.609 .793 .97 r
.6298 .52589 .63491 .53027 .64533 .52777 .64026 .52346 Mtetra
.605 .795 .972 r
.64026 .52346 .64533 .52777 .6558 .52535 .65075 .52106 Mtetra
.61 .799 .972 r
.65075 .52106 .6558 .52535 .66631 .52292 .66129 .51855 Mtetra
.625 .802 .967 r
.66129 .51855 .66631 .52292 .67686 .52034 .67186 .51576 Mtetra
.654 .803 .954 r
.67186 .51576 .67686 .52034 .68743 .51742 .68245 .51242 Mtetra
.682 .796 .935 r
.68245 .51242 .68743 .51742 .69803 .51404 .69305 .50847 Mtetra
.708 .782 .91 r
.69305 .50847 .69803 .51404 .70862 .51004 .70364 .5038 Mtetra
.719 .762 .886 r
.70364 .5038 .70862 .51004 .71923 .50556 .71424 .49863 Mtetra
.719 .741 .869 r
.71424 .49863 .71923 .50556 .72985 .50074 .72485 .49332 Mtetra
.71 .725 .861 r
.72485 .49332 .72985 .50074 .74049 .49585 .73551 .48818 Mtetra
.692 .711 .864 r
.73551 .48818 .74049 .49585 .75118 .49126 .74623 .48368 Mtetra
.674 .708 .874 r
.74623 .48368 .75118 .49126 .76194 .48706 .75704 .47982 Mtetra
.653 .711 .89 r
.75704 .47982 .76194 .48706 .77277 .48338 .76793 .47662 Mtetra
.638 .72 .907 r
.76793 .47662 .77277 .48338 .78367 .48011 .7789 .47384 Mtetra
.63 .735 .923 r
.7789 .47384 .78367 .48011 .79463 .4771 .78992 .4712 Mtetra
.627 .748 .934 r
.78992 .4712 .79463 .4771 .80566 .47422 .80099 .46856 Mtetra
.632 .761 .94 r
.80099 .46856 .80566 .47422 .81672 .47132 .8121 .46575 Mtetra
.638 .767 .941 r
.8121 .46575 .81672 .47132 .82782 .46835 .82324 .46275 Mtetra
.646 .77 .939 r
.82324 .46275 .82782 .46835 .83896 .46524 .8344 .45955 Mtetra
.652 .77 .935 r
.8344 .45955 .83896 .46524 .85013 .46203 .84559 .4562 Mtetra
.656 .767 .931 r
.84559 .4562 .85013 .46203 .86134 .4587 .85682 .45275 Mtetra
.659 .765 .928 r
.85682 .45275 .86134 .4587 .87259 .4553 .86809 .44923 Mtetra
.66 .761 .925 r
.86809 .44923 .87259 .4553 .88387 .45184 .8794 .44567 Mtetra
.661 .759 .923 r
.8794 .44567 .88387 .45184 .89519 .44834 .89074 .44209 Mtetra
.661 .756 .921 r
.89074 .44209 .89519 .44834 .90655 .44482 .90213 .43849 Mtetra
.66 .755 .92 r
.90213 .43849 .90655 .44482 .91796 .44128 .91357 .43489 Mtetra
.65 .75 .923 r
.3005 .61354 .30643 .61871 .31567 .61604 .30976 .61085 Mtetra
.649 .75 .923 r
.30976 .61085 .31567 .61604 .32494 .61336 .31905 .60817 Mtetra
.648 .75 .924 r
.31905 .60817 .32494 .61336 .33424 .61068 .32837 .60549 Mtetra
.648 .751 .925 r
.32837 .60549 .33424 .61068 .34358 .60798 .33772 .60283 Mtetra
.647 .753 .927 r
.33772 .60283 .34358 .60798 .35295 .60525 .34711 .60017 Mtetra
.647 .757 .929 r
.34711 .60017 .35295 .60525 .36236 .60245 .35654 .59748 Mtetra
.649 .762 .932 r
.35654 .59748 .36236 .60245 .37181 .59955 .366 .59473 Mtetra
.654 .77 .934 r
.366 .59473 .37181 .59955 .38129 .59652 .3755 .59185 Mtetra
.662 .778 .935 r
.3755 .59185 .38129 .59652 .39082 .59329 .38504 .58875 Mtetra
.673 .787 .935 r
.38504 .58875 .39082 .59329 .40038 .58988 .39462 .58538 Mtetra
.687 .792 .93 r
.39462 .58538 .40038 .58988 .40998 .5863 .40425 .58168 Mtetra
.694 .789 .924 r
.40425 .58168 .40998 .5863 .41961 .58273 .41392 .57779 Mtetra
.697 .779 .914 r
.41392 .57779 .41961 .58273 .42927 .57929 .42361 .5738 Mtetra
.685 .756 .906 r
.42361 .5738 .42927 .57929 .43894 .57627 .43333 .5701 Mtetra
.661 .727 .898 r
.43333 .5701 .43894 .57627 .44864 .57388 .44306 .56701 Mtetra
.63 .694 .891 r
.44306 .56701 .44864 .57388 .45836 .57212 .45281 .56474 Mtetra
.591 .664 .89 r
.45281 .56474 .45836 .57212 .46812 .57099 .46258 .56347 Mtetra
.567 .651 .892 r
.46258 .56347 .46812 .57099 .47791 .57004 .47238 .56275 Mtetra
.553 .653 .901 r
.47238 .56275 .47791 .57004 .48776 .56895 .48224 .56227 Mtetra
.562 .677 .916 r
.48224 .56227 .48776 .56895 .49765 .5674 .49214 .56147 Mtetra
.589 .715 .931 r
.49214 .56147 .49765 .5674 .5076 .56513 .5021 .55995 Mtetra
.618 .755 .944 r
.5021 .55995 .5076 .56513 .51758 .56226 .51211 .5577 Mtetra
.648 .791 .95 r
.51211 .5577 .51758 .56226 .5276 .55885 .52216 .55469 Mtetra
.666 .813 .954 r
.52216 .55469 .5276 .55885 .53766 .55517 .53224 .55122 Mtetra
.676 .826 .955 r
.53224 .55122 .53766 .55517 .54775 .55137 .54236 .54749 Mtetra
.677 .83 .957 r
.54236 .54749 .54775 .55137 .55787 .5476 .55251 .5437 Mtetra
.672 .828 .958 r
.55251 .5437 .55787 .5476 .56802 .54397 .5627 .54 Mtetra
.665 .824 .96 r
.5627 .54 .56802 .54397 .57822 .5405 .57292 .53646 Mtetra
.654 .819 .963 r
.57292 .53646 .57822 .5405 .58845 .53721 .58318 .53312 Mtetra
.643 .815 .966 r
.58318 .53312 .58845 .53721 .59872 .53411 .59349 .53 Mtetra
.631 .811 .969 r
.59349 .53 .59872 .53411 .60904 .53119 .60383 .52709 Mtetra
.619 .809 .973 r
.60383 .52709 .60904 .53119 .6194 .52846 .61423 .52439 Mtetra
.608 .807 .976 r
.61423 .52439 .6194 .52846 .6298 .52589 .62466 .52185 Mtetra
.601 .807 .979 r
.62466 .52185 .6298 .52589 .64026 .52346 .63515 .5194 Mtetra
.604 .808 .978 r
.63515 .5194 .64026 .52346 .65075 .52106 .64568 .5169 Mtetra
.62 .81 .973 r
.64568 .5169 .65075 .52106 .66129 .51855 .65624 .51413 Mtetra
.647 .808 .96 r
.65624 .51413 .66129 .51855 .67186 .51576 .66682 .51089 Mtetra
.684 .801 .938 r
.66682 .51089 .67186 .51576 .68245 .51242 .67741 .50689 Mtetra
.71 .784 .91 r
.67741 .50689 .68245 .51242 .69305 .50847 .688 .50213 Mtetra
.727 .762 .88 r
.688 .50213 .69305 .50847 .70364 .5038 .69858 .49665 Mtetra
.73 .739 .859 r
.69858 .49665 .70364 .5038 .71424 .49863 .70916 .49082 Mtetra
.719 .718 .848 r
.70916 .49082 .71424 .49863 .72485 .49332 .71979 .48522 Mtetra
.703 .705 .849 r
.71979 .48522 .72485 .49332 .73551 .48818 .73047 .48018 Mtetra
.676 .698 .863 r
.73047 .48018 .73551 .48818 .74623 .48368 .74126 .47616 Mtetra
.652 .702 .883 r
.74126 .47616 .74623 .48368 .75704 .47982 .75214 .47298 Mtetra
.629 .714 .908 r
.75214 .47298 .75704 .47982 .76793 .47662 .7631 .47042 Mtetra
.612 .731 .93 r
.7631 .47042 .76793 .47662 .7789 .47384 .77414 .46817 Mtetra
.612 .752 .945 r
.77414 .46817 .7789 .47384 .78992 .4712 .78522 .46581 Mtetra
.617 .766 .951 r
.78522 .46581 .78992 .4712 .80099 .46856 .79633 .46326 Mtetra
.631 .776 .95 r
.79633 .46326 .80099 .46856 .8121 .46575 .80747 .46036 Mtetra
.643 .779 .946 r
.80747 .46036 .8121 .46575 .82324 .46275 .81862 .45719 Mtetra
.653 .776 .939 r
.81862 .45719 .82324 .46275 .8344 .45955 .8298 .45379 Mtetra
.659 .772 .933 r
.8298 .45379 .8344 .45955 .84559 .4562 .84101 .45025 Mtetra
.662 .766 .927 r
.84101 .45025 .84559 .4562 .85682 .45275 .85226 .44664 Mtetra
.663 .762 .923 r
.85226 .44664 .85682 .45275 .86809 .44923 .86355 .44299 Mtetra
.662 .758 .921 r
.86355 .44299 .86809 .44923 .8794 .44567 .87488 .43935 Mtetra
.662 .756 .92 r
.87488 .43935 .8794 .44567 .89074 .44209 .88626 .43571 Mtetra
.661 .754 .919 r
.88626 .43571 .89074 .44209 .90213 .43849 .89768 .43208 Mtetra
.89768 .43208 .90213 .43849 .91357 .43489 .90915 .42846 Mtetra
.652 .75 .922 r
.29453 .60833 .3005 .61354 .30976 .61085 .30381 .60558 Mtetra
.651 .749 .921 r
.30381 .60558 .30976 .61085 .31905 .60817 .31312 .60284 Mtetra
.65 .747 .921 r
.31312 .60284 .31905 .60817 .32837 .60549 .32247 .60013 Mtetra
.648 .746 .921 r
.32247 .60013 .32837 .60549 .33772 .60283 .33184 .59746 Mtetra
.644 .745 .922 r
.33184 .59746 .33772 .60283 .34711 .60017 .34124 .59485 Mtetra
.642 .747 .925 r
.34124 .59485 .34711 .60017 .35654 .59748 .35068 .59226 Mtetra
.64 .751 .929 r
.35068 .59226 .35654 .59748 .366 .59473 .36015 .58971 Mtetra
.642 .76 .934 r
.36015 .58971 .366 .59473 .3755 .59185 .36966 .58707 Mtetra
.648 .772 .939 r
.36966 .58707 .3755 .59185 .38504 .58875 .37921 .58427 Mtetra
.66 .788 .943 r
.37921 .58427 .38504 .58875 .39462 .58538 .38881 .58117 Mtetra
.679 .803 .942 r
.38881 .58117 .39462 .58538 .40425 .58168 .39846 .5776 Mtetra
.697 .813 .937 r
.39846 .5776 .40425 .58168 .41392 .57779 .40815 .5736 Mtetra
.715 .812 .926 r
.40815 .5736 .41392 .57779 .42361 .5738 .41789 .56912 Mtetra
.713 .794 .914 r
.41789 .56912 .42361 .5738 .43333 .5701 .42765 .56465 Mtetra
.699 .763 .902 r
.42765 .56465 .43333 .5701 .44306 .56701 .43744 .56052 Mtetra
.665 .72 .89 r
.43744 .56052 .44306 .56701 .45281 .56474 .44722 .55731 Mtetra
.615 .674 .883 r
.44722 .55731 .45281 .56474 .46258 .56347 .45702 .55541 Mtetra
.576 .64 .877 r
.45702 .55541 .46258 .56347 .47238 .56275 .46684 .55454 Mtetra
.541 .62 .881 r
.46684 .55454 .47238 .56275 .48224 .56227 .4767 .5545 Mtetra
.535 .631 .893 r
.4767 .5545 .48224 .56227 .49214 .56147 .48661 .55447 Mtetra
.552 .664 .911 r
.48661 .55447 .49214 .56147 .5021 .55995 .49657 .55391 Mtetra
.58 .71 .932 r
.49657 .55391 .5021 .55995 .51211 .5577 .5066 .55256 Mtetra
.618 .759 .946 r
.5066 .55256 .51211 .5577 .52216 .55469 .51667 .55024 Mtetra
.644 .796 .956 r
.51667 .55024 .52216 .55469 .53224 .55122 .52679 .54725 Mtetra
.663 .823 .96 r
.52679 .54725 .53224 .55122 .54236 .54749 .53694 .54376 Mtetra
.669 .836 .963 r
.53694 .54376 .54236 .54749 .55251 .5437 .54712 .54008 Mtetra
.667 .841 .966 r
.54712 .54008 .55251 .5437 .5627 .54 .55734 .53639 Mtetra
.66 .84 .969 r
.55734 .53639 .5627 .54 .57292 .53646 .56759 .53282 Mtetra
.649 .837 .973 r
.56759 .53282 .57292 .53646 .58318 .53312 .57789 .52945 Mtetra
.636 .833 .976 r
.57789 .52945 .58318 .53312 .59349 .53 .58822 .52631 Mtetra
.622 .829 .98 r
.58822 .52631 .59349 .53 .60383 .52709 .5986 .52339 Mtetra
.609 .825 .983 r
.5986 .52339 .60383 .52709 .61423 .52439 .60902 .52068 Mtetra
.601 .822 .985 r
.60902 .52068 .61423 .52439 .62466 .52185 .61949 .51809 Mtetra
.601 .821 .984 r
.61949 .51809 .62466 .52185 .63515 .5194 .63001 .5155 Mtetra
.615 .82 .979 r
.63001 .5155 .63515 .5194 .64568 .5169 .64056 .51271 Mtetra
.646 .818 .966 r
.64056 .51271 .64568 .5169 .65624 .51413 .65113 .50942 Mtetra
.681 .808 .943 r
.65113 .50942 .65624 .51413 .66682 .51089 .66171 .50544 Mtetra
.717 .789 .909 r
.66171 .50544 .66682 .51089 .67741 .50689 .67229 .50048 Mtetra
.734 .762 .875 r
.67229 .50048 .67741 .50689 .688 .50213 .68286 .4947 Mtetra
.739 .734 .847 r
.68286 .4947 .688 .50213 .69858 .49665 .69342 .48838 Mtetra
.731 .711 .832 r
.69342 .48838 .69858 .49665 .70916 .49082 .70401 .48205 Mtetra
.708 .692 .832 r
.70401 .48205 .70916 .49082 .71979 .48522 .71467 .47656 Mtetra
.684 .685 .845 r
.71467 .47656 .71979 .48522 .73047 .48018 .72541 .47212 Mtetra
.648 .686 .872 r
.72541 .47212 .73047 .48018 .74126 .47616 .73628 .46902 Mtetra
.614 .699 .905 r
.73628 .46902 .74126 .47616 .75214 .47298 .74725 .46686 Mtetra
.591 .726 .937 r
.74725 .46686 .75214 .47298 .7631 .47042 .7583 .46506 Mtetra
.579 .752 .959 r
.7583 .46506 .7631 .47042 .77414 .46817 .76941 .46326 Mtetra
.596 .779 .968 r
.76941 .46326 .77414 .46817 .78522 .46581 .78053 .46099 Mtetra
.617 .791 .965 r
.78053 .46099 .78522 .46581 .79633 .46326 .79166 .45825 Mtetra
.641 .794 .956 r
.79166 .45825 .79633 .46326 .80747 .46036 .8028 .45504 Mtetra
.657 .788 .944 r
.8028 .45504 .80747 .46036 .81862 .45719 .81396 .45151 Mtetra
.665 .777 .933 r
.81396 .45151 .81862 .45719 .8298 .45379 .82515 .44781 Mtetra
.668 .768 .925 r
.82515 .44781 .8298 .45379 .84101 .45025 .83637 .44402 Mtetra
.667 .76 .92 r
.83637 .44402 .84101 .45025 .85226 .44664 .84764 .44026 Mtetra
.666 .755 .917 r
.84764 .44026 .85226 .44664 .86355 .44299 .85895 .43652 Mtetra
.663 .751 .916 r
.85895 .43652 .86355 .44299 .87488 .43935 .87032 .43284 Mtetra
.661 .75 .916 r
.87032 .43284 .87488 .43935 .88626 .43571 .88173 .4292 Mtetra
.66 .75 .917 r
.88173 .4292 .88626 .43571 .89768 .43208 .89319 .42558 Mtetra
.659 .751 .918 r
.89319 .42558 .89768 .43208 .90915 .42846 .90469 .42197 Mtetra
.656 .751 .92 r
.28853 .60308 .29453 .60833 .30381 .60558 .29783 .60023 Mtetra
.655 .748 .918 r
.29783 .60023 .30381 .60558 .31312 .60284 .30717 .59739 Mtetra
.653 .745 .917 r
.30717 .59739 .31312 .60284 .32247 .60013 .31653 .59458 Mtetra
.65 .741 .916 r
.31653 .59458 .32247 .60013 .33184 .59746 .32593 .59184 Mtetra
.646 .738 .916 r
.32593 .59184 .33184 .59746 .34124 .59485 .33535 .58918 Mtetra
.642 .736 .917 r
.33535 .58918 .34124 .59485 .35068 .59226 .34481 .58662 Mtetra
.636 .735 .92 r
.34481 .58662 .35068 .59226 .36015 .58971 .35429 .58418 Mtetra
.633 .74 .925 r
.35429 .58418 .36015 .58971 .36966 .58707 .36381 .58178 Mtetra
.632 .749 .932 r
.36381 .58178 .36966 .58707 .37921 .58427 .37336 .57937 Mtetra
.64 .767 .94 r
.37336 .57937 .37921 .58427 .38881 .58117 .38296 .57672 Mtetra
.657 .79 .945 r
.38296 .57672 .38881 .58117 .39846 .5776 .39262 .57363 Mtetra
.683 .816 .947 r
.39262 .57363 .39846 .5776 .40815 .5736 .40233 .56992 Mtetra
.716 .835 .938 r
.40233 .56992 .40815 .5736 .41789 .56912 .4121 .56539 Mtetra
.732 .835 .928 r
.4121 .56539 .41789 .56912 .42765 .56465 .42191 .56041 Mtetra
.738 .816 .913 r
.42191 .56041 .42765 .56465 .43744 .56052 .43174 .55521 Mtetra
.711 .772 .9 r
.43174 .55521 .43744 .56052 .44722 .55731 .44159 .5507 Mtetra
.662 .717 .889 r
.44159 .5507 .44722 .55731 .45702 .55541 .45143 .54753 Mtetra
.608 .66 .875 r
.45143 .54753 .45702 .55541 .46684 .55454 .46128 .5458 Mtetra
.55 .612 .868 r
.46128 .5458 .46684 .55454 .4767 .5545 .47114 .54562 Mtetra
.525 .597 .868 r
.47114 .54562 .4767 .5545 .48661 .55447 .48106 .54602 Mtetra
.522 .608 .88 r
.48106 .54602 .48661 .55447 .49657 .55391 .49103 .54639 Mtetra
.541 .645 .901 r
.49103 .54639 .49657 .55391 .5066 .55256 .50106 .54613 Mtetra
.58 .698 .923 r
.50106 .54613 .5066 .55256 .51667 .55024 .51115 .54482 Mtetra
.612 .748 .942 r
.51115 .54482 .51667 .55024 .52679 .54725 .52129 .54265 Mtetra
.641 .791 .954 r
.52129 .54265 .52679 .54725 .53694 .54376 .53147 .53971 Mtetra
.654 .819 .963 r
.53147 .53971 .53694 .54376 .54712 .54008 .54168 .53638 Mtetra
.657 .836 .969 r
.54168 .53638 .54712 .54008 .55734 .53639 .55193 .53287 Mtetra
.653 .844 .973 r
.55193 .53287 .55734 .53639 .56759 .53282 .56222 .52938 Mtetra
.642 .845 .978 r
.56222 .52938 .56759 .53282 .57789 .52945 .57255 .52603 Mtetra
.63 .843 .982 r
.57255 .52603 .57789 .52945 .58822 .52631 .58292 .52287 Mtetra
.618 .839 .984 r
.58292 .52287 .58822 .52631 .5986 .52339 .59333 .51989 Mtetra
.609 .835 .986 r
.59333 .51989 .5986 .52339 .60902 .52068 .60378 .51706 Mtetra
.61 .831 .984 r
.60378 .51706 .60902 .52068 .61949 .51809 .61428 .51425 Mtetra
.624 .827 .978 r
.61428 .51425 .61949 .51809 .63001 .5155 .62481 .51127 Mtetra
.651 .819 .964 r
.62481 .51127 .63001 .5155 .64056 .51271 .63538 .50788 Mtetra
.689 .806 .937 r
.63538 .50788 .64056 .51271 .65113 .50942 .64595 .50371 Mtetra
.718 .781 .902 r
.64595 .50371 .65113 .50942 .66171 .50544 .65652 .49867 Mtetra
.74 .753 .863 r
.65652 .49867 .66171 .50544 .67229 .50048 .66708 .49256 Mtetra
.744 .724 .833 r
.66708 .49256 .67229 .50048 .68286 .4947 .67763 .48579 Mtetra
.735 .698 .816 r
.67763 .48579 .68286 .4947 .69342 .48838 .68819 .47898 Mtetra
.719 .683 .814 r
.68819 .47898 .69342 .48838 .70401 .48205 .69881 .47275 Mtetra
.685 .671 .831 r
.69881 .47275 .70401 .48205 .71467 .47656 .70953 .46808 Mtetra
.649 .676 .862 r
.70953 .46808 .71467 .47656 .72541 .47212 .72037 .4649 Mtetra
.6 .691 .906 r
.72037 .4649 .72541 .47212 .73628 .46902 .73135 .46308 Mtetra
.553 .716 .949 r
.73135 .46308 .73628 .46902 .74725 .46686 .74242 .46198 Mtetra
.541 .756 .976 r
.74242 .46198 .74725 .46686 .7583 .46506 .75354 .46067 Mtetra
.554 .785 .985 r
.75354 .46067 .7583 .46506 .76941 .46326 .76468 .45889 Mtetra
.602 .806 .978 r
.76468 .45889 .76941 .46326 .78053 .46099 .77581 .45626 Mtetra
.64 .806 .963 r
.77581 .45626 .78053 .46099 .79166 .45825 .78694 .45299 Mtetra
.664 .793 .944 r
.78694 .45299 .79166 .45825 .8028 .45504 .79807 .44927 Mtetra
.675 .778 .928 r
.79807 .44927 .8028 .45504 .81396 .45151 .80923 .44529 Mtetra
.675 .763 .917 r
.80923 .44529 .81396 .45151 .82515 .44781 .82042 .4413 Mtetra
.674 .753 .911 r
.82042 .4413 .82515 .44781 .83637 .44402 .83166 .43734 Mtetra
.669 .746 .908 r
.83166 .43734 .83637 .44402 .84764 .44026 .84296 .43351 Mtetra
.665 .743 .908 r
.84296 .43351 .84764 .44026 .85895 .43652 .8543 .42977 Mtetra
.661 .742 .91 r
.8543 .42977 .85895 .43652 .87032 .43284 .8657 .42613 Mtetra
.659 .743 .913 r
.8657 .42613 .87032 .43284 .88173 .4292 .87716 .42254 Mtetra
.657 .746 .915 r
.87716 .42254 .88173 .4292 .89319 .42558 .88866 .41899 Mtetra
.656 .749 .918 r
.88866 .41899 .89319 .42558 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .918 r
.28248 .59781 .28853 .60308 .29783 .60023 .29181 .59483 Mtetra
.66 .749 .915 r
.29181 .59483 .29783 .60023 .30717 .59739 .30117 .59184 Mtetra
.659 .744 .912 r
.30117 .59184 .30717 .59739 .31653 .59458 .31057 .58888 Mtetra
.656 .738 .91 r
.31057 .58888 .31653 .59458 .32593 .59184 .31999 .58597 Mtetra
.652 .732 .908 r
.31999 .58597 .32593 .59184 .33535 .58918 .32944 .58315 Mtetra
.646 .725 .906 r
.32944 .58315 .33535 .58918 .34481 .58662 .33892 .58048 Mtetra
.637 .72 .907 r
.33892 .58048 .34481 .58662 .35429 .58418 .34842 .57802 Mtetra
.629 .717 .91 r
.34842 .57802 .35429 .58418 .36381 .58178 .35795 .57576 Mtetra
.618 .719 .918 r
.35795 .57576 .36381 .58178 .37336 .57937 .36751 .57371 Mtetra
.616 .732 .929 r
.36751 .57371 .37336 .57937 .38296 .57672 .3771 .57164 Mtetra
.621 .757 .943 r
.3771 .57164 .38296 .57672 .39262 .57363 .38675 .56937 Mtetra
.646 .797 .955 r
.38675 .56937 .39262 .57363 .40233 .56992 .39645 .56645 Mtetra
.688 .84 .956 r
.39645 .56645 .40233 .56992 .4121 .56539 .40623 .5625 Mtetra
.729 .871 .947 r
.40623 .5625 .4121 .56539 .42191 .56041 .41607 .55753 Mtetra
.768 .874 .925 r
.41607 .55753 .42191 .56041 .43174 .55521 .42597 .5515 Mtetra
.763 .841 .911 r
.42597 .5515 .43174 .55521 .44159 .5507 .43588 .54555 Mtetra
.729 .784 .897 r
.43588 .54555 .44159 .5507 .45143 .54753 .44579 .54047 Mtetra
.667 .707 .877 r
.44579 .54047 .45143 .54753 .46128 .5458 .45569 .53707 Mtetra
.589 .631 .861 r
.45569 .53707 .46128 .5458 .47114 .54562 .46558 .53589 Mtetra
.54 .585 .848 r
.46558 .53589 .47114 .54562 .48106 .54602 .4755 .53608 Mtetra
.507 .564 .848 r
.4755 .53608 .48106 .54602 .49103 .54639 .48547 .5371 Mtetra
.509 .581 .863 r
.48547 .5371 .49103 .54639 .50106 .54613 .4955 .53792 Mtetra
.537 .624 .886 r
.4955 .53792 .50106 .54613 .51115 .54482 .50559 .53786 Mtetra
.569 .677 .913 r
.50559 .53786 .51115 .54482 .52129 .54265 .51575 .53686 Mtetra
.607 .734 .935 r
.51575 .53686 .52129 .54265 .53147 .53971 .52595 .53483 Mtetra
.629 .778 .953 r
.52595 .53483 .53147 .53971 .54168 .53638 .5362 .53215 Mtetra
.642 .811 .964 r
.5362 .53215 .54168 .53638 .55193 .53287 .54648 .52905 Mtetra
.644 .829 .972 r
.54648 .52905 .55193 .53287 .56222 .52938 .55681 .52578 Mtetra
.639 .839 .977 r
.55681 .52578 .56222 .52938 .57255 .52603 .56717 .52252 Mtetra
.631 .841 .981 r
.56717 .52252 .57255 .52603 .58292 .52287 .57757 .51934 Mtetra
.626 .839 .982 r
.57757 .51934 .58292 .52287 .59333 .51989 .58801 .51624 Mtetra
.627 .835 .98 r
.58801 .51624 .59333 .51989 .60378 .51706 .59849 .51314 Mtetra
.64 .828 .973 r
.59849 .51314 .60378 .51706 .61428 .51425 .60901 .50988 Mtetra
.666 .818 .956 r
.60901 .50988 .61428 .51425 .62481 .51127 .61956 .5062 Mtetra
.696 .798 .928 r
.61956 .5062 .62481 .51127 .63538 .50788 .63012 .50185 Mtetra
.726 .773 .89 r
.63012 .50185 .63538 .50788 .64595 .50371 .64068 .49646 Mtetra
.741 .74 .851 r
.64068 .49646 .64595 .50371 .65652 .49867 .65123 .4901 Mtetra
.747 .71 .817 r
.65123 .4901 .65652 .49867 .66708 .49256 .66176 .48284 Mtetra
.739 .684 .798 r
.66176 .48284 .66708 .49256 .67763 .48579 .6723 .47536 Mtetra
.718 .663 .795 r
.6723 .47536 .67763 .48579 .68819 .47898 .68289 .46872 Mtetra
.692 .656 .809 r
.68289 .46872 .68819 .47898 .69881 .47275 .69358 .46345 Mtetra
.642 .653 .846 r
.69358 .46345 .69881 .47275 .70953 .46808 .70441 .46045 Mtetra
.58 .67 .901 r
.70441 .46045 .70953 .46808 .72037 .4649 .71539 .45917 Mtetra
.507 .705 .959 r
.71539 .45917 .72037 .4649 .73135 .46308 .72648 .45878 Mtetra
.447 .739 .99 r
.72648 .45878 .73135 .46308 .74242 .46198 .73764 .4585 Mtetra
.489 .797 .999 r
.73764 .4585 .74242 .46198 .75354 .46067 .7488 .45713 Mtetra
.564 .829 .995 r
.7488 .45713 .75354 .46067 .76468 .45889 .75993 .45471 Mtetra
.641 .831 .973 r
.75993 .45471 .76468 .45889 .77581 .45626 .77103 .45123 Mtetra
.68 .809 .944 r
.77103 .45123 .77581 .45626 .78694 .45299 .78213 .44707 Mtetra
.689 .778 .92 r
.78213 .44707 .78694 .45299 .79807 .44927 .79324 .4427 Mtetra
.689 .757 .903 r
.79324 .4427 .79807 .44927 .80923 .44529 .8044 .4383 Mtetra
.68 .74 .896 r
.8044 .4383 .80923 .44529 .82042 .4413 .81561 .43412 Mtetra
.673 .732 .895 r
.81561 .43412 .82042 .4413 .83166 .43734 .82688 .43014 Mtetra
.665 .729 .897 r
.82688 .43014 .83166 .43734 .84296 .43351 .83821 .42637 Mtetra
.66 .73 .901 r
.83821 .42637 .84296 .43351 .8543 .42977 .8496 .42276 Mtetra
.656 .733 .906 r
.8496 .42276 .8543 .42977 .8657 .42613 .86105 .41923 Mtetra
.654 .737 .911 r
.86105 .41923 .8657 .42613 .87716 .42254 .87254 .41577 Mtetra
.652 .741 .915 r
.87254 .41577 .87716 .42254 .88866 .41899 .88409 .41233 Mtetra
.652 .746 .918 r
.88409 .41233 .88866 .41899 .90021 .41544 .89569 .40886 Mtetra
.663 .753 .917 r
.27639 .59249 .28248 .59781 .29181 .59483 .28575 .58942 Mtetra
.665 .751 .914 r
.28575 .58942 .29181 .59483 .30117 .59184 .29514 .58631 Mtetra
.665 .747 .912 r
.29514 .58631 .30117 .59184 .31057 .58888 .30456 .5832 Mtetra
.663 .742 .909 r
.30456 .5832 .31057 .58888 .31999 .58597 .31402 .5801 Mtetra
.661 .736 .905 r
.31402 .5801 .31999 .58597 .32944 .58315 .3235 .57704 Mtetra
.656 .727 .901 r
.3235 .57704 .32944 .58315 .33892 .58048 .33301 .57412 Mtetra
.647 .716 .899 r
.33301 .57412 .33892 .58048 .34842 .57802 .34254 .57141 Mtetra
.635 .705 .897 r
.34254 .57141 .34842 .57802 .35795 .57576 .35209 .569 Mtetra
.617 .695 .9 r
.35209 .569 .35795 .57576 .36751 .57371 .36166 .56701 Mtetra
.605 .693 .905 r
.36166 .56701 .36751 .57371 .3771 .57164 .37125 .56528 Mtetra
.591 .701 .919 r
.37125 .56528 .3771 .57164 .38675 .56937 .38088 .56379 Mtetra
.602 .733 .937 r
.38088 .56379 .38675 .56937 .39645 .56645 .39057 .56193 Mtetra
.633 .785 .955 r
.39057 .56193 .39645 .56645 .40623 .5625 .40032 .55926 Mtetra
.688 .852 .961 r
.40032 .55926 .40623 .5625 .41607 .55753 .41016 .55524 Mtetra
.757 .899 .94 r
.41016 .55524 .41607 .55753 .42597 .5515 .42009 .54942 Mtetra
.787 .908 .924 r
.42009 .54942 .42597 .5515 .43588 .54555 .43006 .54274 Mtetra
.794 .879 .908 r
.43006 .54274 .43588 .54555 .44579 .54047 .44005 .53578 Mtetra
.747 .805 .899 r
.44005 .53578 .44579 .54047 .45569 .53707 .45003 .53014 Mtetra
.664 .711 .883 r
.45003 .53014 .45569 .53707 .46558 .53589 .45998 .52682 Mtetra
.591 .625 .854 r
.45998 .52682 .46558 .53589 .4755 .53608 .46993 .52555 Mtetra
.526 .562 .835 r
.46993 .52555 .4755 .53608 .48547 .5371 .4799 .52619 Mtetra
.507 .545 .83 r
.4799 .52619 .48547 .5371 .4955 .53792 .48993 .52742 Mtetra
.512 .557 .838 r
.48993 .52742 .4955 .53792 .50559 .53786 .50002 .52841 Mtetra
.534 .592 .858 r
.50002 .52841 .50559 .53786 .51575 .53686 .51018 .52866 Mtetra
.57 .642 .882 r
.51018 .52866 .51575 .53686 .52595 .53483 .5204 .5278 Mtetra
.599 .69 .906 r
.5204 .5278 .52595 .53483 .5362 .53215 .53067 .5261 Mtetra
.624 .734 .926 r
.53067 .5261 .5362 .53215 .54648 .52905 .54098 .52369 Mtetra
.637 .765 .94 r
.54098 .52369 .54648 .52905 .55681 .52578 .55134 .52086 Mtetra
.645 .786 .949 r
.55134 .52086 .55681 .52578 .56717 .52252 .56173 .5178 Mtetra
.649 .796 .953 r
.56173 .5178 .56717 .52252 .57757 .51934 .57216 .5146 Mtetra
.654 .797 .951 r
.57216 .5146 .57757 .51934 .58801 .51624 .58263 .51126 Mtetra
.666 .792 .942 r
.58263 .51126 .58801 .51624 .59849 .51314 .59313 .50767 Mtetra
.683 .779 .924 r
.59313 .50767 .59849 .51314 .60901 .50988 .60366 .50368 Mtetra
.706 .761 .895 r
.60366 .50368 .60901 .50988 .61956 .5062 .6142 .49896 Mtetra
.723 .735 .86 r
.6142 .49896 .61956 .5062 .63012 .50185 .62475 .49337 Mtetra
.737 .708 .824 r
.62475 .49337 .63012 .50185 .64068 .49646 .63529 .48668 Mtetra
.739 .683 .797 r
.63529 .48668 .64068 .49646 .65123 .4901 .64582 .4792 Mtetra
.733 .662 .78 r
.64582 .4792 .65123 .4901 .66176 .48284 .65636 .47148 Mtetra
.719 .649 .778 r
.65636 .47148 .66176 .48284 .6723 .47536 .66693 .46433 Mtetra
.686 .64 .797 r
.66693 .46433 .6723 .47536 .68289 .46872 .6776 .45911 Mtetra
.644 .648 .839 r
.6776 .45911 .68289 .46872 .69358 .46345 .68841 .45598 Mtetra
.555 .664 .91 r
.68841 .45598 .69358 .46345 .70441 .46045 .69939 .45523 Mtetra
.423 .685 .972 r
.69939 .45523 .70441 .46045 .71539 .45917 .71051 .45582 Mtetra
.331 .72 .983 r
.71051 .45582 .71539 .45917 .72648 .45878 .72168 .45616 Mtetra
.357 .766 .981 r
.72168 .45616 .72648 .45878 .73764 .4585 .73286 .45561 Mtetra
.533 .845 .999 r
.73286 .45561 .73764 .4585 .7488 .45713 .74399 .45322 Mtetra
.651 .847 .975 r
.74399 .45322 .7488 .45713 .75993 .45471 .75506 .44944 Mtetra
.698 .806 .932 r
.75506 .44944 .75993 .45471 .77103 .45123 .76612 .44482 Mtetra
.708 .769 .899 r
.76612 .44482 .77103 .45123 .78213 .44707 .77718 .43982 Mtetra
.697 .738 .883 r
.77718 .43982 .78213 .44707 .79324 .4427 .7883 .43504 Mtetra
.687 .723 .877 r
.7883 .43504 .79324 .4427 .8044 .4383 .79947 .43053 Mtetra
.674 .715 .88 r
.79947 .43053 .8044 .4383 .81561 .43412 .81072 .42646 Mtetra
.664 .715 .886 r
.81072 .42646 .81561 .43412 .82688 .43014 .82204 .42269 Mtetra
.657 .719 .895 r
.82204 .42269 .82688 .43014 .83821 .42637 .83342 .41914 Mtetra
.652 .725 .902 r
.83342 .41914 .83821 .42637 .8496 .42276 .84487 .41573 Mtetra
.65 .732 .909 r
.84487 .41573 .8496 .42276 .86105 .41923 .85636 .41236 Mtetra
.649 .737 .914 r
.85636 .41236 .86105 .41923 .87254 .41577 .86791 .40901 Mtetra
.648 .742 .918 r
.86791 .40901 .87254 .41577 .88409 .41233 .8795 .40565 Mtetra
.649 .746 .92 r
.8795 .40565 .88409 .41233 .89569 .40886 .89113 .40224 Mtetra
.664 .753 .917 r
.27027 .58715 .27639 .59249 .28575 .58942 .27964 .58405 Mtetra
.666 .753 .916 r
.27964 .58405 .28575 .58942 .29514 .58631 .28906 .58089 Mtetra
.668 .753 .914 r
.28906 .58089 .29514 .58631 .30456 .5832 .29851 .57767 Mtetra
.669 .75 .911 r
.29851 .57767 .30456 .5832 .31402 .5801 .30799 .5744 Mtetra
.671 .745 .906 r
.30799 .5744 .31402 .5801 .3235 .57704 .31751 .57107 Mtetra
.669 .736 .9 r
.31751 .57107 .3235 .57704 .33301 .57412 .32706 .56777 Mtetra
.664 .723 .893 r
.32706 .56777 .33301 .57412 .34254 .57141 .33663 .56458 Mtetra
.652 .705 .886 r
.33663 .56458 .34254 .57141 .35209 .569 .34622 .5617 Mtetra
.633 .685 .881 r
.34622 .5617 .35209 .569 .36166 .56701 .35583 .5593 Mtetra
.611 .666 .879 r
.35583 .5593 .36166 .56701 .37125 .56528 .36544 .55749 Mtetra
.58 .652 .885 r
.36544 .55749 .37125 .56528 .38088 .56379 .37506 .55643 Mtetra
.565 .659 .9 r
.37506 .55643 .38088 .56379 .39057 .56193 .38471 .55562 Mtetra
.556 .692 .93 r
.38471 .55562 .39057 .56193 .40032 .55926 .39442 .55475 Mtetra
.599 .778 .966 r
.39442 .55475 .40032 .55926 .41016 .55524 .40422 .55264 Mtetra
.686 .881 .971 r
.40422 .55264 .41016 .55524 .42009 .54942 .41413 .54844 Mtetra
.755 .949 .942 r
.41413 .54844 .42009 .54942 .43006 .54274 .42412 .54223 Mtetra
.822 .96 .901 r
.42412 .54223 .43006 .54274 .44005 .53578 .43419 .53405 Mtetra
.823 .919 .901 r
.43419 .53405 .44005 .53578 .45003 .53014 .44426 .52606 Mtetra
.773 .833 .899 r
.44426 .52606 .45003 .53014 .45998 .52682 .45431 .51963 Mtetra
.685 .712 .869 r
.45431 .51963 .45998 .52682 .46993 .52555 .46432 .51558 Mtetra
.587 .605 .837 r
.46432 .51558 .46993 .52555 .4799 .52619 .47433 .51446 Mtetra
.537 .546 .812 r
.47433 .51446 .4799 .52619 .48993 .52742 .48436 .51497 Mtetra
.511 .52 .802 r
.48436 .51497 .48993 .52742 .50002 .52841 .49445 .51636 Mtetra
.515 .53 .81 r
.49445 .51636 .50002 .52841 .51018 .52866 .5046 .51757 Mtetra
.539 .561 .826 r
.5046 .51757 .51018 .52866 .5204 .5278 .51482 .51794 Mtetra
.565 .6 .847 r
.51482 .51794 .5204 .5278 .53067 .5261 .5251 .51741 Mtetra
.596 .643 .867 r
.5251 .51741 .53067 .5261 .54098 .52369 .53543 .5159 Mtetra
.619 .678 .884 r
.53543 .5159 .54098 .52369 .55134 .52086 .54581 .51371 Mtetra
.639 .705 .894 r
.54581 .51371 .55134 .52086 .56173 .5178 .55623 .51094 Mtetra
.655 .721 .897 r
.55623 .51094 .56173 .5178 .57216 .5146 .56668 .50771 Mtetra
.671 .726 .891 r
.56668 .50771 .57216 .5146 .58263 .51126 .57717 .50403 Mtetra
.687 .722 .877 r
.57717 .50403 .58263 .51126 .59313 .50767 .58768 .49977 Mtetra
.702 .71 .854 r
.58768 .49977 .59313 .50767 .60366 .50368 .59821 .4948 Mtetra
.718 .693 .825 r
.59821 .4948 .60366 .50368 .6142 .49896 .60874 .48886 Mtetra
.725 .671 .797 r
.60874 .48886 .6142 .49896 .62475 .49337 .61928 .48199 Mtetra
.728 .652 .774 r
.61928 .48199 .62475 .49337 .63529 .48668 .6298 .47426 Mtetra
.723 .636 .76 r
.6298 .47426 .63529 .48668 .64582 .4792 .64033 .46633 Mtetra
.706 .622 .761 r
.64033 .46633 .64582 .4792 .65636 .47148 .6509 .45927 Mtetra
.682 .62 .78 r
.6509 .45927 .65636 .47148 .66693 .46433 .66156 .45386 Mtetra
.622 .621 .828 r
.66156 .45386 .66693 .46433 .6776 .45911 .67238 .45142 Mtetra
.522 .642 .909 r
.67238 .45142 .6776 .45911 .68841 .45598 .68336 .45142 Mtetra
.3 .648 .969 r
.68336 .45142 .68841 .45598 .69939 .45523 .6945 .45303 Mtetra
.055 .582 .866 r
.6945 .45303 .69939 .45523 .71051 .45582 .70572 .45484 Mtetra
.142 .678 .849 r
.70572 .45484 .71051 .45582 .72168 .45616 .7169 .45465 Mtetra
.422 .842 .961 r
.7169 .45465 .72168 .45616 .73286 .45561 .72802 .45241 Mtetra
.669 .883 .977 r
.72802 .45241 .73286 .45561 .74399 .45322 .73906 .44801 Mtetra
.734 .819 .917 r
.73906 .44801 .74399 .45322 .75506 .44944 .75004 .44233 Mtetra
.725 .752 .874 r
.75004 .44233 .75506 .44944 .76612 .44482 .76104 .43657 Mtetra
.71 .716 .853 r
.76104 .43657 .76612 .44482 .77718 .43982 .77209 .43107 Mtetra
.687 .695 .851 r
.77209 .43107 .77718 .43982 .7883 .43504 .78324 .42633 Mtetra
.671 .69 .859 r
.78324 .42633 .7883 .43504 .79947 .43053 .79447 .4222 Mtetra
.658 .694 .872 r
.79447 .4222 .79947 .43053 .81072 .42646 .80578 .41857 Mtetra
.648 .703 .887 r
.80578 .41857 .81072 .42646 .82204 .42269 .81717 .41525 Mtetra
.645 .716 .9 r
.81717 .41525 .82204 .42269 .83342 .41914 .82862 .41204 Mtetra
.642 .727 .91 r
.82862 .41204 .83342 .41914 .84487 .41573 .84012 .40887 Mtetra
.644 .736 .916 r
.84012 .40887 .84487 .41573 .85636 .41236 .85166 .40564 Mtetra
.645 .742 .92 r
.85166 .40564 .85636 .41236 .86791 .40901 .86325 .40234 Mtetra
.647 .746 .922 r
.86325 .40234 .86791 .40901 .8795 .40565 .87488 .39899 Mtetra
.649 .748 .922 r
.87488 .39899 .8795 .40565 .89113 .40224 .88655 .39556 Mtetra
.66 .752 .919 r
.2641 .58177 .27027 .58715 .27964 .58405 .27349 .57874 Mtetra
.662 .756 .92 r
.27349 .57874 .27964 .58405 .28906 .58089 .28292 .57565 Mtetra
.665 .76 .921 r
.28292 .57565 .28906 .58089 .29851 .57767 .29238 .57247 Mtetra
.67 .763 .921 r
.29238 .57247 .29851 .57767 .30799 .5744 .30189 .56917 Mtetra
.676 .764 .917 r
.30189 .56917 .30799 .5744 .31751 .57107 .31144 .5657 Mtetra
.68 .761 .913 r
.31144 .5657 .31751 .57107 .32706 .56777 .32103 .56212 Mtetra
.683 .752 .904 r
.32103 .56212 .32706 .56777 .33663 .56458 .33065 .55845 Mtetra
.676 .735 .895 r
.33065 .55845 .33663 .56458 .34622 .5617 .34029 .55491 Mtetra
.663 .712 .884 r
.34029 .55491 .34622 .5617 .35583 .5593 .34995 .55168 Mtetra
.638 .68 .873 r
.34995 .55168 .35583 .5593 .36544 .55749 .35962 .54912 Mtetra
.601 .646 .867 r
.35962 .54912 .36544 .55749 .37506 .55643 .36927 .54755 Mtetra
.567 .619 .863 r
.36927 .54755 .37506 .55643 .38471 .55562 .37893 .54689 Mtetra
.524 .603 .874 r
.37893 .54689 .38471 .55562 .39442 .55475 .38859 .54715 Mtetra
.53 .639 .903 r
.38859 .54715 .39442 .55475 .40422 .55264 .39833 .54704 Mtetra
.574 .728 .947 r
.39833 .54704 .40422 .55264 .41413 .54844 .40817 .54562 Mtetra
.669 .87 .975 r
.40817 .54562 .41413 .54844 .42412 .54223 .41813 .54175 Mtetra
.781 .965 .922 r
.41813 .54175 .42412 .54223 .43419 .53405 .42821 .53465 Mtetra
.814 .988 .88 r
.42821 .53465 .43419 .53405 .44426 .52606 .43835 .52604 Mtetra
.839 .972 .881 r
.43835 .52604 .44426 .52606 .45431 .51963 .4485 .51702 Mtetra
.804 .892 .907 r
.4485 .51702 .45431 .51963 .46432 .51558 .45861 .50966 Mtetra
.703 .759 .896 r
.45861 .50966 .46432 .51558 .47433 .51446 .4687 .5052 Mtetra
.617 .636 .847 r
.4687 .5052 .47433 .51446 .48436 .51497 .47877 .50314 Mtetra
.551 .553 .81 r
.47877 .50314 .48436 .51497 .49445 .51636 .48887 .50319 Mtetra
.532 .522 .79 r
.48887 .50319 .49445 .51636 .5046 .51757 .49902 .50399 Mtetra
.536 .519 .784 r
.49902 .50399 .5046 .51757 .51482 .51794 .50923 .50472 Mtetra
.551 .534 .789 r
.50923 .50472 .51482 .51794 .5251 .51741 .51951 .50489 Mtetra
.577 .558 .797 r
.51951 .50489 .5251 .51741 .53543 .5159 .52985 .50412 Mtetra
.6 .582 .805 r
.52985 .50412 .53543 .5159 .54581 .51371 .54023 .50251 Mtetra
.623 .604 .811 r
.54023 .50251 .54581 .51371 .55623 .51094 .55066 .50003 Mtetra
.644 .62 .811 r
.55066 .50003 .55623 .51094 .56668 .50771 .56112 .49677 Mtetra
.662 .628 .806 r
.56112 .49677 .56668 .50771 .57717 .50403 .57161 .49275 Mtetra
.678 .631 .794 r
.57161 .49275 .57717 .50403 .58768 .49977 .58213 .48785 Mtetra
.691 .627 .78 r
.58213 .48785 .58768 .49977 .59821 .4948 .59265 .48209 Mtetra
.702 .621 .764 r
.59265 .48209 .59821 .4948 .60874 .48886 .60318 .47538 Mtetra
.705 .614 .753 r
.60318 .47538 .60874 .48886 .61928 .48199 .61371 .46808 Mtetra
.703 .609 .748 r
.61371 .46808 .61928 .48199 .6298 .47426 .62425 .4607 Mtetra
.694 .608 .756 r
.62425 .4607 .6298 .47426 .64033 .46633 .63484 .45408 Mtetra
.664 .611 .785 r
.63484 .45408 .64033 .46633 .6509 .45927 .64552 .44958 Mtetra
.612 .633 .847 r
.64552 .44958 .6509 .45927 .66156 .45386 .65633 .44751 Mtetra
.44 .649 .947 r
.65633 .44751 .66156 .45386 .67238 .45142 .66732 .4484 Mtetra
.052 .552 .884 r
.66732 .4484 .67238 .45142 .68336 .45142 .67846 .451 Mtetra
.194 0 0 r
.67846 .451 .68336 .45142 .6945 .45303 .68967 .4532 Mtetra
.096 0 0 r
.68967 .4532 .6945 .45303 .70572 .45484 .70088 .45388 Mtetra
.408 .848 .932 r
.70088 .45388 .70572 .45484 .7169 .45465 .71197 .45125 Mtetra
.708 .885 .963 r
.71197 .45125 .7169 .45465 .72802 .45241 .72295 .44611 Mtetra
.751 .785 .881 r
.72295 .44611 .72802 .45241 .73906 .44801 .73388 .43961 Mtetra
.741 .723 .835 r
.73388 .43961 .73906 .44801 .75004 .44233 .74481 .4327 Mtetra
.71 .684 .823 r
.74481 .4327 .75004 .44233 .76104 .43657 .75582 .42675 Mtetra
.688 .671 .828 r
.75582 .42675 .76104 .43657 .77209 .43107 .76694 .42171 Mtetra
.665 .672 .847 r
.76694 .42171 .77209 .43107 .78324 .42633 .77816 .41771 Mtetra
.648 .683 .869 r
.77816 .41771 .78324 .42633 .79447 .4222 .78949 .41439 Mtetra
.638 .702 .892 r
.78949 .41439 .79447 .4222 .80578 .41857 .80088 .41138 Mtetra
.631 .719 .91 r
.80088 .41138 .80578 .41857 .81717 .41525 .81234 .40853 Mtetra
.633 .736 .922 r
.81234 .40853 .81717 .41525 .82862 .41204 .82385 .40557 Mtetra
.636 .747 .929 r
.82385 .40557 .82862 .41204 .84012 .40887 .83539 .40249 Mtetra
.642 .754 .93 r
.83539 .40249 .84012 .40887 .85166 .40564 .84697 .39924 Mtetra
.646 .756 .929 r
.84697 .39924 .85166 .40564 .86325 .40234 .85858 .39586 Mtetra
.649 .756 .927 r
.85858 .39586 .86325 .40234 .87488 .39899 .87023 .39239 Mtetra
.652 .753 .924 r
.87023 .39239 .87488 .39899 .88655 .39556 .88193 .38884 Mtetra
.652 .75 .922 r
.25789 .57635 .2641 .58177 .27349 .57874 .26729 .57349 Mtetra
.652 .758 .927 r
.26729 .57349 .27349 .57874 .28292 .57565 .27672 .5706 Mtetra
.656 .766 .931 r
.27672 .5706 .28292 .57565 .29238 .57247 .28619 .56761 Mtetra
.662 .776 .934 r
.28619 .56761 .29238 .57247 .30189 .56917 .29571 .56445 Mtetra
.671 .784 .934 r
.29571 .56445 .30189 .56917 .31144 .5657 .30528 .56107 Mtetra
.681 .791 .932 r
.30528 .56107 .31144 .5657 .32103 .56212 .31489 .55743 Mtetra
.695 .791 .924 r
.31489 .55743 .32103 .56212 .33065 .55845 .32456 .55343 Mtetra
.701 .781 .914 r
.32456 .55343 .33065 .55845 .34029 .55491 .33426 .54926 Mtetra
.703 .759 .896 r
.33426 .54926 .34029 .55491 .34995 .55168 .344 .54495 Mtetra
.685 .722 .877 r
.344 .54495 .34995 .55168 .35962 .54912 .35375 .54105 Mtetra
.654 .675 .858 r
.35375 .54105 .35962 .54912 .36927 .54755 .36348 .53795 Mtetra
.608 .621 .838 r
.36348 .53795 .36927 .54755 .37893 .54689 .3732 .53619 Mtetra
.544 .568 .829 r
.3732 .53619 .37893 .54689 .38859 .54715 .38287 .53629 Mtetra
.501 .544 .832 r
.38287 .53629 .38859 .54715 .39833 .54704 .39256 .53749 Mtetra
.456 .55 .863 r
.39256 .53749 .39833 .54704 .40817 .54562 .40229 .53928 Mtetra
.498 .671 .941 r
.40229 .53928 .40817 .54562 .41813 .54175 .41214 .5393 Mtetra
.627 .878 .988 r
.41214 .5393 .41813 .54175 .42821 .53465 .42215 .53589 Mtetra
.677 .978 .872 r
.42215 .53589 .42821 .53465 .43835 .52604 .43228 .52918 Mtetra
.751 .986 .761 r
.43228 .52918 .43835 .52604 .4485 .51702 .44252 .51926 Mtetra
.812 1 .807 r
.44252 .51926 .4485 .51702 .45861 .50966 .45275 .50906 Mtetra
.834 .961 .892 r
.45275 .50906 .45861 .50966 .4687 .5052 .46295 .50036 Mtetra
.761 .809 .891 r
.46295 .50036 .4687 .5052 .47877 .50314 .47312 .49411 Mtetra
.65 .657 .843 r
.47312 .49411 .47877 .50314 .48887 .50319 .48327 .49093 Mtetra
.592 .569 .797 r
.48327 .49093 .48887 .50319 .49902 .50399 .49344 .48959 Mtetra
.562 .524 .77 r
.49344 .48959 .49902 .50399 .50923 .50472 .50365 .48939 Mtetra
.56 .512 .759 r
.50365 .48939 .50923 .50472 .51951 .50489 .51391 .48934 Mtetra
.572 .517 .756 r
.51391 .48934 .51951 .50489 .52985 .50412 .52424 .48878 Mtetra
.589 .53 .756 r
.52424 .48878 .52985 .50412 .54023 .50251 .53462 .48746 Mtetra
.61 .545 .757 r
.53462 .48746 .54023 .50251 .55066 .50003 .54504 .48515 Mtetra
.63 .558 .755 r
.54504 .48515 .55066 .50003 .56112 .49677 .55551 .48187 Mtetra
.648 .568 .751 r
.55551 .48187 .56112 .49677 .57161 .49275 .566 .4776 Mtetra
.663 .574 .745 r
.566 .4776 .57161 .49275 .58213 .48785 .5765 .47235 Mtetra
.674 .577 .738 r
.5765 .47235 .58213 .48785 .59265 .48209 .58702 .46632 Mtetra
.68 .578 .734 r
.58702 .46632 .59265 .48209 .60318 .47538 .59756 .45977 Mtetra
.679 .579 .736 r
.59756 .45977 .60318 .47538 .61371 .46808 .60811 .45334 Mtetra
.665 .58 .75 r
.60811 .45334 .61371 .46808 .62425 .4607 .61872 .44807 Mtetra
.639 .593 .786 r
.61872 .44807 .62425 .4607 .63484 .45408 .62942 .44467 Mtetra
.55 .609 .865 r
.62942 .44467 .63484 .45408 .64552 .44958 .64027 .44436 Mtetra
.282 .61 .955 r
.64027 .44436 .64552 .44958 .65633 .44751 .65128 .44657 Mtetra
.3 0 0 r
.65128 .44657 .65633 .44751 .66732 .4484 .66243 .45031 Mtetra
.459 0 0 r
.66243 .45031 .66732 .4484 .67846 .451 .67366 .45381 Mtetra
.278 0 0 r
.67366 .45381 .67846 .451 .68967 .4532 .68482 .45404 Mtetra
.26 .767 .756 r
.68482 .45404 .68967 .4532 .70088 .45388 .69588 .45089 Mtetra
.764 .912 .939 r
.69588 .45089 .70088 .45388 .71197 .45125 .70679 .44424 Mtetra
.787 .772 .84 r
.70679 .44424 .71197 .45125 .72295 .44611 .7176 .43574 Mtetra
.741 .682 .794 r
.7176 .43574 .72295 .44611 .73388 .43961 .72847 .42783 Mtetra
.709 .645 .784 r
.72847 .42783 .73388 .43961 .74481 .4327 .73942 .42104 Mtetra
.673 .63 .799 r
.73942 .42104 .74481 .4327 .75582 .42675 .75053 .41616 Mtetra
.646 .637 .827 r
.75053 .41616 .75582 .42675 .76694 .42171 .76177 .41266 Mtetra
.627 .663 .865 r
.76177 .41266 .76694 .42171 .77816 .41771 .77313 .41 Mtetra
.61 .693 .902 r
.77313 .41 .77816 .41771 .78949 .41439 .78457 .40774 Mtetra
.609 .729 .93 r
.78457 .40774 .78949 .41439 .80088 .41138 .79605 .40536 Mtetra
.612 .754 .946 r
.79605 .40536 .80088 .41138 .81234 .40853 .80757 .40279 Mtetra
.624 .771 .951 r
.80757 .40279 .81234 .40853 .82385 .40557 .81911 .39986 Mtetra
.635 .778 .949 r
.81911 .39986 .82385 .40557 .83539 .40249 .83068 .39665 Mtetra
.646 .778 .944 r
.83068 .39665 .83539 .40249 .84697 .39924 .84228 .39319 Mtetra
.653 .774 .937 r
.84228 .39319 .84697 .39924 .85858 .39586 .8539 .38957 Mtetra
.657 .767 .931 r
.8539 .38957 .85858 .39586 .87023 .39239 .86557 .38584 Mtetra
.659 .76 .924 r
.86557 .38584 .87023 .39239 .88193 .38884 .87727 .38207 Mtetra
.643 .748 .925 r
.25164 .57089 .25789 .57635 .26729 .57349 .26104 .56821 Mtetra
.642 .755 .931 r
.26104 .56821 .26729 .57349 .27672 .5706 .27048 .56553 Mtetra
.643 .764 .937 r
.27048 .56553 .27672 .5706 .28619 .56761 .27995 .5628 Mtetra
.647 .776 .942 r
.27995 .5628 .28619 .56761 .29571 .56445 .28947 .55994 Mtetra
.653 .79 .947 r
.28947 .55994 .29571 .56445 .30528 .56107 .29904 .55689 Mtetra
.666 .807 .95 r
.29904 .55689 .30528 .56107 .31489 .55743 .30866 .55353 Mtetra
.685 .822 .949 r
.30866 .55353 .31489 .55743 .32456 .55343 .31834 .54971 Mtetra
.704 .833 .944 r
.31834 .54971 .32456 .55343 .33426 .54926 .32808 .54543 Mtetra
.726 .832 .93 r
.32808 .54543 .33426 .54926 .344 .54495 .33788 .54057 Mtetra
.73 .812 .915 r
.33788 .54057 .344 .54495 .35375 .54105 .34771 .53556 Mtetra
.721 .772 .893 r
.34771 .53556 .35375 .54105 .36348 .53795 .35756 .53066 Mtetra
.68 .706 .868 r
.35756 .53066 .36348 .53795 .3732 .53619 .36738 .5268 Mtetra
.617 .631 .842 r
.36738 .5268 .3732 .53619 .38287 .53629 .37716 .52474 Mtetra
.548 .556 .814 r
.37716 .52474 .38287 .53629 .39256 .53749 .38689 .52479 Mtetra
.465 .491 .801 r
.38689 .52479 .39256 .53749 .40229 .53928 .39658 .52727 Mtetra
.45 .495 .814 r
.39658 .52727 .40229 .53928 .41214 .5393 .40634 .52992 Mtetra
.478 .568 .868 r
.40634 .52992 .41214 .5393 .42215 .53589 .41621 .53121 Mtetra
.59 .775 .968 r
.41621 .53121 .42215 .53589 .43228 .52918 .42624 .52917 Mtetra
.736 .976 .923 r
.42624 .52917 .43228 .52918 .44252 .51926 .43644 .52255 Mtetra
.688 .966 .742 r
.43644 .52255 .44252 .51926 .45275 .50906 .44671 .51337 Mtetra
.688 .947 .674 r
.44671 .51337 .45275 .50906 .46295 .50036 .45701 .50286 Mtetra
.759 .992 .791 r
.45701 .50286 .46295 .50036 .47312 .49411 .46729 .49332 Mtetra
.783 .963 .923 r
.46729 .49332 .47312 .49411 .48327 .49093 .47754 .48609 Mtetra
.726 .808 .916 r
.47754 .48609 .48327 .49093 .49344 .48959 .48777 .481 Mtetra
.647 .668 .856 r
.48777 .481 .49344 .48959 .50365 .48939 .49802 .47793 Mtetra
.612 .594 .808 r
.49802 .47793 .50365 .48939 .51391 .48934 .5083 .47584 Mtetra
.6 .557 .779 r
.5083 .47584 .51391 .48934 .52424 .48878 .51863 .47409 Mtetra
.603 .545 .762 r
.51863 .47409 .52424 .48878 .53462 .48746 .529 .4721 Mtetra
.614 .544 .753 r
.529 .4721 .53462 .48746 .54504 .48515 .53942 .46952 Mtetra
.627 .549 .747 r
.53942 .46952 .54504 .48515 .55551 .48187 .54987 .4662 Mtetra
.64 .557 .744 r
.54987 .4662 .55551 .48187 .566 .4776 .56036 .46215 Mtetra
.651 .565 .745 r
.56036 .46215 .566 .4776 .5765 .47235 .57088 .4575 Mtetra
.658 .575 .75 r
.57088 .4575 .5765 .47235 .58702 .46632 .58142 .45261 Mtetra
.658 .588 .765 r
.58142 .45261 .58702 .46632 .59756 .45977 .59201 .44805 Mtetra
.646 .611 .799 r
.59201 .44805 .59756 .45977 .60811 .45334 .60264 .44448 Mtetra
.592 .644 .871 r
.60264 .44448 .60811 .45334 .61872 .44807 .61338 .44295 Mtetra
.405 .684 .975 r
.61338 .44295 .61872 .44807 .62942 .44467 .62423 .44359 Mtetra
.222 0 0 r
.62423 .44359 .62942 .44467 .64027 .44436 .63523 .4466 Mtetra
.502 0 0 r
.63523 .4466 .64027 .44436 .65128 .44657 .64636 .45061 Mtetra
.479 0 0 r
.64636 .45061 .65128 .44657 .66243 .45031 .65752 .4533 Mtetra
.276 0 0 r
.65752 .4533 .66243 .45031 .67366 .45381 .66865 .45338 Mtetra
.544 .923 .921 r
.66865 .45338 .67366 .45381 .68482 .45404 .67963 .4488 Mtetra
.795 .829 .878 r
.67963 .4488 .68482 .45404 .69588 .45089 .69048 .4408 Mtetra
.767 .697 .785 r
.69048 .4408 .69588 .45089 .70679 .44424 .70126 .43139 Mtetra
.739 .644 .754 r
.70126 .43139 .70679 .44424 .7176 .43574 .71205 .42213 Mtetra
.695 .614 .761 r
.71205 .42213 .7176 .43574 .72847 .42783 .723 .41535 Mtetra
.663 .613 .788 r
.723 .41535 .72847 .42783 .73942 .42104 .7341 .41073 Mtetra
.627 .634 .838 r
.7341 .41073 .73942 .42104 .75053 .41616 .74538 .40796 Mtetra
.59 .669 .894 r
.74538 .40796 .75053 .41616 .76177 .41266 .75678 .40628 Mtetra
.57 .721 .944 r
.75678 .40628 .76177 .41266 .77313 .41 .76825 .40471 Mtetra
.558 .76 .972 r
.76825 .40471 .77313 .41 .78457 .40774 .77976 .40299 Mtetra
.578 .792 .98 r
.77976 .40299 .78457 .40774 .79605 .40536 .79129 .40068 Mtetra
.602 .806 .978 r
.79129 .40068 .79605 .40536 .80757 .40279 .80284 .39788 Mtetra
.629 .808 .969 r
.80284 .39788 .80757 .40279 .81911 .39986 .81439 .39461 Mtetra
.647 .802 .957 r
.81439 .39461 .81911 .39986 .83068 .39665 .82596 .391 Mtetra
.658 .792 .946 r
.82596 .391 .83068 .39665 .84228 .39319 .83756 .38719 Mtetra
.664 .782 .936 r
.83756 .38719 .84228 .39319 .8539 .38957 .84919 .38325 Mtetra
.667 .772 .928 r
.84919 .38325 .8539 .38957 .86557 .38584 .86087 .37924 Mtetra
.666 .763 .922 r
.86087 .37924 .86557 .38584 .87727 .38207 .87259 .37524 Mtetra
.638 .747 .927 r
.24535 .5654 .25164 .57089 .26104 .56821 .25476 .56282 Mtetra
.634 .75 .932 r
.25476 .56282 .26104 .56821 .27048 .56553 .26421 .5603 Mtetra
.631 .756 .938 r
.26421 .5603 .27048 .56553 .27995 .5628 .27368 .5578 Mtetra
.629 .765 .944 r
.27368 .5578 .27995 .5628 .28947 .55994 .2832 .55529 Mtetra
.627 .779 .954 r
.2832 .55529 .28947 .55994 .29904 .55689 .29275 .55275 Mtetra
.633 .802 .964 r
.29275 .55275 .29904 .55689 .30866 .55353 .30236 .54999 Mtetra
.643 .83 .972 r
.30236 .54999 .30866 .55353 .31834 .54971 .31202 .54688 Mtetra
.665 .865 .975 r
.31202 .54688 .31834 .54971 .32808 .54543 .32175 .54317 Mtetra
.702 .894 .967 r
.32175 .54317 .32808 .54543 .33788 .54057 .33157 .53859 Mtetra
.737 .908 .953 r
.33157 .53859 .33788 .54057 .34771 .53556 .34145 .53319 Mtetra
.775 .894 .928 r
.34145 .53319 .34771 .53556 .35756 .53066 .35141 .52686 Mtetra
.772 .839 .903 r
.35141 .52686 .35756 .53066 .36738 .5268 .36139 .52051 Mtetra
.737 .752 .864 r
.36139 .52051 .36738 .5268 .37716 .52474 .37135 .51476 Mtetra
.658 .637 .818 r
.37135 .51476 .37716 .52474 .38689 .52479 .38124 .51119 Mtetra
.559 .53 .78 r
.38124 .51119 .38689 .52479 .39658 .52727 .39103 .51102 Mtetra
.485 .457 .75 r
.39103 .51102 .39658 .52727 .40634 .52992 .40077 .51367 Mtetra
.404 .407 .749 r
.40077 .51367 .40634 .52992 .41621 .53121 .41049 .51879 Mtetra
.396 .458 .808 r
.41049 .51879 .41621 .53121 .42624 .52917 .42034 .52272 Mtetra
.468 .659 .944 r
.42034 .52272 .42624 .52917 .43644 .52255 .43036 .52314 Mtetra
.455 .885 .874 r
.43036 .52314 .43644 .52255 .44671 .51337 .44056 .51927 Mtetra
0 0 0 r
.44056 .51927 .44671 .51337 .45701 .50286 .45089 .51072 Mtetra
.45089 .51072 .45701 .50286 .46729 .49332 .46126 .50031 Mtetra
.46126 .50031 .46729 .49332 .47754 .48609 .47163 .48969 Mtetra
.652 .944 .702 r
.47163 .48969 .47754 .48609 .48777 .481 .48198 .48036 Mtetra
.773 .969 .923 r
.48198 .48036 .48777 .481 .49802 .47793 .49231 .47317 Mtetra
.739 .817 .912 r
.49231 .47317 .49802 .47793 .5083 .47584 .50264 .46761 Mtetra
.68 .693 .855 r
.50264 .46761 .5083 .47584 .51863 .47409 .51299 .46341 Mtetra
.652 .629 .814 r
.51299 .46341 .51863 .47409 .529 .4721 .52337 .45985 Mtetra
.639 .597 .79 r
.52337 .45985 .529 .4721 .53942 .46952 .53379 .45652 Mtetra
.637 .585 .78 r
.53379 .45652 .53942 .46952 .54987 .4662 .54425 .45318 Mtetra
.54425 .45318 .54987 .4662 .56036 .46215 .55475 .44981 Mtetra
.634 .594 .792 r
.55475 .44981 .56036 .46215 .57088 .4575 .5653 .44669 Mtetra
.622 .615 .822 r
.5653 .44669 .57088 .4575 .58142 .45261 .57589 .4442 Mtetra
.573 .648 .886 r
.57589 .4442 .58142 .45261 .59201 .44805 .58656 .44309 Mtetra
.402 .69 .978 r
.58656 .44309 .59201 .44805 .60264 .44448 .59732 .44364 Mtetra
.223 0 0 r
.59732 .44364 .60264 .44448 .61338 .44295 .60821 .44636 Mtetra
.532 .003 0 r
.60821 .44636 .61338 .44295 .62423 .44359 .61922 .45041 Mtetra
.558 .099 .118 r
.61922 .45041 .62423 .44359 .63523 .4466 .63031 .45427 Mtetra
.503 .054 .116 r
.63031 .45427 .63523 .4466 .64636 .45061 .64142 .45628 Mtetra
.214 0 0 r
.64142 .45628 .64636 .45061 .65752 .4533 .65244 .45351 Mtetra
.686 .979 .883 r
.65244 .45351 .65752 .4533 .66865 .45338 .66331 .44639 Mtetra
.823 .779 .811 r
.66331 .44639 .66865 .45338 .67963 .4488 .67404 .43564 Mtetra
.77 .654 .735 r
.67404 .43564 .67963 .4488 .69048 .4408 .6847 .42367 Mtetra
.709 .587 .716 r
.6847 .42367 .69048 .4408 .70126 .43139 .69548 .41419 Mtetra
.671 .565 .727 r
.69548 .41419 .70126 .43139 .71205 .42213 .70643 .40758 Mtetra
.624 .565 .768 r
.70643 .40758 .71205 .42213 .723 .41535 .7176 .40447 Mtetra
.571 .595 .838 r
.7176 .40447 .723 .41535 .7341 .41073 .72897 .4036 Mtetra
.515 .668 .932 r
.72897 .4036 .7341 .41073 .74538 .40796 .74044 .40336 Mtetra
.441 .733 .989 r
.74044 .40336 .74538 .40796 .75678 .40628 .75198 .40311 Mtetra
.437 .794 .997 r
.75198 .40311 .75678 .40628 .76825 .40471 .76351 .40191 Mtetra
.482 .833 .996 r
.76351 .40191 .76825 .40471 .77976 .40299 .77505 .39986 Mtetra
.563 .857 .997 r
.77505 .39986 .77976 .40299 .79129 .40068 .78657 .39691 Mtetra
.621 .855 .987 r
.78657 .39691 .79129 .40068 .80284 .39788 .79809 .39333 Mtetra
.654 .835 .97 r
.79809 .39333 .80284 .39788 .81439 .39461 .80963 .38938 Mtetra
.67 .814 .952 r
.80963 .38938 .81439 .39461 .82596 .391 .82119 .3852 Mtetra
.673 .794 .939 r
.82119 .3852 .82596 .391 .83756 .38719 .83279 .38098 Mtetra
.674 .78 .929 r
.83279 .38098 .83756 .38719 .84919 .38325 .84443 .37674 Mtetra
.674 .77 .923 r
.84443 .37674 .84919 .38325 .86087 .37924 .85612 .37252 Mtetra
.671 .762 .919 r
.85612 .37252 .86087 .37924 .87259 .37524 .86786 .36837 Mtetra
.641 .748 .926 r
.23902 .55988 .24535 .5654 .25476 .56282 .24846 .5572 Mtetra
.637 .744 .926 r
.24846 .5572 .25476 .56282 .26421 .5603 .25792 .55461 Mtetra
.632 .741 .926 r
.25792 .55461 .26421 .5603 .27368 .5578 .26742 .55212 Mtetra
.626 .74 .929 r
.26742 .55212 .27368 .5578 .2832 .55529 .27694 .54974 Mtetra
.616 .743 .936 r
.27694 .54974 .2832 .55529 .29275 .55275 .28649 .54753 Mtetra
.612 .755 .946 r
.28649 .54753 .29275 .55275 .30236 .54999 .29607 .54533 Mtetra
.608 .776 .961 r
.29607 .54533 .30236 .54999 .31202 .54688 .3057 .54308 Mtetra
.618 .815 .976 r
.3057 .54308 .31202 .54688 .32175 .54317 .3154 .54042 Mtetra
.639 .864 .984 r
.3154 .54042 .32175 .54317 .33157 .53859 .32517 .53706 Mtetra
.673 .918 .975 r
.32517 .53706 .33157 .53859 .34145 .53319 .33504 .53264 Mtetra
.729 .957 .946 r
.33504 .53264 .34145 .53319 .35141 .52686 .34502 .52676 Mtetra
.771 .971 .922 r
.34502 .52676 .35141 .52686 .36139 .52051 .35507 .51977 Mtetra
.818 .95 .906 r
.35507 .51977 .36139 .52051 .37135 .51476 .36518 .51179 Mtetra
.798 .873 .903 r
.36518 .51179 .37135 .51476 .38124 .51119 .37526 .5046 Mtetra
.718 .741 .87 r
.37526 .5046 .38124 .51119 .39103 .51102 .38527 .49948 Mtetra
.601 .585 .807 r
.38527 .49948 .39103 .51102 .40077 .51367 .39517 .4978 Mtetra
.479 .457 .756 r
.39517 .4978 .40077 .51367 .41049 .51879 .40496 .50055 Mtetra
.436 .408 .729 r
.40496 .50055 .41049 .51879 .42034 .52272 .41475 .50525 Mtetra
.42 .405 .737 r
.41475 .50525 .42034 .52272 .43036 .52314 .42462 .51028 Mtetra
.467 .494 .803 r
.42462 .51028 .43036 .52314 .44056 .51927 .43465 .51269 Mtetra
.605 .714 .921 r
.43465 .51269 .44056 .51927 .45089 .51072 .44486 .51067 Mtetra
.652 .96 .932 r
.44486 .51067 .45089 .51072 .46126 .50031 .45518 .50519 Mtetra
0 0 0 r
.45518 .50519 .46126 .50031 .47163 .48969 .46558 .49686 Mtetra
.46558 .49686 .47163 .48969 .48198 .48036 .476 .48778 Mtetra
.476 .48778 .48198 .48036 .49231 .47317 .48642 .47918 Mtetra
.48642 .47918 .49231 .47317 .50264 .46761 .49684 .47162 Mtetra
.49684 .47162 .50264 .46761 .51299 .46341 .50726 .46545 Mtetra
.401 .844 .734 r
.50726 .46545 .51299 .46341 .52337 .45985 .51769 .46036 Mtetra
.461 .889 .868 r
.51769 .46036 .52337 .45985 .53379 .45652 .52816 .45623 Mtetra
.455 .88 .916 r
.52816 .45623 .53379 .45652 .54425 .45318 .53867 .45287 Mtetra
.368 .833 .895 r
.53867 .45287 .54425 .45318 .55475 .44981 .54922 .45027 Mtetra
.154 .696 .755 r
.54922 .45027 .55475 .44981 .5653 .44669 .55983 .44865 Mtetra
.14 0 0 r
.55983 .44865 .5653 .44669 .57589 .4442 .5705 .44811 Mtetra
.377 0 0 r
.5705 .44811 .57589 .4442 .58656 .44309 .58127 .44899 Mtetra
.481 0 .033 r
.58127 .44899 .58656 .44309 .59732 .44364 .59212 .45093 Mtetra
.515 .061 .11 r
.59212 .45093 .59732 .44364 .60821 .44636 .60306 .45338 Mtetra
.485 .023 .08 r
.60306 .45338 .60821 .44636 .61922 .45041 .61406 .45509 Mtetra
.269 0 0 r
.61406 .45509 .61922 .45041 .63031 .45427 .62505 .45391 Mtetra
.554 .927 .922 r
.62505 .45391 .63031 .45427 .64142 .45628 .63599 .44923 Mtetra
.798 .772 .829 r
.63599 .44923 .64142 .45628 .65244 .45351 .64678 .44003 Mtetra
.765 .648 .733 r
.64678 .44003 .65244 .45351 .66331 .44639 .65748 .42813 Mtetra
.725 .587 .701 r
.65748 .42813 .66331 .44639 .67404 .43564 .66817 .41654 Mtetra
.699 .567 .702 r
.66817 .41654 .67404 .43564 .6847 .42367 .67895 .40691 Mtetra
.651 .558 .736 r
.67895 .40691 .6847 .42367 .69548 .41419 .68995 .40181 Mtetra
.592 .579 .807 r
.68995 .40181 .69548 .41419 .70643 .40758 .70119 .40024 Mtetra
.476 .641 .929 r
.70119 .40024 .70643 .40758 .7176 .40447 .7126 .4008 Mtetra
.238 .657 .96 r
.7126 .4008 .7176 .40447 .72897 .4036 .72415 .40219 Mtetra
.118 .653 .859 r
.72415 .40219 .72897 .4036 .74044 .40336 .73571 .40258 Mtetra
.172 .703 .845 r
.73571 .40258 .74044 .40336 .75198 .40311 .74726 .40183 Mtetra
.38 .829 .937 r
.74726 .40183 .75198 .40311 .76351 .40191 .75877 .39957 Mtetra
.552 .884 .988 r
.75877 .39957 .76351 .40191 .77505 .39986 .77026 .39621 Mtetra
.645 .869 .983 r
.77026 .39621 .77505 .39986 .78657 .39691 .78173 .39212 Mtetra
.681 .835 .957 r
.78173 .39212 .78657 .39691 .79809 .39333 .79321 .38759 Mtetra
.687 .801 .935 r
.79321 .38759 .79809 .39333 .80963 .38938 .80473 .38302 Mtetra
.687 .778 .921 r
.80473 .38302 .80963 .38938 .82119 .3852 .8163 .37844 Mtetra
.68 .763 .914 r
.8163 .37844 .82119 .3852 .83279 .38098 .82792 .37404 Mtetra
.676 .756 .912 r
.82792 .37404 .83279 .38098 .84443 .37674 .83959 .36974 Mtetra
.672 .754 .912 r
.83959 .36974 .84443 .37674 .85612 .37252 .85132 .36555 Mtetra
.668 .754 .915 r
.85132 .36555 .85612 .37252 .86786 .36837 .8631 .36144 Mtetra
.654 .751 .921 r
.23264 .55431 .23902 .55988 .24846 .5572 .24212 .55134 Mtetra
.651 .74 .915 r
.24212 .55134 .24846 .5572 .25792 .55461 .25163 .54843 Mtetra
.645 .729 .91 r
.25163 .54843 .25792 .55461 .26742 .55212 .26116 .54566 Mtetra
.635 .717 .907 r
.26116 .54566 .26742 .55212 .27694 .54974 .27072 .54311 Mtetra
.621 .708 .908 r
.27072 .54311 .27694 .54974 .28649 .54753 .28028 .54088 Mtetra
.607 .704 .912 r
.28028 .54088 .28649 .54753 .29607 .54533 .28986 .53896 Mtetra
.587 .707 .926 r
.28986 .53896 .29607 .54533 .3057 .54308 .29946 .53741 Mtetra
.575 .728 .947 r
.29946 .53741 .3057 .54308 .3154 .54042 .3091 .53593 Mtetra
.557 .77 .978 r
.3091 .53593 .3154 .54042 .32517 .53706 .31879 .53437 Mtetra
.552 .844 .998 r
.31879 .53437 .32517 .53706 .33504 .53264 .32856 .5321 Mtetra
.543 .909 .958 r
.32856 .5321 .33504 .53264 .34502 .52676 .33845 .5286 Mtetra
.521 .916 .823 r
.33845 .5286 .34502 .52676 .35507 .51977 .34846 .5233 Mtetra
.585 .927 .727 r
.34846 .5233 .35507 .51977 .36518 .51179 .35862 .51564 Mtetra
.686 .963 .732 r
.35862 .51564 .36518 .51179 .37526 .5046 .36886 .50634 Mtetra
.851 .994 .833 r
.36886 .50634 .37526 .5046 .38527 .49948 .37915 .49583 Mtetra
.827 .847 .862 r
.37915 .49583 .38527 .49948 .39517 .4978 .38937 .48695 Mtetra
.69 .639 .793 r
.38937 .48695 .39517 .4978 .40496 .50055 .39946 .48168 Mtetra
.568 .485 .721 r
.39946 .48168 .40496 .50055 .41475 .50525 .40941 .48109 Mtetra
.468 .388 .683 r
.40941 .48109 .41475 .50525 .42462 .51028 .41924 .48586 Mtetra
.429 .361 .679 r
.41924 .48586 .42462 .51028 .43465 .51269 .4291 .4925 Mtetra
.406 .373 .71 r
.4291 .4925 .43465 .51269 .44486 .51067 .43907 .49882 Mtetra
.404 .478 .822 r
.43907 .49882 .44486 .51067 .45518 .50519 .4492 .50231 Mtetra
.405 .781 .993 r
.4492 .50231 .45518 .50519 .46558 .49686 .4595 .5015 Mtetra
.004 0 0 r
.4595 .5015 .46558 .49686 .476 .48778 .4699 .49759 Mtetra
.142 0 0 r
.4699 .49759 .476 .48778 .48642 .47918 .48037 .49128 Mtetra
.194 0 .085 r
.48037 .49128 .48642 .47918 .49684 .47162 .49087 .48425 Mtetra
.228 0 .115 r
.49087 .48425 .49684 .47162 .50726 .46545 .50138 .47753 Mtetra
.253 0 .115 r
.50138 .47753 .50726 .46545 .51769 .46036 .51191 .47164 Mtetra
.291 0 .115 r
.51191 .47164 .51769 .46036 .52816 .45623 .52246 .46699 Mtetra
.337 0 .124 r
.52246 .46699 .52816 .45623 .53867 .45287 .53305 .46362 Mtetra
.389 0 .15 r
.53305 .46362 .53867 .45287 .54922 .45027 .54369 .46153 Mtetra
.441 .043 .187 r
.54369 .46153 .54922 .45027 .55983 .44865 .55438 .46069 Mtetra
.474 .084 .219 r
.55438 .46069 .55983 .44865 .5705 .44811 .56515 .4607 Mtetra
.486 .101 .234 r
.56515 .4607 .5705 .44811 .58127 .44899 .57598 .46102 Mtetra
.462 .071 .212 r
.57598 .46102 .58127 .44899 .59212 .45093 .58687 .46063 Mtetra
.342 0 .096 r
.58687 .46063 .59212 .45093 .60306 .45338 .59777 .45783 Mtetra
0 0 0 r
.59777 .45783 .60306 .45338 .61406 .45509 .60863 .45189 Mtetra
.858 .897 .862 r
.60863 .45189 .61406 .45509 .62505 .45391 .6194 .44156 Mtetra
.79 .672 .733 r
.6194 .44156 .62505 .45391 .63599 .44923 .63007 .42835 Mtetra
.728 .573 .68 r
.63007 .42835 .63599 .44923 .64678 .44003 .6407 .41476 Mtetra
.69 .53 .666 r
.6407 .41476 .64678 .44003 .65748 .42813 .65138 .40305 Mtetra
.636 .498 .677 r
.65138 .40305 .65748 .42813 .66817 .41654 .66227 .39678 Mtetra
.582 .494 .719 r
.66227 .39678 .66817 .41654 .67895 .40691 .67342 .3953 Mtetra
.466 .523 .833 r
.67342 .3953 .67895 .40691 .68995 .40181 .68481 .39753 Mtetra
.039 .495 .884 r
.68481 .39753 .68995 .40181 .70119 .40024 .69637 .40145 Mtetra
.355 0 0 r
.69637 .40145 .70119 .40024 .7126 .4008 .70796 .40416 Mtetra
.349 0 0 r
.70796 .40416 .7126 .4008 .72415 .40219 .71954 .40518 Mtetra
.15 0 0 r
.71954 .40518 .72415 .40219 .73571 .40258 .73105 .40379 Mtetra
.206 .724 .696 r
.73105 .40379 .73571 .40258 .74726 .40183 .74249 .40054 Mtetra
.573 .924 .954 r
.74249 .40054 .74726 .40183 .75877 .39957 .7539 .39601 Mtetra
.701 .89 .966 r
.7539 .39601 .75877 .39957 .77026 .39621 .76528 .39073 Mtetra
.715 .819 .93 r
.76528 .39073 .77026 .39621 .78173 .39212 .7767 .38537 Mtetra
.709 .773 .902 r
.7767 .38537 .78173 .39212 .79321 .38759 .78815 .38007 Mtetra
.694 .744 .89 r
.78815 .38007 .79321 .38759 .80473 .38302 .79968 .37516 Mtetra
.683 .73 .886 r
.79968 .37516 .80473 .38302 .8163 .37844 .81127 .37055 Mtetra
.673 .726 .889 r
.81127 .37055 .8163 .37844 .82792 .37404 .82293 .36627 Mtetra
.666 .727 .896 r
.82293 .36627 .82792 .37404 .83959 .36974 .83467 .36221 Mtetra
.661 .734 .904 r
.83467 .36221 .83959 .36974 .85132 .36555 .84646 .35831 Mtetra
.658 .743 .912 r
.84646 .35831 .85132 .36555 .8631 .36144 .85831 .35446 Mtetra
.669 .754 .915 r
.22623 .54871 .23264 .55431 .24212 .55134 .23576 .54534 Mtetra
.668 .742 .905 r
.23576 .54534 .24212 .55134 .25163 .54843 .24532 .54198 Mtetra
.663 .726 .896 r
.24532 .54198 .25163 .54843 .26116 .54566 .25491 .53871 Mtetra
.654 .709 .888 r
.25491 .53871 .26116 .54566 .27072 .54311 .26451 .53566 Mtetra
.641 .691 .881 r
.26451 .53566 .27072 .54311 .28028 .54088 .27413 .53292 Mtetra
.624 .671 .874 r
.27413 .53292 .28028 .54088 .28986 .53896 .28375 .53062 Mtetra
.601 .653 .873 r
.28375 .53062 .28986 .53896 .29946 .53741 .29337 .52892 Mtetra
.58 .641 .875 r
.29337 .52892 .29946 .53741 .3091 .53593 .303 .52775 Mtetra
.551 .638 .89 r
.303 .52775 .3091 .53593 .31879 .53437 .31264 .52716 Mtetra
.539 .663 .917 r
.31264 .52716 .31879 .53437 .32856 .5321 .32232 .52661 Mtetra
.528 .722 .962 r
.32232 .52661 .32856 .5321 .33845 .5286 .33208 .52575 Mtetra
.544 .837 .999 r
.33208 .52575 .33845 .5286 .34846 .5233 .34195 .52359 Mtetra
.55 .926 .92 r
.34195 .52359 .34846 .5233 .35862 .51564 .35198 .5193 Mtetra
.496 .879 .687 r
.35198 .5193 .35862 .51564 .36886 .50634 .36217 .51237 Mtetra
.542 .855 .556 r
.36217 .51237 .36886 .50634 .37915 .49583 .37251 .50231 Mtetra
.587 .869 .546 r
.37251 .50231 .37915 .49583 .38937 .48695 .3829 .49108 Mtetra
.759 .979 .722 r
.3829 .49108 .38937 .48695 .39946 .48168 .39328 .48004 Mtetra
.816 .928 .908 r
.39328 .48004 .39946 .48168 .40941 .48109 .40353 .47213 Mtetra
.64 .658 .851 r
.40353 .47213 .40941 .48109 .41924 .48586 .41362 .46921 Mtetra
.526 .479 .747 r
.41362 .46921 .41924 .48586 .4291 .4925 .42362 .47033 Mtetra
.462 .396 .697 r
.42362 .47033 .4291 .4925 .43907 .49882 .4336 .4749 Mtetra
.461 .386 .685 r
.4336 .4749 .43907 .49882 .4492 .50231 .44365 .4799 Mtetra
.486 .411 .698 r
.44365 .4799 .4492 .50231 .4595 .5015 .45382 .48351 Mtetra
.521 .466 .736 r
.45382 .48351 .4595 .5015 .4699 .49759 .46411 .48498 Mtetra
.581 .565 .801 r
.46411 .48498 .4699 .49759 .48037 .49128 .47451 .48384 Mtetra
.634 .703 .896 r
.47451 .48384 .48037 .49128 .49087 .48425 .48499 .48107 Mtetra
.649 .867 .981 r
.48499 .48107 .49087 .48425 .50138 .47753 .49552 .47726 Mtetra
.524 .912 .928 r
.49552 .47726 .50138 .47753 .51191 .47164 .50608 .4732 Mtetra
.305 .791 .738 r
.50608 .4732 .51191 .47164 .52246 .46699 .51669 .46937 Mtetra
0 0 0 r
.51669 .46937 .52246 .46699 .53305 .46362 .52733 .46598 Mtetra
.52733 .46598 .53305 .46362 .54369 .46153 .53801 .46304 Mtetra
.53801 .46304 .54369 .46153 .55438 .46069 .54875 .46032 Mtetra
.403 .852 .905 r
.54875 .46032 .55438 .46069 .56515 .4607 .55952 .45737 Mtetra
.655 .869 .98 r
.55952 .45737 .56515 .4607 .57598 .46102 .57033 .45335 Mtetra
.718 .733 .862 r
.57033 .45335 .57598 .46102 .58687 .46063 .58114 .4477 Mtetra
.724 .636 .759 r
.58114 .4477 .58687 .46063 .59777 .45783 .59193 .43939 Mtetra
.713 .579 .703 r
.59193 .43939 .59777 .45783 .60863 .45189 .60268 .4289 Mtetra
.702 .548 .675 r
.60268 .4289 .60863 .45189 .6194 .44156 .61339 .41696 Mtetra
.691 .534 .669 r
.61339 .41696 .6194 .44156 .63007 .42835 .62409 .40544 Mtetra
.663 .524 .684 r
.62409 .40544 .63007 .42835 .6407 .41476 .6349 .3974 Mtetra
.629 .54 .735 r
.6349 .3974 .6407 .41476 .65138 .40305 .64588 .39347 Mtetra
.481 .578 .875 r
.64588 .39347 .65138 .40305 .66227 .39678 .65711 .39464 Mtetra
0 .344 .679 r
.65711 .39464 .66227 .39678 .67342 .3953 .66856 .39903 Mtetra
.543 .015 0 r
.66856 .39903 .67342 .3953 .68481 .39753 .68012 .40363 Mtetra
.527 .043 .05 r
.68012 .40363 .68481 .39753 .69637 .40145 .69172 .40706 Mtetra
.383 0 0 r
.69172 .40706 .69637 .40145 .70796 .40416 .70324 .40731 Mtetra
.065 0 0 r
.70324 .40731 .70796 .40416 .71954 .40518 .71468 .40483 Mtetra
.517 .914 .905 r
.71468 .40483 .71954 .40518 .73105 .40379 .72603 .40015 Mtetra
.734 .894 .952 r
.72603 .40015 .73105 .40379 .74249 .40054 .73734 .39412 Mtetra
.742 .793 .893 r
.73734 .39412 .74249 .40054 .7539 .39601 .74865 .38775 Mtetra
.727 .734 .857 r
.74865 .38775 .7539 .39601 .76528 .39073 .75999 .38142 Mtetra
.705 .7 .843 r
.75999 .38142 .76528 .39073 .7767 .38537 .7714 .37569 Mtetra
.689 .686 .842 r
.7714 .37569 .7767 .38537 .78815 .38007 .78289 .37049 Mtetra
.674 .682 .85 r
.78289 .37049 .78815 .38007 .79968 .37516 .79447 .36591 Mtetra
.663 .686 .861 r
.79447 .36591 .79968 .37516 .81127 .37055 .80614 .36178 Mtetra
.655 .695 .875 r
.80614 .36178 .81127 .37055 .82293 .36627 .81788 .35798 Mtetra
.649 .706 .889 r
.81788 .35798 .82293 .36627 .83467 .36221 .82968 .35439 Mtetra
.645 .719 .902 r
.82968 .35439 .83467 .36221 .84646 .35831 .84155 .35091 Mtetra
.644 .733 .914 r
.84155 .35091 .84646 .35831 .85831 .35446 .85348 .34743 Mtetra
.682 .757 .908 r
.21976 .54307 .22623 .54871 .23576 .54534 .22935 .53934 Mtetra
.684 .746 .899 r
.22935 .53934 .23576 .54534 .24532 .54198 .23897 .53553 Mtetra
.682 .732 .888 r
.23897 .53553 .24532 .54198 .25491 .53871 .24862 .53171 Mtetra
.677 .715 .877 r
.24862 .53171 .25491 .53871 .26451 .53566 .25829 .52796 Mtetra
.669 .694 .864 r
.25829 .52796 .26451 .53566 .27413 .53292 .26799 .52435 Mtetra
.654 .668 .85 r
.26799 .52435 .27413 .53292 .28375 .53062 .27769 .52111 Mtetra
.634 .639 .837 r
.27769 .52111 .28375 .53062 .29337 .52892 .28739 .51841 Mtetra
.608 .607 .825 r
.28739 .51841 .29337 .52892 .303 .52775 .29707 .51647 Mtetra
.575 .578 .818 r
.29707 .51647 .303 .52775 .31264 .52716 .30673 .51556 Mtetra
.543 .557 .818 r
.30673 .51556 .31264 .52716 .32232 .52661 .31638 .51557 Mtetra
.502 .546 .834 r
.31638 .51557 .32232 .52661 .33208 .52575 .32603 .51653 Mtetra
.471 .574 .877 r
.32603 .51653 .33208 .52575 .34195 .52359 .33572 .51769 Mtetra
.411 .657 .96 r
.33572 .51769 .34195 .52359 .35198 .5193 .3455 .51848 Mtetra
.233 .742 .884 r
.3455 .51848 .35198 .5193 .36217 .51237 .35543 .51755 Mtetra
.035 0 0 r
.35543 .51755 .36217 .51237 .37251 .50231 .36554 .51381 Mtetra
.107 0 .006 r
.36554 .51381 .37251 .50231 .3829 .49108 .37586 .50631 Mtetra
.013 0 .043 r
.37586 .50631 .3829 .49108 .39328 .48004 .38637 .49443 Mtetra
0 0 0 r
.38637 .49443 .39328 .48004 .40353 .47213 .39694 .48046 Mtetra
.627 .85 .47 r
.39694 .48046 .40353 .47213 .41362 .46921 .40751 .46604 Mtetra
.869 .86 .829 r
.40751 .46604 .41362 .46921 .42362 .47033 .41795 .45467 Mtetra
.675 .575 .735 r
.41795 .45467 .42362 .47033 .4336 .4749 .42822 .44846 Mtetra
.577 .451 .671 r
.42822 .44846 .4336 .4749 .44365 .4799 .43839 .44683 Mtetra
.521 .391 .644 r
.43839 .44683 .44365 .4799 .45382 .48351 .44851 .4494 Mtetra
.502 .376 .64 r
.44851 .4494 .45382 .48351 .46411 .48498 .45868 .45349 Mtetra
.5 .382 .65 r
.45868 .45349 .46411 .48498 .47451 .48384 .46894 .4575 Mtetra
.509 .407 .675 r
.46894 .4575 .47451 .48384 .48499 .48107 .4793 .46034 Mtetra
.535 .455 .712 r
.4793 .46034 .48499 .48107 .49552 .47726 .48975 .46131 Mtetra
.566 .515 .757 r
.48975 .46131 .49552 .47726 .50608 .4732 .50029 .46071 Mtetra
.607 .582 .8 r
.50029 .46071 .50608 .4732 .51669 .46937 .51089 .45857 Mtetra
.644 .63 .821 r
.51089 .45857 .51669 .46937 .52733 .46598 .52155 .45515 Mtetra
.675 .644 .811 r
.52155 .45515 .52733 .46598 .53801 .46304 .53224 .45045 Mtetra
.694 .625 .775 r
.53224 .45045 .53801 .46304 .54875 .46032 .54296 .44421 Mtetra
.695 .587 .73 r
.54296 .44421 .54875 .46032 .55952 .45737 .55369 .43637 Mtetra
.69 .55 .69 r
.55369 .43637 .55952 .45737 .57033 .45335 .5644 .42663 Mtetra
.677 .517 .662 r
.5644 .42663 .57033 .45335 .58114 .4477 .5751 .41569 Mtetra
.66 .491 .644 r
.5751 .41569 .58114 .4477 .59193 .43939 .58579 .40464 Mtetra
.641 .471 .638 r
.58579 .40464 .59193 .43939 .60268 .4289 .59651 .39511 Mtetra
.607 .45 .644 r
.59651 .39511 .60268 .4289 .61339 .41696 .60733 .38981 Mtetra
.563 .442 .672 r
.60733 .38981 .61339 .41696 .62409 .40544 .61832 .38916 Mtetra
.427 .43 .76 r
.61832 .38916 .62409 .40544 .6349 .3974 .62955 .39378 Mtetra
.397 0 0 r
.62955 .39378 .6349 .3974 .64588 .39347 .64099 .40153 Mtetra
.637 .196 .186 r
.64099 .40153 .64588 .39347 .65711 .39464 .65254 .40887 Mtetra
.587 .207 .288 r
.65254 .40887 .65711 .39464 .66856 .39903 .66411 .41411 Mtetra
.502 .132 .27 r
.66411 .41411 .66856 .39903 .68012 .40363 .67559 .41489 Mtetra
.361 0 .143 r
.67559 .41489 .68012 .40363 .69172 .40706 .68695 .41181 Mtetra
0 0 0 r
.68695 .41181 .69172 .40706 .70324 .40731 .69821 .40583 Mtetra
.769 .971 .922 r
.69821 .40583 .70324 .40731 .71468 .40483 .70939 .39807 Mtetra
.782 .791 .86 r
.70939 .39807 .71468 .40483 .72603 .40015 .72057 .38992 Mtetra
.743 .695 .806 r
.72057 .38992 .72603 .40015 .73734 .39412 .73177 .38194 Mtetra
.709 .647 .786 r
.73177 .38194 .73734 .39412 .74865 .38775 .74306 .37494 Mtetra
.687 .628 .784 r
.74306 .37494 .74865 .38775 .75999 .38142 .75444 .36888 Mtetra
.668 .623 .795 r
.75444 .36888 .75999 .38142 .7714 .37569 .76592 .36388 Mtetra
.654 .628 .812 r
.76592 .36388 .7714 .37569 .78289 .37049 .77751 .35966 Mtetra
.644 .642 .834 r
.77751 .35966 .78289 .37049 .79447 .36591 .78919 .35602 Mtetra
.636 .659 .856 r
.78919 .35602 .79447 .36591 .80614 .36178 .80095 .35275 Mtetra
.633 .68 .876 r
.80095 .35275 .80614 .36178 .81788 .35798 .81278 .34961 Mtetra
.63 .697 .893 r
.81278 .34961 .81788 .35798 .82968 .35439 .82467 .34656 Mtetra
.629 .714 .907 r
.82467 .34656 .82968 .35439 .84155 .35091 .83662 .3435 Mtetra
.631 .729 .918 r
.83662 .3435 .84155 .35091 .85348 .34743 .84861 .34035 Mtetra
.683 .757 .908 r
.21326 .53739 .21976 .54307 .22935 .53934 .22287 .53361 Mtetra
.688 .757 .904 r
.22287 .53361 .22935 .53934 .23897 .53553 .23252 .52968 Mtetra
.691 .755 .9 r
.23252 .52968 .23897 .53553 .24862 .53171 .24221 .52562 Mtetra
.694 .748 .893 r
.24221 .52562 .24862 .53171 .25829 .52796 .25194 .52145 Mtetra
.696 .736 .882 r
.25194 .52145 .25829 .52796 .26799 .52435 .26171 .51715 Mtetra
.69 .715 .868 r
.26171 .51715 .26799 .52435 .27769 .52111 .2715 .51292 Mtetra
.678 .687 .851 r
.2715 .51292 .27769 .52111 .28739 .51841 .28131 .50889 Mtetra
.656 .649 .831 r
.28131 .50889 .28739 .51841 .29707 .51647 .2911 .50541 Mtetra
.626 .607 .811 r
.2911 .50541 .29707 .51647 .30673 .51556 .30088 .50279 Mtetra
.59 .562 .791 r
.30088 .50279 .30673 .51556 .31638 .51557 .31062 .50135 Mtetra
.547 .519 .776 r
.31062 .50135 .31638 .51557 .32603 .51653 .32031 .50141 Mtetra
.51 .487 .767 r
.32031 .50141 .32603 .51653 .33572 .51769 .32998 .50276 Mtetra
.468 .465 .772 r
.32998 .50276 .33572 .51769 .3455 .51848 .33965 .50534 Mtetra
.448 .481 .8 r
.33965 .50534 .3455 .51848 .35543 .51755 .34938 .508 Mtetra
.437 .551 .873 r
.34938 .508 .35543 .51755 .36554 .51381 .35923 .50983 Mtetra
.48 .771 .995 r
.35923 .50983 .36554 .51381 .37586 .50631 .36927 .50886 Mtetra
.41 .848 .729 r
.36927 .50886 .37586 .50631 .38637 .49443 .37956 .50365 Mtetra
0 0 0 r
.37956 .50365 .38637 .49443 .39694 .48046 .39003 .49442 Mtetra
.39003 .49442 .39694 .48046 .40751 .46604 .40065 .48142 Mtetra
0 0 .011 r
.40065 .48142 .40751 .46604 .41795 .45467 .41127 .46791 Mtetra
0 0 0 r
.41127 .46791 .41795 .45467 .42822 .44846 .42181 .45595 Mtetra
.42181 .45595 .42822 .44846 .43839 .44683 .43225 .44701 Mtetra
.599 .946 .919 r
.43225 .44701 .43839 .44683 .44851 .4494 .4426 .44196 Mtetra
.623 .698 .898 r
.4426 .44196 .44851 .4494 .45868 .45349 .45292 .43947 Mtetra
.567 .537 .781 r
.45292 .43947 .45868 .45349 .46894 .4575 .46325 .43879 Mtetra
.557 .483 .727 r
.46325 .43879 .46894 .4575 .4793 .46034 .47363 .43857 Mtetra
.564 .466 .702 r
.47363 .43857 .4793 .46034 .48975 .46131 .48408 .43798 Mtetra
.575 .465 .691 r
.48408 .43798 .48975 .46131 .50029 .46071 .49459 .43664 Mtetra
.589 .471 .686 r
.49459 .43664 .50029 .46071 .51089 .45857 .50516 .43424 Mtetra
.604 .479 .683 r
.50516 .43424 .51089 .45857 .52155 .45515 .51578 .43079 Mtetra
.617 .488 .682 r
.51578 .43079 .52155 .45515 .53224 .45045 .52644 .42626 Mtetra
.631 .497 .681 r
.52644 .42626 .53224 .45045 .54296 .44421 .53714 .42068 Mtetra
.642 .507 .684 r
.53714 .42068 .54296 .44421 .55369 .43637 .54785 .41433 Mtetra
.651 .521 .691 r
.54785 .41433 .55369 .43637 .5644 .42663 .55859 .4076 Mtetra
.658 .543 .713 r
.55859 .4076 .5644 .42663 .5751 .41569 .56935 .40133 Mtetra
.65 .581 .764 r
.56935 .40133 .5751 .41569 .58579 .40464 .58017 .39686 Mtetra
.593 .684 .905 r
.58017 .39686 .58579 .40464 .59651 .39511 .59108 .395 Mtetra
.219 0 0 r
.59108 .395 .59651 .39511 .60733 .38981 .60213 .39709 Mtetra
.589 .133 .138 r
.60213 .39709 .60733 .38981 .61832 .38916 .61336 .40226 Mtetra
.615 .227 .284 r
.61336 .40226 .61832 .38916 .62955 .39378 .62473 .40904 Mtetra
.603 .229 .307 r
.62473 .40904 .62955 .39378 .64099 .40153 .63621 .41534 Mtetra
.533 .15 .26 r
.63621 .41534 .64099 .40153 .65254 .40887 .64766 .41783 Mtetra
.37 0 .074 r
.64766 .41783 .65254 .40887 .66411 .41411 .65903 .41621 Mtetra
.398 .834 .697 r
.65903 .41621 .66411 .41411 .67559 .41489 .67026 .41024 Mtetra
.816 .864 .883 r
.67026 .41024 .67559 .41489 .68695 .41181 .68138 .40139 Mtetra
.77 .701 .787 r
.68138 .40139 .68695 .41181 .69821 .40583 .69246 .39167 Mtetra
.734 .632 .746 r
.69246 .39167 .69821 .40583 .70939 .39807 .70355 .38199 Mtetra
.702 .597 .735 r
.70355 .38199 .70939 .39807 .72057 .38992 .71472 .37357 Mtetra
.682 .583 .738 r
.71472 .37357 .72057 .38992 .73177 .38194 .72598 .36646 Mtetra
.662 .582 .754 r
.72598 .36646 .73177 .38194 .74306 .37494 .73737 .36091 Mtetra
.647 .591 .778 r
.73737 .36091 .74306 .37494 .75444 .36888 .74888 .35656 Mtetra
.634 .61 .808 r
.74888 .35656 .75444 .36888 .76592 .36388 .7605 .3531 Mtetra
.623 .634 .84 r
.7605 .3531 .76592 .36388 .77751 .35966 .77221 .35022 Mtetra
.619 .662 .87 r
.77221 .35022 .77751 .35966 .78919 .35602 .784 .34754 Mtetra
.615 .687 .894 r
.784 .34754 .78919 .35602 .80095 .35275 .79585 .34494 Mtetra
.618 .709 .911 r
.79585 .34494 .80095 .35275 .81278 .34961 .80774 .3422 Mtetra
.62 .724 .92 r
.80774 .3422 .81278 .34961 .82467 .34656 .81969 .33934 Mtetra
.624 .733 .925 r
.81969 .33934 .82467 .34656 .83662 .3435 .83167 .33635 Mtetra
.629 .738 .926 r
.83167 .33635 .83662 .3435 .84861 .34035 .8437 .33321 Mtetra
.672 .755 .913 r
.20671 .53168 .21326 .53739 .22287 .53361 .21631 .52818 Mtetra
.677 .767 .918 r
.21631 .52818 .22287 .53361 .23252 .52968 .22596 .52452 Mtetra
.685 .779 .922 r
.22596 .52452 .23252 .52968 .24221 .52562 .23566 .52065 Mtetra
.696 .789 .922 r
.23566 .52065 .24221 .52562 .25194 .52145 .24541 .51649 Mtetra
.71 .792 .915 r
.24541 .51649 .25194 .52145 .26171 .51715 .25522 .51193 Mtetra
.72 .785 .904 r
.25522 .51193 .26171 .51715 .2715 .51292 .26509 .50705 Mtetra
.726 .765 .884 r
.26509 .50705 .2715 .51292 .28131 .50889 .27501 .50184 Mtetra
.717 .729 .86 r
.27501 .50184 .28131 .50889 .2911 .50541 .28495 .49661 Mtetra
.699 .682 .829 r
.28495 .49661 .2911 .50541 .30088 .50279 .2949 .49157 Mtetra
.667 .623 .797 r
.2949 .49157 .30088 .50279 .31062 .50135 .30483 .48726 Mtetra
.627 .565 .765 r
.30483 .48726 .31062 .50135 .32031 .50141 .31472 .48414 Mtetra
.585 .509 .735 r
.31472 .48414 .32031 .50141 .32998 .50276 .32454 .48261 Mtetra
.541 .459 .712 r
.32454 .48261 .32998 .50276 .33965 .50534 .3343 .48311 Mtetra
.505 .423 .697 r
.3343 .48311 .33965 .50534 .34938 .508 .34401 .48545 Mtetra
.466 .396 .694 r
.34401 .48545 .34938 .508 .35923 .50983 .3537 .48958 Mtetra
.427 .387 .711 r
.3537 .48958 .35923 .50983 .36927 .50886 .36343 .49468 Mtetra
.342 .403 .78 r
.36343 .49468 .36927 .50886 .37956 .50365 .37323 .50002 Mtetra
0 .438 .809 r
.37323 .50002 .37956 .50365 .39003 .49442 .38321 .50354 Mtetra
.443 .012 .124 r
.38321 .50354 .39003 .49442 .40065 .48142 .39339 .50365 Mtetra
.412 .092 .311 r
.39339 .50365 .40065 .48142 .41127 .46791 .40382 .49897 Mtetra
.362 .08 .344 r
.40382 .49897 .41127 .46791 .42181 .45595 .41446 .48885 Mtetra
.316 .046 .336 r
.41446 .48885 .42181 .45595 .43225 .44701 .42519 .47553 Mtetra
.235 0 .284 r
.42519 .47553 .43225 .44701 .4426 .44196 .43594 .46056 Mtetra
.052 0 .12 r
.43594 .46056 .4426 .44196 .45292 .43947 .44664 .44645 Mtetra
0 0 0 r
.44664 .44645 .45292 .43947 .46325 .43879 .45726 .43465 Mtetra
.832 .849 .858 r
.45726 .43465 .46325 .43879 .47363 .43857 .46783 .42523 Mtetra
.701 .616 .759 r
.46783 .42523 .47363 .43857 .48408 .43798 .47837 .41825 Mtetra
.643 .528 .708 r
.47837 .41825 .48408 .43798 .49459 .43664 .4889 .41283 Mtetra
.615 .488 .684 r
.4889 .41283 .49459 .43664 .50516 .43424 .49946 .40857 Mtetra
.601 .471 .676 r
.49946 .40857 .50516 .43424 .51578 .43079 .51004 .40507 Mtetra
.591 .464 .676 r
.51004 .40507 .51578 .43079 .52644 .42626 .52067 .40234 Mtetra
.576 .463 .688 r
.52067 .40234 .52644 .42626 .53714 .42068 .53134 .40076 Mtetra
.551 .472 .719 r
.53134 .40076 .53714 .42068 .54785 .41433 .54208 .40077 Mtetra
.465 .49 .8 r
.54208 .40077 .54785 .41433 .55859 .4076 .55291 .40325 Mtetra
0 .388 .805 r
.55291 .40325 .55859 .4076 .56935 .40133 .56384 .40816 Mtetra
.641 .188 .159 r
.56384 .40816 .56935 .40133 .58017 .39686 .57492 .41543 Mtetra
.622 .269 .351 r
.57492 .41543 .58017 .39686 .59108 .395 .58613 .42361 Mtetra
.586 .27 .401 r
.58613 .42361 .59108 .395 .60213 .39709 .59742 .43016 Mtetra
.551 .25 .41 r
.59742 .43016 .60213 .39709 .61336 .40226 .60875 .43348 Mtetra
.49 .192 .388 r
.60875 .43348 .61336 .40226 .62473 .40904 .62001 .43129 Mtetra
.373 .061 .301 r
.62001 .43129 .62473 .40904 .63621 .41534 .63117 .42421 Mtetra
0 0 0 r
.63117 .42421 .63621 .41534 .64766 .41783 .64222 .41363 Mtetra
.881 .872 .824 r
.64222 .41363 .64766 .41783 .65903 .41621 .65319 .40116 Mtetra
.757 .634 .724 r
.65319 .40116 .65903 .41621 .67026 .41024 .66415 .38889 Mtetra
.704 .559 .687 r
.66415 .38889 .67026 .41024 .68138 .40139 .67515 .3776 Mtetra
.674 .528 .679 r
.67515 .3776 .68138 .40139 .69246 .39167 .68622 .36813 Mtetra
.654 .518 .685 r
.68622 .36813 .69246 .39167 .70355 .38199 .69741 .36053 Mtetra
.636 .518 .702 r
.69741 .36053 .70355 .38199 .71472 .37357 .70873 .35501 Mtetra
.621 .53 .73 r
.70873 .35501 .71472 .37357 .72598 .36646 .72019 .35113 Mtetra
.608 .554 .768 r
.72019 .35113 .72598 .36646 .73737 .36091 .73177 .34847 Mtetra
.594 .588 .815 r
.73177 .34847 .73737 .36091 .74888 .35656 .74347 .34657 Mtetra
.587 .634 .865 r
.74347 .34657 .74888 .35656 .7605 .3531 .75523 .34488 Mtetra
.58 .678 .907 r
.75523 .34488 .7605 .3531 .77221 .35022 .76707 .34318 Mtetra
.585 .719 .936 r
.76707 .34318 .77221 .35022 .784 .34754 .77894 .34112 Mtetra
.593 .746 .95 r
.77894 .34112 .784 .34754 .79585 .34494 .79084 .33874 Mtetra
.609 .762 .953 r
.79084 .33874 .79585 .34494 .80774 .3422 .80277 .33595 Mtetra
.622 .767 .949 r
.80277 .33595 .80774 .3422 .81969 .33934 .81473 .33284 Mtetra
.633 .764 .942 r
.81473 .33284 .81969 .33934 .83167 .33635 .82673 .32951 Mtetra
.64 .755 .932 r
.82673 .32951 .83167 .33635 .8437 .33321 .83876 .32602 Mtetra
.647 .749 .924 r
.20012 .52592 .20671 .53168 .21631 .52818 .20968 .52298 Mtetra
.649 .771 .937 r
.20968 .52298 .21631 .52818 .22596 .52452 .21929 .51995 Mtetra
.655 .796 .95 r
.21929 .51995 .22596 .52452 .23566 .52065 .22896 .51672 Mtetra
.666 .824 .959 r
.22896 .51672 .23566 .52065 .24541 .51649 .23869 .51315 Mtetra
.683 .851 .963 r
.23869 .51315 .24541 .51649 .25522 .51193 .24849 .50913 Mtetra
.703 .875 .962 r
.24849 .50913 .25522 .51193 .26509 .50705 .25836 .50457 Mtetra
.73 .89 .953 r
.25836 .50457 .26509 .50705 .27501 .50184 .26831 .49935 Mtetra
.751 .892 .942 r
.26831 .49935 .27501 .50184 .28495 .49661 .27833 .49359 Mtetra
.769 .872 .923 r
.27833 .49359 .28495 .49661 .2949 .49157 .2884 .48731 Mtetra
.766 .827 .9 r
.2884 .48731 .2949 .49157 .30483 .48726 .2985 .48096 Mtetra
.744 .759 .865 r
.2985 .48096 .30483 .48726 .31472 .48414 .3086 .47486 Mtetra
.699 .674 .822 r
.3086 .47486 .31472 .48414 .32454 .48261 .31866 .46967 Mtetra
.644 .589 .778 r
.31866 .46967 .32454 .48261 .3343 .48311 .32866 .46596 Mtetra
.588 .512 .737 r
.32866 .46596 .3343 .48311 .34401 .48545 .33858 .46424 Mtetra
.535 .449 .704 r
.33858 .46424 .34401 .48545 .3537 .48958 .34842 .46502 Mtetra
.489 .4 .681 r
.34842 .46502 .3537 .48958 .36343 .49468 .35818 .46834 Mtetra
.444 .361 .668 r
.35818 .46834 .36343 .49468 .37323 .50002 .36791 .47415 Mtetra
.428 .353 .67 r
.36791 .47415 .37323 .50002 .38321 .50354 .3777 .48062 Mtetra
.429 .371 .691 r
.3777 .48062 .38321 .50354 .39339 .50365 .38762 .48633 Mtetra
.479 .449 .746 r
.38762 .48633 .39339 .50365 .40382 .49897 .39776 .489 Mtetra
.598 .626 .85 r
.39776 .489 .40382 .49897 .41446 .48885 .40813 .48718 Mtetra
.709 .933 .962 r
.40813 .48718 .41446 .48885 .42519 .47553 .41866 .48166 Mtetra
0 0 0 r
.41866 .48166 .42519 .47553 .43594 .46056 .42932 .47303 Mtetra
.031 0 0 r
.42932 .47303 .43594 .46056 .44664 .44645 .44001 .46339 Mtetra
.2 0 .161 r
.44001 .46339 .44664 .44645 .45726 .43465 .45069 .45401 Mtetra
.285 0 .231 r
.45069 .45401 .45726 .43465 .46783 .42523 .46136 .44561 Mtetra
.343 .02 .266 r
.46136 .44561 .46783 .42523 .47837 .41825 .47201 .43867 Mtetra
.376 .051 .281 r
.47201 .43867 .47837 .41825 .4889 .41283 .48267 .43296 Mtetra
.403 .074 .289 r
.48267 .43296 .4889 .41283 .49946 .40857 .49334 .42845 Mtetra
.425 .092 .295 r
.49334 .42845 .49946 .40857 .51004 .40507 .50404 .42495 Mtetra
.448 .113 .304 r
.50404 .42495 .51004 .40507 .52067 .40234 .51478 .42247 Mtetra
.474 .137 .315 r
.51478 .42247 .52067 .40234 .53134 .40076 .52556 .42118 Mtetra
.498 .161 .326 r
.52556 .42118 .53134 .40076 .54208 .40077 .53641 .42114 Mtetra
.523 .184 .334 r
.53641 .42114 .54208 .40077 .55291 .40325 .54734 .42259 Mtetra
.539 .192 .329 r
.54734 .42259 .55291 .40325 .56384 .40816 .55835 .42505 Mtetra
.541 .18 .304 r
.55835 .42505 .56384 .40816 .57492 .41543 .56945 .42779 Mtetra
.51 .112 .222 r
.56945 .42779 .57492 .41543 .58613 .42361 .58063 .42953 Mtetra
.289 0 0 r
.58063 .42953 .58613 .42361 .59742 .43016 .59181 .42813 Mtetra
.667 .929 .971 r
.59181 .42813 .59742 .43016 .60875 .43348 .60297 .42297 Mtetra
.768 .697 .784 r
.60297 .42297 .60875 .43348 .62001 .43129 .61404 .41323 Mtetra
.74 .6 .701 r
.61404 .41323 .62001 .43129 .63117 .42421 .62501 .40036 Mtetra
.713 .552 .669 r
.62501 .40036 .63117 .42421 .64222 .41363 .63594 .38668 Mtetra
.693 .528 .659 r
.63594 .38668 .64222 .41363 .65319 .40116 .64686 .37364 Mtetra
.669 .51 .661 r
.64686 .37364 .65319 .40116 .66415 .38889 .65787 .36314 Mtetra
.65 .505 .673 r
.65787 .36314 .66415 .38889 .67515 .3776 .669 .3552 Mtetra
.631 .509 .696 r
.669 .3552 .67515 .3776 .68622 .36813 .68026 .34983 Mtetra
.612 .526 .733 r
.68026 .34983 .68622 .36813 .69741 .36053 .69167 .3465 Mtetra
.59 .56 .789 r
.69167 .3465 .69741 .36053 .70873 .35501 .70321 .3447 Mtetra
.559 .611 .861 r
.70321 .3447 .70873 .35501 .72019 .35113 .71487 .34383 Mtetra
.521 .678 .937 r
.71487 .34383 .72019 .35113 .73177 .34847 .72661 .34324 Mtetra
.475 .735 .984 r
.72661 .34324 .73177 .34847 .74347 .34657 .73843 .34258 Mtetra
.46 .781 .998 r
.73843 .34258 .74347 .34657 .75523 .34488 .75028 .34139 Mtetra
.475 .81 .999 r
.75028 .34139 .75523 .34488 .76707 .34318 .76215 .33965 Mtetra
.524 .834 1 r
.76215 .33965 .76707 .34318 .77894 .34112 .77404 .33722 Mtetra
.573 .841 .995 r
.77404 .33722 .77894 .34112 .79084 .33874 .78594 .33423 Mtetra
.615 .834 .984 r
.78594 .33423 .79084 .33874 .80277 .33595 .79786 .33076 Mtetra
.641 .818 .968 r
.79786 .33076 .80277 .33595 .81473 .33284 .8098 .32694 Mtetra
.656 .797 .95 r
.8098 .32694 .81473 .33284 .82673 .32951 .82177 .3229 Mtetra
.662 .775 .933 r
.82177 .3229 .82673 .32951 .83876 .32602 .83378 .31877 Mtetra
.616 .741 .935 r
.19348 .52013 .20012 .52592 .20968 .52298 .203 .51783 Mtetra
.609 .763 .953 r
.203 .51783 .20968 .52298 .21929 .51995 .21256 .51555 Mtetra
.605 .792 .971 r
.21256 .51555 .21929 .51995 .22896 .51672 .22217 .51317 Mtetra
.601 .826 .986 r
.22217 .51317 .22896 .51672 .23869 .51315 .23184 .51057 Mtetra
.595 .863 .993 r
.23184 .51057 .23869 .51315 .24849 .50913 .24158 .50767 Mtetra
.59 .901 .985 r
.24158 .50767 .24849 .50913 .25836 .50457 .25139 .50426 Mtetra
.588 .929 .955 r
.25139 .50426 .25836 .50457 .26831 .49935 .26129 .50015 Mtetra
.588 .944 .908 r
.26129 .50015 .26831 .49935 .27833 .49359 .27129 .4952 Mtetra
.618 .959 .869 r
.27129 .4952 .27833 .49359 .2884 .48731 .28139 .48924 Mtetra
.668 .975 .857 r
.28139 .48924 .2884 .48731 .2985 .48096 .29158 .48237 Mtetra
.753 .992 .88 r
.29158 .48237 .2985 .48096 .3086 .47486 .30184 .47459 Mtetra
.814 .963 .905 r
.30184 .47459 .3086 .47486 .31866 .46967 .31214 .46643 Mtetra
.816 .865 .884 r
.31214 .46643 .31866 .46967 .32866 .46596 .32244 .45826 Mtetra
.758 .728 .825 r
.32244 .45826 .32866 .46596 .33858 .46424 .33271 .45084 Mtetra
.686 .605 .76 r
.33271 .45084 .33858 .46424 .34842 .46502 .34292 .44479 Mtetra
.627 .513 .704 r
.34292 .44479 .34842 .46502 .35818 .46834 .35306 .44038 Mtetra
.583 .448 .663 r
.35306 .44038 .35818 .46834 .36791 .47415 .36313 .43794 Mtetra
.551 .403 .634 r
.36313 .43794 .36791 .47415 .3777 .48062 .37315 .43767 Mtetra
.526 .373 .616 r
.37315 .43767 .3777 .48062 .38762 .48633 .38312 .4398 Mtetra
.501 .349 .607 r
.38312 .4398 .38762 .48633 .39776 .489 .39305 .44463 Mtetra
.47 .33 .609 r
.39305 .44463 .39776 .489 .40813 .48718 .40298 .45208 Mtetra
.431 .323 .63 r
.40298 .45208 .40813 .48718 .41866 .48166 .41298 .46059 Mtetra
.336 .325 .698 r
.41298 .46059 .41866 .48166 .42932 .47303 .42309 .46895 Mtetra
0 .189 .613 r
.42309 .46895 .42932 .47303 .44001 .46339 .43338 .47544 Mtetra
.559 .163 .247 r
.43338 .47544 .44001 .46339 .45069 .45401 .44384 .47906 Mtetra
.521 .2 .365 r
.44384 .47906 .45069 .45401 .46136 .44561 .45444 .48011 Mtetra
.501 .207 .399 r
.45444 .48011 .46136 .44561 .47201 .43867 .46516 .47882 Mtetra
.494 .211 .414 r
.46516 .47882 .47201 .43867 .48267 .43296 .47595 .47626 Mtetra
.491 .213 .42 r
.47595 .47626 .48267 .43296 .49334 .42845 .4868 .47302 Mtetra
.49 .214 .423 r
.4868 .47302 .49334 .42845 .50404 .42495 .49769 .46954 Mtetra
.488 .213 .422 r
.49769 .46954 .50404 .42495 .51478 .42247 .50863 .46582 Mtetra
.48 .204 .417 r
.50863 .46582 .51478 .42247 .52556 .42118 .51961 .46141 Mtetra
.462 .184 .405 r
.51961 .46141 .52556 .42118 .53641 .42114 .53063 .45572 Mtetra
.417 .135 .375 r
.53063 .45572 .53641 .42114 .54734 .42259 .54166 .44768 Mtetra
.308 .014 .292 r
.54166 .44768 .54734 .42259 .55835 .42505 .55269 .437 Mtetra
0 0 0 r
.55269 .437 .55835 .42505 .56945 .42779 .56368 .42341 Mtetra
.904 .846 .776 r
.56368 .42341 .56945 .42779 .58063 .42953 .57461 .40787 Mtetra
.742 .579 .673 r
.57461 .40787 .58063 .42953 .59181 .42813 .58551 .39215 Mtetra
.674 .491 .63 r
.58551 .39215 .59181 .42813 .60297 .42297 .59639 .37746 Mtetra
.634 .448 .614 r
.59639 .37746 .60297 .42297 .61404 .41323 .6073 .36541 Mtetra
.613 .43 .611 r
.6073 .36541 .61404 .41323 .62501 .40036 .61828 .35608 Mtetra
.601 .427 .618 r
.61828 .35608 .62501 .40036 .63594 .38668 .62934 .34918 Mtetra
.592 .432 .634 r
.62934 .34918 .63594 .38668 .64686 .37364 .64051 .34449 Mtetra
.582 .448 .664 r
.64051 .34449 .64686 .37364 .65787 .36314 .65179 .34182 Mtetra
.567 .476 .711 r
.65179 .34182 .65787 .36314 .669 .3552 .66321 .34082 Mtetra
.532 .523 .791 r
.66321 .34082 .669 .3552 .68026 .34983 .67475 .34124 Mtetra
.451 .6 .908 r
.67475 .34124 .68026 .34983 .69167 .3465 .68642 .34246 Mtetra
.262 .665 .967 r
.68642 .34246 .69167 .3465 .70321 .3447 .69817 .34367 Mtetra
.019 .586 .786 r
.69817 .34367 .70321 .3447 .71487 .34383 .70998 .3445 Mtetra
.057 0 0 r
.70998 .3445 .71487 .34383 .72661 .34324 .72181 .34441 Mtetra
.016 0 0 r
.72181 .34441 .72661 .34324 .73843 .34258 .73366 .34339 Mtetra
.124 .67 .699 r
.73366 .34339 .73843 .34258 .75028 .34139 .74551 .34132 Mtetra
.304 .798 .835 r
.74551 .34132 .75028 .34139 .76215 .33965 .75736 .33837 Mtetra
.479 .885 .943 r
.75736 .33837 .76215 .33965 .77404 .33722 .76921 .3347 Mtetra
.593 .903 .984 r
.76921 .3347 .77404 .33722 .78594 .33423 .78107 .3305 Mtetra
.651 .881 .983 r
.78107 .3305 .78594 .33423 .79786 .33076 .79294 .32597 Mtetra
.677 .849 .965 r
.79294 .32597 .79786 .33076 .8098 .32694 .80484 .3212 Mtetra
.687 .817 .945 r
.80484 .3212 .8098 .32694 .82177 .3229 .81678 .31633 Mtetra
.687 .788 .927 r
.81678 .31633 .82177 .3229 .83378 .31877 .82876 .31146 Mtetra
.599 .736 .94 r
.18679 .51429 .19348 .52013 .203 .51783 .1963 .51231 Mtetra
.589 .745 .951 r
.1963 .51231 .203 .51783 .21256 .51555 .20584 .51043 Mtetra
.58 .758 .963 r
.20584 .51043 .21256 .51555 .22217 .51317 .21542 .50859 Mtetra
.57 .777 .976 r
.21542 .50859 .22217 .51317 .23184 .51057 .22505 .50675 Mtetra
.552 .802 .991 r
.22505 .50675 .23184 .51057 .24158 .50767 .23471 .50488 Mtetra
.534 .837 .999 r
.23471 .50488 .24158 .50767 .25139 .50426 .24445 .50276 Mtetra
.5 .868 .983 r
.24445 .50276 .25139 .50426 .26129 .50015 .25426 .50027 Mtetra
.447 .877 .913 r
.25426 .50027 .26129 .50015 .27129 .4952 .26416 .49711 Mtetra
.382 .841 .781 r
.26416 .49711 .27129 .4952 .28139 .48924 .27416 .49303 Mtetra
0 0 0 r
.27416 .49303 .28139 .48924 .29158 .48237 .28428 .48786 Mtetra
.28428 .48786 .29158 .48237 .30184 .47459 .29452 .48138 Mtetra
.29452 .48138 .30184 .47459 .31214 .46643 .30485 .47376 Mtetra
.30485 .47376 .31214 .46643 .32244 .45826 .31526 .46503 Mtetra
.31526 .46503 .32244 .45826 .33271 .45084 .32571 .45574 Mtetra
.616 .921 .664 r
.32571 .45574 .33271 .45084 .34292 .44479 .33618 .44626 Mtetra
.806 .996 .86 r
.33618 .44626 .34292 .44479 .35306 .44038 .34663 .43706 Mtetra
.82 .868 .882 r
.34663 .43706 .35306 .44038 .36313 .43794 .35704 .42865 Mtetra
.726 .688 .814 r
.35704 .42865 .36313 .43794 .37315 .43767 .36737 .4221 Mtetra
.634 .556 .749 r
.36737 .4221 .37315 .43767 .38312 .4398 .37759 .41821 Mtetra
.558 .462 .702 r
.37759 .41821 .38312 .4398 .39305 .44463 .38771 .41769 Mtetra
.497 .395 .669 r
.38771 .41769 .39305 .44463 .40298 .45208 .39775 .4208 Mtetra
.473 .363 .648 r
.39775 .4208 .40298 .45208 .41298 .46059 .40779 .42585 Mtetra
.469 .35 .635 r
.40779 .42585 .41298 .46059 .42309 .46895 .4179 .43171 Mtetra
.487 .357 .629 r
.4179 .43171 .42309 .46895 .43338 .47544 .42814 .43666 Mtetra
.513 .373 .627 r
.42814 .43666 .43338 .47544 .44384 .47906 .43853 .43967 Mtetra
.535 .387 .627 r
.43853 .43967 .44384 .47906 .45444 .48011 .44904 .44079 Mtetra
.554 .401 .628 r
.44904 .44079 .45444 .48011 .46516 .47882 .45966 .44001 Mtetra
.566 .411 .63 r
.45966 .44001 .46516 .47882 .47595 .47626 .47036 .43802 Mtetra
.575 .419 .631 r
.47036 .43802 .47595 .47626 .4868 .47302 .48113 .43511 Mtetra
.582 .424 .632 r
.48113 .43511 .4868 .47302 .49769 .46954 .49194 .43158 Mtetra
.587 .428 .632 r
.49194 .43158 .49769 .46954 .50863 .46582 .50281 .42741 Mtetra
.595 .432 .631 r
.50281 .42741 .50863 .46582 .51961 .46141 .51372 .42233 Mtetra
.604 .437 .629 r
.51372 .42233 .51961 .46141 .53063 .45572 .52466 .41601 Mtetra
.618 .446 .627 r
.52466 .41601 .53063 .45572 .54166 .44768 .53562 .40778 Mtetra
.632 .456 .625 r
.53562 .40778 .54166 .44768 .55269 .437 .54658 .39762 Mtetra
.648 .467 .625 r
.54658 .39762 .55269 .437 .56368 .42341 .55752 .38548 Mtetra
.657 .476 .627 r
.55752 .38548 .56368 .42341 .57461 .40787 .56843 .37238 Mtetra
.658 .481 .633 r
.56843 .37238 .57461 .40787 .58551 .39215 .57933 .36006 Mtetra
.652 .485 .644 r
.57933 .36006 .58551 .39215 .59639 .37746 .59026 .34971 Mtetra
.63 .484 .664 r
.59026 .34971 .59639 .37746 .6073 .36541 .60127 .34301 Mtetra
.601 .49 .699 r
.60127 .34301 .6073 .36541 .61828 .35608 .6124 .33974 Mtetra
.558 .512 .76 r
.6124 .33974 .61828 .35608 .62934 .34918 .62367 .33919 Mtetra
.465 .568 .875 r
.62367 .33919 .62934 .34918 .64051 .34449 .63506 .34055 Mtetra
.154 .6 .933 r
.63506 .34055 .64051 .34449 .65179 .34182 .64658 .34272 Mtetra
.311 0 0 r
.64658 .34272 .65179 .34182 .66321 .34082 .65819 .34522 Mtetra
.44 0 0 r
.65819 .34522 .66321 .34082 .67475 .34124 .6699 .34754 Mtetra
.451 0 0 r
.6699 .34754 .67475 .34124 .68642 .34246 .68166 .34929 Mtetra
.413 0 0 r
.68166 .34929 .68642 .34246 .69817 .34367 .69346 .34993 Mtetra
.344 0 0 r
.69346 .34993 .69817 .34367 .70998 .3445 .70526 .34939 Mtetra
.214 0 0 r
.70526 .34939 .70998 .3445 .72181 .34441 .71707 .3475 Mtetra
.006 0 0 r
.71707 .3475 .72181 .34441 .73366 .34339 .72886 .34449 Mtetra
.281 .776 .734 r
.72886 .34449 .73366 .34339 .74551 .34132 .74064 .34052 Mtetra
.523 .913 .921 r
.74064 .34052 .74551 .34132 .75736 .33837 .75242 .33586 Mtetra
.646 .923 .976 r
.75242 .33586 .75736 .33837 .76921 .3347 .76422 .33078 Mtetra
.692 .887 .97 r
.76422 .33078 .76921 .3347 .78107 .3305 .77604 .32545 Mtetra
.703 .848 .952 r
.77604 .32545 .78107 .3305 .79294 .32597 .78789 .32008 Mtetra
.706 .819 .935 r
.78789 .32008 .79294 .32597 .80484 .3212 .79978 .3147 Mtetra
.703 .797 .923 r
.79978 .3147 .80484 .3212 .81678 .31633 .81172 .30935 Mtetra
.698 .78 .914 r
.81172 .30935 .81678 .31633 .82876 .31146 .82371 .3041 Mtetra
.604 .737 .939 r
.18006 .50842 .18679 .51429 .1963 .51231 .1896 .50631 Mtetra
.597 .731 .938 r
.1896 .50631 .1963 .51231 .20584 .51043 .19916 .50435 Mtetra
.587 .726 .94 r
.19916 .50435 .20584 .51043 .21542 .50859 .20875 .50257 Mtetra
.573 .724 .945 r
.20875 .50257 .21542 .50859 .22505 .50675 .21837 .501 Mtetra
.552 .728 .956 r
.21837 .501 .22505 .50675 .23471 .50488 .228 .49972 Mtetra
.528 .742 .973 r
.228 .49972 .23471 .50488 .24445 .50276 .23767 .49859 Mtetra
.488 .767 .993 r
.23767 .49859 .24445 .50276 .25426 .50027 .24738 .49758 Mtetra
.424 .798 .993 r
.24738 .49758 .25426 .50027 .26416 .49711 .25714 .49643 Mtetra
.294 .782 .9 r
.25714 .49643 .26416 .49711 .27416 .49303 .26699 .49496 Mtetra
0 0 0 r
.26699 .49496 .27416 .49303 .28428 .48786 .27692 .49285 Mtetra
.06 0 0 r
.27692 .49285 .28428 .48786 .29452 .48138 .28697 .48978 Mtetra
.154 0 0 r
.28697 .48978 .29452 .48138 .30485 .47376 .29715 .48552 Mtetra
.19 0 .034 r
.29715 .48552 .30485 .47376 .31526 .46503 .30745 .47979 Mtetra
.201 0 .105 r
.30745 .47979 .31526 .46503 .32571 .45574 .31787 .47255 Mtetra
.184 0 .132 r
.31787 .47255 .32571 .45574 .33618 .44626 .3284 .46376 Mtetra
.162 0 .133 r
.3284 .46376 .33618 .44626 .34663 .43706 .33899 .45402 Mtetra
.126 0 .108 r
.33899 .45402 .34663 .43706 .35704 .42865 .3496 .44376 Mtetra
.077 0 .054 r
.3496 .44376 .35704 .42865 .36737 .4221 .3602 .43369 Mtetra
0 0 0 r
.3602 .43369 .36737 .4221 .37759 .41821 .37077 .42423 Mtetra
.486 .826 .538 r
.37077 .42423 .37759 .41821 .38771 .41769 .38135 .41471 Mtetra
.848 .881 .864 r
.38135 .41471 .38771 .41769 .39775 .4208 .39194 .40489 Mtetra
.724 .602 .72 r
.39194 .40489 .39775 .4208 .40779 .42585 .40253 .39483 Mtetra
.655 .488 .646 r
.40253 .39483 .40779 .42585 .4179 .43171 .41313 .38473 Mtetra
.613 .43 .61 r
.41313 .38473 .4179 .43171 .42814 .43666 .42369 .3757 Mtetra
.588 .398 .592 r
.42369 .3757 .42814 .43666 .43853 .43967 .43421 .36825 Mtetra
.573 .38 .582 r
.43421 .36825 .43853 .43967 .44904 .44079 .4447 .36242 Mtetra
.562 .369 .576 r
.4447 .36242 .44904 .44079 .45966 .44001 .45519 .35807 Mtetra
.558 .364 .574 r
.45519 .35807 .45966 .44001 .47036 .43802 .46569 .35438 Mtetra
.557 .362 .573 r
.46569 .35438 .47036 .43802 .48113 .43511 .47624 .35092 Mtetra
.47624 .35092 .48113 .43511 .49194 .43158 .48683 .34729 Mtetra
.558 .363 .573 r
.48683 .34729 .49194 .43158 .50281 .42741 .49746 .3435 Mtetra
.557 .362 .573 r
.49746 .3435 .50281 .42741 .51372 .42233 .50813 .33994 Mtetra
.554 .361 .574 r
.50813 .33994 .51372 .42233 .52466 .41601 .51884 .33704 Mtetra
.548 .358 .575 r
.51884 .33704 .52466 .41601 .53562 .40778 .5296 .33564 Mtetra
.54 .356 .58 r
.5296 .33564 .53562 .40778 .54658 .39762 .54043 .33587 Mtetra
.53 .355 .589 r
.54043 .33587 .54658 .39762 .55752 .38548 .55134 .33771 Mtetra
.519 .362 .608 r
.55134 .33771 .55752 .38548 .56843 .37238 .56234 .34066 Mtetra
.508 .389 .652 r
.56234 .34066 .56843 .37238 .57933 .36006 .57344 .34359 Mtetra
.472 .46 .763 r
.57344 .34359 .57933 .36006 .59026 .34971 .58462 .34628 Mtetra
.072 .563 .894 r
.58462 .34628 .59026 .34971 .60127 .34301 .59588 .3487 Mtetra
.472 0 0 r
.59588 .3487 .60127 .34301 .6124 .33974 .60724 .35108 Mtetra
.532 .117 .2 r
.60724 .35108 .6124 .33974 .62367 .33919 .6187 .35411 Mtetra
.542 .159 .266 r
.6187 .35411 .62367 .33919 .63506 .34055 .63026 .35734 Mtetra
.534 .165 .286 r
.63026 .35734 .63506 .34055 .64658 .34272 .6419 .36007 Mtetra
.517 .152 .286 r
.6419 .36007 .64658 .34272 .65819 .34522 .6536 .36185 Mtetra
.483 .116 .266 r
.6536 .36185 .65819 .34522 .6699 .34754 .66532 .36205 Mtetra
.436 .055 .217 r
.66532 .36205 .6699 .34754 .68166 .34929 .67704 .3607 Mtetra
.355 0 .122 r
.67704 .3607 .68166 .34929 .69346 .34993 .68875 .35785 Mtetra
.211 0 0 r
.68875 .35785 .69346 .34993 .70526 .34939 .70045 .35375 Mtetra
0 0 0 r
.70045 .35375 .70526 .34939 .71707 .3475 .71213 .34867 Mtetra
.442 .872 .774 r
.71213 .34867 .71707 .3475 .72886 .34449 .72382 .3429 Mtetra
.669 .955 .948 r
.72382 .3429 .72886 .34449 .74064 .34052 .73552 .33679 Mtetra
.73 .904 .956 r
.73552 .33679 .74064 .34052 .75242 .33586 .74724 .33053 Mtetra
.732 .845 .934 r
.74724 .33053 .75242 .33586 .76422 .33078 .759 .32438 Mtetra
.725 .806 .915 r
.759 .32438 .76422 .33078 .77604 .32545 .77081 .31839 Mtetra
.713 .781 .905 r
.77081 .31839 .77604 .32545 .78789 .32008 .78267 .31267 Mtetra
.705 .768 .901 r
.78267 .31267 .78789 .32008 .79978 .3147 .7946 .30717 Mtetra
.699 .763 .902 r
.7946 .30717 .79978 .3147 .81172 .30935 .80657 .30185 Mtetra
.694 .763 .905 r
.80657 .30185 .81172 .30935 .82371 .3041 .81861 .29669 Mtetra
.636 .746 .928 r
.17328 .5025 .18006 .50842 .1896 .50631 .1829 .49973 Mtetra
.631 .723 .914 r
.1829 .49973 .1896 .50631 .19916 .50435 .19255 .49709 Mtetra
.622 .7 .9 r
.19255 .49709 .19916 .50435 .20875 .50257 .20222 .49466 Mtetra
.61 .677 .889 r
.20222 .49466 .20875 .50257 .21837 .501 .21189 .49256 Mtetra
.592 .656 .882 r
.21189 .49256 .21837 .501 .228 .49972 .22157 .49088 Mtetra
.575 .639 .877 r
.22157 .49088 .228 .49972 .23767 .49859 .23126 .48962 Mtetra
.553 .628 .88 r
.23126 .48962 .23767 .49859 .24738 .49758 .24095 .48886 Mtetra
.534 .627 .889 r
.24095 .48886 .24738 .49758 .25714 .49643 .25066 .48844 Mtetra
.511 .638 .911 r
.25066 .48844 .25714 .49643 .26699 .49496 .26041 .4883 Mtetra
.488 .674 .946 r
.26041 .4883 .26699 .49496 .27692 .49285 .27022 .48815 Mtetra
.446 .732 .988 r
.27022 .48815 .27692 .49285 .28697 .48978 .28009 .48776 Mtetra
.35 .785 .966 r
.28009 .48776 .28697 .48978 .29715 .48552 .29007 .48675 Mtetra
.154 .692 .715 r
.29007 .48675 .29715 .48552 .30745 .47979 .30017 .48477 Mtetra
.043 0 0 r
.30017 .48477 .30745 .47979 .31787 .47255 .31039 .48153 Mtetra
.144 0 0 r
.31039 .48153 .31787 .47255 .3284 .46376 .32075 .47676 Mtetra
.214 0 .074 r
.32075 .47676 .3284 .46376 .33899 .45402 .33121 .47075 Mtetra
.253 0 .163 r
.33121 .47075 .33899 .45402 .3496 .44376 .34176 .46363 Mtetra
.271 0 .212 r
.34176 .46363 .3496 .44376 .3602 .43369 .35238 .45542 Mtetra
.266 0 .229 r
.35238 .45542 .3602 .43369 .37077 .42423 .36307 .44614 Mtetra
.221 0 .212 r
.36307 .44614 .37077 .42423 .38135 .41471 .37383 .43532 Mtetra
.142 0 .164 r
.37383 .43532 .38135 .41471 .39194 .40489 .38465 .42295 Mtetra
.057 0 .094 r
.38465 .42295 .39194 .40489 .40253 .39483 .39547 .4102 Mtetra
0 0 .016 r
.39547 .4102 .40253 .39483 .41313 .38473 .40625 .39789 Mtetra
0 0 0 r
.40625 .39789 .41313 .38473 .42369 .3757 .41697 .38729 Mtetra
.056 0 0 r
.41697 .38729 .42369 .3757 .43421 .36825 .4276 .379 Mtetra
.142 0 0 r
.4276 .379 .43421 .36825 .4447 .36242 .43819 .37266 Mtetra
.221 0 .02 r
.43819 .37266 .4447 .36242 .45519 .35807 .44877 .36795 Mtetra
.254 0 .027 r
.44877 .36795 .45519 .35807 .46569 .35438 .45936 .36401 Mtetra
.265 0 .026 r
.45936 .36401 .46569 .35438 .47624 .35092 .46999 .36039 Mtetra
.261 0 .018 r
.46999 .36039 .47624 .35092 .48683 .34729 .48066 .35676 Mtetra
.26 0 .018 r
.48066 .35676 .48683 .34729 .49746 .3435 .49137 .3531 Mtetra
.282 0 .034 r
.49137 .3531 .49746 .3435 .50813 .33994 .50212 .34975 Mtetra
.326 0 .064 r
.50212 .34975 .50813 .33994 .51884 .33704 .51291 .34719 Mtetra
.403 0 .113 r
.51291 .34719 .51884 .33704 .5296 .33564 .52375 .34628 Mtetra
.476 .056 .162 r
.52375 .34628 .5296 .33564 .54043 .33587 .53466 .34733 Mtetra
.544 .133 .213 r
.53466 .34733 .54043 .33587 .55134 .33771 .54567 .35074 Mtetra
.581 .185 .257 r
.54567 .35074 .55134 .33771 .56234 .34066 .55678 .35591 Mtetra
.587 .207 .29 r
.55678 .35591 .56234 .34066 .57344 .34359 .56801 .36155 Mtetra
.577 .214 .316 r
.56801 .36155 .57344 .34359 .58462 .34628 .57934 .36684 Mtetra
.551 .202 .33 r
.57934 .36684 .58462 .34628 .59588 .3487 .59075 .37058 Mtetra
.528 .187 .333 r
.59075 .37058 .59588 .3487 .60724 .35108 .60222 .37278 Mtetra
.511 .17 .325 r
.60222 .37278 .60724 .35108 .6187 .35411 .61375 .3739 Mtetra
.488 .139 .301 r
.61375 .3739 .6187 .35411 .63026 .35734 .62533 .37392 Mtetra
.452 .086 .251 r
.62533 .37392 .63026 .35734 .6419 .36007 .63694 .37281 Mtetra
.386 0 .161 r
.63694 .37281 .6419 .36007 .6536 .36185 .64857 .37044 Mtetra
.234 0 0 r
.64857 .37044 .6536 .36185 .66532 .36205 .6602 .36649 Mtetra
0 0 0 r
.6602 .36649 .66532 .36205 .67704 .3607 .67181 .36124 Mtetra
.553 .932 .847 r
.67181 .36124 .67704 .3607 .68875 .35785 .68342 .35499 Mtetra
.748 .934 .948 r
.68342 .35499 .68875 .35785 .70045 .35375 .69501 .34807 Mtetra
.764 .837 .908 r
.69501 .34807 .70045 .35375 .71213 .34867 .70662 .3409 Mtetra
.749 .768 .869 r
.70662 .3409 .71213 .34867 .72382 .3429 .71826 .3337 Mtetra
.73 .725 .846 r
.71826 .3337 .72382 .3429 .73552 .33679 .72994 .32678 Mtetra
.716 .702 .836 r
.72994 .32678 .73552 .33679 .74724 .33053 .74166 .3202 Mtetra
.702 .69 .835 r
.74166 .3202 .74724 .33053 .759 .32438 .75346 .31413 Mtetra
.692 .688 .841 r
.75346 .31413 .759 .32438 .77081 .31839 .76532 .30848 Mtetra
.683 .693 .853 r
.76532 .30848 .77081 .31839 .78267 .31267 .77726 .30328 Mtetra
.677 .703 .867 r
.77726 .30328 .78267 .31267 .7946 .30717 .78927 .29839 Mtetra
.673 .718 .883 r
.78927 .29839 .7946 .30717 .80657 .30185 .80134 .29374 Mtetra
.671 .737 .9 r
.80134 .29374 .80657 .30185 .81861 .29669 .81347 .28921 Mtetra
.676 .756 .911 r
.16646 .49655 .17328 .5025 .1829 .49973 .1762 .4928 Mtetra
.671 .725 .89 r
.1762 .4928 .1829 .49973 .19255 .49709 .18597 .48911 Mtetra
.661 .693 .869 r
.18597 .48911 .19255 .49709 .20222 .49466 .19575 .48559 Mtetra
.647 .662 .85 r
.19575 .48559 .20222 .49466 .21189 .49256 .20555 .48236 Mtetra
.631 .631 .833 r
.20555 .48236 .21189 .49256 .22157 .49088 .21534 .47953 Mtetra
.612 .602 .816 r
.21534 .47953 .22157 .49088 .23126 .48962 .22512 .47721 Mtetra
.591 .574 .803 r
.22512 .47721 .23126 .48962 .24095 .48886 .23489 .47552 Mtetra
.571 .55 .792 r
.23489 .47552 .24095 .48886 .25066 .48844 .24465 .47448 Mtetra
.549 .53 .786 r
.24465 .47448 .25066 .48844 .26041 .4883 .2544 .47415 Mtetra
.531 .517 .785 r
.2544 .47415 .26041 .4883 .27022 .48815 .26417 .47438 Mtetra
.513 .514 .794 r
.26417 .47438 .27022 .48815 .28009 .48776 .27395 .47512 Mtetra
.498 .524 .815 r
.27395 .47512 .28009 .48776 .29007 .48675 .28378 .4761 Mtetra
.479 .556 .856 r
.28378 .4761 .29007 .48675 .30017 .48477 .29367 .47712 Mtetra
.441 .622 .928 r
.29367 .47712 .30017 .48477 .31039 .48153 .30365 .47792 Mtetra
.298 .705 .975 r
.30365 .47792 .31039 .48153 .32075 .47676 .31371 .47829 Mtetra
.102 0 0 r
.31371 .47829 .32075 .47676 .33121 .47075 .32388 .47796 Mtetra
.316 0 0 r
.32388 .47796 .33121 .47075 .34176 .46363 .33416 .47667 Mtetra
.36 0 .15 r
.33416 .47667 .34176 .46363 .35238 .45542 .34458 .47385 Mtetra
.365 .017 .235 r
.34458 .47385 .35238 .45542 .36307 .44614 .35514 .46926 Mtetra
.381 .058 .287 r
.35514 .46926 .36307 .44614 .37383 .43532 .36578 .46371 Mtetra
.407 .102 .332 r
.36578 .46371 .37383 .43532 .38465 .42295 .37646 .45782 Mtetra
.446 .154 .375 r
.37646 .45782 .38465 .42295 .39547 .4102 .38712 .45287 Mtetra
.48 .198 .408 r
.38712 .45287 .39547 .4102 .40625 .39789 .39776 .44947 Mtetra
.497 .224 .43 r
.39776 .44947 .40625 .39789 .41697 .38729 .40841 .44701 Mtetra
.506 .239 .443 r
.40841 .44701 .41697 .38729 .4276 .379 .41909 .44512 Mtetra
.507 .244 .45 r
.41909 .44512 .4276 .379 .43819 .37266 .42982 .44298 Mtetra
.505 .245 .453 r
.42982 .44298 .43819 .37266 .44877 .36795 .44063 .44023 Mtetra
.504 .245 .455 r
.44063 .44023 .44877 .36795 .45936 .36401 .45149 .43706 Mtetra
.502 .244 .455 r
.45149 .43706 .45936 .36401 .46999 .36039 .46241 .43354 Mtetra
.502 .243 .455 r
.46241 .43354 .46999 .36039 .48066 .35676 .47337 .42994 Mtetra
.47337 .42994 .48066 .35676 .49137 .3531 .48438 .42627 Mtetra
.5 .241 .454 r
.48438 .42627 .49137 .3531 .50212 .34975 .49543 .42224 Mtetra
.497 .239 .453 r
.49543 .42224 .50212 .34975 .51291 .34719 .50653 .41779 Mtetra
.492 .234 .451 r
.50653 .41779 .51291 .34719 .52375 .34628 .51767 .41272 Mtetra
.488 .228 .446 r
.51767 .41272 .52375 .34628 .53466 .34733 .52885 .40739 Mtetra
.488 .223 .439 r
.52885 .40739 .53466 .34733 .54567 .35074 .54006 .40263 Mtetra
.488 .216 .427 r
.54006 .40263 .54567 .35074 .55678 .35591 .55132 .39882 Mtetra
.493 .209 .411 r
.55132 .39882 .55678 .35591 .56801 .36155 .56264 .39659 Mtetra
.494 .196 .389 r
.56264 .39659 .56801 .36155 .57934 .36684 .57403 .39531 Mtetra
.48 .167 .357 r
.57403 .39531 .57934 .36684 .59075 .37058 .58549 .39369 Mtetra
.45 .12 .314 r
.58549 .39369 .59075 .37058 .60222 .37278 .59698 .39111 Mtetra
.383 .035 .246 r
.59698 .39111 .60222 .37278 .61375 .3739 .60848 .38671 Mtetra
.253 0 .103 r
.60848 .38671 .61375 .3739 .62533 .37392 .61998 .38074 Mtetra
0 0 0 r
.61998 .38074 .62533 .37392 .63694 .37281 .63148 .37378 Mtetra
.634 .963 .831 r
.63148 .37378 .63694 .37281 .64857 .37044 .64298 .36608 Mtetra
.796 .884 .909 r
.64298 .36608 .64857 .37044 .6602 .36649 .65447 .35792 Mtetra
.767 .75 .838 r
.65447 .35792 .6602 .36649 .67181 .36124 .66598 .34952 Mtetra
.736 .675 .792 r
.66598 .34952 .67181 .36124 .68342 .35499 .6775 .34115 Mtetra
.714 .635 .767 r
.6775 .34115 .68342 .35499 .69501 .34807 .68905 .333 Mtetra
.697 .611 .757 r
.68905 .333 .69501 .34807 .70662 .3409 .70064 .32536 Mtetra
.685 .6 .755 r
.70064 .32536 .70662 .3409 .71826 .3337 .7123 .3183 Mtetra
.673 .596 .761 r
.7123 .3183 .71826 .3337 .72994 .32678 .72402 .31196 Mtetra
.665 .599 .771 r
.72402 .31196 .72994 .32678 .74166 .3202 .73582 .30628 Mtetra
.657 .607 .787 r
.73582 .30628 .74166 .3202 .75346 .31413 .7477 .30124 Mtetra
.651 .62 .806 r
.7477 .30124 .75346 .31413 .76532 .30848 .75967 .29673 Mtetra
.646 .638 .828 r
.75967 .29673 .76532 .30848 .77726 .30328 .77172 .29264 Mtetra
.642 .659 .852 r
.77172 .29264 .77726 .30328 .78927 .29839 .78385 .28885 Mtetra
.639 .684 .876 r
.78385 .28885 .78927 .29839 .80134 .29374 .79604 .28523 Mtetra
.638 .713 .901 r
.79604 .28523 .80134 .29374 .81347 .28921 .8083 .28168 Mtetra
.705 .762 .896 r
.15958 .49055 .16646 .49655 .1762 .4928 .16944 .48593 Mtetra
.701 .735 .877 r
.16944 .48593 .1762 .4928 .18597 .48911 .17933 .48128 Mtetra
.693 .708 .859 r
.17933 .48128 .18597 .48911 .19575 .48559 .18924 .47668 Mtetra
.682 .679 .841 r
.18924 .47668 .19575 .48559 .20555 .48236 .19916 .47224 Mtetra
.669 .649 .822 r
.19916 .47224 .20555 .48236 .21534 .47953 .20909 .46803 Mtetra
.652 .618 .802 r
.20909 .46803 .21534 .47953 .22512 .47721 .21902 .46418 Mtetra
.633 .586 .783 r
.21902 .46418 .22512 .47721 .23489 .47552 .22893 .46082 Mtetra
.613 .554 .765 r
.22893 .46082 .23489 .47552 .24465 .47448 .23883 .45807 Mtetra
.591 .524 .748 r
.23883 .45807 .24465 .47448 .2544 .47415 .24871 .45606 Mtetra
.572 .497 .732 r
.24871 .45606 .2544 .47415 .26417 .47438 .25857 .4548 Mtetra
.553 .473 .72 r
.25857 .4548 .26417 .47438 .27395 .47512 .26842 .45436 Mtetra
.537 .455 .711 r
.26842 .45436 .27395 .47512 .28378 .4761 .27828 .45463 Mtetra
.523 .442 .706 r
.27828 .45463 .28378 .4761 .29367 .47712 .28814 .45556 Mtetra
.512 .435 .706 r
.28814 .45556 .29367 .47712 .30365 .47792 .29803 .45698 Mtetra
.503 .434 .711 r
.29803 .45698 .30365 .47792 .31371 .47829 .30798 .45875 Mtetra
.503 .445 .725 r
.30798 .45875 .31371 .47829 .32388 .47796 .318 .46041 Mtetra
.51 .468 .746 r
.318 .46041 .32388 .47796 .33416 .47667 .32811 .4616 Mtetra
.528 .508 .778 r
.32811 .4616 .33416 .47667 .34458 .47385 .33835 .46197 Mtetra
.554 .573 .828 r
.33835 .46197 .34458 .47385 .35514 .46926 .3487 .46131 Mtetra
.534 .661 .917 r
.3487 .46131 .35514 .46926 .36578 .46371 .35912 .46059 Mtetra
.335 .746 .98 r
.35912 .46059 .36578 .46371 .37646 .45782 .36958 .46028 Mtetra
.232 0 0 r
.36958 .46028 .37646 .45782 .38712 .45287 .38007 .46054 Mtetra
.433 0 .045 r
.38007 .46054 .38712 .45287 .39776 .44947 .39061 .46132 Mtetra
.452 .042 .17 r
.39061 .46132 .39776 .44947 .40841 .44701 .40124 .46146 Mtetra
.434 .05 .209 r
.40124 .46146 .40841 .44701 .41909 .44512 .41198 .46041 Mtetra
.402 .026 .206 r
.41198 .46041 .41909 .44512 .42982 .44298 .42282 .45805 Mtetra
.36 0 .183 r
.42282 .45805 .42982 .44298 .44063 .44023 .43375 .45447 Mtetra
.335 0 .156 r
.43375 .45447 .44063 .44023 .45149 .43706 .44473 .45047 Mtetra
.322 0 .135 r
.44473 .45047 .45149 .43706 .46241 .43354 .45575 .44646 Mtetra
.33 0 .129 r
.45575 .44646 .46241 .43354 .47337 .42994 .4668 .44286 Mtetra
.346 0 .136 r
.4668 .44286 .47337 .42994 .48438 .42627 .4779 .43965 Mtetra
.354 0 .15 r
.4779 .43965 .48438 .42627 .49543 .42224 .48904 .43645 Mtetra
.351 0 .164 r
.48904 .43645 .49543 .42224 .50653 .41779 .50024 .43281 Mtetra
.321 0 .166 r
.50024 .43281 .50653 .41779 .51767 .41272 .51148 .42795 Mtetra
.279 0 .152 r
.51148 .42795 .51767 .41272 .52885 .40739 .52277 .42176 Mtetra
.215 0 .109 r
.52277 .42176 .52885 .40739 .54006 .40263 .53408 .41436 Mtetra
.105 0 0 r
.53408 .41436 .54006 .40263 .55132 .39882 .54541 .40629 Mtetra
0 0 0 r
.54541 .40629 .55132 .39882 .56264 .39659 .55675 .39873 Mtetra
.514 .903 .753 r
.55675 .39873 .56264 .39659 .57403 .39531 .56813 .39173 Mtetra
.749 .899 .945 r
.56813 .39173 .57403 .39531 .58549 .39369 .57954 .38515 Mtetra
.731 .735 .855 r
.57954 .38515 .58549 .39369 .59698 .39111 .59097 .37849 Mtetra
.717 .651 .783 r
.59097 .37849 .59698 .39111 .60848 .38671 .6024 .37077 Mtetra
.705 .605 .741 r
.6024 .37077 .60848 .38671 .61998 .38074 .61383 .36219 Mtetra
.695 .576 .717 r
.61383 .36219 .61998 .38074 .63148 .37378 .62526 .35311 Mtetra
.685 .555 .702 r
.62526 .35311 .63148 .37378 .64298 .36608 .6367 .3439 Mtetra
.673 .539 .693 r
.6367 .3439 .64298 .36608 .65447 .35792 .64815 .33502 Mtetra
.664 .53 .69 r
.64815 .33502 .65447 .35792 .66598 .34952 .65964 .32663 Mtetra
.656 .525 .692 r
.65964 .32663 .66598 .34952 .6775 .34115 .67117 .31891 Mtetra
.649 .525 .698 r
.67117 .31891 .6775 .34115 .68905 .333 .68277 .31191 Mtetra
.643 .528 .709 r
.68277 .31191 .68905 .333 .70064 .32536 .69443 .30574 Mtetra
.637 .536 .723 r
.69443 .30574 .70064 .32536 .7123 .3183 .70617 .30035 Mtetra
.631 .547 .741 r
.70617 .30035 .7123 .3183 .72402 .31196 .718 .29571 Mtetra
.626 .561 .762 r
.718 .29571 .72402 .31196 .73582 .30628 .72991 .29169 Mtetra
.621 .58 .786 r
.72991 .29169 .73582 .30628 .7477 .30124 .74192 .28819 Mtetra
.617 .6 .811 r
.74192 .28819 .7477 .30124 .75967 .29673 .754 .28507 Mtetra
.614 .624 .838 r
.754 .28507 .75967 .29673 .77172 .29264 .76617 .28218 Mtetra
.61 .649 .864 r
.76617 .28218 .77172 .29264 .78385 .28885 .7784 .27945 Mtetra
.607 .674 .888 r
.7784 .27945 .78385 .28885 .79604 .28523 .79071 .27678 Mtetra
.606 .701 .911 r
.79071 .27678 .79604 .28523 .8083 .28168 .80308 .27409 Mtetra
.721 .764 .887 r
.15266 .48451 .15958 .49055 .16944 .48593 .1626 .47935 Mtetra
.72 .749 .875 r
.1626 .47935 .16944 .48593 .17933 .48128 .17257 .47408 Mtetra
.717 .732 .862 r
.17257 .47408 .17933 .48128 .18924 .47668 .18258 .46874 Mtetra
.712 .712 .848 r
.18258 .46874 .18924 .47668 .19916 .47224 .19261 .46335 Mtetra
.706 .688 .831 r
.19261 .46335 .19916 .47224 .20909 .46803 .20268 .45793 Mtetra
.695 .661 .812 r
.20268 .45793 .20909 .46803 .21902 .46418 .21275 .45261 Mtetra
.68 .63 .792 r
.21275 .45261 .21902 .46418 .22893 .46082 .22284 .44746 Mtetra
.663 .597 .771 r
.22284 .44746 .22893 .46082 .23883 .45807 .23292 .44264 Mtetra
.643 .563 .749 r
.23292 .44264 .23883 .45807 .24871 .45606 .24299 .43829 Mtetra
.622 .529 .728 r
.24299 .43829 .24871 .45606 .25857 .4548 .25305 .43454 Mtetra
.601 .498 .709 r
.25305 .43454 .25857 .4548 .26842 .45436 .26307 .43151 Mtetra
.583 .471 .692 r
.26307 .43151 .26842 .45436 .27828 .45463 .27308 .42926 Mtetra
.565 .447 .677 r
.27308 .42926 .27828 .45463 .28814 .45556 .28308 .42786 Mtetra
.552 .429 .665 r
.28308 .42786 .28814 .45556 .29803 .45698 .29307 .42718 Mtetra
.542 .414 .656 r
.29307 .42718 .29803 .45698 .30798 .45875 .30307 .42716 Mtetra
.537 .405 .648 r
.30307 .42716 .30798 .45875 .318 .46041 .31311 .42746 Mtetra
.535 .4 .643 r
.31311 .42746 .318 .46041 .32811 .4616 .32321 .42788 Mtetra
.53 .395 .641 r
.32321 .42788 .32811 .4616 .33835 .46197 .33335 .42865 Mtetra
.525 .392 .642 r
.33335 .42865 .33835 .46197 .3487 .46131 .34354 .42985 Mtetra
.515 .392 .65 r
.34354 .42985 .3487 .46131 .35912 .46059 .35376 .43164 Mtetra
.506 .395 .661 r
.35376 .43164 .35912 .46059 .36958 .46028 .36404 .43389 Mtetra
.518 .414 .676 r
.36404 .43389 .36958 .46028 .38007 .46054 .37443 .43527 Mtetra
.546 .439 .683 r
.37443 .43527 .38007 .46054 .39061 .46132 .38497 .43501 Mtetra
.577 .455 .676 r
.38497 .43501 .39061 .46132 .40124 .46146 .39565 .43269 Mtetra
.601 .461 .663 r
.39565 .43269 .40124 .46146 .41198 .46041 .40647 .42826 Mtetra
.605 .453 .649 r
.40647 .42826 .41198 .46041 .42282 .45805 .41735 .42281 Mtetra
.603 .444 .638 r
.41735 .42281 .42282 .45805 .43375 .45447 .42827 .41701 Mtetra
.596 .433 .632 r
.42827 .41701 .43375 .45447 .44473 .45047 .43922 .4116 Mtetra
.586 .424 .629 r
.43922 .4116 .44473 .45047 .45575 .44646 .45017 .40701 Mtetra
.576 .416 .627 r
.45017 .40701 .45575 .44646 .4668 .44286 .46115 .40335 Mtetra
.567 .41 .627 r
.46115 .40335 .4668 .44286 .4779 .43965 .47215 .40062 Mtetra
.56 .405 .629 r
.47215 .40062 .4779 .43965 .48904 .43645 .48319 .39871 Mtetra
.556 .406 .633 r
.48319 .39871 .48904 .43645 .50024 .43281 .49429 .39719 Mtetra
.561 .415 .639 r
.49429 .39719 .50024 .43281 .51148 .42795 .50545 .39535 Mtetra
.576 .433 .65 r
.50545 .39535 .51148 .42795 .52277 .42176 .51667 .39247 Mtetra
.605 .464 .662 r
.51667 .39247 .52277 .42176 .53408 .41436 .52794 .38746 Mtetra
.635 .492 .671 r
.52794 .38746 .53408 .41436 .54541 .40629 .53924 .38035 Mtetra
.656 .51 .673 r
.53924 .38035 .54541 .40629 .55675 .39873 .55055 .37157 Mtetra
.661 .508 .665 r
.55055 .37157 .55675 .39873 .56813 .39173 .56186 .36189 Mtetra
.647 .489 .655 r
.56186 .36189 .56813 .39173 .57954 .38515 .57318 .35266 Mtetra
.634 .473 .646 r
.57318 .35266 .57954 .38515 .59097 .37849 .58452 .344 Mtetra
.625 .461 .64 r
.58452 .344 .59097 .37849 .6024 .37077 .59589 .33577 Mtetra
.621 .457 .639 r
.59589 .33577 .6024 .37077 .61383 .36219 .60727 .32787 Mtetra
.621 .459 .641 r
.60727 .32787 .61383 .36219 .62526 .35311 .61868 .32009 Mtetra
.621 .462 .646 r
.61868 .32009 .62526 .35311 .6367 .3439 .63012 .31262 Mtetra
.619 .466 .653 r
.63012 .31262 .6367 .3439 .64815 .33502 .64161 .30581 Mtetra
.616 .471 .662 r
.64161 .30581 .64815 .33502 .65964 .32663 .65315 .29974 Mtetra
.612 .477 .674 r
.65315 .29974 .65964 .32663 .67117 .31891 .66476 .29453 Mtetra
.608 .487 .69 r
.66476 .29453 .67117 .31891 .68277 .31191 .67646 .29012 Mtetra
.603 .5 .709 r
.67646 .29012 .68277 .31191 .69443 .30574 .68823 .28645 Mtetra
.599 .516 .732 r
.68823 .28645 .69443 .30574 .70617 .30035 .7001 .28341 Mtetra
.595 .536 .759 r
.7001 .28341 .70617 .30035 .718 .29571 .71205 .28084 Mtetra
.591 .559 .787 r
.71205 .28084 .718 .29571 .72991 .29169 .72409 .27862 Mtetra
.588 .585 .817 r
.72409 .27862 .72991 .29169 .74192 .28819 .73621 .27659 Mtetra
.585 .612 .845 r
.73621 .27659 .74192 .28819 .754 .28507 .7484 .27466 Mtetra
.585 .638 .87 r
.7484 .27466 .754 .28507 .76617 .28218 .76066 .2727 Mtetra
.583 .661 .891 r
.76066 .2727 .76617 .28218 .7784 .27945 .77298 .2707 Mtetra
.583 .682 .909 r
.77298 .2707 .7784 .27945 .79071 .27678 .78537 .26863 Mtetra
.583 .701 .923 r
.78537 .26863 .79071 .27678 .80308 .27409 .79782 .26643 Mtetra
.716 .763 .89 r
.14569 .47843 .15266 .48451 .1626 .47935 .15564 .47342 Mtetra
.721 .769 .891 r
.15564 .47342 .1626 .47935 .17257 .47408 .16562 .46825 Mtetra
.726 .774 .891 r
.16562 .46825 .17257 .47408 .18258 .46874 .17565 .46292 Mtetra
.731 .776 .889 r
.17565 .46292 .18258 .46874 .19261 .46335 .18572 .45739 Mtetra
.736 .773 .883 r
.18572 .45739 .19261 .46335 .20268 .45793 .19585 .45163 Mtetra
.738 .764 .874 r
.19585 .45163 .20268 .45793 .21275 .45261 .20601 .44571 Mtetra
.736 .747 .861 r
.20601 .44571 .21275 .45261 .22284 .44746 .2162 .43965 Mtetra
.728 .723 .845 r
.2162 .43965 .22284 .44746 .23292 .44264 .22641 .43359 Mtetra
.716 .691 .826 r
.22641 .43359 .23292 .44264 .24299 .43829 .23664 .42764 Mtetra
.698 .655 .803 r
.23664 .42764 .24299 .43829 .25305 .43454 .24687 .42193 Mtetra
.676 .615 .78 r
.24687 .42193 .25305 .43454 .26307 .43151 .25709 .41663 Mtetra
.653 .575 .755 r
.25709 .41663 .26307 .43151 .27308 .42926 .2673 .41183 Mtetra
.63 .538 .731 r
.2673 .41183 .27308 .42926 .28308 .42786 .27748 .40765 Mtetra
.61 .505 .709 r
.27748 .40765 .28308 .42786 .29307 .42718 .28766 .40406 Mtetra
.593 .477 .69 r
.28766 .40406 .29307 .42718 .30307 .42716 .29784 .40108 Mtetra
.579 .454 .673 r
.29784 .40108 .30307 .42716 .31311 .42746 .30802 .39863 Mtetra
.569 .436 .66 r
.30802 .39863 .31311 .42746 .32321 .42788 .31821 .39667 Mtetra
.556 .419 .65 r
.31821 .39667 .32321 .42788 .33335 .42865 .32841 .3955 Mtetra
.543 .405 .643 r
.32841 .3955 .33335 .42865 .34354 .42985 .33861 .39521 Mtetra
.538 .397 .637 r
.33861 .39521 .34354 .42985 .35376 .43164 .34885 .3953 Mtetra
.539 .394 .632 r
.34885 .3953 .35376 .43164 .36404 .43389 .35916 .39531 Mtetra
.552 .398 .627 r
.35916 .39531 .36404 .43389 .37443 .43527 .36959 .39411 Mtetra
.568 .405 .621 r
.36959 .39411 .37443 .43527 .38497 .43501 .38015 .39116 Mtetra
.576 .407 .615 r
.38015 .39116 .38497 .43501 .39565 .43269 .39082 .38696 Mtetra
.582 .408 .611 r
.39082 .38696 .39565 .43269 .40647 .42826 .40155 .38186 Mtetra
.581 .406 .61 r
.40155 .38186 .40647 .42826 .41735 .42281 .41232 .37679 Mtetra
.577 .405 .611 r
.41232 .37679 .41735 .42281 .42827 .41701 .42311 .37217 Mtetra
.575 .405 .613 r
.42311 .37217 .42827 .41701 .43922 .4116 .43392 .36793 Mtetra
.573 .405 .616 r
.43392 .36793 .43922 .4116 .45017 .40701 .44476 .36408 Mtetra
.572 .406 .617 r
.44476 .36408 .45017 .40701 .46115 .40335 .45564 .36035 Mtetra
.571 .405 .617 r
.45564 .36035 .46115 .40335 .47215 .40062 .46657 .35677 Mtetra
.567 .401 .616 r
.46657 .35677 .47215 .40062 .48319 .39871 .47753 .35356 Mtetra
.563 .396 .613 r
.47753 .35356 .48319 .39871 .49429 .39719 .48853 .35074 Mtetra
.558 .391 .61 r
.48853 .35074 .49429 .39719 .50545 .39535 .49958 .34839 Mtetra
.557 .39 .61 r
.49958 .34839 .50545 .39535 .51667 .39247 .51069 .34606 Mtetra
.565 .396 .611 r
.51069 .34606 .51667 .39247 .52794 .38746 .52185 .34283 Mtetra
.577 .407 .615 r
.52185 .34283 .52794 .38746 .53924 .38035 .53306 .33833 Mtetra
.594 .424 .62 r
.53306 .33833 .53924 .38035 .55055 .37157 .5443 .33205 Mtetra
.609 .438 .626 r
.5443 .33205 .55055 .37157 .56186 .36189 .55556 .32454 Mtetra
.613 .446 .631 r
.55556 .32454 .56186 .36189 .57318 .35266 .56684 .31693 Mtetra
.613 .449 .636 r
.56684 .31693 .57318 .35266 .58452 .344 .57814 .30969 Mtetra
.607 .449 .641 r
.57814 .30969 .58452 .344 .59589 .33577 .58948 .30334 Mtetra
.603 .451 .648 r
.58948 .30334 .59589 .33577 .60727 .32787 .60087 .29779 Mtetra
.602 .458 .658 r
.60087 .29779 .60727 .32787 .61868 .32009 .61231 .29274 Mtetra
.602 .468 .672 r
.61231 .29274 .61868 .32009 .63012 .31262 .62381 .28821 Mtetra
.6 .481 .689 r
.62381 .28821 .63012 .31262 .64161 .30581 .63537 .28431 Mtetra
.598 .497 .711 r
.63537 .28431 .64161 .30581 .65315 .29974 .64701 .28102 Mtetra
.593 .516 .738 r
.64701 .28102 .65315 .29974 .66476 .29453 .65872 .27837 Mtetra
.587 .539 .768 r
.65872 .27837 .66476 .29453 .67646 .29012 .67053 .27624 Mtetra
.579 .566 .803 r
.67053 .27624 .67646 .29012 .68823 .28645 .68241 .27452 Mtetra
.571 .596 .839 r
.68241 .27452 .68823 .28645 .7001 .28341 .69438 .27307 Mtetra
.563 .627 .873 r
.69438 .27307 .7001 .28341 .71205 .28084 .70643 .27174 Mtetra
.557 .657 .902 r
.70643 .27174 .71205 .28084 .72409 .27862 .71855 .2704 Mtetra
.555 .683 .924 r
.71855 .2704 .72409 .27862 .73621 .27659 .73074 .26894 Mtetra
.556 .702 .938 r
.73074 .26894 .73621 .27659 .7484 .27466 .74298 .26731 Mtetra
.563 .717 .944 r
.74298 .26731 .7484 .27466 .76066 .2727 .75528 .26544 Mtetra
.571 .724 .946 r
.75528 .26544 .76066 .2727 .77298 .2707 .76764 .26337 Mtetra
.578 .727 .944 r
.76764 .26337 .77298 .2707 .78537 .26863 .78005 .26112 Mtetra
.586 .726 .94 r
.78005 .26112 .78537 .26863 .79782 .26643 .79252 .25872 Mtetra
.692 .759 .903 r
.13868 .4723 .14569 .47843 .15564 .47342 .14856 .468 Mtetra
.699 .785 .917 r
.14856 .468 .15564 .47342 .16562 .46825 .15849 .46355 Mtetra
.708 .811 .929 r
.15849 .46355 .16562 .46825 .17565 .46292 .16847 .45888 Mtetra
.718 .837 .938 r
.16847 .45888 .17565 .46292 .18572 .45739 .17852 .45394 Mtetra
.73 .86 .942 r
.17852 .45394 .18572 .45739 .19585 .45163 .18862 .44864 Mtetra
.742 .878 .943 r
.18862 .44864 .19585 .45163 .20601 .44571 .19879 .44299 Mtetra
.754 .889 .939 r
.19879 .44299 .20601 .44571 .2162 .43965 .20902 .43696 Mtetra
.764 .891 .934 r
.20902 .43696 .2162 .43965 .22641 .43359 .2193 .43064 Mtetra
.773 .882 .925 r
.2193 .43064 .22641 .43359 .23664 .42764 .22962 .42405 Mtetra
.775 .861 .913 r
.22962 .42405 .23664 .42764 .24687 .42193 .23997 .41733 Mtetra
.77 .826 .896 r
.23997 .41733 .24687 .42193 .25709 .41663 .25034 .41057 Mtetra
.757 .78 .872 r
.25034 .41057 .25709 .41663 .2673 .41183 .26073 .40388 Mtetra
.736 .726 .841 r
.26073 .40388 .2673 .41183 .27748 .40765 .27112 .39738 Mtetra
.711 .67 .807 r
.27112 .39738 .27748 .40765 .28766 .40406 .28151 .39114 Mtetra
.685 .617 .774 r
.28151 .39114 .28766 .40406 .29784 .40108 .29189 .38526 Mtetra
.658 .57 .744 r
.29189 .38526 .29784 .40108 .30802 .39863 .30227 .37988 Mtetra
.634 .53 .719 r
.30227 .37988 .30802 .39863 .31821 .39667 .31263 .37513 Mtetra
.613 .499 .7 r
.31263 .37513 .31821 .39667 .32841 .3955 .32298 .37103 Mtetra
.597 .473 .682 r
.32298 .37103 .32841 .3955 .33861 .39521 .33333 .36752 Mtetra
.593 .457 .665 r
.33333 .36752 .33861 .39521 .34885 .3953 .34374 .36377 Mtetra
.595 .445 .648 r
.34374 .36377 .34885 .3953 .35916 .39531 .35422 .35932 Mtetra
.594 .433 .633 r
.35422 .35932 .35916 .39531 .36959 .39411 .36478 .35421 Mtetra
.592 .424 .623 r
.36478 .35421 .36959 .39411 .38015 .39116 .37538 .3486 Mtetra
.583 .413 .616 r
.37538 .3486 .38015 .39116 .39082 .38696 .38599 .34366 Mtetra
.572 .404 .615 r
.38599 .34366 .39082 .38696 .40155 .38186 .39658 .33987 Mtetra
.563 .399 .618 r
.39658 .33987 .40155 .38186 .41232 .37679 .40717 .33717 Mtetra
.556 .399 .623 r
.40717 .33717 .41232 .37679 .42311 .37217 .41778 .33533 Mtetra
.56 .408 .632 r
.41778 .33533 .42311 .37217 .43392 .36793 .42845 .33337 Mtetra
.569 .42 .639 r
.42845 .33337 .43392 .36793 .44476 .36408 .43919 .33074 Mtetra
.583 .433 .643 r
.43919 .33074 .44476 .36408 .45564 .36035 .45001 .32696 Mtetra
.595 .441 .643 r
.45001 .32696 .45564 .36035 .46657 .35677 .4609 .32205 Mtetra
.6 .441 .638 r
.4609 .32205 .46657 .35677 .47753 .35356 .47183 .31647 Mtetra
.597 .433 .631 r
.47183 .31647 .47753 .35356 .48853 .35074 .4828 .31075 Mtetra
.584 .419 .624 r
.4828 .31075 .48853 .35074 .49958 .34839 .49378 .30588 Mtetra
.572 .406 .618 r
.49378 .30588 .49958 .34839 .51069 .34606 .5048 .30212 Mtetra
.56 .395 .615 r
.5048 .30212 .51069 .34606 .52185 .34283 .51586 .29953 Mtetra
.554 .392 .616 r
.51586 .29953 .52185 .34283 .53306 .33833 .52698 .2976 Mtetra
.561 .402 .623 r
.52698 .2976 .53306 .33833 .5443 .33205 .53815 .29518 Mtetra
.571 .417 .633 r
.53815 .29518 .5443 .33205 .55556 .32454 .54937 .29209 Mtetra
.584 .437 .648 r
.54937 .29209 .55556 .32454 .56684 .31693 .56063 .2883 Mtetra
.593 .457 .665 r
.56063 .2883 .56684 .31693 .57814 .30969 .57194 .28425 Mtetra
.591 .469 .682 r
.57194 .28425 .57814 .30969 .58948 .30334 .58331 .2808 Mtetra
.587 .483 .703 r
.58331 .2808 .58948 .30334 .60087 .29779 .59474 .27802 Mtetra
.581 .499 .727 r
.59474 .27802 .60087 .29779 .61231 .29274 .60624 .27589 Mtetra
.574 .523 .76 r
.60624 .27589 .61231 .29274 .62381 .28821 .61783 .27427 Mtetra
.566 .556 .802 r
.61783 .27427 .62381 .28821 .63537 .28431 .62949 .27303 Mtetra
.554 .598 .853 r
.62949 .27303 .63537 .28431 .64701 .28102 .64123 .27206 Mtetra
.533 .646 .907 r
.64123 .27206 .64701 .28102 .65872 .27837 .65305 .27129 Mtetra
.503 .693 .953 r
.65305 .27129 .65872 .27837 .67053 .27624 .66495 .27061 Mtetra
.468 .731 .983 r
.66495 .27061 .67053 .27624 .68241 .27452 .67692 .26989 Mtetra
.439 .757 .995 r
.67692 .26989 .68241 .27452 .69438 .27307 .68897 .26904 Mtetra
.43 .776 .997 r
.68897 .26904 .69438 .27307 .70643 .27174 .70107 .26793 Mtetra
.441 .791 .997 r
.70107 .26793 .70643 .27174 .71855 .2704 .71324 .26652 Mtetra
.472 .805 .999 r
.71324 .26652 .71855 .2704 .73074 .26894 .72545 .26472 Mtetra
.509 .811 .999 r
.72545 .26472 .73074 .26894 .74298 .26731 .73771 .26255 Mtetra
.548 .81 .994 r
.73771 .26255 .74298 .26731 .75528 .26544 .75001 .26002 Mtetra
.579 .799 .983 r
.75001 .26002 .75528 .26544 .76764 .26337 .76235 .2572 Mtetra
.6 .781 .967 r
.76235 .2572 .76764 .26337 .78005 .26112 .77474 .25415 Mtetra
.614 .759 .948 r
.77474 .25415 .78005 .26112 .79252 .25872 .78718 .25095 Mtetra
.649 .75 .923 r
.13161 .46613 .13868 .4723 .14856 .468 .14138 .46294 Mtetra
.65 .789 .949 r
.14138 .46294 .14856 .468 .15849 .46355 .15121 .45965 Mtetra
.649 .833 .971 r
.15121 .45965 .15849 .46355 .16847 .45888 .16109 .45616 Mtetra
.645 .876 .984 r
.16109 .45616 .16847 .45888 .17852 .45394 .17103 .45241 Mtetra
.635 .913 .981 r
.17103 .45241 .17852 .45394 .18862 .44864 .18105 .4483 Mtetra
.614 .937 .957 r
.18105 .4483 .18862 .44864 .19879 .44299 .19115 .44379 Mtetra
.584 .942 .911 r
.19115 .44379 .19879 .44299 .20902 .43696 .20132 .43883 Mtetra
.546 .929 .849 r
.20132 .43883 .20902 .43696 .2193 .43064 .21156 .43342 Mtetra
.512 .907 .786 r
.21156 .43342 .2193 .43064 .22962 .42405 .22186 .42756 Mtetra
.483 .884 .731 r
.22186 .42756 .22962 .42405 .23997 .41733 .23223 .42131 Mtetra
.47 .869 .696 r
.23223 .42131 .23997 .41733 .25034 .41057 .24265 .41472 Mtetra
.474 .868 .685 r
.24265 .41472 .25034 .41057 .26073 .40388 .25311 .40789 Mtetra
.496 .882 .699 r
.25311 .40789 .26073 .40388 .27112 .39738 .2636 .40092 Mtetra
.535 .909 .738 r
.2636 .40092 .27112 .39738 .28151 .39114 .2741 .39393 Mtetra
.584 .94 .794 r
.2741 .39393 .28151 .39114 .29189 .38526 .28462 .38704 Mtetra
.63 .963 .856 r
.28462 .38704 .29189 .38526 .30227 .37988 .29514 .38044 Mtetra
.669 .969 .914 r
.29514 .38044 .30227 .37988 .31263 .37513 .30564 .37426 Mtetra
.707 .954 .951 r
.30564 .37426 .31263 .37513 .32298 .37103 .31615 .36836 Mtetra
.733 .904 .954 r
.31615 .36836 .32298 .37103 .33333 .36752 .32668 .36261 Mtetra
.747 .826 .913 r
.32668 .36261 .33333 .36752 .34374 .36377 .33726 .35652 Mtetra
.744 .754 .861 r
.33726 .35652 .34374 .36377 .35422 .35932 .34788 .34993 Mtetra
.719 .696 .827 r
.34788 .34993 .35422 .35932 .36478 .35421 .35852 .34362 Mtetra
.693 .663 .816 r
.35852 .34362 .36478 .35421 .37538 .3486 .36914 .33805 Mtetra
.658 .65 .831 r
.36914 .33805 .37538 .3486 .38599 .34366 .37972 .33395 Mtetra
.609 .648 .864 r
.37972 .33395 .38599 .34366 .39658 .33987 .39027 .33153 Mtetra
.568 .668 .905 r
.39027 .33153 .39658 .33987 .40717 .33717 .40083 .33005 Mtetra
.537 .694 .94 r
.40083 .33005 .40717 .33717 .41778 .33533 .41143 .32895 Mtetra
.554 .727 .955 r
.41143 .32895 .41778 .33533 .42845 .33337 .42212 .32736 Mtetra
.602 .76 .955 r
.42212 .32736 .42845 .33337 .43919 .33074 .43288 .32479 Mtetra
.658 .782 .94 r
.43288 .32479 .43919 .33074 .45001 .32696 .44373 .32099 Mtetra
.704 .795 .921 r
.44373 .32099 .45001 .32696 .4609 .32205 .45466 .31596 Mtetra
.735 .799 .903 r
.45466 .31596 .4609 .32205 .47183 .31647 .46563 .30995 Mtetra
.745 .788 .888 r
.46563 .30995 .47183 .31647 .4828 .31075 .47664 .30343 Mtetra
.73 .762 .878 r
.47664 .30343 .4828 .31075 .49378 .30588 .48767 .29729 Mtetra
.696 .717 .866 r
.48767 .29729 .49378 .30588 .5048 .30212 .49873 .29208 Mtetra
.64 .661 .855 r
.49873 .29208 .5048 .30212 .51586 .29953 .50981 .28857 Mtetra
.591 .619 .848 r
.50981 .28857 .51586 .29953 .52698 .2976 .52093 .28655 Mtetra
.565 .604 .851 r
.52093 .28655 .52698 .2976 .53815 .29518 .53212 .28529 Mtetra
.55 .625 .879 r
.53212 .28529 .53815 .29518 .54937 .29209 .54337 .2843 Mtetra
.557 .689 .928 r
.54337 .2843 .54937 .29209 .56063 .2883 .55469 .28283 Mtetra
.54 .766 .981 r
.55469 .28283 .56063 .2883 .57194 .28425 .56606 .28101 Mtetra
.445 .809 .996 r
.56606 .28101 .57194 .28425 .58331 .2808 .57751 .27936 Mtetra
.288 .772 .916 r
.57751 .27936 .58331 .2808 .59474 .27802 .58902 .27798 Mtetra
.105 .66 .763 r
.58902 .27798 .59474 .27802 .60624 .27589 .60061 .27705 Mtetra
.04 0 0 r
.60061 .27705 .60624 .27589 .61783 .27427 .61228 .27643 Mtetra
.128 0 0 r
.61228 .27643 .61783 .27427 .62949 .27303 .62403 .27591 Mtetra
.176 0 0 r
.62403 .27591 .62949 .27303 .64123 .27206 .63585 .27539 Mtetra
.191 0 0 r
.63585 .27539 .64123 .27206 .65305 .27129 .64775 .27473 Mtetra
.18 0 0 r
.64775 .27473 .65305 .27129 .66495 .27061 .65971 .27383 Mtetra
.141 0 0 r
.65971 .27383 .66495 .27061 .67692 .26989 .67173 .27259 Mtetra
.074 0 0 r
.67173 .27259 .67692 .26989 .68897 .26904 .68381 .27095 Mtetra
0 0 0 r
.68381 .27095 .68897 .26904 .70107 .26793 .69593 .26885 Mtetra
.162 .697 .712 r
.69593 .26885 .70107 .26793 .71324 .26652 .70809 .26629 Mtetra
.315 .804 .846 r
.70809 .26629 .71324 .26652 .72545 .26472 .72029 .26325 Mtetra
.452 .87 .943 r
.72029 .26325 .72545 .26472 .73771 .26255 .73252 .25979 Mtetra
.555 .887 .987 r
.73252 .25979 .73771 .26255 .75001 .26002 .74478 .25597 Mtetra
.616 .868 .99 r
.74478 .25597 .75001 .26002 .76235 .2572 .75708 .25186 Mtetra
.647 .833 .972 r
.75708 .25186 .76235 .2572 .77474 .25415 .76942 .24754 Mtetra
.66 .793 .945 r
.76942 .24754 .77474 .25415 .78718 .25095 .7818 .24311 Mtetra
.589 .733 .943 r
.12449 .45992 .13161 .46613 .14138 .46294 .13414 .45793 Mtetra
.576 .773 .972 r
.13414 .45793 .14138 .46294 .15121 .45965 .14384 .45589 Mtetra
.556 .815 .994 r
.14384 .45589 .15121 .45965 .16109 .45616 .1536 .45374 Mtetra
.521 .851 .997 r
.1536 .45374 .16109 .45616 .17103 .45241 .16342 .4514 Mtetra
.465 .867 .963 r
.16342 .4514 .17103 .45241 .18105 .4483 .17331 .4488 Mtetra
.38 .843 .874 r
.17331 .4488 .18105 .4483 .19115 .44379 .18328 .44587 Mtetra
.279 .776 .736 r
.18328 .44587 .19115 .44379 .20132 .43883 .19333 .44253 Mtetra
0 0 0 r
.19333 .44253 .20132 .43883 .21156 .43342 .20347 .43874 Mtetra
.20347 .43874 .21156 .43342 .22186 .42756 .21369 .43446 Mtetra
.21369 .43446 .22186 .42756 .23223 .42131 .22399 .42969 Mtetra
.031 0 0 r
.22399 .42969 .23223 .42131 .24265 .41472 .23436 .42444 Mtetra
.07 0 0 r
.23436 .42444 .24265 .41472 .25311 .40789 .24479 .41878 Mtetra
.1 0 0 r
.24479 .41878 .25311 .40789 .2636 .40092 .25529 .41276 Mtetra
.125 0 0 r
.25529 .41276 .2636 .40092 .2741 .39393 .26582 .40652 Mtetra
.147 0 .003 r
.26582 .40652 .2741 .39393 .28462 .38704 .27638 .40016 Mtetra
.165 0 .026 r
.27638 .40016 .28462 .38704 .29514 .38044 .28697 .39378 Mtetra
.177 0 .038 r
.28697 .39378 .29514 .38044 .30564 .37426 .29758 .38745 Mtetra
.165 0 .03 r
.29758 .38745 .30564 .37426 .31615 .36836 .30823 .38095 Mtetra
.134 0 0 r
.30823 .38095 .31615 .36836 .32668 .36261 .31891 .3742 Mtetra
.093 0 0 r
.31891 .3742 .32668 .36261 .33726 .35652 .32962 .36735 Mtetra
.074 0 0 r
.32962 .36735 .33726 .35652 .34788 .34993 .34034 .36065 Mtetra
.144 0 0 r
.34034 .36065 .34788 .34993 .35852 .34362 .35102 .35506 Mtetra
.258 0 .043 r
.35102 .35506 .35852 .34362 .36914 .33805 .36165 .35105 Mtetra
.349 0 .128 r
.36165 .35105 .36914 .33805 .37972 .33395 .37225 .34836 Mtetra
.404 .015 .183 r
.37225 .34836 .37972 .33395 .39027 .33153 .38286 .34674 Mtetra
.412 .029 .199 r
.38286 .34674 .39027 .33153 .40083 .33005 .39352 .34516 Mtetra
.397 .013 .19 r
.39352 .34516 .40083 .33005 .41143 .32895 .40425 .34309 Mtetra
.367 0 .158 r
.40425 .34309 .41143 .32895 .42212 .32736 .41507 .34043 Mtetra
.327 0 .118 r
.41507 .34043 .42212 .32736 .43288 .32479 .42595 .33709 Mtetra
.294 0 .084 r
.42595 .33709 .43288 .32479 .44373 .32099 .43689 .33328 Mtetra
.274 0 .074 r
.43689 .33328 .44373 .32099 .45466 .31596 .44789 .329 Mtetra
.261 0 .086 r
.44789 .329 .45466 .31596 .46563 .30995 .45895 .32403 Mtetra
.259 0 .107 r
.45895 .32403 .46563 .30995 .47664 .30343 .47005 .31846 Mtetra
.26 0 .127 r
.47005 .31846 .47664 .30343 .48767 .29729 .48119 .3124 Mtetra
.264 0 .131 r
.48119 .3124 .48767 .29729 .49873 .29208 .49236 .30637 Mtetra
.291 0 .128 r
.49236 .30637 .49873 .29208 .50981 .28857 .50356 .30141 Mtetra
.318 0 .111 r
.50356 .30141 .50981 .28857 .52093 .28655 .51479 .29779 Mtetra
.355 0 .09 r
.51479 .29779 .52093 .28655 .53212 .28529 .52606 .29576 Mtetra
.387 0 .085 r
.52606 .29576 .53212 .28529 .54337 .2843 .53741 .29487 Mtetra
.394 0 .091 r
.53741 .29487 .54337 .2843 .55469 .28283 .54882 .29413 Mtetra
.4 0 .112 r
.54882 .29413 .55469 .28283 .56606 .28101 .5603 .29331 Mtetra
.403 0 .136 r
.5603 .29331 .56606 .28101 .57751 .27936 .57185 .29224 Mtetra
.403 0 .148 r
.57185 .29224 .57751 .27936 .58902 .27798 .58347 .29101 Mtetra
.407 0 .152 r
.58347 .29101 .58902 .27798 .60061 .27705 .59516 .28983 Mtetra
.404 0 .145 r
.59516 .28983 .60061 .27705 .61228 .27643 .60692 .28864 Mtetra
.394 0 .128 r
.60692 .28864 .61228 .27643 .62403 .27591 .61875 .28733 Mtetra
.377 0 .101 r
.61875 .28733 .62403 .27591 .63585 .27539 .63064 .2858 Mtetra
.348 0 .061 r
.63064 .2858 .63585 .27539 .64775 .27473 .64259 .28391 Mtetra
.307 0 .003 r
.64259 .28391 .64775 .27473 .65971 .27383 .65458 .2816 Mtetra
.245 0 0 r
.65458 .2816 .65971 .27383 .67173 .27259 .66662 .27879 Mtetra
.157 0 0 r
.66662 .27879 .67173 .27259 .68381 .27095 .6787 .27548 Mtetra
.027 0 0 r
.6787 .27548 .68381 .27095 .69593 .26885 .69081 .27165 Mtetra
0 0 0 r
.69081 .27165 .69593 .26885 .70809 .26629 .70295 .26736 Mtetra
.343 .816 .757 r
.70295 .26736 .70809 .26629 .72029 .26325 .71511 .26264 Mtetra
.514 .912 .903 r
.71511 .26264 .72029 .26325 .73252 .25979 .7273 .25756 Mtetra
.625 .932 .967 r
.7273 .25756 .73252 .25979 .74478 .25597 .73952 .25221 Mtetra
.68 .904 .975 r
.73952 .25221 .74478 .25597 .75708 .25186 .75177 .24665 Mtetra
.702 .859 .957 r
.75177 .24665 .75708 .25186 .76942 .24754 .76405 .24096 Mtetra
.707 .813 .931 r
.76405 .24096 .76942 .24754 .7818 .24311 .77637 .23521 Mtetra
.536 .715 .955 r
.11732 .45366 .12449 .45992 .13414 .45793 .12688 .45251 Mtetra
.518 .74 .975 r
.12688 .45251 .13414 .45793 .14384 .45589 .13649 .45138 Mtetra
.494 .766 .992 r
.13649 .45138 .14384 .45589 .1536 .45374 .14616 .45022 Mtetra
.461 .791 .999 r
.14616 .45022 .1536 .45374 .16342 .4514 .15588 .44898 Mtetra
.412 .807 .986 r
.15588 .44898 .16342 .4514 .17331 .4488 .16566 .44763 Mtetra
.342 .802 .937 r
.16566 .44763 .17331 .4488 .18328 .44587 .17552 .44607 Mtetra
.251 .763 .836 r
.17552 .44607 .18328 .44587 .19333 .44253 .18546 .44425 Mtetra
0 0 0 r
.18546 .44425 .19333 .44253 .20347 .43874 .19547 .4421 Mtetra
.19547 .4421 .20347 .43874 .21369 .43446 .20557 .43956 Mtetra
.043 0 0 r
.20557 .43956 .21369 .43446 .22399 .42969 .21576 .4366 Mtetra
.108 0 0 r
.21576 .4366 .22399 .42969 .23436 .42444 .22603 .43317 Mtetra
.161 0 0 r
.22603 .43317 .23436 .42444 .24479 .41878 .23638 .42933 Mtetra
.201 0 0 r
.23638 .42933 .24479 .41878 .25529 .41276 .2468 .42509 Mtetra
.234 0 .04 r
.2468 .42509 .25529 .41276 .26582 .40652 .25728 .42052 Mtetra
.26 0 .091 r
.25728 .42052 .26582 .40652 .27638 .40016 .26782 .41567 Mtetra
.28 0 .129 r
.26782 .41567 .27638 .40016 .28697 .39378 .27841 .41059 Mtetra
.294 0 .157 r
.27841 .41059 .28697 .39378 .29758 .38745 .28904 .40529 Mtetra
.298 0 .174 r
.28904 .40529 .29758 .38745 .30823 .38095 .29973 .39967 Mtetra
.301 0 .187 r
.29973 .39967 .30823 .38095 .31891 .3742 .31047 .39374 Mtetra
.317 0 .205 r
.31047 .39374 .31891 .3742 .32962 .36735 .32123 .38796 Mtetra
.345 .001 .229 r
.32123 .38796 .32962 .36735 .34034 .36065 .33198 .38268 Mtetra
.385 .045 .261 r
.33198 .38268 .34034 .36065 .35102 .35506 .34271 .37842 Mtetra
.42 .084 .287 r
.34271 .37842 .35102 .35506 .36165 .35105 .35341 .37533 Mtetra
.431 .098 .298 r
.35341 .37533 .36165 .35105 .37225 .34836 .36415 .37256 Mtetra
.428 .095 .296 r
.36415 .37256 .37225 .34836 .38286 .34674 .37494 .36965 Mtetra
.407 .07 .278 r
.37494 .36965 .38286 .34674 .39352 .34516 .38581 .36604 Mtetra
.374 .03 .246 r
.38581 .36604 .39352 .34516 .40425 .34309 .39676 .36161 Mtetra
.348 0 .209 r
.39676 .36161 .40425 .34309 .41507 .34043 .40775 .35699 Mtetra
.332 0 .176 r
.40775 .35699 .41507 .34043 .42595 .33709 .41878 .35253 Mtetra
.34 0 .163 r
.41878 .35253 .42595 .33709 .43689 .33328 .42983 .34871 Mtetra
.362 0 .173 r
.42983 .34871 .43689 .33328 .44789 .329 .44091 .34553 Mtetra
.378 .005 .197 r
.44091 .34553 .44789 .329 .45895 .32403 .45203 .34251 Mtetra
.39 .03 .227 r
.45203 .34251 .45895 .32403 .47005 .31846 .46321 .3393 Mtetra
.387 .042 .252 r
.46321 .3393 .47005 .31846 .48119 .3124 .47445 .33527 Mtetra
.385 .05 .27 r
.47445 .33527 .48119 .3124 .49236 .30637 .48574 .33053 Mtetra
.391 .061 .282 r
.48574 .33053 .49236 .30637 .50356 .30141 .49708 .32565 Mtetra
.398 .069 .286 r
.49708 .32565 .50356 .30141 .51479 .29779 .50846 .32109 Mtetra
.418 .081 .285 r
.50846 .32109 .51479 .29779 .52606 .29576 .51988 .31771 Mtetra
.432 .087 .279 r
.51988 .31771 .52606 .29576 .53741 .29487 .53135 .31537 Mtetra
.436 .083 .267 r
.53135 .31537 .53741 .29487 .54882 .29413 .54288 .31353 Mtetra
.435 .075 .254 r
.54288 .31353 .54882 .29413 .5603 .29331 .55448 .31187 Mtetra
.423 .059 .24 r
.55448 .31187 .5603 .29331 .57185 .29224 .56614 .30989 Mtetra
.41 .041 .224 r
.56614 .30989 .57185 .29224 .58347 .29101 .57786 .30758 Mtetra
.396 .021 .204 r
.57786 .30758 .58347 .29101 .59516 .28983 .58964 .30506 Mtetra
.378 0 .175 r
.58964 .30506 .59516 .28983 .60692 .28864 .60148 .30229 Mtetra
.351 0 .136 r
.60148 .30229 .60692 .28864 .61875 .28733 .61337 .29924 Mtetra
.314 0 .081 r
.61337 .29924 .61875 .28733 .63064 .2858 .6253 .29586 Mtetra
.258 0 .005 r
.6253 .29586 .63064 .2858 .64259 .28391 .63728 .29207 Mtetra
.178 0 0 r
.63728 .29207 .64259 .28391 .65458 .2816 .6493 .28783 Mtetra
.061 0 0 r
.6493 .28783 .65458 .2816 .66662 .27879 .66134 .28312 Mtetra
0 0 0 r
.66134 .28312 .66662 .27879 .6787 .27548 .67341 .27797 Mtetra
.67341 .27797 .6787 .27548 .69081 .27165 .68551 .2724 Mtetra
.477 .894 .813 r
.68551 .2724 .69081 .27165 .70295 .26736 .69763 .26648 Mtetra
.612 .951 .919 r
.69763 .26648 .70295 .26736 .71511 .26264 .70977 .26027 Mtetra
.688 .948 .958 r
.70977 .26027 .71511 .26264 .7273 .25756 .72194 .25385 Mtetra
.723 .917 .96 r
.72194 .25385 .7273 .25756 .73952 .25221 .73413 .24729 Mtetra
.736 .88 .947 r
.73413 .24729 .73952 .25221 .75177 .24665 .74635 .24064 Mtetra
.738 .843 .929 r
.74635 .24064 .75177 .24665 .76405 .24096 .75861 .23394 Mtetra
.734 .81 .911 r
.75861 .23394 .76405 .24096 .77637 .23521 .7709 .22725 Mtetra
.51 .705 .958 r
.1101 .44736 .11732 .45366 .12688 .45251 .11963 .44657 Mtetra
.497 .713 .968 r
.11963 .44657 .12688 .45251 .13649 .45138 .12921 .44584 Mtetra
.482 .723 .977 r
.12921 .44584 .13649 .45138 .14616 .45022 .13883 .44517 Mtetra
.463 .735 .986 r
.13883 .44517 .14616 .45022 .15588 .44898 .1485 .44453 Mtetra
.436 .747 .993 r
.1485 .44453 .15588 .44898 .16566 .44763 .15822 .44392 Mtetra
.403 .76 .994 r
.15822 .44392 .16566 .44763 .17552 .44607 .168 .44327 Mtetra
.355 .768 .98 r
.168 .44327 .17552 .44607 .18546 .44425 .17785 .44254 Mtetra
.289 .762 .936 r
.17785 .44254 .18546 .44425 .19547 .4421 .18776 .44167 Mtetra
.202 .726 .846 r
.18776 .44167 .19547 .4421 .20557 .43956 .19775 .44058 Mtetra
.096 .651 .704 r
.19775 .44058 .20557 .43956 .21576 .4366 .20782 .43924 Mtetra
.009 0 0 r
.20782 .43924 .21576 .4366 .22603 .43317 .21798 .43758 Mtetra
.102 0 0 r
.21798 .43758 .22603 .43317 .23638 .42933 .22821 .4356 Mtetra
.173 0 0 r
.22821 .4356 .23638 .42933 .2468 .42509 .23853 .43328 Mtetra
.226 0 0 r
.23853 .43328 .2468 .42509 .25728 .42052 .24892 .43063 Mtetra
.263 0 0 r
.24892 .43063 .25728 .42052 .26782 .41567 .25938 .42764 Mtetra
.288 0 .058 r
.25938 .42764 .26782 .41567 .27841 .41059 .26992 .4243 Mtetra
.306 0 .106 r
.26992 .4243 .27841 .41059 .28904 .40529 .28053 .42063 Mtetra
.321 0 .143 r
.28053 .42063 .28904 .40529 .29973 .39967 .29119 .41668 Mtetra
.337 0 .177 r
.29119 .41668 .29973 .39967 .31047 .39374 .30191 .41255 Mtetra
.367 .007 .215 r
.30191 .41255 .31047 .39374 .32123 .38796 .31265 .40876 Mtetra
.398 .048 .251 r
.31265 .40876 .32123 .38796 .33198 .38268 .3234 .40552 Mtetra
.418 .077 .278 r
.3234 .40552 .33198 .38268 .34271 .37842 .33417 .40263 Mtetra
.426 .09 .291 r
.33417 .40263 .34271 .37842 .35341 .37533 .34498 .39981 Mtetra
.408 .075 .286 r
.34498 .39981 .35341 .37533 .36415 .37256 .3559 .39604 Mtetra
.372 .038 .263 r
.3559 .39604 .36415 .37256 .37494 .36965 .36692 .39093 Mtetra
.325 0 .224 r
.36692 .39093 .37494 .36965 .38581 .36604 .37803 .38472 Mtetra
.272 0 .171 r
.37803 .38472 .38581 .36604 .39676 .36161 .3892 .37781 Mtetra
.248 0 .125 r
.3892 .37781 .39676 .36161 .40775 .35699 .40037 .37134 Mtetra
.256 0 .097 r
.40037 .37134 .40775 .35699 .41878 .35253 .41154 .36593 Mtetra
.305 0 .102 r
.41154 .36593 .41878 .35253 .42983 .34871 .42269 .36209 Mtetra
.366 0 .132 r
.42269 .36209 .42983 .34871 .44091 .34553 .43383 .35984 Mtetra
.411 .014 .171 r
.43383 .35984 .44091 .34553 .45203 .34251 .44501 .35867 Mtetra
.437 .053 .212 r
.44501 .35867 .45203 .34251 .46321 .3393 .45625 .35794 Mtetra
.433 .067 .242 r
.45625 .35794 .46321 .3393 .47445 .33527 .46756 .35651 Mtetra
.421 .071 .264 r
.46756 .35651 .47445 .33527 .48574 .33053 .47896 .35399 Mtetra
.404 .067 .277 r
.47896 .35399 .48574 .33053 .49708 .32565 .49043 .3501 Mtetra
.39 .06 .28 r
.49043 .3501 .49708 .32565 .50846 .32109 .50195 .34526 Mtetra
.391 .059 .278 r
.50195 .34526 .50846 .32109 .51988 .31771 .51352 .34049 Mtetra
.39 .051 .266 r
.51352 .34049 .51988 .31771 .53135 .31537 .52513 .33607 Mtetra
.389 .04 .247 r
.52513 .33607 .53135 .31537 .54288 .31353 .53679 .33221 Mtetra
.383 .021 .222 r
.53679 .33221 .54288 .31353 .55448 .31187 .5485 .32868 Mtetra
.362 0 .189 r
.5485 .32868 .55448 .31187 .56614 .30989 .56026 .32497 Mtetra
.334 0 .15 r
.56026 .32497 .56614 .30989 .57786 .30758 .57207 .32099 Mtetra
.298 0 .103 r
.57207 .32099 .57786 .30758 .58964 .30506 .58393 .31665 Mtetra
.248 0 .038 r
.58393 .31665 .58964 .30506 .60148 .30229 .59582 .31195 Mtetra
.178 0 0 r
.59582 .31195 .60148 .30229 .61337 .29924 .60776 .3069 Mtetra
.079 0 0 r
.60776 .3069 .61337 .29924 .6253 .29586 .61972 .3015 Mtetra
0 0 0 r
.61972 .3015 .6253 .29586 .63728 .29207 .63172 .29574 Mtetra
.63172 .29574 .63728 .29207 .6493 .28783 .64375 .28965 Mtetra
.437 .863 .737 r
.64375 .28965 .6493 .28783 .66134 .28312 .6558 .28322 Mtetra
.592 .949 .872 r
.6558 .28322 .66134 .28312 .67341 .27797 .66787 .2765 Mtetra
.687 .966 .935 r
.66787 .2765 .67341 .27797 .68551 .2724 .67996 .26956 Mtetra
.733 .945 .951 r
.67996 .26956 .68551 .2724 .69763 .26648 .69207 .26245 Mtetra
.751 .912 .946 r
.69207 .26245 .69763 .26648 .70977 .26027 .70422 .25524 Mtetra
.757 .88 .935 r
.70422 .25524 .70977 .26027 .72194 .25385 .71638 .24799 Mtetra
.755 .852 .923 r
.71638 .24799 .72194 .25385 .73413 .24729 .72858 .24074 Mtetra
.751 .83 .912 r
.72858 .24074 .73413 .24729 .74635 .24064 .74082 .23353 Mtetra
.747 .812 .903 r
.74082 .23353 .74635 .24064 .75861 .23394 .75308 .22635 Mtetra
.742 .796 .896 r
.75308 .22635 .75861 .23394 .7709 .22725 .76539 .21923 Mtetra
.534 .714 .955 r
.10283 .44102 .1101 .44736 .11963 .44657 .11242 .43985 Mtetra
.533 .701 .947 r
.11242 .43985 .11963 .44657 .12921 .44584 .12205 .43878 Mtetra
.531 .689 .94 r
.12205 .43878 .12921 .44584 .13883 .44517 .13172 .4378 Mtetra
.528 .679 .934 r
.13172 .4378 .13883 .44517 .1485 .44453 .14142 .43693 Mtetra
.522 .67 .93 r
.14142 .43693 .1485 .44453 .15822 .44392 .15117 .43619 Mtetra
.517 .664 .928 r
.15117 .43619 .15822 .44392 .168 .44327 .16096 .43555 Mtetra
.512 .663 .93 r
.16096 .43555 .168 .44327 .17785 .44254 .17079 .43499 Mtetra
.508 .668 .934 r
.17079 .43499 .17785 .44254 .18776 .44167 .18069 .43444 Mtetra
.505 .678 .943 r
.18069 .43444 .18776 .44167 .19775 .44058 .19064 .43386 Mtetra
.501 .694 .955 r
.19064 .43386 .19775 .44058 .20782 .43924 .20066 .43318 Mtetra
.497 .718 .97 r
.20066 .43318 .20782 .43924 .21798 .43758 .21075 .43236 Mtetra
.488 .746 .986 r
.21075 .43236 .21798 .43758 .22821 .4356 .22091 .43136 Mtetra
.474 .777 .997 r
.22091 .43136 .22821 .4356 .23853 .43328 .23116 .43012 Mtetra
.449 .806 .997 r
.23116 .43012 .23853 .43328 .24892 .43063 .24148 .42862 Mtetra
.41 .823 .975 r
.24148 .42862 .24892 .43063 .25938 .42764 .25188 .42683 Mtetra
.354 .817 .921 r
.25188 .42683 .25938 .42764 .26992 .4243 .26236 .42474 Mtetra
.279 .782 .83 r
.26236 .42474 .26992 .4243 .28053 .42063 .27291 .42235 Mtetra
.174 .704 .699 r
.27291 .42235 .28053 .42063 .29119 .41668 .28352 .41981 Mtetra
0 0 0 r
.28352 .41981 .29119 .41668 .30191 .41255 .29419 .41721 Mtetra
.083 0 0 r
.29419 .41721 .30191 .41255 .31265 .40876 .3049 .41482 Mtetra
.182 0 0 r
.3049 .41482 .31265 .40876 .3234 .40552 .31564 .41268 Mtetra
.202 0 0 r
.31564 .41268 .3234 .40552 .33417 .40263 .32645 .41018 Mtetra
.164 0 0 r
.32645 .41018 .33417 .40263 .34498 .39981 .33736 .40692 Mtetra
.034 0 0 r
.33736 .40692 .34498 .39981 .3559 .39604 .3484 .40227 Mtetra
0 0 0 r
.3484 .40227 .3559 .39604 .36692 .39093 .35955 .39608 Mtetra
.35955 .39608 .36692 .39093 .37803 .38472 .37077 .38912 Mtetra
.4 .814 .619 r
.37077 .38912 .37803 .38472 .3892 .37781 .38203 .38196 Mtetra
0 0 0 r
.38203 .38196 .3892 .37781 .40037 .37134 .39327 .37548 Mtetra
.39327 .37548 .40037 .37134 .41154 .36593 .4045 .3702 Mtetra
.4045 .3702 .41154 .36593 .42269 .36209 .41572 .36635 Mtetra
.072 0 0 r
.41572 .36635 .42269 .36209 .43383 .35984 .42693 .36393 Mtetra
.17 0 0 r
.42693 .36393 .43383 .35984 .44501 .35867 .43818 .36271 Mtetra
.225 0 0 r
.43818 .36271 .44501 .35867 .45625 .35794 .44947 .3622 Mtetra
.22 0 0 r
.44947 .3622 .45625 .35794 .46756 .35651 .46083 .3615 Mtetra
.195 0 0 r
.46083 .3615 .46756 .35651 .47896 .35399 .47228 .36002 Mtetra
.131 0 0 r
.47228 .36002 .47896 .35399 .49043 .3501 .48382 .357 Mtetra
.074 0 0 r
.48382 .357 .49043 .3501 .50195 .34526 .49543 .35257 Mtetra
.042 0 0 r
.49543 .35257 .50195 .34526 .51352 .34049 .50708 .34736 Mtetra
0 0 0 r
.50708 .34736 .51352 .34049 .52513 .33607 .51878 .34178 Mtetra
.51878 .34178 .52513 .33607 .53679 .33221 .53052 .33646 Mtetra
.53052 .33646 .53679 .33221 .5485 .32868 .54229 .33133 Mtetra
.29 .766 .654 r
.54229 .33133 .5485 .32868 .56026 .32497 .55411 .32615 Mtetra
.435 .872 .802 r
.55411 .32615 .56026 .32497 .57207 .32099 .56597 .3208 Mtetra
.562 .934 .902 r
.56597 .3208 .57207 .32099 .58393 .31665 .57787 .31513 Mtetra
.652 .949 .952 r
.57787 .31513 .58393 .31665 .59582 .31195 .5898 .30915 Mtetra
.705 .932 .963 r
.5898 .30915 .59582 .31195 .60776 .3069 .60175 .30287 Mtetra
.733 .899 .953 r
.60175 .30287 .60776 .3069 .61972 .3015 .61374 .2963 Mtetra
.745 .863 .934 r
.61374 .2963 .61972 .3015 .63172 .29574 .62575 .28948 Mtetra
.749 .83 .914 r
.62575 .28948 .63172 .29574 .64375 .28965 .63779 .28246 Mtetra
.748 .802 .895 r
.63779 .28246 .64375 .28965 .6558 .28322 .64985 .27527 Mtetra
.745 .78 .881 r
.64985 .27527 .6558 .28322 .66787 .2765 .66194 .26798 Mtetra
.742 .764 .871 r
.66194 .26798 .66787 .2765 .67996 .26956 .67405 .26064 Mtetra
.739 .753 .864 r
.67405 .26064 .67996 .26956 .69207 .26245 .68619 .2533 Mtetra
.735 .747 .862 r
.68619 .2533 .69207 .26245 .70422 .25524 .69837 .24602 Mtetra
.732 .745 .862 r
.69837 .24602 .70422 .25524 .71638 .24799 .71058 .23883 Mtetra
.73 .747 .866 r
.71058 .23883 .71638 .24799 .72858 .24074 .72283 .23176 Mtetra
.729 .752 .871 r
.72283 .23176 .72858 .24074 .74082 .23353 .73512 .2248 Mtetra
.728 .76 .878 r
.73512 .2248 .74082 .23353 .75308 .22635 .74745 .21793 Mtetra
.728 .769 .886 r
.74745 .21793 .75308 .22635 .76539 .21923 .75983 .21113 Mtetra
.588 .732 .943 r
.09551 .43462 .10283 .44102 .11242 .43985 .10523 .43255 Mtetra
.589 .704 .922 r
.10523 .43255 .11242 .43985 .12205 .43878 .11498 .43056 Mtetra
.587 .676 .902 r
.11498 .43056 .12205 .43878 .13172 .4378 .12477 .42868 Mtetra
.582 .65 .883 r
.12477 .42868 .13172 .4378 .14142 .43693 .13458 .42696 Mtetra
.574 .627 .866 r
.13458 .42696 .14142 .43693 .15117 .43619 .14442 .42543 Mtetra
.568 .606 .851 r
.14442 .42543 .15117 .43619 .16096 .43555 .15429 .42408 Mtetra
.561 .589 .839 r
.15429 .42408 .16096 .43555 .17079 .43499 .16419 .42291 Mtetra
.556 .575 .828 r
.16419 .42291 .17079 .43499 .18069 .43444 .17413 .42189 Mtetra
.553 .565 .821 r
.17413 .42189 .18069 .43444 .19064 .43386 .18411 .42098 Mtetra
.551 .559 .816 r
.18411 .42098 .19064 .43386 .20066 .43318 .19414 .42013 Mtetra
.55 .557 .814 r
.19414 .42013 .20066 .43318 .21075 .43236 .20423 .41929 Mtetra
.552 .558 .814 r
.20423 .41929 .21075 .43236 .22091 .43136 .21438 .4184 Mtetra
.555 .562 .816 r
.21438 .4184 .22091 .43136 .23116 .43012 .2246 .4174 Mtetra
.56 .569 .82 r
.2246 .4174 .23116 .43012 .24148 .42862 .23489 .41625 Mtetra
.566 .579 .826 r
.23489 .41625 .24148 .42862 .25188 .42683 .24525 .41492 Mtetra
.571 .591 .835 r
.24525 .41492 .25188 .42683 .26236 .42474 .25568 .41343 Mtetra
.576 .606 .846 r
.25568 .41343 .26236 .42474 .27291 .42235 .26618 .41178 Mtetra
.577 .623 .862 r
.26618 .41178 .27291 .42235 .28352 .41981 .27674 .41009 Mtetra
.574 .643 .881 r
.27674 .41009 .28352 .41981 .29419 .41721 .28735 .40841 Mtetra
.573 .668 .903 r
.28735 .40841 .29419 .41721 .3049 .41482 .29802 .40669 Mtetra
.577 .69 .918 r
.29802 .40669 .3049 .41482 .31564 .41268 .30877 .40478 Mtetra
.614 .712 .915 r
.30877 .40478 .31564 .41268 .32645 .41018 .31962 .40201 Mtetra
.658 .72 .894 r
.31962 .40201 .32645 .41018 .33736 .40692 .33059 .39803 Mtetra
.691 .713 .866 r
.33059 .39803 .33736 .40692 .3484 .40227 .34168 .39287 Mtetra
.712 .708 .845 r
.34168 .39287 .3484 .40227 .35955 .39608 .35286 .3867 Mtetra
.714 .71 .845 r
.35286 .3867 .35955 .39608 .37077 .38912 .36407 .38045 Mtetra
.71 .726 .863 r
.36407 .38045 .37077 .38912 .38203 .38196 .37529 .37458 Mtetra
.7 .76 .898 r
.37529 .37458 .38203 .38196 .39327 .37548 .38651 .36935 Mtetra
.676 .793 .937 r
.38651 .36935 .39327 .37548 .4045 .3702 .39774 .36488 Mtetra
.646 .814 .964 r
.39774 .36488 .4045 .3702 .41572 .36635 .40899 .361 Mtetra
.616 .804 .972 r
.40899 .361 .41572 .36635 .42693 .36393 .42027 .35771 Mtetra
.585 .763 .963 r
.42027 .35771 .42693 .36393 .43818 .36271 .43158 .35519 Mtetra
.565 .712 .94 r
.43158 .35519 .43818 .36271 .44947 .3622 .44293 .35331 Mtetra
.556 .667 .911 r
.44293 .35331 .44947 .3622 .46083 .3615 .45433 .35183 Mtetra
.563 .65 .894 r
.45433 .35183 .46083 .3615 .47228 .36002 .4658 .35027 Mtetra
.601 .666 .885 r
.4658 .35027 .47228 .36002 .48382 .357 .47735 .3477 Mtetra
.642 .696 .884 r
.47735 .3477 .48382 .357 .49543 .35257 .48897 .34393 Mtetra
.682 .729 .886 r
.48897 .34393 .49543 .35257 .50708 .34736 .50065 .33894 Mtetra
.708 .745 .88 r
.50065 .33894 .50708 .34736 .51878 .34178 .51238 .33307 Mtetra
.711 .739 .873 r
.51238 .33307 .51878 .34178 .53052 .33646 .52415 .32699 Mtetra
.707 .72 .859 r
.52415 .32699 .53052 .33646 .54229 .33133 .53595 .32087 Mtetra
.7 .695 .842 r
.53595 .32087 .54229 .33133 .55411 .32615 .54779 .31474 Mtetra
.694 .674 .827 r
.54779 .31474 .55411 .32615 .56597 .3208 .55966 .30857 Mtetra
.692 .659 .813 r
.55966 .30857 .56597 .3208 .57787 .31513 .57157 .30223 Mtetra
.691 .648 .802 r
.57157 .30223 .57787 .31513 .5898 .30915 .5835 .29571 Mtetra
.691 .64 .794 r
.5835 .29571 .5898 .30915 .60175 .30287 .59547 .28899 Mtetra
.69 .633 .787 r
.59547 .28899 .60175 .30287 .61374 .2963 .60746 .2821 Mtetra
.69 .629 .783 r
.60746 .2821 .61374 .2963 .62575 .28948 .61949 .2751 Mtetra
.69 .627 .781 r
.61949 .2751 .62575 .28948 .63779 .28246 .63154 .26803 Mtetra
.69 .627 .78 r
.63154 .26803 .63779 .28246 .64985 .27527 .64362 .26095 Mtetra
.69 .629 .783 r
.64362 .26095 .64985 .27527 .66194 .26798 .65573 .25392 Mtetra
.689 .633 .787 r
.65573 .25392 .66194 .26798 .67405 .26064 .66788 .247 Mtetra
.69 .64 .794 r
.66788 .247 .67405 .26064 .68619 .2533 .68007 .24022 Mtetra
.69 .649 .804 r
.68007 .24022 .68619 .2533 .69837 .24602 .69231 .23361 Mtetra
.691 .661 .816 r
.69231 .23361 .69837 .24602 .71058 .23883 .70459 .22718 Mtetra
.692 .677 .831 r
.70459 .22718 .71058 .23883 .72283 .23176 .71692 .22095 Mtetra
.694 .696 .848 r
.71692 .22095 .72283 .23176 .73512 .2248 .72931 .21486 Mtetra
.696 .718 .866 r
.72931 .21486 .73512 .2248 .74745 .21793 .74174 .20888 Mtetra
.699 .743 .885 r
.74174 .20888 .74745 .21793 .75983 .21113 .75422 .20298 Mtetra
.651 .75 .922 r
.08813 .42819 .09551 .43462 .10523 .43255 .09804 .4248 Mtetra
.646 .71 .894 r
.09804 .4248 .10523 .43255 .11498 .43056 .10797 .42148 Mtetra
.639 .673 .867 r
.10797 .42148 .11498 .43056 .12477 .42868 .11793 .41827 Mtetra
.629 .64 .842 r
.11793 .41827 .12477 .42868 .13458 .42696 .12791 .4152 Mtetra
.618 .609 .82 r
.12791 .4152 .13458 .42696 .14442 .42543 .13791 .41234 Mtetra
.607 .582 .8 r
.13791 .41234 .14442 .42543 .15429 .42408 .14793 .40968 Mtetra
.597 .559 .782 r
.14793 .40968 .15429 .42408 .16419 .42291 .15796 .40725 Mtetra
.589 .538 .766 r
.15796 .40725 .16419 .42291 .17413 .42189 .16802 .40503 Mtetra
.581 .521 .752 r
.16802 .40503 .17413 .42189 .18411 .42098 .17811 .40299 Mtetra
.575 .507 .74 r
.17811 .40299 .18411 .42098 .19414 .42013 .18823 .4011 Mtetra
.571 .495 .73 r
.18823 .4011 .19414 .42013 .20423 .41929 .19839 .39932 Mtetra
.568 .486 .722 r
.19839 .39932 .20423 .41929 .21438 .4184 .20859 .39758 Mtetra
.567 .479 .715 r
.20859 .39758 .21438 .4184 .2246 .4174 .21885 .39586 Mtetra
.566 .473 .709 r
.21885 .39586 .2246 .4174 .23489 .41625 .22917 .3941 Mtetra
.566 .47 .704 r
.22917 .3941 .23489 .41625 .24525 .41492 .23954 .39229 Mtetra
.566 .467 .701 r
.23954 .39229 .24525 .41492 .25568 .41343 .24997 .39044 Mtetra
.566 .465 .699 r
.24997 .39044 .25568 .41343 .26618 .41178 .26046 .38853 Mtetra
.566 .464 .697 r
.26046 .38853 .26618 .41178 .27674 .41009 .271 .38662 Mtetra
.566 .463 .696 r
.271 .38662 .27674 .41009 .28735 .40841 .28159 .38469 Mtetra
.57 .464 .694 r
.28159 .38469 .28735 .40841 .29802 .40669 .29226 .38252 Mtetra
.576 .466 .691 r
.29226 .38252 .29802 .40669 .30877 .40478 .30302 .37994 Mtetra
.588 .47 .686 r
.30302 .37994 .30877 .40478 .31962 .40201 .31387 .37653 Mtetra
.601 .475 .681 r
.31387 .37653 .31962 .40201 .33059 .39803 .32484 .37215 Mtetra
.607 .477 .679 r
.32484 .37215 .33059 .39803 .34168 .39287 .33588 .36728 Mtetra
.609 .481 .68 r
.33588 .36728 .34168 .39287 .35286 .3867 .34696 .36227 Mtetra
.605 .484 .688 r
.34696 .36227 .35286 .3867 .36407 .38045 .35805 .35777 Mtetra
.599 .491 .702 r
.35805 .35777 .36407 .38045 .37529 .37458 .36914 .35398 Mtetra
.599 .506 .719 r
.36914 .35398 .37529 .37458 .38651 .36935 .38027 .35047 Mtetra
.604 .523 .736 r
.38027 .35047 .38651 .36935 .39774 .36488 .39145 .34698 Mtetra
.615 .539 .745 r
.39145 .34698 .39774 .36488 .40899 .361 .40269 .34307 Mtetra
.624 .544 .744 r
.40269 .34307 .40899 .361 .42027 .35771 .414 .33871 Mtetra
.619 .531 .734 r
.414 .33871 .42027 .35771 .43158 .35519 .42535 .33438 Mtetra
.608 .51 .718 r
.42535 .33438 .43158 .35519 .44293 .35331 .43673 .33033 Mtetra
.589 .485 .703 r
.43673 .33033 .44293 .35331 .45433 .35183 .44815 .32699 Mtetra
.577 .466 .691 r
.44815 .32699 .45433 .35183 .4658 .35027 .45961 .32417 Mtetra
.577 .46 .683 r
.45961 .32417 .4658 .35027 .47735 .3477 .47112 .32121 Mtetra
.583 .462 .681 r
.47112 .32121 .47735 .3477 .48897 .34393 .4827 .31776 Mtetra
.598 .473 .682 r
.4827 .31776 .48897 .34393 .50065 .33894 .49435 .31332 Mtetra
.611 .485 .684 r
.49435 .31332 .50065 .33894 .51238 .33307 .50604 .30804 Mtetra
.618 .493 .687 r
.50604 .30804 .51238 .33307 .52415 .32699 .51778 .30233 Mtetra
.623 .497 .689 r
.51778 .30233 .52415 .32699 .53595 .32087 .52955 .29637 Mtetra
.623 .499 .69 r
.52955 .29637 .53595 .32087 .54779 .31474 .54136 .29039 Mtetra
.624 .5 .691 r
.54136 .29039 .54779 .31474 .55966 .30857 .55321 .28439 Mtetra
.625 .502 .693 r
.55321 .28439 .55966 .30857 .57157 .30223 .56509 .27833 Mtetra
.627 .505 .695 r
.56509 .27833 .57157 .30223 .5835 .29571 .57702 .27221 Mtetra
.629 .509 .697 r
.57702 .27221 .5835 .29571 .59547 .28899 .58897 .26603 Mtetra
.631 .514 .701 r
.58897 .26603 .59547 .28899 .60746 .2821 .60096 .25981 Mtetra
.634 .52 .706 r
.60096 .25981 .60746 .2821 .61949 .2751 .61299 .25359 Mtetra
.636 .527 .713 r
.61299 .25359 .61949 .2751 .63154 .26803 .62506 .24741 Mtetra
.638 .535 .721 r
.62506 .24741 .63154 .26803 .64362 .26095 .63717 .24133 Mtetra
.64 .544 .73 r
.63717 .24133 .64362 .26095 .65573 .25392 .64932 .23539 Mtetra
.642 .555 .742 r
.64932 .23539 .65573 .25392 .66788 .247 .66152 .22964 Mtetra
.644 .569 .755 r
.66152 .22964 .66788 .247 .68007 .24022 .67378 .22409 Mtetra
.646 .584 .771 r
.67378 .22409 .68007 .24022 .69231 .23361 .68609 .21877 Mtetra
.648 .603 .79 r
.68609 .21877 .69231 .23361 .70459 .22718 .69847 .21366 Mtetra
.649 .624 .811 r
.69847 .21366 .70459 .22718 .71692 .22095 .7109 .20876 Mtetra
.652 .65 .835 r
.7109 .20876 .71692 .22095 .72931 .21486 .7234 .204 Mtetra
.655 .68 .861 r
.7234 .204 .72931 .21486 .74174 .20888 .73595 .19935 Mtetra
.658 .714 .89 r
.73595 .19935 .74174 .20888 .75422 .20298 .74857 .19475 Mtetra
.702 .761 .898 r
.0807 .4217 .08813 .42819 .09804 .4248 .09081 .41691 Mtetra
.692 .72 .871 r
.09081 .41691 .09804 .4248 .10797 .42148 .10095 .41215 Mtetra
.681 .683 .845 r
.10095 .41215 .10797 .42148 .11793 .41827 .11111 .40746 Mtetra
.668 .649 .821 r
.11111 .40746 .11793 .41827 .12791 .4152 .12128 .40291 Mtetra
.655 .618 .8 r
.12128 .40291 .12791 .4152 .13791 .41234 .13147 .39853 Mtetra
.642 .59 .78 r
.13147 .39853 .13791 .41234 .14793 .40968 .14166 .39434 Mtetra
.63 .564 .762 r
.14166 .39434 .14793 .40968 .15796 .40725 .15186 .39038 Mtetra
.619 .542 .746 r
.15186 .39038 .15796 .40725 .16802 .40503 .16208 .38664 Mtetra
.609 .522 .731 r
.16208 .38664 .16802 .40503 .17811 .40299 .17231 .38311 Mtetra
.6 .505 .718 r
.17231 .38311 .17811 .40299 .18823 .4011 .18256 .37977 Mtetra
.593 .49 .707 r
.18256 .37977 .18823 .4011 .19839 .39932 .19284 .3766 Mtetra
.587 .478 .697 r
.19284 .3766 .19839 .39932 .20859 .39758 .20314 .37355 Mtetra
.583 .468 .688 r
.20314 .37355 .20859 .39758 .21885 .39586 .21348 .37059 Mtetra
.579 .459 .68 r
.21348 .37059 .21885 .39586 .22917 .3941 .22386 .3677 Mtetra
.576 .452 .674 r
.22386 .3677 .22917 .3941 .23954 .39229 .23428 .36487 Mtetra
.573 .446 .668 r
.23428 .36487 .23954 .39229 .24997 .39044 .24475 .36209 Mtetra
.571 .44 .664 r
.24475 .36209 .24997 .39044 .26046 .38853 .25526 .35933 Mtetra
.57 .437 .66 r
.25526 .35933 .26046 .38853 .271 .38662 .26581 .35656 Mtetra
.569 .433 .656 r
.26581 .35656 .271 .38662 .28159 .38469 .27643 .35372 Mtetra
.572 .432 .652 r
.27643 .35372 .28159 .38469 .29226 .38252 .28711 .35058 Mtetra
.576 .432 .648 r
.28711 .35058 .29226 .38252 .30302 .37994 .29787 .34702 Mtetra
.58 .431 .644 r
.29787 .34702 .30302 .37994 .31387 .37653 .30871 .343 Mtetra
.582 .432 .642 r
.30871 .343 .31387 .37653 .32484 .37215 .31961 .33865 Mtetra
.578 .429 .642 r
.31961 .33865 .32484 .37215 .33588 .36728 .33053 .33469 Mtetra
.57 .426 .646 r
.33053 .33469 .33588 .36728 .34696 .36227 .34145 .33145 Mtetra
.56 .426 .654 r
.34145 .33145 .34696 .36227 .35805 .35777 .35237 .32915 Mtetra
.552 .429 .666 r
.35237 .32915 .35805 .35777 .36914 .35398 .3633 .32759 Mtetra
.557 .443 .679 r
.3633 .32759 .36914 .35398 .38027 .35047 .37431 .32583 Mtetra
.573 .463 .69 r
.37431 .32583 .38027 .35047 .39145 .34698 .38541 .32328 Mtetra
.597 .484 .695 r
.38541 .32328 .39145 .34698 .40269 .34307 .39663 .31932 Mtetra
.619 .497 .693 r
.39663 .31932 .40269 .34307 .414 .33871 .40794 .31393 Mtetra
.626 .496 .685 r
.40794 .31393 .414 .33871 .42535 .33438 .41932 .30776 Mtetra
.623 .485 .674 r
.41932 .30776 .42535 .33438 .43673 .33033 .43074 .30136 Mtetra
.606 .465 .663 r
.43074 .30136 .43673 .33033 .44815 .32699 .44216 .29572 Mtetra
.59 .446 .654 r
.44216 .29572 .44815 .32699 .45961 .32417 .4536 .291 Mtetra
.577 .431 .646 r
.4536 .291 .45961 .32417 .47112 .32121 .46508 .28703 Mtetra
.571 .424 .643 r
.46508 .28703 .47112 .32121 .4827 .31776 .47659 .28344 Mtetra
.575 .426 .642 r
.47659 .28344 .4827 .31776 .49435 .31332 .48816 .27951 Mtetra
.581 .432 .644 r
.48816 .27951 .49435 .31332 .50604 .30804 .49978 .27512 Mtetra
.587 .439 .648 r
.49978 .27512 .50604 .30804 .51778 .30233 .51146 .2703 Mtetra
.592 .446 .651 r
.51146 .2703 .51778 .30233 .52955 .29637 .52317 .26517 Mtetra
.595 .45 .655 r
.52317 .26517 .52955 .29637 .54136 .29039 .53494 .25996 Mtetra
.596 .454 .659 r
.53494 .25996 .54136 .29039 .55321 .28439 .54674 .25473 Mtetra
.598 .458 .662 r
.54674 .25473 .55321 .28439 .56509 .27833 .55859 .24952 Mtetra
.599 .463 .667 r
.55859 .24952 .56509 .27833 .57702 .27221 .57048 .24436 Mtetra
.601 .468 .672 r
.57048 .24436 .57702 .27221 .58897 .26603 .58241 .23924 Mtetra
.602 .474 .678 r
.58241 .23924 .58897 .26603 .60096 .25981 .59439 .2342 Mtetra
.604 .482 .686 r
.59439 .2342 .60096 .25981 .61299 .25359 .60643 .22925 Mtetra
.606 .49 .695 r
.60643 .22925 .61299 .25359 .62506 .24741 .61851 .22442 Mtetra
.607 .499 .705 r
.61851 .22442 .62506 .24741 .63717 .24133 .63065 .21975 Mtetra
.609 .51 .717 r
.63065 .21975 .63717 .24133 .64932 .23539 .64284 .21527 Mtetra
.609 .523 .731 r
.64284 .21527 .64932 .23539 .66152 .22964 .6551 .21102 Mtetra
.61 .537 .747 r
.6551 .21102 .66152 .22964 .67378 .22409 .66743 .20698 Mtetra
.61 .554 .766 r
.66743 .20698 .67378 .22409 .68609 .21877 .67982 .20317 Mtetra
.611 .573 .787 r
.67982 .20317 .68609 .21877 .69847 .21366 .69228 .19957 Mtetra
.611 .596 .811 r
.69228 .19957 .69847 .21366 .7109 .20876 .70482 .19615 Mtetra
.611 .623 .838 r
.70482 .19615 .7109 .20876 .7234 .204 .71744 .19285 Mtetra
.611 .654 .867 r
.71744 .19285 .7234 .204 .73595 .19935 .73012 .18964 Mtetra
.61 .689 .899 r
.73012 .18964 .73595 .19935 .74857 .19475 .74288 .18646 Mtetra
.734 .766 .878 r
.07322 .41517 .0807 .4217 .09081 .41691 .08351 .40919 Mtetra
.725 .733 .857 r
.08351 .40919 .09081 .41691 .10095 .41215 .09383 .40323 Mtetra
.714 .703 .838 r
.09383 .40323 .10095 .41215 .11111 .40746 .10416 .39731 Mtetra
.702 .674 .82 r
.10416 .39731 .11111 .40746 .12128 .40291 .11451 .39148 Mtetra
.69 .647 .802 r
.11451 .39148 .12128 .40291 .13147 .39853 .12486 .38579 Mtetra
.677 .622 .786 r
.12486 .38579 .13147 .39853 .14166 .39434 .13522 .38026 Mtetra
.665 .598 .77 r
.13522 .38026 .14166 .39434 .15186 .39038 .14559 .37493 Mtetra
.653 .576 .756 r
.14559 .37493 .15186 .39038 .16208 .38664 .15596 .3698 Mtetra
.641 .555 .742 r
.15596 .3698 .16208 .38664 .17231 .38311 .16633 .36489 Mtetra
.631 .537 .729 r
.16633 .36489 .17231 .38311 .18256 .37977 .17672 .36018 Mtetra
.622 .521 .718 r
.17672 .36018 .18256 .37977 .19284 .3766 .18711 .35565 Mtetra
.614 .506 .708 r
.18711 .35565 .19284 .3766 .20314 .37355 .19753 .35128 Mtetra
.608 .494 .698 r
.19753 .35128 .20314 .37355 .21348 .37059 .20797 .34705 Mtetra
.602 .483 .69 r
.20797 .34705 .21348 .37059 .22386 .3677 .21844 .34294 Mtetra
.597 .473 .682 r
.21844 .34294 .22386 .3677 .23428 .36487 .22893 .33892 Mtetra
.592 .465 .675 r
.22893 .33892 .23428 .36487 .24475 .36209 .23946 .33498 Mtetra
.589 .457 .669 r
.23946 .33498 .24475 .36209 .25526 .35933 .25002 .33109 Mtetra
.586 .451 .663 r
.25002 .33109 .25526 .35933 .26581 .35656 .26063 .32721 Mtetra
.584 .445 .658 r
.26063 .32721 .26581 .35656 .27643 .35372 .27127 .32331 Mtetra
.583 .441 .653 r
.27127 .32331 .27643 .35372 .28711 .35058 .28197 .31933 Mtetra
.582 .437 .65 r
.28197 .31933 .28711 .35058 .29787 .34702 .29271 .3153 Mtetra
.578 .433 .648 r
.29271 .3153 .29787 .34702 .30871 .343 .30347 .31152 Mtetra
.571 .429 .65 r
.30347 .31152 .30871 .343 .31961 .33865 .31424 .30826 Mtetra
.557 .424 .655 r
.31424 .30826 .31961 .33865 .33053 .33469 .32499 .30616 Mtetra
.538 .419 .665 r
.32499 .30616 .33053 .33469 .34145 .33145 .33571 .30542 Mtetra
.521 .42 .68 r
.33571 .30542 .34145 .33145 .35237 .32915 .34644 .30567 Mtetra
.511 .429 .699 r
.34644 .30567 .35237 .32915 .3633 .32759 .35722 .30639 Mtetra
.528 .456 .719 r
.35722 .30639 .3633 .32759 .37431 .32583 .36811 .30627 Mtetra
.564 .493 .734 r
.36811 .30627 .37431 .32583 .38541 .32328 .37916 .30455 Mtetra
.613 .529 .736 r
.37916 .30455 .38541 .32328 .39663 .31932 .39036 .30055 Mtetra
.652 .552 .729 r
.39036 .30055 .39663 .31932 .40794 .31393 .4017 .29425 Mtetra
.672 .556 .716 r
.4017 .29425 .40794 .31393 .41932 .30776 .41314 .28634 Mtetra
.674 .545 .7 r
.41314 .28634 .41932 .30776 .43074 .30136 .42461 .27758 Mtetra
.657 .521 .686 r
.42461 .27758 .43074 .30136 .44216 .29572 .43609 .26928 Mtetra
.634 .493 .673 r
.43609 .26928 .44216 .29572 .4536 .291 .44756 .26196 Mtetra
.609 .466 .662 r
.44756 .26196 .4536 .291 .46508 .28703 .45902 .256 Mtetra
.59 .446 .654 r
.45902 .256 .46508 .28703 .47659 .28344 .4705 .2512 Mtetra
.581 .436 .649 r
.4705 .2512 .47659 .28344 .48816 .27951 .48201 .24693 Mtetra
.577 .433 .648 r
.48201 .24693 .48816 .27951 .49978 .27512 .49357 .24291 Mtetra
.578 .435 .65 r
.49357 .24291 .49978 .27512 .51146 .2703 .50518 .23884 Mtetra
.581 .439 .653 r
.50518 .23884 .51146 .2703 .52317 .26517 .51684 .23469 Mtetra
.583 .444 .658 r
.51684 .23469 .52317 .26517 .53494 .25996 .52855 .23052 Mtetra
.584 .45 .663 r
.52855 .23052 .53494 .25996 .54674 .25473 .54031 .22635 Mtetra
.586 .455 .669 r
.54031 .22635 .54674 .25473 .55859 .24952 .55212 .22224 Mtetra
.587 .461 .676 r
.55212 .22224 .55859 .24952 .57048 .24436 .56399 .2182 Mtetra
.588 .467 .683 r
.56399 .2182 .57048 .24436 .58241 .23924 .57591 .21425 Mtetra
.589 .475 .691 r
.57591 .21425 .58241 .23924 .59439 .2342 .58789 .21043 Mtetra
.589 .482 .7 r
.58789 .21043 .59439 .2342 .60643 .22925 .59992 .20674 Mtetra
.59 .491 .711 r
.59992 .20674 .60643 .22925 .61851 .22442 .61202 .20322 Mtetra
.589 .501 .723 r
.61202 .20322 .61851 .22442 .63065 .21975 .62419 .19989 Mtetra
.589 .512 .736 r
.62419 .19989 .63065 .21975 .64284 .21527 .63642 .19676 Mtetra
.587 .525 .752 r
.63642 .19676 .64284 .21527 .6551 .21102 .64873 .19386 Mtetra
.586 .539 .769 r
.64873 .19386 .6551 .21102 .66743 .20698 .66112 .19117 Mtetra
.583 .555 .789 r
.66112 .19117 .66743 .20698 .67982 .20317 .67358 .18868 Mtetra
.581 .574 .81 r
.67358 .18868 .67982 .20317 .69228 .19957 .68613 .18637 Mtetra
.578 .594 .833 r
.68613 .18637 .69228 .19957 .70482 .19615 .69876 .1842 Mtetra
.574 .618 .858 r
.69876 .1842 .70482 .19615 .71744 .19285 .71147 .18213 Mtetra
.57 .644 .885 r
.71147 .18213 .71744 .19285 .73012 .18964 .72426 .18011 Mtetra
.565 .674 .912 r
.72426 .18011 .73012 .18964 .74288 .18646 .73713 .1781 Mtetra
.753 .768 .865 r
.06568 .40859 .07322 .41517 .08351 .40919 .07611 .40181 Mtetra
.746 .746 .852 r
.07611 .40181 .08351 .40919 .09383 .40323 .08656 .39502 Mtetra
.738 .726 .84 r
.08656 .39502 .09383 .40323 .10416 .39731 .09703 .38825 Mtetra
.73 .705 .828 r
.09703 .38825 .10416 .39731 .11451 .39148 .10751 .38154 Mtetra
.72 .685 .816 r
.10751 .38154 .11451 .39148 .12486 .38579 .11799 .3749 Mtetra
.71 .665 .804 r
.11799 .3749 .12486 .38579 .13522 .38026 .12849 .36839 Mtetra
.7 .645 .792 r
.12849 .36839 .13522 .38026 .14559 .37493 .13899 .36203 Mtetra
.689 .626 .78 r
.13899 .36203 .14559 .37493 .15596 .3698 .14948 .35584 Mtetra
.678 .607 .769 r
.14948 .35584 .15596 .3698 .16633 .36489 .15999 .34984 Mtetra
.667 .589 .758 r
.15999 .34984 .16633 .36489 .17672 .36018 .17049 .34403 Mtetra
.658 .572 .747 r
.17049 .34403 .17672 .36018 .18711 .35565 .181 .3384 Mtetra
.649 .556 .737 r
.181 .3384 .18711 .35565 .19753 .35128 .19153 .33294 Mtetra
.64 .542 .727 r
.19153 .33294 .19753 .35128 .20797 .34705 .20206 .32763 Mtetra
.633 .529 .719 r
.20206 .32763 .20797 .34705 .21844 .34294 .21262 .32245 Mtetra
.627 .518 .71 r
.21262 .32245 .21844 .34294 .22893 .33892 .22319 .31737 Mtetra
.621 .507 .702 r
.22319 .31737 .22893 .33892 .23946 .33498 .23379 .31236 Mtetra
.617 .498 .695 r
.23379 .31236 .23946 .33498 .25002 .33109 .24442 .30741 Mtetra
.612 .489 .688 r
.24442 .30741 .25002 .33109 .26063 .32721 .25508 .30251 Mtetra
.608 .481 .682 r
.25508 .30251 .26063 .32721 .27127 .32331 .26577 .29768 Mtetra
.602 .473 .677 r
.26577 .29768 .27127 .32331 .28197 .31933 .27648 .29303 Mtetra
.595 .465 .674 r
.27648 .29303 .28197 .31933 .29271 .3153 .28721 .28872 Mtetra
.583 .456 .673 r
.28721 .28872 .29271 .3153 .30347 .31152 .29791 .28523 Mtetra
.565 .446 .676 r
.29791 .28523 .30347 .31152 .31424 .30826 .30858 .28286 Mtetra
.54 .434 .683 r
.30858 .28286 .31424 .30826 .32499 .30616 .3192 .282 Mtetra
.511 .423 .692 r
.3192 .282 .32499 .30616 .33571 .30542 .32979 .28263 Mtetra
.493 .421 .704 r
.32979 .28263 .33571 .30542 .34644 .30567 .34042 .28401 Mtetra
.491 .428 .714 r
.34042 .28401 .34644 .30567 .35722 .30639 .35112 .28543 Mtetra
.518 .452 .721 r
.35112 .28543 .35722 .30639 .36811 .30627 .36197 .28567 Mtetra
.56 .482 .723 r
.36197 .28567 .36811 .30627 .37916 .30455 .37299 .28402 Mtetra
.607 .511 .72 r
.37299 .28402 .37916 .30455 .39036 .30055 .38418 .27997 Mtetra
.646 .534 .713 r
.38418 .27997 .39036 .30055 .4017 .29425 .39551 .27353 Mtetra
.672 .549 .706 r
.39551 .27353 .4017 .29425 .41314 .28634 .40695 .26517 Mtetra
.685 .553 .699 r
.40695 .26517 .41314 .28634 .42461 .27758 .41844 .25563 Mtetra
.68 .545 .694 r
.41844 .25563 .42461 .27758 .43609 .26928 .42995 .2461 Mtetra
.665 .529 .689 r
.42995 .2461 .43609 .26928 .44756 .26196 .44143 .23731 Mtetra
.639 .505 .683 r
.44143 .23731 .44756 .26196 .45902 .256 .4529 .23001 Mtetra
.615 .483 .678 r
.4529 .23001 .45902 .256 .4705 .2512 .46436 .22422 Mtetra
.596 .466 .674 r
.46436 .22422 .4705 .2512 .48201 .24693 .47584 .21957 Mtetra
.584 .457 .673 r
.47584 .21957 .48201 .24693 .49357 .24291 .48735 .21574 Mtetra
.579 .455 .675 r
.48735 .21574 .49357 .24291 .50518 .23884 .49892 .21226 Mtetra
.577 .457 .679 r
.49892 .21226 .50518 .23884 .51684 .23469 .51053 .20897 Mtetra
.578 .462 .685 r
.51053 .20897 .51684 .23469 .52855 .23052 .5222 .20574 Mtetra
.579 .468 .691 r
.5222 .20574 .52855 .23052 .54031 .22635 .53393 .20257 Mtetra
.58 .475 .699 r
.53393 .20257 .54031 .22635 .55212 .22224 .54572 .19945 Mtetra
.58 .482 .707 r
.54572 .19945 .55212 .22224 .56399 .2182 .55758 .19642 Mtetra
.581 .49 .716 r
.55758 .19642 .56399 .2182 .57591 .21425 .56949 .19348 Mtetra
.58 .498 .726 r
.56949 .19348 .57591 .21425 .58789 .21043 .58147 .19068 Mtetra
.579 .506 .737 r
.58147 .19068 .58789 .21043 .59992 .20674 .59352 .18804 Mtetra
.578 .516 .749 r
.59352 .18804 .59992 .20674 .61202 .20322 .60564 .18557 Mtetra
.575 .526 .763 r
.60564 .18557 .61202 .20322 .62419 .19989 .61783 .1833 Mtetra
.572 .537 .778 r
.61783 .1833 .62419 .19989 .63642 .19676 .6301 .18122 Mtetra
.568 .55 .794 r
.6301 .18122 .63642 .19676 .64873 .19386 .64245 .17934 Mtetra
.564 .563 .811 r
.64245 .17934 .64873 .19386 .66112 .19117 .65489 .17764 Mtetra
.558 .578 .829 r
.65489 .17764 .66112 .19117 .67358 .18868 .66741 .1761 Mtetra
.553 .593 .848 r
.66741 .1761 .67358 .18868 .68613 .18637 .68002 .1747 Mtetra
.547 .61 .867 r
.68002 .1747 .68613 .18637 .69876 .1842 .69272 .17339 Mtetra
.541 .628 .887 r
.69272 .17339 .69876 .1842 .71147 .18213 .70551 .17213 Mtetra
.535 .647 .906 r
.70551 .17213 .71147 .18213 .72426 .18011 .71838 .17091 Mtetra
.528 .666 .924 r
.71838 .17091 .72426 .18011 .73713 .1781 .73134 .16968 Mtetra
.755 .768 .863 r
.05808 .40196 .06568 .40859 .07611 .40181 .06856 .39503 Mtetra
.755 .764 .861 r
.06856 .39503 .07611 .40181 .08656 .39502 .07906 .38806 Mtetra
.753 .76 .858 r
.07906 .38806 .08656 .39502 .09703 .38825 .08958 .38109 Mtetra
.751 .756 .856 r
.08958 .38109 .09703 .38825 .10751 .38154 .10012 .37414 Mtetra
.748 .75 .854 r
.10012 .37414 .10751 .38154 .11799 .3749 .11067 .36722 Mtetra
.744 .743 .851 r
.11067 .36722 .11799 .3749 .12849 .36839 .12123 .36038 Mtetra
.739 .735 .847 r
.12123 .36038 .12849 .36839 .13899 .36203 .1318 .35364 Mtetra
.733 .725 .843 r
.1318 .35364 .13899 .36203 .14948 .35584 .14237 .34703 Mtetra
.726 .714 .839 r
.14237 .34703 .14948 .35584 .15999 .34984 .15294 .34056 Mtetra
.719 .703 .834 r
.15294 .34056 .15999 .34984 .17049 .34403 .16353 .33425 Mtetra
.711 .69 .828 r
.16353 .33425 .17049 .34403 .181 .3384 .17411 .32809 Mtetra
.704 .678 .822 r
.17411 .32809 .181 .3384 .19153 .33294 .18471 .32208 Mtetra
.696 .665 .816 r
.18471 .32208 .19153 .33294 .20206 .32763 .19531 .31623 Mtetra
.689 .653 .809 r
.19531 .31623 .20206 .32763 .21262 .32245 .20593 .31051 Mtetra
.682 .642 .803 r
.20593 .31051 .21262 .32245 .22319 .31737 .21657 .30491 Mtetra
.677 .631 .797 r
.21657 .30491 .22319 .31737 .23379 .31236 .22723 .29941 Mtetra
.671 .622 .791 r
.22723 .29941 .23379 .31236 .24442 .30741 .23791 .29399 Mtetra
.666 .613 .786 r
.23791 .29399 .24442 .30741 .25508 .30251 .24861 .28866 Mtetra
.662 .605 .781 r
.24861 .28866 .25508 .30251 .26577 .29768 .25934 .28343 Mtetra
.655 .597 .777 r
.25934 .28343 .26577 .29768 .27648 .29303 .27008 .27838 Mtetra
.647 .588 .774 r
.27008 .27838 .27648 .29303 .28721 .28872 .28084 .27359 Mtetra
.633 .575 .771 r
.28084 .27359 .28721 .28872 .29791 .28523 .2916 .26931 Mtetra
.616 .557 .765 r
.2916 .26931 .29791 .28523 .30858 .28286 .30235 .26567 Mtetra
.597 .532 .752 r
.30235 .26567 .30858 .28286 .3192 .282 .3131 .26266 Mtetra
.579 .501 .731 r
.3131 .26266 .3192 .282 .32979 .28263 .32388 .26018 Mtetra
.572 .473 .704 r
.32388 .26018 .32979 .28263 .34042 .28401 .3347 .2577 Mtetra
.57 .45 .677 r
.3347 .2577 .34042 .28401 .35112 .28543 .34559 .25495 Mtetra
.569 .432 .654 r
.34559 .25495 .35112 .28543 .36197 .28567 .35657 .25175 Mtetra
.57 .421 .64 r
.35657 .25175 .36197 .28567 .37299 .28402 .36762 .24803 Mtetra
.572 .417 .632 r
.36762 .24803 .37299 .28402 .38418 .27997 .37874 .24393 Mtetra
.576 .419 .632 r
.37874 .24393 .38418 .27997 .39551 .27353 .38991 .23945 Mtetra
.585 .431 .639 r
.38991 .23945 .39551 .27353 .40695 .26517 .40116 .23445 Mtetra
.597 .451 .653 r
.40116 .23445 .40695 .26517 .41844 .25563 .41246 .229 Mtetra
.612 .477 .674 r
.41246 .229 .41844 .25563 .42995 .2461 .42381 .22326 Mtetra
.624 .506 .698 r
.42381 .22326 .42995 .2461 .44143 .23731 .43519 .21752 Mtetra
.628 .53 .724 r
.43519 .21752 .44143 .23731 .4529 .23001 .44659 .21231 Mtetra
.625 .548 .747 r
.44659 .21231 .4529 .23001 .46436 .22422 .45802 .20774 Mtetra
.617 .557 .765 r
.45802 .20774 .46436 .22422 .47584 .21957 .46949 .20381 Mtetra
.608 .561 .777 r
.46949 .20381 .47584 .21957 .48735 .21574 .48099 .20039 Mtetra
.602 .564 .784 r
.48099 .20039 .48735 .21574 .49892 .21226 .49255 .19725 Mtetra
.598 .568 .791 r
.49255 .19725 .49892 .21226 .51053 .20897 .50417 .19429 Mtetra
.597 .572 .797 r
.50417 .19429 .51053 .20897 .5222 .20574 .51585 .19142 Mtetra
.595 .577 .804 r
.51585 .19142 .5222 .20574 .53393 .20257 .52758 .18865 Mtetra
.593 .583 .811 r
.52758 .18865 .53393 .20257 .54572 .19945 .53938 .18597 Mtetra
.591 .59 .82 r
.53938 .18597 .54572 .19945 .55758 .19642 .55125 .18339 Mtetra
.587 .597 .829 r
.55125 .18339 .55758 .19642 .56949 .19348 .56318 .18094 Mtetra
.583 .605 .84 r
.56318 .18094 .56949 .19348 .58147 .19068 .57518 .17863 Mtetra
.578 .613 .851 r
.57518 .17863 .58147 .19068 .59352 .18804 .58725 .17647 Mtetra
.572 .621 .862 r
.58725 .17647 .59352 .18804 .60564 .18557 .5994 .17448 Mtetra
.565 .629 .874 r
.5994 .17448 .60564 .18557 .61783 .1833 .61163 .17265 Mtetra
.557 .636 .885 r
.61163 .17265 .61783 .1833 .6301 .18122 .62394 .17098 Mtetra
.549 .644 .896 r
.62394 .17098 .6301 .18122 .64245 .17934 .63633 .16948 Mtetra
.541 .65 .906 r
.63633 .16948 .64245 .17934 .65489 .17764 .6488 .1681 Mtetra
.534 .656 .914 r
.6488 .1681 .65489 .17764 .66741 .1761 .66137 .16684 Mtetra
.527 .662 .922 r
.66137 .16684 .66741 .1761 .68002 .1747 .67402 .16566 Mtetra
.522 .667 .928 r
.67402 .16566 .68002 .1747 .69272 .17339 .68676 .16453 Mtetra
.518 .671 .933 r
.68676 .16453 .69272 .17339 .70551 .17213 .69958 .16342 Mtetra
.516 .676 .937 r
.69958 .16342 .70551 .17213 .71838 .17091 .7125 .16231 Mtetra
.515 .68 .94 r
.7125 .16231 .71838 .17091 .73134 .16968 .7255 .16118 Mtetra
.746 .767 .87 r
.05043 .39529 .05808 .40196 .06856 .39503 .06088 .38873 Mtetra
.75 .779 .877 r
.06088 .38873 .06856 .39503 .07906 .38806 .07136 .38214 Mtetra
.753 .791 .883 r
.07136 .38214 .07906 .38806 .08958 .38109 .08186 .37552 Mtetra
.756 .802 .89 r
.08186 .37552 .08958 .38109 .10012 .37414 .09239 .36888 Mtetra
.758 .813 .896 r
.09239 .36888 .10012 .37414 .11067 .36722 .10293 .36224 Mtetra
.759 .823 .902 r
.10293 .36224 .11067 .36722 .12123 .36038 .11349 .35563 Mtetra
.759 .831 .908 r
.11349 .35563 .12123 .36038 .1318 .35364 .12407 .34907 Mtetra
.757 .838 .913 r
.12407 .34907 .1318 .35364 .14237 .34703 .13466 .34258 Mtetra
.755 .844 .918 r
.13466 .34258 .14237 .34703 .15294 .34056 .14526 .33619 Mtetra
.751 .847 .922 r
.14526 .33619 .15294 .34056 .16353 .33425 .15588 .3299 Mtetra
.748 .849 .926 r
.15588 .3299 .16353 .33425 .17411 .32809 .1665 .32372 Mtetra
.743 .849 .929 r
.1665 .32372 .17411 .32809 .18471 .32208 .17714 .31767 Mtetra
.738 .848 .931 r
.17714 .31767 .18471 .32208 .19531 .31623 .18779 .31173 Mtetra
.734 .846 .933 r
.18779 .31173 .19531 .31623 .20593 .31051 .19845 .30592 Mtetra
.729 .844 .935 r
.19845 .30592 .20593 .31051 .21657 .30491 .20913 .30023 Mtetra
.724 .841 .937 r
.20913 .30023 .21657 .30491 .22723 .29941 .21983 .29465 Mtetra
.72 .839 .938 r
.21983 .29465 .22723 .29941 .23791 .29399 .23055 .28919 Mtetra
.715 .838 .94 r
.23055 .28919 .23791 .29399 .24861 .28866 .24129 .28383 Mtetra
.711 .837 .942 r
.24129 .28383 .24861 .28866 .25934 .28343 .25205 .27856 Mtetra
.707 .837 .944 r
.25205 .27856 .25934 .28343 .27008 .27838 .26284 .27337 Mtetra
.706 .833 .943 r
.26284 .27337 .27008 .27838 .28084 .27359 .27366 .26821 Mtetra
.707 .822 .936 r
.27366 .26821 .28084 .27359 .2916 .26931 .28453 .26298 Mtetra
.711 .793 .915 r
.28453 .26298 .2916 .26931 .30235 .26567 .29544 .25758 Mtetra
.716 .743 .873 r
.29544 .25758 .30235 .26567 .3131 .26266 .30642 .25166 Mtetra
.709 .676 .816 r
.30642 .25166 .3131 .26266 .32388 .26018 .31747 .24508 Mtetra
.691 .607 .758 r
.31747 .24508 .32388 .26018 .3347 .2577 .3286 .23777 Mtetra
.668 .55 .711 r
.3286 .23777 .3347 .2577 .34559 .25495 .33978 .23 Mtetra
.638 .5 .679 r
.33978 .23 .34559 .25495 .35657 .25175 .35095 .22276 Mtetra
.609 .464 .659 r
.35095 .22276 .35657 .25175 .36762 .24803 .36208 .21667 Mtetra
.579 .435 .649 r
.36208 .21667 .36762 .24803 .37874 .24393 .37314 .21252 Mtetra
.553 .417 .65 r
.37314 .21252 .37874 .24393 .38991 .23945 .38416 .21032 Mtetra
.537 .416 .662 r
.38416 .21032 .38991 .23945 .40116 .23445 .39518 .20928 Mtetra
.53 .431 .687 r
.39518 .20928 .40116 .23445 .41246 .229 .40626 .20878 Mtetra
.542 .474 .729 r
.40626 .20878 .41246 .229 .42381 .22326 .41742 .20783 Mtetra
.564 .541 .787 r
.41742 .20783 .42381 .22326 .43519 .21752 .42868 .20615 Mtetra
.588 .624 .855 r
.42868 .20615 .43519 .21752 .44659 .21231 .44002 .2038 Mtetra
.605 .705 .915 r
.44002 .2038 .44659 .21231 .45802 .20774 .45144 .20095 Mtetra
.605 .761 .953 r
.45144 .20095 .45802 .20774 .46949 .20381 .46292 .19791 Mtetra
.599 .79 .972 r
.46292 .19791 .46949 .20381 .48099 .20039 .47445 .19481 Mtetra
.592 .8 .979 r
.47445 .19481 .48099 .20039 .49255 .19725 .48605 .19175 Mtetra
.585 .801 .982 r
.48605 .19175 .49255 .19725 .50417 .19429 .4977 .18876 Mtetra
.579 .799 .983 r
.4977 .18876 .50417 .19429 .51585 .19142 .50942 .18587 Mtetra
.572 .796 .984 r
.50942 .18587 .51585 .19142 .52758 .18865 .52119 .18309 Mtetra
.564 .794 .985 r
.52119 .18309 .52758 .18865 .53938 .18597 .53303 .18042 Mtetra
.555 .792 .987 r
.53303 .18042 .53938 .18597 .55125 .18339 .54494 .17788 Mtetra
.545 .79 .989 r
.54494 .17788 .55125 .18339 .56318 .18094 .55691 .17546 Mtetra
.536 .787 .99 r
.55691 .17546 .56318 .18094 .57518 .17863 .56895 .17317 Mtetra
.526 .785 .992 r
.56895 .17317 .57518 .17863 .58725 .17647 .58107 .171 Mtetra
.517 .781 .992 r
.58107 .171 .58725 .17647 .5994 .17448 .59326 .16897 Mtetra
.508 .777 .993 r
.59326 .16897 .5994 .17448 .61163 .17265 .60553 .16706 Mtetra
.502 .771 .992 r
.60553 .16706 .61163 .17265 .62394 .17098 .61787 .16525 Mtetra
.498 .765 .991 r
.61787 .16525 .62394 .17098 .63633 .16948 .6303 .16355 Mtetra
.497 .759 .989 r
.6303 .16355 .63633 .16948 .6488 .1681 .64281 .16193 Mtetra
.498 .751 .986 r
.64281 .16193 .6488 .1681 .66137 .16684 .6554 .16037 Mtetra
.502 .743 .981 r
.6554 .16037 .66137 .16684 .67402 .16566 .66808 .15884 Mtetra
.508 .735 .976 r
.66808 .15884 .67402 .16566 .68676 .16453 .68084 .15731 Mtetra
.514 .725 .969 r
.68084 .15731 .68676 .16453 .69958 .16342 .69368 .15577 Mtetra
.522 .715 .96 r
.69368 .15577 .69958 .16342 .7125 .16231 .7066 .15421 Mtetra
.529 .705 .951 r
.7066 .15421 .7125 .16231 .7255 .16118 .71961 .15261 Mtetra
.721 .764 .886 r
.04273 .38856 .05043 .39529 .06088 .38873 .05306 .38295 Mtetra
.728 .794 .904 r
.05306 .38295 .06088 .38873 .07136 .38214 .06343 .37729 Mtetra
.733 .825 .922 r
.06343 .37729 .07136 .38214 .08186 .37552 .07384 .3716 Mtetra
.735 .856 .938 r
.07384 .3716 .08186 .37552 .09239 .36888 .08427 .36586 Mtetra
.734 .887 .95 r
.08427 .36586 .09239 .36888 .10293 .36224 .09474 .36009 Mtetra
.726 .915 .958 r
.09474 .36009 .10293 .36224 .11349 .35563 .10523 .35432 Mtetra
.712 .937 .96 r
.10523 .35432 .11349 .35563 .12407 .34907 .11575 .34855 Mtetra
.689 .953 .953 r
.11575 .34855 .12407 .34907 .13466 .34258 .12629 .3428 Mtetra
.656 .959 .937 r
.12629 .3428 .13466 .34258 .14526 .33619 .13686 .33711 Mtetra
.616 .954 .911 r
.13686 .33711 .14526 .33619 .15588 .3299 .14745 .33146 Mtetra
.57 .94 .875 r
.14745 .33146 .15588 .3299 .1665 .32372 .15806 .32587 Mtetra
.519 .916 .833 r
.15806 .32587 .1665 .32372 .17714 .31767 .16869 .32034 Mtetra
.467 .887 .787 r
.16869 .32034 .17714 .31767 .18779 .31173 .17934 .31489 Mtetra
.417 .854 .741 r
.17934 .31489 .18779 .31173 .19845 .30592 .19002 .3095 Mtetra
.37 .819 .695 r
.19002 .3095 .19845 .30592 .20913 .30023 .20073 .30417 Mtetra
.326 .785 .653 r
.20073 .30417 .20913 .30023 .21983 .29465 .21145 .29892 Mtetra
0 0 0 r
.21145 .29892 .21983 .29465 .23055 .28919 .22221 .29375 Mtetra
.22221 .29375 .23055 .28919 .24129 .28383 .23299 .28866 Mtetra
.23299 .28866 .24129 .28383 .25205 .27856 .24379 .28365 Mtetra
.24379 .28365 .25205 .27856 .26284 .27337 .25464 .27865 Mtetra
.25464 .27865 .26284 .27337 .27366 .26821 .26552 .2736 Mtetra
.26552 .2736 .27366 .26821 .28453 .26298 .27646 .26824 Mtetra
.27646 .26824 .28453 .26298 .29544 .25758 .28748 .26235 Mtetra
.382 .803 .614 r
.28748 .26235 .29544 .25758 .30642 .25166 .2986 .2555 Mtetra
.549 .911 .723 r
.2986 .2555 .30642 .25166 .31747 .24508 .30982 .24755 Mtetra
.703 .983 .818 r
.30982 .24755 .31747 .24508 .3286 .23777 .32113 .23861 Mtetra
.79 .994 .872 r
.32113 .23861 .3286 .23777 .33978 .23 .33248 .22917 Mtetra
.794 .972 .911 r
.33248 .22917 .33978 .23 .35095 .22276 .34378 .22059 Mtetra
.746 .94 .948 r
.34378 .22059 .35095 .22276 .36208 .21667 .355 .21373 Mtetra
.619 .892 .988 r
.355 .21373 .36208 .21667 .37314 .21252 .36611 .20955 Mtetra
.399 .799 .985 r
.36611 .20955 .37314 .21252 .38416 .21032 .37713 .20807 Mtetra
.156 .671 .894 r
.37713 .20807 .38416 .21032 .39518 .20928 .38814 .20831 Mtetra
0 .531 .729 r
.38814 .20831 .39518 .20928 .40626 .20878 .39919 .20944 Mtetra
.118 0 0 r
.39919 .20944 .40626 .20878 .41742 .20783 .41035 .21007 Mtetra
.124 0 0 r
.41035 .21007 .41742 .20783 .42868 .20615 .42162 .20973 Mtetra
.103 0 0 r
.42162 .20973 .42868 .20615 .44002 .2038 .433 .20828 Mtetra
.071 0 0 r
.433 .20828 .44002 .2038 .45144 .20095 .44448 .20587 Mtetra
.053 0 0 r
.44448 .20587 .45144 .20095 .46292 .19791 .45603 .20292 Mtetra
.035 0 0 r
.45603 .20292 .46292 .19791 .47445 .19481 .46765 .19967 Mtetra
.023 0 0 r
.46765 .19967 .47445 .19481 .48605 .19175 .47933 .19636 Mtetra
.012 0 0 r
.47933 .19636 .48605 .19175 .4977 .18876 .49107 .19307 Mtetra
.002 0 0 r
.49107 .19307 .4977 .18876 .50942 .18587 .50286 .18985 Mtetra
0 0 0 r
.50286 .18985 .50942 .18587 .52119 .18309 .51471 .18672 Mtetra
.51471 .18672 .52119 .18309 .53303 .18042 .52663 .18368 Mtetra
.52663 .18368 .53303 .18042 .54494 .17788 .53861 .18071 Mtetra
.53861 .18071 .54494 .17788 .55691 .17546 .55065 .17781 Mtetra
.55065 .17781 .55691 .17546 .56895 .17317 .56276 .17498 Mtetra
.56276 .17498 .56895 .17317 .58107 .171 .57494 .17222 Mtetra
.163 .697 .704 r
.57494 .17222 .58107 .171 .59326 .16897 .58718 .16953 Mtetra
.208 .733 .765 r
.58718 .16953 .59326 .16897 .60553 .16706 .5995 .1669 Mtetra
.259 .769 .827 r
.5995 .1669 .60553 .16706 .61787 .16525 .61189 .16433 Mtetra
.313 .799 .885 r
.61189 .16433 .61787 .16525 .6303 .16355 .62435 .1618 Mtetra
.368 .821 .935 r
.62435 .1618 .6303 .16355 .64281 .16193 .63689 .15931 Mtetra
.42 .832 .972 r
.63689 .15931 .64281 .16193 .6554 .16037 .6495 .15682 Mtetra
.466 .83 .994 r
.6495 .15682 .6554 .16037 .66808 .15884 .66219 .15432 Mtetra
.505 .819 1 r
.66219 .15432 .66808 .15884 .68084 .15731 .67495 .1518 Mtetra
.534 .798 .994 r
.67495 .1518 .68084 .15731 .69368 .15577 .68778 .14923 Mtetra
.555 .772 .979 r
.68778 .14923 .69368 .15577 .7066 .15421 .70069 .14662 Mtetra
.57 .745 .959 r
.70069 .14662 .7066 .15421 .71961 .15261 .71368 .14397 Mtetra
.68 .757 .909 r
.03496 .38178 .04273 .38856 .05306 .38295 .04513 .37744 Mtetra
.684 .798 .935 r
.04513 .37744 .05306 .38295 .06343 .37729 .05534 .37305 Mtetra
.683 .841 .959 r
.05534 .37305 .06343 .37729 .07384 .3716 .0656 .36861 Mtetra
.673 .882 .976 r
.0656 .36861 .07384 .3716 .08427 .36586 .0759 .36411 Mtetra
.651 .915 .979 r
.0759 .36411 .08427 .36586 .09474 .36009 .08623 .35955 Mtetra
.61 .933 .961 r
.08623 .35955 .09474 .36009 .10523 .35432 .09661 .35495 Mtetra
.548 .926 .916 r
.09661 .35495 .10523 .35432 .11575 .34855 .10703 .35033 Mtetra
.468 .892 .843 r
.10703 .35033 .11575 .34855 .12629 .3428 .11748 .34569 Mtetra
.377 .834 .749 r
.11748 .34569 .12629 .3428 .13686 .33711 .12797 .34105 Mtetra
0 0 0 r
.12797 .34105 .13686 .33711 .14745 .33146 .1385 .3364 Mtetra
.1385 .3364 .14745 .33146 .15806 .32587 .14906 .33175 Mtetra
.14906 .33175 .15806 .32587 .16869 .32034 .15965 .32711 Mtetra
.15965 .32711 .16869 .32034 .17934 .31489 .17029 .32247 Mtetra
.17029 .32247 .17934 .31489 .19002 .3095 .18096 .31783 Mtetra
.033 0 0 r
.18096 .31783 .19002 .3095 .20073 .30417 .19166 .31319 Mtetra
.069 0 0 r
.19166 .31319 .20073 .30417 .21145 .29892 .20241 .30855 Mtetra
.099 0 0 r
.20241 .30855 .21145 .29892 .22221 .29375 .21318 .30394 Mtetra
.125 0 0 r
.21318 .30394 .22221 .29375 .23299 .28866 .224 .29937 Mtetra
.147 0 0 r
.224 .29937 .23299 .28866 .24379 .28365 .23485 .29483 Mtetra
.162 0 0 r
.23485 .29483 .24379 .28365 .25464 .27865 .24574 .29028 Mtetra
.171 0 0 r
.24574 .29028 .25464 .27865 .26552 .2736 .25668 .28562 Mtetra
.162 0 0 r
.25668 .28562 .26552 .2736 .27646 .26824 .26769 .28059 Mtetra
.139 0 0 r
.26769 .28059 .27646 .26824 .28748 .26235 .27878 .27495 Mtetra
.09 0 0 r
.27878 .27495 .28748 .26235 .2986 .2555 .28999 .2683 Mtetra
.033 0 0 r
.28999 .2683 .2986 .2555 .30982 .24755 .3013 .26053 Mtetra
0 0 0 r
.3013 .26053 .30982 .24755 .32113 .23861 .3127 .25183 Mtetra
.3127 .25183 .32113 .23861 .33248 .22917 .32414 .24268 Mtetra
.038 0 0 r
.32414 .24268 .33248 .22917 .34378 .22059 .33554 .23437 Mtetra
.137 0 0 r
.33554 .23437 .34378 .22059 .355 .21373 .34687 .22767 Mtetra
.261 0 .057 r
.34687 .22767 .355 .21373 .36611 .20955 .35808 .22348 Mtetra
.36 0 .108 r
.35808 .22348 .36611 .20955 .37713 .20807 .36921 .22179 Mtetra
.415 0 .131 r
.36921 .22179 .37713 .20807 .38814 .20831 .38033 .22174 Mtetra
.439 .016 .137 r
.38033 .22174 .38814 .20831 .39919 .20944 .39149 .22254 Mtetra
.423 0 .121 r
.39149 .22254 .39919 .20944 .41035 .21007 .40275 .22291 Mtetra
.389 0 .098 r
.40275 .22291 .41035 .21007 .42162 .20973 .41412 .22234 Mtetra
.345 0 .07 r
.41412 .22234 .42162 .20973 .433 .20828 .42562 .22065 Mtetra
.302 0 .043 r
.42562 .22065 .433 .20828 .44448 .20587 .4372 .21795 Mtetra
.272 0 .021 r
.4372 .21795 .44448 .20587 .45603 .20292 .44887 .21464 Mtetra
.248 0 0 r
.44887 .21464 .45603 .20292 .46765 .19967 .4606 .21095 Mtetra
.235 0 0 r
.4606 .21095 .46765 .19967 .47933 .19636 .47239 .20716 Mtetra
.224 0 0 r
.47239 .20716 .47933 .19636 .49107 .19307 .48424 .20334 Mtetra
.213 0 0 r
.48424 .20334 .49107 .19307 .50286 .18985 .49614 .19957 Mtetra
.201 0 0 r
.49614 .19957 .50286 .18985 .51471 .18672 .5081 .19583 Mtetra
.186 0 0 r
.5081 .19583 .51471 .18672 .52663 .18368 .52011 .19211 Mtetra
.166 0 0 r
.52011 .19211 .52663 .18368 .53861 .18071 .53219 .18841 Mtetra
.141 0 0 r
.53219 .18841 .53861 .18071 .55065 .17781 .54432 .1847 Mtetra
.109 0 0 r
.54432 .1847 .55065 .17781 .56276 .17498 .55652 .18099 Mtetra
.07 0 0 r
.55652 .18099 .56276 .17498 .57494 .17222 .56877 .17727 Mtetra
.021 0 0 r
.56877 .17727 .57494 .17222 .58718 .16953 .58108 .17356 Mtetra
0 0 0 r
.58108 .17356 .58718 .16953 .5995 .1669 .59346 .16985 Mtetra
.59346 .16985 .5995 .1669 .61189 .16433 .6059 .16614 Mtetra
.6059 .16614 .61189 .16433 .62435 .1618 .6184 .16242 Mtetra
.294 .791 .787 r
.6184 .16242 .62435 .1618 .63689 .15931 .63097 .15868 Mtetra
.39 .848 .884 r
.63097 .15868 .63689 .15931 .6495 .15682 .6436 .15492 Mtetra
.475 .878 .954 r
.6436 .15492 .6495 .15682 .66219 .15432 .65629 .15111 Mtetra
.542 .879 .989 r
.65629 .15111 .66219 .15432 .67495 .1518 .66905 .14723 Mtetra
.587 .857 .995 r
.66905 .14723 .67495 .1518 .68778 .14923 .68187 .1433 Mtetra
.613 .822 .98 r
.68187 .1433 .68778 .14923 .70069 .14662 .69475 .13931 Mtetra
.627 .782 .955 r
.69475 .13931 .70069 .14662 .71368 .14397 .70769 .13525 Mtetra
.621 .742 .933 r
.02714 .37496 .03496 .38178 .04513 .37744 .03712 .37202 Mtetra
.617 .788 .964 r
.03712 .37202 .04513 .37744 .05534 .37305 .04714 .36902 Mtetra
.602 .833 .988 r
.04714 .36902 .05534 .37305 .0656 .36861 .05723 .36595 Mtetra
.572 .87 .995 r
.05723 .36595 .0656 .36861 .0759 .36411 .06736 .36282 Mtetra
.52 .887 .975 r
.06736 .36282 .0759 .36411 .08623 .35955 .07755 .35961 Mtetra
.443 .873 .916 r
.07755 .35961 .08623 .35955 .09661 .35495 .08779 .35633 Mtetra
.346 .824 .82 r
.08779 .35633 .09661 .35495 .10703 .35033 .09808 .353 Mtetra
.242 .747 .699 r
.09808 .353 .10703 .35033 .11748 .34569 .10842 .34962 Mtetra
0 0 0 r
.10842 .34962 .11748 .34569 .12797 .34105 .11881 .34619 Mtetra
.11881 .34619 .12797 .34105 .1385 .3364 .12925 .3427 Mtetra
.013 0 0 r
.12925 .3427 .1385 .3364 .14906 .33175 .13974 .33917 Mtetra
.069 0 0 r
.13974 .33917 .14906 .33175 .15965 .32711 .15028 .33559 Mtetra
.113 0 0 r
.15028 .33559 .15965 .32711 .17029 .32247 .16087 .33195 Mtetra
.148 0 0 r
.16087 .33195 .17029 .32247 .18096 .31783 .17151 .32825 Mtetra
.176 0 0 r
.17151 .32825 .18096 .31783 .19166 .31319 .1822 .32448 Mtetra
.199 0 0 r
.1822 .32448 .19166 .31319 .20241 .30855 .19295 .32066 Mtetra
.219 0 0 r
.19295 .32066 .20241 .30855 .21318 .30394 .20374 .31681 Mtetra
.236 0 .008 r
.20374 .31681 .21318 .30394 .224 .29937 .21457 .31293 Mtetra
.25 0 .031 r
.21457 .31293 .224 .29937 .23485 .29483 .22546 .30903 Mtetra
.26 0 .05 r
.22546 .30903 .23485 .29483 .24574 .29028 .23639 .30508 Mtetra
.267 0 .066 r
.23639 .30508 .24574 .29028 .25668 .28562 .24738 .30101 Mtetra
.265 0 .075 r
.24738 .30101 .25668 .28562 .26769 .28059 .25843 .29665 Mtetra
.257 0 .083 r
.25843 .29665 .26769 .28059 .27878 .27495 .26957 .29183 Mtetra
.243 0 .089 r
.26957 .29183 .27878 .27495 .28999 .2683 .28081 .28631 Mtetra
.232 0 .101 r
.28081 .28631 .28999 .2683 .3013 .26053 .29214 .28001 Mtetra
.233 0 .122 r
.29214 .28001 .3013 .26053 .3127 .25183 .30354 .27307 Mtetra
.249 0 .151 r
.30354 .27307 .3127 .25183 .32414 .24268 .31499 .26583 Mtetra
.288 0 .189 r
.31499 .26583 .32414 .24268 .33554 .23437 .32644 .25909 Mtetra
.33 0 .221 r
.32644 .25909 .33554 .23437 .34687 .22767 .33785 .25334 Mtetra
.373 .028 .246 r
.33785 .25334 .34687 .22767 .35808 .22348 .34921 .24914 Mtetra
.406 .059 .26 r
.34921 .24914 .35808 .22348 .36921 .22179 .36054 .24649 Mtetra
.423 .07 .259 r
.36054 .24649 .36921 .22179 .38033 .22174 .37187 .24485 Mtetra
.428 .067 .248 r
.37187 .24485 .38033 .22174 .39149 .22254 .38325 .24371 Mtetra
.414 .044 .224 r
.38325 .24371 .39149 .22254 .40275 .22291 .39472 .24227 Mtetra
.389 .01 .194 r
.39472 .24227 .40275 .22291 .41412 .22234 .40628 .2402 Mtetra
.357 0 .161 r
.40628 .2402 .41412 .22234 .42562 .22065 .41793 .23735 Mtetra
.324 0 .129 r
.41793 .23735 .42562 .22065 .4372 .21795 .42966 .2338 Mtetra
.299 0 .104 r
.42966 .2338 .4372 .21795 .44887 .21464 .44147 .22978 Mtetra
.279 0 .083 r
.44147 .22978 .44887 .21464 .4606 .21095 .45334 .22545 Mtetra
.266 0 .065 r
.45334 .22545 .4606 .21095 .47239 .20716 .46526 .22102 Mtetra
.253 0 .047 r
.46526 .22102 .47239 .20716 .48424 .20334 .47723 .21652 Mtetra
.241 0 .027 r
.47723 .21652 .48424 .20334 .49614 .19957 .48926 .212 Mtetra
.226 0 .003 r
.48926 .212 .49614 .19957 .5081 .19583 .50134 .20746 Mtetra
.206 0 0 r
.50134 .20746 .5081 .19583 .52011 .19211 .51347 .20287 Mtetra
.183 0 0 r
.51347 .20287 .52011 .19211 .53219 .18841 .52565 .19823 Mtetra
.153 0 0 r
.52565 .19823 .53219 .18841 .54432 .1847 .53789 .19351 Mtetra
.117 0 0 r
.53789 .19351 .54432 .1847 .55652 .18099 .55017 .18873 Mtetra
.073 0 0 r
.55017 .18873 .55652 .18099 .56877 .17727 .56252 .18389 Mtetra
.018 0 0 r
.56252 .18389 .56877 .17727 .58108 .17356 .57491 .17899 Mtetra
0 0 0 r
.57491 .17899 .58108 .17356 .59346 .16985 .58735 .17404 Mtetra
.58735 .17404 .59346 .16985 .6059 .16614 .59985 .16902 Mtetra
.59985 .16902 .6059 .16614 .6184 .16242 .6124 .16395 Mtetra
.34 .811 .739 r
.6124 .16395 .6184 .16242 .63097 .15868 .625 .15882 Mtetra
.449 .882 .851 r
.625 .15882 .63097 .15868 .6436 .15492 .63765 .15362 Mtetra
.543 .92 .932 r
.63765 .15362 .6436 .15492 .65629 .15111 .65035 .14835 Mtetra
.613 .922 .974 r
.65035 .14835 .65629 .15111 .66905 .14723 .6631 .143 Mtetra
.655 .896 .982 r
.6631 .143 .66905 .14723 .68187 .1433 .6759 .13756 Mtetra
.677 .855 .967 r
.6759 .13756 .68187 .1433 .69475 .13931 .68875 .13205 Mtetra
.685 .809 .941 r
.68875 .13205 .69475 .13931 .70769 .13525 .70165 .12647 Mtetra
.546 .718 .953 r
.01926 .36808 .02714 .37496 .03712 .37202 .02904 .36649 Mtetra
.53 .76 .981 r
.02904 .36649 .03712 .37202 .04714 .36902 .03889 .36481 Mtetra
.503 .797 .998 r
.03889 .36481 .04714 .36902 .05723 .36595 .0488 .36306 Mtetra
.459 .822 .995 r
.0488 .36306 .05723 .36595 .06736 .36282 .05877 .36121 Mtetra
.395 .825 .96 r
.05877 .36121 .06736 .36282 .07755 .35961 .06881 .35928 Mtetra
.312 .798 .889 r
.06881 .35928 .07755 .35961 .08779 .35633 .07891 .35727 Mtetra
.219 .742 .785 r
.07891 .35727 .08779 .35633 .09808 .353 .08907 .35517 Mtetra
0 0 0 r
.08907 .35517 .09808 .353 .10842 .34962 .0993 .35299 Mtetra
.0993 .35299 .10842 .34962 .11881 .34619 .10959 .35072 Mtetra
.024 0 0 r
.10959 .35072 .11881 .34619 .12925 .3427 .11995 .34836 Mtetra
.081 0 0 r
.11995 .34836 .12925 .3427 .13974 .33917 .13036 .34591 Mtetra
.126 0 0 r
.13036 .34591 .13974 .33917 .15028 .33559 .14084 .34337 Mtetra
.162 0 0 r
.14084 .34337 .15028 .33559 .16087 .33195 .15138 .34075 Mtetra
.191 0 0 r
.15138 .34075 .16087 .33195 .17151 .32825 .16198 .33803 Mtetra
.216 0 0 r
.16198 .33803 .17151 .32825 .1822 .32448 .17264 .33523 Mtetra
.236 0 0 r
.17264 .33523 .1822 .32448 .19295 .32066 .18337 .33234 Mtetra
.252 0 0 r
.18337 .33234 .19295 .32066 .20374 .31681 .19415 .32935 Mtetra
.266 0 .013 r
.19415 .32935 .20374 .31681 .21457 .31293 .205 .32628 Mtetra
.276 0 .036 r
.205 .32628 .21457 .31293 .22546 .30903 .2159 .32311 Mtetra
.285 0 .056 r
.2159 .32311 .22546 .30903 .23639 .30508 .22687 .31985 Mtetra
.292 0 .073 r
.22687 .31985 .23639 .30508 .24738 .30101 .23789 .3165 Mtetra
.299 0 .089 r
.23789 .3165 .24738 .30101 .25843 .29665 .24897 .31305 Mtetra
.308 0 .109 r
.24897 .31305 .25843 .29665 .26957 .29183 .26011 .30951 Mtetra
.32 0 .134 r
.26011 .30951 .26957 .29183 .28081 .28631 .27131 .30588 Mtetra
.336 0 .167 r
.27131 .30588 .28081 .28631 .29214 .28001 .28256 .30215 Mtetra
.354 0 .203 r
.28256 .30215 .29214 .28001 .30354 .27307 .29388 .29833 Mtetra
.372 .022 .237 r
.29388 .29833 .30354 .27307 .31499 .26583 .30525 .29442 Mtetra
.386 .048 .265 r
.30525 .29442 .31499 .26583 .32644 .25909 .31667 .29041 Mtetra
.395 .065 .284 r
.31667 .29041 .32644 .25909 .33785 .25334 .32815 .2863 Mtetra
.399 .074 .294 r
.32815 .2863 .33785 .25334 .34921 .24914 .33969 .2821 Mtetra
.398 .073 .293 r
.33969 .2821 .34921 .24914 .36054 .24649 .35128 .2778 Mtetra
.391 .062 .283 r
.35128 .2778 .36054 .24649 .37187 .24485 .36293 .27341 Mtetra
.378 .041 .262 r
.36293 .27341 .37187 .24485 .38325 .24371 .37462 .26892 Mtetra
.359 .011 .232 r
.37462 .26892 .38325 .24371 .39472 .24227 .38638 .26433 Mtetra
.336 0 .194 r
.38638 .26433 .39472 .24227 .40628 .2402 .39818 .25965 Mtetra
.31 0 .155 r
.39818 .25965 .40628 .2402 .41793 .23735 .41004 .25486 Mtetra
.286 0 .118 r
.41004 .25486 .41793 .23735 .42966 .2338 .42194 .24998 Mtetra
.265 0 .088 r
.42194 .24998 .42966 .2338 .44147 .22978 .4339 .24501 Mtetra
.247 0 .064 r
.4339 .24501 .44147 .22978 .45334 .22545 .44591 .23993 Mtetra
.231 0 .043 r
.44591 .23993 .45334 .22545 .46526 .22102 .45797 .23476 Mtetra
.214 0 .02 r
.45797 .23476 .46526 .22102 .47723 .21652 .47008 .22948 Mtetra
.195 0 0 r
.47008 .22948 .47723 .21652 .48926 .212 .48223 .22411 Mtetra
.171 0 0 r
.48223 .22411 .48926 .212 .50134 .20746 .49443 .21864 Mtetra
.142 0 0 r
.49443 .21864 .50134 .20746 .51347 .20287 .50668 .21307 Mtetra
.108 0 0 r
.50668 .21307 .51347 .20287 .52565 .19823 .51898 .2074 Mtetra
.067 0 0 r
.51898 .2074 .52565 .19823 .53789 .19351 .53132 .20164 Mtetra
.018 0 0 r
.53132 .20164 .53789 .19351 .55017 .18873 .54371 .19577 Mtetra
0 0 0 r
.54371 .19577 .55017 .18873 .56252 .18389 .55614 .1898 Mtetra
.55614 .1898 .56252 .18389 .57491 .17899 .56861 .18374 Mtetra
.56861 .18374 .57491 .17899 .58735 .17404 .58113 .17757 Mtetra
.58113 .17757 .58735 .17404 .59985 .16902 .59369 .17131 Mtetra
.383 .828 .704 r
.59369 .17131 .59985 .16902 .6124 .16395 .60628 .16494 Mtetra
.485 .897 .806 r
.60628 .16494 .6124 .16395 .625 .15882 .61892 .15848 Mtetra
.576 .941 .888 r
.61892 .15848 .625 .15882 .63765 .15362 .6316 .15192 Mtetra
.646 .955 .94 r
.6316 .15192 .63765 .15362 .65035 .14835 .64432 .14525 Mtetra
.693 .941 .962 r
.64432 .14525 .65035 .14835 .6631 .143 .65708 .13849 Mtetra
.72 .909 .961 r
.65708 .13849 .6631 .143 .6759 .13756 .66987 .13163 Mtetra
.731 .867 .945 r
.66987 .13163 .6759 .13756 .68875 .13205 .6827 .12467 Mtetra
.732 .823 .921 r
.6827 .12467 .68875 .13205 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03ok_Bjol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o^m;[00?o
0000ok_Bjoooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool2ok_Ml@?o^m;[00?o0000ojo?l?ooool05?oo
ool00ol0003oooooo`00001Aooooo`00H?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00006_ooool3o`0006Gooooo1OnkgO400onkd^_o[lo`o`000002ojo?l1Kooooo
00?o0000ooooooooool0Coooool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0001Sooooo0_l0001Vooooo`;o^>Sf1?nkgO42ojgJm`03ojo?l?l0003o[lo`00;o
[lo`5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0HOooool5okSXmP03
ok_MlOn]f_Oo[M[g00?o[M[g00Co0000ojo?l?nPb?CoX<Sd5_ooool00ol0003oooooooooo`1>oooo
o`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000004oooool2o`00
06Oooooo0_nal?H4okSXmP;oYnGk1?n]f_L00onLd_[o0000oj38m003oj38m1Kooooo00?o0000oooo
ooooool0COooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00oooooo0ol0001Wooooo`Go/O3f00?o^>SfojOUnonWiO/00onWiO/01On]f_OoW=;joicBn_nLd_[o
000000GoX<Sd5_ooool00ol0003oooooooooo`1<ooooo`00P_ooool2o`0006Sooooo0onUm?02ok7`
mP?oW>ci0onWiO/2oiKKoPCoW=;j00Co0000oj38m?nPb?CoX<Sd0_nA__DFooooo`03o`000?oooooo
oooo04cooooo001oooooo`?o00000_ooool00ol0003oooooooooo`1Sooooo`CoYOC`0_n;jnh2oic/
n@CoR^7m1?nFfoh2oicBnP03ohk5n_l0003oS/Gj00GoTKke5?ooool3o`0004gooooo001looooo`?o
0000JOooool2oi?`h`04ojGdl?n;jnkoRn_^oh_[kPCoNN3d0_n:hOd3oh7Ao`CoR<cn0_n>aOX00ol0
003oS/Gjohk5nP04oi6nmAOooooo00?o0000ooooooooool0B_ooool007[ooooo0_l0001[ooooo`;o
To3S0_mbhMT3of?IhP;oNN3d0omge?h5oh7Ao`CoR<cn0_n>aOX00ol0003oQKOeohNdl`04ohNdlaKo
oooo00?o0000ooooooooool0B_ooool007Oooooo0ol0001/ooooo`03oi?`hombhMWoL^7I00?oHmWR
1?m[e?P4ogODoP;oPM7o0on2_?T4oh>in004ohFgmOl0003oQKOeohFgm@GoQkCc5_ooool00ol0003o
ooooooooo`19ooooo`00MOooool2o`0000;ooooo00?o0000ooooooooool0J?ooool2oeO?_@;oBl[9
1?mNd^l2of_Dn0?oOl3l1?n0__/5oh:ln@CoPkWh00Co0000ohFgmOn5]oGoQKOe0_n7]?<2oh>^l1Oo
oooo00?o0000ooooooooool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06?ooooo
00Co0000of;C]?m2a=?o@/CC0_m@c>83ogo3o@CoOl;m1Omo`?`4oh2nn`;oP[ci0_n5Z^d4ohB[kP03
o`000?n4[NooQ:g_00;oQ:g_1?n3[_0Fooooo`03o`000?oooooooooo04Sooooo001`ooooo`;o0000
J_ooool3o`000003of;C]?n2a_koP<Gm00?oP<Gm1Omo`od4ogo2o@;oOl3l0_n8YnT4ohJYk0GoQJ[]
0on4Znh00ol0003oQ:g_ohB]k`03ohB]k`CoPjk`5_ooool00ol0003oooooooooo`17ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3o`0006Wooooo
00?o1@00o`000?l000000_l00004oh;6oPCoP<Gm0_mo`od2ohbTi@CoRZKW1On8YnT4ohJYk0GoQJ[]
0_n4Znh01?l0003oQ:_^ohB]kon4[Nl2ohRUi`CoQj[/5Oooool3o`0004Sooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Noooo
o`;o00000oooool00ol0003oooooooooo`1Pooooo`;o00000_lA00000ol5003o1000o`000002o`00
00;oQ<Om0_n2a_h2oi2Qg`CoSZ;R1On<Y>D4ohZVi`GoR:OY1?n6ZN`2ohFZk@;oS9cM0_n:X><00ol0
003oRZ3SohRUi`04ohRUi`CoQj[/5_ooool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Yooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07?ooool3o`0006Cooooo0_l00002
oa/000?o4@000_l40002o`0000CoTYkL1On@XMl4ohjRhPGoS:CU1?n:Y^L2ohRWj@;oSY?D1?n=UmT5
ohbLg@04ohZPhol0003oRZ3SohZPh`GoR:GW1?n7Z^`Fooooo`03o`000?oooooooooo00Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0006?ooooo
0_l00002ob@000?o6`0000Co4@00oa800?lB003o10000_l00003oi>Lf@CoTYkL1On@XMl4ohjRhP;o
S:CU0_nAS</4oi2@c`GoSY?D1?n=UmT4ohbLg@03ohZPhol0003oRZ3S00;oRZ3S0_n8YNL2oi6ThPGo
T:cY5_ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
02_ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Eoooo
o`?o0000G_ooool5o`0000;o:P000olT00000olK003o7@00oad00003oa8000;o00000_nEV]L3oi>L
f@GoTYkL0_n@XMl2oi>6``CoTXW71OnAS</4oi2@c`CoSY?D1On=UmT4ohbLg@04o`000?n:X>?oTYkK
oi:Nf`GoTJCR1On@[>TEooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`1Gooooo`Go0000
0_l_0003obX00003ob@00?lW003o9`0000?o7@0000Co4P00o`000?l0003oUYSD1?nEV]L4oi>Lf@;o
TYkL0_nCQ;l5oi>6``CoTXW71?nAS</4oi2@c`GoSY?D0_n=UmT2oiBBc`CoTiSE00?o0000oi:NfonB
W]/00_nBW]/5oi6ThP;oT:cY0_nL/>HFooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002cooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@017ooooo0_l0001Looooo`;o0`001?l0
00001Olc003o;`00obl00?l_003o:P0000;o;P001?lW00000olM003o1000o`000004oiJHe0GoUI[G
0_nCW=T00onDPKcoThBooi>4_`03oi>4_`CoThK31?nBRLL4oi6<b`GoT93?0_n>Tm@2oiF>b@GoU9;?
0onCV=D00ol0003oTYkKoi:Nf`03oi:Nf`;oTJCR0_nLYmd5oib`iQKooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000;?ooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03_ooool3o`00
05_ooooo00Go1@00o`<00?l3003o0`00o`000002ocH000;o<`0000?o;`00oc@00?ld00001?l^0003
obL000;o10000_nGUm45oiJHe0;oUI[G0_nDOkT4oiB1_0CoThBo1?nCQ/<4oi:9a`GoTHc;0_n@T<l2
oiJ9a0GoUHk91?nDT/l3oi>He@04o`000?nCV=GoTYkKoi:Nf`;oW9oF1OnLYmd5oib`iQCooooo0_l0
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`00FOoo
ool3o`0005Wooooo0_l80002o`D00003o`<00?li003o>@0000Co=P0000?o>@00oc@00?ld00000_ld
0003obh00004obL00?lA003o4@00o`@000GoUiOA0_nFV=@2oiAm]`GoU7ni0onDPK`4oi>4_`GoThK3
1?nBRLL2oi6<b`;oUXK01OnFRL@4oiF>b@CoU9;?0onCV=D00ol0003oW9S?oibOeP04oibOePCoW:OM
1?nL/>H00onX]^?oooooooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001Fooooo`?o00000oooool00ol0003o
ooooooooo`1Booooo`;o3@000ol800000ol5003o?000ocT00003ocT000?o=P000_li0003oc@000;o
;P0000Co6`00oa400?lA003o4@000onGULl2oiNGd@;oU7^d1OnDOKL4oiAo^@CoU86l1?nCQ;l4oi>6
``;oTXW70_nFPk`5oiJ6`0CoUXW41?nES/T5oiBBc`03oi>HeOnLV<oo000000;oW9S?1?nLWmH5oibW
g@03oib`i_nX]^?oZ;KS00;oZ;KS5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2o`0005So
oooo00Go4P00o`d00?l=003o3@00o`P00002ocl000?o?0000oli00000olf003o?@06ocd01P02ocT0
00Co=0000olK00000olA003oV9?=oiRCc@02oiNEc`03oiAi/_nDNkCoU7^d00?oU7^d1?nDOKL4oiAo
^@CoU86l1?nCQ;l2oi>6``;oUX2i1OnFPk`4oiJ6`0CoUXW41OnES/T2oiBBc`;oW9;90_nLV<l00ol0
003oW9S?oibHc`05oibOeP;oW:OM0_nW[]`5ojRfhaKooooo00?o0000ooooooooool0@?ooool0057o
oooo0ol0001Fooooo`05oaX00?lB003o4P00oa800?l=00000_m500D3ocl000?o?00000?o>@00od00
3?m000`01?lm00H2ocT00003oc@00?lT003o900000?o6`000_nHTld2oiAg/0?oU7Vb1OnDNk@4oiAm
]`GoU7ni1?nDPK`2oi>4_`03oiMm]_nFP;WoUX2i00?oUX2i1?nFPk`4oiJ6`0GoUXW40_nES/T2oib=
a0GoW9;900?oW9S?o`000?nLV<l00_nLV<l2oibOeP;oYZKE1OnW[]`3ojRfh`;o/[kR5_ooool00ol0
003oooooooooo`0oooooo`00C_ooool5o`0004?ooooo0_mL01/3ofX08@?oL0@S1Oooool01OlN003o
7`00oal00?lO003o6P0000;oF00A0om=00/4odD01@;o?`0000?o?000od@04?m401001?m000`3ocd0
1P03ocT00?l[003o900000?o900000?o6`00oi=f[onCMZl01?nDMk04oiAi/PCoU7^d1OnDOKL4oiAo
^@;oU86l0_nFNk<4oiMm]PCoUX2i1?nFPk`5oiJ6`0;oUXW40_nLRKl5oib=a0CoW9;900GoW9S?o`00
0?nLV<ooW9S?ojJOc`05ojJVe@CoYjkL00?oZ;KSok:nh_nb_^800onb_^8Fooooo`03o`000?oooooo
oooo03kooooo001<ooooo`;o00001Oooool00ol0003oooooooooo`0mooooo`03od803_mL01_oG00K
00;oG00K0omZ0244og048`?oK00N1?mS01T4oeP04@?oC@0;0om500D00olo003oA`0Eod@04003od@0
40?o@00<0olm00H3ob/000?o90001?nCMZl5oiAg/0?oU7Vb1OnDNk@4oiAm]`;oU7ni0_nFNK04oiIk
/`CoUgff1?nFP;T5oiJ3_0?oUXK000?oVhFkoib9_onLRKl00onLRKl4oib=a0GoW9;900?o0000ojJO
conVWll00_nVWll5ojJVe@;oYjkL0_nb]md4ok:nhP03ok[4h_oooooooooo01Cooooo00?o0000oooo
ooooool0?_ooool004Wooooo0ol00014ooooo`04ob<00?m200ko@P0>od803P?oG00K0omZ0245og04
8`?oK00N1?mS01T3oeP04@?oC@0;00?oA@05od`06_m<01X00om701D3od@040Co@00<00?o?@06oc40
0?l[00000_l[0002ob@000;oTgB]1OnCMZl4oiAg/0?oU7Vb1OnDNk@2oiAm]`;oUWN^1?nFNK05oiIk
/`?oUgff1OnFP;T4oiJ3_003oiJ6`?nKQK_oVhFk00;oVhFk1?nLRKl4oib=a0CoW9;900?oYI[:ojJO
col000000onVWll4ojJVe@03ok6bfOnb]mgo/[OM00?o/[OM00?o/[kRok[4h_nja>800_nja>8Doooo
o`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000AOooool3ob<0
00;o@P0>0omL01/4ofX08@CoL0@S0om/01h4of<06@?oF00A00?oC@0;oe808OmB02401?m<01X2odL0
5@CoA00@00?o@00<ocH01Olf00D00ola0003ob/000GoTgB]1?nCMZl4oiAg/0CoU7Vb0onDNk@00onF
MZgoUWN^oiIg[P02oiIg[PGoUWV`1?nFNk<4oiMm]PCoUX2i0_nFPk`2oi^2]`GoVhFk1?nLRKl5oib=
a003oibBbOnUV/[oYI[:00;oYI[:00?o0000ojJOconVWll00_nVWll01?nVY]Go/K;Iok6bfOna/]T4
ok:gg@03ok[2h?nja>;o^/CR00Co^/CR5Oooool00ol0003oooooooooo`0mooooo`008_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo047ooooo0olS0003
od803P?oG00K1?mZ0243og048`CoK00N1?mS01T00omH017oF`0Yoe808@03oe808@?oC00J0om701D2
od@04003oc/02olf00Go=P0500;o=P050_la00000ol[003oU7B/oiAd[002oiAd[0CoTgB]1?nCMZl5
oiAg/0?oU7Vb00CoU7^doiIf[OnFMZgoUWJ]1OnFMjh4oiIi/0CoUW^c1?nGOKH2oiJ0^@;oVgnd1OnK
P[L4oi^5^`GoW8Vo0_nLSL@2ojFEa@GoYI[:00Go0000ojJOconVWlooYYo?ok6]e005ok6bf@;o/[OM
0onj`^04ok[4hP;o_L_U5Oooool00ol0003oooooooooo`0looooo`008_ooool01Ol@413ooooooooo
oooooooo410@01_ooooo0_l00018ooooo`04o`T00?lS003o8`00od803P;oG`Ln0omW3d84of`A@P?o
KA4o1?mY2cT4of<2<@?oF`0Y0omB0243od`06PCoA`0E0olk00/3ocH01@03oc400?nEM:coUGB/00;o
UGB/0onDM:`4oi=d[@GoTgJ_1?nDMk02oiAi/P03oiIdZonFMZgoUWJ]00?oUWJ]1?nFMjh4oiIi/0Go
UW^c0_nGOKH00onKOK7oVgndoi]o]002oi]o]0GoVh:g1OnKQK/3oib9_`03ojBA`OnUULGoYIG500?o
YIG51?nUV/X00ol0003oYYo?ok6]e002ok6]e0Go/K;I00?o/[OMok[2h?nj`^000onj`^000onja>;o
_L_Uokg;i@03okg;iAGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooooooo
ooooo`00000Hooooo`?o0000BOooool00ol9003o8`00ob<00004oel7?P?oI`m21?m/4D83ofdA?`Co
J@/i1?mS0S42oe/0:@CoDP0Q0om<01X00om701Go?`0@ocl04003oc/02`?o=P050_nHMj`4oiEd[0?o
U7B/1?nCM:d5oi=f[`;oU7N`0_nELjT3oiIdZ`GoUWJ]1?nFMjh4oiIi/0GoUW^c00?oUgffoi]m/OnK
OK401OnKOk@4oi^2]`GoVhFk00?oW8VoojBA`OnTTL400_nTTL44ojFEa@CoYI[:00?o0000ok6]e?na
[M@00ona[M@3ok6bf@;o^/3N1?nj`^02oko?i`Co_L_U00?o^loYooooooooool04oooool00ol0003o
ooooooooo`0kooooo`008_ooool01Ol0003ooooooooooooooooo000001Kooooo0ol00019ooooo`05
o`000?l9003o2@00ob<00?mD03P00omO1ch4ofL?@P?oK1521?m]4Cl3ofT;>@CoH`8a0omK02T4oe80
8@03od`06_m301Ko?`0@00?o?`0@0_lk00/2ocH01@CoV7N/1?nEM:`3oiAd[0GoTgB]0onCMZl00onE
LJSoUG>YoiEcZ@02oiEcZ@CoUWB[1?nFMZd4oiIg[PGoUWV`0onFNk<00onJNjooVgfaoi]m/@02oi]m
/@CoVgnd1OnKP[L3oi^5^`03ojB>_OnTTL7oY97100?oY9711OnUULD01OnUV/[o/:W@ok2Yd?l0003o
/:W@00Co/JgD00?o/K;Iok[0g_nj`=h00onj`=h00onj`^3o_loWoko?i`03oko?i`03okg;iOnkcnWo
^loY00;o^loY5Oooool00ol0003oooooooooo`0jooooo`008_ooool01Ol@413ooooooooooooooooo
410@01?ooooo0ol00002ooooo`03o`000?oooooooooo04Kooooo0_l00002o`T00003oe@0>?mO1cko
G`Ln00;oG`Ln0omW3d84of`A@P?oKA4o1?mY2cT3of<2<@CoF`0Y0_mB02401?m901ko@`0Fod<05_m3
01H3ocl040?o>`0;0_nMNjd4oiQg[0CoUGB/1?nDM:`4oi=d[@04oi=f[onELJSoUG6XoiEaZ0GoUG>Y
0onFM:/4oiIf[@GoUWN^1?nFNK001?nFNk?oVW^_oiYk[onJNjl4oi]m/@CoVgnd1OnKP[L00onKQK_o
Y8jmojB>_@02ojB>_@CoY9711?nUULD01_n`Y/go/:W@ok2Yd?n`ZM3o0000ok2Yd0?o/JgD00?o^[oM
ok[0g_nj`=h00onj`=h00oo0e>Wo_loWoko?i`03oko?i`03okcGkOnkcnWo^loY00?o^loY5_ooool0
0ol0003oooooooooo`0iooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg013ooooo0ol0001=
ooooo`;o000000Co2@00odT0<?mD03SoE00h1?mO1ch3ofL?@P?oK1521?m]4Cl3ofT;>@CoH`8a0omK
02T01?mB027oB@0NodT07_m901h2od<05PCo?`0@00?o>`0;oj>1[_nMNjd00onMNjd3oiQg[0GoUGB/
0onDM:`2oi=d[@;oU72W1OnELJP4oiEcZ@?oUWB[1?nFMZd5oiIg[P;oUWV`0_nJNJd5oiYk[`?oVgfa
1OnKOk@3oi^2]`03oj>;^_nTS[goY8jm00?oY8jm1OnTTL400onUULGo/:K=ok2Vc@02ok2Vc@;o/:W@
00Co0000ok2Yd?n`ZM3o/JgD0onj_md3ok[0gP?o`=CY0onocnL3okcGk@?o^loY0_ndd>hDooooo`;o
0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0>ooooo`;o0000Coooool2o`0000?o
B@0`0_mD03P3oel7?PCoI`m20om/4D84ofdA?`?oJ@/i00?oH`8aoeH0<OmF03401?m?02L3odT07P?o
@`0F0_lo0104oj>1[PCoWG^]0onHMj`5oiEd[0;oU7B/00?oTfnVoiA`YonDL:L00_nDL:L5oiEaZ0Co
UG>Y0onFM:/5oiIf[@?oUWN^00?oVGN/oiYi[OnJNJd00_nJNJd5oiYk[`?oVgfa1OnKOk@00onKP[Oo
Xh^joj>;^P02oj>;^PCoY8jm1?nTTL400on`Xl_o/:K=ok2Vc@03ok2Vc@;o/:W@00?o0000ok2Yd?nk
_]`01Onj_md00onj`=ko`=CYol3Dj@03ol3Dj@03oko?ionlengo_=O]00?o_=O]00?o^loYokC@k_nd
d>h00_ndd>hEooooo`03o`000?oooooooooo03Sooooo000booooo`Go0000C_ooool00ol0003o?`0V
odT0<002odT0<0;oE00h1?mO1ch3ofL?@PCoK1520om]4Cl2ofT;>@03oe/2>omF037oEP0a00;oEP0a
1?m?02L3odT07P?o@`0F00?oZXN`oj>1[_nSPJh00onSPJh4oiek[@CoV7N/0onEM:`01?nCKZGoTfnV
oi=_Y_nCKjH5oiA`Y`CoUG6X1?nELjT4oiIdZ`CoUWJ]00CoUWN^oiUg[?nIMjcoVGN/1OnJNJd4oiYk
[`CoVgfa0onKOk@00onSR;SoXh^joj>;^P03oj>;^PGoY8jm0_nTTL43ok2Sb`Go/:K=0_l00003ok^n
g0?o^[oM0_o1f^`4ol3Dj@;o_>7b1?nlend00oncfoCo]=3^okC@kP02okC@kP03ojS;lOoooooooooo
01Cooooo00?o0000ooooooooool0=oooool0033ooooo0_l0001Booooo`03o`000?lo02Ko?`0V00?o
B@0`0_mD03P4oel7?P03ofL?@_mU4T_oIA9;00?oI0m81?mP2T<3oe/2>`CoEP0a0om?02L3odT07P;o
@`0F1?nZQk04oj>1[PCoWG^]1?nHMj`01?nEM:coTfjUoi=^YOnCKZD4oi=_YPCoU72W1?nELJP4oiEc
Z@CoUWB[0_nFMZd2oiUfZPGoVGN/1?nJNJd4oiYk[`CoVgfa00?oVgndoj>8^?nSR;P00_nSR;P4oj>;
^PGoY8jm00?oY971ok2Sbon`Xl/00_n`Xl/2ok2Vc@?o000000?o^kkLo`000?nk_]`00_nk_]`00onj
_mgo`M[/ol7Jk003ol7Jk003ol3DjOnlhO;o_>7b00?o_>7b00?o_=O]ok?Km?ncfo@00_ncfo@00ond
d>koZ<_aojS;l@02ojS;lAGooooo00?o0000ooooooooool0=oooool002gooooo0ol0001Booooo`04
o`P00?l0003o?`0Vocl09P?oB@0`0omD03P2oel7?P03ofHBBomU4T_oIA9;00;oIA9;0omT3dP4of0:
@`?oF`8k0omF0343odl09`CoB@0N0_n^Rk44ojZ7/0GoXh6^0onMNjd2oiQg[0;oU6nV1?nCKZD4oi=_
YPCoU72W1?nELJP5oiEcZ@;oUWB[00?oVGFYoiUfZ_nIMZX00_nIMZX5oiUg[0CoVWV]1OnJNjl2oi]m
/@03oj:6]_nSR;SoXhRh00?oXhRh1OnSRkX3ojB>_@03ok2RbOn`Xl_o/:?;00;o/:?;0ol000001on`
Y/go_;oLokbog?nl_mco^kkLo`000?nk_]`00_o1hNl4ol7Jk0?o^N[e0_nlhO83ojkWn@;o/m_d0onU
eOP5ojS;lAGooooo00?o0000ooooooooool0=_ooool002cooooo0_l0001Booooo`?o20000olo02H3
odT0<0;oE00h00CoG`LnofHBBomV4T_oIQ9;1?mU4T/2of@?B0CoH0Y30omK0S/4oeH0<@?oC`0W00?o
B@0NoiQcYonLNZ`01?n^Rk43ojZ7/0GoXh6^0_nMNjd00onGLZOoU6nVoiA_YP02oiA_YPGoTfjU0onC
KjH4oiA`Y`GoUG6X1?nELjT00onFM:_oVGFYoiUeZ@05oiUfZPCoVGN/1?nJNJd5oiYk[`04oi]m/OnR
Q[KoXXJfoj:6]PCoXhRh1OnSRkX00onTS[go/:;9ok2Rb@02ok2Rb@?o00000_n`Xl/00on`Y/go_;oL
okbog003okbog003ok^ng?l0003o`N7_00;o`N7_00?o`M[/okWZmOnij_D00_nij_D2oio^m`;o[^Oi
0onMg_d5ojGEn0;oZ<_a0onM`_8Eooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000Cooo
ool01OlG003o2000o`P00?l8003o>`0O00?o?`0V0om903000omD03SoIA18ofHBB`03ofHBB`?oIA9;
0omT3dP4of0:@`?oF`8k1?mF03401Om?02OoV7>WoiQcYonHLjOo[hfb00Go[X^a1?nZQk03oj>1[P04
oi]gZOnGLZOoUg:WoiMbY`GoU6nV1?nCKZD3oi=_YPCoU72W1OnELJP3oiEcZ@03oiQdZ?nIMJWoVGFY
00;oVGFY1?nIMZX4oiUg[0GoVWV]0onJNjl00onRQKCoXXJfoj:6]P02oj:6]PGoXhRh0onSRkX00on`
XLSo/:;9ok2Rb@03o`0000Co/:?;00?o_L3Mokbog?nl_m`00onl_m`01Oo0jO;o`N7_ol7Qkol0003o
`N7_00?o/?;e00Co^N[eoio^monOk_OoWnkg0_n>ho`5oigNo@;oYMGh0onIaoL5oig2lQCooooo00?o
0000ooooooooool0=Oooool002cooooo00Co0000ooooool0003o0000C?ooool3oaL000;o20000_lk
01l2ocl09P;oB@0`00CoHPa3ofD@B?mU44SoIA180omV4T/4ofDBB`?oI0m81?mP2T<3oe/2>`?oEP0a
00CoC`0WoiE^XonHLjOoV7>W0_n_SK85ojj;/@CoZXN`00CoXh6^oi]gZOnKMjWoVgNY1?nGLZL4oiA_
YPCoTfjU0onCKjH5oiA`Y`CoUG6X00CoUG>YoiQdZ?nHM:SoV7BX1?nIMJT4oiUfZPCoVGN/1OnJNJd0
1?nJNjooXXFdoj:5]?nRQK@5oj:6]PCoXhRh00?oXh^jok2Qb?n`XLP00ol00004ok2Rb@03ok2Sbonm
`=go_L3M00;o_L3M0onl_m`3ol3YlP03ol7Qkol0003o/?;e00;o/?;e0on3jNL00onOk_OoS^?lohkS
o002ohkSo0;oWMkm0onDc?/5oiW7m`;oWL;b0_nF^O0Cooooo`03o`000?oooooo000000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Wo
oooo000/ooooo`;o00000_ooool00ol0003oooooooooo`17ooooo`06ob<00?lG003o5`00oaL00?l8
003o>`0I0_lk01l3ocl09P03odT0<?mR34?oHPa300?oIA180omV4T/4ofDBB`;oI0m81?mP2T<3oe/2
>`;oEP0a1?nEKZ<00onHLjOo[hfbojn=/P02ojn=/PCo[X^a1?nZQk05oi]gZ@?oUg:W1?nDKjH4oi=^
Y@CoTfnV1?nDL:L2oiEaZ0;oV7>W1OnHM:P3oiUeZ@CoVGJZ1OnIMj`3oiYi[@03oj63/onRQKCoXXFd
00?oXXFd1?nRQ[H3oj>8^004ok2Paol0003o0000o`0000;o/:781?n`X/T00onm`mko_L3Mokg0g@04
okg0g@04okbog?o0jO;o`>Wbol3YlP?oW??[00Co0000oh?Yion3jNOoPnWW0omcg_42ohkSo0CoS<on
1?nDc?/2oiW7m`;oTk[a1OnF^O0Eooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0AOooool2ob<000;o5`000olk01T2oc/07`?o
?`0V0omR34<2ofD@B0CoIQ9;0omU4T/3of@?B0CoH0Y30_mK0S/4oi=[X@?oUFjS1On_SK85ojj;/@;o
ZXN`00?oXWj/oi]gZOnKMjT00onKMjT3oiMbY`CoU6nV1?nCKZD4oi=_YP?oU72W00?oUg:VoiQcYonH
LjL00_nHLjL5oiQdZ0?oVGFY1?nIMZX5oiUg[004oiYi[OnQPk?oXH>coj63/`GoXXFd1OnRQ[H01?nS
R;So0000o`000?n`X<L5ok2Qb003ok2RbOnm`mko_L?N00;o_L?N1?nm`=d2ok_al`04ol3Yl_nLln_o
W??[oiccj`;oEm3100CoD<gHo`000?mhc_ooN<ko1On2col2ohc?oP;oT;Oa1?nB^O85oi>jl@CoU[W`
5Oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000001Wooooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0@Oooool01_l0003o:@00ob<00?lS003o5`00och05P?o>`0I0olk01l00olo02KoG`Dlof8<@`02
of8<@`?oIA180omV4T/4ofDBB`?oI0m81?mP2T<00onBJZ7oTf^Qoi=[X@03oi=[X@;oUFjS00?o[8bd
ojn=/_n_SK800on_SK85ojj;/@04ojZ7/?nROZcoXWj/oj9n[0CoVgNY0onGLZL4oiA_YPGoTfjU0onC
KjH01?nDL:OoUg:VoiMbY_nGLZH5oiQcY`CoV7BX0onIMJT5oiUfZP?oVGN/00?oXH:boj63/onQPk<0
0onQPk<4oj:5]0?oXXJf0ol00003ok2Pa`Co/:7800?o_/OQokg3g_nm`mh01?nm`mh01Onm`=go^o7c
ok_alonklO?oN^C@00;o000000?oK/Koog3:oom`b_l00_m`b_l01?l0003oN<koogS>oomhc_l2oh;?
o`?oS[?`1?n@]o44oi:ilP;oTk[a0_nE[^P5oiFck1Gooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3
o`0000Gooooo00?o0000ooooooooool0?oooool3obT000;o8`000_ln01H3oc/06@;o>`0O00?o?`0V
oel5??mO1C`00omR34<3ofD@B0?oIQ9;1?mU4T/2of@?B0;oH0Y300?oTF^Soi9ZXOnBJZ400_nBJZ44
oi=[X@04oiE^Xon/S;Co[8bdojb<]0Go[hfb0on^Rk400onXQJooXWj/oj9n[002oj9n[0CoVgNY0onG
LZL5oiA_YPCoTfjU0_nCKjH00onFL:GoUg:VoiMbYP03oiMbYPCoV7>W1?nHM:P4oiUeZ@CoVGJZ00Co
VGN/oj62/_nQP[;oXH:b1OnQPk<4oj:5]0?o00001_n`X<L3ok2Qb0?o_/OQ1?nm`mh3ojogk`04ok_a
lom``OkoK/Koofk6o`;oT:3O1?n>Z>H00on>[^co0000ohj^k002ohj^k0GoS[?`0on@]o42oi:ilP;o
UJWT1OnE[^P5oiFck1Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000oeEEEOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03cooooo00Ko:`00obT00?lY003o:@00ob<00?m101D2och05P?o>`0I0_lk
01l00omJ03?oG`Dloel5?004of8<@`;oIA181?mV4T/3ofDBB`;oI0m81OnAJj<3oi9ZX@?oTf^Q00?o
YHRfojb<]?n/S;@00_n/S;@5ojn=/P04ojj;/OnXQJooZ8F_ojR5[`CoXWj/1?nKMjT4oiMbY`CoU6nV
1?nCKZD00onCKjKoUW2UoiI`Y@05oiMbYPCoV7>W1?nHM:P4oiUeZ@?oVGJZ00?oX86aoj62/_nQP[80
0onQP[84oj63/`06oj:5]?l0003o0000o`000?nRQKCoXXJf2?n`X<L00on`XLSo_/OQokk7h@03okk7
h@05okg3g_n_mnoo[oO_ojogkonDT<d00onBV=H5oi2Pg`CoSZSV00?oSZk/o`000?n>[^`00_n>[^`2
ohjcl0;oUIcH0onEXmh5oiFYi0GoUJkX0_nE/n`2oi^cjAGooooo00?o0000ooooooooool00oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?l[003o:`0000;o:@000om101D2
och05P?o>`0I0omJ03<2oel5?0?oHPa30omU44P4ofHBB`;oIA9;00CoTG>]oi5^YonAKZOoTFjW1?nA
Jj<3oi9ZX@04oi=[XOnUR;KoYHRfojF8]PCo[8bd1?n_SK800on/Rk?oZ8F_ojR5[`02ojR5[`CoXWj/
1OnKMjT3oiMbY`CoU6nV0_nCKZD2oiA^Y0CoUW2U1?nGLZH4oiQcY`GoV7BX0onIMJT01?nIMZ[oX86a
oj21/OnPPK45oj62/P;oXH>c0ol00003oj:5]003ok2Qb?n`X<Oo/:3700Ko/:370_nocND4okk7h@;o
Uo;O00?o0000oiB@cOnDT<d00_nDT<d3oi:HePGoT:3O1?n>Z>H01?n>[^co0000oiJEdOnFUM44oiFL
f0CoUJ?N1OnEZN@2oiF^j0;oVjcS1OnK/nTCooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0fooooo`06o`000?lY003o:`00ob/00?lY003o@`0C0om101D2och05P;o>`0I
00CoEP0ZoeX0<omJ03?oFP0c0omO1C`3of8<@`?oIA180omV4T/01?mU4T_oTG>]oi5c[OnALjd3oi5^
Y`CoTF^S0_nBJZ400onKP[SoYHRfojF8]P03ojF8]PCo[8bd0_n_SK82ojb;/`CoZ8F_1?nROZ`5oi]g
Z@?oUg:W0_nDKjH2oi=]Y0CoU6jT1?nFL:D4oiMbYPCoV7>W1OnHM:P2oiUeZ@03oin0/OnPPK7oX86a
00?oX86a0onQP[83o`0000?oXH>c00?oXXFdok2Qb?n`XLP00_n`XLP6ok2Pa`Co_lgU00?o_/OQoiOb
gonGl]l00onFRL@4oiB@c@CoTYSF0_n@X=l2oiR9`PCoUho900?oUYGAo`000?nFUM400_nFUM44oiFL
f0CoUJ?N0_nEZN@2oibVg@GoVjcS1OnK/nTEooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0003o
ooooooooo`0booooo`04o`000?lU003o:@00obT000?o:`000_m301<3od405@;o?P0F0omF02X3oeX0
<`;oG`Dl1?mR34<2ofD@B0;oIQ9;0_mnJk@3oge]]P04oi5c[OnAKZOoTFjWoi5^Y`;oTF^S0_n?NkT3
oi^2^0GoYHRf1?n/S;@00on_SK;o[8^cojb;/`02ojb;/`CoZ8F_1?nROZ`4oi]gZ@;oUg:W00?oTVbT
oi=]Y?nCKJ@00_nCKJ@5oiA^Y0?oUW2U1?nGLZH5oiQcY`?oV7BX00?oWgn`oin0/OnOP;400_nOP;44
oj21/@?o00000_nQP[83oj63/`03ok2RbOn`XLSo/:7800?o/:781?n`X<L00onoe>Wo_lgUoko=i@02
oko=i@;oKmbl00?oUhBloiJ9a?nFRL@00_nFRL@5oiB@c@;oTYSF00?oVHBkoiR9`_nHRL800onHRL84
oiN?b@04oiJEdOl0003oUYGAoiJEd@CoUIcH0_nEXmh2oifOePGoW:KM1OnK[><2oi^cj@;oXkKV5Ooo
ool00ol0003oooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00Ko
0000obD00?lU003o9@00obT00?l[0002od@040;o@`0C0om101D00oln01KoD@0RoeH0:P02oeH0:P?o
FP0c0omO1C`3of8<@`;oIA180_n2K;43ogi[]0CoOFff0on4LkP4ohmk^@CoVh:h1?nUR;H4ojb<]0Go
[8^c1?nXQJl4oj9n[0?oVgNY00CoTfjUoi9/Y?nBK:CoTVbT1?nCKJ@5oiA^Y0?oUW2U1OnGLZH4oiQc
Y`04oiQdZ?nOOk3oWgn`oimo/0CoWh2a0_nPPK42o`0000GoXH:b00?oXH>cok2RbOn`X/T00_n`X/T5
ok2Qb003ok2Paonoe>Wo_mCY00;o_mCY00?o_lgUofoL_?m_g;`00onGQ;`5oiJ9a0;oU93=0_nJOkD4
oiV4^`CoV8W21?nGSlT2oiJEd@03o`000?nFUM7oUYGA00;oUIcH00?oWIW?oifOe_nMWmH00onMWmH5
oibVg@;oVjcS0_nS[n05oj>fiQGooooo00?o0000ooooooooool0;_ooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?lO003o9@0000;o9@0000?o@P0<od@04?m401000_m4
01000om301?o@@0Eod405@02od405@;oD@0R0omF02X3oeX0<`?oG`Dl0_mR34<2ohY_[PCoPVba0omn
Jk@4oge]]P?oQ7>h1?n?NkT3oi^2^0GoYHRf0_n/S;@00on/S[Oo[8^cojb;/`03ojb;/`CoZ8F_1?nR
OZ`01?nKMjWoTfjUoi=^YOnCKZD3oi9/Y0GoTffT1?nDKZ@3oiI`Y@GoUg:V0onHLjL6oimo/0;oWh2a
0ol00003oj21/@?oXH:b00?o/:?;ok2RbOn`X/T00on`X/T4ok2Qb0;o_]c_0onoe>T00ol0003oVGnf
oiUo]P04oiN4_0CoUXW400?oVgb`oiYo]OnJOkD00_nJOkD4oiV4^`CoV8W21OnGSlT01?nFUM7o0000
oijDbOnNU<T4oifIc`GoWIoF0_nLY]d2ojBXfPGoXjoP0_nS]^H3oj^liQGooooo00?o0000oooooooo
ool0;Oooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03oaT00?lO003o7`00
00?o9@000_m200`3od@040;o@`0C00?o@@0Eodh06om>01/00_mA0283oeH0:P?oFP0c0omO1C`00omR
34?oT7:]ohY_[P02ohY_[PCoPVba0omnJk@4oge]]P?oQ7>h1?n?NkT3oi^2^0GoYHRf00Co[8bdojb>
]on/S[Oo[8jg1?n/Rk<4ojR5[`;oXWj/0_nGLZL4oi=^Y@CoTVbT1?nCKJ@4oiA^Y0CoUW2U1?nGLZH0
0onHLjOoWgn`oimo/005oimo/0?o00000_nOP;44oj21/@03oj62/_n`Xl_o/:?;00;o/:?;1On`X/T0
0on`XLSo_]c_okkLk`03okkLk`03okoDjOnINk3oVGnf00?oVGnf1?nGQ;`01?nFRLCoVgb`oi]l/?nK
O;04oiYo]@CoVHBk1OnHRL82oiN?b@;oX8o30_nNU<T00ol0003oWYC9oifIc`04oifIc`;oWIoF0_nU
Xm<5ojBXfP?oXjoP00?o[;ORoj^li_n[_>H01?n[_>HDooooo`03o`000?oooooooooo02gooooo000@
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o00003ooo
ool2o`0002Oooooo0olI00001?lO003o9@00ocl01olo00L2od8030?oA00@00?o@`0Cod`05_m>01/0
0om>01/2oe408P?oEP0Z0omJ03<00omO1CcoT7:]oi1b[@02oi1b[@?oRVn^1?n2K;43ogi[]0CoOFff
0on4LkP4ohmk^@CoVh:h0onUR;H00onVSK[o[8jgojb>]`02ojb>]`Go[8^c0_nXQJl00onKMjWoUg:W
oiMbY`02oiMbY`GoTfjU0onBK:@4oi=]Y0CoU6jT1?nFL:D3oiMbYPKoWgn`0ol000000onOOk3oWh2a
oin0/@02oin0/@?oX86a00?o/:G=ok2Sbon`Xl/00on`Xl/4ok2Rb@;o^nKc1?nng>l3oiUk/0CoVGnf
0_nGQ;`2oiaj[0GoVgb`1?nJOkD4oiV4^`?oV8W200?oXHbmoj2?`onPSl<00onPSl<2oijDb@03o`00
0?nNU<WoWIW?00;oWIW?00?oYYk>ojFSdonUXm<00onUXm<5ojBXfP04oj>_h?n/]n;o[;ORojbghPCo
ZkcV00?o/L?Wooooooooool04oooool00ol0003oooooooooo`0/ooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02;ooooo00Go4@00oaT00?lI003o6@00oc`00P04ocl01`03od803?m4013oA00@
00;oA00@0_m<01H3odh06`;oD@0R1?mF02X00omJ03?oUGB/oiEd[002oiEd[0?oT7:]1?n:Kjh4oh9/
/@?oOV^d1?mmKKH3ohAc^0CoSg^i0onKP[P00onUR;KoYXfjojJ=^P02ojJ=^P?o[8jg1On/Rk<00onX
QJooVgNYoi]gZ@05oiMbY`CoTfjU0onBK:@4oi=]Y0GoU6jT0onFL:D00onGLZKoWgn`oimo/003oimo
/0?o00001?nOOk05oin0/@04oj21/On`YLgo/:G=ok2Uc@Go/:?;00?o/:;9ok_Vlonki_<00onki_<0
0onng>ooVWN/oiUk/004oiUk/0;oVGnf00?oWGRYoiaj[?nLNZ`00_nLNZ`5oi]l/0CoVWne1?nIQ;/0
0onHRL;oXHbmoj6<_@02oj6<_@CoX8o30onNU<T00ol0003oWIW?ojJNcP03ojJNcPGoYJ?C0_nTZ=X2
ojfcg@Go[;OR00?oZkcVok73iona`nL00_na`nLCooooo`;o0000;_ooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Pooooo`04oa400?lI003o6@00oaT000;o?0020olo00L2od803003od@04?m:
01;oBP0B00;oC00F0om>01/3oe408P03oeH0:_nJNJgoV7N/00;oV7N/1?nEM:`4oi1b[@?oRVn^1?n2
K;43ogi[]0CoOFff0on4LkP4ohmk^@;oVh:h00?oW8NlojJ=^_nVSKX00onVSKX4ojb>]`?o[8^c00?o
Wgb/oi]gZOnKMjT00_nKMjT4oiMbY`CoTfjU0onBK:@4oi=]Y0GoU6jT0_nFL:D01?nNOZooWgn`oimo
/?nOOk03o`0000SoWgn`0onOP;400onaZ=3o/:G=ok2Uc@02ok2Uc@Co/:?;0_ndk_H4ok_Vl`?oVWN/
1OnINk000onIOkKoWGRYoiehZ@05oiaj[0CoVgb`1?nJOkD2oiV4^`;oXhVi1OnQS;d5oj2?``;oWYC9
00?o0000ojJNc_nVW/h00onVW/h4ojFSd`03ojjaf_n]/mgo[K?M00?o[K?M0on/]n82ok;3iPCo/L?W
5Oooool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Cooooo00?o0000ooooooooool07?oo
ool01?mNdK7o2000oa400?lI0002ocP000;o?0020olo00L00om200coB00>odX04P03odX04P;oC00F
0om>01/00omA02;oVWV]oiYi[@02oiYi[@?oV7N/1?nEM:`4oi1b[@;oRVn^00?oSVbWohU[Z_n9JjX0
0_n9JjX3ohE[[PCoPVfb0on7M;P4oi1n^`CoW8Nl1?nVSKX4ojb>]`04ojb;/onOO:coWgb/oiml[0Co
VgNY1?nGLZL4oi=^Y@?oTVbT1OnCKJ@4oiA^Y003oiI`YOnNOZooWWj_00?o00002onOOk000onOP;7o
/JS@ok6Xd002ok6Xd0Co/:G=00?o/:?;okC^m_ndk_H00ondk_H00onki_?oVWFXoiYg[004oiYg[0?o
VG^`00?oWWNWoiehZOnMN:T00_nMN:T4oiaj[0GoVgb`0_nJOkD00onTQkGoXhVioj>9^@03oj>9^@Co
XHbm1?nPSl<01OnZVLGoZ9_9ojRKbOnXVlWo000000GoYYk>00?oYJ?Cojjaf_n^/MX00_n^/MX4ojfc
g@03ojbgh_nb`nKo//?V00?o//?V0_na`nL2ok;7jAGooooo00?o0000ooooooooool0:_ooool002Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`04o`000?l8003o2000oc80
00Co>00000Co?002ocl01olo00OoAP090om800h3odX04P;oC00F0_m>01/3oi]k[PCoVWV]1?nHMj`3
oiEd[0;oT7:]0_nBKJH3ohi/Y`CoRF^Z0on5Jjh4oh9]/P?oQgBh1?n@O[/4oib7_0GoYXfj0_n/S[L0
0onPOZooWgb/oiml[003oiml[0?oVgNY1?nGLZL4oi=^Y@CoTVbT1?nCKJ@3oiA^Y005oial[onNOZoo
0000o`000?nNOZl03?nOOk000ona[=?o/JS@ok6Xd003ok6Xd0?o/:G=0onVl_<2okC^mP04oiYcYOnJ
MJSoVWFXoiYeZ0GoVWN/00CoVG^`oiigYonNMjOoWWNW1?nMN:T4oiaj[0GoVgb`00CoVWneojB7]OnT
QkGoY8Ne1?nSRKT5oj6<_@04oj2?`onZVLGoZYW5ojZIa@CoZ9_900Go0000ojJNc_nVW/koYYk>ok6`
e`05ojjafP;o[K?M0onda>H4ok;3iP03ok?<k?nbanWo//OY00?o//OY5?ooool00ol0003ooooooooo
o`0Zooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo0_l00002
o`P000;o<P000olh0002oc`00P?oAP090_m800h3odX04P?oC00F0_nLOK04oi]k[P?oVWV]1?nHMj`2
oiEd[003oi=^YOnBKJKoTVfV00;oTVfV1?n>K:L4ohU[ZP?oQF^^0on2KK84ohMd^0?oT7jk1?nLQk`5
ojJ=^P03ojb>]onPOZooX7j_00GoWgb/0onKMjT4oiMbY`GoTfjU0onBK:@4oi=]Y003oiA^Y?nLO:oo
000000;o00000onNOZl:oimo/0Co/JcC1OnaZ=001?n`YLgoY_;cojKblonVl_<4oiYcY@?oVWFX1?nJ
Mj`00onNMZGoWWNWoiigY`03oiigY`?oWGRY1OnLNZ`3oi]l/003ojJ6/_nTQkGoY8Ne00;oY8Ne1?nS
RKT4oj6<_@03ojbH`_nZVLGoZYW500?oZYW51?nXVlT00ol0003o/K3Gok6`e`02ok6`e`?o[[7J00?o
]/OWokC4i_nda>H01?nda>H00onb`nKo/lc/ok?<k002ok?<k0?o//OY0_n_bNdDooooo`03o`000?oo
oooooooo02Wooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool3
o`000004o`P00?l]003o<P00oc8000?o>00000?o?002od@00om600T00_m600T2odP03PCoBP0B00?o
C00Foieo/OnLOK000_nLOK04oi]k[PCoVWV]0_nHMj`01?nDKjKoTfjUoi=^YOnCKZD5oi9]YP?oSVbW
1?n9JjX3ohE[[PCoPVfb0on7M;P4oi1n^`CoW8Nl0onVSKX00onNOk7oX7j_oj1n[`02oj1n[`CoWgb/
0onKMjT5oiMbY`CoTfjU0onBK:@2oi=]Y004oiUi[_l0003o0000o`0000?oW7b_0onNOZl8oimo/003
ok>aeona[=?o/JcC00?o/JcC1?naZ=02oho_iP03ojKblonKLZCoVg:T00CoVW>U1?nJMJP2oiYg[0;o
WWJU1OnNMjL3oiehZ@GoW7Z/00CoVgb`ojJ6/_nVQ[;oYXJb1?nTQkD5oj>9^@03oj6<_On/V<;o[9S2
00;o[9S21?nZVLD3ojRKb@03ok>`eOl0003o/K3G00Co/K3G00Co[[7JokK7ionfanOo]/OW1?nda>H0
0onddNoo/lc/ok?<k003ok?<k003ok;7jOn_bNgo[lW]00?o[lW]5?ooool00ol0003oooooooooo`0X
ooooo`00:Oooool3o`0001Oooooo00?o0000ooooooooool04Oooool2o`000003obD00?l]003o;@00
00;o<P0000?o>000od000?m000000om400<2odH02@?oB00>00?oBP0Boij1/onMOk400onMOk43oiam
/0CoVg^^1?nJNJd00onHMjcoU6nVoiA_YP04oi=^Y@CoTVfV0on>K:L4ohU[ZP?oQF^^1?n2KK83ohMd
^0CoT7jk1?nLQk`01?nVSK[oWWnaoiio/OnNOk44oj1n[`CoWgb/1?nKMjT4oiMbY`CoTfjU0_nBK:@0
1OnEMZko0000o`000?l0003oVGV^00GoW7b_0onNOZl6oimo/0Co/k7G1Ona[=<01OnaZ=3oSnoVoho_
i_n?knKoW7:R00?oVg:T1?nJLjD4oiYeZ003oiYg[?nNMZGoWWJU00;oWWJU1?nNMjL3oiehZ@CoW7Z/
00?oYhJaojJ6/_nVQ[800onVQ[84ojB7]@?oXhVi00?o[iW1ojbH`_n/V<800on/V<84ojZIa@03ojRK
bOnc/=Go/k3E00;o/k3E00Go0000ok6`eona/=Oo/K3GokW>jP05okK7i`03okC4i_nddNoo]=7_00;o
]=7_0_ncc>`3ojoAl@Co[lW]00?oZLK^ooooooooool04Oooool2o`0002[ooooo000Yooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03_ooool2o`0000;o9@000_l]00000olb003o?000
od000003od0000;oA0030om600T00om800koWX6coij1/`02oij1/`CoWGna1?nLOK03oi]k[P;oVWV]
0_nEL:L4oiA_YP?oTfjU1?nBKJH3ohi/Y`CoRF^Z0on5Jjh4oh9]/PCoQgBh0on@O[/2oib7_0;oV7^a
1OnNOk43oj1n[`CoWgb/1?nKMjT4oiMbY`;oTfjU0_nCMJh3o`0000GoVGV^1?nLO:l4oiin[`?oWgn`
00?o];SKok>aeonc/ML00onc/ML4ok6/d`03ofoOcOnLLZ;oW7:R00?oW7:R0onKLZ@5oiYcY@;oVWFX
00?oWWFToiifYOnNMZD00onNMZD4oiigY`CoWGRY0_nLNZ`2ojN6/@GoYXJb1?nTQkD00onSRKWo[iW1
ojnI`@02ojnI`@Co[9S20onZVLD00ong/mKo/k3Eok>`e@04ok>`e@03o`000?nic^[o^LkZ00;o^LkZ
0onfanL2ok?Il`?o]=7_0_n]fOL5ojoAl@03ojo9kOnYa^koZLK^00;oZLK^5?ooool00ol0003ooooo
ooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo0_l000001OlL003o9@00
obD00?l]003o=`0000?o?0000om00002od@00`03odH02OnRQkSoX8Be00?oX8Be0onNPK<5oieo/@?o
W7f`0_nKNjh00onELJSoUG2WoiE`Y`02oiE`Y`CoU6nV0onCKZD4oi9]YP?oSVbW1On9JjX3ohE[[P?o
PVfb1?n7M;P2oi1n^`03oi9f/?nHNk7oV7^a00;oV7^a1OnNOk43oj1n[`GoWgb/0onKMjT2oiMbY`;o
TgN`00CoTgF^o`000?l0003o00001?nEMZh4oiUi[PCoW7b_1?nNOZl00onOOk3o];SKokBhf`02okBh
f`Go/k7G00Co/JcCoiabXOnLLZ7oW7:Q1OnLLZ83oi]bY0GoVW>U00?oVWFXoiieY?nNMJ@01OnNMZD4
oiigY`CoWGRY00?oW7Z/ojN6/OnWQ[400_nWQ[44ojJ6/PCoY8Ne1On_VL45ojbH`P04ojZIaOng/mKo
]k?FokNcePCo/k3E00?o^mS_o`000?nic^X00onic^X00onfanOo/mWcok?Il`03ok?Il`03okCAkon]
fOOo[MWg00;o[MWg0_n_dO42ojO<l`GoZLK^5Oooool00ol0003oooooooooo`0Vooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00Ko0000oa400?lL003o
7000obD00?l`0003ocL000;o?0000om000000om400?oXXNhoj:7^003oj:7^0?oX8Be0onNPK<5oieo
/@;oW7f`00CoUW>YoiEaZ?nELJSoUG6X1?nEL:L4oiA_YP?oTfjU1?nBKJH4ohi/Y`CoRF^Z0on5Jjh2
oh9]/P03ohe]Z_n>LJgoSW6]00;oSW6]0onBM[05oiQk/@CoWWna1?nPOZl4oiml[0;oVgNY00?oUWbc
oi=g/?nCMk000ol00004oi=e[P?oUGJ^1?nINJh5oial[`;oWWj_0_nf_Ml5okBhf`;o/k7G00?oB/BW
oi]`X?nLLZ401?nLLZ44oiabXPCoVg:T0onJLjD00onNM:?oWWFToiieY002oiieY0CoWWJU1OnNMjL3
oiehZ@GoYhJa1OnVQ[82ojB7]@;o/Yc11?n_VL44ojbH`P03okZif?ng/mKo]k?F00?o]k?F00?o/k3E
ok_Hkonkf>l00_nkf>l00ol0003o^LkZokW>jP03ok7Sn0;o/mWc0onVhO/2ojgIm`?oY=7g1?nWc?<2
ojW6kP?oXl7^5?ooool00ol0003oooooooooo`0Vooooo`001_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000Mooooo`03o`000?oooooo
oooo00Cooooo0ol000000olA003o7000oa`00002oc0000?o=`000_ll00000om0003o]:gBok:Zd003
oj>:^PCoXXNh0onPQ;D4oij1/`?oWGna00CoUWB[oiIcZOnFLjWoUW>Y1?nELJP3oiE`Y`CoU6nV0onC
KZD5oi9]YP?oSVbW0_n9JjX2oi5]Y@?oSffW0on=KJX4ohia[@CoTWJ`1?nHNk44oiio/@CoX7j_0_nO
O:`2oi^2]`?oUWbc0_l00003oi=g/0CoTgF^0onEMZh4oiUi[PGoW7b_00?oWWj_okJmgonf_Ml00_nf
_Ml3okBhf`03o`000?n?IYooTVZR00;oVg2P1OnLLZ44oiabXPCoVg:T0_nJLjD2oiidX`CoWWFT1?nN
MZD5oiigY`;oWGRY00?oZHN`ojN6/OnWQ[400onWQ[45ojJ6/P04ojB7]OnbW<7o/Yc1ok:L`@Go[iW1
00?o[9S2okZif?nj^MP00_nj^MP3okNceP;o^^Od1?nkf>l01?nUk?Wo0000ok7Sn?nahoP4oiOWn`;o
Y^7k0_nMeO/5ojCAm`;oYlcc0_nR`o45oj?1kQCooooo00?o0000ooooooooool09Oooool000kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`02ooooo`05o`000?l3003o4@00oa400?lL00000ol`0003ocL0
0005oc`00?nd[M;o]:gBokB]d_nVS[`01?nSR[X4oj:7^0CoX8Be0onNPK<01?nMOk7oUWB[oiIdZonF
M:/4oiIcZ@?oUG6X1?nEL:L3oiA_YPCoTfjU1?nBKJH2ohi/Y`03oi=]Y?nAKJGoTFfU00;oTFfU0on?
KJL4ohe]ZPCoSW6]0onBM[04oiQk/@GoWWna0_nPOZl00onNQk_oVh:goi^2]`02oi^2]`?o000000?o
UWbcoi=g/?nCMk000_nCMk04oi=e[P?oUGJ^1OnINJh3oial[`03okFnhOnf_Moo][gO00Co][gO00Co
];SKohmVWon?IYooV6bN1?nKL:04oiabX@GoW7:R0onKLZ@01?nJLjGoWWBSoiidXonNM:<4oiieY0Go
WWJU1?nNMjL01?nMN:WoZHN`ojV7/?nYQk05ojN6/@?oYXJb00?o]Z;4ok:L`OnbW<400_nbW<44ojnI
`@03oko4g_nj^MSo^[WH00Co^[WH00?o]k?Fok[Wm?njio@00_njio@01onkf>ooYNciojG/nOnUk?Wo
N^;ao`000?mjh_400_nGio/2oi;GoPGoWMGk0_nTdOL2oio4lPGoX/?a0_nS`Nh2oj6lkAGooooo00?o
0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`0000?o0`0000Co4@00obT00?lY003o<000
0onh/mD5okJ`d`04okB]d_nVS[coYXjlojJ>_0?oXhZj1OnRQkP3oj24]@;oWX6c00?oUgN/oiIdZonF
M:/00_nFM:/4oiIcZ@?oUG6X1?nEL:L4oiA_YP?oTfjU1?nBKJH00on>K:OoTffToi=]Y004oi5]Y@Co
SffW0on=KJX4ohia[@?oTWJ`1OnHNk44oiio/@04oj1n[onNQk_oWXNkoi^2]`?o000000CoVh:goiIl
/onFO;?oUWbc1?nCMk04oi=e[PCoUGJ^1?nINJh00onLO:oo]KkQokFnh@02okFnh@Co][gO00?oSFBM
ohmVWonHK9h00_nHK9h4oi]`X0CoW7:Q1OnLLZ82oi]bY003oimfXonNM:?oWWBS00?oWWBS1?nNMJ@4
oiifY@?oWWNW00?o[8VaojV7/?nYQk000_nYQk05ojN6/@03ojJ6/_nfX/Co]Z;400;o]Z;41?nbW<40
0on_VL7o_lCNoko4gP02oko4gPCo^[WH0_n[m?82ok[Wm0?oQNW[00GoYNciog[RlOmjh_7oN^;ao`00
0002ohKEo`CoT]On0_nMeO/2oi_3l`GoWlCb0_nR`o43oinkk0CoXKc]4oooool2o`0000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Wo
oooo000>ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`;o
00007_ooool2o`000007o`<00?lD003o8000ob000?lY003o`MS[okVfeP05okRce@;o][3C0_nXT[l4
ojJ>_0CoXhZj1?nRQkP2oj24]@04oiQi[_nGMjcoUgN/oiMg[0CoUWB[1?nFLjT3oiEaZ0CoUG2W1?nD
KjH3oi=^Y@;oTVfV0_nDKZ@3oi=]Y0CoTFfU1?n?KJL3ohe]ZPCoSW6]1?nBM[04oiQk/@;oWWna0_nO
Rkh01?nNQk_o0000o`000?l00004oi^2]`?oUWbc1?nCMk04oi=e[PCoUGJ^0_nINJh3ojjjhPGo]KkQ
00Co][gOoheTWOn=I9goTfRM1?nHK9h4oi]`X0CoW7:Q1OnLLZ800onKLZCoWgJSoimfX`05oiidX`Co
WWFT1?nNMZD01?nNMjOo[8Vaojb9/On/RK44ojV7/0CoYhJa00?o_:c:okJRa?nfX/@00onfX/@4ok:L
`@Ko_lCN00Co^[WHoj_dl_n[m?;oZoCb0om7a[/2ohGYj`03odg<eOmicoooNLoo00;oNLoo00?oQ]Go
o`000?nE^>l01OnG__<4oi_3l`;oWlCb0onN^N/5oinkk0;oXKc]0_nQ^^/Dooooo`03o`000?oooooo
oooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo0_l0000Nooooo`07o`000?lD003o5000oa@00?lP003o`MKYol7Hj`04
okVfeP?o^;?E00?oZYK2ojRB_onXT[l00onXT[l3ojJ>_0CoXhZj0_nRQkP2oiYk/0?oV7V^1?nGMj`4
oiIdZ`?oUW>Y0onELJP4oiE`Y`CoU6nV0_nCKZD5oiA^Y0CoTffT0onAKJD4ohm]Y`?oSFfZ1On>LJd3
oi9f/0;oV7^a0_nMRKh2oin;_P?o00000onNQk/4oi^2]`?oUWbc1OnCMk04oi=e[P;oUGJ^00?oY;;R
ojjjh_n^^^801?n^^^82okFnh@03ohmUWOn@IIcoT6FL00?oTfRM1OnHK9h3oi]`X0GoW7:Q0onLLZ80
1?nRNJGoWgJSoimfXonOMZ<5oiidX`CoWWFT1?nNMZD5ojb9/@CoZHN`0_nWQ[43okb/bPCo]Z;40onb
W<42ol?Fj0Co_lCN0_maglH00on[m?;oNKckogVln`02ogVln`CoMLOo0_micol2oiB]j0;oUKS_00?o
0000oiFhkonG__<01?nG__<2oi_3l`;oW[GY1OnN^N/2oinkk0;oXKKX1OnQ^^/Dooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool00ol0003oooooooooo`0Jooooo`05ocfo/_l6003o1P00oa@00?n`lo<00oo1e^T2
ok^ie`Go^KKF00Co^;?EojZF`_nZU/;oZYK21?nXT[l4ojJ>_0;oXhZj00?oVgjboiYk/?nJNk000_nJ
Nk04oiQi[P?oUgN/1?nFM:/3oiIcZ@CoUG6X0onEL:L2oiA_YP;oTfjU1onDKZ@4oi=]Y0CoTFfU0on?
KJL3ohe]ZPGoSW6]0_nBM[001?nJQKcoWHVnoif9__nMRKh3o`0000?oWh^n0onNQk/5oi^2]`?oUWbc
1?nCMk04oi=e[P04oiEf[_nT/^;oY;;RojBbhPCo[[[R00?oTVNNohiSW?n@II`00on@II`3oi=XW@Go
V6bN0onKL:05oiabX@;oW7:R0_nRNJD4oimfX`CoWWBS1OnNMJ@2oiifY@03ojn>/on/RK7o[8Va00?o
[8Va1?nYQk000onWQ[7o_:c:okb/bP02okb/bPGo]Z;400?o/Yc1ol?Fj?o3e^P00_o3e^P00onoa=ko
SicLohF]k`03ohF]k`;oNKck0_nHU]04oiJRg@GoU:gX0_nE^>l01?l0003oUKS_oiNnlonG__<2oif_
i0GoW[GY0_nN^N/2oj6bi0GoXKKX0onQ^^/00onT^nWoooooooooo`0Booooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802Ooo
ool002Oooooo00?o0000ooooooooool05oooool3o`000003o`H00?nfkoGo]^oe00?o`]CX00?o`MKY
ok^ieonk^ML00_nk^ML3okVfeP03ojfKa?nZU/;oZYK200;oZYK21?nXT[l4ojJ>_003oj>:^_nKO[;o
Vgjb00CoVW^`1?nHNJh3oiMg[0CoUWB[1?nFLjT3oiEaZ0;oUG2W00?oTVjVoi=^YOnCKZD00_nCKZD7
oiA^Y0CoTffT1?nAKJD3ohm]Y`CoSFfZ0on>LJd01?nIPKSoVXFloiZ5_?nJQK`3o`0000;oWHVn1?nO
Rkh4oij7^`CoVh:g0onFO;<2oi=g/0;oT:KT1?nIZ^85ojBbhP03ojjjh_n>I9coSV>L00;oSV>L1?n@
II`4oi=XW@CoV6bN0onKL:05oiabX@04oiabX_nRNJGoXWVUoj9iY@CoWgJS1?nNM:<5oiieY004oiif
YOn_S[?o[hjcojn>/`Co[8Va1?nYQk05okb/bPCo]Z;40_noko82ol?Fj0GoSicL0_n5[Nl00onKSLCo
V9K@oiRFd003oiRFd0CoUZ;M0_nD[NP2oinRe`;oWZWN00?o0000oijYg_nNZMh01?nM[n@2oijej@;o
XZkP1OnQ/^@4oj6fj003oj6jjonT^nWoY;_Y00;oY;_Y5?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Woooo
o`;o00005Oooool00ol0003oF=;Aohc]jP02ohc]jP;o]^oe1Oo2e>P6ok^ie`04okVfe_n]VlCo[I_4
ojfKa0?oZYK21OnXT[l2ojJ>_003oif1]OnKO[;oVgjb00;oVgjb0onJNk04oiQi[P?oUgN/1?nFM:/4
oiIcZ@;oUG6X00CoTFjWoi9^Y_nBKZKoTVjV1?nCKZD7oiA^Y0CoTffT1?nAKJD4ohm]Y`?oSFfZ00?o
SW6]oiV1^?nIPKP00_nIPKP2o`000003oiZ5_?nMRKkoWHVn00;oWHVn1OnORkh3oij7^`;oVh:g0_n@
]_03ohjZj@GoT:KT1?nIZ^83ojBbhP?oSVBL0on>Hi`5oi1UW0?oTfRM1?nHK9h4oi]`X0?oW7:Q00?o
YGfWoj9iYOnRNJD00onRNJD3oimfX`GoWWBS0onNMJ@00onaTkOo[hjcojn>/`02ojn>/`Go[8Va0_nY
Qk02olBoePGo_:c:00Co]Z;4oko_l_noko;o_nob1?nGSlT2ohnLg0;oWXNj1?nKSL@5oiRFd0;oUZ;M
00?oXYc>oinReonOX]L00onOX]L2oijYgP03o`000?nNZMkoWZWN00;oWJoT00?oXZSKoj:^h?nR[^00
0onR[^04oj6bi0;oXKKX0onU^>H4ojBkjAGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4009ooooo`009oooool00ol0003o
ooooooooo`0Aooooo`?oLMoZ0_nLk_H3okWZm@?o`];V0oo2e>P2okflf0Co^kWG00?o/:37ojfKa?n]
Vl@00_n]Vl@4ojZF`P?oZ9:o00CoWhFgoif1]OnMPKGoWH6e1?nKO[84oiYk/0?oV7V^1?nGMj`3oiId
Z`;oUW>Y0_nAKjP3oi5^Y`?oTVjV1?nCKZD8oiA^Y0?oTffT1?nAKJD4ohm]Y`;oSFfZ00?oVGfcoiV1
^?nIPKP00ol00003oiZ5_0GoWHVn1?nORkh2oij7^`;oUL?f1?n@]_03ohjZj@GoT:KT1?nIZ^800onT
/^;oSVBLohiTW002ohiTW0?oSV>L1On@II`3oi=XW@CoV6bN1?nKL:02oiabX@;oYGfW1OnRNJD3oimf
X`GoWWBS0_nNMJ@2ok6C]`Co[hjc1On/RK401?nYQk3oa;oFolBoe_o4_mH4okb/bP?oSNkH00?o_nob
oib6^onGSlT00_nGSlT00onRQ;?oWXNjoij7^P02oij7^PCoVhg41?nHU]000onUUlOoXYc>oj:LcP02
oj:LcPGoWj;G0_nNZMh00ol0003oY:CEoj:Xf`03oj:Xf`GoXZkP0_nQ/^@2ojJdh`GoYKSV0_nT^nT2
ojRnjA;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000000Wooooo000Wooooo`03o`000?oooooooooo00_ooooo0omUdoD3ohGSn@;oY^[j1?nk
ho<00onij_Go`];Vol;BiP03ol;BiP03ol;Dj?nm_=So_KcH00;o_KcH00?o^kWGok2Paon`X<L00_n`
X<L3ojfKa0CoZYK200CoZ9:ooin5]onOQKOoWhFg1?nMPKD3oi]n/PCoVW^`1?nHNJh3oiMg[0;oUWB[
00?oTW2Yoi5_Z?nAKjP00_nAKjP4oi5^Y`?oTVjV0onCKZD8oiA^Y0CoTffT0onAKJD2ohm]Y`;oVW^`
0_nIOK<3o`0000?oVH6h1?nJQK`4oif9_P;oWh^n0onMcOP4oiG3mPCoT;K`0on>Z^T2oi2Vi0CoTFJM
0on@II`4ohiTW0CoSV>L1?n@II`3oi=XW@CoV6bN1?nKL:000onLLZ7oYGfWojEmY`02ojEmY`CoXWVU
0onOMZ<5oiidX`03oiieY?naTkOo/I>g00;o/I>g1?n_S[<3ojb9/@03ol_Rj?o4_mKoa;oF00?oa;oF
00Co_:c:ohg^f?n=k]SoSNkH1?nLQ[/00onGSlWoXXBcoj:4/`02oj:4/`CoWXNj1?nKSL@00onHU]3o
YIO7ojFGa`02ojFGa`?oXYc>1?nOX]L01?nWX<ooY:CEojBTeOl00002ojBTe@CoXZSK0_nR[^02ojNa
g`GoY[CS0_nU^>H2ojVki`GoZ;kY5?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool002Kooooo0ol00006ooooo`?oP<co
0_med_h4oi;NoP04ohGSnOnVj_[oY^[jojKZnPCo^n?c0_o2d>D4ol;BiP;o_[kI0onm_=P00oncYL[o
/:37ok2Pa`03ok2Pa`Co[I_40_nZU/800onQRK[oWhFgoin5]`02oin5]`CoWH6e0onKO[84oiYk/0Co
V7V^0_nGMj`01?nBLZ_oTW2Yoi9`ZOnBL:T4oi5_Z0CoTFjW0onBKZH4oi=^Y@OoU6jT1?nCKJ@2oi5]
Y@04oi]k[_nJNk3oVW^`oiYk/0?o00000_nIOK<5oiV1^0?oVXFl0_nMRKh4ojG@mPCoWLgh0_nE`oH3
oi5[X`;oUFjT1OnBIid4oi5VW@CoT6FL1?n>I9`3ohiSW0CoT6FL0onCJ9d5oiQ/WP?oVg2P1OnUOJL4
oj9iY@CoWgJS0onNM:<00ondV[go/I>gok6C]`03ok6C]`Co[hjc00?o[8Vaol_Rj?o;h^P00_o;h^P3
olBoeP03ojJ1[?nQP[;oXH:b00?oXH:b0_nLQ[/00onWQ:ooXXBcoj:4/`03oj:4/`CoWXNj0onKSL@0
0onYU<7oYIO7ojFGa`03ojFGa`CoXYc>00?oWj;GojNPconWX<l00_nWX<l2ojBTe@04o`000?nTY=Go
XZSKoj:Xf`;oZJoL1OnW/Ml2ojJdh`;oZ[[U1OnY^nL2ojRnj@;oZl7Z5Oooool00ol0003ooooooooo
o`0Nooooo`009_ooool00ol0003oooooooooo`02ooooo`CoQl;k0_n0c?l4oi[Eo0;oT]kn0on/hOT4
okcKl003ok_Sloo2d>Go`]3U00;o`]3U00?o`];VokjnfOnn_]T00onn_]T01?nm_=So/jG:ok>Ub_nc
YLX4ok2Pa`?o[I_400?oY8jmoj69^_nQRKX00_nQRKX4oin5]`?oWH6e1?nKO[83oiYk/0;oV7V^0_nC
Lj`3oi9bZ`CoTW2Y0onAKjP4oi5^Y`?oTVjV1?nCKZD7oiA^Y0CoTffT00?oTFfUoi]k[_nKNjh00ol0
0002oiYk/0?oVGfc1OnIPKP2oiZ5_0?o[L__0onUd?H3ohiVW`CoSfRQ0_nAJj<9oi9WW@?oTFJM1?n@
II`4ohiTW0?oSV>L1?n@II`3oi=XW@GoV6bN0_nKL:000onYPZ[oYGfWojEmY`03ojEmY`CoXWVU1?nO
MZ<2oiidX`?o]9Zm1?naTkL4ojn>/`03oj;fe?o;h^Sobn;X00?obn;X00?oa;oFojJ1[?nVPJ`01OnQ
P[801?nLQ[_oYhB_ojN4[onWQ:l4oj:4/`CoWXNj00?oVhg4ojVD`OnYU<400_nYU<45ojFGa`;oXYc>
00?oZio;ojNPconWX<l00onWX<l3ojBTe@03o`000?nY[mcoZJoL00?oZJoL0onW/Ml00on/^N?oZ[[U
ojZji@03ojZji@?oZK_W0_n/`NT4oj_1jQCooooo00?o0000ooooooooool07_ooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooRkOc00?oRkOc0_n7`_/3oig9mP?oV]Gl
1?n^eoD00on/hOWo_=_`okcKl002okcKl0;o`LgS0oo2d>D3oknofP?o_[kI00?o]J[=ok>Ub_ncYLX0
0_ncYLX5ok2Pa`04ojfKa?nTS[goY8jmojB>_@?oXHVj1?nOQKL4oif1]@?oVgjb0_nJNk000onDMJko
Tg>/oi=c[002oi=c[0CoTW:[0onBL:T3oi5_Z0CoTFjW0onBKZH4oi=^Y@OoU6jT0_nCKJ@2oi]j[@?o
000000?oVg^^oiYk/?nJNk000_nJNk04oiUm/`?oVH6h0_nc`^D5ojg;k`03ojG@m_n@IYkoSVJO00;o
SVJO0_n?J:42oi=WW0_oTVNM0onAIYd4oi1UW0CoSVBL0on>Hi`4oi1UW0?oTfRM1OnHK9h01?nKL:3o
ZH:ZojV2Z_nYPZX4ojEmY`GoXWVU0onOMZ<00onNM:?o]9ZmokBJ_@02okBJ_@Go/I>g0_n_S[<3oj;f
e0;obn;X0_n[PZT3ojJ1[0CoXH:b00?o[8N]ojN4[onWQ:l00_nWQ:l5oj:4/`;oWXNj00?o[YFlojVD
`OnYU<400onYU<44ojFGa`03ojnPb?n[Wl_oZio;00;oZio;1OnWX<l01?nTY=Go[:kIojb^fOl00005
ojV_g004ojNagon/^N?o[;WSojbih`GoZ[[U00?oZK_Wojc1jOn/`NT00_n/`NT2oj_1jP;oZl?[5?oo
ool00ol0003oooooooooo`0Mooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00_n;]o<3oijmkPCoWLWf00?oV]GlojkGmOn^eoD00_n^eoD3ok_Ck003okcKl?o1
cN?o`LgS00?o`LgS00?o`]3Uoknof_no_mX00ono_mX01?nn_]Wo]J[=okFZcOneZ/d4ok>UbP;o/:37
0_nWTl44ojB>_@?oXHVj1?nOQKL4oif1]@;oVgjb00CoUGN`oiAe[_nDMJkoU7F^1?nCLj`4oi9bZ`?o
TW2Y1?nAKjP3oi5^Y`?oTVjV1?nCKZD6oiA^Y003oiUi[_nKNZgo000000;o00001?nKNjh4oiYk/0Co
VGfc00?oVH6hok?2iOnc`^D00onc`^D2ojg;k`04oi9WWOn@IYkoT6JNoi1VWP;oSVJO1OnCIi`;oi9W
W@?oTFJM1?n@II`4ohiTW0?oSV>L1?n@II`4oi=XW@?oV6bN00?oYh:/ojV2Z_nYPZX00_nYPZX4ojEm
Y`GoXWVU0_nOMZ<00ongY/So]9ZmokBJ_@03okBJ_@Go/I>g00Go[hjcoj;fe?nRm]CoUfjRoiAbZ@04
oj^2Z@CoYX6/0_nQP[82ojb7[@CoYhB_1OnRQ;<01?nNQk[o[YFlojjE_?n^UK`5ojVD`@04ojFGaon_
X<So[j38ojnPb0GoZio;0_nWX<l2ok2_e`?o[:kI00Co0000ojb^fOnY[mcoZJoL0_n^^^85ojbih`;o
Z[[U0_n]`NT4ojc1j@03ojc5k?n[`n_oZl?[00?oZl?[4oooool2o`0001kooooo000Kooooo`05oa0@
4?ooooooooooooooool@41001_ooool2o`0000;ooooo1OnN_Nh2oig9mP?o[lc_00?o[]Oeok_Ck?nk
dn`00_nkdn`3ol3:hP?o`LgS0_o0`M/4oknofP03okR_d?neZ/go]J[=00;o]J[=0oncYLX00onZVLGo
Yi?1ojNC`@03ojNC`@?oY8jm1?nQRKX3oin5]`;oWH6e0_nFN[83oiEg/0CoU7F^0onCLj`4oi9bZ`?o
TW2Y1?nAKjP4oi5^Y`?oTVjV0onCKZD5oiA^Y0?o00001?nKNZd3oi]k[PGoVW^`0_nIOK<2okFig0Co
/l;U00Co0000oi9WWOnBIigoTVNM0on@IYh00on>IYooTfNLoi=WW004oi=WW0_oTVNM1?nAIYd3oi1U
W0CoSVBL0on>Hi`5oi1UW0?oTfRM0_nHK9h2ojN2[0CoZH:Z1OnUOJL4oj9iY@04oimfXongY/So]jK8
okNVb0Go]9Zm0onaTkL00onIKIkoUfjRoiM^XP02oiM^XPGoZh:Y1?nVPJ`00onQP[;o[8N]ojb7[@02
ojb7[@CoYhB_0onRQ;<00oncV;co[YFlojjE_002ojjE_0CoZIC100?o]JG9ojnPb?n_X<P00on_X<P3
oj^Ob`03okBceon`[mOo/:oG00?o/:oG0on/[]T00ol0003o[[[RojjjhP03ojjjhP;o[;WS0_n^`nT5
ojg1j@03ojc1jOn/aNco[<G/00;o[<G/0on[`n/00onZ`ncoooooooooo`0@ooooo`03o`000?oooooo
000001kooooo000Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`;oW[g^0on^`NP3ojo<k`Co^/_W00?o^m?/ol3:h_o0b^800oo0b^800oo1cN?o`<7Kol31f`02
ol31f`03oknof_nh[m3o^:o@00;o^:o@1?neZ/d01?ncYL[oZYW5ojZIaOnZVLD4ojNC`@CoY8jm0onQ
RKX2oin5]`03oiMm]?nFN[;oUWZb00;oUWZb1?nEMk03oiAe[PCoTg>/0onBLZ/3oi9`Z@CoTFnX1?nA
KZL3oi9^YP?oTfjU0_nDKZ@00onFN:oo0000o`000003oiUi[PCoVgZ]0onKNjh5oiYk/003oiUm/one
^Mco]KWL00;o]KWL00?o/l;Uo`000?nEJId01?nBIid2oi1VWP03oiAWW?nCIicoTfNL00KoTfNL2_nB
Iid4oi5VW@?oT6FL1?n>I9`3ohiSW0GoT6FL0onCJ9d00onHK9koYh:/ojN2[002ojN2[0?oZH:Z1OnU
OJL3oj9iY@03ok^lf_ngY/So]jK800;o]jK81OndV[d00onaTkOoVFfNoiU]WP02oiU]WP?oUfjR1On[
PZT4ojJ1[0Go[8N]1?nWQ:l00onRQ;?o/iRlok>H_002ok>H_0Co[YFl00?oZIC1okFUbOneYLT00_ne
YLT4ojnPb003oj^Obond/mOo];?G00;o];?G1?n`[mL01On/[]Wo/KkSok6nhona_^?o000000?o[[[R
0_n_an/4ojk3j@;o[L7Y0on/and4ojc5k003oj_3jonZ`ncoZ/?/00;oZ/?/5?ooool00ol0003ooooo
ooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0oooool5ojk1j003ojo<konjbnOo^/_W00?o^/_W00?o_lOPol3:h_o0b^800_o0b^82ol32f`?o`<7K
0_nj]=<4okR_d0?o]J[=00?o[Io9ojZIaOnZVLD00_nZVLD4ojNC`@CoY8jm0_nQRKX01?nIPKOoUgfd
oiMm]?nGOK@4oiIj/PCoUGN`0onDMJh4oi=c[0?oTW:[1?nBL:T3oi5_Z0CoTFjW0onBKZH2oi=^Y@05
oi=g/?l0003o0000o`000?nFN:l01?nINJh4oi]j[@CoVg^^0onJNk000onf]MSo]KWLokFig003okFi
g0?oUFVM0onBIid01?nDJ9coU6NLoiAWW?nDIi`8oi=WW0[oTVNM1?nAIYd3oi1UW0CoSVBL1?n>Hi`4
oi1UW0;oTfRM00?oXWf[ojN2[?nWPZ`00onWPZ`3ojV2ZPGoYGfW00?oXWVUok^lf_nk_=X00_nk_=X3
okNVb0Co]9Zm00?oW6jLoiU]W_nIKIh00onIKIh2oiM^XP;o/HNX1?n[PZT4ojJ1[0Go[8N]1?nWQ:l5
ok>H_0Co[YFl1OneYLT3ojnPb003okZkfond/mOo];?G00?o];?G0on`[mL2okG5iP?o/KkS00?o0000
ojjjh_n_an/01?n_an/2ojk3j@;o[<_`1On/and2ojc5k0;oZ/G]0onZ`n`00onX`^coooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`05ooooo`?o[/7X0onh`n83ok[;i`?o_lOP00?o`<[Rol32foo0`]/00oo0`]/0
0oo0`M_o^[CCokZdd`02okZdd`Co^:o@00Co]J[=ojfObOn]WlWo[Io90onZVLD5ojNC`@;oY8jm00?o
VhFkoiV1]onIPKL00_nIPKL3oiMm]0CoUWZb0onEMk03oiAe[PCoTg>/1?nBLZ/3oi9`Z@?oTFnX0_nA
KZL2oi1f/P?oTGJa0ol00005oiIh[`?oVGV^1?nKNZd4oi]k[P03oiYk/?nf]MSo][GH00;o][GH0one
^M`01OnGK9ooUFVMoiEYWOnEJIgoTVNM00?oU6RL0onDIi`8oi=WW0[oTVNM1?nAIYd4oi1UW0CoSVBL
0on>Hi`4oi1UW003oi=XWOnROJ_oXWf[00GoYh:/1?nYPZX3ojEmY`03okoVlOnk_=[o^kcJ00?o^kcJ
1?ngY/P01?ndV[goW6jLoia^W?nLKY`5oiU]WP04oiM^X_naQjSo/HNXok67Z0GoZh:Y0_nVPJ`2okB?
[`Co[8N]1?nWQ:l00onkXKko/iRlok>H_002ok>H_0?o[YFl0_nn/Lh5okFUb@04ojnPb?nj^m_o^[_K
okZkf`Go];?G00?o/:oGokG5i_neaNH00_neaNH2ok6nh`03ojo=kol0003o[lO[00?o[lO[00?oZm3c
ojc;l?n/bo000on/bo02ojc7k@;oZLS_1OnZaNd01?nZ`ncoZ<;/ojS2k?nX`^`Dooooo`03o`000?oo
oooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo00?o
[/7XokS3h_nh`n800onh`n800onjbnOo_lOPoko7h002oko7h003ol73g?o0`]_o`<;K00?o`<;K1_nj
]=<2okR_d003ok2UcOn]WlWo[Io900;o[Io91?nZVLD2ojNC`@;oWXZn1?nKQK/3oiV1]`?oUgfd1?nF
N[83oiEg/0CoU7F^0onCLj`4oi9bZ`?oTW2Y0_nAKjP5oi1f/P?o00001?nCMk04oiIh[`?oVGV^1OnK
NZd2oi]k[POo][GH00?o]KWLoiM/WonGK9l00_nEJId00onCJ9goU6RLoiAXW002oiAXW0CoU6NL1onC
Ii`;oi9WW@?oTFJM1?n@II`4ohiTW0?oSV>L0on@II`00onJMZWoXWf[oj9mZ`02oj9mZ`CoYh:/1?nY
PZX2ojEmY`?o_nKa1Onk_=X2okNVb0;oXW:M1?nLKY`4oiU]WPCo/HNX1On[PZT01?nVPJco]8n_okB?
[ondSjl5ojb7[@;oYhB_0_nkXKh5ok>H_004ojjE_?nn/Lko_[7>okjacPCo]JG900?o_L_TokZkfonj
^m/00onj^m/2okBce`;o]m7^1?neaNH00on^eOCo[lg_ojo=k`02ojo=k`03o`000?n_an_oZm3c00?o
Zm3c0_n/bo02ojS:lPGoZLS_0_nZaNd2ojS4kPGoZ<;/5?ooool00ol0003oooooooooo`0Iooooo`00
6oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01oooool4okS3hP;o
_/CN0onoan03ol73g0?o`<;K0_nl^ML4okZdd`03ok>/dOn`YLgo/:G=00;o/:G=1?n]WlT2ojZIa@03
oj6@`onNR[koWXZn00?oWXZn0onKQK/3oiV1]`?oUgfd1?nFN[84oiEg/0?oU7F^0onCLj`2oi9bZ`;o
T7Nc0on@Mk84oi1f/P?o00001?nAM[43oi=g/0CoUWR_0onINJh5oi]j[@03oi]k[_nf]MSo][GH00Go
][GH0_nGK9l2oi5WWP?oTfRM1?nDJ9`4oiAWW0OoTfNL2onBIid3oi5VW@CoT6FL1?n>I9`3ohiSW004
oi1UW?nJMZWoVWJYoiYfZ@CoXWf[1?nWPZ`4ojV2ZP03ojEmYonoi_7o_nKa00?o_nKa0_nk_=X2ojam
X@CoXW:M1?nLKY`3oiU]WP03okJ=ZonaQjSo/HNX00;o/HNX1On[PZT4okB?[`Go[8N]00CoYhB_ok^Q
__nkXKko^j6n1?ncV;`00oo8b]co_[7>okjacP03okjacP03okFUbOnmbnCo_L_T00;o_L_T0onj^m/2
ok?Sm`Co]m7^00?o]LGVojkEm?n^eO@00_n^eO@2ojo=k`;oYmGh00Co0000ojOEn?n[d??oZm3c0_nU
cO@4ojS:lP;oZLS_0onWa^l4ojS4kP;oZ<;/0_nV`>`Dooooo`03o`000?oooooooooo01Wooooo000U
ooooo`03o`000?oooooooooo00Sooooo00?o^<?Rokk4g_nna=h00onna=h00onoan3o`L?Lol73g003
ol73g003ol32fonl^MOo_;WG00;o_;WG00?o^[CCok>/dOnc[=400_nc[=43ok2Uc@?o[Io900?oY9O7
oj6@`onQT<<00_nQT<<4oij:_P?oVhFk1?nIPKL3oiMm]0?oUWZb1?nEMk02oiAe[P04oi1i]On@N;Co
T7Rdoi1h]0CoT7Nc0on@Mk801?n@M[;o0000o`000?l00003oi1f/PCoTGJa0onCMk04oiIh[`CoVGV^
0onKNZd00on`]]go][GHokJef004okJef003oiQ^X_n=IJ3oTFNN00?oTFNN0onCJ9d4oiAXW0CoU6NL
1onCIi`;oi9WW@?oTFJM1?n@II`4ohiTW0;oSV>L00?oTfjVoiYfZOnJMZT00onJMZT3oj9mZ`GoYh:/
0_nYPZX3oh?W`0;o_nKa0_nXNj84ojamX@CoXW:M1?nLKY`2oiU]WP?o]Xf[0onaQjP4oj^2Z@;o`J:i
0ondSjl4ojb7[@03olFcbOnkXKko^j6n00?o^j6n0_ncV;`3olS:g0?o_[7>0_nki?<4okg;i003okZk
fonchoOo/n?g00?o/n?g0_ngdNh3ojGNn`;o[]Gd0onNf_`2ojOEn003o`000?nQc_SoYLgd00CoYLgd
0_nXb_82ojG7l@GoYlK_0_nXa>h2ojK1k@CoY/3/4_ooool00ol0003oooooo`00000Jooooo`009Ooo
ool00ol0003oooooooooo`0:ooooo`?o_/CN0_o1a=`4ol73g0;o_[kJ0onl^ML00onf/mKo/jcAok>/
d@03ok>/d@Co/:G=00Co[Io9ojBGaonTUlOoY9O70onQT<<4oij:_PCoVhFk0onIPKL3oiMm]0;oUWZb
00?oTGbhoi5j]onAN[L00_nAN[L3oi1i]@?oT7Rd1?n@Mk<01?n@Mk;o0000o`000?l00007oi1f/P?o
TGJa0onCMk05oiIh[`?oVGV^00?oVgZ]ok2fgOn`]]d00_n`]]d3okJef004ohUTXOn=IJ3oSFFPoheU
X0CoTFNN0onCJ9d4oiAXW0CoU6NL1onCIi`;oi9WW@?oTFJM0_n@II`2ohiWXPCoSfZS0onCKZH5oiYf
Z@?oXWf[1OnWPZ`00onYPZ[oZ7VPojQiX002ojQiX0CoZ7^R1?n/OJ44oj9bW@CoW6jL00?oVFfNokJ=
ZonfSJ/00_nfSJ/4ok67Z0;oZh:Y0oo1X[T4okB?[`;o[8N]0oo5/lT4ok^Q_P03ok>H_?o8b]cob<[L
00?ob<[L00?o_[7>ok_Tlonki?<00_nki?<2okg;i0?oT^cd0_nchoL3ohgRo0;oYMkk0on@fol2oikJ
o0;oV/kj0onQc_P01?l0003oXLkhojG=m?nUcO@2oj;7lPGoYLOa0_nWa^l2ojG1k@GoY/7]0_nV`>`2
ojJok1Cooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`03okk4g_o1a=co`LCL
00;o`LCL00?o`L?Lokjnf_nn_]X00onn_]X01?nl^MOo][?FokJce_nf/mH5ok>/d@;o/:G=00?oYik<
ojBGaonTUlL00_nTUlL3oj6@``GoWXZn0onKQK/2oiV1]`04oi>1_OnBO[[oTWjjoi9n^P?oTGbh1?nA
N[L4oi1i]@?oT7Rd0_n@Mk<2o`0000?oT7Nb1on@M[84oi5f/@?oTgN`1?nFN:l2oiUi[P;oZ;ST1On`
]]d00onf]MSoRFBQohUTX@03oheUX0CoTFNN1?nCJ9d3oiAXW0CoU6NL2?nCIi`9oi9WW@04oi5XX?n?
Ij7oSfNQohmWX@CoSVNR1?n?JZ<4oi=^YPCoVWJY1?nROJ/3ojN2[0;oYGNO1?nXNJ03ojQkXP03okfD
[?n/OJ7o[7fQ00;o[7fQ1OnRLYd3oia^W0Go]Xf[1?naQjP00on[PZWo`J:iol6R^@02ol6R^@Co]8n_
00?o[8N]olFcbOo5/lT00_o5/lT3ok^Q_P;oa?S/1?o8b]`2ohCYi`;o^nCc0old^K82oi;/m0?oHMC_
0_n=h_`4og_EoP;oT=_o0_nCb_X4oi[>nP;oXLkh00?oWlGco`000?nOaO<01?nRao82ojG7l@;oY<7^
1OnU`Nd2ojK1k@;oYKk/1OnV_n`Cooooo`03o`000?oooooooooo01Oooooo000Tooooo`03o`000?oo
oooooooo00gooooo0oo1a=`3ol34g@?o_[kJ00?o^K_KokJce_nf/mH00_nf/mH4ok>/d@03oj^Vd_nW
W/coYik<00;oYik<0onTUlL4oj6@``CoWXZn0_nKQK/01?nDQL3oTh6moi>1_OnCPKd4oi9n^P?oTGbh
0onAN[L4oi1i]@;oT7Rd0ol00002oi1g/`?oT7Nb1on@M[84oi5f/@?oTgN`0_nFN:l3oiffjPCoZ;ST
0_n`]]d2ohUUX`?oRFBQ1?n=IJ03oi5WWPCoTfRM1?nDJ9`3oiAWW0SoTfNL1OnBIid2oi=ZX0?oTFRP
0on?Ij44ohiWXPCoSfZS1?nCKZH4oiYfZ@CoXWf[00?oYh:/ojEgWonUMil00_nUMil4ojQiX0;oZ7^R
0onmU:`3ojamX@GoXW:M0onLKY`5okJ=Z`Co/HNX1_o1X[T2okB?[`03om3Mh_o5/lWoaK?900CoaK?9
00?o^j6nolChk?o4n>`00_o4n>`01?o8b]coQ>WWohCYionBV=H5oh>[kPCoL;_m1?m_bol2og_EoP;o
S/;h1OnCb_X2oi[>nP;oW<7b0onOaO<01?l0003oWlGcoj;7l_nRao82oj:ok@CoY<7^0_nU`Nd3ojFm
j`CoYKk/0_nV_n`2ojJnjaCooooo00?o0000ooooooooool05_ooool002Cooooo00?o0000oooooooo
ool03_ooool00oo1a=co`<CMol34g@03ol34g@04okjnf_ni^m_o^K_KokVkf`Co][?F00?o/jcAoj^V
d_n[Y]800_n[Y]83ojNNc0CoY9O70_nQT<<00onHSlSoUXW4oiJ9a002oiJ9a0CoU8G00onCPKd3oi9n
^P?oTGbh1?nAN[L2oi1i]@?o000000?oT7Rdoi1g/on@Mk<00_n@Mk<4oi1g/PKoT7Jb0_nAM[42oi:[
i`CoTk3[1OnM]^X2ojRhi0;oRfNT0on9IJ<4ohUTX@?oSFFP0onAIih4oi=XW@CoU6RL0onDIi`8oi=W
W0;oTVNM00?oUVbQoi=ZX?nCJZ000_nCJZ03oi5XX0?oSfNQ1On>Ij83ohmZX`CoTfjV1?nJMZT4oj9m
Z`;oXGBO0onUMil4ojQiX003ojQkX_nmU:co_IB/00;o_IB/0on/OJ45oj9bW@;oW6jL0_nmVK<5okJ=
Z`;o/HNX0_oQgm85ol6R^@04okB?[oo@gN;od=gRom3MhPCoaK?90onGU<h2ogVTk@;oWi341?nBV=H5
oh>[kP;oL;_m0_nGZn@4oi6hl@CoS/;h0_nCb_X2oi^jkPGoW<7b0_nOaO<00ol0003oX[c/oj:ok@04
oj:ok@;oY<7^0_nT_>X5ojFmj`;oYKk/0_nU_N/4ojJnjaCooooo00?o0000ooooooooool05Oooool0
02Cooooo0ol0000?ooooo`Co`<CM00?o^lCPokVkfoni^m/00oni^m/2okJceP;o[ZkH1?n[Y]84ojNN
c0;oY9O700?oViC<oiR?b?nHSlP00_nHSlP3oiJ9a0CoU8G00onCPKd3oi9n^P?oTGbh0onAN[L3o`00
00;oT7Ve0on@N;@3oi1g/`CoT7Nb0_n@M[800onCWmcoTZCQoi:Th@02oi:Th@CoTZ_W1?nC/>/2oiff
jP?oSV^V0on;Ij@3ohUUX`CoRFBQ0on=IJ03oi5WWPCoTfRM1?nDJ9`4oiAWW0OoTfNL00?oTVNMoiI/
XOnFK:401?nCJZ04oi5XX0?oSfNQ1?n>Ij83ohmZX`CoTfjV1OnJMZT2oj9mZ`?oXGBO0onUMil4ojQi
X0Go_IB/1?n/OJ44oj9bW@04oia^W?nmVK?o_IVcokfI/`Go]Xf[00Co/HNXon7Od_oQgm;ohMoB1?o1
X[T2ofGE/PCod=gR00?oaK?9ojJ>_?nGU<h00_nGU<h00on[T;[oWi34oin@a003oin@a0CoTYSF0_n3
Znh2oj2RePGoUj_T0_nA^?400onPZMgoW;7VoibaiP03oibaiPCoVk[^0_nL`O82oj6hj0?oX[c/00Co
0000oj:lk?nR_ngoX[o]0_nT^^P5ojBljP;oYKg[0_nV_>T5ojFmj`CoY[k[4_ooool2o`0000Wooooo
1?l000000ol@413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03ol34gOnk
a>3o^lCP00;o^lCP0oni^m/00ona^=ko[ZkHojj^f003ojj^f0CoZjKB0_nWW/`00onNVm7oViC<oi^D
c002oi^Dc0?oV8o81?nFRL@3oiB5`0?oTh6m1?nBO[X2oi5l^0?o000000?oTGZgoi1i]On@NKD00_n@
NKD3oi1h]0;oT7Nc00?oTYOEoi>Kf?nCVmP00_nCVmP4oi>Og0CoTZCQ1?nBZnL2oi>`j`?oTFnX0on>
JjH4oh]WY0?oRFFS0on9I:43oheUX0CoTFNN0onCJ9d4oiAXW0CoU6NL1_nCIi`01?nHKZ7oUVbQoiI/
XOnFK:44oi=ZX0CoTFRP0on?Ij44ohiWXPCoSfZS0onCKZH5oiYfZ@03oj9mZonQM9ooXGBO00;oXGBO
0onUMil4ojQiX0Go_IB/1?n/OJ43oj9bW@03olBbb?nmVK?o_IVc00;o_IVc1OnfSJ/00ol0003ohMoB
on7OdP02on7OdP03ol6R^OmUeK;oIMFb00?oIMFb0_o@gN84ojJ>_004oiNDc_n[T;[oZi2joj^@^PGo
Wi340_nBV=H00onYW<WoX:;Foj2ReP03oj2ReP;oUj_T0_nUXm<4oj2Yg@GoW;7V0_nK^^h2oj>ci0Co
XKSX0_nR_>`00onU]nKo0000ojFgiP04ojBjj0;oY;cZ0_nV^nP5ojJlj@;oYKg[0_nV_NX5ojJnja?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`Co
^lCP00Co^K_Kok6hg_na^=ko/KSN1On^[]P2oj^VdP03oj6SeonNVm7oWY_A00;oWY_A0onKU<`3oiR?
b0CoUXW41?nDQL03oi>1_@;oTWjj0ol000001?nAO;SoTGZgoi5j]onAN[L2oi1i]@;oSi7A0on@U=<4
oi:Ge@CoTi_H1?nCWm`4oi:Th@;oTZ_W0onDM:`3oi5_Z0?oSV^V1?n;Ij@3ohUUX`?oRFBQ0on=IJ04
oi5WWP?oTfRM1?nDJ9`4oiAWW0CoTfNL0onHKZ44oiI/X@?oTfZP1?nAJ:03ohmWX@CoSVNR1?n?JZ<4
oi=^YP?oVWJY00?oWW:Poj5dWonQM9l00onQM9l4ojEgW`;oZ7VP0_oWf<H4okfD[0Co[7fQ0_nRLYd3
olBbb0?o_IVc1?nfSJ/2ok27ZP03o`000?oQgm;ohMoB00CoXWn]1OnbTK<3ojJ>_003okFF]on[T;[o
Zi2j00;oZi2j1?nOT<@00onaWL;oZIc9ojVLb@02ojVLb@?oX:;F00?o[:7<ojFSdonUXm<00onUXm<4
oj2Yg@;oW;7V0_nU[]h5oj>ci0;oXKSX0_nU/n<2ojFgiP03o`000?nU]nKoYKOV00;oY;[X0_nV^NH4
ojJkj0;oY[cY0_nW_>T5ojJmjP;oY[k[0_nW_n/Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04oooool2ok_4h0;o/l;U1?na
^=h2ojj^f0;oXjcM1?nQXmL3oijKd@?oViC<1?nHSlP3oiJ9a0CoU8G00_nCPKd3o`000004ohb>d?n=
S]3oSHk@ohf>d0?oSXo@1On?TM43oi2Dd`?oTYOE1OnCVmP2oi>Og003obbd/_nLPKGoW86e00CoUgZ`
0onDM:`4oi5_Z0?oSV^V0on;Ij@3ohUUX`?oRFBQ0on=IJ04oi5WWP?oTfRM1?nDJ9`4oiAWW0;oTfNL
00?oVW6SoiQ^XOnHKZ400_nHKZ44oiI/X@?oTfZP1?nAJ:03ohmWX@CoSVNR1?n?JZ<4oi=^YP03oiYf
ZOnNLZ3oWW:P00;oWW:P1?nQM9l4ojEgW`04ojQiX?oWf<KoimS6onOHaPGo_IB/0on/OJ400onRLYgo
a;;8olBbb002olBbb0Co_IVc0_nfSJ/00onYQZoo/8NZok27ZP03ok27ZPCoXWn]00?o^IJcok:A/onb
TK<00_nbTK<2ojJ>_0?o]IJg1?n[T;X01?nOT<Co/Ig2ok6M`_naWL85ojVLb@04oj2Re_n/XLco[:7<
ojbQc0CoYJ?C0_nPZMd3ojZ/f0CoYJkN0_nS/n@2ojRag`GoYK?S0_nU]nH00ol0003oZ;SUojJiiP04
ojJiiP;oY[_X0_nW^nL4ojNlj@;oY[gZ0onX_^X4ojNoja?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`Co/l;U0_na^=h2ojFei0CoXjcM0onQXmL4
oijKd@?oViC<0_nHSlP01?n?U]KoSY?CohjCdon>Tm<4ohf@dP;o000000?oSHo@ohb>d?n<S]000_n<
S]03ohf>d0?oSXo@1?n?TM43oi2Dd`CoTYOE0_nCVmP3odO8e0;oXHVk0onLPKD3oiMj/0CoU7B/0onA
KjP3ohi[YP?oRfNT0on9IJ<3ohUTX@?oSFFP1?nAIih4oi=XW@?oU6RL0onDIi`01?nJLjKoVW6SoiYa
XonJLJ<4oiQ^X@CoUVbQ1?nCJZ03oi5XX0?oSfNQ1?n>Ij84ohmZX`?oTfjV0_nJKj44oiibX0CoXGBO
1?nUMil01?nXNJ3oimS6onOHa_oWf<H5okfD[0;o[7fQ00?oZ^gholBbb?o4//P00oo4//P4okfI/`04
okJ=ZonYQZoo^Y:^okZB[PGo/8NZ0_nROjd2okVF/`Co/Y6c00?oYXjlokFF]oneU[L00_neU[L4oj^@
^PGo/Ig20onYW<T00oneYLSo[:7<ojbQc002ojbQc0?oYJ?C00?o/:_CojZ/f?nZ[=P01?nZ[=P2ojF^
gP03oj^`fonX/MooZ;7O00?oZ;7O0onU/n<01_nY]n;oZ;SUojRhiOnX^>Go0000ojRhi@?oY[WV00?o
Z;[VojNkionW^nL00onW^nL2ojNlj@;oZ;kY1OnX_^X2ojNoj`;oZ<3[4oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP05ooooo`?o00005_ooool2ok?2i@?oY[o/0onU]N@4oj>/g@?oXJ?G0_nN
Vm401?nBX=goTI_Ioi6KfOnAVmT4ohnFeP?oSY?C0ol000001?n=T=;oSHo@ohf?d?n=Sm03ohb>d0?o
SHk@1?n>Sm04ohnAd@?oT9CC0_nBUmD3oe[Aj`;oYi?10onQRK/3oib1]@?oUgZ`1?nDM:`3oi5_Z0?o
SV^V0on;Ij@3ohUUX`CoRFBQ0on=IJ03oi5WWPCoTfRM0onDJ9`01?nDIicoVW>VoiYcY_nJLjH3oiYa
X`CoV6jQ1?nFK:44oi=ZX0?oTFRP0on?Ij45ohiWXP?oSfZS00?oTfjVoiY_XOnJKj400onJKj43oiib
X0CoXGBO1?nUMil00onXRkKo0000onOHaP02onOHaPCo_IB/00Co[7fQoj[]n?nZkOSoZ^gh1Oo4//P2
okfI/`03ok28ZonYQZoo^Y:^00;o^Y:^1On`QjX01?nROjgo^IJcokVF/oniU[<4ok:A/`Go]IJg0on[
T;X2okfT`@Co/Ig200CoZIc9okFUb?neYLSo]JG81On/XL`01?nUXm?o/:_Cok2[don`Zm<4ojZ/f003
ojnafOn[/=_oZk3K00;oZk3K1?nX/Ml00onU/n?oZKORojVghP02ojVghP?oZ;SU00?o0000ojJii_nX
^^H00onX^^H3ojNki`03ojVmj?nX_^WoZ;kY00?oZ;kY0_nX_^X2ojRojPGoZ<3[4Oooool3o`0000Oo
oooo00?o0000ooooooooool02Oooool000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06?ooool4ojJok0?oYKGT0_nS[=d01?nF[NKo
U:KRoiBVh_nDY^84oi:Pg@?oTI_I0on?U]H3o`000004ohjCdon=T=;oSI3Bohf@dP?oSHo@1?n<S]03
ohf>d0CoSXo@0_n?TM43og;>o`;oJ=;i0on]WLL2ojNC`@04oiEh/On@LZgoT7:]oi1b[@?oSFfZ0on:
JJL4ohUWY@?oR6JT0on7IJ@3ohITY0?oRFFS1?n9I:43oheUX0?oTFNN1?nCJ9d2oiAXW003oiUfZOnJ
LjKoVW>V00;oVW>V1?nJLJ<3oiQ^X@CoUVbQ1?nCJZ03oi5XX0CoSfNQ1?n>Ij82ohmZX`;oV6jQ1OnJ
Kj43oiibX0GoXGBO0onUMil5ojf4Z@;o_IB/00CoZ7fTojAhXonTN:?oY7RS0_nZkOP5olBbb003okfI
/on`R:_o/8R[00Co^Y:^1On`QjX5okVF/`;o/Y6c0_o5Yk`5okFF]`04oj^@^_nmY<7o_JC1okfT`@?o
/Ig200?o_Jk;okFUb?neYLP00oneYLP3ojbQc003okF_d_n`Zm?o/:_C00?o/:_C00?oZZcHojnafOn_
/MT00_n_/MT4oj^`f`;oZ;7O0_n/]n44ojVghP;oZ;SU00?oZ[[Uo`000?nZ^^D01?nX^^H00onW^nOo
ZKgXojVmj002ojVmj0?oZ;kY00?oZKoZojRoj_nX_nX00onX_nX2ojS0j`;oZL7[3_ooool4o`000003
ooooool0003ooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool2ojJok003
oiJklOnF]>coU[C/00;oU[C/0onF[NH3oiBVhP?oTZ3M0onAVmT3o`000003ohnFe_n>Tm?oSY?C00;o
SY?C0on=T=83ohf?d0;oS8k@0_mo]oP5ogbno0?oNLKo0_mbc_l3ok:Wc@;o[Ig700CoVGneoiEh/OnE
N;7oUGRa0on@LZd3ohe]ZP?oRVVW1?n9IjD3ohQVY0?oQfFT0on6I:@3oh=TYP?oPFFY00CoRFBQoheU
X?n=IJ3oSFFP0onAIih4oi=XW@03oiAXW?nIMZWoVGJY00CoVW>V1?nJLJ<4oiQ^X@?oUVbQ1?nCJZ04
oi5XX0?oSfNQ1?n>Ij800on?JZ?oV6jQoiQ^X@02oiQ^X@CoVVnQ0onNLZ05oj5dW`;oYGNO00?o/8b`
ojf4ZOn]Q:T00on]Q:T4ojQmY0?oY7RS0_ncS:`2olBbb003ok><[?n`R:_o/8R[00;o/8R[1?njTZh4
ok27ZP;o`jFk1?niU[<01?nbTK?oaJNlolFW_?o5Yk`4okFF]`03olBbb?nmY<7o_JC100?o_JC100Co
/Ig2okf^bonm[/_o_Jk;1?neYLP00on/XLco]JoBokF_dP02okF_dP?o/:_C00?o]KOJojnafOn_/MT0
0on_/MT2oj^`f`;o[kWP1On/]n42ojVghP;o[;_U0onZ^^D01?l0003oZ[[UojRji_nX^^H2ojZnj0Co
ZKgX00?oZ;kYojVoj_nY_nX00_nY_nX2ojRojPOoZL7[2_ooool3o`0000Gooooo00?o0000oooooooo
ool00oooool00omEEEGoIVIVo`00000;ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`;o00006oooool3oiJkl@CoU[C/0onF[NH3oiBV
hP;oTZ3M0ol00002ohBYk@?oPjW^1?n2Znl3oh6]l@?oP;7d1?mo]oP2ogbno003okZif?ng/=?o]k3C
00?o]k3C0_nbYld2oin7^P?oVGne1?nEN;43oi1b[@?oSFfZ0on:JJL3ohUWY@?oR6JT0on7IJ@3ohIT
Y0?oPfBV1?n1IJT3ohAY[@?oRg2^1?nCM:d4oiUfZ@?oVW>V1?nJLJ<4oiQ^X@?oUVbQ1?nCJZ04oi5X
X0?oSfNQ0_n>Ij83oiI]X@CoV6jQ1?nJKj43oiibX0GoXGBO00CoYGNOok2</?n`S;3o/8b`1?n]Q:T4
ojQmY0;oY7RS0_nfU;<5ok><[0;o/8R[0_o:[;/4okZB[P;o/8NZ0oo3YK/4okVF/`CoaJNl0oneU[L2
olBbb0Co_JC100?obLGGokf^bonm[//00_nm[//3okFUb003okfieOne[m;o]JoB00Co]JoB00Co/:_C
okFgf_ne]m[o]KOJ0on_/MT00onb_>;o[kWPojnih003ojnih0;o[;OQ0_n^_ND5ojbki@;oZ[[U00?o
ZkkXo`000?nZ_^P01?nZ_^P2ojVmj0;oZL3Z0onY_nX8ojW1j`;oZ<7[1_ooool4o`0000Sooooo00?o
0000ooooooooool04Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Kooooo`?oU[_a0_nF]>`00on8/o;oQk3`
ohN`l002ohN`l004ohN]kol0003o0000o`0000;oQJ_^1?n4ZNd3oh>YkPCoPZ__0on1[O43oh2am0;o
OkOh00?o`N?`ol?Tkonj^MP00_nj^MP3okN`d`03ojB@_onOQk[oWhNj00;oWhNj0onIOkD4oiEh/@?o
T7:]0on=KJX3ohYYY`?oRFNU0on8IZ@4ohMUY0?oQVBT0on3I:H3oh5UZ@?oQ6V]0on;L:h4oi=d[@Co
VGJY0onJLjH4oiYaX`CoV6jQ1?nFK:43oi=ZX0CoTFRP0_n?Ij42oiA/X@GoUVfQ0onHKZ44oiY_X@Co
WW:P0onQM9l00onaU[[o/8b`ok2</002ok2</0Go[HBY0onXOJ@01?nTN:?o]YBcokJD/onfU;<5ok><
[004ok28Zoo:[;_obZbkolZ/^`Co^Y:^00?o/8NZol>U^oo3YK/00_o3YK/4okVF/`03om;7coo5Ykco
aJNl00;oaJNl00?o]IJgolBbb?o4//P00_o4//P2okfT`@?obLGG1?nm[//01?neYLSo_KWEokfieOnm
^MD4okF_dP03okW0gone]m[o]KOJ00?o]KOJ00Co[k7Iok:lh_nb_>;o/[cR0on_^N000on``NOo[[gU
ojjmi@03ojjmi@;o[;_U0_n/`>T3oj^nj004o`000?n[_^SoZ[kXojZnj0;oZ/7Z1OnY`>X00onY_n[o
ZL7[ojW1j`06ojW1j`CoZ<7[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool3ohRfm0?oR;?b00CoQk3`o`000?l0003o00000on7[Nl3ohF[kPCo
Q:W]0on3ZNh2oh:[k`;oBL?_0_l000000onElNWo`N?`ol7Sl002ol7Sl0;o_;oL1?nj^MP01?ng/=?o
Y92oojB@_onTT;l3oin7^PCoVGne0onEN;43oi1b[@?oSFfZ0on:JJL3ohUWY@?oR6JT1?n7IJ@3ohIT
Y0?oPfBV0on1IJT4ohAY[@?oRg2^1?nCM:d3oiUfZ@CoVW>V0onJLJ<4oiQ^X@CoUVbQ0onCJZ02oi5X
X0?oTf^Q1?nDK:44oiI]X@?oV6jQ1?nJKj44oiibX0;oXGBO0onaU[X3ok2</0Go[HBY0_nXOJ@00oni
X/;o]YBcokJD/`02okJD/`Go/hb/1?o:[;/4okZB[PKo`jFk0_niU[<2om;7c`CoaJNl1Oo4//P00onm
Y<7obLGGolW5e`02olW5e`?o_Jk;0_o0b>44okfie@03okF_d_ni`=oo^L3O00;o^L3O0_ne]mX2okG4
iPGo/[cR00Co[kWPok31ion``NOo/<7W0on^_ND2ojc3jPCo[<3Y0_n[_^P00onZ`^_o0000oj[2j`04
oj[1jP;oZL3Z0_nY`^/4ojW1j`03ojW2k?nY`N_oZL7[00?oZL7[1?nX`N/00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01kooooo0on8]_@00on8
/o;o0000o`000002ohN`l0?oNkWj0omf_?`4ofnooP?oIl;n0_mJa?X2od33eP;oWNod1?nmh?400oo1
ho3o_;oLokbog002okbog0;o^[WH00?oZIS5ojB@_onTT;l00_nTT;l4oin7^P?oVGne0onEN;43oi1b
[@?oSFfZ0on:JJL4ohUWY@?oR6JT0on7IJ@3ohITY0?oPfBV0on1IJT4ohAY[@?oRg2^1?nCM:d3oiUf
Z@CoVW>V1?nJLJ<3oiQ^X@CoUVbQ0_nCJZ02oi1YX@GoTf^Q0onDK:44oiI]X@?oV6jQ1?nJKj44oiib
X003oj5dWonaU[[o/IJj00;o/IJj0on`S;05ojf4Z@04ojQmY?niX/;o^J;2okVR`P?o]YBc1?ncS:`0
0ooKiMcobZbkolZ/^`03olZ/^`;o^Y:^0_o<aM@5ol>U^`04okVF/ooBalood/O?om;7c`?oaJNl0_o;
e>03olBbb0;o`nW`1Oo9aML00onm[/_o`<SQol38h@02ol38h@;o_KWE0_nkdNX3okW0g`;o//k^1?ne
a>H2ok:lhP;o/<O[1On``NL00on^_NGo[<?Zojc3jP02ojc3jP;o[<3Y0_n[a>`3oj[2j`04o`000?nZ
`^_oZ/7Zoj[1jP;oZL?/1?nY`^/00onY`N_oZL;/ojW2k002ojW2k0;oZL7[0_nX`N`5ojS1ja3ooooo
00?o0000ooooooooool04?ooool002;ooooo0_l0000Pooooo`?o00001Omo]_L3og^inP?oM[cl0_m_
_oh3ofW>o0;oElg_0onRjO/00onMkoCo_N3aokgPl@02okgPl@;o_<?O0onl_m`00on^XL[oZIS5ojVH
a@02ojVHa@?oY92o1?nOQkX3oiUo]@CoUGRa0_n@LZd3ohe]ZP?oRVVW1?n9IjD3ohQVY0?oQfFT0on6
I:@3oh=TYPCoPFFY0on4JJd3oh]`[PCoTgB]0onIMZT4oiYcYPCoVW6S0onHKZ42oiI/X@?oSFJP1?n@
JJ44oi=[X@?oU6bQ1?nFKJ43oiQ^X@GoVVnQ0onNLZ000onaWlKo/IJjok6F^P02ok6F^PCo/8b`0on]
Q:T00ong^mco^J;2okVR`P02okVR`PCo]YBc0_ncS:`3om_Ug0CobZbk00Co^Y:^olc5e?o<aMCoc<GD
1?o3YK/00on_n^;od/O?om;7c`03om;7c`03olFW_?o;e>3obmCP00;obmCP00?oa;;8ol?Yl?o3jO00
0_o3jO02olW5e`;o]N;f1?o0b>400on[h_[o^m7Zok_AjP03ok_AjP03okW0gonbc^ko//k^00;o//k^
0_nea>H2ojk?l@Co/<O[0_n``NL3ojc7k@;o[<?Z0_nZa^h5oj_4k0;oZ/;[00?oZLC]o`000?nY`n`0
1?nY`n`2ojW2j`;oZ<;/0onY`^`2ojS2k0CoZ<7/1?nX`N/@ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01cooooo0ol000001?ooooooP[Ceoh:dmOn2]?D2ognfm`?oQ;gi
1?mna?d2ogK:o`?oQMWo00?oMmgfoj;YnonRjO/00_nRjO/3ok[Ll@03okgPlOnl`moo_<?O00?o_<?O
00Co_;oLojjQb_n^XL[o[Z7:0onYV<D4ojB@_`?oWhNj0onIOkD4oiEh/@?oT7:]0on=KJX3ohYYY`?o
RFNU0on8IZ@3ohMUY0?oQVBT0on3I:H4oh5UZ@?oQ6V]0on;L:h4oi=d[@CoVGJY0onJLjH4oiYaX`;o
V6jQ0on8Hj04oheVX0?oT6VQ1?nCJj43oiA/X@CoUVfQ0onHKZ45oiY_X@;oWW:P0_naWlH5ok6F^P?o
/8b`00Co[HBYokNkg?ng^mco]k_L1?niX/84okJD/`03ok><[?oKiMcofnGL00;ofnGL0_o:[;/3ohg]
k0Coc<GD00?o`jFkojojh_n_n^800_n_n^82om;7c`?oRnc[0_o;e>04od;4`@;o`nW`0omXfNh3okGR
mP03ol38hOn[h_[oZn;j00;oZn;j0_nkdNX3ojKHn@;o//k^0_nTe?T5ojk?l@;o/<O[0_nYbo43ojc7
k@;oZ<Wa1?nZa^h2oj_4k0;oZ<G^0onYa>d01?l0003oZLC]ojW3k?nY`n`2ojS3k@GoZ<;/00?oZL;/
ojS2k?nX`^`00_nX`^`4ojS1k0CoZ<7[3oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0
003oooooooooo`0Iooooo`?o00001_ooool3ohVgm0CoQ;gi0_mna?d3ohk@oP;oQMWo0onUh?/3okOF
l0;o^]ca0onlaN83okc3g`03ok6Ycon^XL[o[Z7:00;o[Z7:0onYV<D4ojB@_`?oWhNj0_nIOkD00on=
NKSoRGBfohUd]P02ohUd]P?oQG6d0on=KJX3ohYYY`?oRFNU0on8IZ@4ohMUY0?oQVBT0on3I:H3oh5U
Z@CoQ6V]0_n;L:h4oi=d[@CoVGJY0onJLjH3oiYaX`?oPenP0on8Hj04oheVX0?oT6VQ1?nCJj43oiA/
X@CoUVfQ1?nHKZ44oiY_X@04oiibX?naWlKo/Io6ok6OaPGo/IJj0_n`S;02ojONnPCo]k_L1?niX/82
okJD/`03ojfD_?nZU;ooZYBo00;ofnGL1?nSUlT00onaVl7oZIc8ohg]k002olc5e0?oW:;H00?o[Yk7
oinNdonOW]<00_nOW]<5ohFTj0?oC:Gh0_l>U=d2ofSIkP?o9:gI1?m/eoH2oj_RnP?oR=So0_nVf?T2
oi3DoPCoY=Ci0_n^co42oj?>mPGoZL_a00?o[<O]ojS9lOnXbO400_nXbO42oj[6kP;oYlK`1?nXaNh2
ojW4k@03ojO4k_l0003oZ<?]00CoZ<?]2?nX`^`00onW`NcoZ<7/ojS1k003ojS1k0;oZ<7[00?oYl3[
ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Foooo
o`?o00002_ooool3ohVgm0;oQ;gi0onCaOP2ohk@oPCoY]Gh00CoYN3kokOFl?nge_3o]mK`0_nka^<5
okc5hP04okc3gonaZLoo/JW?ok6Yc`Co[Z7:0onYV<D2ojB@_`04oiN6_onBOk_oTWnkoi9o^`?oSGVh
1?n9M;H3ohEa]0?oPfnd0on0KkH3ohUWY@?oR6JT1?n7IJ@3ohITY0?oPfBV0on1IJT4ohAY[@?oRg2^
1?nCM:d3oiUfZ@?oVW>V00?oVW6SogaKXOmlFj400on3Gj03ohQSX0CoSFJP0on@JJ44oi=[X@?oU6bQ
1OnFKJ43oiQ^X@?oVVnQ0_n/Y<l4ok6OaP;o/IJj0omWf^L4ojONnP?o]k_L0_niX/82ojRF``04ojFL
c?n]U;co[IBlojfD_0CoZYBo00CoXiO9ok6K`OnaVl7o/I_11OnYW<P01?nLX]So[Yk7ojjNaon^W/L4
oinNd`;oQJCX0_nTYMH5ohjYj0?oK:oh1?mD^?/3oe_4n`;oR=So0ommc?l4oi3DoP;oY=Ci0onJc_X3
oj?>mP;oZL_a0onTbo@2ojS9l@;oY<Ob1OnWa_02ojS5kP;oY/G_0onWa>h00ol0003oZ<?]ojS3k@02
ojO2k@KoZ<;/1?nW`N`2ojS1k0;oYl3/1?nW`>/>ooooo`03o`000?oooooooooo013ooooo000Roooo
o`;o00005?ooool3o`0000kooooo1?nF^o42oi?5n0CoY/Wb0_nVeOP3okG?k@03okOFl?nka^?o^lKS
00;o^lKS0_nlaN82okB`e0Co/JW?0on^XLX01?nRU/SoW8g3oib=`onLSL<4oiN6_`?oTWnk0on=NKP3
ohUd]P?oQG6d0on3Kk@3oh1_]P?oP76i0on2Mkh4ohMUY0?oQVBT0_n3I:H3ohRYjP04oeFnn_n=Ij;o
SFNRoheWXP;oQUnM0_n0FI/4oi=d[@;oVGJY00CoKU:QoeIC/_mhFJ;oN5VR0omlFj43oh=OX0CoR6>P
0on=IZ03oi1YX@CoTf^Q1?nDK:44oiI]X@?oV6jQ00?oVVnQojBQd_n/Y<l00on/Y<l2ok6OaP;o0000
0onSULL01?nRV<[oYY2nojJ@__nVT;h4ojRC_`?oZ9K300?o[Y>kojfD_?n]U;`00_n]U;`4ojZD_`Go
/I_10onYW<P00ondWl;o[Yk7ojjNa`02ojjNa`?oWikC00?o[j?<ojBUe_nTYMH00onTYMH2ohjYj0;o
Y:OH1?nDZnH4oh6dm@CoL[gm0_mmc?l2oh[1n@CoSLSl0_nJc_X2oiS7m`GoWL[g0_nTbo@2oj76l`Co
Y<Ob0_nWa_02ojG5l0GoY/G_0_nWa>h00onW`nko0000ojO2k@03ojO2k@;oZ<;/1OnW`N`7ojO0k0Co
Yl3[3Oooool00ol0003oooooooooo`0@ooooo`008Oooool2o`0001;ooooo0ol0000Booooo`;oU[_a
0_nV_n`4ojK9lP;o//SZ0onecnd2okW6i0?o^lKS00?o][KIokB`e?nd/=@00ond/=@4ok6Yc`04ojjQ
b_nRU/SoXYK8oj:Fb0?oW8g30onGQ[l3oi9o^`?oSGVh1?n9M;H2ohEa]0CoPfnd0on0KkH3oh1a^@;o
PWNn1?n7P/L4ohfBd`?oR:WZ00?oUG:YoheWX_n=Ij800_n=Ij83ohIOW@;oP5VK1?mhE9/2ofiBX@;o
EU>b00CoN5VRogaKXOmlFj7oO5^Q0on3Gj04ohQSX0?oSFJP0on@JJ45oi=[X@?oU6bQ1?nFKJ42oiQ^
X@?oY:7B0_n/Y<l2oj>HbPKoXiG700?oXhjnojJ@__nVT;h00_nVT;h4ojRC_`03ojRF`on^Tk_o[Y>k
00;o[Y>k0on]U;`3ojZD_`;o/i^o1?naVl401?nYW<So]9o2okBO`_ndWl85ojjNa`04oinNdon_Xlco
[j?<ojnSc0?oY:GF00?o/JO?ojBWf?nTYmP00onTYmP4oiB[iP;oPKCe0_nI/>L4ohfglPCoR/7i0_n=
b?`2oiC0m@CoV<Og0_nMb_L2oig4l`GoXLKc0_nTao82oj?4l0CoYLG`0_nVaNl2ojK3kP?oYl?^00?o
0000ojO3k_nW`^d00onW`^d3ojO1k0SoYl3/1onW`>/<ooooo`03o`000?oooooooooo013ooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`CoY[o/00?oY/Wbok;8j_nbb>X00onb
b>X00onecngo^LKTokW6i002okW6i004ok_6honf]]Wo][KIokJff@Go];3D0_naZLl00onVW/goXYK8
oj:Fb002oj:Fb0?oW8g30onGQ[l3oi9o^`?oSGVh1?n9M;H3ohEa]0?oPfnd0on0KkH3oh1a^@?oPWNn
1?n7P/L4ohfBd`04ohRYj_nELZWoUG:YoiEbZ@?oSFNR0on6Gid3oh1IV`?oN5BK0om^DZ42oeIC/PCo
O5^Q0_n3Gj04ohQSX0?oSFJP1?n@JJ44oi=[X@?oU6bQ0_nFKJ44oi^Dc0;oY:7B00?oYZ7@oj>Hb_nS
V<X00_nSV<X2oj>Ea`;oX8bo1?nSS[h3ojJ@_P?oZ9>o00?o[9>lojjC^on^Tk/00on^Tk/4ojfD_004
ojZD_oncVkoo/i^ook>K_`Co/I_11OndWl83ojjNa`03okRVaon_Xlco[j?<00?o[j?<00CoY:GFok6W
conaYloo/JO?1?nTYmP2oiB[iP;oYZgL1OnI/>L2ohfglP;oWK;W1?nG^Nl4oiC0m@;oV<Og0_nL`?44
oig4l`;oXLKc0_nQ`_05oj?4l0;oYLG`0_nU`^h4ojK3kP;oYl?^00?oY/7]o`000?nW`^d01?nW`^d0
0onW`NcoYl3/ojO0k004ojO0k0[oYl3[3Oooool00ol0003oooooooooo`0?ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03?ooool3o`0001Wooooo0_nV_n`4ok72i`;o//SZ0_nha>@3okW6i0;o]k_L1?nf]]T2
okB`e0;oZjKB1?nVW/d3oj:Fb0?oW8g31?nGQ[l3oi9o^`?oSGVh0on9M;H3ohEa]0?oPfnd0on0KkH3
oh1a^@?oPWNn1?n7P/L3ohfBd`;oOFJ^0_maG:/01?nELZWoSFNRoheWX_n=Ij83ohIOW@?oP5VK0omh
E9/3ofiBX@CoEU>b0_mlFj43oh=OX0?oR6>P1?n=IZ03oi1YX@CoTf^Q0_nDK:44oi23`@;oViC<00?o
C/ZlojJQd?nVXM000_nVXM02oj>HbP03oif;`?nPS;ooX8bo00;oX8bo1?nSS[h4ojJ@_P04ojRC_on/
Tkco[9>lojbC_0Co[Y>k0on]U;`00ondWL3o/i^ook>K_`02ok>K_`?o/I_10_niX/84okBO`P03ojjN
aonhY/Oo^:K700;o^:K70on_Xl`00ongZL_o/JO?ok6Wc`03ok6Wc`;oY:OH0_n_Zm@4ojJ]g0;oVK3W
0_nU[ml5oifbi`;oUkW_0_nQ]^P3oibkkPGoW<3a0_nMa?<2oj2ok`CoXL;`0_nSa?02ojC1kPGoYL;^
0_nV`nh5ojK1k@03o`000?nW`^goYl;]00GoYl3/0_nW_n/7ojO0j`;oYko[1?nW`>/<ooooo`03o`00
0?oooooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo
0_l0000:ooooo`?o00007Oooool4ok72i`;o]l?S1?nha>@00onia^Co]k_LokNkg002okNkg0;o][KI
00?o[ZgGoj^Vd_n[Y]800on[Y]83ojJNc@CoXYK80onLSL<3oiN6_`?oTWnk0on=NKP3ohUd]P?oQG6d
1?n3Kk@3oh1_]P?oP76i0on2Mkh4ohN2a`04ohfBdommIZkoOFJ^ogeV[P?oLEb[0on=Ij83ohIOW@?o
P5VK0omhE9/3ofiBX@CoEU>b0_mfIK83oh=OX0?oR6>P1?n=IZ03oi1YX@;oTf^Q1?n8M;H3oi23`@;o
Q^W]0on^/MX2ojJQd003oiZ;`onMRl3oWH_000;oWH_01?nPS;l3oj>>_P?oYY2n00?oZI:nojbC_?n/
Tk`00_n/Tk`5ojjC^`04ojfD_?ndWL3o]9g0okBM`0Co/i^o00Co/I_1okVR`_niX/;o^J;20ondWl80
0onkZLOo^:K7okRVa`03okRVa`03ojnSc?ngZL_o]jW;00;o]jW;0onaYll00onh[]3o[j_Dojn[e003
ojn[e0;oYZgL00?o[joHojF_gonU[ml00onU[ml2oifbi`;oY[?R1OnQ]^P3oibkkP;oW<3a0_nQ_>`5
oj2ok`;oXL;`0_nS_nd4ojC1kP;oYL;^0_nU`>`7ojK1k@03o`000?nV`>coY/3/00;oYl3/1_nW_n/2
ojO0j`OoYko[1?nW`>/;ooooo`03o`000?oooooooooo00oooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Kooooo0ol0
000Qooooo`03ok72iong`n?o]l?S00?o]l?S0_nha>@2okRog`?o]k_L00?o/KGKojj]eon^[ML00_n^
[ML5oj^VdP?oYYk=0_nRU/P01?nGT/goTXc:oi:<b_nBS<X3ohb7b@?oQhC80on3Pl/3ogn6d0?oNXkK
1?n3Kk@3oh1_]P?oP76i0_n2Mkh4oiJ3_0;oR7:d1?mmIZh2og5LZ`;oKEZ[00CoSFNRohIOWOn6Gigo
QUnM0on0FI/3ogQDV`CoKU:Q0_mFDk83ogIU/P?oMV:_0on8Hj04oheVX0;oT6VQ1?n2J:`3ohQd]P04
oi23`On6jNgoQ^W]oibHcPCoVHk71?nJRl<3oif;`0CoX8bo1?nSS[h01?nVT;koZI:nojVB__nYT[h3
ojbC_0Co[Y>k00?o/ik3okBM`?ndWL000_ndWL03ok>K_`03okZVa_niX/;o^J;200?o^J;200Co]9o2
ok^YaonkZLOo^jW70onhY/L00onm[lco]jW;okNYb`04okNYb`04ok6Wconh[]3o^:k@okR^d0?o[j_D
00?o]K7Dojn_f?n_[mP00_n_[mP3ojF_g`03ojfbg?nV/n;oY[?R00?oY[?R0_nQ]^P2ojNfh`CoXkSX
1?nQ_>`2oj2ok`;oXkc[1OnS_nd2ojC1kP;oYKk/1?nU`>`2ojK1k@?oY[o[0_nV`>`00ol0003oYko[
ojNoj`0@ojNoj`GoYl3[2_ooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`03ooooo`?o
00009_ooool3okO3h`;o^<?S1?nh_ml01?ng^mco/KGKok6efona]M/4ojj]e`;oZjKB0_nQXMD3oibJ
d0CoUi;=0onBS<X3ohb7b@?oQhC80on3Pl/3ogn6d0?oNXkK1Om`Wnd01?m<]?Wo/ZcBok:/d_nb[=83
ojBFa`?oUX>l0on8L[@3ogeV[P;oLEb[0om]FZ/3ohIOW@?oP5VK1?mhE9/3ofiBX@03oeIC/_nek_Ko
QWZo00;oMVFb0omfHZl2ogaY/P04ohETY?n=IZ3oSFJPoh1PX`CoOf6V0on2J:`2ohQd]P;oY]gk1?nL
V<h4oiV>a`?oVX_30onMRl04oj2<_`;oXhjn0_nUTL04ojVB_PCo[9>l00Co[Y>kok>N`oncW/?o/ik3
1OndWL001?ncVkoo^ZK6okZVa_njY/H4okVR`PGo^jW700Co^:K7okf_c?nm[lco_Jo<1?ngZL/00onl
/]3o^:k@okR^d003okR^d004ojn[e?ne/MCo]K7DokFae0Co[joH00CoYJoOojfbg?n]/]co[K;L0onV
/n800on/]MooYkKSojNfh`03ojNfh`CoXkSX0_nQ_>`2ojFjj0CoXkc[0_nS_nd2ojFmjPGoYKk/0_nU
`>`2ojJnj`?oY[o[0_nW_^X2ojNoj`03o`000?nW_n_oYko[013oYko[1?nW`>/:ooooo`03o`000?oo
oooooooo00oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0005ooooo`04o`000?ooooooooooooooo`?o0000:_ooool00ong`n?o^<?SokS3h`02okS3h`;o^;oO
0_nc_>04ok6ef`;o[ZgG00?oYJWIoj6QeOnQXMD00onQXMD3oibJd0?oUi;=0onBS<X3ohb7b@?oQhC8
0on3Pl/3ogn6d0CoNXkK0_m`Wnd3okk2g@;o/ZcB00CoUH:lohYe]_n:MKKoRWFf0onFPk`3ohQb]0?o
OFJ^0omaG:/2ofeJZ`;oKEj`00CoQUnMoh1IVon0FI_oP5VK1?mhE9/2ofiBX@;o]Nkf0_n6N[l3ogIU
/P;oMV:_0omlJK83oh1PX`CoOf6V0_n2J:`3oj:ci@03ojKMnonUZm_oYJ_K00?oW9S>1?nIS/L3oiZ;
``CoWH_00_nPS;l00onQS/7oYI70ojFA`003ojFA`0?oZI:n0on/Tk`00on`X<Oo/ik3ok>N``03ok>N
``?o]9g000?o^J_<okZVa_njY/H00_njY/H3okVR`P;o_Jk<1?nkZLL5okf_c003okNYbonl/]3o_;;@
00;o_;;@0onh[]000onk]]Co]K7DokFae003okFae0;o[joH0_nc]=T4ojfbg004ojJch_n/]Moo[;GO
ojbeg`CoYkKS0_nS^>P2ojNhi@GoYK[X0_nS_>/2ojJkj0CoYKgZ0_nU_^`2ojJmjPGoY[k[00?oY[o[
ojNnj_nW_^X00_nW_^X2ojNoj`03o`000?nW_n_oYko[00ooYko[1OnW`>/9ooooo`03o`000?oooooo
oooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005
ooooo`Co0000;_ooool3okS3h`03okC3iOnc_>3o/kcP00?o/kcP0_na]M/00onY/MkoYJWIojFYf@02
ojFYf@CoXJ7E0onLV]04oiNBc@?oTXc:0on<QlT3ohN4b0?oPh?;0omoQ]02ogZ>f`?oa=?V0_nn`]d0
1?nPT<?oUH:loiF2_?nEP[`3ohYe]P?oPFbb0_mgIK401?n8L[CoOFJ^ogeV[_mmIZh3og5LZ`;oKEZ[
0om]G[03oh1IV`CoN5BK00?oKU:QokG^m_nek_H00_m]G:d01?n6N[ooMVFbogIU/_mfIK83ogIR[`;o
O6Vb0on5Mk`5oiB@c@?oX[?U00?o^LkZojF[fonUZm/00_nUZm/3oibHcPCoVHk70onJRl<2oif;`003
oib;`OnQS/7oXHk100;oXHk11?nUTL04ojVB_P04ojbC_?n`X<Oo/:37ok2Pa`Co/ik300Co]9g0okV[
c?niZlco^J_<1OnjY/H01?niX/;o_Jk<okf^c?nm[/`3ok^Ya`;o_kGA1?nm[l`5okbbd003okR^d?nk
]]Co^kKD00;o^kKD0one/M@00onh]mWo/kCIok>df@03ok>df@;o[K;L00?o/KKMojbegon/]Ml00on/
]Ml2ojNfh`;oZkOR1?nW^>D2ojFjj0;oZ;[V1OnV^nP2ojFmjP;oYkcX1?nV_NX2ojJnj`?oYkgY0_nW
_^X2ojNnj@;oYkkZ00Co0000ojNnj_nW_n_oYko[0_nW_nX=ojNoj`;oYl3[0_nX`>/9ooooo`03o`00
0?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`04ooooo`;o0000<Oooool01?nh`n?o]<?UokC3iOnd`nD3ok>lh003oj^ihonY/MkoZK7N00;o
ZK7N0onUZMT5oj6Qe@?oW9[@0_nGT/d01?n=X>7oR:3SohRPhon8X><4oh:Sj@?oO:cb1?mb^o`00omI
b?Ooa=o/olCOk002olCCiP03ojZOc?nPT<?oX93300;oX9330onEP[`2ohYe]P?oPFbb0omgIK44ogeV
[P;oLEb[0om]FZ/2ofeN/0?oNW:n1_nIX=T01?mgHjkoKEb]ofeL[Om]G:d3ogIU/P?oMV:_0omlJK83
ohEg_0GoU93=00CoX[?UokW>j_nic^[o^LkZ0_nUZm/01?n?Q/GoSh?2ohn3`_n?Pl84oi:4`@?oUXO1
1?nLRl43oj6>`@CoYI700onYT[h00on]XL_o/:37ok2Pa`02ok2Pa`?o/ik300?o]k7CokV[c?niZl`0
0oniZl`3okZVaP03okbed_nm[/co_Jk<00?o_Jk<00Co^jW7oknedOno]M7o_kGA0onm[l`2okjie@?o
_;;@00?o_K_Hok^fe?nk]]@00onk]]@00one/MCo^;OIokRgf@02okRgf@?o/kCI00?o]KWLok6fgOna
]]d00_na]]d2ojbeg`;o[kSP1On[]n82ojNhi@;oZkWT1?nX^^H2ojJkj0;oZ;_W1OnW_>P2ojJmjPGo
YkgY00?oZ;gYojNnjOnW_^T00onW_^T2ojNnjP03o`000?nX_^[oYkoZ00?oYkoZ0_nW_n/2ojRojPOo
Yko[0_nX_n/4ojS0j`Sooooo00?o0000ooooooooool03oooool002;ooooo00?o0000ooooooooool0
;oooool4okC3i@04ok>lh?n[^N?oZkWSoj^ih`CoZK7N0onUZMT2oj6Qe@;oUjOQ1?nCXn03ohfPh@?o
R:3S1?n2XnT3ogb/lP;oL[_l0oo4gn`00onb[]CoZYo<ojZOc002ojZOc0?oX9330onEP[`3ohYe]P?o
PFbb0_mgIK43ofeS]P03ogeV[_maG:_oLEb[00?oKEZ[0om]G[03ogYb_PCoVJ3I0omgHjh2ofeL[@;o
Iene0_mfIK82ogIR[`?oO6Vb0on5Mk`4oiB@c@;oYZSG0onGTL`4ohn6a@?oSh?20onBQ<44oiJ7`@?o
W8_10onQS/45ojFA`004ojVB__n]XL_o[J7;ojfQb`Co/:3700Co/ik3okNadong/M?o]k7C1?niZl`0
0onjY/Ko_;GBokbedP02okbedP?o_Jk<00?o_KgIoknedOno]M400ono]M400onm[lco_[WEokjie@02
okjie@04okbbd?nm^mSo_K_Hokfkf0?o^kKD0_nj_M/4okRgf@03ok>dfOne^Mco]KWL00;o]KWL0_na
]]d2ok:jg`Co[kSP0_n[]n82ojfihPGoZkWT0_nX^^H2ojZkiPCoZ;_W0_nW_>P2ojRlj0KoYkgY0onX
_NT2ojNnj@;oZ;kY0onX_^X01?l0003oZ;kZojNoj_nW_nX6ojRojP;oYko[1onX_n/3ojS0j`Wooooo
00?o0000ooooooooool03_ooool002?ooooo00?o0000ooooooooool0;oooool2okC3i@;o[L7Y1?n[
^N<2ojVagP03oinci_nL[N?oW:gS00?oW:gS0onGYn44oi>Sh0?oSJ3Q0on8X><2oh:Sj@;oBlSV0_nF
lNP3ol3Tl@04olCOk?nb[]Co/ZkDok:^e0?oZYo<0onPT<<3oiF2_0?oRWFf0on1K;83ogMU/@?oKF>f
0_mGIlL00omaG:_oKEZ[ofeJZ`03ofeN/0?oNW:n0onIX=T01?nAO;SoMf>^ogMS[_mgHjh2ofeL[@Co
Iene0_mfHZl3ogaY/PCoQGNl00?oU93=ojJXeonVZ=L00_nVZ=L4oiNAc0?oShK50on?Pl84oi:4`@?o
UXO10onLRl44oj6>`@;oYI700_nYX<h4ojfQb`?o/:3700?o/kGJokNadong/M<00_ng/M<3okV[c0;o
^KcL1?nl]M800onm[/co_KgIokfmf@02okfmf@;o_kGA0_nm`=`4okjie@03ok_3gonm^mSo_K_H00?o
_K_H00?o^kKDokZmfonj_M/00_nj_M/2okRgf@;o^;gN1?ne^M`00ona]]go/[[Ook:jg`02ok:jg`;o
[kSP0_n`^n84ojfihP;oZkWT0_n/^n@5ojZkiP;oZ;_W0_nZ_>L4ojRlj0;oYkgY0_nX_NP3ojRmj@Ko
Z;kY0_nX_^X00ol0003oZ;oZojRojP08ojRojPKoZ;o[1_nX`>/8ooooo`03o`000?oooooooooo00ko
oooo000Tooooo`03o`000?oooooooooo02oooooo1?n]`NT2oj^ih`;oXKWY0onO/nH5oib]h`?oUjOQ
0_nCXn02ohNmn@CoO<Cn0_m/c?h00ombh>WoU_7XoiKaj003ol3Tl@;o]k[L1?nb[]@4ojZOc0?oX933
0onEP[`2ohYe]P?oPFbb0omgIK43ofeS]P?oEfO70om]FZ/2ofeN/0CoNW:n00?oVJ3Ioi5l^?nAO;P0
0omgHjh3ofeL[@?oIene0_mWN]801?mfHZooO6VbogaY/_mlJK82ohEg_0?o`/oT1?nVZ=L3oiNAc0?o
ShK50on?Pl84oi:4`@?oUXO11?nLRl42oj6>`@03ojBNconYX<koZJ3>00?oZJ3>1?n]XL/01?n`X<Oo
/kGJok>ef_nc]MX4okNad`03okV[c?ni_=co^KcL00;o^KcL0_nl]M82okW5h`?o_KgI00?o]lOVokg0
g?nm`=`00onm`=`00onn^MGo^l?Ook_3g`02ok_3g`?o_K_H00?o^/?QokZmfonj_M/00_nj_M/00onh
`n;o^;gNokRmgP03okRmgP;o]KWL0_ne_^43ok:jg`03ok:nhon`^n;o/;_R00?o/;_R0_n]^N82ojjl
i0Co[;_T0_nZ^nH2oj^liPGoZ[cW0_nX_>P2ojVmj0CoZ;gX00?oZ;gYojRnjOnX_^T01_nX_^T2ojRo
jP03o`000?nX_n[oZ;oZ00SoZ;oZ0_nX_n/:ojS0j`Oooooo00?o0000ooooooooool03_ooool002Go
oooo0_l0000`ooooo`;o[L7Y0_nR_^d4oj6ij@?oWk?V0_nL[N<3oi:il@CoSK[d0on7_OT2ogc4oP;o
Omkk0_nFkO@2ok[Sl`03okW3h_ng^]co]k[L00?o]k[L1?nb[]@2ojZOc004oiN?b_n<Q<KoS8C6ohb4
aP?oPWc40on:MKH3oh5//P;oMfFa1?m]HkH4oeMWa`04o`1`com]G[3oKEj`ofeN/0;oNW:n0_mjM<42
ofmX^P03oi5l^?mgHjkoMf>^00?oKEb]0omWGkD3ofMjdP;oO6Vb0_mWaoh00ooEm^Co`/oTol;?i002
ol;?i0?oYZSG1?nGTL`3ohn6a@?oSh?20onBQ<44oiJ7`@;oW8_100?oWi[?ojBNconTW/l00_nTW/l4
ojVPcP;o[J7;0_n_^>05ok>efP;o]k7C0_nd`^D3okVlg0;o//c]1?niaN<01?nm_MWo]lOVokO7i_ng
anH3okg0g0;o]lWX1?nk`ml00onm^mSo^/?Qok[3h@02ok[3h@03okZmfonh`n;o^<?R00;o^<?R0onh
_Mh00one`^Co]KkQokFnh@03okFnh@04ok:jgonb_^?o/[kSok:nh`?o/;_R00?o/;kTojjli?n^_>@0
0on^_>@2ojbki0;o[KgV1?n[_>H2ojZli`;oZkgW1OnY_NP2ojRmj0;oZKkX0_nX_^T2ojVnj@GoZ;kY
0_nX_nX00ol0003oZ;oZojRojP05ojRojP;oZ;o[3OnX`>/6ooooo`03o`000?oooooooooo00kooooo
000Wooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj6ij@?oV;_`0onF^O04oi:il@;oSK[d0on=
cOd2ohSFo`;oUnKl0oncgoH01?njho?o^L?RokW3h_ni`n85okNjg0;o/ZkD00?oX9_?oiN?b_nGSlX0
0_nGSlX3ohb4aP;oPWc40omgMlD3oh5//P?oMfFa0om]HkH3oeMWa`?o]kgN1?nIULh2ogYd`@?oKfRj
0omgHjh2ofeL[@CoIene1?mWN]801?mWaokoeOKTomGfi?oEm^@2ol;?i004oifRf?n=SLooSHg?ohf=
c`CoR8G:0on9Q<P3ohf8b@?oThk<1?nIU<h4oinJc`CoY9k?0_nYX<h2oj^ii0Co[kSP0_nc]MX2ojk7
k0Go]<;U00?o^KcLok;<kOnbc>d00_nbc>d2okW5h`;o/<k_1?nganH00onm`=co]lWXokO9j002okO9
j0;o^l?O0_neb>P3ok[3h@;o]LSX1?nh`n800onh_Mko]L;TokG2i002okG2i0;o]KkQ0_nc`ND5ok:n
h`04ok2kh_n`_^Co/;kTok2ni0;o[[cT0_n^_^H5ojfmiP;oZkcV0_n[_^L4oj^mi`;oZKgX0_nZ_^P3
ojVnj0;oZKoY1?nY_^T2ojRnj@;oZKoZ0onX_nX00ol0003oZ;oZojRojP02ojRojPGoZ;o[3?nX`>/6
ooooo`03o`000?oooooooooo00kooooo000Xooooo`03o`000?oooooooooo02kooooo0_nR_^d3oiZl
l0CoV;_`0onF^O02oi:il@?oTLKi0_n=cOd3oiSLoP04oiOVo?ncgoKo/mofok?OmP;o^<SW1?ni`n82
okNjg0;oYjKD1?nPVll3oiN?bP?oS8C60on2O<@2ogMga@?oLW_<0om_SMl3ofeS]P04oeMWaoo<gnOo
c=oWolcOi`?o]kgN0onIULh2ogYd`@?oKfRj0om[Ik`3ofeL[@?oIene0_mWN]800onVmNko/?:/omGf
i002omGfi0;o/l;U0onMX]P3ohf=c`?oR8G:1?n9Q<P3ohf8b@?oThk<1?nIU<h4oinJc`;oY9k?0_nW
^>D4oj^ii0;o[kSP0_nZb_44ojk7k0;o]<;U0onZdO@2ok;<k@;oY]7f1On`c^l2okO7iP?o[/ka0_ng
bNP2ojo=l0Co]LSX00?o^/?QokG8j?neb>P00_neb>P2okS3hP;o/lKX0one`^@2ok;5j0Co/l7U0_nb
_^<2ok31iP?o/;kT0_n_`NL4ojjniP;o[KgV0_n/_nL5oj^ni`;oZkgW0_n[_^P4ojZnj003ojVnj?nY
_nWoZKoY00;oZKoY0_nY_^T6ojVojP;oZ;oZ00?o0000ojS0j_nX_nX00onX_nX2ojRoj`ooZ<3[1Ooo
ool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`CoV[c`0_nH^o02
oiJnl`CoU<;f0_nAa_T3oiWCo0;oV=cn0on^fOH00oncgoKo^<SWokS8i`02okS8i`;o^L?R00?o[JoI
ojNVe?nWY]@00onWY]@3oj2Kc`?oUho:0on<Q<H3oh9la0?oMgO50ombNl`4ofn=g`05og[5o_o<gnOo
c=oWolcOionXXm400on?QlL3ogad_`?oNWC10om_J;X2of]W_0?oMgk=0_mWGkD3oiZfj`04ok3g_Oo?
olkocNCXolgTj0Co/l;U0_nMX]P3ohf=c`CoR8G:0on9Q<P3ohf8b@?oThk<1?nIU<h2oinJc`;oXkCT
1OnW^>D2oj^ii0;oYlcc1?nZb_42ojk7k0?oXm?i0_nZdO@2oioCnPCoY]7f0_n`c^l3ojGAm`;o[/ka
0_nUc_D5ojo=l0;o]LSX0on^bnl2okG8j0;o[lW]1?nca^P00one`^Co//GXok;5j002ok;5j0;o/l7U
0_n`a>P4ok31iP03ok2ni?n_`NOo[l7W00;o[l7W0_n^_^H2ojg0j0Co[;oW0_n[_^L2oj^oj0GoZkkX
0_nZ_^P2ojZoj@;oZKoY2OnY_nX01_nY`>[oZ<3ZojS0j_nX`>[o0000ojS0jP;oZ;oZ4onX`>/4oooo
o`03o`000?oooooooooo00kooooo000Zooooo`;o0000<Oooool3oiVll0CoU[kc0_nD`_H3oi[:n0;o
VM?l0onZd_D2ojkImP?o]L[Z0_nhb>L00on`]mko[JoIojf_f@02ojf_f@CoYjKD1?nPVll3oiN?bP?o
S8C60on2O<@2ogMga@CoLW_<0_m_SMl3om7ci`04olcOionXXm7oZ:?AojRSd@?oShO70_mlM;l2ofMX
_`04ogYd`Om_J;[oKfRjofmX^P?oJfNl0omgO/d3oiZfj`03ok3g_Oo=i>SocNCX00?ocNCX0_nc`^D0
1?nFV]KoRH_?ohV;con9Rll3ohf=c`?oR8G:0on9Q<P4ohf8b@?oThk<0_nIU<h2oij]hPCoXkCT0onW
^>D00onVbo?oYlccojO<l`03ojO<l`;oZ/[a0onPeOX2oj?Cn@;oW=Ck1?nOdoX2ojKAmP?oWM7j0_nU
dOL2oik?n@CoYLke0_n_cO03ojO=m0;o[/__0_nXbo85ojo9k@;o/lKX0_n^b>`2ok;5j0;o[/K/1On`
a>P2ok31iP;o[/?Y0on_`NL00on]`^Wo[L3Xojg0j003ojg0j0;o[;oW0_n/`NT4oj^oj0;oZkkX0_nZ
`>T3ojZoj@;oZ/3Z1_nY_nX6ojW0jP;oZ<3Z00?oZ<3[o`000?nX`>/05OnX`>/3ooooo`03o`000?oo
oooooooo00kooooo000/ooooo`03o`000?oooooooooo02oooooo0onI_?02oiJnl`?oVl?c0_nJb_P3
ojO;l`;oZ];e0_nbbN`3okG:jP03ok:lhOn`]mko/;ON00;o/;ON1?n][mT2ojNVe003oi^KdonCTm7o
Ti?A00;oTi?A0on;S]43oh2;e@CoN9;P0_mYZ?D2og9kc003oc^mh_nEkK[odO?W00;odO?W00?o_<3M
ojRSdOnXXm400_nXXm43ohn7a`?oO7Bo0_mWJ;l3ofmX^P?oJfNl1?mgO/d01?nJ]^_o/?NmomKhhOoF
n>42olgTj0;o[kKN0onFV]H3ohV;c`?oPXG=0on3Qll3ohV?d`04ohV4b?n=R<WoSHS9oi2If0CoV:CM
1?nN[N83oj>di003ojNhiOnVbo?oY/_c00;oY/_c0_nWc?<3oj3Fn`;oX=Gj0onKeO`4oicDn`;oWm?j
0onId_/2oigAnP;oV/kj1?nNcoT2ojG>m@?oWlgg0_nWcO@2oj;;m@CoZ<_b0_n_bNd2oj[9l0?o[/S/
0_nZanl4ojk6k0;o/<CX0_n]aN/5ojk3j@04ojo1ion]`^Wo[L;Yojg2j@;o[L3X0_n/`^X5ojc1j@;o
ZkoX0_n[`NT4oj[0j@03ojZojOnZ`>[oZ/3Z00;oZ/3Z0_nY_nX8ojW0jP;oZL3[0onX`>/00ol0003o
Z<3[ojS0j`0DojS0j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0
;oooool4oifmk`;oVl?c0_nVaNl3ojO;l`;o[lO/1?nbbN`01?neb^[o/[cQok:lhOnb_>44ok2ggP;o
[JoI00?oXZ?Foi^KdonKVm<00_nKVm<4oi>Cd@?oRhkA0on0RmD4ogRBh0;oJJSe00?oS>g[olGhk?o5
n>`00_o5e^L3okc0g@?oZ:?A0on?QlL3ogad_`;oIfRo0omUMLh01?m_J;[oJfNlof]W_?m[Ik`2ogMn
c@04ogCRgoo0o<;oe_SQomKhh@;oaMGV1?n_]]h3oiJJeP?oRH_?0on2QLd3oh>7c`?oRHoC1?n@VMP4
oiRTg@;oWZgR0_nS`o04ojG9lP;oY/_c0onQeo/2oj3Fn`?oW]Kk0_nKeO`2oi_Cn`CoVM;l0_nId_/3
oiW>nPCoV/kj0_nNcoT3oic<n0;oWlgg00?oW/[foj;;mOnRboD00onRboD2ojS;lP;oY<Wc1?nZbO00
0on^b>coZ/O_oj[7k`02oj[7k`;o[/K/0_n[a^h4ojg5j`;o[/?Y0on/a>/2ojg2j@;oZl?[1?n/`^X2
ojc1j@;oZl7Z1On[`NT2oj[0j@;oZ/7Z0_nZ`>X2ojW1j`OoZL3Z00?oZL7[ojW0jonY`>/00onY`>/2
ojS0j`03o`000?nX`N_oZ<3[00GoZ<3[0_nX`N/=ojS0j`?ooooo00?o0000ooooooooool03Oooool0
02kooooo00?o0000ooooooooool0;oooool2oifmk`;oYKo/1?nVaNl00onWbo?o[lO/ojo7k002ojo7
k0;o//W/0_na_n@4ok:lh@;o/;ON00?oYj_Ioj:Se_nRXmH00_nRXmH3oi^Kd`CoTi?A0on;S]44oh2;
e@;oN9;P0_n;e_l00on5j];oaOS/olGhk004olGFi`?o_<3M0onXXm43ohn7a`;oO7Bo0omWJ;l3ofEe
cPCoMjSa00Co_?W/ol3l`_oFn>7oe_SQ1?o5eNH3ojnfgP?oUY[F0on9Rll3oh:5c@?oPhO?1?n9Sm<4
oi2If0;oV:CM0_nO^nd4oj?3l0;oYLWb0onSe_X5oj7Gn`;oW]Kk0onOe?X3oi_Cn`;oVM;l0onKc_T2
oiW>nP;oVl_h1?nJboP2oic<n0;oW<Wg1?nNb_H2oj;;m@?oX<We1?nTbO<2oj[9l0?oY/Sa0_nZanl0
0onWao3oZlK^oj_6kP03oj_6kP;o[LG[0on[aNd2ojc4j`;oZ/C]1?n[`n/2ojc2jP;oZl;[1?n[`NX2
oj_1j@?oZ/7[0_nZ`NX6ojW1j`;oZL3Z1_nY`N/2ojW0j`GoZ<7[00Co0000ojS1jonX`>_oZ<3[1_nX
`N/2ojS0j`?oZ<7[2?nX`>/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooo
oooo02oooooo1?nU_n`2ojK5k`?o[LC[0_n_an`2ok31iPCo/KoT0_nb_>42oj^ag@?oYj_I1?nRXmH3
oi^Kd`;oTi?A00?oSJ?SohVYj_n9ZNX00_n9ZNX5ohNhmP03oh_Foonjm?;o^_Cb00;oa^C]0oo5e^L0
1?n^]=koWJ7GoifQeonMXML3ohb>d0?oMgg=0omlM;l2ofMX_`CoIGG>00CoMjSaokcik?nlnNco[O[O
0_o@o>42om;[iP;oaMGV00CoZKKRoiNOf_nGWm[oUioJ0on6SmD3oh6;e004ohV;con2QLgoPXG=oh:5
c@?oPhO?0on9Sm<2oi2If0;oVK3W1OnO^nd2oj?3l0?oY=Ch0_nSe_X3ojCHnP;oXMOk0_nReOT2oioD
nP;oXLoh1OnNcoT2oi_>n@?oW/_g0onKboP2oi[;n0?oW<Sf0onLbOL2oik:mP?oW/Oe0_nPbOD2oj37
l`CoX/Oc0_nVb?42ojC7l@CoYlO`0_n[a^h3ojS6k`;oZlG]0_nXaNh5oj[4k@;oZl?[00?oZ/?/oj_2
jon[`^/00on[`^/2oj_1jP;oZ/;[0onZ`N/00onY`^_oZL7[ojW1j`0=ojW1j`WoZ<7[00?o0000ojS1
jonX`N/02onX`N/8ojS0j`;ooooo00?o0000ooooooooool03Oooool0033ooooo0_l0000`ooooo`;o
YKo/0_n/`NT3ojg4j`;o/<7W1?n``NH2ok6oi0;o[KOP1?n[/Md3ojN[f@;oXZ?F00?oVJOOoiBTgonD
Y=l00_nDY=l3ohfSh`CoRJWZ0_n7^?H2oh_Xm@;o^_Cb1?o6i>d01?o5e^Oo[[CNojjdg_n^]=h3oifQ
e`?oS8k@0_mgOLd3og=nd0?oNY7N0_mUMLh2oiO6m`;o[O[O0_o@o>42om;[iP03oko>i_nY]^;oZKKR
00;oZKKR0onGWmX3ohJ?e@?oPH_D0on3S]H3ohRGf`CoTJCQ1?nI/>L2oinkk@?oY<of0_nTe?P3ojOH
n@;oY=Sj0onVe_T2oj;En@;oY=3g1?nQcoP2oik?n@?oX<_f0_nNboL2oj37m0GoW/Oe0_nLb?H00onN
a_CoWLKeoig6m@03oig6m@;oW/Oe0_nOa_<4oj37l`;oX/Oc0_nRa_84ojC7l@;oYlO`0onVa_02ojS6
k`;oYlG_1?nXaNh2oj[4k@;oZ<C]1?nZ`n`2oj_2j`;oZL?/1OnZ`^/01?nZ`N_oZL;[ojW2jonY`^/2
ojW1j`;oZL;/1onY`N/00onX`NcoZ<7[ojS1j`09ojS1j`03o`000?nX`N_oZ<7[00KoZ<7[00?oZ<7/
ojS1jonX`N/00onX`N/8ojS0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo
02kooooo1?n/`NT00on]a>_o/<7Wok31i`02ok31i`;o/<7V0_n^^n<4ojfgh0;oZk7M00?oY;3Qoin[
gonOZml00_nOZml3oiVWg`CoU:CO0on=Xn<2ohVYjP?oSMSo0_n/joT3okcXl`;oa^C]0_nhaN@4ojjd
gP?oWJ7G0_n<S]03ogMmc@?oLgk@1?mjTMh00onGa_Oo[O[Oojgjg`02om3lh@;od^_V0onoc^H4ojVf
hP?oUioJ0_n6SmD4oh6;e0?oPhkF0on8Um/4oi6Th@;oVK3W0onQao<2ojC?mP?oZ=Kh0_nWf?T3ojSG
n0;oY]Ki0_nWdOH4ojC@m`;oXLoh0onSbo@2oj3;mP;oX/Oc1?nPao@2oik7m@;oX<Gc1?nNa_@2oig6
m@;oWlGc1OnOa_<2oj37l`03oj75l_nRa_;oX/Kb00?oX/Kb0_nTao43ojC5l@;oY/K`00?oYLG`ojO5
konWaNl00onWaNl2ojS5kP;oYlC^1?nXa>d2oj[3k0;oZ<?]1?nY`n`2oj[2j`?oZL;/0_nY`^/2ojS2
k0CoZL;/0_nY`N/2ojS2k0CoZ<7/0_nX`N/2ojS1k0OoZ<7[00Co0000ojS1k?nX`N_oZ<7[1_nX`N`4
ojS1j`OoZ<3[00?oYl3[ooooool000003oooool003?ooooo00?o0000ooooooooool0;_ooool2ojc1
j@?o[/7X0_n``NL2ojnniPCo[[_S0_n]]n000onW]N?oY;3QojB`h@02ojB`h@CoWj_O0onIYml2oiBT
g`;oTk[b1?n>aOX00on=f?oo[>_iojc[n@04okcXl`03ok[?j_nhaNCo^<GT00?o^<GT0_n^]=h01?nK
W]KoRi7Doh^Ae?n;TM@3oh2;e0?oMgg=0omcO]02ogZAgP;oX>3l0_o7mn`2om;eiP;obn7X1?noc^H2
ojVfhP04oiJQg?n:UMWoRYGIohZEf@?oPI3I0on1Rm@4oh>>eP?oR9OK0_nAY>43oi^kk`;oXLOc0_nW
dOH3ojSFn0;oZ]Og0onXeoP2oj[Bm@CoYm7f0_nTd?L3ojG<m0;oXl_d0_nTb?84oj;7l`;oX<Od0_nR
aO44oj35l`;oW/Kd0onQa?83oio5l`;oWlKc0onPa?83oj75lP;oX/Kb0onRa?42ojC5l@;oXlC`1?nU
aO02ojO5k`;oY/C_1OnWa>h2ojS4k@03ojO4k_nX`ngoZ<?]00?oZ<?]0_nY`n`3ojS3k@;oZL;/1_nX
`^`2ojW2k0KoZ<;/0_nX`N`2ojS2k0CoZ<7/0_nX`N/5ojS1k003o`000?nX`NcoZ<7/00OoZ<7/1?nX
`N/2ojS0j`KoYl3[00?o0000ooooooooool03Oooool003Cooooo00?o0000ooooooooool0;_ooool5
ojk1j0Co[kkV0_n^^n<2ojVii@?oYkGS1?nT/>42oin[g`;oVkCY0onF]>d4oi>jlP;oS/Gj0_nSgO/3
ok?Tm`03okcXlonjcn[o^/oZ00;o^/oZ0_nhaN@2ojN/f`?oVikF0on;TM@3oh2;e0CoM8cL1?moZo00
0onPh?coaoO/olOgk002om;eiPCobn7X0_noc^H2ojZdh0?oUZ7L0on:UMT2oh6@f@CoPYCL0on9Wn85
oi6]j@;oVk__0_nTb_@4ojOAmP03ojSFn?nZeoOoZ]Og00;oZ]Og00?oZ=Ohoj[BmOnZd_D00_nZd_D2
ojOAmP?oZ<gc0_nUc?@00onVb?7oY<SbojC8lP03ojC8lP;oX/Oc0onTaO43oj;5l@;oX<Gc0onRa?42
oj74lP;oX/?`1?nQ`o42oj34lP;oX/?`1_nRa?42oj?3l0CoXlC`0_nUaO02ojC4k`CoY/C_0_nWa>h2
ojK4kPCoYlC^2OnX`ndEojS2k0_oZ<7/00?o0000ojS1k?nX`N`01onX`N`2ojS1j`03ojO1k?nW`>_o
Yl3[00GoYl3[00?oooooo`000?ooool03_ooool003Gooooo0_l0000_ooooo`Go[/7X0_n__^H2oj^m
i`CoZKWU0onW]N<2ojB`h@;oW[GX1?nK]>T3oiJdk@;oTk[b0onNd?T01?nSgO_o/nCgok?Tmonci?L3
okWDkP;o^/oZ0_n_^>04ojN/f`?oVikF0on;TM@3oh2;e0CoM8cL0_moZo02oj_Nn@;o`O;a0_o9j>`2
ol_Qj0;o^/SU1OnZ]>03oiJQg0?oRYGI0_n1T=T4oh:Dg0?oRIoR0_nA[NT2oibol@GoY<[d0_nWdOH2
oj_FmP;oZ]Og0on/doD2oj[Bm@?oZ/kc0_nXcO<2ojS9l@CoY/Sa0_nTb?83ojG5l0;oY<Ga0_nU`nl4
oj?3l0;oX/Ca0_nS`^l5oj;3l0;oXL?a00?oX/;`oj;3l?nR`o000onR`o02oj;4l@KoXl?`0_nSa?02
ojC3k`CoY<C_0_nVa>l2ojG3k`CoY/C^0_nWa>h3ojO3kP;oZ<?]0_nW`nd4ojS3k@;oZ<;/0_nX`^dA
ojS2k0;oZ<7/0_nX`^`6ojS1k003o`000?nX`NcoZ<7/00GoZ<7/1_nW`N`2ojO0j`Kooooo00?o0000
ooooooooool03?ooool003Oooooo00?o0000ooooooooool0;_ooool2ojk1j0;oZl7Z1?n[_NL2ojVi
i@;oYK[X0onR]nP4oijej0;oVkCY0_nL`O84oi_6mP;oW]3i0_nZgOT3okCEl@;o^MC^0_nc`^D4ojnh
h0?oYjcK0onKW]H3oh^Ae0CoP8_D0_mdS=`3oi:jlP03oj_NnOo1l_7o`O;a00;obNS/0_o3enT4ok[8
i@;oZ[CP0_nKZ=l3ohbLgP?oQYSN0on5Vn42oh:Dg003ohZUi_nD/^coU;;/00;oU;;/1?nL_o42ojC:
m0?oZM;e0_n[e_H3ojgDm0;o[=?e0on/d?<2oj[>l`;oZ/[a1?nXbO42ojK8l@?oYlK_0_nUaO02ojK3
kPCoYL?_0_nS`o02ojG2kPCoXl;_0_nR`o02oj?2k`CoX/;`0_nR`o02oj?2k`OoXl?`00?oXl?_ojC3
konT`nl00onT`nl2ojC4k`KoYL?_0_nVa>h3ojK3kP;oYl?^00?oY/?^ojO3kOnW`nd00onW`nd2ojS3
k@03ojO2kOnX`^goZ<;]00?oZ<;]0_nX`^`2ojS2kA7oZ<;/1_nX`N`01?l0003oZ<7/ojS1k?nX`N`8
ojO1k0Wooooo00?o0000ooooooooool03?ooool003Sooooo00?o0000ooooooooool0;_ooool4oj_1
jP;oZkgW0_nV_NX4ojFjj0?oX[OX0_nN]NP2oifnk`CoW<7b0_nKa_H3ojCDn004oj[MnOndeO7o]=Ga
okCEl@;o/lOY1?nc`^D2ojnhh004oj>^gonIYMgoVJGMoiVUg@CoTIkL0on6V]l3ohNSi`CoT[[b0_n_
hOP00oo1l_7obNS/olWXk004ol?Gj@;o^/SU0_nY]n<4oi^Xg`?oS9cN0on6V=h3ohFKh@?oRZGV1?nD
/^`2oibol@?oY<_d0_nYd_D3ojgCm0;o[MCd0on]dO<2ojc@l`;o[<ca1?nZb_42ojS9l@?oZ<K_0_nW
a^l2ojO4kPCoY/?^0_nU`nl6ojG2kP;oXl;_0_nT`^h4oj?2k`;oX/;`0_nT`^h4oj?2k`;oXl?`0onT
`^l3oj?3k`;oY<?_0onT`^l2ojG3k`;oYL;^1?nU`nh2ojK3kP;oY/;^1?nV`nh2ojO3k@KoYl;]0_nX
`^d2ojO2k@GoZ<;]4?nX`^`6ojS1k003ojO1k?l0003oYl7/00KoYl7/3?ooool00ol0003ooooooooo
o`0<ooooo`00>Oooool00ol0003oooooooooo`0^ooooo`;oZl7Z0_nW`>/4ojJmjP;oYK[X0_nQ_Nd4
oj2mk@?oWKk_0_nL`O83oj;=mP;oY=Ch0on_d_800ondeO7o/lOYok?7j@02ok?7j@;o/l;U00?oZKKR
oj>^gonS[]l00_nS[]l3oiVUg@CoTIkL0on6V]l3ohNSi`04oi:jl_n_hOSo[n7hojoQn0;o`NK`0oo4
gn`2ol?Gj@;o]/GV1?nY]n<3oi^Xg`?oS9cN1?n6V=h3ohFKh@?oRZGV0_nD/^`3oik2lP;oY<_d0onZ
d?@2ojgCm0?o[]7c0_n]dO<2ojg=l@Co[<ca0_nZb_43ojW7k`;oZ<K_00?oZ<C^ojO4k_nWa>h00onW
a>h2ojK3kP;oY/;]1_nU`^h3ojG1k@?oY<;^0_nS`^l3ojC1kP?oY<;^0_nS`^l3ojC1kP;oY<;_0_nT
`Nh4ojC2kP;oY<;_1_nU`^h2ojG3kPKoY/;^0_nV`nh2ojK2k@coYl;]0_nX`^d3ojO2k@;oZ<;/0_nW
`^d6ojS2k0;oYl;/1?nX`^`2ojS1k0GoYl7/00?o0000ojO1k?nW`N`04?ooool00ol0003ooooooooo
o`0<ooooo`00>_ooool2o`0002oooooo1?nW`>/2ojJmjP;oXkk]1?nQ_Nd2oj2mk@;oXL?a1?nPao@2
oj;=mP?oZ/kc0_n_d_83ok7:k0;o/lOY0_n]_>D3ojVfhPCoXjkO0onIYMd2oi6Ng003oi2Xi_n>/Nko
S[7^00;oS[7^0onIaoL3ok3JmP04ol7Vl?o4gncoa=o/olCOk0;o_=3Y1?nfaNH2ojVgh`04oif/h_nC
Xn3oTj?Poi>Sh0?oRYkQ1?n8XN@3ohfYj@GoU;G^0_nN`_82ojG:l`?oZ]3d00?o[M3cojkAlon^dO<0
0_n^dO<00on^c_7o[Lgaojg=l@03ojg=l@;o[<ca0_n[b>l2ojW7k`;oZLG^1?nXa>h2ojO4kP;oYl;]
1OnV`^d2ojG2kP;oY/7]0_nU`Nd2ojK1k@CoYL7]0_nT`Nh2ojG1k@KoY<7^0_nU`Nd5ojC1kP;oY<;^
00?oYL7^ojG2k_nU`^h01_nU`^h7ojK2kPKoY/;]5OnW`^d2ojS2k003ojO2kOnW`^coYl;/00?oYl;/
0_nX`^`00onW`^coYl7/ojO1k005ojO1k003o`000?oooooooooo013ooooo00?o0000ooooooooool0
3?ooool003cooooo00?o0000ooooooooool0;Oooool2ojO0j`;oY;o]1?nS_^d2oj6mk@;oXL7`1?nQ
`o42oj37m0?oYl[b0_nZc_<2ojk:kP?o/L[/0_n^`>L4ojfli@?oZKKR0_nS[]l00onLZ^7oU:KRoiBV
hP02oiBVhP?oT:SV1?n>/Nh01?nIaoOo/=[fok3Jm_n`f_H3ok[NlP03olCOk?nld>Wo_=3Y00;o_=3Y
0_nfaNH2ojZhh`?oWJcR0onCXn03ohZNh@CoR:7T0on=ZNT2oiBekP;oW/7a1OnUb_<01OnZd?Co[M3c
ojg@lon]d??o[]7c00Co[/ka0_n]cO43ojc:k`;oZlS_0_nZa^h4ojW5kP;oZ<C^0_nX`nd4ojO2k@;o
Y/;]0onW`Nd2ojK1k@;oY/7/1?nV`Nd2ojG1k@;oY/7]1?nU`Nd2ojC1kPKoYL7]0_nT`Nh2ojG1k@Co
YL7^0_nU`^h2ojG1k@CoYL;^0_nV`^h;ojK2kASoYl;]2?nW`^`2ojO1k0Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoY;o]
0_nS_^d2oj:okPCoXL7`0_nQ`o43ojG6l@;oYl[b0_n[b>l4ojk:kP03ok7:k?n^`>Oo[/3W00;o[/3W
0_n]_>D00onV]>;oXZoQoj:_h@02oj:_h@?oW:[Q1?nDY^83oi2XiP;oS[7^0onRb?@01?n`f_Ko^]kb
ok[Nl_njg_83ok_Ek@;o_=3Y0_nb`nH4ojZhh`?oWJcR0onCXn03ohZNh@;oR:7T0_n?[NX3oiJgkPCo
W/7a0_nUb_<3oj[>l`;o[M3c0on^co42ojk>l@?o[L__0_n/b^l2oj_7kPCoZ/K^0_nYaNh3ojW3k@?o
Z<?]0_nW`^d3ojO2k0;oYl7]0_nW`N`4ojK1k0;oY/7]0_nV`N`4ojK1k@;oYL7]0_nV`Nd<ojG1k@;o
YL7^1_nU`Nd2ojG2kP?oY/7]3?nV`^dIojO2k@GoYl;/2Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nT_nd3oj>ok@?oX[o^
0_nQ`O03ojC3k`;oYLKa0_nYa^l4oj_8k`;o[/[^0on^`^T2ojk0i`03ojVii?nV]>;oY[CR00;oY[CR
1?nR[n43oibZh@;oU:KR0_nG/n/4oiZkk`;oX/Sd0on`eo@01?njg_;o^mG]ok_EkOnkeNd2okK;j@Co
//?V0_nZ^><00onQ/NCoUjWSoiNYh`02oiNYh`?oTJKT0on=YnH4ohn]jP?oU[O^0_nN`O43ojC8lP;o
Z/kc0on/c_42ojk?l@?o[/c`0_n]bnl2ojc9kPCoZlO^0_nZa^h3ojW4k@;oZL?]1_nX`^`2ojO2k0Ko
Yl7/0_nV`N`00onW`NcoY/7/ojK1k003ojK1k0;oY/7]00?oY/3/ojK1kOnV`Nd00onV`Nd2ojG1k@03
ojK1kOnU`NgoYL7]00GoYL7]0_nV`Nd6ojG1k@_oY/7]0_nV`^d00onV`NgoY/;]ojK2k@03ojK2kAKo
Yl;]4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo000oooooo`;o0000
;oooool2oj>ok@;oY;o/1?nT`Nh2ojC3k`;oYlC^1?nYa^l2oj_8k`?o[L?Z0_n^`^T2oj^liP?oZKWT
1?nV]>82oj:_h@;oWK7V0onJ/NL4oiNcj`;oV[__0onUc?@2ok3Gm0?o]mG`00?o^mG]okK;jOnfbnT0
0_nfbnT2ok;3iP;oZK[U0onQ/N@4oiNYh`?oTJKT0on=YnH2ohn]jP;oUkS^1?nN`O42ojC8lP?oZL_a
0_n/c_42ojg=l0?o[/c`0_n]b^l4ojc9kP;oZlO^0_n[aNd2ojW4k@;oZL?/1_nX`^`2ojS1k0coYl7/
0_nV`N`2ojO0k0CoY/3/0_nV`Nd2ojK0k0CoY/7]0_nU`Nd3ojK1k0;oY/7]0_nV`N`DojK1k@;oY/;]
5OnW`^dDooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o
0000ooooooooool0;Oooool4ojBok0;oY<7^0_nV`^d4ojO4kP;oZLK_0on[`n/2ojg3jP;oZkkW1?n[
_>H3ojVii0;oY[CR0_nR]>D4oifaiP?oV[7W0_nG/n/3oik1l@;oYLcd0on^d?82okOEl0?o]lo]0_nf
bnT00on_`NOoZK[UojVji@03ojVji@?oXK7T0_nGZN<00onEZnKoTZcXoi:/j002oi:/j0?oTk3[1?nG
^>h2oik1l@?oY<Ka0_nYbo42oj_;l@Co[Lg`00?o[/c`ojg:kon]b^l00_n]b^l2ojc9kP;oZlK]0_n[
aNd2oj[4k@CoZL?/1?nX`^`4ojS1k0[oYl7/1_nW`>`8ojK0k0;oY/7]0onV`>`2ojK1k0;oY/3/1?nV
`N`2ojK1k@;oY/7/3_nV`Nd2ojO1kA?oYl;]6?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo0012ooooo`03o`000?oooooooooo02gooooo0_nT_n`2ojJok0CoY/;]0_nWa>h3
oj[2j`;oZl?[0_n[_nT4oj^ni`;oZkcV0_nW^^H3ojFgiPCoX[CU0_nM/NH2oijhj`CoWK_]0_nN`O43
ojS:l@;o[]3b0_nbd>l3okO?k@03ok;7jOn_`NOo[l7W00;o[l7W0_nY^^D2oj:di@?oW:oU1?nEZnH4
oi:/j0?oTk3[0_nG^>h3oijol0;oY<Ka00?oZ<Waoj_;lOn[bo400on[bo42ojg=l0;o[L__0_n]b^l2
ojc8kP?oZlK]0_n[aNd4oj[4k@;oZL?/0_nY`^`4ojS2k0CoZ<7/1_nW`N`;ojO0k0;oY/3/0_nW`>`<
ojK0k0;oY/7/00?oY/3/ojK1k?nV`N`00onV`N`2ojK1k@03ojK1k?nV`NgoY/7]00GoY/7]00?oYl7/
ojO1kOnW`Nd00onW`Nd2ojO2k@;oYl7]2_nW`^dMooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool004?ooooo00?o0000ooooooooool0;Oooool4ojJok0;oY/;]0_nY`N/3oj[2
j`;oZl3Y1?n[_nT2oj^ni`;oZKcW1?nW^^H3ojFgiP;oX[CU0_nQ]nP4oijhj`;oWK_]0_nSa?03ojS:
l@03ojg=lOnbd>oo/]3_00?o/]3_00Co]lo]ok;7jOnbanWo//OY0_n_`NL2ojRjiPCoX[CU0onL[nD3
oiF[iP;oTZcX0_nG/n/4oiVhkP;oW[o`0_nSa?04ojS9l@;oZl_a0on/b_02ojg;k`Ko[<S^00?oZlK]
oj_5kOn[aNd00_n[aNd2oj[4k@;oZL?/1?nY`^`2ojS2k0KoZ<7/0_nW`N`CojO0k0;oY/3/00?oYl3/
ojK0k?nV`>`02_nV`>`8ojK1k0;oY/7]1_nW`N`2ojO1k@?oYl7/0_nW`Nd2ojO1k0KoYl;]8?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oooooooooo
02gooooo0_nV_n`2ojS0j`CoZL7[00?oZ/;[oj_0jOn[`>T00_n[`>T2oj^oj@;oZKgX1?nY_>L2ojNj
iP;oYKWW0onS^>P4oj6gj0;oW[S[0_nQ_nh4oj?4l004ojS:lOn]cO7o[Lgaojg=l@;o/]3_0onabN`2
ok;7j@;o[L3X1?nX^^H2oj:di@03oijci_nJ/>OoV[3W00;oV[3W0onG/>T4oiNcj`;oVKS^0_nO_nl4
oj?4l0;oZ<Wa0onZbO02ojc:l0;o[<W_1_n/b>h3oj_6k@;oZlG]0_nZa>`4ojW3k0;oZL;/0_nX`^`6
ojS1k0;oYl7/0_nW`>`2ojO0j`KoYl3/0_nW`>/<ojO0k0;oY/3/0_nW`>`6ojK0k0;oYl3/1_nV`N`C
ojO1k0;oYl;]9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0015oooo
o`;o0000;oooool3ojS0j`;oZL7[0onZ`>X2oj_0j@;oZ[oY1?nY_NP2ojVli`;oY[_X1?nU^NL3oj>h
j0;oXKOX0_nR_N`4oj6okP;oXlC`0_nXbO42ojg=l@?o[l[^0_nabN`2ojk4jPCo[L3X0_nX^^H2ojBg
iP?oW[?V1?nJ/>L3oiN`j@;oUk?[0_nK^Nd4oinok`;oXlC`0onVa_02oj[9l0;oZlW_1?n/bNl2ojc8
kP?o[<O]0_n[a^d00on[a>goZ/C/oj[4k003oj[4k0;oZL?/0_nY`^`4ojS2k0CoZ<7/0_nW`N`6ojO0
j`;oYl3/1_nW`>/2ojO0k0;oYl3[3?nW`>`2ojK0k0KoYl3/0_nV`N`3ojO0k17oYl7/:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`000?oooooooooo02go
oooo1?nY`>X2oj[0jP;oZ/3Y1?nZ_nT2ojVmj0;oYkcX1?nV^nP2ojFii`03ojBlj_nR_>_oX[c[00;o
X[c[0_nR_N`2ojC2k`CoYLG`0_nXbO43ojc9k`;o[l[^0_n^a^/4ojk4jP;o[L3X0_nX^nL4ojBgiP?o
W[?V0_nJ/>L2oi^dj@CoV[G[0onK^Nd2oinok`?oXl?_0_nVa_02ojS7k`CoZlW_0_n/bNl3ojc7kP;o
[<O]00?oZlG]oj_4kOn[a>d00_n[a>d2oj[4k0?oZL?/0_nY`^`8ojS1k0;oZ<7[5?nW`>/2ojO0k0;o
Yl3[5?nW`>`>ojO1k2cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00
B?ooool00ol0003oooooooooo`0]ooooo`CoZL3Z1?nZ`>T2ojZoj@;oZ;kY1?nW_>P2ojJkj003ojFl
j_nT_>[oY;cZ00;oY;cZ0_nR_>/2oj?0k@CoY<;_0_nUaO03ojW7k`;o[<W_0_n]and4ojk6j`;o[/CZ
0_n[_nP4ojRki`;oY;OV0_nQ]^L3oifdj0CoVkCY0_nJ]N/2oifjk@CoWkk^0_nS`nl2ojK5k`CoZ<O_
0_n[bNl2oj_7kP;o[<O^0_n[a^d4oj_5k@;oZlC]0onZ`n`2ojW3k0;oZL;/1_nX`N`6ojS1jaSoYl3[
0_nW`>`2ojO0j`;oYl3/0_nW`>/<ojO0k0[oYl7/<?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo0019ooooo`03o`000?oooooooooo02gooooo1?nY`>X2oj[0j@;oZ;oZ1?nX
_^T2ojNlj003ojJmj_nU_>[oYKcZ00;oYKcZ0_nT_>X2ojBok0CoXl3]0_nT`^l3ojO5k`;oZLO_0_n[
a^h4ojg7k@;o[/K[0_n/`^T4oj^oj0;oZ;_W0_nT^>L4oj6fi`?oWKCX0_nK]>T2oifhj`CoWK[]0_nO
_^h00onS`^ooY/G_ojK5k`03ojK5k`;oZ<O_0_nYanl2oj_7kP;oZlK^1?n[a^d2oj_5k@?oZ/C/0_nZ
`n`6ojW2k0CoZ<7/1_nX`N/00onX`>_oYl3[ojO0j`0OojO0j`_oYl3/1onW`N`dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oZL3Z0_nX`>/4
ojRojP;oZ;kY0_nW_^X3ojJmjP;oYKcZ0_nT_^`4ojBok0;oXl3]0onV`nh2ojO5k`;oZLG^1?n[a^h2
ojg7k@;o[<?[1?n/`^T2oj^oj0;oYk_X1?nT^>L2oj6fi`03oj2gjOnN]n[oW[OZ00?oW[OZ0onM^>/2
oifjk@03oj6nk_nS`^ooXl;_00;oXl;_0_nVaNl3ojS5k`;oZLO_0_nZa^h4oj_6kP;oZlK]0on[aNd2
oj[4k0;oZL?/1_nY`^`6ojS1k0?oZ<7[1?nX`>/PojO0j`coYl3/0_nW`N`iooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o0000ooooooooool0;?ooool4ojS0
j`;oZ;oZ0onW_n/3ojNnjP04ojJmj_nU_^_oYKk[ojFnj`?oY;k/0_nT_n`3ojG1k@;oY/?^0_nWa>h4
ojW5kP;oZlK^0_n[a>`4ojc3j`;o[<;Y0onY_^T3ojNkj0;oY;SW00?oX[SXoj2gjOnP]nT00_nP]nT2
oijgjP;oWk[[1?nO^nd3oj6nkP;oXl;_0onU`nl2ojS5k`;oZLK^1?nZa^h2oj_6kPGoZlG]00?oZ/C/
ojW3k?nY`n`00onY`n`3ojW2k0KoZ<7/1_nX`N/2ojS0jb;oYl3[0_nW`>`3ojO0j`GoYl3/??ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo001=ooooo`03o`000?oooooooooo
02cooooo0_nX`>/3ojO0j`;oYko[1OnV_n/2ojFnj`;oYL3/1?nU`>d2ojG1k@;oY/?^1?nWa>h2ojW5
kP;oZ/C]1?n[a>`2ojc3j`?oZ/3Y0_nY_^T00onW_>SoYK[XojFjj002ojFjj0?oX[SX0_nP]nT2oj2i
jPCoWk[[0_nO^nd2oj:nk@CoXl7^0_nU`nl2ojO4kPCoZLK^0_nZa^h3oj[5k@;oZlG]00?oZ/C]oj[4
k?nZa>`00_nZa>`2ojW3k0KoZL;/0_nX`N`7ojS1j`CoZ<3[9_nW`>]3ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool004kooooo00?o0000ooooooooool0;Oooool2ojO0j`03
ojJok?nV_n_oY[o[00CoY[o[0_nU_n`4ojG0k0;oYL3]0_nV`^d4ojK3kP;oYlC^0onY`nd3oj[4k@;o
ZlC/0onZ`N/2oj[0j@03ojRnjOnW_>SoYkcX00;oYkcX0_nU^^P2ojBjj@?oX[WY1?nP^NX2oinjj`;o
XKc/1?nR_^d2oj?1kP;oYL?^1?nWa>h2ojW6kP?oZLG^0onZaNd4oj[4k@;oZ/C/0_nY`n`6ojW2k0?o
Z<7/2?nX`N/3ojS0jb?oYl3[Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo001?ooooo`;o0000;_ooool3ojJok0;oY[o[0_nV_n`4ojFok0;oYL3/0_nV`Nd4ojK2k@;oY/?^
0onX`nd2ojW3k@;oZL;/1?nZ`^/2oj[1j`03ojVoj_nX_^WoZ;kY00;oZ;kY0_nW_>P2ojFkj@CoY;[Y
0onR^NT2oj2ijP;oXK_[1?nQ_>`2oj:nk@;oY<7^1?nU`nh2ojO4kP?oZ<C^0_nYaNh00onYaNgoZ/G]
oj[5k@02oj[5k@;oZ/C]1_nY`n`5ojW2k0;oZ<7/2?nX`N/5ojS0jakoYl3[C?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo1onV
_n`2ojFok0;oY/3/1?nV`Nd2ojK2k@?oYl;]0_nX`nd2ojS2k0CoZL;/0_nZ`^/00onY`>[oZKoZojVo
jP02ojVojP;oZ;kY0_nW_>T4ojFkj@;oY;[Y0_nS^nX4oj:kj`?oXK_[0_nQ_>`3oj>ok@?oY<7^0_nU
`nh2ojO3kPCoZ<C^1?nYaNd2oj[5k@?oZLC]1?nY`n`6ojW2k003ojS1k?nX`N_oZ<7[00KoZ<7[1_nX
`>/LojO0jdoooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool0
0ol0003oooooooooo`0[ooooo`KoY[o/1_nV`>`2ojK1k@?oYl7/0_nW`^d6ojS2k0;oZL;/00?oZL7[
ojW0j_nY`>X00_nY`>X2ojVojP;oYkkY1?nW_>T2ojFkj@;oY;_Y1?nS^nX2oj:kj`;oXkc[1?nS_N`2
oj>ok@03ojC0kOnU`^koYL;^00;oYL;^0_nW`nh2ojO4kPCoZ<C^0_nYaNd5ojW4k@KoZL?/0_nY`^`0
0onX`^coZ<7/ojS1k002ojS1k0SoZ<7[1OnX`>/IojO0je?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`00Doooool00ol0003oooooooooo`0[ooooo`GoY[o/1?nV`>`4ojK1
k0CoYl7/1_nX`^`00onX`N_oZL7[ojW1j`02ojW1j`;oZL3Z0_nX_^X4ojNnj@;oYkcY0_nV_>T4ojBk
j@;oXk_Z1_nS_>/2oj>mk003ojBokOnT`>goY<3]00;oY<3]0_nU`^h2ojK3kPCoYlC^0_nXa>h5ojW4
k@03ojW3kOnY`ncoZL?/00GoZL?/00?oZL;/ojS2k?nX`^`00_nX`^`5ojS1k0GoZ<7[1OnX`>/GojO0
jeOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002go
oooo1?nV_n`4ojK0k0;oY/7/1_nW`N`2ojS2k0GoZ<7[0_nY`N/3ojRojP?oZ;kZ0_nW_^T3ojJmj@?o
Y[cY0_nT^nT2ojBljPKoXkc[00?oY;k/ojBokOnT_nd00_nT_nd2ojC0k@;oY/;]1?nV`nh2ojO4kP?o
Z<?]0_nYa>d5ojW3k@;oZL?/1_nY`^`2ojS2k0GoZ<7/1_nX`N/3ojS0jaKoYl3[F_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Fooooo`03o`000?oooooooooo02_ooooo
1?nV_n`2ojK0k0;oYl3/1_nW`N`7ojS1j`?oZ<3[0_nX_nX6ojNnjP;oY[gY0_nV_NX4ojFljP?oY;cZ
0_nS_>/2ojBmk0?oY;k/0_nT_nd3ojG1k@?oY/;]0_nV`nh3ojO3k@?oZ<?]1_nY`nd3ojW3k0GoZL;/
0onX`^`3ojS1k0OoZ<7[1OnX`>/BojO0jekooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`00Eoooool00ol0003oooooooooo`0[ooooo`;oY[o/0onW`>/3ojO0k0;oYl7/0onW
`>/2ojS1j`OoZ<3[0_nX_nX6ojNnjPKoY[gZ0_nU_>X00onU_N_oY;g[ojBmj`02ojBmj`;oY;g/0_nT
_n`4ojFok@;oYL7]0_nV`Nd4ojK2k@;oYl?]1OnX`nd2ojW3k@?oZ<?]0_nY`n`8ojS2k0GoZ<7/1?nX
`N/6ojS0j`coYl3[I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo001H
ooooo`03o`000?oooooooooo02cooooo2_nW`>/7ojS0j`;oZ;o[1?nX_nX4ojNnjPKoY[gZ1OnU_N/2
ojBmj`;oYKk/1?nT_n`2ojFok@;oYL7]1?nV`Nd2ojK2k@03ojO2kOnX`ngoZ<?]00WoZ<?]2OnX`^`8
ojS1k0CoZ<7[0_nX`>/<ojO0jf[ooooo00Go0000ooooooooooooooooo`00000;ooooo`00FOooool0
0ol0003oooooooooo`0/ooooo`KoYl3[1onX`>/6ojRoj`;oZ;oZ1_nW_^X2ojJmjP03ojJnjonU_N_o
YKg[00CoYKg[0_nU_^/4ojFnk0;oY;o/0_nU`>`4ojG1k@;oY/7]0_nV`^d3ojO2k@OoZ<?]0_nX`^d;
ojS2k0SoZ<7/0_nX`N/3ojS0j`WoYl3[KOooool01Ol0003ooooooooooooooooo000000_ooooo001J
ooooo`;o0000;Oooool4ojO0j`OoZ<3[1_nX_n/3ojNoj`GoYkkZ1OnV_^/2ojFmj`KoYKk[0_nU_^`3
ojFok0?oYL3/0_nU`Nd2ojK1k@;oY/;]1_nW`^d2ojS3k@KoZ<;]2OnX`^`;ojS1k0;oZ<3[1onW`>]a
ooooo`04o`000?ooooooooooo`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1?nW`>/7
ojS0j`;oZ;o[1onW_n/4ojNnj`OoY[k[0_nU_^/8ojFok003ojK0k?nV`NgoY/7]00CoY/7]0_nV`^d8
ojO2k@KoZ<;]1_nX`^`>ojS1k003ojO1k?nW`>_oYl3[00CoYl3[MOooool00ol0003oooooo`00000;
ooooo`00GOooool00ol0003oooooooooo`0[ooooo`;oYl3[1_nX`>/<ojNoj`;oYkk[00?oY[o[ojJn
jonV_^/01?nV_^/2ojJoj`KoYKo/1OnV`>`4ojK1k@CoY/;]2?nW`^d4ojS2k@SoZ<;/2_nX`N`5ojO1
k0;oYl3[N?ooool01?l0003oooooooooool0000:ooooo`00G_ooool00ol0003oooooooooo`0[oooo
o`;oZ<3[0_nW`>/4ojS0j`_oYko[1?nV_n/2ojJnj`KoY[o[0_nU_n`00onV_ncoY/3/ojK0k004ojK0
k0KoY/7]0_nV`^d6ojO2k@KoZ<;]2?nX`^`7ojS1k0SoYl7/O?ooool00ol0003oooooo`00000:oooo
o`00Goooool2o`0002cooooo1?nW`>/2ojS0j`;oYl3[2onW_n/:ojJoj`GoY[o/1OnV`>`4ojK1k@_o
Yl;]0_nX`^d2ojO2k@SoZ<;/1OnX`N`5ojO1k8?ooooo0_l0000:ooooo`00HOooool00ol0003ooooo
ooooo`0Zooooo`SoYl3[2OnW_n/7ojJoj`KoY[o/1onV`>`6ojK1k@ooYl;]0_nX`^`2ojO2k0;oZ<;/
0_nW`^`6ojO1k8Gooooo0ol0000:ooooo`00H_ooool00ol0003oooooooooo`0[ooooo`CoYl3[2onW
_n/8ojJoj`;oY[o/1onV`>`2ojK1k0KoY/7]00?oYl7]ojO2kOnW`^d03onW`^d7ojO2k0;oYl7/Q?oo
ool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo1?nW`>/9ojNoj`SoY[o[2_nV`>`3
ojK1k0CoY/7]0onW`Nd@ojO2k@KoYl;/Poooool4o`00017ooooo001Tooooo`;o0000;?ooool3ojO0
j`WoYko[1OnV_n/<ojK0k0KoY/7/00?oY/7]ojO1kOnW`Nd04onW`^d2ojO2k8?ooooo0ol0000Eoooo
o`00I_ooool00ol0003oooooooooo`0[ooooo`;oYl3[1onW_n/?ojK0k0SoY/7/1OnW`Nd>ojO2kHGo
oooo1?l0000Hooooo`00Ioooool00ol0003oooooooooo`0Zooooo`CoYl3[0_nW_n/2ojO0k0ooY/3/
1_nV`N`2ojO1k0GoYl7]3?nW`^f4ooooo`Co00007?ooool006Sooooo00?o0000ooooooooool0:_oo
ool4ojO0j`CoYl3/3onV`>`2ojK1k0[oYl7/2OnW`^f3ooooo`Co00008?ooool006Wooooo0_l0000/
ooooo`?oYl3[1OnW`>`4ojK0k0?oYl3/0_nV`>`2ojO0k0koYl7/1_nW`^f2ooooo`Co00009?ooool0
06_ooooo00?o0000ooooooooool0:_oooolCojO0k0koYl7/0_nW`^f2ooooo`?o0000:?ooool006co
oooo00?o0000ooooooooool0:_ooool2ojO0k003ojO0jonW`>coYl3/00coYl3/3?nW`Nb3ooooo`Co
0000:oooool006gooooo00?o0000ooooooooool0:oooool2ojO0j`coYl3/2_nW`Nb2ooooo`Co0000
;oooool006kooooo00?o0000ooooooooool0:_ooool4ojO0j`;oYl3/0_nW`>/7ojO0k0KoYl7/POoo
ool4o`0003?ooooo001_ooooo`;o0000:oooool8ojO0j`OoYl3/0_nW`Nb0ooooo`Co0000=oooool0
077ooooo00?o0000ooooooooool0:_ooool7ojO0j`;oYl3/P_ooool4o`0003_ooooo001booooo`03
o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool007?ooooo00?o0000ooooooooool0
:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_ooool007Cooooo0_l0000Zooooo`03o`000?oo
oooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0001:ooooo`00Moooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo077o
oooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o0000ooooooooool0KOooool4o`0005Gooooo
001kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005Wooooo001l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0IOooool4o`0005gooooo001moooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool4o`00067ooooo001nooooo`;o
00007oooool00ol0003oooooooooo`1Mooooo`Co0000IOooool0083ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Jooooo`?o0000JOooool0087ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000Iooooo`03o`000?oooooooooo04[o
oooo1?l0001hooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo
1?l0001looooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo0ol0
0020ooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo1?l00023
ooooo`00ROooool2o`0001Cooooo00?o0000ooooooooool0>oooool4o`0008Oooooo002;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008_ooooo002<ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0008oooooo002=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<?ooool3o`0009?ooooo002>ooooo`;o00003oooool0
0ol0003oooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo1?l0
002Vooooo`00UOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo0ol0002Z
ooooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002]oooo
o`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002aooooo`00
V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002eooooo`00VOoo
ool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Wooooo002Kooooo`04o`000?oooooo
ooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000`?ooool0
09gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:kooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o410@olc<c0Gooooo0_lQ8B6Hooooo`00[_ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`;o8B4QV?ooool00:kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000Woooool00:kooooo00?o0000oooo
ooooool01?ooool6o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003oV9RHoooooonHV9So
8B4Q09oooooo002^ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0
003oEEEEo`000?l@413oc<c<09oooooo002/ooooo`03oa0@4?l0003o000000?o00003Oooool00ol0
003oooooooooo`02ooooo`03oeEEEOn7QhOooooo0:7ooooo002^ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ooMgMgo410@oiRHV02Qooooo`00[_ooool00ol0003ooooo
ooooo`0<ooooo`03oeEEEOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@Woooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16.8) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69215 Mtetra
.41427 .69215 .41957 .69681 .42855 .69428 .42327 .68961 Mtetra
.42327 .68961 .42855 .69428 .43756 .69174 .4323 .68706 Mtetra
.655 .753 .922 r
.4323 .68706 .43756 .69174 .4466 .68919 .44137 .68451 Mtetra
.44137 .68451 .4466 .68919 .45567 .68663 .45046 .68196 Mtetra
.654 .754 .923 r
.45046 .68196 .45567 .68663 .46478 .68407 .45958 .6794 Mtetra
.654 .755 .924 r
.45958 .6794 .46478 .68407 .47391 .68149 .46873 .67684 Mtetra
.654 .756 .925 r
.46873 .67684 .47391 .68149 .48307 .67891 .47791 .67427 Mtetra
.654 .757 .926 r
.47791 .67427 .48307 .67891 .49227 .67632 .48713 .67169 Mtetra
.654 .758 .927 r
.48713 .67169 .49227 .67632 .50149 .67371 .49637 .6691 Mtetra
.653 .76 .927 r
.49637 .6691 .50149 .67371 .51075 .6711 .50565 .66651 Mtetra
.653 .761 .928 r
.50565 .66651 .51075 .6711 .52004 .66849 .51496 .6639 Mtetra
.654 .762 .929 r
.51496 .6639 .52004 .66849 .52936 .66586 .5243 .66127 Mtetra
.654 .763 .93 r
.5243 .66127 .52936 .66586 .53871 .66322 .53367 .65863 Mtetra
.53367 .65863 .53871 .66322 .54809 .66058 .54308 .65597 Mtetra
.655 .764 .93 r
.54308 .65597 .54809 .66058 .55751 .65792 .55252 .65329 Mtetra
.655 .763 .929 r
.55252 .65329 .55751 .65792 .56695 .65526 .56199 .6506 Mtetra
.656 .763 .929 r
.56199 .6506 .56695 .65526 .57643 .65259 .57149 .64788 Mtetra
.656 .762 .928 r
.57149 .64788 .57643 .65259 .58595 .6499 .58102 .64515 Mtetra
.656 .761 .927 r
.58102 .64515 .58595 .6499 .59549 .64721 .59059 .64241 Mtetra
.656 .759 .926 r
.59059 .64241 .59549 .64721 .60507 .64451 .60019 .63966 Mtetra
.656 .758 .925 r
.60019 .63966 .60507 .64451 .61468 .6418 .60982 .6369 Mtetra
.656 .757 .924 r
.60982 .6369 .61468 .6418 .62432 .63908 .61949 .63414 Mtetra
.656 .756 .923 r
.61949 .63414 .62432 .63908 .634 .63636 .62919 .63137 Mtetra
.656 .755 .922 r
.62919 .63137 .634 .63636 .64371 .63362 .63892 .6286 Mtetra
.656 .754 .922 r
.63892 .6286 .64371 .63362 .65345 .63087 .64868 .62582 Mtetra
.656 .753 .922 r
.64868 .62582 .65345 .63087 .66323 .62811 .65849 .62304 Mtetra
.656 .753 .921 r
.65849 .62304 .66323 .62811 .67304 .62535 .66832 .62025 Mtetra
.66832 .62025 .67304 .62535 .68289 .62257 .67819 .61745 Mtetra
.655 .753 .921 r
.67819 .61745 .68289 .62257 .69277 .61979 .6881 .61465 Mtetra
.655 .753 .922 r
.6881 .61465 .69277 .61979 .70269 .61699 .69804 .61185 Mtetra
.69804 .61185 .70269 .61699 .71264 .61418 .70801 .60904 Mtetra
.70801 .60904 .71264 .61418 .72262 .61137 .71802 .60622 Mtetra
.654 .754 .923 r
.71802 .60622 .72262 .61137 .73264 .60854 .72807 .6034 Mtetra
.654 .755 .924 r
.72807 .6034 .73264 .60854 .7427 .60571 .73815 .60058 Mtetra
.654 .756 .925 r
.73815 .60058 .7427 .60571 .75279 .60286 .74827 .59775 Mtetra
.654 .757 .926 r
.74827 .59775 .75279 .60286 .76291 .60001 .75842 .59491 Mtetra
.654 .759 .927 r
.75842 .59491 .76291 .60001 .77308 .59714 .76861 .59206 Mtetra
.653 .76 .928 r
.76861 .59206 .77308 .59714 .78328 .59427 .77884 .5892 Mtetra
.654 .761 .929 r
.77884 .5892 .78328 .59427 .79351 .59138 .7891 .58632 Mtetra
.654 .762 .929 r
.7891 .58632 .79351 .59138 .80378 .58849 .7994 .58342 Mtetra
.654 .763 .93 r
.7994 .58342 .80378 .58849 .81409 .58558 .80974 .5805 Mtetra
.654 .764 .93 r
.80974 .5805 .81409 .58558 .82443 .58267 .82011 .57756 Mtetra
.655 .764 .93 r
.82011 .57756 .82443 .58267 .83482 .57974 .83052 .5746 Mtetra
.655 .763 .929 r
.83052 .5746 .83482 .57974 .84523 .5768 .84096 .57163 Mtetra
.656 .763 .928 r
.84096 .57163 .84523 .5768 .85569 .57385 .85145 .56863 Mtetra
.656 .762 .927 r
.85145 .56863 .85569 .57385 .86618 .57089 .86196 .56562 Mtetra
.656 .76 .927 r
.86196 .56562 .86618 .57089 .87672 .56792 .87252 .5626 Mtetra
.656 .759 .926 r
.87252 .5626 .87672 .56792 .88729 .56494 .88312 .55957 Mtetra
.656 .758 .925 r
.88312 .55957 .88729 .56494 .89789 .56195 .89375 .55653 Mtetra
.656 .757 .924 r
.89375 .55653 .89789 .56195 .90854 .55895 .90442 .55348 Mtetra
.656 .756 .923 r
.90442 .55348 .90854 .55895 .91923 .55594 .91513 .55042 Mtetra
.656 .755 .922 r
.91513 .55042 .91923 .55594 .92995 .55292 .92588 .54736 Mtetra
.656 .754 .922 r
.92588 .54736 .92995 .55292 .94071 .54988 .93667 .54429 Mtetra
.656 .753 .921 r
.93667 .54429 .94071 .54988 .95152 .54684 .9475 .54121 Mtetra
.9475 .54121 .95152 .54684 .96236 .54378 .95838 .53812 Mtetra
.656 .752 .921 r
.95838 .53812 .96236 .54378 .97324 .54071 .96929 .53502 Mtetra
.656 .752 .92 r
.96929 .53502 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .92 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .751 .921 r
.39996 .68999 .4053 .69468 .41427 .69215 .40895 .68745 Mtetra
.655 .752 .921 r
.40895 .68745 .41427 .69215 .42327 .68961 .41797 .6849 Mtetra
.41797 .6849 .42327 .68961 .4323 .68706 .42702 .68235 Mtetra
.654 .752 .922 r
.42702 .68235 .4323 .68706 .44137 .68451 .4361 .6798 Mtetra
.654 .753 .922 r
.4361 .6798 .44137 .68451 .45046 .68196 .44521 .67724 Mtetra
.654 .753 .923 r
.44521 .67724 .45046 .68196 .45958 .6794 .45435 .67469 Mtetra
.653 .754 .924 r
.45435 .67469 .45958 .6794 .46873 .67684 .46352 .67213 Mtetra
.653 .755 .925 r
.46352 .67213 .46873 .67684 .47791 .67427 .47272 .66958 Mtetra
.652 .756 .926 r
.47272 .66958 .47791 .67427 .48713 .67169 .48196 .66702 Mtetra
.652 .757 .927 r
.48196 .66702 .48713 .67169 .49637 .6691 .49122 .66445 Mtetra
.652 .759 .928 r
.49122 .66445 .49637 .6691 .50565 .66651 .50052 .66187 Mtetra
.652 .76 .929 r
.50052 .66187 .50565 .66651 .51496 .6639 .50985 .65927 Mtetra
.653 .761 .929 r
.50985 .65927 .51496 .6639 .5243 .66127 .51921 .65665 Mtetra
.653 .763 .93 r
.51921 .65665 .5243 .66127 .53367 .65863 .52861 .65401 Mtetra
.654 .763 .93 r
.52861 .65401 .53367 .65863 .54308 .65597 .53804 .65134 Mtetra
.655 .764 .93 r
.53804 .65134 .54308 .65597 .55252 .65329 .5475 .64864 Mtetra
.656 .764 .929 r
.5475 .64864 .55252 .65329 .56199 .6506 .55699 .64591 Mtetra
.657 .764 .928 r
.55699 .64591 .56199 .6506 .57149 .64788 .56651 .64316 Mtetra
.657 .763 .927 r
.56651 .64316 .57149 .64788 .58102 .64515 .57607 .64038 Mtetra
.658 .762 .926 r
.57607 .64038 .58102 .64515 .59059 .64241 .58566 .63759 Mtetra
.658 .76 .925 r
.58566 .63759 .59059 .64241 .60019 .63966 .59528 .63479 Mtetra
.658 .759 .924 r
.59528 .63479 .60019 .63966 .60982 .6369 .60493 .63198 Mtetra
.658 .757 .923 r
.60493 .63198 .60982 .6369 .61949 .63414 .61462 .62917 Mtetra
.657 .756 .923 r
.61462 .62917 .61949 .63414 .62919 .63137 .62434 .62636 Mtetra
.657 .755 .922 r
.62434 .62636 .62919 .63137 .63892 .6286 .6341 .62355 Mtetra
.657 .754 .922 r
.6341 .62355 .63892 .6286 .64868 .62582 .64389 .62074 Mtetra
.656 .753 .921 r
.64389 .62074 .64868 .62582 .65849 .62304 .65371 .61792 Mtetra
.65371 .61792 .65849 .62304 .66832 .62025 .66357 .61511 Mtetra
.66357 .61511 .66832 .62025 .67819 .61745 .67346 .6123 Mtetra
.655 .753 .921 r
.67346 .6123 .67819 .61745 .6881 .61465 .68339 .60949 Mtetra
.655 .753 .922 r
.68339 .60949 .6881 .61465 .69804 .61185 .69336 .60667 Mtetra
.654 .753 .922 r
.69336 .60667 .69804 .61185 .70801 .60904 .70336 .60386 Mtetra
.654 .753 .923 r
.70336 .60386 .70801 .60904 .71802 .60622 .71339 .60105 Mtetra
.653 .754 .923 r
.71339 .60105 .71802 .60622 .72807 .6034 .72346 .59823 Mtetra
.653 .755 .924 r
.72346 .59823 .72807 .6034 .73815 .60058 .73357 .59542 Mtetra
.653 .756 .925 r
.73357 .59542 .73815 .60058 .74827 .59775 .74372 .5926 Mtetra
.652 .757 .926 r
.74372 .5926 .74827 .59775 .75842 .59491 .7539 .58978 Mtetra
.652 .758 .927 r
.7539 .58978 .75842 .59491 .76861 .59206 .76412 .58695 Mtetra
.652 .76 .928 r
.76412 .58695 .76861 .59206 .77884 .5892 .77438 .58409 Mtetra
.652 .761 .929 r
.77438 .58409 .77884 .5892 .7891 .58632 .78467 .58122 Mtetra
.653 .762 .93 r
.78467 .58122 .7891 .58632 .7994 .58342 .795 .57832 Mtetra
.654 .763 .93 r
.795 .57832 .7994 .58342 .80974 .5805 .80536 .57539 Mtetra
.655 .764 .93 r
.80536 .57539 .80974 .5805 .82011 .57756 .81576 .57243 Mtetra
.655 .764 .929 r
.81576 .57243 .82011 .57756 .83052 .5746 .82619 .56943 Mtetra
.656 .764 .929 r
.82619 .56943 .83052 .5746 .84096 .57163 .83666 .56641 Mtetra
.657 .763 .928 r
.83666 .56641 .84096 .57163 .85145 .56863 .84717 .56337 Mtetra
.657 .762 .927 r
.84717 .56337 .85145 .56863 .86196 .56562 .85771 .5603 Mtetra
.658 .76 .926 r
.85771 .5603 .86196 .56562 .87252 .5626 .8683 .55723 Mtetra
.658 .759 .925 r
.8683 .55723 .87252 .5626 .88312 .55957 .87892 .55414 Mtetra
.658 .758 .924 r
.87892 .55414 .88312 .55957 .89375 .55653 .88958 .55105 Mtetra
.657 .756 .923 r
.88958 .55105 .89375 .55653 .90442 .55348 .90027 .54796 Mtetra
.657 .755 .922 r
.90027 .54796 .90442 .55348 .91513 .55042 .91101 .54486 Mtetra
.657 .754 .922 r
.91101 .54486 .91513 .55042 .92588 .54736 .92179 .54176 Mtetra
.657 .754 .921 r
.92179 .54176 .92588 .54736 .93667 .54429 .93261 .53865 Mtetra
.657 .753 .921 r
.93261 .53865 .93667 .54429 .9475 .54121 .94346 .53554 Mtetra
.656 .752 .921 r
.94346 .53554 .9475 .54121 .95838 .53812 .95436 .53242 Mtetra
.656 .752 .92 r
.95436 .53242 .95838 .53812 .96929 .53502 .9653 .5293 Mtetra
.9653 .5293 .96929 .53502 .98024 .53192 .97628 .52616 Mtetra
.655 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68527 Mtetra
.39458 .68527 .39996 .68999 .40895 .68745 .40359 .68271 Mtetra
.40359 .68271 .40895 .68745 .41797 .6849 .41263 .68015 Mtetra
.654 .751 .921 r
.41263 .68015 .41797 .6849 .42702 .68235 .4217 .6776 Mtetra
.654 .752 .921 r
.4217 .6776 .42702 .68235 .4361 .6798 .4308 .67504 Mtetra
.653 .752 .922 r
.4308 .67504 .4361 .6798 .44521 .67724 .43993 .67248 Mtetra
.653 .752 .923 r
.43993 .67248 .44521 .67724 .45435 .67469 .44909 .66993 Mtetra
.652 .753 .923 r
.44909 .66993 .45435 .67469 .46352 .67213 .45828 .66738 Mtetra
.652 .754 .924 r
.45828 .66738 .46352 .67213 .47272 .66958 .4675 .66483 Mtetra
.651 .755 .925 r
.4675 .66483 .47272 .66958 .48196 .66702 .47675 .66228 Mtetra
.651 .756 .926 r
.47675 .66228 .48196 .66702 .49122 .66445 .48604 .65973 Mtetra
.651 .757 .927 r
.48604 .65973 .49122 .66445 .50052 .66187 .49536 .65717 Mtetra
.651 .759 .928 r
.49536 .65717 .50052 .66187 .50985 .65927 .50471 .65459 Mtetra
.651 .76 .929 r
.50471 .65459 .50985 .65927 .51921 .65665 .51409 .65199 Mtetra
.652 .762 .93 r
.51409 .65199 .51921 .65665 .52861 .65401 .52351 .64935 Mtetra
.653 .763 .93 r
.52351 .64935 .52861 .65401 .53804 .65134 .53296 .64668 Mtetra
.655 .764 .93 r
.53296 .64668 .53804 .65134 .5475 .64864 .54244 .64396 Mtetra
.656 .764 .929 r
.54244 .64396 .5475 .64864 .55699 .64591 .55195 .64121 Mtetra
.657 .764 .928 r
.55195 .64121 .55699 .64591 .56651 .64316 .5615 .63842 Mtetra
.658 .764 .927 r
.5615 .63842 .56651 .64316 .57607 .64038 .57108 .6356 Mtetra
.659 .763 .926 r
.57108 .6356 .57607 .64038 .58566 .63759 .58069 .63275 Mtetra
.659 .761 .925 r
.58069 .63275 .58566 .63759 .59528 .63479 .59033 .6299 Mtetra
.659 .76 .924 r
.59033 .6299 .59528 .63479 .60493 .63198 .60001 .62704 Mtetra
.659 .758 .923 r
.60001 .62704 .60493 .63198 .61462 .62917 .60972 .62418 Mtetra
.658 .757 .923 r
.60972 .62418 .61462 .62917 .62434 .62636 .61946 .62132 Mtetra
.658 .756 .922 r
.61946 .62132 .62434 .62636 .6341 .62355 .62924 .61847 Mtetra
.657 .755 .922 r
.62924 .61847 .6341 .62355 .64389 .62074 .63906 .61563 Mtetra
.657 .754 .921 r
.63906 .61563 .64389 .62074 .65371 .61792 .6489 .61279 Mtetra
.656 .753 .921 r
.6489 .61279 .65371 .61792 .66357 .61511 .65878 .60995 Mtetra
.65878 .60995 .66357 .61511 .67346 .6123 .6687 .60712 Mtetra
.655 .753 .922 r
.6687 .60712 .67346 .6123 .68339 .60949 .67866 .6043 Mtetra
.654 .753 .922 r
.67866 .6043 .68339 .60949 .69336 .60667 .68864 .60147 Mtetra
.654 .753 .923 r
.68864 .60147 .69336 .60667 .70336 .60386 .69867 .59866 Mtetra
.653 .753 .923 r
.69867 .59866 .70336 .60386 .71339 .60105 .70873 .59585 Mtetra
.652 .754 .924 r
.70873 .59585 .71339 .60105 .72346 .59823 .71883 .59304 Mtetra
.652 .755 .925 r
.71883 .59304 .72346 .59823 .73357 .59542 .72897 .59024 Mtetra
.651 .756 .926 r
.72897 .59024 .73357 .59542 .74372 .5926 .73914 .58744 Mtetra
.651 .757 .927 r
.73914 .58744 .74372 .5926 .7539 .58978 .74935 .58464 Mtetra
.651 .758 .928 r
.74935 .58464 .7539 .58978 .76412 .58695 .7596 .58182 Mtetra
.651 .76 .929 r
.7596 .58182 .76412 .58695 .77438 .58409 .76988 .57897 Mtetra
.652 .761 .93 r
.76988 .57897 .77438 .58409 .78467 .58122 .7802 .5761 Mtetra
.653 .763 .93 r
.7802 .5761 .78467 .58122 .795 .57832 .79056 .57319 Mtetra
.654 .764 .93 r
.79056 .57319 .795 .57832 .80536 .57539 .80095 .57024 Mtetra
.655 .764 .93 r
.80095 .57024 .80536 .57539 .81576 .57243 .81138 .56724 Mtetra
.656 .764 .929 r
.81138 .56724 .81576 .57243 .82619 .56943 .82184 .56421 Mtetra
.658 .763 .928 r
.82184 .56421 .82619 .56943 .83666 .56641 .83233 .56114 Mtetra
.658 .762 .927 r
.83233 .56114 .83666 .56641 .84717 .56337 .84286 .55804 Mtetra
.659 .761 .925 r
.84286 .55804 .84717 .56337 .85771 .5603 .85343 .55492 Mtetra
.659 .76 .924 r
.85343 .55492 .85771 .5603 .8683 .55723 .86404 .55179 Mtetra
.659 .758 .923 r
.86404 .55179 .8683 .55723 .87892 .55414 .87468 .54865 Mtetra
.659 .757 .923 r
.87468 .54865 .87892 .55414 .88958 .55105 .88537 .54551 Mtetra
.658 .756 .922 r
.88537 .54551 .88958 .55105 .90027 .54796 .89609 .54237 Mtetra
.658 .755 .921 r
.89609 .54237 .90027 .54796 .91101 .54486 .90686 .53923 Mtetra
.658 .754 .921 r
.90686 .53923 .91101 .54486 .92179 .54176 .91766 .5361 Mtetra
.657 .753 .921 r
.91766 .5361 .92179 .54176 .93261 .53865 .92851 .53296 Mtetra
.657 .753 .92 r
.92851 .53296 .93261 .53865 .94346 .53554 .9394 .52982 Mtetra
.657 .752 .92 r
.9394 .52982 .94346 .53554 .95436 .53242 .95032 .52668 Mtetra
.656 .752 .92 r
.95032 .52668 .95436 .53242 .9653 .5293 .96129 .52353 Mtetra
.96129 .52353 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.655 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68527 .38918 .68051 Mtetra
.38918 .68051 .39458 .68527 .40359 .68271 .3982 .67794 Mtetra
.3982 .67794 .40359 .68271 .41263 .68015 .40726 .67537 Mtetra
.654 .751 .921 r
.40726 .67537 .41263 .68015 .4217 .6776 .41635 .6728 Mtetra
.41635 .6728 .4217 .6776 .4308 .67504 .42546 .67023 Mtetra
.653 .751 .922 r
.42546 .67023 .4308 .67504 .43993 .67248 .43461 .66766 Mtetra
.652 .751 .922 r
.43461 .66766 .43993 .67248 .44909 .66993 .44379 .6651 Mtetra
.652 .751 .923 r
.44379 .6651 .44909 .66993 .45828 .66738 .453 .66256 Mtetra
.651 .752 .924 r
.453 .66256 .45828 .66738 .4675 .66483 .46225 .66002 Mtetra
.65 .753 .925 r
.46225 .66002 .4675 .66483 .47675 .66228 .47152 .65748 Mtetra
.649 .754 .926 r
.47152 .65748 .47675 .66228 .48604 .65973 .48083 .65495 Mtetra
.649 .755 .927 r
.48083 .65495 .48604 .65973 .49536 .65717 .49016 .65241 Mtetra
.649 .756 .928 r
.49016 .65241 .49536 .65717 .50471 .65459 .49954 .64985 Mtetra
.65 .758 .929 r
.49954 .64985 .50471 .65459 .51409 .65199 .50894 .64727 Mtetra
.651 .76 .929 r
.50894 .64727 .51409 .65199 .52351 .64935 .51838 .64465 Mtetra
.652 .762 .93 r
.51838 .64465 .52351 .64935 .53296 .64668 .52785 .64198 Mtetra
.654 .763 .93 r
.52785 .64198 .53296 .64668 .54244 .64396 .53735 .63926 Mtetra
.656 .764 .929 r
.53735 .63926 .54244 .64396 .55195 .64121 .54689 .63649 Mtetra
.658 .765 .929 r
.54689 .63649 .55195 .64121 .5615 .63842 .55646 .63367 Mtetra
.659 .765 .928 r
.55646 .63367 .5615 .63842 .57108 .6356 .56606 .6308 Mtetra
.66 .764 .927 r
.56606 .6308 .57108 .6356 .58069 .63275 .57569 .62791 Mtetra
.661 .763 .926 r
.57569 .62791 .58069 .63275 .59033 .6299 .58536 .625 Mtetra
.661 .761 .924 r
.58536 .625 .59033 .6299 .60001 .62704 .59506 .62208 Mtetra
.66 .76 .924 r
.59506 .62208 .60001 .62704 .60972 .62418 .60479 .61917 Mtetra
.66 .758 .923 r
.60479 .61917 .60972 .62418 .61946 .62132 .61456 .61627 Mtetra
.659 .757 .922 r
.61456 .61627 .61946 .62132 .62924 .61847 .62436 .61337 Mtetra
.658 .755 .922 r
.62436 .61337 .62924 .61847 .63906 .61563 .63419 .61049 Mtetra
.657 .754 .922 r
.63419 .61049 .63906 .61563 .6489 .61279 .64406 .60762 Mtetra
.656 .754 .922 r
.64406 .60762 .6489 .61279 .65878 .60995 .65397 .60477 Mtetra
.656 .753 .922 r
.65397 .60477 .65878 .60995 .6687 .60712 .66391 .60192 Mtetra
.655 .753 .922 r
.66391 .60192 .6687 .60712 .67866 .6043 .67389 .59908 Mtetra
.654 .753 .922 r
.67389 .59908 .67866 .6043 .68864 .60147 .6839 .59625 Mtetra
.653 .753 .923 r
.6839 .59625 .68864 .60147 .69867 .59866 .69395 .59343 Mtetra
.652 .753 .924 r
.69395 .59343 .69867 .59866 .70873 .59585 .70404 .59063 Mtetra
.651 .754 .925 r
.70404 .59063 .70873 .59585 .71883 .59304 .71417 .58783 Mtetra
.65 .755 .926 r
.71417 .58783 .71883 .59304 .72897 .59024 .72433 .58505 Mtetra
.649 .756 .927 r
.72433 .58505 .72897 .59024 .73914 .58744 .73453 .58227 Mtetra
.649 .758 .929 r
.73453 .58227 .73914 .58744 .74935 .58464 .74477 .57948 Mtetra
.649 .759 .93 r
.74477 .57948 .74935 .58464 .7596 .58182 .75505 .57668 Mtetra
.65 .761 .93 r
.75505 .57668 .7596 .58182 .76988 .57897 .76536 .57384 Mtetra
.651 .762 .931 r
.76536 .57384 .76988 .57897 .7802 .5761 .77571 .57096 Mtetra
.653 .763 .931 r
.77571 .57096 .7802 .5761 .79056 .57319 .78609 .56803 Mtetra
.654 .764 .93 r
.78609 .56803 .79056 .57319 .80095 .57024 .79651 .56505 Mtetra
.656 .764 .929 r
.79651 .56505 .80095 .57024 .81138 .56724 .80696 .56201 Mtetra
.658 .764 .928 r
.80696 .56201 .81138 .56724 .82184 .56421 .81745 .55892 Mtetra
.659 .763 .926 r
.81745 .55892 .82184 .56421 .83233 .56114 .82797 .55579 Mtetra
.66 .762 .925 r
.82797 .55579 .83233 .56114 .84286 .55804 .83852 .55263 Mtetra
.661 .76 .924 r
.83852 .55263 .84286 .55804 .85343 .55492 .84912 .54945 Mtetra
.661 .759 .923 r
.84912 .54945 .85343 .55492 .86404 .55179 .85975 .54626 Mtetra
.66 .757 .922 r
.85975 .54626 .86404 .55179 .87468 .54865 .87042 .54308 Mtetra
.66 .756 .921 r
.87042 .54308 .87468 .54865 .88537 .54551 .88113 .53989 Mtetra
.659 .755 .921 r
.88113 .53989 .88537 .54551 .89609 .54237 .89188 .53671 Mtetra
.659 .754 .92 r
.89188 .53671 .89609 .54237 .90686 .53923 .90267 .53354 Mtetra
.658 .753 .92 r
.90267 .53354 .90686 .53923 .91766 .5361 .91351 .53038 Mtetra
.657 .752 .92 r
.91351 .53038 .91766 .5361 .92851 .53296 .92438 .52721 Mtetra
.92438 .52721 .92851 .53296 .9394 .52982 .9353 .52405 Mtetra
.9353 .52405 .9394 .52982 .95032 .52668 .94626 .52089 Mtetra
.656 .752 .92 r
.94626 .52089 .95032 .52668 .96129 .52353 .95725 .51772 Mtetra
.95725 .51772 .96129 .52353 .9723 .52037 .96829 .51454 Mtetra
.655 .751 .92 r
.37472 .67831 .38018 .68308 .38918 .68051 .38373 .67572 Mtetra
.38373 .67572 .38918 .68051 .3982 .67794 .39278 .67313 Mtetra
.39278 .67313 .3982 .67794 .40726 .67537 .40185 .67054 Mtetra
.40185 .67054 .40726 .67537 .41635 .6728 .41096 .66795 Mtetra
.654 .75 .92 r
.41096 .66795 .41635 .6728 .42546 .67023 .4201 .66536 Mtetra
.653 .75 .921 r
.4201 .66536 .42546 .67023 .43461 .66766 .42927 .66278 Mtetra
.652 .75 .921 r
.42927 .66278 .43461 .66766 .44379 .6651 .43847 .66021 Mtetra
.651 .75 .922 r
.43847 .66021 .44379 .6651 .453 .66256 .4477 .65765 Mtetra
.65 .75 .922 r
.4477 .65765 .453 .66256 .46225 .66002 .45696 .65511 Mtetra
.649 .75 .923 r
.45696 .65511 .46225 .66002 .47152 .65748 .46625 .65259 Mtetra
.648 .751 .924 r
.46625 .65259 .47152 .65748 .48083 .65495 .47558 .65007 Mtetra
.648 .752 .925 r
.47558 .65007 .48083 .65495 .49016 .65241 .48494 .64755 Mtetra
.647 .754 .927 r
.48494 .64755 .49016 .65241 .49954 .64985 .49433 .64503 Mtetra
.648 .756 .928 r
.49433 .64503 .49954 .64985 .50894 .64727 .50375 .64248 Mtetra
.649 .758 .929 r
.50375 .64248 .50894 .64727 .51838 .64465 .51321 .63989 Mtetra
.651 .76 .93 r
.51321 .63989 .51838 .64465 .52785 .64198 .52271 .63724 Mtetra
.653 .763 .93 r
.52271 .63724 .52785 .64198 .53735 .63926 .53223 .63453 Mtetra
.656 .764 .93 r
.53223 .63453 .53735 .63926 .54689 .63649 .54179 .63176 Mtetra
.658 .766 .929 r
.54179 .63176 .54689 .63649 .55646 .63367 .55138 .62891 Mtetra
.66 .766 .928 r
.55138 .62891 .55646 .63367 .56606 .6308 .56101 .62601 Mtetra
.661 .766 .927 r
.56101 .62601 .56606 .6308 .57569 .62791 .57066 .62307 Mtetra
.662 .765 .926 r
.57066 .62307 .57569 .62791 .58536 .625 .58035 .6201 Mtetra
.662 .763 .925 r
.58035 .6201 .58536 .625 .59506 .62208 .59007 .61713 Mtetra
.662 .761 .924 r
.59007 .61713 .59506 .62208 .60479 .61917 .59983 .61416 Mtetra
.661 .76 .923 r
.59983 .61416 .60479 .61917 .61456 .61627 .60962 .6112 Mtetra
.66 .758 .922 r
.60962 .6112 .61456 .61627 .62436 .61337 .61944 .60826 Mtetra
.659 .756 .922 r
.61944 .60826 .62436 .61337 .63419 .61049 .6293 .60534 Mtetra
.658 .755 .922 r
.6293 .60534 .63419 .61049 .64406 .60762 .63919 .60244 Mtetra
.657 .754 .922 r
.63919 .60244 .64406 .60762 .65397 .60477 .64912 .59956 Mtetra
.656 .754 .922 r
.64912 .59956 .65397 .60477 .66391 .60192 .65909 .59669 Mtetra
.654 .753 .922 r
.65909 .59669 .66391 .60192 .67389 .59908 .66909 .59384 Mtetra
.653 .753 .923 r
.66909 .59384 .67389 .59908 .6839 .59625 .67913 .59101 Mtetra
.652 .753 .924 r
.67913 .59101 .6839 .59625 .69395 .59343 .68921 .58819 Mtetra
.651 .754 .925 r
.68921 .58819 .69395 .59343 .70404 .59063 .69932 .5854 Mtetra
.649 .754 .926 r
.69932 .5854 .70404 .59063 .71417 .58783 .70948 .58262 Mtetra
.648 .755 .928 r
.70948 .58262 .71417 .58783 .72433 .58505 .71967 .57986 Mtetra
.647 .757 .929 r
.71967 .57986 .72433 .58505 .73453 .58227 .7299 .5771 Mtetra
.647 .758 .93 r
.7299 .5771 .73453 .58227 .74477 .57948 .74016 .57433 Mtetra
.647 .76 .931 r
.74016 .57433 .74477 .57948 .75505 .57668 .75047 .57154 Mtetra
.649 .762 .932 r
.75047 .57154 .75505 .57668 .76536 .57384 .76081 .5687 Mtetra
.65 .763 .932 r
.76081 .5687 .76536 .57384 .77571 .57096 .77119 .56581 Mtetra
.653 .764 .931 r
.77119 .56581 .77571 .57096 .78609 .56803 .7816 .56285 Mtetra
.655 .765 .93 r
.7816 .56285 .78609 .56803 .79651 .56505 .79204 .55981 Mtetra
.658 .764 .928 r
.79204 .55981 .79651 .56505 .80696 .56201 .80251 .55671 Mtetra
.66 .763 .926 r
.80251 .55671 .80696 .56201 .81745 .55892 .81302 .55355 Mtetra
.661 .762 .925 r
.81302 .55355 .81745 .55892 .82797 .55579 .82357 .55035 Mtetra
.662 .76 .923 r
.82357 .55035 .82797 .55579 .83852 .55263 .83415 .54713 Mtetra
.662 .758 .921 r
.83415 .54713 .83852 .55263 .84912 .54945 .84477 .54389 Mtetra
.662 .757 .92 r
.84477 .54389 .84912 .54945 .85975 .54626 .85542 .54064 Mtetra
.661 .755 .92 r
.85542 .54064 .85975 .54626 .87042 .54308 .86612 .53741 Mtetra
.661 .754 .919 r
.86612 .53741 .87042 .54308 .88113 .53989 .87686 .53419 Mtetra
.66 .753 .919 r
.87686 .53419 .88113 .53989 .89188 .53671 .88764 .53098 Mtetra
.659 .752 .919 r
.88764 .53098 .89188 .53671 .90267 .53354 .89846 .52778 Mtetra
.658 .752 .919 r
.89846 .52778 .90267 .53354 .91351 .53038 .90932 .52459 Mtetra
.657 .751 .919 r
.90932 .52459 .91351 .53038 .92438 .52721 .92022 .52141 Mtetra
.92022 .52141 .92438 .52721 .9353 .52405 .93117 .51823 Mtetra
.657 .751 .92 r
.93117 .51823 .9353 .52405 .94626 .52089 .94216 .51505 Mtetra
.656 .751 .92 r
.94216 .51505 .94626 .52089 .95725 .51772 .95319 .51186 Mtetra
.95319 .51186 .95725 .51772 .96829 .51454 .96426 .50866 Mtetra
.36922 .67351 .37472 .67831 .38373 .67572 .37826 .67091 Mtetra
.37826 .67091 .38373 .67572 .39278 .67313 .38732 .66829 Mtetra
.655 .751 .92 r
.38732 .66829 .39278 .67313 .40185 .67054 .39642 .66567 Mtetra
.655 .75 .92 r
.39642 .66567 .40185 .67054 .41096 .66795 .40554 .66305 Mtetra
.654 .75 .92 r
.40554 .66305 .41096 .66795 .4201 .66536 .4147 .66044 Mtetra
.654 .749 .92 r
.4147 .66044 .4201 .66536 .42927 .66278 .42389 .65784 Mtetra
.653 .749 .92 r
.42389 .65784 .42927 .66278 .43847 .66021 .43311 .65525 Mtetra
.652 .748 .92 r
.43311 .65525 .43847 .66021 .4477 .65765 .44236 .65267 Mtetra
.65 .748 .921 r
.44236 .65267 .4477 .65765 .45696 .65511 .45164 .65012 Mtetra
.649 .748 .922 r
.45164 .65012 .45696 .65511 .46625 .65259 .46095 .6476 Mtetra
.647 .748 .923 r
.46095 .6476 .46625 .65259 .47558 .65007 .4703 .64509 Mtetra
.646 .749 .924 r
.4703 .64509 .47558 .65007 .48494 .64755 .47968 .64259 Mtetra
.646 .75 .925 r
.47968 .64259 .48494 .64755 .49433 .64503 .48909 .6401 Mtetra
.646 .752 .927 r
.48909 .6401 .49433 .64503 .50375 .64248 .49854 .63759 Mtetra
.647 .755 .928 r
.49854 .63759 .50375 .64248 .51321 .63989 .50802 .63505 Mtetra
.648 .758 .929 r
.50802 .63505 .51321 .63989 .52271 .63724 .51753 .63244 Mtetra
.651 .761 .93 r
.51753 .63244 .52271 .63724 .53223 .63453 .52708 .62976 Mtetra
.654 .764 .93 r
.52708 .62976 .53223 .63453 .54179 .63176 .53666 .627 Mtetra
.657 .766 .93 r
.53666 .627 .54179 .63176 .55138 .62891 .54627 .62415 Mtetra
.66 .767 .929 r
.54627 .62415 .55138 .62891 .56101 .62601 .55592 .62123 Mtetra
.662 .768 .928 r
.55592 .62123 .56101 .62601 .57066 .62307 .5656 .61825 Mtetra
.664 .767 .927 r
.5656 .61825 .57066 .62307 .58035 .6201 .57531 .61523 Mtetra
.664 .766 .926 r
.57531 .61523 .58035 .6201 .59007 .61713 .58506 .61219 Mtetra
.663 .764 .925 r
.58506 .61219 .59007 .61713 .59983 .61416 .59484 .60916 Mtetra
.662 .762 .924 r
.59484 .60916 .59983 .61416 .60962 .6112 .60465 .60614 Mtetra
.661 .76 .923 r
.60465 .60614 .60962 .6112 .61944 .60826 .6145 .60315 Mtetra
.66 .758 .923 r
.6145 .60315 .61944 .60826 .6293 .60534 .62438 .60019 Mtetra
.658 .756 .922 r
.62438 .60019 .6293 .60534 .63919 .60244 .63429 .59725 Mtetra
.657 .755 .922 r
.63429 .59725 .63919 .60244 .64912 .59956 .64425 .59434 Mtetra
.655 .754 .923 r
.64425 .59434 .64912 .59956 .65909 .59669 .65424 .59145 Mtetra
.654 .754 .923 r
.65424 .59145 .65909 .59669 .66909 .59384 .66426 .58859 Mtetra
.652 .754 .924 r
.66426 .58859 .66909 .59384 .67913 .59101 .67433 .58576 Mtetra
.651 .754 .925 r
.67433 .58576 .67913 .59101 .68921 .58819 .68443 .58295 Mtetra
.649 .754 .926 r
.68443 .58295 .68921 .58819 .69932 .5854 .69457 .58017 Mtetra
.647 .755 .928 r
.69457 .58017 .69932 .5854 .70948 .58262 .70475 .57741 Mtetra
.646 .756 .929 r
.70475 .57741 .70948 .58262 .71967 .57986 .71497 .57468 Mtetra
.645 .758 .931 r
.71497 .57468 .71967 .57986 .7299 .5771 .72523 .57194 Mtetra
.645 .76 .932 r
.72523 .57194 .7299 .5771 .74016 .57433 .73553 .56919 Mtetra
.646 .761 .933 r
.73553 .56919 .74016 .57433 .75047 .57154 .74586 .5664 Mtetra
.648 .763 .933 r
.74586 .5664 .75047 .57154 .76081 .5687 .75623 .56355 Mtetra
.651 .764 .932 r
.75623 .56355 .76081 .5687 .77119 .56581 .76663 .56063 Mtetra
.654 .765 .931 r
.76663 .56063 .77119 .56581 .7816 .56285 .77707 .55761 Mtetra
.657 .765 .929 r
.77707 .55761 .7816 .56285 .79204 .55981 .78753 .55451 Mtetra
.66 .764 .927 r
.78753 .55451 .79204 .55981 .80251 .55671 .79803 .55133 Mtetra
.663 .762 .924 r
.79803 .55133 .80251 .55671 .81302 .55355 .80857 .54809 Mtetra
.664 .76 .922 r
.80857 .54809 .81302 .55355 .82357 .55035 .81913 .54481 Mtetra
.664 .758 .92 r
.81913 .54481 .82357 .55035 .83415 .54713 .82974 .54151 Mtetra
.664 .756 .919 r
.82974 .54151 .83415 .54713 .84477 .54389 .84038 .53821 Mtetra
.663 .754 .918 r
.84038 .53821 .84477 .54389 .85542 .54064 .85106 .53491 Mtetra
.662 .753 .917 r
.85106 .53491 .85542 .54064 .86612 .53741 .86178 .53164 Mtetra
.661 .752 .917 r
.86178 .53164 .86612 .53741 .87686 .53419 .87255 .52839 Mtetra
.66 .751 .918 r
.87255 .52839 .87686 .53419 .88764 .53098 .88336 .52516 Mtetra
.659 .751 .918 r
.88336 .52516 .88764 .53098 .89846 .52778 .89421 .52195 Mtetra
.658 .75 .918 r
.89421 .52195 .89846 .52778 .90932 .52459 .9051 .51874 Mtetra
.657 .75 .919 r
.9051 .51874 .90932 .52459 .92022 .52141 .91603 .51555 Mtetra
.91603 .51555 .92022 .52141 .93117 .51823 .92701 .51236 Mtetra
.656 .751 .919 r
.92701 .51236 .93117 .51823 .94216 .51505 .93803 .50916 Mtetra
.656 .751 .92 r
.93803 .50916 .94216 .51505 .95319 .51186 .94909 .50596 Mtetra
.94909 .50596 .95319 .51186 .96426 .50866 .9602 .50275 Mtetra
.36369 .66869 .36922 .67351 .37826 .67091 .37275 .66605 Mtetra
.37275 .66605 .37826 .67091 .38732 .66829 .38183 .66341 Mtetra
.38183 .66341 .38732 .66829 .39642 .66567 .39095 .66077 Mtetra
.656 .75 .919 r
.39095 .66077 .39642 .66567 .40554 .66305 .40009 .65812 Mtetra
.655 .75 .919 r
.40009 .65812 .40554 .66305 .4147 .66044 .40927 .65547 Mtetra
.654 .749 .919 r
.40927 .65547 .4147 .66044 .42389 .65784 .41848 .65284 Mtetra
.654 .748 .919 r
.41848 .65284 .42389 .65784 .43311 .65525 .42771 .65021 Mtetra
.652 .747 .919 r
.42771 .65021 .43311 .65525 .44236 .65267 .43698 .64761 Mtetra
.651 .746 .919 r
.43698 .64761 .44236 .65267 .45164 .65012 .44629 .64504 Mtetra
.649 .745 .92 r
.44629 .64504 .45164 .65012 .46095 .6476 .45562 .6425 Mtetra
.647 .745 .921 r
.45562 .6425 .46095 .6476 .4703 .64509 .46498 .63999 Mtetra
.645 .745 .922 r
.46498 .63999 .4703 .64509 .47968 .64259 .47438 .63751 Mtetra
.644 .746 .923 r
.47438 .63751 .47968 .64259 .48909 .6401 .48382 .63506 Mtetra
.643 .748 .925 r
.48382 .63506 .48909 .6401 .49854 .63759 .49328 .6326 Mtetra
.643 .751 .927 r
.49328 .6326 .49854 .63759 .50802 .63505 .50278 .63011 Mtetra
.645 .754 .929 r
.50278 .63011 .50802 .63505 .51753 .63244 .51232 .62758 Mtetra
.648 .758 .93 r
.51232 .62758 .51753 .63244 .52708 .62976 .52189 .62495 Mtetra
.652 .763 .931 r
.52189 .62495 .52708 .62976 .53666 .627 .53149 .62223 Mtetra
.656 .766 .931 r
.53149 .62223 .53666 .627 .54627 .62415 .54113 .6194 Mtetra
.66 .769 .93 r
.54113 .6194 .54627 .62415 .55592 .62123 .5508 .61647 Mtetra
.663 .77 .929 r
.5508 .61647 .55592 .62123 .5656 .61825 .56051 .61345 Mtetra
.665 .77 .928 r
.56051 .61345 .5656 .61825 .57531 .61523 .57024 .61037 Mtetra
.666 .769 .927 r
.57024 .61037 .57531 .61523 .58506 .61219 .58001 .60727 Mtetra
.665 .767 .925 r
.58001 .60727 .58506 .61219 .59484 .60916 .58981 .60417 Mtetra
.664 .764 .924 r
.58981 .60417 .59484 .60916 .60465 .60614 .59965 .60109 Mtetra
.663 .762 .924 r
.59965 .60109 .60465 .60614 .6145 .60315 .60952 .59804 Mtetra
.661 .76 .923 r
.60952 .59804 .6145 .60315 .62438 .60019 .61942 .59503 Mtetra
.659 .758 .923 r
.61942 .59503 .62438 .60019 .63429 .59725 .62936 .59205 Mtetra
.657 .757 .923 r
.62936 .59205 .63429 .59725 .64425 .59434 .63934 .58911 Mtetra
.655 .755 .923 r
.63934 .58911 .64425 .59434 .65424 .59145 .64935 .5862 Mtetra
.653 .755 .924 r
.64935 .5862 .65424 .59145 .66426 .58859 .65941 .58333 Mtetra
.651 .755 .925 r
.65941 .58333 .66426 .58859 .67433 .58576 .6695 .5805 Mtetra
.649 .755 .926 r
.6695 .5805 .67433 .58576 .68443 .58295 .67962 .57771 Mtetra
.647 .755 .928 r
.67962 .57771 .68443 .58295 .69457 .58017 .68979 .57495 Mtetra
.645 .756 .93 r
.68979 .57495 .69457 .58017 .70475 .57741 .7 .57222 Mtetra
.644 .758 .932 r
.7 .57222 .70475 .57741 .71497 .57468 .71025 .56952 Mtetra
.643 .759 .933 r
.71025 .56952 .71497 .57468 .72523 .57194 .72054 .56681 Mtetra
.643 .761 .935 r
.72054 .56681 .72523 .57194 .73553 .56919 .73086 .56407 Mtetra
.645 .763 .935 r
.73086 .56407 .73553 .56919 .74586 .5664 .74123 .56129 Mtetra
.648 .765 .934 r
.74123 .56129 .74586 .5664 .75623 .56355 .75162 .55841 Mtetra
.652 .766 .933 r
.75162 .55841 .75623 .56355 .76663 .56063 .76205 .55543 Mtetra
.657 .767 .931 r
.76205 .55543 .76663 .56063 .77707 .55761 .77251 .55233 Mtetra
.661 .766 .928 r
.77251 .55233 .77707 .55761 .78753 .55451 .783 .54914 Mtetra
.664 .764 .924 r
.783 .54914 .78753 .55451 .79803 .55133 .79352 .54585 Mtetra
.666 .761 .921 r
.79352 .54585 .79803 .55133 .80857 .54809 .80407 .54251 Mtetra
.667 .758 .919 r
.80407 .54251 .80857 .54809 .81913 .54481 .81466 .53913 Mtetra
.667 .756 .917 r
.81466 .53913 .81913 .54481 .82974 .54151 .82529 .53576 Mtetra
.666 .753 .916 r
.82529 .53576 .82974 .54151 .84038 .53821 .83595 .5324 Mtetra
.664 .751 .915 r
.83595 .5324 .84038 .53821 .85106 .53491 .84666 .52907 Mtetra
.663 .75 .915 r
.84666 .52907 .85106 .53491 .86178 .53164 .85741 .52577 Mtetra
.661 .749 .915 r
.85741 .52577 .86178 .53164 .87255 .52839 .86821 .5225 Mtetra
.66 .749 .916 r
.86821 .5225 .87255 .52839 .88336 .52516 .87905 .51927 Mtetra
.658 .749 .917 r
.87905 .51927 .88336 .52516 .89421 .52195 .88993 .51605 Mtetra
.657 .749 .918 r
.88993 .51605 .89421 .52195 .9051 .51874 .90085 .51284 Mtetra
.90085 .51284 .9051 .51874 .91603 .51555 .91182 .50964 Mtetra
.656 .75 .919 r
.91182 .50964 .91603 .51555 .92701 .51236 .92283 .50644 Mtetra
.92283 .50644 .92701 .51236 .93803 .50916 .93388 .50323 Mtetra
.656 .751 .92 r
.93388 .50323 .93803 .50916 .94909 .50596 .94497 .50002 Mtetra
.94497 .50002 .94909 .50596 .9602 .50275 .9561 .4968 Mtetra
.656 .752 .92 r
.35813 .66383 .36369 .66869 .37275 .66605 .3672 .66118 Mtetra
.656 .751 .92 r
.3672 .66118 .37275 .66605 .38183 .66341 .3763 .65851 Mtetra
.3763 .65851 .38183 .66341 .39095 .66077 .38544 .65584 Mtetra
.656 .751 .919 r
.38544 .65584 .39095 .66077 .40009 .65812 .3946 .65316 Mtetra
.656 .75 .919 r
.3946 .65316 .40009 .65812 .40927 .65547 .4038 .65048 Mtetra
.655 .749 .919 r
.4038 .65048 .40927 .65547 .41848 .65284 .41303 .6478 Mtetra
.655 .748 .919 r
.41303 .6478 .41848 .65284 .42771 .65021 .42229 .64514 Mtetra
.653 .747 .918 r
.42229 .64514 .42771 .65021 .43698 .64761 .43158 .64249 Mtetra
.652 .745 .918 r
.43158 .64249 .43698 .64761 .44629 .64504 .4409 .63988 Mtetra
.65 .744 .918 r
.4409 .63988 .44629 .64504 .45562 .6425 .45025 .6373 Mtetra
.647 .742 .919 r
.45025 .6373 .45562 .6425 .46498 .63999 .45964 .63478 Mtetra
.645 .742 .92 r
.45964 .63478 .46498 .63999 .47438 .63751 .46906 .6323 Mtetra
.642 .742 .921 r
.46906 .6323 .47438 .63751 .48382 .63506 .47851 .62987 Mtetra
.641 .743 .923 r
.47851 .62987 .48382 .63506 .49328 .6326 .488 .62746 Mtetra
.64 .745 .925 r
.488 .62746 .49328 .6326 .50278 .63011 .49752 .62506 Mtetra
.641 .749 .927 r
.49752 .62506 .50278 .63011 .51232 .62758 .50707 .6226 Mtetra
.644 .754 .929 r
.50707 .6226 .51232 .62758 .52189 .62495 .51667 .62007 Mtetra
.648 .76 .931 r
.51667 .62007 .52189 .62495 .53149 .62223 .52629 .61742 Mtetra
.653 .765 .931 r
.52629 .61742 .53149 .62223 .54113 .6194 .53595 .61463 Mtetra
.658 .769 .931 r
.53595 .61463 .54113 .6194 .5508 .61647 .54565 .61172 Mtetra
.663 .772 .931 r
.54565 .61172 .5508 .61647 .56051 .61345 .55538 .60868 Mtetra
.666 .773 .929 r
.55538 .60868 .56051 .61345 .57024 .61037 .56514 .60556 Mtetra
.667 .772 .928 r
.56514 .60556 .57024 .61037 .58001 .60727 .57493 .6024 Mtetra
.667 .77 .927 r
.57493 .6024 .58001 .60727 .58981 .60417 .58475 .59923 Mtetra
.666 .768 .926 r
.58475 .59923 .58981 .60417 .59965 .60109 .59461 .59607 Mtetra
.665 .765 .925 r
.59461 .59607 .59965 .60109 .60952 .59804 .6045 .59295 Mtetra
.662 .762 .924 r
.6045 .59295 .60952 .59804 .61942 .59503 .61443 .58988 Mtetra
.66 .76 .924 r
.61443 .58988 .61942 .59503 .62936 .59205 .6244 .58686 Mtetra
.658 .758 .924 r
.6244 .58686 .62936 .59205 .63934 .58911 .6344 .58389 Mtetra
.655 .757 .925 r
.6344 .58389 .63934 .58911 .64935 .5862 .64444 .58096 Mtetra
.653 .756 .926 r
.64444 .58096 .64935 .5862 .65941 .58333 .65452 .57809 Mtetra
.65 .756 .927 r
.65452 .57809 .65941 .58333 .6695 .5805 .66463 .57526 Mtetra
.647 .756 .928 r
.66463 .57526 .6695 .5805 .67962 .57771 .67479 .57249 Mtetra
.645 .757 .93 r
.67479 .57249 .67962 .57771 .68979 .57495 .68498 .56976 Mtetra
.642 .758 .933 r
.68498 .56976 .68979 .57495 .7 .57222 .69522 .56707 Mtetra
.641 .76 .935 r
.69522 .56707 .7 .57222 .71025 .56952 .7055 .5644 Mtetra
.64 .762 .936 r
.7055 .5644 .71025 .56952 .72054 .56681 .71582 .56172 Mtetra
.642 .764 .937 r
.71582 .56172 .72054 .56681 .73086 .56407 .72617 .55899 Mtetra
.645 .766 .937 r
.72617 .55899 .73086 .56407 .74123 .56129 .73656 .55618 Mtetra
.649 .768 .935 r
.73656 .55618 .74123 .56129 .75162 .55841 .74698 .55325 Mtetra
.655 .768 .933 r
.74698 .55325 .75162 .55841 .76205 .55543 .75743 .55018 Mtetra
.66 .767 .929 r
.75743 .55018 .76205 .55543 .77251 .55233 .76791 .54697 Mtetra
.665 .765 .925 r
.76791 .54697 .77251 .55233 .783 .54914 .77842 .54365 Mtetra
.668 .762 .921 r
.77842 .54365 .783 .54914 .79352 .54585 .78896 .54024 Mtetra
.67 .759 .917 r
.78896 .54024 .79352 .54585 .80407 .54251 .79953 .53678 Mtetra
.67 .755 .915 r
.79953 .53678 .80407 .54251 .81466 .53913 .81015 .53331 Mtetra
.668 .752 .913 r
.81015 .53331 .81466 .53913 .82529 .53576 .8208 .52987 Mtetra
.666 .75 .912 r
.8208 .52987 .82529 .53576 .83595 .5324 .83149 .52647 Mtetra
.664 .748 .913 r
.83149 .52647 .83595 .5324 .84666 .52907 .84223 .52312 Mtetra
.662 .747 .913 r
.84223 .52312 .84666 .52907 .85741 .52577 .85301 .51981 Mtetra
.66 .747 .914 r
.85301 .51981 .85741 .52577 .86821 .5225 .86383 .51655 Mtetra
.659 .747 .916 r
.86383 .51655 .86821 .5225 .87905 .51927 .8747 .51332 Mtetra
.657 .748 .917 r
.8747 .51332 .87905 .51927 .88993 .51605 .88562 .5101 Mtetra
.657 .749 .918 r
.88562 .5101 .88993 .51605 .90085 .51284 .89657 .5069 Mtetra
.656 .749 .919 r
.89657 .5069 .90085 .51284 .91182 .50964 .90757 .50369 Mtetra
.656 .75 .919 r
.90757 .50369 .91182 .50964 .92283 .50644 .91861 .50048 Mtetra
.655 .75 .92 r
.91861 .50048 .92283 .50644 .93388 .50323 .92969 .49727 Mtetra
.655 .751 .92 r
.92969 .49727 .93388 .50323 .94497 .50002 .94082 .49404 Mtetra
.94082 .49404 .94497 .50002 .9561 .4968 .95198 .4908 Mtetra
.656 .752 .92 r
.35253 .65894 .35813 .66383 .3672 .66118 .36162 .65627 Mtetra
.36162 .65627 .3672 .66118 .3763 .65851 .37074 .65359 Mtetra
.657 .752 .92 r
.37074 .65359 .3763 .65851 .38544 .65584 .3799 .65089 Mtetra
.657 .751 .92 r
.3799 .65089 .38544 .65584 .3946 .65316 .38908 .64819 Mtetra
.657 .751 .919 r
.38908 .64819 .3946 .65316 .4038 .65048 .3983 .64547 Mtetra
.657 .75 .919 r
.3983 .64547 .4038 .65048 .41303 .6478 .40755 .64275 Mtetra
.656 .749 .918 r
.40755 .64275 .41303 .6478 .42229 .64514 .41683 .64003 Mtetra
.655 .747 .918 r
.41683 .64003 .42229 .64514 .43158 .64249 .42614 .63733 Mtetra
.654 .745 .917 r
.42614 .63733 .43158 .64249 .4409 .63988 .43548 .63465 Mtetra
.652 .743 .917 r
.43548 .63465 .4409 .63988 .45025 .6373 .44486 .63202 Mtetra
.649 .741 .917 r
.44486 .63202 .45025 .6373 .45964 .63478 .45426 .62945 Mtetra
.645 .739 .917 r
.45426 .62945 .45964 .63478 .46906 .6323 .4637 .62695 Mtetra
.641 .737 .918 r
.4637 .62695 .46906 .6323 .47851 .62987 .47317 .62453 Mtetra
.639 .737 .92 r
.47317 .62453 .47851 .62987 .488 .62746 .48268 .62217 Mtetra
.636 .739 .923 r
.48268 .62217 .488 .62746 .49752 .62506 .49222 .61984 Mtetra
.636 .743 .926 r
.49222 .61984 .49752 .62506 .50707 .6226 .5018 .61749 Mtetra
.638 .748 .929 r
.5018 .61749 .50707 .6226 .51667 .62007 .51141 .61508 Mtetra
.642 .755 .931 r
.51141 .61508 .51667 .62007 .52629 .61742 .52106 .61255 Mtetra
.648 .763 .932 r
.52106 .61255 .52629 .61742 .53595 .61463 .53074 .60985 Mtetra
.655 .769 .933 r
.53074 .60985 .53595 .61463 .54565 .61172 .54046 .60699 Mtetra
.661 .773 .933 r
.54046 .60699 .54565 .61172 .55538 .60868 .55021 .60396 Mtetra
.666 .776 .931 r
.55021 .60396 .55538 .60868 .56514 .60556 .56 .60081 Mtetra
.669 .776 .93 r
.56 .60081 .56514 .60556 .57493 .6024 .56981 .59758 Mtetra
.669 .774 .928 r
.56981 .59758 .57493 .6024 .58475 .59923 .57966 .59433 Mtetra
.669 .772 .927 r
.57966 .59433 .58475 .59923 .59461 .59607 .58955 .5911 Mtetra
.667 .769 .926 r
.58955 .5911 .59461 .59607 .6045 .59295 .59946 .5879 Mtetra
.664 .766 .926 r
.59946 .5879 .6045 .59295 .61443 .58988 .60941 .58477 Mtetra
.661 .763 .925 r
.60941 .58477 .61443 .58988 .6244 .58686 .6194 .58169 Mtetra
.658 .761 .926 r
.6194 .58169 .6244 .58686 .6344 .58389 .62943 .57868 Mtetra
.655 .759 .926 r
.62943 .57868 .6344 .58389 .64444 .58096 .63949 .57574 Mtetra
.652 .758 .927 r
.63949 .57574 .64444 .58096 .65452 .57809 .6496 .57286 Mtetra
.648 .758 .929 r
.6496 .57286 .65452 .57809 .66463 .57526 .65974 .57005 Mtetra
.645 .758 .931 r
.65974 .57005 .66463 .57526 .67479 .57249 .66992 .5673 Mtetra
.642 .759 .933 r
.66992 .5673 .67479 .57249 .68498 .56976 .68015 .56461 Mtetra
.639 .76 .936 r
.68015 .56461 .68498 .56976 .69522 .56707 .69041 .56197 Mtetra
.637 .762 .938 r
.69041 .56197 .69522 .56707 .7055 .5644 .70072 .55933 Mtetra
.638 .764 .94 r
.70072 .55933 .7055 .5644 .71582 .56172 .71107 .55668 Mtetra
.64 .767 .94 r
.71107 .55668 .71582 .56172 .72617 .55899 .72145 .55394 Mtetra
.645 .769 .939 r
.72145 .55394 .72617 .55899 .73656 .55618 .73186 .55109 Mtetra
.652 .771 .936 r
.73186 .55109 .73656 .55618 .74698 .55325 .74231 .54807 Mtetra
.659 .77 .932 r
.74231 .54807 .74698 .55325 .75743 .55018 .75278 .54487 Mtetra
.666 .768 .926 r
.75278 .54487 .75743 .55018 .76791 .54697 .76328 .54151 Mtetra
.671 .765 .921 r
.76328 .54151 .76791 .54697 .77842 .54365 .7738 .53802 Mtetra
.673 .76 .916 r
.7738 .53802 .77842 .54365 .78896 .54024 .78436 .53446 Mtetra
.674 .755 .912 r
.78436 .53446 .78896 .54024 .79953 .53678 .79496 .53087 Mtetra
.672 .751 .91 r
.79496 .53087 .79953 .53678 .81015 .53331 .80559 .52732 Mtetra
.67 .748 .909 r
.80559 .52732 .81015 .53331 .8208 .52987 .81627 .52383 Mtetra
.666 .746 .909 r
.81627 .52383 .8208 .52987 .83149 .52647 .82699 .52041 Mtetra
.663 .745 .911 r
.82699 .52041 .83149 .52647 .84223 .52312 .83776 .51707 Mtetra
.661 .745 .912 r
.83776 .51707 .84223 .52312 .85301 .51981 .84857 .51378 Mtetra
.659 .745 .914 r
.84857 .51378 .85301 .51981 .86383 .51655 .85943 .51054 Mtetra
.657 .746 .916 r
.85943 .51054 .86383 .51655 .8747 .51332 .87033 .50733 Mtetra
.656 .747 .917 r
.87033 .50733 .8747 .51332 .88562 .5101 .88128 .50413 Mtetra
.655 .749 .918 r
.88128 .50413 .88562 .5101 .89657 .5069 .89227 .50093 Mtetra
.655 .75 .919 r
.89227 .50093 .89657 .5069 .90757 .50369 .9033 .49772 Mtetra
.655 .75 .92 r
.9033 .49772 .90757 .50369 .91861 .50048 .91437 .4945 Mtetra
.655 .751 .92 r
.91437 .4945 .91861 .50048 .92969 .49727 .92548 .49127 Mtetra
.92548 .49127 .92969 .49727 .94082 .49404 .93664 .48802 Mtetra
.93664 .48802 .94082 .49404 .95198 .4908 .94784 .48476 Mtetra
.656 .751 .92 r
.34689 .65403 .35253 .65894 .36162 .65627 .356 .65134 Mtetra
.656 .752 .92 r
.356 .65134 .36162 .65627 .37074 .65359 .36515 .64865 Mtetra
.36515 .64865 .37074 .65359 .3799 .65089 .37432 .64594 Mtetra
.657 .752 .92 r
.37432 .64594 .3799 .65089 .38908 .64819 .38353 .64321 Mtetra
.38353 .64321 .38908 .64819 .3983 .64547 .39276 .64047 Mtetra
.39276 .64047 .3983 .64547 .40755 .64275 .40203 .63771 Mtetra
.658 .751 .919 r
.40203 .63771 .40755 .64275 .41683 .64003 .41133 .63493 Mtetra
.657 .749 .918 r
.41133 .63493 .41683 .64003 .42614 .63733 .42067 .63216 Mtetra
.656 .747 .917 r
.42067 .63216 .42614 .63733 .43548 .63465 .43003 .62941 Mtetra
.654 .744 .916 r
.43003 .62941 .43548 .63465 .44486 .63202 .43943 .62669 Mtetra
.651 .741 .915 r
.43943 .62669 .44486 .63202 .45426 .62945 .44885 .62405 Mtetra
.647 .738 .915 r
.44885 .62405 .45426 .62945 .4637 .62695 .45831 .62149 Mtetra
.642 .735 .916 r
.45831 .62149 .4637 .62695 .47317 .62453 .4678 .61904 Mtetra
.638 .733 .917 r
.4678 .61904 .47317 .62453 .48268 .62217 .47733 .61669 Mtetra
.633 .733 .92 r
.47733 .61669 .48268 .62217 .49222 .61984 .48689 .61444 Mtetra
.631 .735 .923 r
.48689 .61444 .49222 .61984 .5018 .61749 .49648 .61221 Mtetra
.631 .741 .927 r
.49648 .61221 .5018 .61749 .51141 .61508 .50612 .60995 Mtetra
.635 .748 .93 r
.50612 .60995 .51141 .61508 .52106 .61255 .51579 .60757 Mtetra
.642 .757 .933 r
.51579 .60757 .52106 .61255 .53074 .60985 .52549 .60501 Mtetra
.65 .766 .934 r
.52549 .60501 .53074 .60985 .54046 .60699 .53524 .60225 Mtetra
.658 .774 .934 r
.53524 .60225 .54046 .60699 .55021 .60396 .54501 .59927 Mtetra
.665 .778 .934 r
.54501 .59927 .55021 .60396 .56 .60081 .55482 .59612 Mtetra
.67 .78 .932 r
.55482 .59612 .56 .60081 .56981 .59758 .56467 .59284 Mtetra
.671 .779 .931 r
.56467 .59284 .56981 .59758 .57966 .59433 .57454 .58952 Mtetra
.671 .777 .929 r
.57454 .58952 .57966 .59433 .58955 .5911 .58445 .5862 Mtetra
.669 .774 .928 r
.58445 .5862 .58955 .5911 .59946 .5879 .59439 .58292 Mtetra
.666 .77 .928 r
.59439 .58292 .59946 .5879 .60941 .58477 .60436 .57971 Mtetra
.662 .767 .928 r
.60436 .57971 .60941 .58477 .6194 .58169 .61438 .57658 Mtetra
.659 .764 .928 r
.61438 .57658 .6194 .58169 .62943 .57868 .62443 .57353 Mtetra
.655 .762 .929 r
.62443 .57353 .62943 .57868 .63949 .57574 .63452 .57057 Mtetra
.651 .761 .93 r
.63452 .57057 .63949 .57574 .6496 .57286 .64464 .56769 Mtetra
.646 .76 .932 r
.64464 .56769 .6496 .57286 .65974 .57005 .65481 .5649 Mtetra
.642 .761 .935 r
.65481 .5649 .65974 .57005 .66992 .5673 .66503 .56218 Mtetra
.638 .761 .937 r
.66503 .56218 .66992 .5673 .68015 .56461 .67528 .55954 Mtetra
.635 .763 .94 r
.67528 .55954 .68015 .56461 .69041 .56197 .68558 .55694 Mtetra
.634 .765 .942 r
.68558 .55694 .69041 .56197 .70072 .55933 .69591 .55435 Mtetra
.635 .768 .943 r
.69591 .55435 .70072 .55933 .71107 .55668 .70629 .5517 Mtetra
.64 .771 .943 r
.70629 .5517 .71107 .55668 .72145 .55394 .7167 .54893 Mtetra
.647 .773 .94 r
.7167 .54893 .72145 .55394 .73186 .55109 .72714 .54599 Mtetra
.657 .774 .935 r
.72714 .54599 .73186 .55109 .74231 .54807 .7376 .54282 Mtetra
.666 .772 .929 r
.7376 .54282 .74231 .54807 .75278 .54487 .74809 .53945 Mtetra
.673 .768 .922 r
.74809 .53945 .75278 .54487 .76328 .54151 .75861 .53588 Mtetra
.677 .762 .915 r
.75861 .53588 .76328 .54151 .7738 .53802 .76915 .5322 Mtetra
.678 .756 .91 r
.76915 .5322 .7738 .53802 .78436 .53446 .77972 .52848 Mtetra
.677 .751 .907 r
.77972 .52848 .78436 .53446 .79496 .53087 .79034 .52478 Mtetra
.673 .746 .906 r
.79034 .52478 .79496 .53087 .80559 .52732 .801 .52117 Mtetra
.669 .743 .906 r
.801 .52117 .80559 .52732 .81627 .52383 .8117 .51767 Mtetra
.665 .742 .908 r
.8117 .51767 .81627 .52383 .82699 .52041 .82245 .51427 Mtetra
.661 .742 .91 r
.82245 .51427 .82699 .52041 .83776 .51707 .83325 .51097 Mtetra
.658 .743 .913 r
.83325 .51097 .83776 .51707 .84857 .51378 .8441 .50773 Mtetra
.656 .745 .915 r
.8441 .50773 .84857 .51378 .85943 .51054 .855 .50453 Mtetra
.655 .747 .917 r
.855 .50453 .85943 .51054 .87033 .50733 .86593 .50135 Mtetra
.654 .748 .919 r
.86593 .50135 .87033 .50733 .88128 .50413 .87691 .49816 Mtetra
.654 .75 .92 r
.87691 .49816 .88128 .50413 .89227 .50093 .88793 .49496 Mtetra
.654 .751 .921 r
.88793 .49496 .89227 .50093 .9033 .49772 .899 .49175 Mtetra
.655 .752 .921 r
.899 .49175 .9033 .49772 .91437 .4945 .9101 .48851 Mtetra
.9101 .48851 .91437 .4945 .92548 .49127 .92124 .48525 Mtetra
.92124 .48525 .92548 .49127 .93664 .48802 .93243 .48198 Mtetra
.656 .752 .921 r
.93243 .48198 .93664 .48802 .94784 .48476 .94366 .47868 Mtetra
.655 .751 .921 r
.34122 .64908 .34689 .65403 .356 .65134 .35035 .6464 Mtetra
.655 .752 .921 r
.35035 .6464 .356 .65134 .36515 .64865 .35951 .6437 Mtetra
.656 .753 .921 r
.35951 .6437 .36515 .64865 .37432 .64594 .3687 .64099 Mtetra
.656 .754 .922 r
.3687 .64099 .37432 .64594 .38353 .64321 .37793 .63826 Mtetra
.657 .754 .922 r
.37793 .63826 .38353 .64321 .39276 .64047 .38719 .63549 Mtetra
.658 .754 .921 r
.38719 .63549 .39276 .64047 .40203 .63771 .39648 .6327 Mtetra
.659 .754 .92 r
.39648 .6327 .40203 .63771 .41133 .63493 .4058 .62988 Mtetra
.659 .753 .919 r
.4058 .62988 .41133 .63493 .42067 .63216 .41515 .62704 Mtetra
.659 .751 .918 r
.41515 .62704 .42067 .63216 .43003 .62941 .42454 .62419 Mtetra
.658 .748 .916 r
.42454 .62419 .43003 .62941 .43943 .62669 .43396 .62137 Mtetra
.655 .743 .915 r
.43396 .62137 .43943 .62669 .44885 .62405 .44341 .6186 Mtetra
.651 .738 .913 r
.44341 .6186 .44885 .62405 .45831 .62149 .45289 .61593 Mtetra
.645 .733 .913 r
.45289 .61593 .45831 .62149 .4678 .61904 .4624 .6134 Mtetra
.639 .729 .914 r
.4624 .6134 .4678 .61904 .47733 .61669 .47195 .61102 Mtetra
.631 .726 .916 r
.47195 .61102 .47733 .61669 .48689 .61444 .48152 .60881 Mtetra
.626 .727 .919 r
.48152 .60881 .48689 .61444 .49648 .61221 .49114 .60669 Mtetra
.623 .731 .924 r
.49114 .60669 .49648 .61221 .50612 .60995 .50079 .60461 Mtetra
.626 .739 .929 r
.50079 .60461 .50612 .60995 .51579 .60757 .51048 .60244 Mtetra
.632 .75 .933 r
.51048 .60244 .51579 .60757 .52549 .60501 .52021 .60009 Mtetra
.641 .762 .936 r
.52021 .60009 .52549 .60501 .53524 .60225 .52998 .5975 Mtetra
.653 .773 .937 r
.52998 .5975 .53524 .60225 .54501 .59927 .53978 .59461 Mtetra
.662 .78 .937 r
.53978 .59461 .54501 .59927 .55482 .59612 .54962 .5915 Mtetra
.669 .785 .935 r
.54962 .5915 .55482 .59612 .56467 .59284 .55948 .5882 Mtetra
.673 .785 .934 r
.55948 .5882 .56467 .59284 .57454 .58952 .56938 .58481 Mtetra
.673 .783 .932 r
.56938 .58481 .57454 .58952 .58445 .5862 .57931 .5814 Mtetra
.672 .78 .931 r
.57931 .5814 .58445 .5862 .59439 .58292 .58928 .57803 Mtetra
.668 .776 .93 r
.58928 .57803 .59439 .58292 .60436 .57971 .59928 .57473 Mtetra
.664 .772 .93 r
.59928 .57473 .60436 .57971 .61438 .57658 .60932 .57154 Mtetra
.659 .769 .931 r
.60932 .57154 .61438 .57658 .62443 .57353 .61939 .56845 Mtetra
.654 .767 .932 r
.61939 .56845 .62443 .57353 .63452 .57057 .62951 .56547 Mtetra
.649 .765 .934 r
.62951 .56547 .63452 .57057 .64464 .56769 .63966 .56259 Mtetra
.644 .764 .936 r
.63966 .56259 .64464 .56769 .65481 .5649 .64986 .55983 Mtetra
.638 .764 .939 r
.64986 .55983 .65481 .5649 .66503 .56218 .6601 .55716 Mtetra
.634 .765 .942 r
.6601 .55716 .66503 .56218 .67528 .55954 .67039 .55457 Mtetra
.631 .767 .945 r
.67039 .55457 .67528 .55954 .68558 .55694 .68071 .55202 Mtetra
.63 .77 .947 r
.68071 .55202 .68558 .55694 .69591 .55435 .69108 .54946 Mtetra
.634 .773 .947 r
.69108 .54946 .69591 .55435 .70629 .5517 .70148 .5468 Mtetra
.642 .776 .945 r
.70148 .5468 .70629 .5517 .7167 .54893 .71192 .54395 Mtetra
.652 .778 .94 r
.71192 .54395 .7167 .54893 .72714 .54599 .72238 .54087 Mtetra
.665 .777 .933 r
.72238 .54087 .72714 .54599 .7376 .54282 .73286 .53749 Mtetra
.675 .773 .924 r
.73286 .53749 .7376 .54282 .74809 .53945 .74336 .53387 Mtetra
.682 .766 .915 r
.74336 .53387 .74809 .53945 .75861 .53588 .75389 .53005 Mtetra
.684 .758 .908 r
.75389 .53005 .75861 .53588 .76915 .5322 .76444 .52614 Mtetra
.682 .751 .903 r
.76444 .52614 .76915 .5322 .77972 .52848 .77504 .52227 Mtetra
.679 .745 .901 r
.77504 .52227 .77972 .52848 .79034 .52478 .78567 .51848 Mtetra
.673 .74 .901 r
.78567 .51848 .79034 .52478 .801 .52117 .79636 .51487 Mtetra
.667 .738 .903 r
.79636 .51487 .801 .52117 .8117 .51767 .8071 .5114 Mtetra
.661 .739 .907 r
.8071 .5114 .8117 .51767 .82245 .51427 .81789 .50808 Mtetra
.657 .74 .911 r
.81789 .50808 .82245 .51427 .83325 .51097 .82872 .50486 Mtetra
.655 .743 .915 r
.82872 .50486 .83325 .51097 .8441 .50773 .83961 .50169 Mtetra
.653 .746 .918 r
.83961 .50169 .8441 .50773 .855 .50453 .85054 .49855 Mtetra
.653 .749 .92 r
.85054 .49855 .855 .50453 .86593 .50135 .86151 .4954 Mtetra
.653 .751 .922 r
.86151 .4954 .86593 .50135 .87691 .49816 .87253 .49223 Mtetra
.654 .752 .922 r
.87253 .49223 .87691 .49816 .88793 .49496 .88358 .48902 Mtetra
.654 .753 .922 r
.88358 .48902 .88793 .49496 .899 .49175 .89467 .48578 Mtetra
.655 .754 .922 r
.89467 .48578 .899 .49175 .9101 .48851 .9058 .48251 Mtetra
.656 .753 .922 r
.9058 .48251 .9101 .48851 .92124 .48525 .91698 .47922 Mtetra
.656 .753 .921 r
.91698 .47922 .92124 .48525 .93243 .48198 .92819 .4759 Mtetra
.656 .752 .921 r
.92819 .4759 .93243 .48198 .94366 .47868 .93945 .47256 Mtetra
.654 .751 .921 r
.33552 .6441 .34122 .64908 .35035 .6464 .34466 .64143 Mtetra
.654 .752 .922 r
.34466 .64143 .35035 .6464 .35951 .6437 .35384 .63874 Mtetra
.654 .753 .922 r
.35384 .63874 .35951 .6437 .3687 .64099 .36305 .63604 Mtetra
.655 .754 .923 r
.36305 .63604 .3687 .64099 .37793 .63826 .3723 .63331 Mtetra
.656 .755 .923 r
.3723 .63331 .37793 .63826 .38719 .63549 .38157 .63055 Mtetra
.657 .756 .923 r
.38157 .63055 .38719 .63549 .39648 .6327 .39088 .62774 Mtetra
.659 .757 .922 r
.39088 .62774 .39648 .6327 .4058 .62988 .40023 .62489 Mtetra
.661 .757 .921 r
.40023 .62489 .4058 .62988 .41515 .62704 .4096 .62199 Mtetra
.662 .756 .92 r
.4096 .62199 .41515 .62704 .42454 .62419 .41901 .61905 Mtetra
.662 .753 .918 r
.41901 .61905 .42454 .62419 .43396 .62137 .42846 .61611 Mtetra
.661 .749 .916 r
.42846 .61611 .43396 .62137 .44341 .6186 .43793 .6132 Mtetra
.657 .743 .913 r
.43793 .6132 .44341 .6186 .45289 .61593 .44743 .61037 Mtetra
.651 .736 .912 r
.44743 .61037 .45289 .61593 .4624 .6134 .45697 .60769 Mtetra
.642 .729 .911 r
.45697 .60769 .4624 .6134 .47195 .61102 .46653 .60521 Mtetra
.632 .722 .912 r
.46653 .60521 .47195 .61102 .48152 .60881 .47613 .60297 Mtetra
.624 .719 .915 r
.47613 .60297 .48152 .60881 .49114 .60669 .48576 .60091 Mtetra
.616 .72 .92 r
.48576 .60091 .49114 .60669 .50079 .60461 .49543 .599 Mtetra
.615 .726 .925 r
.49543 .599 .50079 .60461 .51048 .60244 .50514 .59707 Mtetra
.62 .738 .931 r
.50514 .59707 .51048 .60244 .52021 .60009 .51489 .59499 Mtetra
.63 .752 .936 r
.51489 .59499 .52021 .60009 .52998 .5975 .52468 .59264 Mtetra
.644 .768 .938 r
.52468 .59264 .52998 .5975 .53978 .59461 .53451 .58994 Mtetra
.656 .779 .939 r
.53451 .58994 .53978 .59461 .54962 .5915 .54437 .58694 Mtetra
.667 .788 .938 r
.54437 .58694 .54962 .5915 .55948 .5882 .55426 .58366 Mtetra
.673 .791 .937 r
.55426 .58366 .55948 .5882 .56938 .58481 .56419 .58023 Mtetra
.675 .791 .936 r
.56419 .58023 .56938 .58481 .57931 .5814 .57415 .57674 Mtetra
.674 .788 .935 r
.57415 .57674 .57931 .5814 .58928 .57803 .58414 .57327 Mtetra
.67 .784 .934 r
.58414 .57327 .58928 .57803 .59928 .57473 .59416 .56989 Mtetra
.665 .779 .934 r
.59416 .56989 .59928 .57473 .60932 .57154 .60423 .56662 Mtetra
.659 .776 .935 r
.60423 .56662 .60932 .57154 .61939 .56845 .61433 .56349 Mtetra
.653 .773 .936 r
.61433 .56349 .61939 .56845 .62951 .56547 .62447 .56048 Mtetra
.647 .77 .939 r
.62447 .56048 .62951 .56547 .63966 .56259 .63465 .55762 Mtetra
.64 .769 .942 r
.63465 .55762 .63966 .56259 .64986 .55983 .64488 .55489 Mtetra
.634 .769 .945 r
.64488 .55489 .64986 .55983 .6601 .55716 .65515 .55227 Mtetra
.628 .77 .948 r
.65515 .55227 .6601 .55716 .67039 .55457 .66546 .54973 Mtetra
.626 .773 .951 r
.66546 .54973 .67039 .55457 .68071 .55202 .67582 .54723 Mtetra
.628 .776 .952 r
.67582 .54723 .68071 .55202 .69108 .54946 .68622 .54466 Mtetra
.634 .779 .951 r
.68622 .54466 .69108 .54946 .70148 .5468 .69665 .54195 Mtetra
.647 .782 .946 r
.69665 .54195 .70148 .5468 .71192 .54395 .7071 .53895 Mtetra
.661 .781 .938 r
.7071 .53895 .71192 .54395 .72238 .54087 .71758 .53564 Mtetra
.676 .778 .927 r
.71758 .53564 .72238 .54087 .73286 .53749 .72807 .53198 Mtetra
.686 .771 .916 r
.72807 .53198 .73286 .53749 .74336 .53387 .73859 .52803 Mtetra
.691 .761 .906 r
.73859 .52803 .74336 .53387 .75389 .53005 .74912 .52394 Mtetra
.69 .752 .899 r
.74912 .52394 .75389 .53005 .76444 .52614 .75969 .51981 Mtetra
.685 .743 .896 r
.75969 .51981 .76444 .52614 .77504 .52227 .77031 .51583 Mtetra
.678 .738 .896 r
.77031 .51583 .77504 .52227 .78567 .51848 .78097 .51203 Mtetra
.669 .735 .899 r
.78097 .51203 .78567 .51848 .79636 .51487 .79169 .50848 Mtetra
.662 .735 .904 r
.79169 .50848 .79636 .51487 .8071 .5114 .80247 .50513 Mtetra
.656 .738 .91 r
.80247 .50513 .8071 .5114 .81789 .50808 .8133 .50193 Mtetra
.652 .741 .915 r
.8133 .50193 .81789 .50808 .82872 .50486 .82417 .49882 Mtetra
.65 .746 .919 r
.82417 .49882 .82872 .50486 .83961 .50169 .8351 .49574 Mtetra
.65 .749 .922 r
.8351 .49574 .83961 .50169 .85054 .49855 .84607 .49264 Mtetra
.651 .752 .924 r
.84607 .49264 .85054 .49855 .86151 .4954 .85707 .48951 Mtetra
.652 .754 .925 r
.85707 .48951 .86151 .4954 .87253 .49223 .86812 .48633 Mtetra
.654 .755 .924 r
.86812 .48633 .87253 .49223 .88358 .48902 .8792 .4831 Mtetra
.655 .756 .924 r
.8792 .4831 .88358 .48902 .89467 .48578 .89032 .47982 Mtetra
.656 .755 .923 r
.89032 .47982 .89467 .48578 .9058 .48251 .90148 .4765 Mtetra
.657 .755 .922 r
.90148 .4765 .9058 .48251 .91698 .47922 .91268 .47315 Mtetra
.657 .754 .921 r
.91268 .47315 .91698 .47922 .92819 .4759 .92393 .46978 Mtetra
.657 .753 .921 r
.92393 .46978 .92819 .4759 .93945 .47256 .93521 .46639 Mtetra
.653 .751 .922 r
.32977 .63908 .33552 .6441 .34466 .64143 .33894 .63643 Mtetra
.652 .752 .923 r
.33894 .63643 .34466 .64143 .35384 .63874 .34813 .63376 Mtetra
.653 .753 .923 r
.34813 .63376 .35384 .63874 .36305 .63604 .35736 .63108 Mtetra
.653 .755 .924 r
.35736 .63108 .36305 .63604 .3723 .63331 .36662 .62837 Mtetra
.654 .757 .925 r
.36662 .62837 .3723 .63331 .38157 .63055 .37592 .62563 Mtetra
.656 .759 .925 r
.37592 .62563 .38157 .63055 .39088 .62774 .38525 .62284 Mtetra
.658 .76 .925 r
.38525 .62284 .39088 .62774 .40023 .62489 .39461 .61998 Mtetra
.661 .762 .925 r
.39461 .61998 .40023 .62489 .4096 .62199 .40401 .61706 Mtetra
.664 .762 .923 r
.40401 .61706 .4096 .62199 .41901 .61905 .41345 .61406 Mtetra
.665 .761 .921 r
.41345 .61406 .41901 .61905 .42846 .61611 .42291 .611 Mtetra
.667 .757 .918 r
.42291 .611 .42846 .61611 .43793 .6132 .43241 .60791 Mtetra
.664 .751 .915 r
.43241 .60791 .43793 .6132 .44743 .61037 .44194 .60488 Mtetra
.659 .742 .911 r
.44194 .60488 .44743 .61037 .45697 .60769 .4515 .60196 Mtetra
.65 .732 .909 r
.4515 .60196 .45697 .60769 .46653 .60521 .46109 .59927 Mtetra
.637 .721 .908 r
.46109 .59927 .46653 .60521 .47613 .60297 .47071 .5969 Mtetra
.624 .713 .91 r
.47071 .5969 .47613 .60297 .48576 .60091 .48036 .59483 Mtetra
.611 .708 .914 r
.48036 .59483 .48576 .60091 .49543 .599 .49004 .59306 Mtetra
.605 .712 .92 r
.49004 .59306 .49543 .599 .50514 .59707 .49977 .59138 Mtetra
.605 .722 .927 r
.49977 .59138 .50514 .59707 .51489 .59499 .50954 .58964 Mtetra
.614 .739 .934 r
.50954 .58964 .51489 .59499 .52468 .59264 .51935 .58764 Mtetra
.631 .759 .939 r
.51935 .58764 .52468 .59264 .53451 .58994 .5292 .58523 Mtetra
.646 .776 .942 r
.5292 .58523 .53451 .58994 .54437 .58694 .53909 .58242 Mtetra
.662 .789 .942 r
.53909 .58242 .54437 .58694 .55426 .58366 .54901 .57922 Mtetra
.671 .796 .941 r
.54901 .57922 .55426 .58366 .56419 .58023 .55896 .5758 Mtetra
.676 .798 .94 r
.55896 .5758 .56419 .58023 .57415 .57674 .56895 .57225 Mtetra
.676 .797 .939 r
.56895 .57225 .57415 .57674 .58414 .57327 .57897 .56869 Mtetra
.672 .793 .939 r
.57897 .56869 .58414 .57327 .59416 .56989 .58902 .56522 Mtetra
.667 .788 .939 r
.58902 .56522 .59416 .56989 .60423 .56662 .59911 .56187 Mtetra
.66 .784 .94 r
.59911 .56187 .60423 .56662 .61433 .56349 .60923 .55869 Mtetra
.652 .78 .942 r
.60923 .55869 .61433 .56349 .62447 .56048 .6194 .55567 Mtetra
.644 .778 .945 r
.6194 .55567 .62447 .56048 .63465 .55762 .62961 .55281 Mtetra
.635 .776 .948 r
.62961 .55281 .63465 .55762 .64488 .55489 .63987 .55012 Mtetra
.628 .776 .952 r
.63987 .55012 .64488 .55489 .65515 .55227 .65017 .54755 Mtetra
.623 .777 .955 r
.65017 .54755 .65515 .55227 .66546 .54973 .66051 .54507 Mtetra
.621 .78 .957 r
.66051 .54507 .66546 .54973 .67582 .54723 .6709 .54259 Mtetra
.626 .784 .957 r
.6709 .54259 .67582 .54723 .68622 .54466 .68132 .53998 Mtetra
.638 .786 .953 r
.68132 .53998 .68622 .54466 .69665 .54195 .69178 .53714 Mtetra
.656 .788 .945 r
.69178 .53714 .69665 .54195 .7071 .53895 .70225 .5339 Mtetra
.674 .785 .933 r
.70225 .5339 .7071 .53895 .71758 .53564 .71274 .53026 Mtetra
.69 .777 .918 r
.71274 .53026 .71758 .53564 .72807 .53198 .72324 .52621 Mtetra
.698 .766 .905 r
.72324 .52621 .72807 .53198 .73859 .52803 .73376 .52187 Mtetra
.699 .754 .894 r
.73376 .52187 .73859 .52803 .74912 .52394 .74431 .51747 Mtetra
.694 .743 .889 r
.74431 .51747 .74912 .52394 .75969 .51981 .75489 .51316 Mtetra
.684 .734 .888 r
.75489 .51316 .75969 .51981 .77031 .51583 .76553 .50915 Mtetra
.674 .73 .892 r
.76553 .50915 .77031 .51583 .78097 .51203 .77623 .50545 Mtetra
.663 .73 .899 r
.77623 .50545 .78097 .51203 .79169 .50848 .78699 .50207 Mtetra
.654 .733 .907 r
.78699 .50207 .79169 .50848 .80247 .50513 .79781 .49892 Mtetra
.649 .738 .915 r
.79781 .49892 .80247 .50513 .8133 .50193 .80869 .49589 Mtetra
.646 .744 .921 r
.80869 .49589 .8133 .50193 .82417 .49882 .81961 .49292 Mtetra
.646 .751 .925 r
.81961 .49292 .82417 .49882 .8351 .49574 .83057 .48992 Mtetra
.647 .755 .928 r
.83057 .48992 .8351 .49574 .84607 .49264 .84157 .48685 Mtetra
.65 .758 .928 r
.84157 .48685 .84607 .49264 .85707 .48951 .85261 .4837 Mtetra
.652 .759 .928 r
.85261 .4837 .85707 .48951 .86812 .48633 .86369 .48048 Mtetra
.654 .759 .927 r
.86369 .48048 .86812 .48633 .8792 .4831 .8748 .47719 Mtetra
.656 .759 .925 r
.8748 .47719 .8792 .4831 .89032 .47982 .88595 .47385 Mtetra
.657 .758 .924 r
.88595 .47385 .89032 .47982 .90148 .4765 .89713 .47047 Mtetra
.658 .756 .923 r
.89713 .47047 .90148 .4765 .91268 .47315 .90836 .46706 Mtetra
.658 .755 .921 r
.90836 .46706 .91268 .47315 .92393 .46978 .91963 .46363 Mtetra
.658 .754 .92 r
.91963 .46363 .92393 .46978 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33894 .63643 .33318 .63139 Mtetra
.651 .751 .923 r
.33318 .63139 .33894 .63643 .34813 .63376 .34239 .62874 Mtetra
.651 .752 .924 r
.34239 .62874 .34813 .63376 .35736 .63108 .35164 .62607 Mtetra
.651 .754 .925 r
.35164 .62607 .35736 .63108 .36662 .62837 .36092 .62339 Mtetra
.652 .756 .926 r
.36092 .62339 .36662 .62837 .37592 .62563 .37023 .62068 Mtetra
.653 .758 .927 r
.37023 .62068 .37592 .62563 .38525 .62284 .37958 .61793 Mtetra
.655 .761 .927 r
.37958 .61793 .38525 .62284 .39461 .61998 .38896 .61512 Mtetra
.659 .764 .927 r
.38896 .61512 .39461 .61998 .40401 .61706 .39838 .61221 Mtetra
.663 .766 .927 r
.39838 .61221 .40401 .61706 .41345 .61406 .40784 .6092 Mtetra
.667 .768 .925 r
.40784 .6092 .41345 .61406 .42291 .611 .41733 .60607 Mtetra
.672 .767 .922 r
.41733 .60607 .42291 .611 .43241 .60791 .42685 .60284 Mtetra
.672 .762 .918 r
.42685 .60284 .43241 .60791 .44194 .60488 .43641 .59958 Mtetra
.67 .754 .913 r
.43641 .59958 .44194 .60488 .4515 .60196 .44599 .59637 Mtetra
.661 .741 .909 r
.44599 .59637 .4515 .60196 .46109 .59927 .45561 .59338 Mtetra
.647 .727 .907 r
.45561 .59338 .46109 .59927 .47071 .5969 .46525 .59073 Mtetra
.63 .712 .906 r
.46525 .59073 .47071 .5969 .48036 .59483 .47492 .58851 Mtetra
.61 .7 .908 r
.47492 .58851 .48036 .59483 .49004 .59306 .48463 .58676 Mtetra
.597 .697 .913 r
.48463 .58676 .49004 .59306 .49977 .59138 .49437 .58528 Mtetra
.59 .702 .921 r
.49437 .58528 .49977 .59138 .50954 .58964 .50415 .5839 Mtetra
.596 .719 .93 r
.50415 .5839 .50954 .58964 .51935 .58764 .51398 .58232 Mtetra
.612 .741 .937 r
.51398 .58232 .51935 .58764 .5292 .58523 .52386 .58032 Mtetra
.631 .765 .943 r
.52386 .58032 .5292 .58523 .53909 .58242 .53377 .57784 Mtetra
.652 .786 .945 r
.53377 .57784 .53909 .58242 .54901 .57922 .54372 .57484 Mtetra
.666 .798 .946 r
.54372 .57484 .54901 .57922 .55896 .5758 .5537 .5715 Mtetra
.675 .805 .945 r
.5537 .5715 .55896 .5758 .56895 .57225 .56371 .56794 Mtetra
.677 .806 .944 r
.56371 .56794 .56895 .57225 .57897 .56869 .57376 .56433 Mtetra
.674 .804 .945 r
.57376 .56433 .57897 .56869 .58902 .56522 .58384 .56078 Mtetra
.668 .8 .945 r
.58384 .56078 .58902 .56522 .59911 .56187 .59395 .55736 Mtetra
.659 .795 .947 r
.59395 .55736 .59911 .56187 .60923 .55869 .60411 .55412 Mtetra
.65 .791 .95 r
.60411 .55412 .60923 .55869 .6194 .55567 .61431 .55108 Mtetra
.64 .788 .953 r
.61431 .55108 .6194 .55567 .62961 .55281 .62455 .54823 Mtetra
.63 .786 .957 r
.62455 .54823 .62961 .55281 .63987 .55012 .63483 .54558 Mtetra
.622 .785 .96 r
.63483 .54558 .63987 .55012 .65017 .54755 .64516 .54305 Mtetra
.617 .786 .963 r
.64516 .54305 .65017 .54755 .66051 .54507 .65554 .54059 Mtetra
.619 .789 .963 r
.65554 .54059 .66051 .54507 .6709 .54259 .66595 .53808 Mtetra
.63 .792 .96 r
.66595 .53808 .6709 .54259 .68132 .53998 .6764 .53534 Mtetra
.647 .793 .952 r
.6764 .53534 .68132 .53998 .69178 .53714 .68687 .53226 Mtetra
.671 .792 .939 r
.68687 .53226 .69178 .53714 .70225 .5339 .69736 .52866 Mtetra
.691 .784 .922 r
.69736 .52866 .70225 .5339 .71274 .53026 .70785 .52456 Mtetra
.705 .771 .904 r
.70785 .52456 .71274 .53026 .72324 .52621 .71836 .52003 Mtetra
.709 .757 .89 r
.71836 .52003 .72324 .52621 .73376 .52187 .72888 .51528 Mtetra
.704 .742 .882 r
.72888 .51528 .73376 .52187 .74431 .51747 .73944 .51064 Mtetra
.694 .732 .88 r
.73944 .51064 .74431 .51747 .75489 .51316 .75005 .50626 Mtetra
.679 .725 .885 r
.75005 .50626 .75489 .51316 .76553 .50915 .76072 .50237 Mtetra
.665 .724 .893 r
.76072 .50237 .76553 .50915 .77623 .50545 .77147 .4989 Mtetra
.652 .728 .905 r
.77147 .4989 .77623 .50545 .78699 .50207 .78228 .49579 Mtetra
.643 .735 .915 r
.78228 .49579 .78699 .50207 .79781 .49892 .79315 .49291 Mtetra
.64 .744 .924 r
.79315 .49291 .79781 .49892 .80869 .49589 .80407 .49007 Mtetra
.639 .751 .93 r
.80407 .49007 .80869 .49589 .81961 .49292 .81503 .48721 Mtetra
.643 .758 .932 r
.81503 .48721 .81961 .49292 .83057 .48992 .82603 .48423 Mtetra
.646 .761 .933 r
.82603 .48423 .83057 .48992 .84157 .48685 .83706 .48114 Mtetra
.651 .763 .931 r
.83706 .48114 .84157 .48685 .85261 .4837 .84813 .47793 Mtetra
.654 .763 .929 r
.84813 .47793 .85261 .4837 .86369 .48048 .85923 .47462 Mtetra
.657 .761 .927 r
.85923 .47462 .86369 .48048 .8748 .47719 .87036 .47125 Mtetra
.658 .76 .925 r
.87036 .47125 .8748 .47719 .88595 .47385 .88154 .46783 Mtetra
.659 .758 .923 r
.88154 .46783 .88595 .47385 .89713 .47047 .89275 .46438 Mtetra
.659 .756 .922 r
.89275 .46438 .89713 .47047 .90836 .46706 .90401 .46091 Mtetra
.66 .755 .921 r
.90401 .46091 .90836 .46706 .91963 .46363 .91531 .45742 Mtetra
.659 .754 .92 r
.91531 .45742 .91963 .46363 .93095 .46018 .92665 .45393 Mtetra
.651 .75 .922 r
.31818 .62896 .32399 .63404 .33318 .63139 .32738 .6263 Mtetra
.651 .75 .923 r
.32738 .6263 .33318 .63139 .34239 .62874 .33661 .62365 Mtetra
.65 .751 .923 r
.33661 .62365 .34239 .62874 .35164 .62607 .34588 .62099 Mtetra
.65 .752 .924 r
.34588 .62099 .35164 .62607 .36092 .62339 .35517 .61833 Mtetra
.649 .753 .925 r
.35517 .61833 .36092 .62339 .37023 .62068 .3645 .61567 Mtetra
.65 .756 .927 r
.3645 .61567 .37023 .62068 .37958 .61793 .37387 .61298 Mtetra
.651 .759 .929 r
.37387 .61298 .37958 .61793 .38896 .61512 .38327 .61025 Mtetra
.654 .764 .93 r
.38327 .61025 .38896 .61512 .39838 .61221 .39271 .60743 Mtetra
.659 .769 .931 r
.39271 .60743 .39838 .61221 .40784 .6092 .40218 .60448 Mtetra
.665 .774 .931 r
.40218 .60448 .40784 .6092 .41733 .60607 .41169 .60136 Mtetra
.674 .777 .928 r
.41169 .60136 .41733 .60607 .42685 .60284 .42124 .59805 Mtetra
.679 .776 .924 r
.42124 .59805 .42685 .60284 .43641 .59958 .43083 .5946 Mtetra
.682 .77 .918 r
.43083 .5946 .43641 .59958 .44599 .59637 .44045 .59106 Mtetra
.676 .757 .911 r
.44045 .59106 .44599 .59637 .45561 .59338 .45009 .58765 Mtetra
.664 .739 .906 r
.45009 .58765 .45561 .59338 .46525 .59073 .45976 .58455 Mtetra
.644 .718 .902 r
.45976 .58455 .46525 .59073 .47492 .58851 .46946 .58197 Mtetra
.617 .697 .902 r
.46946 .58197 .47492 .58851 .48463 .58676 .47918 .58007 Mtetra
.595 .684 .904 r
.47918 .58007 .48463 .58676 .49437 .58528 .48894 .57867 Mtetra
.577 .68 .911 r
.48894 .57867 .49437 .58528 .50415 .5839 .49874 .57765 Mtetra
.576 .693 .921 r
.49874 .57765 .50415 .5839 .51398 .58232 .50858 .57656 Mtetra
.588 .717 .933 r
.50858 .57656 .51398 .58232 .52386 .58032 .51847 .57511 Mtetra
.609 .747 .943 r
.51847 .57511 .52386 .58032 .53377 .57784 .52841 .57312 Mtetra
.636 .776 .948 r
.52841 .57312 .53377 .57784 .54372 .57484 .53839 .57046 Mtetra
.655 .797 .95 r
.53839 .57046 .54372 .57484 .5537 .5715 .5484 .56733 Mtetra
.67 .81 .951 r
.5484 .56733 .5537 .5715 .56371 .56794 .55844 .56384 Mtetra
.675 .816 .951 r
.55844 .56384 .56371 .56794 .57376 .56433 .56852 .56021 Mtetra
.673 .816 .952 r
.56852 .56021 .57376 .56433 .58384 .56078 .57862 .5566 Mtetra
.667 .813 .953 r
.57862 .5566 .58384 .56078 .59395 .55736 .58877 .55312 Mtetra
.658 .808 .955 r
.58877 .55312 .59395 .55736 .60411 .55412 .59895 .54984 Mtetra
.646 .804 .958 r
.59895 .54984 .60411 .55412 .61431 .55108 .60918 .54678 Mtetra
.635 .8 .962 r
.60918 .54678 .61431 .55108 .62455 .54823 .61945 .54394 Mtetra
.623 .797 .966 r
.61945 .54394 .62455 .54823 .63483 .54558 .62976 .54131 Mtetra
.615 .797 .969 r
.62976 .54131 .63483 .54558 .64516 .54305 .64013 .5388 Mtetra
.613 .797 .97 r
.64013 .5388 .64516 .54305 .65554 .54059 .65053 .53631 Mtetra
.62 .799 .968 r
.65053 .53631 .65554 .54059 .66595 .53808 .66097 .53369 Mtetra
.639 .802 .961 r
.66097 .53369 .66595 .53808 .6764 .53534 .67144 .53071 Mtetra
.664 .8 .948 r
.67144 .53071 .6764 .53534 .68687 .53226 .68193 .52724 Mtetra
.692 .793 .928 r
.68193 .52724 .68687 .53226 .69736 .52866 .69241 .5231 Mtetra
.71 .779 .906 r
.69241 .5231 .69736 .52866 .70785 .52456 .70291 .5184 Mtetra
.719 .761 .886 r
.70291 .5184 .70785 .52456 .71836 .52003 .71341 .51333 Mtetra
.717 .744 .873 r
.71341 .51333 .71836 .52003 .72888 .51528 .72394 .50817 Mtetra
.704 .728 .869 r
.72394 .50817 .72888 .51528 .73944 .51064 .73451 .5034 Mtetra
.689 .719 .873 r
.73451 .5034 .73944 .51064 .75005 .50626 .74516 .49913 Mtetra
.668 .715 .884 r
.74516 .49913 .75005 .50626 .76072 .50237 .75588 .49556 Mtetra
.65 .719 .899 r
.75588 .49556 .76072 .50237 .77147 .4989 .76668 .49252 Mtetra
.637 .729 .915 r
.76668 .49252 .77147 .4989 .78228 .49579 .77755 .4898 Mtetra
.629 .741 .928 r
.77755 .4898 .78228 .49579 .79315 .49291 .78848 .48721 Mtetra
.63 .754 .936 r
.78848 .48721 .79315 .49291 .80407 .49007 .79944 .48453 Mtetra
.634 .762 .94 r
.79944 .48453 .80407 .49007 .81503 .48721 .81044 .48171 Mtetra
.642 .768 .939 r
.81044 .48171 .81503 .48721 .82603 .48423 .82147 .47868 Mtetra
.649 .769 .937 r
.82147 .47868 .82603 .48423 .83706 .48114 .83253 .47548 Mtetra
.655 .768 .933 r
.83253 .47548 .83706 .48114 .84813 .47793 .84361 .47214 Mtetra
.658 .765 .929 r
.84361 .47214 .84813 .47793 .85923 .47462 .85473 .46871 Mtetra
.66 .762 .926 r
.85473 .46871 .85923 .47462 .87036 .47125 .86589 .46523 Mtetra
.661 .759 .923 r
.86589 .46523 .87036 .47125 .88154 .46783 .87709 .46172 Mtetra
.661 .757 .921 r
.87709 .46172 .88154 .46783 .89275 .46438 .88833 .4582 Mtetra
.66 .755 .92 r
.88833 .4582 .89275 .46438 .90401 .46091 .89962 .45468 Mtetra
.66 .754 .92 r
.89962 .45468 .90401 .46091 .91531 .45742 .91095 .45115 Mtetra
.66 .753 .919 r
.91095 .45115 .91531 .45742 .92665 .45393 .92232 .44763 Mtetra
.652 .75 .922 r
.31232 .62385 .31818 .62896 .32738 .6263 .32154 .62116 Mtetra
.651 .75 .922 r
.32154 .62116 .32738 .6263 .33661 .62365 .3308 .61847 Mtetra
.65 .749 .922 r
.3308 .61847 .33661 .62365 .34588 .62099 .34008 .61579 Mtetra
.649 .748 .922 r
.34008 .61579 .34588 .62099 .35517 .61833 .3494 .61313 Mtetra
.648 .749 .923 r
.3494 .61313 .35517 .61833 .3645 .61567 .35875 .61049 Mtetra
.647 .75 .924 r
.35875 .61049 .3645 .61567 .37387 .61298 .36813 .60786 Mtetra
.646 .753 .927 r
.36813 .60786 .37387 .61298 .38327 .61025 .37754 .60523 Mtetra
.648 .758 .929 r
.37754 .60523 .38327 .61025 .39271 .60743 .387 .60253 Mtetra
.652 .764 .932 r
.387 .60253 .39271 .60743 .40218 .60448 .39649 .59973 Mtetra
.659 .773 .933 r
.39649 .59973 .40218 .60448 .41169 .60136 .40602 .59674 Mtetra
.67 .781 .933 r
.40602 .59674 .41169 .60136 .42124 .59805 .41559 .59349 Mtetra
.68 .787 .93 r
.41559 .59349 .42124 .59805 .43083 .5946 .4252 .58997 Mtetra
.691 .787 .924 r
.4252 .58997 .43083 .5946 .44045 .59106 .43485 .58617 Mtetra
.692 .778 .917 r
.43485 .58617 .44045 .59106 .45009 .58765 .44453 .58234 Mtetra
.686 .761 .909 r
.44453 .58234 .45009 .58765 .45976 .58455 .45423 .57865 Mtetra
.665 .736 .902 r
.45423 .57865 .45976 .58455 .46946 .58197 .46396 .57549 Mtetra
.634 .707 .899 r
.46396 .57549 .46946 .58197 .47918 .58007 .4737 .57315 Mtetra
.603 .681 .897 r
.4737 .57315 .47918 .58007 .48894 .57867 .48348 .57158 Mtetra
.57 .663 .901 r
.48348 .57158 .48894 .57867 .49874 .57765 .49329 .57076 Mtetra
.559 .666 .909 r
.49329 .57076 .49874 .57765 .50858 .57656 .50315 .57014 Mtetra
.562 .683 .921 r
.50315 .57014 .50858 .57656 .51847 .57511 .51306 .56933 Mtetra
.581 .715 .935 r
.51306 .56933 .51847 .57511 .52841 .57312 .52301 .56798 Mtetra
.612 .753 .945 r
.52301 .56798 .52841 .57312 .53839 .57046 .53302 .56586 Mtetra
.637 .784 .952 r
.53302 .56586 .53839 .57046 .5484 .56733 .54306 .56312 Mtetra
.659 .807 .954 r
.54306 .56312 .5484 .56733 .55844 .56384 .55313 .55984 Mtetra
.668 .82 .956 r
.55313 .55984 .55844 .56384 .56852 .56021 .56324 .55631 Mtetra
.67 .825 .958 r
.56324 .55631 .56852 .56021 .57862 .5566 .57338 .55271 Mtetra
.664 .825 .961 r
.57338 .55271 .57862 .5566 .58877 .55312 .58355 .5492 Mtetra
.654 .822 .964 r
.58355 .5492 .58877 .55312 .59895 .54984 .59377 .54588 Mtetra
.642 .818 .968 r
.59377 .54588 .59895 .54984 .60918 .54678 .60402 .54281 Mtetra
.628 .814 .971 r
.60402 .54281 .60918 .54678 .61945 .54394 .61432 .53996 Mtetra
.617 .811 .975 r
.61432 .53996 .61945 .54394 .62976 .54131 .62467 .53731 Mtetra
.611 .809 .976 r
.62467 .53731 .62976 .54131 .64013 .5388 .63506 .53476 Mtetra
.614 .809 .975 r
.63506 .53476 .64013 .5388 .65053 .53631 .64549 .53214 Mtetra
.63 .809 .969 r
.64549 .53214 .65053 .53631 .66097 .53369 .65595 .52927 Mtetra
.659 .808 .955 r
.65595 .52927 .66097 .53369 .67144 .53071 .66643 .52585 Mtetra
.688 .799 .934 r
.66643 .52585 .67144 .53071 .68193 .52724 .67692 .5218 Mtetra
.715 .785 .907 r
.67692 .5218 .68193 .52724 .69241 .5231 .68741 .51696 Mtetra
.727 .765 .882 r
.68741 .51696 .69241 .5231 .70291 .5184 .6979 .51156 Mtetra
.727 .743 .865 r
.6979 .51156 .70291 .5184 .71341 .51333 .7084 .50598 Mtetra
.718 .727 .857 r
.7084 .50598 .71341 .51333 .72394 .50817 .71894 .50057 Mtetra
.697 .713 .861 r
.71894 .50057 .72394 .50817 .73451 .5034 .72955 .49593 Mtetra
.675 .709 .873 r
.72955 .49593 .73451 .5034 .74516 .49913 .74024 .49207 Mtetra
.649 .711 .893 r
.74024 .49207 .74516 .49913 .75588 .49556 .75103 .48905 Mtetra
.627 .721 .914 r
.75103 .48905 .75588 .49556 .76668 .49252 .7619 .48657 Mtetra
.617 .738 .933 r
.7619 .48657 .76668 .49252 .77755 .4898 .77283 .48424 Mtetra
.614 .753 .944 r
.77283 .48424 .77755 .4898 .78848 .48721 .78381 .48187 Mtetra
.624 .767 .948 r
.78381 .48187 .78848 .48721 .79944 .48453 .79481 .47922 Mtetra
.636 .774 .947 r
.79481 .47922 .79944 .48453 .81044 .48171 .80583 .4763 Mtetra
.648 .775 .941 r
.80583 .4763 .81044 .48171 .82147 .47868 .81688 .4731 Mtetra
.656 .772 .935 r
.81688 .4731 .82147 .47868 .83253 .47548 .82795 .4697 Mtetra
.661 .767 .929 r
.82795 .4697 .83253 .47548 .84361 .47214 .83905 .46619 Mtetra
.663 .763 .924 r
.83905 .46619 .84361 .47214 .85473 .46871 .85019 .46261 Mtetra
.663 .758 .921 r
.85019 .46261 .85473 .46871 .86589 .46523 .86138 .45903 Mtetra
.663 .755 .919 r
.86138 .45903 .86589 .46523 .87709 .46172 .8726 .45545 Mtetra
.661 .753 .918 r
.8726 .45545 .87709 .46172 .88833 .4582 .88387 .4519 Mtetra
.661 .752 .918 r
.88387 .4519 .88833 .4582 .89962 .45468 .89519 .44835 Mtetra
.66 .752 .918 r
.89519 .44835 .89962 .45468 .91095 .45115 .90655 .44481 Mtetra
.659 .752 .919 r
.90655 .44481 .91095 .45115 .92232 .44763 .91796 .44128 Mtetra
.654 .751 .921 r
.30643 .61871 .31232 .62385 .32154 .62116 .31567 .61595 Mtetra
.654 .749 .92 r
.31567 .61595 .32154 .62116 .3308 .61847 .32495 .61319 Mtetra
.653 .747 .919 r
.32495 .61319 .3308 .61847 .34008 .61579 .33426 .61045 Mtetra
.651 .745 .918 r
.33426 .61045 .34008 .61579 .3494 .61313 .34359 .60775 Mtetra
.648 .743 .919 r
.34359 .60775 .3494 .61313 .35875 .61049 .35296 .60509 Mtetra
.646 .743 .92 r
.35296 .60509 .35875 .61049 .36813 .60786 .36236 .60249 Mtetra
.642 .743 .922 r
.36236 .60249 .36813 .60786 .37754 .60523 .37179 .59994 Mtetra
.641 .747 .926 r
.37179 .59994 .37754 .60523 .387 .60253 .38126 .5974 Mtetra
.641 .754 .93 r
.38126 .5974 .387 .60253 .39649 .59973 .39076 .59484 Mtetra
.647 .765 .935 r
.39076 .59484 .39649 .59973 .40602 .59674 .4003 .5921 Mtetra
.658 .779 .938 r
.4003 .5921 .40602 .59674 .41559 .59349 .40989 .5891 Mtetra
.673 .793 .939 r
.40989 .5891 .41559 .59349 .4252 .58997 .41952 .58571 Mtetra
.693 .803 .933 r
.41952 .58571 .4252 .58997 .43485 .58617 .4292 .58183 Mtetra
.705 .803 .926 r
.4292 .58183 .43485 .58617 .44453 .58234 .43891 .57764 Mtetra
.71 .791 .914 r
.43891 .57764 .44453 .58234 .45423 .57865 .44865 .57328 Mtetra
.694 .763 .905 r
.44865 .57328 .45423 .57865 .46396 .57549 .45842 .56932 Mtetra
.664 .727 .897 r
.45842 .56932 .46396 .57549 .4737 .57315 .4682 .56617 Mtetra
.624 .689 .89 r
.4682 .56617 .4737 .57315 .48348 .57158 .47799 .56407 Mtetra
.576 .654 .889 r
.47799 .56407 .48348 .57158 .49329 .57076 .48782 .56317 Mtetra
.549 .64 .893 r
.48782 .56317 .49329 .57076 .50315 .57014 .49769 .56287 Mtetra
.536 .645 .904 r
.49769 .56287 .50315 .57014 .51306 .56933 .50761 .56275 Mtetra
.548 .674 .921 r
.50761 .56275 .51306 .56933 .52301 .56798 .51758 .5622 Mtetra
.579 .717 .937 r
.51758 .5622 .52301 .56798 .53302 .56586 .52761 .56085 Mtetra
.61 .759 .95 r
.52761 .56085 .53302 .56586 .54306 .56312 .53767 .55872 Mtetra
.64 .795 .957 r
.53767 .55872 .54306 .56312 .55313 .55984 .54778 .55584 Mtetra
.655 .818 .962 r
.54778 .55584 .55313 .55984 .56324 .55631 .55792 .55255 Mtetra
.662 .831 .965 r
.55792 .55255 .56324 .55631 .57338 .55271 .56809 .54905 Mtetra
.658 .836 .968 r
.56809 .54905 .57338 .55271 .58355 .5492 .5783 .54558 Mtetra
.648 .835 .972 r
.5783 .54558 .58355 .5492 .59377 .54588 .58854 .54226 Mtetra
.635 .832 .976 r
.58854 .54226 .59377 .54588 .60402 .54281 .59883 .53916 Mtetra
.622 .828 .98 r
.59883 .53916 .60402 .54281 .61432 .53996 .60916 .53629 Mtetra
.612 .824 .982 r
.60916 .53629 .61432 .53996 .62467 .53731 .61954 .53357 Mtetra
.612 .822 .981 r
.61954 .53357 .62467 .53731 .63506 .53476 .62996 .53087 Mtetra
.625 .821 .975 r
.62996 .53087 .63506 .53476 .64549 .53214 .64041 .52797 Mtetra
.651 .817 .963 r
.64041 .52797 .64549 .53214 .65595 .52927 .65089 .52465 Mtetra
.688 .809 .94 r
.65089 .52465 .65595 .52927 .66643 .52585 .66138 .52057 Mtetra
.716 .792 .911 r
.66138 .52057 .66643 .52585 .67692 .5218 .67186 .5157 Mtetra
.736 .769 .88 r
.67186 .5157 .67692 .5218 .68741 .51696 .68234 .51 Mtetra
.739 .744 .856 r
.68234 .51 .68741 .51696 .6979 .51156 .69281 .50387 Mtetra
.729 .721 .843 r
.69281 .50387 .6979 .51156 .7084 .50598 .70332 .4979 Mtetra
.712 .706 .843 r
.70332 .4979 .7084 .50598 .71894 .50057 .71389 .49253 Mtetra
.681 .696 .857 r
.71389 .49253 .71894 .50057 .72955 .49593 .72455 .48838 Mtetra
.65 .698 .881 r
.72455 .48838 .72955 .49593 .74024 .49207 .73532 .48531 Mtetra
.618 .71 .911 r
.73532 .48531 .74024 .49207 .75103 .48905 .74619 .48306 Mtetra
.594 .728 .938 r
.74619 .48306 .75103 .48905 .7619 .48657 .75714 .48124 Mtetra
.593 .755 .955 r
.75714 .48124 .7619 .48657 .77283 .48424 .76812 .47923 Mtetra
.603 .773 .962 r
.76812 .47923 .77283 .48424 .78381 .48187 .77913 .47691 Mtetra
.627 .785 .958 r
.77913 .47691 .78381 .48187 .79481 .47922 .79015 .47409 Mtetra
.646 .786 .949 r
.79015 .47409 .79481 .47922 .80583 .4763 .80119 .47086 Mtetra
.659 .78 .938 r
.80119 .47086 .80583 .4763 .81688 .4731 .81224 .46736 Mtetra
.667 .772 .928 r
.81224 .46736 .81688 .4731 .82795 .4697 .82332 .46367 Mtetra
.668 .762 .921 r
.82332 .46367 .82795 .4697 .83905 .46619 .83444 .45996 Mtetra
.668 .756 .916 r
.83444 .45996 .83905 .46619 .85019 .46261 .8456 .45624 Mtetra
.665 .751 .914 r
.8456 .45624 .85019 .46261 .86138 .45903 .85681 .45259 Mtetra
.663 .748 .913 r
.85681 .45259 .86138 .45903 .8726 .45545 .86806 .44898 Mtetra
.661 .747 .914 r
.86806 .44898 .8726 .45545 .88387 .4519 .87937 .44543 Mtetra
.659 .747 .915 r
.87937 .44543 .88387 .4519 .89519 .44835 .89072 .4419 Mtetra
.658 .749 .917 r
.89072 .4419 .89519 .44835 .90655 .44481 .90212 .4384 Mtetra
.657 .75 .918 r
.90212 .4384 .90655 .44481 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31567 .61595 .30977 .61069 Mtetra
.657 .749 .918 r
.30977 .61069 .31567 .61595 .32495 .61319 .31907 .60784 Mtetra
.656 .746 .916 r
.31907 .60784 .32495 .61319 .33426 .61045 .3284 .60501 Mtetra
.654 .743 .915 r
.3284 .60501 .33426 .61045 .34359 .60775 .33776 .60221 Mtetra
.651 .74 .914 r
.33776 .60221 .34359 .60775 .35296 .60509 .34715 .59948 Mtetra
.647 .736 .914 r
.34715 .59948 .35296 .60509 .36236 .60249 .35657 .59683 Mtetra
.642 .734 .916 r
.35657 .59683 .36236 .60249 .37179 .59994 .36602 .5943 Mtetra
.638 .734 .918 r
.36602 .5943 .37179 .59994 .38126 .5974 .3755 .59186 Mtetra
.633 .737 .923 r
.3755 .59186 .38126 .5974 .39076 .59484 .38501 .5895 Mtetra
.634 .746 .929 r
.38501 .5895 .39076 .59484 .4003 .5921 .39456 .58708 Mtetra
.64 .76 .936 r
.39456 .58708 .4003 .5921 .40989 .5891 .40415 .58449 Mtetra
.656 .782 .941 r
.40415 .58449 .40989 .5891 .41952 .58571 .41379 .58148 Mtetra
.682 .804 .94 r
.41379 .58148 .41952 .58571 .4292 .58183 .42349 .57785 Mtetra
.706 .82 .936 r
.42349 .57785 .4292 .58183 .43891 .57764 .43323 .57361 Mtetra
.729 .821 .922 r
.43323 .57361 .43891 .57764 .44865 .57328 .44302 .56875 Mtetra
.725 .802 .912 r
.44302 .56875 .44865 .57328 .45842 .56932 .45283 .56395 Mtetra
.704 .767 .902 r
.45283 .56395 .45842 .56932 .4682 .56617 .46265 .55968 Mtetra
.66 .718 .892 r
.46265 .55968 .4682 .56617 .47799 .56407 .47248 .55659 Mtetra
.6 .666 .886 r
.47248 .55659 .47799 .56407 .48782 .56317 .48233 .5551 Mtetra
.556 .631 .881 r
.48233 .5551 .48782 .56317 .49769 .56287 .49221 .5547 Mtetra
.522 .613 .884 r
.49221 .5547 .49769 .56287 .50761 .56275 .50213 .55508 Mtetra
.521 .627 .897 r
.50213 .55508 .50761 .56275 .51758 .5622 .51212 .55533 Mtetra
.544 .664 .916 r
.51212 .55533 .51758 .5622 .52761 .56085 .52216 .55491 Mtetra
.575 .712 .935 r
.52216 .55491 .52761 .56085 .53767 .55872 .53225 .55364 Mtetra
.613 .76 .949 r
.53225 .55364 .53767 .55872 .54778 .55584 .54238 .55143 Mtetra
.635 .796 .959 r
.54238 .55143 .54778 .55584 .55792 .55255 .55256 .5486 Mtetra
.649 .821 .966 r
.55256 .5486 .55792 .55255 .56809 .54905 .56276 .54538 Mtetra
.65 .834 .971 r
.56276 .54538 .56809 .54905 .5783 .54558 .573 .54205 Mtetra
.643 .839 .976 r
.573 .54205 .5783 .54558 .58854 .54226 .58328 .53878 Mtetra
.632 .839 .98 r
.58328 .53878 .58854 .54226 .59883 .53916 .5936 .53566 Mtetra
.622 .836 .982 r
.5936 .53566 .59883 .53916 .60916 .53629 .60397 .53269 Mtetra
.619 .832 .982 r
.60397 .53269 .60916 .53629 .61954 .53357 .61437 .52979 Mtetra
.629 .827 .977 r
.61437 .52979 .61954 .53357 .62996 .53087 .62481 .52678 Mtetra
.654 .822 .964 r
.62481 .52678 .62996 .53087 .64041 .52797 .63528 .52337 Mtetra
.685 .81 .942 r
.63528 .52337 .64041 .52797 .65089 .52465 .64576 .51934 Mtetra
.72 .792 .909 r
.64576 .51934 .65089 .52465 .66138 .52057 .65624 .51435 Mtetra
.739 .766 .875 r
.65624 .51435 .66138 .52057 .67186 .5157 .66672 .5085 Mtetra
.746 .74 .846 r
.66672 .5085 .67186 .5157 .68234 .51 .67718 .50194 Mtetra
.741 .717 .829 r
.67718 .50194 .68234 .51 .69281 .50387 .68766 .49525 Mtetra
.72 .697 .828 r
.68766 .49525 .69281 .50387 .70332 .4979 .69819 .48933 Mtetra
.694 .689 .84 r
.69819 .48933 .70332 .4979 .71389 .49253 .70881 .48452 Mtetra
.652 .686 .869 r
.70881 .48452 .71389 .49253 .72455 .48838 .71956 .48134 Mtetra
.608 .697 .906 r
.71956 .48134 .72455 .48838 .73532 .48531 .73042 .47937 Mtetra
.573 .722 .943 r
.73042 .47937 .73532 .48531 .74619 .48306 .74137 .47795 Mtetra
.554 .748 .967 r
.74137 .47795 .74619 .48306 .75714 .48124 .75238 .47659 Mtetra
.578 .78 .975 r
.75238 .47659 .75714 .48124 .76812 .47923 .7634 .4746 Mtetra
.611 .794 .969 r
.7634 .4746 .76812 .47923 .77913 .47691 .77443 .47198 Mtetra
.645 .795 .955 r
.77443 .47198 .77913 .47691 .79015 .47409 .78545 .46872 Mtetra
.666 .786 .938 r
.78545 .46872 .79015 .47409 .80119 .47086 .79648 .46503 Mtetra
.674 .771 .924 r
.79648 .46503 .80119 .47086 .81224 .46736 .80753 .46115 Mtetra
.676 .76 .914 r
.80753 .46115 .81224 .46736 .82332 .46367 .81862 .4572 Mtetra
.672 .75 .909 r
.81862 .4572 .82332 .46367 .83444 .45996 .82976 .45334 Mtetra
.669 .744 .907 r
.82976 .45334 .83444 .45996 .8456 .45624 .84095 .44957 Mtetra
.664 .741 .907 r
.84095 .44957 .8456 .45624 .85681 .45259 .85219 .44592 Mtetra
.661 .741 .909 r
.85219 .44592 .85681 .45259 .86806 .44898 .86348 .44235 Mtetra
.658 .742 .912 r
.86348 .44235 .86806 .44898 .87937 .44543 .87483 .43884 Mtetra
.656 .744 .914 r
.87483 .43884 .87937 .44543 .89072 .4419 .88622 .43537 Mtetra
.655 .746 .917 r
.88622 .43537 .89072 .4419 .90212 .4384 .89766 .43192 Mtetra
.655 .749 .919 r
.89766 .43192 .90212 .4384 .91357 .43489 .90915 .42846 Mtetra
.66 .752 .918 r
.29453 .60833 .3005 .61354 .30977 .61069 .30382 .60539 Mtetra
.661 .75 .916 r
.30382 .60539 .30977 .61069 .31907 .60784 .31315 .60244 Mtetra
.66 .747 .914 r
.31315 .60244 .31907 .60784 .3284 .60501 .3225 .59949 Mtetra
.659 .743 .912 r
.3225 .59949 .3284 .60501 .33776 .60221 .33189 .59656 Mtetra
.657 .738 .91 r
.33189 .59656 .33776 .60221 .34715 .59948 .34131 .59367 Mtetra
.652 .732 .908 r
.34131 .59367 .34715 .59948 .35657 .59683 .35075 .59089 Mtetra
.646 .726 .907 r
.35075 .59089 .35657 .59683 .36602 .5943 .36022 .58825 Mtetra
.639 .721 .907 r
.36022 .58825 .36602 .5943 .3755 .59186 .36972 .58578 Mtetra
.628 .718 .911 r
.36972 .58578 .3755 .59186 .38501 .5895 .37924 .58355 Mtetra
.622 .721 .917 r
.37924 .58355 .38501 .5895 .39456 .58708 .3888 .58143 Mtetra
.617 .731 .927 r
.3888 .58143 .39456 .58708 .40415 .58449 .39839 .57938 Mtetra
.628 .755 .939 r
.39839 .57938 .40415 .58449 .41379 .58148 .40804 .57701 Mtetra
.651 .788 .948 r
.40804 .57701 .41379 .58148 .42349 .57785 .41774 .57406 Mtetra
.687 .825 .949 r
.41774 .57406 .42349 .57785 .43323 .57361 .4275 .57022 Mtetra
.732 .849 .936 r
.4275 .57022 .43323 .57361 .44302 .56875 .43731 .56524 Mtetra
.75 .847 .923 r
.43731 .56524 .44302 .56875 .45283 .56395 .44717 .55974 Mtetra
.751 .82 .906 r
.44717 .55974 .45283 .56395 .46265 .55968 .45705 .55413 Mtetra
.712 .765 .894 r
.45705 .55413 .46265 .55968 .47248 .55659 .46693 .54957 Mtetra
.646 .699 .884 r
.46693 .54957 .47248 .55659 .48233 .5551 .47681 .54681 Mtetra
.586 .639 .87 r
.47681 .54681 .48233 .5551 .49221 .5547 .48671 .54572 Mtetra
.525 .593 .865 r
.48671 .54572 .49221 .5547 .50213 .55508 .49664 .54618 Mtetra
.505 .586 .87 r
.49664 .54618 .50213 .55508 .51212 .55533 .50663 .54707 Mtetra
.51 .607 .885 r
.50663 .54707 .51212 .55533 .52216 .55491 .51668 .54766 Mtetra
.535 .65 .908 r
.51668 .54766 .52216 .55491 .53225 .55364 .52679 .54747 Mtetra
.576 .706 .93 r
.52679 .54747 .53225 .55364 .54238 .55143 .53695 .5462 Mtetra
.606 .754 .949 r
.53695 .5462 .54238 .55143 .55256 .5486 .54715 .54411 Mtetra
.63 .793 .961 r
.54715 .54411 .55256 .5486 .56276 .54538 .55739 .54137 Mtetra
.638 .817 .969 r
.55739 .54137 .56276 .54538 .573 .54205 .56766 .53833 Mtetra
.638 .831 .975 r
.56766 .53833 .573 .54205 .58328 .53878 .57798 .53518 Mtetra
.634 .835 .978 r
.57798 .53518 .58328 .53878 .5936 .53566 .58833 .53204 Mtetra
.632 .835 .978 r
.58833 .53204 .5936 .53566 .60397 .53269 .59872 .52892 Mtetra
.64 .831 .974 r
.59872 .52892 .60397 .53269 .61437 .52979 .60915 .52569 Mtetra
.66 .823 .962 r
.60915 .52569 .61437 .52979 .62481 .52678 .61961 .52215 Mtetra
.692 .811 .939 r
.61961 .52215 .62481 .52678 .63528 .52337 .63008 .51795 Mtetra
.72 .789 .906 r
.63008 .51795 .63528 .52337 .64576 .51934 .64056 .51293 Mtetra
.744 .762 .868 r
.64056 .51293 .64576 .51934 .65624 .51435 .65103 .50681 Mtetra
.751 .732 .835 r
.65103 .50681 .65624 .51435 .66672 .5085 .66149 .49987 Mtetra
.746 .706 .814 r
.66149 .49987 .66672 .5085 .67718 .50194 .67194 .49263 Mtetra
.732 .687 .807 r
.67194 .49263 .67718 .50194 .68766 .49525 .68244 .4858 Mtetra
.699 .671 .82 r
.68244 .4858 .68766 .49525 .69819 .48933 .69303 .48054 Mtetra
.661 .67 .849 r
.69303 .48054 .69819 .48933 .70881 .48452 .70374 .47697 Mtetra
.6 .678 .896 r
.70374 .47697 .70881 .48452 .71956 .48134 .71459 .47525 Mtetra
.534 .699 .945 r
.71459 .47525 .71956 .48134 .73042 .47937 .72556 .47461 Mtetra
.504 .742 .98 r
.72556 .47461 .73042 .47937 .74137 .47795 .73659 .47387 Mtetra
.515 .779 .992 r
.73659 .47387 .74137 .47795 .75238 .47659 .74764 .47259 Mtetra
.586 .814 .986 r
.74764 .47259 .75238 .47659 .7634 .4746 .75866 .47014 Mtetra
.644 .816 .966 r
.75866 .47014 .7634 .4746 .77443 .47198 .76967 .46679 Mtetra
.676 .797 .939 r
.76967 .46679 .77443 .47198 .78545 .46872 .78067 .46282 Mtetra
.688 .775 .917 r
.78067 .46282 .78545 .46872 .79648 .46503 .79168 .45853 Mtetra
.685 .754 .903 r
.79168 .45853 .79648 .46503 .80753 .46115 .80274 .45429 Mtetra
.68 .741 .896 r
.80274 .45429 .80753 .46115 .81862 .4572 .81385 .45017 Mtetra
.672 .732 .896 r
.81385 .45017 .81862 .4572 .82976 .45334 .82501 .44629 Mtetra
.665 .73 .898 r
.82501 .44629 .82976 .45334 .84095 .44957 .83624 .44259 Mtetra
.66 .731 .902 r
.83624 .44259 .84095 .44957 .85219 .44592 .84752 .43903 Mtetra
.656 .733 .906 r
.84752 .43903 .85219 .44592 .86348 .44235 .85886 .43558 Mtetra
.654 .737 .911 r
.85886 .43558 .86348 .44235 .87483 .43884 .87024 .43217 Mtetra
.653 .741 .914 r
.87024 .43217 .87483 .43884 .88622 .43537 .88168 .42878 Mtetra
.652 .744 .917 r
.88168 .42878 .88622 .43537 .89766 .43192 .89317 .42539 Mtetra
.652 .747 .919 r
.89317 .42539 .89766 .43192 .90915 .42846 .90469 .42197 Mtetra
.661 .753 .918 r
.28853 .60308 .29453 .60833 .30382 .60539 .29784 .6001 Mtetra
.663 .752 .916 r
.29784 .6001 .30382 .60539 .31315 .60244 .30719 .59707 Mtetra
.663 .75 .915 r
.30719 .59707 .31315 .60244 .3225 .59949 .31657 .59403 Mtetra
.663 .747 .913 r
.31657 .59403 .3225 .59949 .33189 .59656 .32598 .59097 Mtetra
.663 .743 .91 r
.32598 .59097 .33189 .59656 .34131 .59367 .33542 .58791 Mtetra
.66 .737 .907 r
.33542 .58791 .34131 .59367 .35075 .59089 .3449 .58491 Mtetra
.655 .729 .904 r
.3449 .58491 .35075 .59089 .36022 .58825 .3544 .58203 Mtetra
.646 .719 .901 r
.3544 .58203 .36022 .58825 .36972 .58578 .36392 .57936 Mtetra
.633 .709 .901 r
.36392 .57936 .36972 .58578 .37924 .58355 .37347 .57701 Mtetra
.62 .701 .902 r
.37347 .57701 .37924 .58355 .3888 .58143 .38304 .57496 Mtetra
.604 .698 .91 r
.38304 .57496 .3888 .58143 .39839 .57938 .39263 .57328 Mtetra
.602 .711 .921 r
.39263 .57328 .39839 .57938 .40804 .57701 .40227 .57157 Mtetra
.609 .739 .937 r
.40227 .57157 .40804 .57701 .41774 .57406 .41196 .56959 Mtetra
.646 .789 .951 r
.41196 .56959 .41774 .57406 .4275 .57022 .42171 .5667 Mtetra
.705 .842 .948 r
.42171 .5667 .4275 .57022 .43731 .56524 .43155 .56238 Mtetra
.751 .875 .936 r
.43155 .56238 .43731 .56524 .44717 .55974 .44144 .55683 Mtetra
.786 .874 .912 r
.44144 .55683 .44717 .55974 .45705 .55413 .45137 .55021 Mtetra
.767 .834 .904 r
.45137 .55021 .45705 .55413 .46693 .54957 .46131 .54406 Mtetra
.715 .769 .895 r
.46131 .54406 .46693 .54957 .47681 .54681 .47124 .53938 Mtetra
.641 .687 .877 r
.47124 .53938 .47681 .54681 .48671 .54572 .48118 .53673 Mtetra
.557 .61 .861 r
.48118 .53673 .48671 .54572 .49664 .54618 .49113 .53642 Mtetra
.515 .571 .85 r
.49113 .53642 .49664 .54618 .50663 .54707 .50112 .53728 Mtetra
.495 .561 .852 r
.50112 .53728 .50663 .54707 .51668 .54766 .51117 .53858 Mtetra
.508 .585 .867 r
.51117 .53858 .51668 .54766 .52679 .54747 .52129 .53942 Mtetra
.542 .63 .888 r
.52129 .53942 .52679 .54747 .53695 .5462 .53146 .53925 Mtetra
.574 .68 .912 r
.53146 .53925 .53695 .5462 .54715 .54411 .54169 .53814 Mtetra
.608 .728 .93 r
.54169 .53814 .54715 .54411 .55739 .54137 .55196 .53612 Mtetra
.627 .763 .944 r
.55196 .53612 .55739 .54137 .56766 .53833 .56227 .53355 Mtetra
.64 .787 .953 r
.56227 .53355 .56766 .53833 .57798 .53518 .57262 .53061 Mtetra
.647 .799 .956 r
.57262 .53061 .57798 .53518 .58833 .53204 .583 .52745 Mtetra
.657 .802 .952 r
.583 .52745 .58833 .53204 .59872 .52892 .59341 .52408 Mtetra
.675 .797 .94 r
.59341 .52408 .59872 .52892 .60915 .52569 .60386 .52033 Mtetra
.696 .784 .919 r
.60386 .52033 .60915 .52569 .61961 .52215 .61433 .51602 Mtetra
.722 .765 .887 r
.61433 .51602 .61961 .52215 .63008 .51795 .6248 .5108 Mtetra
.738 .739 .852 r
.6248 .5108 .63008 .51795 .64056 .51293 .63527 .50462 Mtetra
.749 .713 .819 r
.63527 .50462 .64056 .51293 .65103 .50681 .64572 .4974 Mtetra
.746 .69 .798 r
.64572 .4974 .65103 .50681 .66149 .49987 .65617 .4897 Mtetra
.732 .671 .791 r
.65617 .4897 .66149 .49987 .67194 .49263 .66664 .48243 Mtetra
.71 .662 .801 r
.66664 .48243 .67194 .49263 .68244 .4858 .67719 .47634 Mtetra
.662 .656 .834 r
.67719 .47634 .68244 .4858 .69303 .48054 .68788 .47263 Mtetra
.598 .667 .888 r
.68788 .47263 .69303 .48054 .70374 .47697 .69871 .47097 Mtetra
.503 .689 .951 r
.69871 .47097 .70374 .47697 .71459 .47525 .70968 .47083 Mtetra
.407 .71 .985 r
.70968 .47083 .71459 .47525 .72556 .47461 .72075 .47119 Mtetra
.44 .773 .997 r
.72075 .47119 .72556 .47461 .73659 .47387 .73181 .47044 Mtetra
.535 .819 .998 r
.73181 .47044 .73659 .47387 .74764 .47259 .74285 .46845 Mtetra
.643 .83 .972 r
.74285 .46845 .74764 .47259 .75866 .47014 .75384 .465 Mtetra
.692 .805 .935 r
.75384 .465 .75866 .47014 .76967 .46679 .7648 .46059 Mtetra
.701 .769 .905 r
.7648 .46059 .76967 .46679 .78067 .46282 .77578 .45589 Mtetra
.699 .745 .887 r
.77578 .45589 .78067 .46282 .79168 .45853 .78679 .45117 Mtetra
.686 .728 .882 r
.78679 .45117 .79168 .45853 .80274 .45429 .79787 .44681 Mtetra
.675 .721 .883 r
.79787 .44681 .80274 .45429 .81385 .45017 .80901 .44277 Mtetra
.665 .719 .889 r
.80901 .44277 .81385 .45017 .82501 .44629 .82022 .43905 Mtetra
.658 .722 .897 r
.82022 .43905 .82501 .44629 .83624 .44259 .8315 .43556 Mtetra
.653 .728 .904 r
.8315 .43556 .83624 .44259 .84752 .43903 .84283 .43218 Mtetra
.65 .733 .91 r
.84283 .43218 .84752 .43903 .85886 .43558 .85421 .42887 Mtetra
.65 .739 .915 r
.85421 .42887 .85886 .43558 .87024 .43217 .86564 .42554 Mtetra
.65 .743 .918 r
.86564 .42554 .87024 .43217 .88168 .42878 .87712 .42221 Mtetra
.65 .746 .92 r
.87712 .42221 .88168 .42878 .89317 .42539 .88864 .41885 Mtetra
.651 .748 .921 r
.88864 .41885 .89317 .42539 .90469 .42197 .90021 .41544 Mtetra
.66 .752 .918 r
.28248 .59781 .28853 .60308 .29784 .6001 .29181 .59483 Mtetra
.662 .754 .918 r
.29181 .59483 .29784 .6001 .30719 .59707 .30118 .5918 Mtetra
.664 .755 .918 r
.30118 .5918 .30719 .59707 .31657 .59403 .31058 .58872 Mtetra
.666 .755 .917 r
.31058 .58872 .31657 .59403 .32598 .59097 .32002 .58557 Mtetra
.669 .753 .913 r
.32002 .58557 .32598 .59097 .33542 .58791 .32949 .58234 Mtetra
.669 .748 .909 r
.32949 .58234 .33542 .58791 .3449 .58491 .339 .5791 Mtetra
.668 .74 .903 r
.339 .5791 .3449 .58491 .3544 .58203 .34853 .57585 Mtetra
.661 .726 .897 r
.34853 .57585 .3544 .58203 .36392 .57936 .3581 .57277 Mtetra
.65 .71 .892 r
.3581 .57277 .36392 .57936 .37347 .57701 .36768 .56999 Mtetra
.632 .691 .887 r
.36768 .56999 .37347 .57701 .38304 .57496 .37727 .56767 Mtetra
.606 .674 .889 r
.37727 .56767 .38304 .57496 .39263 .57328 .38688 .566 Mtetra
.586 .667 .895 r
.38688 .566 .39263 .57328 .40227 .57157 .39652 .56476 Mtetra
.566 .675 .912 r
.39652 .56476 .40227 .57157 .41196 .56959 .40618 .56388 Mtetra
.584 .722 .938 r
.40618 .56388 .41196 .56959 .42171 .5667 .41591 .5624 Mtetra
.634 .796 .96 r
.41591 .5624 .42171 .5667 .43155 .56238 .42573 .55965 Mtetra
.709 .878 .96 r
.42573 .55965 .43155 .56238 .44144 .55683 .43563 .55505 Mtetra
.791 .92 .924 r
.43563 .55505 .44144 .55683 .45137 .55021 .4456 .54819 Mtetra
.811 .909 .908 r
.4456 .54819 .45137 .55021 .46131 .54406 .45561 .5407 Mtetra
.794 .859 .898 r
.45561 .5407 .46131 .54406 .47124 .53938 .46562 .53364 Mtetra
.725 .765 .885 r
.46562 .53364 .47124 .53938 .48118 .53673 .47561 .52855 Mtetra
.624 .661 .866 r
.47561 .52855 .48118 .53673 .49113 .53642 .48559 .52636 Mtetra
.555 .586 .839 r
.48559 .52636 .49113 .53642 .50112 .53728 .4956 .5262 Mtetra
.505 .539 .826 r
.4956 .5262 .50112 .53728 .51117 .53858 .50565 .52757 Mtetra
.497 .537 .828 r
.50565 .52757 .51117 .53858 .52129 .53942 .51577 .5291 Mtetra
.516 .562 .841 r
.51577 .5291 .52129 .53942 .53146 .53925 .52595 .53001 Mtetra
.544 .601 .862 r
.52595 .53001 .53146 .53925 .54169 .53814 .53619 .53001 Mtetra
.581 .649 .882 r
.53619 .53001 .54169 .53814 .55196 .53612 .54648 .5289 Mtetra
.609 .688 .899 r
.54648 .5289 .55196 .53612 .56227 .53355 .55682 .52697 Mtetra
.635 .72 .908 r
.55682 .52697 .56227 .53355 .57262 .53061 .56719 .52434 Mtetra
.655 .738 .91 r
.56719 .52434 .57262 .53061 .583 .52745 .5776 .52116 Mtetra
.675 .744 .903 r
.5776 .52116 .583 .52745 .59341 .52408 .58803 .51743 Mtetra
.696 .74 .885 r
.58803 .51743 .59341 .52408 .60386 .52033 .59849 .51299 Mtetra
.715 .727 .859 r
.59849 .51299 .60386 .52033 .61433 .51602 .60896 .50773 Mtetra
.732 .708 .828 r
.60896 .50773 .61433 .51602 .6248 .5108 .61942 .50134 Mtetra
.739 .686 .8 r
.61942 .50134 .6248 .5108 .63527 .50462 .62987 .49401 Mtetra
.739 .667 .779 r
.62987 .49401 .63527 .50462 .64572 .4974 .64031 .48604 Mtetra
.73 .652 .771 r
.64031 .48604 .64572 .4974 .65617 .4897 .65078 .47822 Mtetra
.704 .639 .781 r
.65078 .47822 .65617 .4897 .66664 .48243 .66131 .47193 Mtetra
.669 .639 .811 r
.66131 .47193 .66664 .48243 .67719 .47634 .67196 .46771 Mtetra
.587 .643 .873 r
.67196 .46771 .67719 .47634 .68788 .47263 .68278 .46642 Mtetra
.453 .657 .948 r
.68278 .46642 .68788 .47263 .69871 .47097 .69377 .46716 Mtetra
.29 .673 .973 r
.69377 .46716 .69871 .47097 .70968 .47083 .70484 .46834 Mtetra
.233 .695 .948 r
.70484 .46834 .70968 .47083 .72075 .47119 .71596 .4689 Mtetra
.446 .827 .989 r
.71596 .4689 .72075 .47119 .73181 .47044 .727 .46716 Mtetra
.635 .865 .985 r
.727 .46716 .73181 .47044 .74285 .46845 .73797 .46351 Mtetra
.712 .819 .932 r
.73797 .46351 .74285 .46845 .75384 .465 .74889 .45855 Mtetra
.726 .769 .887 r
.74889 .45855 .75384 .465 .7648 .46059 .7598 .45297 Mtetra
.709 .729 .866 r
.7598 .45297 .7648 .46059 .77578 .45589 .77077 .44774 Mtetra
.693 .709 .86 r
.77077 .44774 .77578 .45589 .78679 .45117 .7818 .44295 Mtetra
.674 .7 .866 r
.7818 .44295 .78679 .45117 .79787 .44681 .79293 .43884 Mtetra
.661 .702 .877 r
.79293 .43884 .79787 .44681 .80901 .44277 .80413 .4352 Mtetra
.652 .71 .89 r
.80413 .4352 .80901 .44277 .82022 .43905 .81541 .43186 Mtetra
.645 .72 .903 r
.81541 .43186 .82022 .43905 .8315 .43556 .82674 .42869 Mtetra
.644 .731 .912 r
.82674 .42869 .8315 .43556 .84283 .43218 .83813 .42553 Mtetra
.644 .739 .918 r
.83813 .42553 .84283 .43218 .85421 .42887 .84956 .42234 Mtetra
.647 .746 .922 r
.84956 .42234 .85421 .42887 .86564 .42554 .86103 .41907 Mtetra
.648 .749 .923 r
.86103 .41907 .86564 .42554 .87712 .42221 .87254 .41572 Mtetra
.65 .75 .923 r
.87254 .41572 .87712 .42221 .88864 .41885 .88409 .41232 Mtetra
.652 .751 .922 r
.88409 .41232 .88864 .41885 .90021 .41544 .89569 .40886 Mtetra
.656 .752 .92 r
.27639 .59249 .28248 .59781 .29181 .59483 .28574 .58959 Mtetra
.658 .755 .922 r
.28574 .58959 .29181 .59483 .30118 .5918 .29512 .58663 Mtetra
.66 .759 .923 r
.29512 .58663 .30118 .5918 .31058 .58872 .30454 .58361 Mtetra
.664 .763 .924 r
.30454 .58361 .31058 .58872 .32002 .58557 .31399 .58048 Mtetra
.67 .766 .922 r
.31399 .58048 .32002 .58557 .32949 .58234 .32349 .57721 Mtetra
.674 .766 .92 r
.32349 .57721 .32949 .58234 .339 .5791 .33303 .57381 Mtetra
.68 .762 .914 r
.33303 .57381 .339 .5791 .34853 .57585 .3426 .57027 Mtetra
.678 .752 .907 r
.3426 .57027 .34853 .57585 .3581 .57277 .35221 .56674 Mtetra
.673 .736 .897 r
.35221 .56674 .3581 .57277 .36768 .56999 .36184 .56331 Mtetra
.656 .711 .888 r
.36184 .56331 .36768 .56999 .37727 .56767 .37148 .56032 Mtetra
.629 .682 .881 r
.37148 .56032 .37727 .56767 .38688 .566 .38113 .55805 Mtetra
.597 .653 .876 r
.38113 .55805 .38688 .566 .39652 .56476 .39078 .55661 Mtetra
.555 .63 .881 r
.39078 .55661 .39652 .56476 .40618 .56388 .40044 .55618 Mtetra
.542 .638 .895 r
.40044 .55618 .40618 .56388 .41591 .5624 .41014 .55591 Mtetra
.549 .682 .926 r
.41014 .55591 .41591 .5624 .42573 .55965 .41991 .55522 Mtetra
.625 .789 .961 r
.41991 .55522 .42573 .55965 .43563 .55505 .42978 .55264 Mtetra
.742 .896 .948 r
.42978 .55264 .43563 .55505 .4456 .54819 .43976 .54718 Mtetra
.803 .948 .917 r
.43976 .54718 .4456 .54819 .45561 .5407 .44981 .53975 Mtetra
.842 .944 .888 r
.44981 .53975 .45561 .5407 .46562 .53364 .4599 .53098 Mtetra
.813 .887 .898 r
.4599 .53098 .46562 .53364 .47561 .52855 .46997 .5233 Mtetra
.728 .785 .898 r
.46997 .5233 .47561 .52855 .48559 .52636 .48001 .51816 Mtetra
.635 .667 .863 r
.48001 .51816 .48559 .52636 .4956 .5262 .49005 .51561 Mtetra
.549 .573 .831 r
.49005 .51561 .4956 .5262 .50565 .52757 .50012 .51565 Mtetra
.519 .533 .81 r
.50012 .51565 .50565 .52757 .51577 .5291 .51023 .51676 Mtetra
.515 .524 .804 r
.51023 .51676 .51577 .5291 .52595 .53001 .52041 .51807 Mtetra
.532 .541 .81 r
.52041 .51807 .52595 .53001 .53619 .53001 .53066 .5188 Mtetra
.563 .571 .82 r
.53066 .5188 .53619 .53001 .54648 .5289 .54096 .51849 Mtetra
.592 .601 .83 r
.54096 .51849 .54648 .5289 .55682 .52697 .55131 .51719 Mtetra
.623 .63 .836 r
.55131 .51719 .55682 .52697 .56719 .52434 .5617 .51488 Mtetra
.649 .649 .836 r
.5617 .51488 .56719 .52434 .5776 .52116 .57212 .51168 Mtetra
.672 .658 .828 r
.57212 .51168 .5776 .52116 .58803 .51743 .58256 .50758 Mtetra
.693 .66 .813 r
.58256 .50758 .58803 .51743 .59849 .51299 .59302 .50245 Mtetra
.708 .654 .794 r
.59302 .50245 .59849 .51299 .60896 .50773 .60348 .49633 Mtetra
.72 .646 .775 r
.60348 .49633 .60896 .50773 .61942 .50134 .61394 .48914 Mtetra
.722 .637 .762 r
.61394 .48914 .61942 .50134 .62987 .49401 .62439 .48136 Mtetra
.716 .628 .758 r
.62439 .48136 .62987 .49401 .64031 .48604 .63486 .47376 Mtetra
.702 .627 .77 r
.63486 .47376 .64031 .48604 .65078 .47822 .64538 .46723 Mtetra
.659 .626 .806 r
.64538 .46723 .65078 .47822 .66131 .47193 .65603 .46332 Mtetra
.586 .644 .875 r
.65603 .46332 .66131 .47193 .67196 .46771 .66683 .46204 Mtetra
.39 .647 .959 r
.66683 .46204 .67196 .46771 .68278 .46642 .6778 .46335 Mtetra
.081 .569 .899 r
.6778 .46335 .68278 .46642 .69377 .46716 .6889 .4658 Mtetra
.038 .593 .822 r
.6889 .4658 .69377 .46716 .70484 .46834 .70001 .46689 Mtetra
.283 .762 .927 r
.70001 .46689 .70484 .46834 .71596 .4689 .71109 .46598 Mtetra
.636 .882 .986 r
.71109 .46598 .71596 .4689 .727 .46716 .72204 .46212 Mtetra
.74 .823 .916 r
.72204 .46212 .727 .46716 .73797 .46351 .73291 .45631 Mtetra
.738 .75 .862 r
.73291 .45631 .73797 .46351 .74889 .45855 .74378 .45005 Mtetra
.723 .711 .839 r
.74378 .45005 .74889 .45855 .7598 .45297 .75468 .44395 Mtetra
.695 .689 .84 r
.75468 .44395 .7598 .45297 .77077 .44774 .76568 .43888 Mtetra
.674 .684 .852 r
.76568 .43888 .77077 .44774 .7818 .44295 .77679 .43468 Mtetra
.655 .691 .872 r
.77679 .43468 .7818 .44295 .79293 .43884 .78799 .4312 Mtetra
.641 .704 .893 r
.78799 .4312 .79293 .43884 .80413 .4352 .79927 .42818 Mtetra
.635 .722 .91 r
.79927 .42818 .80413 .4352 .81541 .43186 .81062 .42527 Mtetra
.633 .737 .923 r
.81062 .42527 .81541 .43186 .82674 .42869 .82201 .42237 Mtetra
.637 .749 .929 r
.82201 .42237 .82674 .42869 .83813 .42553 .83344 .41932 Mtetra
.641 .756 .932 r
.83344 .41932 .83813 .42553 .84956 .42234 .84491 .41614 Mtetra
.647 .759 .931 r
.84491 .41614 .84956 .42234 .86103 .41907 .8564 .4128 Mtetra
.651 .759 .929 r
.8564 .4128 .86103 .41907 .87254 .41572 .86794 .40935 Mtetra
.653 .757 .926 r
.86794 .40935 .87254 .41572 .88409 .41232 .87952 .40582 Mtetra
.655 .754 .923 r
.87952 .40582 .88409 .41232 .89569 .40886 .89113 .40224 Mtetra
.65 .75 .923 r
.27027 .58715 .27639 .59249 .28574 .58959 .27962 .58436 Mtetra
.65 .755 .926 r
.27962 .58436 .28574 .58959 .29512 .58663 .28901 .58157 Mtetra
.652 .762 .93 r
.28901 .58157 .29512 .58663 .30454 .58361 .29844 .5787 Mtetra
.656 .77 .933 r
.29844 .5787 .30454 .58361 .31399 .58048 .30791 .57572 Mtetra
.662 .778 .935 r
.30791 .57572 .31399 .58048 .32349 .57721 .31742 .57257 Mtetra
.671 .785 .935 r
.31742 .57257 .32349 .57721 .33303 .57381 .32697 .5692 Mtetra
.684 .79 .93 r
.32697 .5692 .33303 .57381 .3426 .57027 .33658 .56553 Mtetra
.692 .787 .923 r
.33658 .56553 .3426 .57027 .35221 .56674 .34623 .56163 Mtetra
.7 .776 .911 r
.34623 .56163 .35221 .56674 .36184 .56331 .35592 .55751 Mtetra
.691 .75 .896 r
.35592 .55751 .36184 .56331 .37148 .56032 .36562 .55355 Mtetra
.673 .715 .88 r
.36562 .55355 .37148 .56032 .38113 .55805 .37534 .55003 Mtetra
.636 .668 .864 r
.37534 .55003 .38113 .55805 .39078 .55661 .38505 .54752 Mtetra
.582 .619 .854 r
.38505 .54752 .39078 .55661 .40044 .55618 .39474 .54651 Mtetra
.536 .585 .85 r
.39474 .54651 .40044 .55618 .41014 .55591 .40443 .54674 Mtetra
.48 .569 .868 r
.40443 .54674 .41014 .55591 .41991 .55522 .41414 .54804 Mtetra
.505 .641 .916 r
.41414 .54804 .41991 .55522 .42978 .55264 .42394 .54829 Mtetra
.603 .788 .969 r
.42394 .54829 .42978 .55264 .43976 .54718 .43387 .54602 Mtetra
.717 .942 .957 r
.43387 .54602 .43976 .54718 .44981 .53975 .44391 .54057 Mtetra
.821 .992 .868 r
.44391 .54057 .44981 .53975 .4599 .53098 .45405 .53158 Mtetra
.848 .985 .861 r
.45405 .53158 .4599 .53098 .46997 .5233 .46421 .5219 Mtetra
.839 .933 .89 r
.46421 .5219 .46997 .5233 .48001 .51816 .47435 .51322 Mtetra
.759 .803 .888 r
.47435 .51322 .48001 .51816 .49005 .51561 .48446 .50704 Mtetra
.643 .662 .854 r
.48446 .50704 .49005 .51561 .50012 .51565 .49456 .50418 Mtetra
.577 .572 .811 r
.49456 .50418 .50012 .51565 .51023 .51676 .50469 .5034 Mtetra
.541 .524 .786 r
.50469 .5034 .51023 .51676 .52041 .51807 .51486 .50399 Mtetra
.54 .514 .776 r
.51486 .50399 .52041 .51807 .53066 .5188 .5251 .5047 Mtetra
.557 .524 .774 r
.5251 .5047 .53066 .5188 .54096 .51849 .5354 .50477 Mtetra
.581 .543 .777 r
.5354 .50477 .54096 .51849 .55131 .51719 .54575 .50389 Mtetra
.61 .564 .779 r
.54575 .50389 .55131 .51719 .5617 .51488 .55614 .50183 Mtetra
.636 .582 .777 r
.55614 .50183 .5617 .51488 .57212 .51168 .56657 .4986 Mtetra
.659 .594 .771 r
.56657 .4986 .57212 .51168 .58256 .50758 .57701 .49419 Mtetra
.679 .601 .761 r
.57701 .49419 .58256 .50758 .59302 .50245 .58747 .48858 Mtetra
.692 .602 .751 r
.58747 .48858 .59302 .50245 .60348 .49633 .59793 .48202 Mtetra
.699 .601 .743 r
.59793 .48202 .60348 .49633 .61394 .48914 .60839 .47479 Mtetra
.697 .599 .744 r
.60839 .47479 .61394 .48914 .62439 .48136 .61887 .46768 Mtetra
.679 .598 .758 r
.61887 .46768 .62439 .48136 .63486 .47376 .62941 .46193 Mtetra
.649 .608 .795 r
.62941 .46193 .63486 .47376 .64538 .46723 .64004 .45829 Mtetra
.548 .618 .874 r
.64004 .45829 .64538 .46723 .65603 .46332 .65085 .45801 Mtetra
.289 .607 .954 r
.65085 .45801 .65603 .46332 .66683 .46204 .66182 .46029 Mtetra
0 .408 .711 r
.66182 .46029 .66683 .46204 .6778 .46335 .67292 .46361 Mtetra
.301 0 0 r
.67292 .46361 .6778 .46335 .6889 .4658 .68408 .46624 Mtetra
0 0 0 r
.68408 .46624 .6889 .4658 .70001 .46689 .69513 .46527 Mtetra
.603 .92 .974 r
.69513 .46527 .70001 .46689 .71109 .46598 .70606 .46105 Mtetra
.77 .834 .901 r
.70606 .46105 .71109 .46598 .72204 .46212 .71688 .45424 Mtetra
.766 .741 .83 r
.71688 .45424 .72204 .46212 .73291 .45631 .72765 .44634 Mtetra
.725 .681 .807 r
.72765 .44634 .73291 .45631 .74378 .45005 .7385 .43952 Mtetra
.695 .658 .809 r
.7385 .43952 .74378 .45005 .75468 .44395 .74946 .43396 Mtetra
.663 .654 .831 r
.74946 .43396 .75468 .44395 .76568 .43888 .76056 .42995 Mtetra
.638 .667 .862 r
.76056 .42995 .76568 .43888 .77679 .43468 .77178 .42698 Mtetra
.622 .695 .896 r
.77178 .42698 .77679 .43468 .78799 .4312 .78309 .42447 Mtetra
.611 .722 .924 r
.78309 .42447 .78799 .4312 .79927 .42818 .79446 .42213 Mtetra
.616 .75 .941 r
.79446 .42213 .79927 .42818 .81062 .42527 .80587 .41955 Mtetra
.622 .767 .949 r
.80587 .41955 .81062 .42527 .82201 .42237 .81731 .41674 Mtetra
.634 .776 .948 r
.81731 .41674 .82201 .42237 .83344 .41932 .82877 .41361 Mtetra
.644 .778 .945 r
.82877 .41361 .83344 .41932 .84491 .41614 .84025 .41025 Mtetra
.652 .775 .939 r
.84025 .41025 .84491 .41614 .8564 .4128 .85177 .40672 Mtetra
.657 .771 .933 r
.85177 .40672 .8564 .4128 .86794 .40935 .86332 .40306 Mtetra
.66 .765 .928 r
.86332 .40306 .86794 .40935 .87952 .40582 .87491 .39932 Mtetra
.66 .759 .923 r
.87491 .39932 .87952 .40582 .89113 .40224 .88655 .39556 Mtetra
.645 .749 .925 r
.2641 .58177 .27027 .58715 .27962 .58436 .27346 .57908 Mtetra
.643 .753 .929 r
.27346 .57908 .27962 .58436 .28901 .58157 .28286 .57642 Mtetra
.643 .759 .933 r
.28286 .57642 .28901 .58157 .29844 .5787 .2923 .57373 Mtetra
.645 .767 .937 r
.2923 .57373 .29844 .5787 .30791 .57572 .30177 .57097 Mtetra
.649 .777 .942 r
.30177 .57097 .30791 .57572 .31742 .57257 .31129 .56809 Mtetra
.658 .79 .945 r
.31129 .56809 .31742 .57257 .32697 .5692 .32085 .56498 Mtetra
.672 .804 .946 r
.32085 .56498 .32697 .5692 .33658 .56553 .33047 .56153 Mtetra
.688 .817 .944 r
.33047 .56153 .33658 .56553 .34623 .56163 .34014 .55767 Mtetra
.71 .823 .935 r
.34014 .55767 .34623 .56163 .35592 .55751 .34987 .55327 Mtetra
.72 .814 .924 r
.34987 .55327 .35592 .55751 .36562 .55355 .35964 .54861 Mtetra
.722 .789 .905 r
.35964 .54861 .36562 .55355 .37534 .55003 .36944 .54381 Mtetra
.694 .74 .886 r
.36944 .54381 .37534 .55003 .38505 .54752 .37924 .53968 Mtetra
.646 .678 .866 r
.37924 .53968 .38505 .54752 .39474 .54651 .38901 .53684 Mtetra
.581 .607 .843 r
.38901 .53684 .39474 .54651 .40443 .54674 .39875 .53588 Mtetra
.494 .539 .831 r
.39875 .53588 .40443 .54674 .41414 .54804 .40846 .5373 Mtetra
.466 .527 .836 r
.40846 .5373 .41414 .54804 .42394 .54829 .4182 .53933 Mtetra
.469 .572 .876 r
.4182 .53933 .42394 .54829 .43387 .54602 .42803 .54075 Mtetra
.579 .744 .955 r
.42803 .54075 .43387 .54602 .44391 .54057 .43801 .53913 Mtetra
.755 .937 .945 r
.43801 .53913 .44391 .54057 .45405 .53158 .44813 .53299 Mtetra
.792 .998 .851 r
.44813 .53299 .45405 .53158 .46421 .5219 .45833 .52409 Mtetra
.824 1 .803 r
.45833 .52409 .46421 .5219 .47435 .51322 .46855 .51357 Mtetra
.84 .983 .869 r
.46855 .51357 .47435 .51322 .48446 .50704 .47876 .50418 Mtetra
.784 .887 .92 r
.47876 .50418 .48446 .50704 .49456 .50418 .48893 .49747 Mtetra
.692 .733 .882 r
.48893 .49747 .49456 .50418 .50469 .5034 .49911 .49323 Mtetra
.61 .614 .831 r
.49911 .49323 .50469 .5034 .51486 .50399 .5093 .49134 Mtetra
.58 .557 .793 r
.5093 .49134 .51486 .50399 .5251 .5047 .51953 .49045 Mtetra
.576 .533 .77 r
.51953 .49045 .5251 .5047 .5354 .50477 .52982 .48974 Mtetra
.588 .531 .759 r
.52982 .48974 .5354 .50477 .54575 .50389 .54017 .48852 Mtetra
.607 .539 .752 r
.54017 .48852 .54575 .50389 .55614 .50183 .55055 .48635 Mtetra
.628 .55 .748 r
.55055 .48635 .55614 .50183 .56657 .4986 .56097 .48308 Mtetra
.647 .561 .743 r
.56097 .48308 .56657 .4986 .57701 .49419 .57142 .47872 Mtetra
.663 .57 .74 r
.57142 .47872 .57701 .49419 .58747 .48858 .58188 .4734 Mtetra
.673 .578 .741 r
.58188 .4734 .58747 .48858 .59793 .48202 .59235 .46756 Mtetra
.674 .586 .75 r
.59235 .46756 .59793 .48202 .60839 .47479 .60286 .46189 Mtetra
.665 .6 .773 r
.60286 .46189 .60839 .47479 .61887 .46768 .61342 .45722 Mtetra
.619 .618 .828 r
.61342 .45722 .61887 .46768 .62941 .46193 .62408 .45492 Mtetra
.499 .653 .928 r
.62408 .45492 .62941 .46193 .64004 .45829 .63487 .45513 Mtetra
.021 .524 .871 r
.63487 .45513 .64004 .45829 .65085 .45801 .64583 .45807 Mtetra
.413 0 0 r
.64583 .45807 .65085 .45801 .66182 .46029 .65692 .46219 Mtetra
.398 0 0 r
.65692 .46219 .66182 .46029 .67292 .46361 .66803 .46467 Mtetra
.086 0 0 r
.66803 .46467 .67292 .46361 .68408 .46624 .67909 .46437 Mtetra
.662 .93 .971 r
.67909 .46437 .68408 .46624 .69513 .46527 .68998 .45944 Mtetra
.791 .806 .864 r
.68998 .45944 .69513 .46527 .70606 .46105 .70074 .4514 Mtetra
.761 .701 .795 r
.70074 .4514 .70606 .46105 .71688 .45424 .71148 .44272 Mtetra
.733 .658 .775 r
.71148 .44272 .71688 .45424 .72765 .44634 .72226 .43463 Mtetra
.689 .635 .791 r
.72226 .43463 .72765 .44634 .7385 .43952 .7332 .42898 Mtetra
.653 .639 .824 r
.7332 .42898 .7385 .43952 .74946 .43396 .74431 .42526 Mtetra
.619 .665 .873 r
.74431 .42526 .74946 .43396 .76056 .42995 .75555 .42288 Mtetra
.587 .7 .921 r
.75555 .42288 .76056 .42995 .77178 .42698 .7669 .42119 Mtetra
.578 .743 .955 r
.7669 .42119 .77178 .42698 .78309 .42447 .77829 .41936 Mtetra
.579 .773 .971 r
.77829 .41936 .78309 .42447 .79446 .42213 .78972 .41725 Mtetra
.603 .794 .973 r
.78972 .41725 .79446 .42213 .80587 .41955 .80116 .4146 Mtetra
.624 .8 .967 r
.80116 .4146 .80587 .41955 .81731 .41674 .81261 .41151 Mtetra
.643 .797 .957 r
.81261 .41151 .81731 .41674 .82877 .41361 .82408 .40807 Mtetra
.656 .79 .946 r
.82408 .40807 .82877 .41361 .84025 .41025 .83557 .40438 Mtetra
.661 .781 .937 r
.83557 .40438 .84025 .41025 .85177 .40672 .8471 .40057 Mtetra
.665 .773 .93 r
.8471 .40057 .85177 .40672 .86332 .40306 .85867 .39668 Mtetra
.666 .766 .925 r
.85867 .39668 .86332 .40306 .87491 .39932 .87027 .39275 Mtetra
.665 .76 .921 r
.87027 .39275 .87491 .39932 .88655 .39556 .88193 .38884 Mtetra
.643 .748 .926 r
.25789 .57635 .2641 .58177 .27346 .57908 .26727 .57369 Mtetra
.639 .749 .928 r
.26727 .57369 .27346 .57908 .28286 .57642 .27668 .5711 Mtetra
.637 .751 .931 r
.27668 .5711 .28286 .57642 .2923 .57373 .28613 .56854 Mtetra
.635 .756 .936 r
.28613 .56854 .2923 .57373 .30177 .57097 .29561 .56599 Mtetra
.632 .765 .943 r
.29561 .56599 .30177 .57097 .31129 .56809 .30512 .56346 Mtetra
.635 .78 .951 r
.30512 .56346 .31129 .56809 .32085 .56498 .31468 .56081 Mtetra
.641 .801 .96 r
.31468 .56081 .32085 .56498 .33047 .56153 .32429 .55794 Mtetra
.658 .83 .966 r
.32429 .55794 .33047 .56153 .34014 .55767 .33396 .55461 Mtetra
.687 .858 .964 r
.33396 .55461 .34014 .55767 .34987 .55327 .3437 .55059 Mtetra
.718 .878 .956 r
.3437 .55059 .34987 .55327 .35964 .54861 .3535 .54582 Mtetra
.754 .876 .935 r
.3535 .54582 .35964 .54861 .36944 .54381 .36338 .54015 Mtetra
.76 .843 .914 r
.36338 .54015 .36944 .54381 .37924 .53968 .37328 .53429 Mtetra
.741 .778 .883 r
.37328 .53429 .37924 .53968 .38901 .53684 .38319 .52869 Mtetra
.675 .682 .849 r
.38319 .52869 .38901 .53684 .39875 .53588 .39306 .52486 Mtetra
.581 .581 .817 r
.39306 .52486 .39875 .53588 .40846 .5373 .40285 .52393 Mtetra
.5 .5 .788 r
.40285 .52393 .40846 .5373 .4182 .53933 .41259 .52569 Mtetra
.407 .442 .784 r
.41259 .52569 .4182 .53933 .42803 .54075 .42233 .52995 Mtetra
.412 .498 .837 r
.42233 .52995 .42803 .54075 .43801 .53913 .43218 .53304 Mtetra
.518 .691 .946 r
.43218 .53304 .43801 .53913 .44813 .53299 .44219 .53264 Mtetra
.623 .945 .947 r
.44219 .53264 .44813 .53299 .45833 .52409 .45234 .5279 Mtetra
.656 .944 .696 r
.45234 .5279 .45833 .52409 .46855 .51357 .46262 .51845 Mtetra
.655 .921 .624 r
.46262 .51845 .46855 .51357 .47876 .50418 .47291 .50755 Mtetra
.747 .979 .733 r
.47291 .50755 .47876 .50418 .48893 .49747 .48319 .49709 Mtetra
.823 .972 .894 r
.48319 .49709 .48893 .49747 .49911 .49323 .49345 .48854 Mtetra
.749 .817 .905 r
.49345 .48854 .49911 .49323 .5093 .49134 .50369 .48272 Mtetra
.675 .678 .845 r
.50369 .48272 .5093 .49134 .51953 .49045 .51395 .47869 Mtetra
.629 .597 .798 r
.51395 .47869 .51953 .49045 .52982 .48974 .52424 .47593 Mtetra
.616 .562 .77 r
.52424 .47593 .52982 .48974 .54017 .48852 .53458 .47346 Mtetra
.618 .549 .754 r
.53458 .47346 .54017 .48852 .55055 .48635 .54496 .47073 Mtetra
.628 .549 .746 r
.54496 .47073 .55055 .48635 .56097 .48308 .55537 .46743 Mtetra
.638 .554 .744 r
.55537 .46743 .56097 .48308 .57142 .47872 .56582 .46357 Mtetra
.644 .563 .749 r
.56582 .46357 .57142 .47872 .58188 .4734 .5763 .45944 Mtetra
.643 .576 .764 r
.5763 .45944 .58188 .4734 .59235 .46756 .58682 .4556 Mtetra
.622 .593 .8 r
.58682 .4556 .59235 .46756 .60286 .46189 .59741 .45304 Mtetra
.564 .629 .874 r
.59741 .45304 .60286 .46189 .61342 .45722 .60809 .45229 Mtetra
.277 .62 .959 r
.60809 .45229 .61342 .45722 .62408 .45492 .6189 .45431 Mtetra
.36 0 0 r
.6189 .45431 .62408 .45492 .63487 .45513 .62986 .45829 Mtetra
.547 .015 0 r
.62986 .45829 .63487 .45513 .64583 .45807 .64092 .46273 Mtetra
.509 .003 0 r
.64092 .46273 .64583 .45807 .65692 .46219 .65202 .46573 Mtetra
.163 0 0 r
.65202 .46573 .65692 .46219 .66803 .46467 .663 .46395 Mtetra
.687 .967 .931 r
.663 .46395 .66803 .46467 .67909 .46437 .67384 .45775 Mtetra
.814 .785 .826 r
.67384 .45775 .67909 .46437 .68998 .45944 .68453 .44796 Mtetra
.774 .675 .755 r
.68453 .44796 .68998 .45944 .70074 .4514 .69515 .43694 Mtetra
.715 .612 .742 r
.69515 .43694 .70074 .4514 .71148 .44272 .70591 .42848 Mtetra
.675 .594 .758 r
.70591 .42848 .71148 .44272 .72226 .43463 .71684 .42275 Mtetra
.625 .601 .807 r
.71684 .42275 .72226 .43463 .7332 .42898 .72798 .42 Mtetra
.568 .634 .877 r
.72798 .42 .7332 .42898 .74431 .42526 .73929 .41908 Mtetra
.522 .703 .953 r
.73929 .41908 .74431 .42526 .75555 .42288 .75069 .41844 Mtetra
.481 .757 .991 r
.75069 .41844 .75555 .42288 .7669 .42119 .76214 .41761 Mtetra
.508 .809 .999 r
.76214 .41761 .7669 .42119 .77829 .41936 .77358 .41584 Mtetra
.557 .835 .997 r
.77358 .41584 .77829 .41936 .78972 .41725 .78501 .41331 Mtetra
.613 .84 .986 r
.78501 .41331 .78972 .41725 .80116 .4146 .79644 .41006 Mtetra
.648 .829 .97 r
.79644 .41006 .80116 .4146 .81261 .41151 .80788 .40632 Mtetra
.664 .809 .953 r
.80788 .40632 .81261 .41151 .82408 .40807 .81934 .40236 Mtetra
.672 .792 .939 r
.81934 .40236 .82408 .40807 .83557 .40438 .83084 .39825 Mtetra
.671 .777 .929 r
.83084 .39825 .83557 .40438 .8471 .40057 .84237 .39417 Mtetra
.671 .768 .923 r
.84237 .39417 .8471 .40057 .85867 .39668 .85396 .3901 Mtetra
.669 .762 .92 r
.85396 .3901 .85867 .39668 .87027 .39275 .86559 .38605 Mtetra
.667 .758 .918 r
.86559 .38605 .87027 .39275 .88193 .38884 .87727 .38207 Mtetra
.647 .749 .924 r
.25164 .57089 .25789 .57635 .26727 .57369 .26105 .56812 Mtetra
.644 .745 .923 r
.26105 .56812 .26727 .57369 .27668 .5711 .27049 .56542 Mtetra
.64 .741 .922 r
.27049 .56542 .27668 .5711 .28613 .56854 .27995 .5628 Mtetra
.634 .738 .923 r
.27995 .5628 .28613 .56854 .29561 .56599 .28945 .5603 Mtetra
.626 .738 .927 r
.28945 .5603 .29561 .56599 .30512 .56346 .29897 .55796 Mtetra
.621 .744 .934 r
.29897 .55796 .30512 .56346 .31468 .56081 .30852 .55568 Mtetra
.616 .757 .946 r
.30852 .55568 .31468 .56081 .32429 .55794 .31811 .55345 Mtetra
.623 .785 .959 r
.31811 .55345 .32429 .55794 .33396 .55461 .32776 .55094 Mtetra
.639 .824 .972 r
.32776 .55094 .33396 .55461 .3437 .55059 .33747 .54793 Mtetra
.672 .874 .975 r
.33747 .54793 .3437 .55059 .3535 .54582 .34726 .54403 Mtetra
.723 .915 .96 r
.34726 .54403 .3535 .54582 .36338 .54015 .35715 .53887 Mtetra
.764 .936 .94 r
.35715 .53887 .36338 .54015 .37328 .53429 .36711 .53262 Mtetra
.804 .92 .915 r
.36711 .53262 .37328 .53429 .38319 .52869 .37713 .52533 Mtetra
.784 .857 .905 r
.37713 .52533 .38319 .52869 .39306 .52486 .38714 .5186 Mtetra
.718 .749 .877 r
.38714 .5186 .39306 .52486 .40285 .52393 .39711 .51359 Mtetra
.604 .607 .827 r
.39711 .51359 .40285 .52393 .41259 .52569 .40698 .51187 Mtetra
.471 .477 .783 r
.40698 .51187 .41259 .52569 .42233 .52995 .41675 .5145 Mtetra
.425 .429 .76 r
.41675 .5145 .42233 .52995 .43218 .53304 .42654 .51885 Mtetra
.409 .437 .778 r
.42654 .51885 .43218 .53304 .44219 .53264 .43642 .52322 Mtetra
.488 .573 .868 r
.43642 .52322 .44219 .53264 .45234 .5279 .44646 .52433 Mtetra
.681 .848 .963 r
.44646 .52433 .45234 .5279 .46262 .51845 .45666 .52029 Mtetra
.681 .978 .829 r
.45666 .52029 .46262 .51845 .47291 .50755 .46696 .51269 Mtetra
.57 .874 .578 r
.46696 .51269 .47291 .50755 .48319 .49709 .4773 .50253 Mtetra
.531 .845 .54 r
.4773 .50253 .48319 .49709 .49345 .48854 .48765 .49237 Mtetra
.576 .904 .659 r
.48765 .49237 .49345 .48854 .50369 .48272 .49797 .48362 Mtetra
.701 .983 .875 r
.49797 .48362 .50369 .48272 .51395 .47869 .5083 .4765 Mtetra
.72 .916 .961 r
.5083 .4765 .51395 .47869 .52424 .47593 .51863 .47114 Mtetra
.696 .808 .934 r
.51863 .47114 .52424 .47593 .53458 .47346 .52899 .4668 Mtetra
.67 .734 .898 r
.52899 .4668 .53458 .47346 .54496 .47073 .53939 .46314 Mtetra
.656 .702 .88 r
.53939 .46314 .54496 .47073 .55537 .46743 .54983 .45982 Mtetra
.644 .697 .884 r
.54983 .45982 .55537 .46743 .56582 .46357 .56031 .45684 Mtetra
.616 .715 .916 r
.56031 .45684 .56582 .46357 .5763 .45944 .57084 .45454 Mtetra
.537 .754 .976 r
.57084 .45454 .5763 .45944 .58682 .4556 .58144 .45327 Mtetra
.207 .687 .933 r
.58144 .45327 .58682 .4556 .59741 .45304 .59212 .45379 Mtetra
.31 0 0 r
.59212 .45379 .59741 .45304 .60809 .45229 .60292 .45597 Mtetra
.521 0 0 r
.60292 .45597 .60809 .45229 .6189 .45431 .61383 .45958 Mtetra
.543 .054 .047 r
.61383 .45958 .6189 .45431 .62986 .45829 .62483 .46323 Mtetra
.421 0 0 r
.62483 .46323 .62986 .45829 .64092 .46273 .63583 .46429 Mtetra
0 0 0 r
.63583 .46429 .64092 .46273 .65202 .46573 .64677 .46176 Mtetra
.8 .872 .9 r
.64677 .46176 .65202 .46573 .663 .46395 .65755 .45398 Mtetra
.792 .705 .769 r
.65755 .45398 .663 .46395 .67384 .45775 .66819 .44285 Mtetra
.745 .623 .724 r
.66819 .44285 .67384 .45775 .68453 .44796 .67883 .43171 Mtetra
.714 .595 .722 r
.67883 .43171 .68453 .44796 .69515 .43694 .68954 .42231 Mtetra
.659 .582 .757 r
.68954 .42231 .69515 .43694 .70591 .42848 .7005 .41735 Mtetra
.594 .6 .827 r
.7005 .41735 .70591 .42848 .71684 .42275 .71168 .41576 Mtetra
.493 .659 .934 r
.71168 .41576 .71684 .42275 .72798 .42 .72303 .41595 Mtetra
.33 .693 .981 r
.72303 .41595 .72798 .42 .73929 .41908 .73449 .41673 Mtetra
.293 .743 .959 r
.73449 .41673 .73929 .41908 .75069 .41844 .74596 .41645 Mtetra
.369 .801 .966 r
.74596 .41645 .75069 .41844 .76214 .41761 .75741 .41505 Mtetra
.522 .86 .994 r
.75741 .41505 .76214 .41761 .77358 .41584 .76882 .41235 Mtetra
.622 .863 .988 r
.76882 .41235 .77358 .41584 .78501 .41331 .78022 .40871 Mtetra
.667 .834 .963 r
.78022 .40871 .78501 .41331 .79644 .41006 .79161 .40456 Mtetra
.684 .804 .939 r
.79161 .40456 .79644 .41006 .80788 .40632 .80303 .40012 Mtetra
.683 .779 .923 r
.80303 .40012 .80788 .40632 .81934 .40236 .81449 .39572 Mtetra
.68 .763 .914 r
.81449 .39572 .81934 .40236 .83084 .39825 .82599 .39137 Mtetra
.674 .753 .91 r
.82599 .39137 .83084 .39825 .84237 .39417 .83756 .3872 Mtetra
.67 .749 .91 r
.83756 .3872 .84237 .39417 .85396 .3901 .84918 .38313 Mtetra
.666 .749 .912 r
.84918 .38313 .85396 .3901 .86559 .38605 .86086 .37916 Mtetra
.663 .751 .915 r
.86086 .37916 .86559 .38605 .87727 .38207 .87259 .37524 Mtetra
.657 .752 .92 r
.24535 .5654 .25164 .57089 .26105 .56812 .2548 .56238 Mtetra
.656 .743 .914 r
.2548 .56238 .26105 .56812 .27049 .56542 .26428 .55938 Mtetra
.651 .732 .909 r
.26428 .55938 .27049 .56542 .27995 .5628 .27378 .5565 Mtetra
.643 .722 .905 r
.27378 .5565 .27995 .5628 .28945 .5603 .2833 .5538 Mtetra
.632 .713 .905 r
.2833 .5538 .28945 .5603 .29897 .55796 .29285 .55136 Mtetra
.62 .706 .907 r
.29285 .55136 .29897 .55796 .30852 .55568 .30241 .5492 Mtetra
.602 .705 .916 r
.30241 .5492 .30852 .55568 .31811 .55345 .31199 .54741 Mtetra
.591 .718 .931 r
.31199 .54741 .31811 .55345 .32776 .55094 .3216 .54576 Mtetra
.578 .746 .957 r
.3216 .54576 .32776 .55094 .33747 .54793 .33125 .54414 Mtetra
.586 .807 .984 r
.33125 .54414 .33747 .54793 .34726 .54403 .34098 .54195 Mtetra
.607 .883 .991 r
.34098 .54195 .34726 .54403 .35715 .53887 .3508 .53873 Mtetra
.639 .95 .946 r
.3508 .53873 .35715 .53887 .36711 .53262 .36073 .53389 Mtetra
.715 .986 .881 r
.36073 .53389 .36711 .53262 .37713 .52533 .37079 .52686 Mtetra
.783 .997 .861 r
.37079 .52686 .37713 .52533 .38714 .5186 .38093 .51835 Mtetra
.856 .957 .874 r
.38093 .51835 .38714 .5186 .39711 .51359 .39112 .50884 Mtetra
.792 .809 .866 r
.39112 .50884 .39711 .51359 .40698 .51187 .40123 .50129 Mtetra
.655 .626 .809 r
.40123 .50129 .40698 .51187 .41675 .5145 .41121 .49769 Mtetra
.534 .48 .743 r
.41121 .49769 .41675 .5145 .42654 .51885 .42109 .49868 Mtetra
.422 .382 .709 r
.42109 .49868 .42654 .51885 .43642 .52322 .43089 .50453 Mtetra
.394 .377 .722 r
.43089 .50453 .43642 .52322 .44646 .52433 .44077 .51087 Mtetra
.407 .448 .791 r
.44077 .51087 .44646 .52433 .45666 .52029 .45079 .51501 Mtetra
.458 .702 .972 r
.45079 .51501 .45666 .52029 .46696 .51269 .46098 .51504 Mtetra
.387 .832 .715 r
.46098 .51504 .46696 .51269 .4773 .50253 .47131 .50994 Mtetra
0 0 0 r
.47131 .50994 .4773 .50253 .48765 .49237 .4817 .50209 Mtetra
.4817 .50209 .48765 .49237 .49797 .48362 .49211 .49282 Mtetra
.49211 .49282 .49797 .48362 .5083 .4765 .50253 .48388 Mtetra
.50253 .48388 .5083 .4765 .51863 .47114 .51294 .47627 Mtetra
.51294 .47627 .51863 .47114 .52899 .4668 .52336 .47005 Mtetra
.52336 .47005 .52899 .4668 .53939 .46314 .53382 .46536 Mtetra
.53382 .46536 .53939 .46314 .54983 .45982 .5443 .46203 Mtetra
.003 0 0 r
.5443 .46203 .54983 .45982 .56031 .45684 .55485 .46004 Mtetra
.247 0 0 r
.55485 .46004 .56031 .45684 .57084 .45454 .56546 .4596 Mtetra
.422 0 0 r
.56546 .4596 .57084 .45454 .58144 .45327 .57615 .46057 Mtetra
.515 .063 .116 r
.57615 .46057 .58144 .45327 .59212 .45379 .58694 .4629 Mtetra
.536 .113 .184 r
.58694 .4629 .59212 .45379 .60292 .45597 .59781 .46558 Mtetra
.497 .079 .177 r
.59781 .46558 .60292 .45597 .61383 .45958 .60873 .46685 Mtetra
.349 0 .017 r
.60873 .46685 .61383 .45958 .62483 .46323 .61965 .46534 Mtetra
.499 .892 .732 r
.61965 .46534 .62483 .46323 .63583 .46429 .63045 .45863 Mtetra
.841 .813 .823 r
.63045 .45863 .63583 .46429 .64677 .46176 .64112 .44772 Mtetra
.773 .645 .72 r
.64112 .44772 .64677 .46176 .65755 .45398 .6517 .43455 Mtetra
.729 .581 .689 r
.6517 .43455 .65755 .45398 .66819 .44285 .66227 .42184 Mtetra
.669 .537 .695 r
.66227 .42184 .66819 .44285 .67883 .43171 .67305 .41408 Mtetra
.615 .529 .733 r
.67305 .41408 .67883 .43171 .68954 .42231 .68408 .41098 Mtetra
.513 .553 .834 r
.68408 .41098 .68954 .42231 .7005 .41735 .69536 .41195 Mtetra
.226 .571 .94 r
.69536 .41195 .7005 .41735 .71168 .41576 .70684 .41495 Mtetra
.122 0 0 r
.70684 .41495 .71168 .41576 .72303 .41595 .71834 .41693 Mtetra
.151 0 0 r
.71834 .41693 .72303 .41595 .73449 .41673 .72984 .41741 Mtetra
.114 .663 .705 r
.72984 .41741 .73449 .41673 .74596 .41645 .74126 .41564 Mtetra
.452 .877 .925 r
.74126 .41564 .74596 .41645 .75741 .41505 .75262 .41219 Mtetra
.653 .901 .982 r
.75262 .41219 .75741 .41505 .76882 .41235 .76394 .40766 Mtetra
.708 .844 .947 r
.76394 .40766 .76882 .41235 .78022 .40871 .77526 .40255 Mtetra
.707 .788 .914 r
.77526 .40255 .78022 .40871 .79161 .40456 .78662 .39746 Mtetra
.699 .754 .895 r
.78662 .39746 .79161 .40456 .80303 .40012 .79802 .39251 Mtetra
.685 .734 .888 r
.79802 .39251 .80303 .40012 .81449 .39572 .8095 .38792 Mtetra
.675 .726 .888 r
.8095 .38792 .81449 .39572 .82599 .39137 .82104 .38363 Mtetra
.667 .724 .892 r
.82104 .38363 .82599 .39137 .83756 .3872 .83266 .37961 Mtetra
.66 .728 .899 r
.83266 .37961 .83756 .3872 .84918 .38313 .84434 .37578 Mtetra
.656 .734 .907 r
.84434 .37578 .84918 .38313 .86086 .37916 .85607 .37206 Mtetra
.655 .742 .914 r
.85607 .37206 .86086 .37916 .87259 .37524 .86786 .36837 Mtetra
.669 .754 .915 r
.23902 .55988 .24535 .5654 .2548 .56238 .24851 .55656 Mtetra
.669 .745 .907 r
.24851 .55656 .2548 .56238 .26428 .55938 .25803 .55322 Mtetra
.666 .733 .9 r
.25803 .55322 .26428 .55938 .27378 .5565 .26758 .54994 Mtetra
.659 .719 .893 r
.26758 .54994 .27378 .5565 .2833 .5538 .27715 .54681 Mtetra
.649 .704 .887 r
.27715 .54681 .2833 .5538 .29285 .55136 .28674 .54392 Mtetra
.635 .687 .881 r
.28674 .54392 .29285 .55136 .30241 .5492 .29634 .54139 Mtetra
.615 .67 .879 r
.29634 .54139 .30241 .5492 .31199 .54741 .30594 .53939 Mtetra
.594 .657 .881 r
.30594 .53939 .31199 .54741 .3216 .54576 .31556 .53789 Mtetra
.567 .651 .892 r
.31556 .53789 .3216 .54576 .33125 .54414 .32518 .53698 Mtetra
.556 .668 .913 r
.32518 .53698 .33125 .54414 .34098 .54195 .33484 .53618 Mtetra
.548 .715 .95 r
.33484 .53618 .34098 .54195 .3508 .53873 .34457 .53517 Mtetra
.578 .817 .989 r
.34457 .53517 .3508 .53873 .36073 .53389 .3544 .53295 Mtetra
.63 .929 .971 r
.3544 .53295 .36073 .53389 .37079 .52686 .36437 .52871 Mtetra
.651 .969 .845 r
.36437 .52871 .37079 .52686 .38093 .51835 .37448 .52195 Mtetra
.729 .978 .75 r
.37448 .52195 .38093 .51835 .39112 .50884 .38474 .51221 Mtetra
.78 .992 .765 r
.38474 .51221 .39112 .50884 .40123 .50129 .39502 .50174 Mtetra
.849 .978 .867 r
.39502 .50174 .40123 .50129 .41121 .49769 .40527 .4921 Mtetra
.742 .78 .884 r
.40527 .4921 .41121 .49769 .42109 .49868 .41538 .48633 Mtetra
.551 .547 .803 r
.41538 .48633 .42109 .49868 .43089 .50453 .42535 .4863 Mtetra
.467 .428 .73 r
.42535 .4863 .43089 .50453 .44077 .51087 .43527 .48997 Mtetra
.421 .377 .704 r
.43527 .48997 .44077 .51087 .45079 .51501 .44521 .49605 Mtetra
.441 .406 .724 r
.44521 .49605 .45079 .51501 .46098 .51504 .45527 .50088 Mtetra
.509 .5 .782 r
.45527 .50088 .46098 .51504 .47131 .50994 .46549 .50237 Mtetra
.595 .68 .9 r
.46549 .50237 .47131 .50994 .4817 .50209 .47581 .50066 Mtetra
.664 .932 .97 r
.47581 .50066 .4817 .50209 .49211 .49282 .48623 .49588 Mtetra
.397 .823 .657 r
.48623 .49588 .49211 .49282 .50253 .48388 .49668 .48981 Mtetra
0 0 0 r
.49668 .48981 .50253 .48388 .51294 .47627 .50716 .4835 Mtetra
.056 0 0 r
.50716 .4835 .51294 .47627 .52336 .47005 .51766 .47779 Mtetra
.171 0 0 r
.51766 .47779 .52336 .47005 .53382 .46536 .52818 .47319 Mtetra
.257 0 0 r
.52818 .47319 .53382 .46536 .5443 .46203 .53874 .46985 Mtetra
.329 0 .027 r
.53874 .46985 .5443 .46203 .55485 .46004 .54935 .46775 Mtetra
.384 0 .053 r
.54935 .46775 .55485 .46004 .56546 .4596 .56002 .46678 Mtetra
.401 0 .041 r
.56002 .46678 .56546 .4596 .57615 .46057 .57076 .46642 Mtetra
.353 0 0 r
.57076 .46642 .57615 .46057 .58694 .4629 .58156 .46582 Mtetra
.088 0 0 r
.58156 .46582 .58694 .4629 .59781 .46558 .59238 .46394 Mtetra
.662 .934 .969 r
.59238 .46394 .59781 .46558 .60873 .46685 .60319 .45895 Mtetra
.771 .741 .825 r
.60319 .45895 .60873 .46685 .61965 .46534 .61394 .45072 Mtetra
.752 .629 .724 r
.61394 .45072 .61965 .46534 .63045 .45863 .6246 .43906 Mtetra
.73 .581 .688 r
.6246 .43906 .63045 .45863 .64112 .44772 .6352 .42612 Mtetra
.695 .55 .685 r
.6352 .42612 .64112 .44772 .6517 .43455 .64587 .4156 Mtetra
.665 .548 .711 r
.64587 .4156 .6517 .43455 .66227 .42184 .65669 .40882 Mtetra
.575 .558 .798 r
.65669 .40882 .66227 .42184 .67305 .41408 .66779 .4079 Mtetra
.264 .564 .935 r
.66779 .4079 .67305 .41408 .68408 .41098 .67914 .41095 Mtetra
.372 0 0 r
.67914 .41095 .68408 .41098 .69536 .41195 .69062 .41487 Mtetra
.464 0 0 r
.69062 .41487 .69536 .41195 .70684 .41495 .70216 .41807 Mtetra
.283 0 0 r
.70216 .41807 .70684 .41495 .71834 .41693 .71362 .41823 Mtetra
0 0 0 r
.71362 .41823 .71834 .41693 .72984 .41741 .72499 .4158 Mtetra
.601 .925 .968 r
.72499 .4158 .72984 .41741 .74126 .41564 .73627 .41127 Mtetra
.732 .861 .942 r
.73627 .41127 .74126 .41564 .75262 .41219 .74751 .40549 Mtetra
.732 .777 .889 r
.74751 .40549 .75262 .41219 .76394 .40766 .75877 .39949 Mtetra
.718 .73 .86 r
.75877 .39949 .76394 .40766 .77526 .40255 .77006 .39358 Mtetra
.698 .703 .851 r
.77006 .39358 .77526 .40255 .78662 .39746 .78142 .38828 Mtetra
.683 .692 .852 r
.78142 .38828 .78662 .39746 .79802 .39251 .79287 .38349 Mtetra
.669 .691 .861 r
.79287 .38349 .79802 .39251 .8095 .38792 .80441 .37924 Mtetra
.659 .695 .873 r
.80441 .37924 .8095 .38792 .82104 .38363 .81602 .37538 Mtetra
.652 .705 .885 r
.81602 .37538 .82104 .38363 .83266 .37961 .8277 .37175 Mtetra
.647 .715 .897 r
.8277 .37175 .83266 .37961 .84434 .37578 .83945 .36828 Mtetra
.645 .726 .908 r
.83945 .36828 .84434 .37578 .85607 .37206 .85125 .36487 Mtetra
.645 .737 .916 r
.85125 .36487 .85607 .37206 .86786 .36837 .8631 .36144 Mtetra
.677 .756 .911 r
.23264 .55431 .23902 .55988 .24851 .55656 .24217 .55076 Mtetra
.679 .75 .904 r
.24217 .55076 .24851 .55656 .25803 .55322 .25174 .54712 Mtetra
.679 .74 .897 r
.25174 .54712 .25803 .55322 .26758 .54994 .26134 .54344 Mtetra
.677 .728 .888 r
.26134 .54344 .26758 .54994 .27715 .54681 .27097 .53979 Mtetra
.673 .711 .877 r
.27097 .53979 .27715 .54681 .28674 .54392 .28062 .5362 Mtetra
.661 .689 .865 r
.28062 .5362 .28674 .54392 .29634 .54139 .29029 .53287 Mtetra
.644 .663 .853 r
.29029 .53287 .29634 .54139 .30594 .53939 .29996 .52998 Mtetra
.62 .633 .842 r
.29996 .52998 .30594 .53939 .31556 .53789 .30963 .52777 Mtetra
.588 .604 .836 r
.30963 .52777 .31556 .53789 .32518 .53698 .31927 .52651 Mtetra
.556 .582 .836 r
.31927 .52651 .32518 .53698 .33484 .53618 .32891 .52613 Mtetra
.514 .571 .851 r
.32891 .52613 .33484 .53618 .34457 .53517 .33855 .52672 Mtetra
.489 .601 .892 r
.33855 .52672 .34457 .53517 .3544 .53295 .34824 .52741 Mtetra
.452 .687 .966 r
.34824 .52741 .3544 .53295 .36437 .52871 .35802 .52761 Mtetra
.391 .828 .951 r
.35802 .52761 .36437 .52871 .37448 .52195 .36795 .52578 Mtetra
0 0 0 r
.36795 .52578 .37448 .52195 .38474 .51221 .37806 .52068 Mtetra
.37806 .52068 .38474 .51221 .39502 .50174 .38835 .51182 Mtetra
.38835 .51182 .39502 .50174 .40527 .4921 .3988 .49897 Mtetra
.673 .898 .55 r
.3988 .49897 .40527 .4921 .41538 .48633 .40925 .48576 Mtetra
.886 .94 .845 r
.40925 .48576 .41538 .48633 .42535 .4863 .4196 .47459 Mtetra
.701 .631 .776 r
.4196 .47459 .42535 .4863 .43527 .48997 .4298 .4684 Mtetra
.549 .455 .701 r
.4298 .4684 .43527 .48997 .44521 .49605 .43985 .46879 Mtetra
.49 .389 .667 r
.43985 .46879 .44521 .49605 .45527 .50088 .44987 .473 Mtetra
.454 .363 .662 r
.44987 .473 .45527 .50088 .46549 .50237 .45993 .47934 Mtetra
.45 .384 .692 r
.45993 .47934 .46549 .50237 .47581 .50066 .47011 .48479 Mtetra
.475 .46 .761 r
.47011 .48479 .47581 .50066 .48623 .49588 .48042 .48766 Mtetra
.495 .618 .902 r
.48042 .48766 .48623 .49588 .49668 .48981 .49083 .48815 Mtetra
.409 .827 .969 r
.49083 .48815 .49668 .48981 .50716 .4835 .50132 .48637 Mtetra
0 0 0 r
.50132 .48637 .50716 .4835 .51766 .47779 .51187 .48352 Mtetra
.15 0 0 r
.51187 .48352 .51766 .47779 .52818 .47319 .52245 .48018 Mtetra
.217 0 0 r
.52245 .48018 .52818 .47319 .53874 .46985 .53308 .47682 Mtetra
.216 0 0 r
.53308 .47682 .53874 .46985 .54935 .46775 .54376 .47344 Mtetra
.11 0 0 r
.54376 .47344 .54935 .46775 .56002 .46678 .55446 .46957 Mtetra
0 0 0 r
.55446 .46957 .56002 .46678 .57076 .46642 .5652 .46462 Mtetra
.779 .946 .931 r
.5652 .46462 .57076 .46642 .58156 .46582 .57593 .45737 Mtetra
.788 .732 .8 r
.57593 .45737 .58156 .46582 .59238 .46394 .58663 .44771 Mtetra
.746 .612 .709 r
.58663 .44771 .59238 .46394 .60319 .45895 .59727 .43541 Mtetra
.711 .55 .669 r
.59727 .43541 .60319 .45895 .61394 .45072 .60787 .42218 Mtetra
.672 .508 .655 r
.60787 .42218 .61394 .45072 .6246 .43906 .61852 .41109 Mtetra
.639 .488 .662 r
.61852 .41109 .6246 .43906 .6352 .42612 .62927 .40384 Mtetra
.565 .466 .701 r
.62927 .40384 .6352 .42612 .64587 .4156 .64029 .40328 Mtetra
.381 .459 .816 r
.64029 .40328 .64587 .4156 .65669 .40882 .65156 .40781 Mtetra
.502 0 0 r
.65156 .40781 .65669 .40882 .66779 .4079 .66303 .41446 Mtetra
.617 .153 .129 r
.66303 .41446 .66779 .4079 .67914 .41095 .6746 .42078 Mtetra
.519 .097 .179 r
.6746 .42078 .67914 .41095 .69062 .41487 .68607 .42303 Mtetra
.364 0 .054 r
.68607 .42303 .69062 .41487 .70216 .41807 .69743 .42144 Mtetra
0 0 0 r
.69743 .42144 .70216 .41807 .71362 .41823 .70866 .41649 Mtetra
.75 .961 .937 r
.70866 .41649 .71362 .41823 .72499 .4158 .7198 .40943 Mtetra
.774 .799 .873 r
.7198 .40943 .72499 .4158 .73627 .41127 .73093 .40184 Mtetra
.742 .709 .82 r
.73093 .40184 .73627 .41127 .74751 .40549 .74208 .39436 Mtetra
.708 .662 .802 r
.74208 .39436 .74751 .40549 .75877 .39949 .75331 .38786 Mtetra
.686 .644 .802 r
.75331 .38786 .75877 .39949 .77006 .39358 .76465 .38226 Mtetra
.667 .64 .814 r
.76465 .38226 .77006 .39358 .78142 .38828 .77609 .37764 Mtetra
.653 .647 .832 r
.77609 .37764 .78142 .38828 .79287 .38349 .78763 .37372 Mtetra
.644 .662 .853 r
.78763 .37372 .79287 .38349 .80441 .37924 .79926 .37026 Mtetra
.637 .679 .873 r
.79926 .37026 .80441 .37924 .81602 .37538 .81096 .36707 Mtetra
.635 .697 .89 r
.81096 .36707 .81602 .37538 .8277 .37175 .82272 .36394 Mtetra
.634 .712 .903 r
.82272 .36394 .8277 .37175 .83945 .36828 .83453 .36084 Mtetra
.634 .725 .913 r
.83453 .36084 .83945 .36828 .85125 .36487 .8464 .3577 Mtetra
.636 .736 .92 r
.8464 .3577 .85125 .36487 .8631 .36144 .85831 .35446 Mtetra
.675 .756 .912 r
.22623 .54871 .23264 .55431 .24217 .55076 .23577 .54519 Mtetra
.68 .758 .911 r
.23577 .54519 .24217 .55076 .25174 .54712 .24536 .54153 Mtetra
.684 .76 .909 r
.24536 .54153 .25174 .54712 .26134 .54344 .25499 .53774 Mtetra
.688 .757 .904 r
.25499 .53774 .26134 .54344 .27097 .53979 .26466 .53381 Mtetra
.693 .75 .895 r
.26466 .53381 .27097 .53979 .28062 .5362 .27437 .52971 Mtetra
.691 .734 .884 r
.27437 .52971 .28062 .5362 .29029 .53287 .28411 .52561 Mtetra
.684 .71 .868 r
.28411 .52561 .29029 .53287 .29996 .52998 .29388 .5216 Mtetra
.664 .675 .851 r
.29388 .5216 .29996 .52998 .30963 .52777 .30364 .51806 Mtetra
.636 .635 .832 r
.30364 .51806 .30963 .52777 .31927 .52651 .31339 .51529 Mtetra
.599 .59 .813 r
.31339 .51529 .31927 .52651 .32891 .52613 .32311 .51365 Mtetra
.552 .545 .8 r
.32311 .51365 .32891 .52613 .33855 .52672 .33278 .5135 Mtetra
.513 .513 .793 r
.33278 .5135 .33855 .52672 .34824 .52741 .34244 .51459 Mtetra
.467 .494 .803 r
.34244 .51459 .34824 .52741 .35802 .52761 .35211 .51683 Mtetra
.456 .528 .843 r
.35211 .51683 .35802 .52761 .36795 .52578 .36185 .51877 Mtetra
.469 .642 .932 r
.36185 .51877 .36795 .52578 .37806 .52068 .37173 .51928 Mtetra
.531 .886 .981 r
.37173 .51928 .37806 .52068 .38835 .51182 .38182 .51634 Mtetra
.476 .848 .614 r
.38182 .51634 .38835 .51182 .3988 .49897 .39214 .50851 Mtetra
0 0 0 r
.39214 .50851 .3988 .49897 .40925 .48576 .40261 .49712 Mtetra
.40261 .49712 .40925 .48576 .4196 .47459 .41314 .48318 Mtetra
.41314 .48318 .4196 .47459 .4298 .4684 .42361 .47085 Mtetra
.691 .977 .798 r
.42361 .47085 .4298 .4684 .43985 .46879 .43394 .46256 Mtetra
.681 .751 .905 r
.43394 .46256 .43985 .46879 .44987 .473 .44417 .45862 Mtetra
.536 .513 .776 r
.44417 .45862 .44987 .473 .45993 .47934 .45434 .45914 Mtetra
.506 .438 .715 r
.45434 .45914 .45993 .47934 .47011 .48479 .46454 .46151 Mtetra
.507 .42 .692 r
.46454 .46151 .47011 .48479 .48042 .48766 .47481 .46423 Mtetra
.523 .43 .692 r
.47481 .46423 .48042 .48766 .49083 .48815 .48517 .4661 Mtetra
.551 .456 .701 r
.48517 .4661 .49083 .48815 .50132 .48637 .49561 .46636 Mtetra
.575 .485 .715 r
.49561 .46636 .50132 .48637 .51187 .48352 .50613 .46529 Mtetra
.601 .514 .728 r
.50613 .46529 .51187 .48352 .52245 .48018 .5167 .46292 Mtetra
.621 .534 .735 r
.5167 .46292 .52245 .48018 .53308 .47682 .52732 .45952 Mtetra
.638 .544 .731 r
.52732 .45952 .53308 .47682 .54376 .47344 .53798 .4551 Mtetra
.654 .545 .719 r
.53798 .4551 .54376 .47344 .55446 .46957 .54867 .44937 Mtetra
.664 .539 .702 r
.54867 .44937 .55446 .46957 .5652 .46462 .55936 .4423 Mtetra
.673 .533 .685 r
.55936 .4423 .5652 .46462 .57593 .45737 .57005 .43359 Mtetra
.676 .528 .676 r
.57005 .43359 .57593 .45737 .58663 .44771 .58074 .424 Mtetra
.673 .526 .677 r
.58074 .424 .58663 .44771 .59727 .43541 .59143 .41474 Mtetra
.665 .537 .698 r
.59143 .41474 .59727 .43541 .60787 .42218 .60217 .40734 Mtetra
.618 .558 .764 r
.60217 .40734 .60787 .42218 .61852 .41109 .61304 .40444 Mtetra
.392 .622 .944 r
.61304 .40444 .61852 .41109 .62927 .40384 .62411 .40597 Mtetra
.568 .017 0 r
.62411 .40597 .62927 .40384 .64029 .40328 .63539 .41164 Mtetra
.638 .204 .2 r
.63539 .41164 .64029 .40328 .65156 .40781 .64684 .41898 Mtetra
.582 .176 .237 r
.64684 .41898 .65156 .40781 .66303 .41446 .6583 .42375 Mtetra
.481 .051 .144 r
.6583 .42375 .66303 .41446 .6746 .42078 .66971 .4249 Mtetra
.021 0 0 r
.66971 .4249 .6746 .42078 .68607 .42303 .68096 .42105 Mtetra
.771 .955 .932 r
.68096 .42105 .68607 .42303 .69743 .42144 .69206 .41365 Mtetra
.785 .76 .83 r
.69206 .41365 .69743 .42144 .70866 .41649 .7031 .40476 Mtetra
.749 .669 .773 r
.7031 .40476 .70866 .41649 .7198 .40943 .71413 .39554 Mtetra
.713 .624 .756 r
.71413 .39554 .7198 .40943 .73093 .40184 .72524 .38749 Mtetra
.69 .607 .758 r
.72524 .38749 .73093 .40184 .74208 .39436 .73645 .3807 Mtetra
.667 .604 .775 r
.73645 .3807 .74208 .39436 .75331 .38786 .74779 .37545 Mtetra
.65 .614 .8 r
.74779 .37545 .75331 .38786 .76465 .38226 .75925 .37136 Mtetra
.636 .634 .832 r
.75925 .37136 .76465 .38226 .77609 .37764 .77082 .36806 Mtetra
.625 .658 .863 r
.77082 .36806 .77609 .37764 .78763 .37372 .78247 .36526 Mtetra
.621 .686 .89 r
.78247 .36526 .78763 .37372 .79926 .37026 .79419 .36255 Mtetra
.619 .709 .909 r
.79419 .36255 .79926 .37026 .81096 .36707 .80597 .35985 Mtetra
.624 .727 .921 r
.80597 .35985 .81096 .36707 .82272 .36394 .81778 .35696 Mtetra
.628 .738 .927 r
.81778 .35696 .82272 .36394 .83453 .36084 .82964 .35392 Mtetra
.632 .743 .928 r
.82964 .35392 .83453 .36084 .8464 .3577 .84154 .35075 Mtetra
.637 .745 .926 r
.84154 .35075 .8464 .3577 .85831 .35446 .85348 .34743 Mtetra
.662 .753 .917 r
.21976 .54307 .22623 .54871 .23577 .54519 .2293 .53984 Mtetra
.667 .765 .924 r
.2293 .53984 .23577 .54519 .24536 .54153 .23889 .53649 Mtetra
.674 .779 .929 r
.23889 .53649 .24536 .54153 .25499 .53774 .24852 .53294 Mtetra
.685 .79 .93 r
.24852 .53294 .25499 .53774 .26466 .53381 .2582 .52912 Mtetra
.7 .797 .926 r
.2582 .52912 .26466 .53381 .27437 .52971 .26795 .52491 Mtetra
.712 .796 .917 r
.26795 .52491 .27437 .52971 .28411 .52561 .27775 .52035 Mtetra
.722 .782 .9 r
.27775 .52035 .28411 .52561 .29388 .5216 .2876 .5154 Mtetra
.719 .752 .878 r
.2876 .5154 .29388 .5216 .30364 .51806 .29749 .51037 Mtetra
.705 .707 .85 r
.29749 .51037 .30364 .51806 .31339 .51529 .30739 .50546 Mtetra
.673 .649 .818 r
.30739 .50546 .31339 .51529 .32311 .51365 .31727 .50126 Mtetra
.631 .588 .787 r
.31727 .50126 .32311 .51365 .33278 .5135 .32711 .49827 Mtetra
.584 .527 .757 r
.32711 .49827 .33278 .5135 .34244 .51459 .3369 .49699 Mtetra
.531 .472 .735 r
.3369 .49699 .34244 .51459 .35211 .51683 .34661 .49793 Mtetra
.486 .434 .724 r
.34661 .49793 .35211 .51683 .36185 .51877 .35628 .50076 Mtetra
.43 .407 .732 r
.35628 .50076 .36185 .51877 .37173 .51928 .36595 .5053 Mtetra
.38 .426 .784 r
.36595 .5053 .37173 .51928 .38182 .51634 .3757 .50988 Mtetra
.21 .527 .92 r
.3757 .50988 .38182 .51634 .39214 .50851 .38559 .51312 Mtetra
.275 0 0 r
.38559 .51312 .39214 .50851 .40261 .49712 .39571 .51226 Mtetra
.266 0 .169 r
.39571 .51226 .40261 .49712 .41314 .48318 .4061 .50549 Mtetra
.23 0 .241 r
.4061 .50549 .41314 .48318 .42361 .47085 .41667 .49376 Mtetra
.111 0 .196 r
.41667 .49376 .42361 .47085 .43394 .46256 .42735 .47798 Mtetra
0 0 0 r
.42735 .47798 .43394 .46256 .44417 .45862 .43798 .46246 Mtetra
.827 .988 .722 r
.43798 .46246 .44417 .45862 .45434 .45914 .44851 .44966 Mtetra
.766 .697 .785 r
.44851 .44966 .45434 .45914 .46454 .46151 .45894 .4406 Mtetra
.633 .513 .699 r
.45894 .4406 .46454 .46151 .47481 .46423 .46931 .43573 Mtetra
.586 .45 .662 r
.46931 .43573 .47481 .46423 .48517 .4661 .47967 .43321 Mtetra
.567 .424 .647 r
.47967 .43321 .48517 .4661 .49561 .46636 .49007 .43196 Mtetra
.567 .421 .642 r
.49007 .43196 .49561 .46636 .50613 .46529 .50052 .43062 Mtetra
.576 .427 .641 r
.50052 .43062 .50613 .46529 .5167 .46292 .51102 .4284 Mtetra
.589 .436 .642 r
.51102 .4284 .5167 .46292 .52732 .45952 .52158 .42495 Mtetra
.6 .444 .641 r
.52158 .42495 .52732 .45952 .53798 .4551 .53217 .42029 Mtetra
.608 .448 .64 r
.53217 .42029 .53798 .4551 .54867 .44937 .5428 .41473 Mtetra
.609 .45 .641 r
.5428 .41473 .54867 .44937 .55936 .4423 .55345 .40908 Mtetra
.599 .446 .646 r
.55345 .40908 .55936 .4423 .57005 .43359 .56414 .40469 Mtetra
.579 .445 .663 r
.56414 .40469 .57005 .43359 .58074 .424 .5749 .40268 Mtetra
.512 .438 .709 r
.5749 .40268 .58074 .424 .59143 .41474 .5858 .40491 Mtetra
.212 .414 .843 r
.5858 .40491 .59143 .41474 .60217 .40734 .59686 .41094 Mtetra
.681 .186 .063 r
.59686 .41094 .60217 .40734 .61304 .40444 .6081 .41978 Mtetra
.644 .274 .328 r
.6081 .41978 .61304 .40444 .62411 .40597 .61948 .42891 Mtetra
.577 .247 .372 r
.61948 .42891 .62411 .40597 .63539 .41164 .63086 .43397 Mtetra
.507 .181 .349 r
.63086 .43397 .63539 .41164 .64684 .41898 .64216 .434 Mtetra
.323 0 .205 r
.64216 .434 .64684 .41898 .6583 .42375 .65329 .42799 Mtetra
.523 .849 .559 r
.65329 .42799 .6583 .42375 .66971 .4249 .66427 .41777 Mtetra
.835 .785 .804 r
.66427 .41777 .66971 .4249 .68096 .42105 .67518 .40615 Mtetra
.751 .631 .727 r
.67518 .40615 .68096 .42105 .69206 .41365 .68609 .39454 Mtetra
.702 .571 .704 r
.68609 .39454 .69206 .41365 .7031 .40476 .69707 .38467 Mtetra
.674 .548 .704 r
.69707 .38467 .7031 .40476 .71413 .39554 .70817 .37672 Mtetra
.649 .543 .72 r
.70817 .37672 .71413 .39554 .72524 .38749 .71942 .37105 Mtetra
.63 .552 .749 r
.71942 .37105 .72524 .38749 .73645 .3807 .73082 .36713 Mtetra
.613 .578 .79 r
.73082 .36713 .73645 .3807 .74779 .37545 .74234 .36447 Mtetra
.597 .614 .839 r
.74234 .36447 .74779 .37545 .75925 .37136 .75398 .36255 Mtetra
.59 .662 .888 r
.75398 .36255 .75925 .37136 .77082 .36806 .76569 .36075 Mtetra
.584 .705 .926 r
.76569 .36075 .77082 .36806 .78247 .36526 .77745 .35887 Mtetra
.592 .743 .948 r
.77745 .35887 .78247 .36526 .79419 .36255 .78924 .35659 Mtetra
.603 .765 .957 r
.78924 .35659 .79419 .36255 .80597 .35985 .80106 .35395 Mtetra
.62 .775 .955 r
.80106 .35395 .80597 .35985 .81778 .35696 .8129 .35091 Mtetra
.633 .776 .949 r
.8129 .35091 .81778 .35696 .82964 .35392 .82477 .34757 Mtetra
.643 .77 .94 r
.82477 .34757 .82964 .35392 .84154 .35075 .83667 .34402 Mtetra
.649 .76 .93 r
.83667 .34402 .84154 .35075 .85348 .34743 .84861 .34035 Mtetra
.642 .748 .926 r
.21326 .53739 .21976 .54307 .2293 .53984 .22278 .53462 Mtetra
.642 .765 .938 r
.22278 .53462 .2293 .53984 .23889 .53649 .23233 .5318 Mtetra
.646 .787 .949 r
.23233 .5318 .23889 .53649 .24852 .53294 .24194 .52881 Mtetra
.655 .812 .959 r
.24194 .52881 .24852 .53294 .2582 .52912 .2516 .52554 Mtetra
.67 .838 .964 r
.2516 .52554 .2582 .52912 .26795 .52491 .26134 .52187 Mtetra
.69 .863 .964 r
.26134 .52187 .26795 .52491 .27775 .52035 .27114 .51767 Mtetra
.718 .881 .957 r
.27114 .51767 .27775 .52035 .2876 .5154 .28102 .51281 Mtetra
.741 .886 .946 r
.28102 .51281 .2876 .5154 .29749 .51037 .29097 .50738 Mtetra
.763 .872 .927 r
.29097 .50738 .29749 .51037 .30739 .50546 .30098 .50135 Mtetra
.762 .83 .905 r
.30098 .50135 .30739 .50546 .31727 .50126 .31101 .49523 Mtetra
.741 .764 .872 r
.31101 .49523 .31727 .50126 .32711 .49827 .32105 .48936 Mtetra
.692 .677 .831 r
.32105 .48936 .32711 .49827 .3369 .49699 .33104 .48458 Mtetra
.631 .588 .788 r
.33104 .48458 .3369 .49699 .34661 .49793 .34097 .48158 Mtetra
.567 .506 .747 r
.34097 .48158 .34661 .49793 .35628 .50076 .35081 .48094 Mtetra
.502 .437 .716 r
.35081 .48094 .35628 .50076 .36595 .5053 .36055 .48324 Mtetra
.455 .391 .697 r
.36055 .48324 .36595 .5053 .3757 .50988 .37026 .48784 Mtetra
.408 .361 .694 r
.37026 .48784 .3757 .50988 .38559 .51312 .37997 .49425 Mtetra
.416 .392 .724 r
.37997 .49425 .38559 .51312 .39571 .51226 .38983 .49948 Mtetra
.475 .505 .809 r
.38983 .49948 .39571 .51226 .4061 .50549 .3999 .50143 Mtetra
.615 .819 .979 r
.3999 .50143 .4061 .50549 .41667 .49376 .41021 .49857 Mtetra
.484 .845 .593 r
.41021 .49857 .41667 .49376 .42735 .47798 .42073 .49011 Mtetra
0 0 0 r
.42073 .49011 .42735 .47798 .43798 .46246 .43135 .47883 Mtetra
.055 0 .09 r
.43135 .47883 .43798 .46246 .44851 .44966 .44198 .46646 Mtetra
.126 0 .132 r
.44198 .46646 .44851 .44966 .45894 .4406 .45257 .45525 Mtetra
.172 0 .119 r
.45257 .45525 .45894 .4406 .46931 .43573 .46311 .44643 Mtetra
.142 0 .012 r
.46311 .44643 .46931 .43573 .47967 .43321 .47361 .43966 Mtetra
.047 0 0 r
.47361 .43966 .47967 .43321 .49007 .43196 .48412 .43473 Mtetra
0 0 0 r
.48412 .43473 .49007 .43196 .50052 .43062 .49464 .43072 Mtetra
.437 .874 .889 r
.49464 .43072 .50052 .43062 .51102 .4284 .5052 .42716 Mtetra
.536 .899 .969 r
.5052 .42716 .51102 .4284 .52158 .42495 .5158 .4237 Mtetra
.525 .895 .968 r
.5158 .4237 .52158 .42495 .53217 .42029 .52644 .42033 Mtetra
.359 .831 .868 r
.52644 .42033 .53217 .42029 .5428 .41473 .53713 .41742 Mtetra
.043 0 0 r
.53713 .41742 .5428 .41473 .55345 .40908 .54786 .41543 Mtetra
.383 0 0 r
.54786 .41543 .55345 .40908 .56414 .40469 .55867 .4153 Mtetra
.514 .102 .197 r
.55867 .4153 .56414 .40469 .5749 .40268 .56957 .41725 Mtetra
.574 .2 .294 r
.56957 .41725 .5749 .40268 .5858 .40491 .58059 .42165 Mtetra
.591 .23 .325 r
.58059 .42165 .5858 .40491 .59686 .41094 .59174 .42725 Mtetra
.574 .21 .313 r
.59174 .42725 .59686 .41094 .6081 .41978 .60296 .43176 Mtetra
.51 .111 .22 r
.60296 .43176 .6081 .41978 .61948 .42891 .61421 .43344 Mtetra
.022 0 0 r
.61421 .43344 .61948 .42891 .63086 .43397 .62536 .42943 Mtetra
.819 .861 .879 r
.62536 .42943 .63086 .43397 .64216 .434 .63639 .42051 Mtetra
.771 .655 .734 r
.63639 .42051 .64216 .434 .65329 .42799 .64729 .40821 Mtetra
.735 .585 .688 r
.64729 .40821 .65329 .42799 .66427 .41777 .65813 .39468 Mtetra
.699 .547 .677 r
.65813 .39468 .66427 .41777 .67518 .40615 .66903 .38296 Mtetra
.675 .532 .682 r
.66903 .38296 .67518 .40615 .68609 .39454 .68003 .37358 Mtetra
.65 .529 .702 r
.68003 .37358 .68609 .39454 .69707 .38467 .69119 .3672 Mtetra
.627 .541 .738 r
.69119 .3672 .69707 .38467 .70817 .37672 .70251 .36325 Mtetra
.6 .572 .794 r
.70251 .36325 .70817 .37672 .71942 .37105 .71398 .36113 Mtetra
.565 .621 .866 r
.71398 .36113 .71942 .37105 .73082 .36713 .72558 .36014 Mtetra
.527 .688 .941 r
.72558 .36014 .73082 .36713 .74234 .36447 .73727 .35941 Mtetra
.484 .744 .986 r
.73727 .35941 .74234 .36447 .75398 .36255 .74902 .3586 Mtetra
.48 .79 .999 r
.74902 .3586 .75398 .36255 .76569 .36075 .7608 .35718 Mtetra
.503 .819 1 r
.7608 .35718 .76569 .36075 .77745 .35887 .7726 .35517 Mtetra
.555 .838 .998 r
.7726 .35517 .77745 .35887 .78924 .35659 .7844 .35246 Mtetra
.599 .84 .99 r
.7844 .35246 .78924 .35659 .80106 .35395 .79621 .34922 Mtetra
.633 .829 .976 r
.79621 .34922 .80106 .35395 .8129 .35091 .80804 .34554 Mtetra
.653 .813 .96 r
.80804 .34554 .8129 .35091 .82477 .34757 .81989 .34157 Mtetra
.664 .793 .944 r
.81989 .34157 .82477 .34757 .83667 .34402 .83178 .33742 Mtetra
.667 .773 .929 r
.83178 .33742 .83667 .34402 .84861 .34035 .8437 .33321 Mtetra
.619 .742 .934 r
.20671 .53168 .21326 .53739 .22278 .53462 .2162 .52937 Mtetra
.612 .757 .948 r
.2162 .52937 .22278 .53462 .23233 .5318 .22573 .52711 Mtetra
.607 .779 .963 r
.22573 .52711 .23233 .5318 .24194 .52881 .2353 .5248 Mtetra
.605 .806 .977 r
.2353 .5248 .24194 .52881 .2516 .52554 .24492 .52235 Mtetra
.6 .839 .989 r
.24492 .52235 .2516 .52554 .26134 .52187 .2546 .51968 Mtetra
.601 .878 .992 r
.2546 .51968 .26134 .52187 .27114 .51767 .26435 .51655 Mtetra
.606 .915 .978 r
.26435 .51655 .27114 .51767 .28102 .51281 .27418 .51279 Mtetra
.615 .943 .945 r
.27418 .51279 .28102 .51281 .29097 .50738 .28411 .50818 Mtetra
.653 .966 .912 r
.28411 .50818 .29097 .50738 .30098 .50135 .29414 .50249 Mtetra
.702 .981 .895 r
.29414 .50249 .30098 .50135 .31101 .49523 .30426 .49582 Mtetra
.779 .984 .903 r
.30426 .49582 .31101 .49523 .32105 .48936 .31446 .48816 Mtetra
.818 .935 .907 r
.31446 .48816 .32105 .48936 .33104 .48458 .32469 .48016 Mtetra
.8 .823 .87 r
.32469 .48016 .33104 .48458 .34097 .48158 .33492 .4723 Mtetra
.73 .684 .806 r
.33492 .4723 .34097 .48158 .35081 .48094 .3451 .46556 Mtetra
.654 .566 .743 r
.3451 .46556 .35081 .48094 .36055 .48324 .35519 .46076 Mtetra
.591 .477 .692 r
.35519 .46076 .36055 .48324 .37026 .48784 .36519 .45847 Mtetra
.54 .414 .657 r
.36519 .45847 .37026 .48784 .37997 .49425 .37509 .45928 Mtetra
.498 .369 .635 r
.37509 .45928 .37997 .49425 .38983 .49948 .38491 .46342 Mtetra
.454 .335 .628 r
.38491 .46342 .38983 .49948 .3999 .50143 .39469 .4709 Mtetra
.406 .319 .644 r
.39469 .4709 .3999 .50143 .41021 .49857 .40452 .47983 Mtetra
.286 .311 .712 r
.40452 .47983 .41021 .49857 .42073 .49011 .41446 .48866 Mtetra
.499 0 0 r
.41446 .48866 .42073 .49011 .43135 .47883 .42462 .49439 Mtetra
.507 .143 .283 r
.42462 .49439 .43135 .47883 .44198 .46646 .435 .49529 Mtetra
.465 .165 .371 r
.435 .49529 .44198 .46646 .45257 .45525 .44555 .49183 Mtetra
.435 .157 .391 r
.44555 .49183 .45257 .45525 .46311 .44643 .45623 .48454 Mtetra
.422 .149 .392 r
.45623 .48454 .46311 .44643 .47361 .43966 .46694 .4758 Mtetra
.415 .139 .384 r
.46694 .4758 .47361 .43966 .48412 .43473 .47767 .4671 Mtetra
.418 .133 .371 r
.47767 .4671 .48412 .43473 .49464 .43072 .48838 .45959 Mtetra
.434 .138 .361 r
.48838 .45959 .49464 .43072 .5052 .42716 .4991 .45402 Mtetra
.46 .155 .36 r
.4991 .45402 .5052 .42716 .5158 .4237 .50983 .45056 Mtetra
.492 .183 .37 r
.50983 .45056 .5158 .4237 .52644 .42033 .52061 .44922 Mtetra
.521 .215 .388 r
.52061 .44922 .52644 .42033 .53713 .41742 .53144 .44983 Mtetra
.537 .237 .406 r
.53144 .44983 .53713 .41742 .54786 .41543 .54235 .45167 Mtetra
.538 .245 .418 r
.54235 .45167 .54786 .41543 .55867 .4153 .55334 .45355 Mtetra
.525 .237 .42 r
.55334 .45355 .55867 .4153 .56957 .41725 .5644 .45399 Mtetra
.484 .2 .406 r
.5644 .45399 .56957 .41725 .58059 .42165 .57546 .45057 Mtetra
.401 .11 .352 r
.57546 .45057 .58059 .42165 .59174 .42725 .58649 .44273 Mtetra
.063 0 .098 r
.58649 .44273 .59174 .42725 .60296 .43176 .59742 .42996 Mtetra
.933 .912 .774 r
.59742 .42996 .60296 .43176 .61421 .43344 .60825 .41401 Mtetra
.759 .6 .681 r
.60825 .41401 .61421 .43344 .62536 .42943 .61904 .39792 Mtetra
.688 .511 .642 r
.61904 .39792 .62536 .42943 .63639 .42051 .62983 .38326 Mtetra
.647 .47 .631 r
.62983 .38326 .63639 .42051 .64729 .40821 .64071 .37198 Mtetra
.623 .456 .636 r
.64071 .37198 .64729 .40821 .65813 .39468 .65171 .36408 Mtetra
.605 .458 .656 r
.65171 .36408 .65813 .39468 .66903 .38296 .66287 .35934 Mtetra
.585 .473 .693 r
.66287 .35934 .66903 .38296 .68003 .37358 .67419 .35717 Mtetra
.553 .508 .76 r
.67419 .35717 .68003 .37358 .69119 .3672 .68566 .35701 Mtetra
.49 .574 .868 r
.68566 .35701 .69119 .3672 .70251 .36325 .69727 .35801 Mtetra
.349 .663 .973 r
.69727 .35801 .70251 .36325 .71398 .36113 .70897 .35916 Mtetra
.122 .644 .883 r
.70897 .35916 .71398 .36113 .72558 .36014 .72073 .35998 Mtetra
.037 .607 .737 r
.72073 .35998 .72558 .36014 .73727 .35941 .73251 .35979 Mtetra
.083 .642 .718 r
.73251 .35979 .73727 .35941 .74902 .3586 .74429 .35859 Mtetra
.24 .756 .811 r
.74429 .35859 .74902 .3586 .7608 .35718 .75606 .35627 Mtetra
.415 .857 .917 r
.75606 .35627 .7608 .35718 .7726 .35517 .76783 .35308 Mtetra
.556 .899 .978 r
.76783 .35308 .7726 .35517 .7844 .35246 .77959 .34921 Mtetra
.634 .89 .986 r
.77959 .34921 .7844 .35246 .79621 .34922 .79136 .34487 Mtetra
.668 .86 .973 r
.79136 .34487 .79621 .34922 .80804 .34554 .80316 .34029 Mtetra
.683 .83 .954 r
.80316 .34029 .80804 .34554 .81989 .34157 .81498 .33555 Mtetra
.687 .803 .937 r
.81498 .33555 .81989 .34157 .83178 .33742 .82685 .33076 Mtetra
.685 .781 .923 r
.82685 .33076 .83178 .33742 .8437 .33321 .83876 .32602 Mtetra
.612 .74 .936 r
.20012 .52592 .20671 .53168 .2162 .52937 .20961 .52373 Mtetra
.604 .742 .942 r
.20961 .52373 .2162 .52937 .22573 .52711 .21914 .52165 Mtetra
.596 .748 .949 r
.21914 .52165 .22573 .52711 .2353 .5248 .2287 .51967 Mtetra
.588 .758 .96 r
.2287 .51967 .2353 .5248 .24492 .52235 .23829 .51775 Mtetra
.574 .775 .974 r
.23829 .51775 .24492 .52235 .2546 .51968 .24793 .5159 Mtetra
.563 .806 .99 r
.24793 .5159 .2546 .51968 .26435 .51655 .25761 .5139 Mtetra
.545 .846 .998 r
.25761 .5139 .26435 .51655 .27418 .51279 .26736 .51162 Mtetra
.523 .886 .977 r
.26736 .51162 .27418 .51279 .28411 .50818 .2772 .50871 Mtetra
.488 .9 .9 r
.2772 .50871 .28411 .50818 .29414 .50249 .28715 .50489 Mtetra
.439 .869 .766 r
.28715 .50489 .29414 .50249 .30426 .49582 .2972 .49989 Mtetra
.428 .836 .648 r
.2972 .49989 .30426 .49582 .31446 .48816 .30738 .49341 Mtetra
.436 .817 .575 r
.30738 .49341 .31446 .48816 .32469 .48016 .31766 .48565 Mtetra
.528 .865 .598 r
.31766 .48565 .32469 .48016 .33492 .4723 .32802 .47666 Mtetra
.664 .95 .708 r
.32802 .47666 .33492 .4723 .3451 .46556 .33841 .46718 Mtetra
.811 .997 .853 r
.33841 .46718 .3451 .46556 .35519 .46076 .3488 .45781 Mtetra
.818 .879 .889 r
.3488 .45781 .35519 .46076 .36519 .45847 .35913 .44963 Mtetra
.72 .693 .823 r
.35913 .44963 .36519 .45847 .37509 .45928 .36937 .44358 Mtetra
.609 .539 .751 r
.36937 .44358 .37509 .45928 .38491 .46342 .37947 .44102 Mtetra
.516 .43 .697 r
.37947 .44102 .38491 .46342 .39469 .4709 .38943 .44284 Mtetra
.466 .369 .661 r
.38943 .44284 .39469 .4709 .40452 .47983 .39933 .44798 Mtetra
.436 .335 .642 r
.39933 .44798 .40452 .47983 .41446 .48866 .40924 .45557 Mtetra
.451 .342 .64 r
.40924 .45557 .41446 .48866 .42462 .49439 .41928 .46258 Mtetra
.486 .371 .648 r
.41928 .46258 .42462 .49439 .435 .49529 .42949 .46714 Mtetra
.528 .413 .666 r
.42949 .46714 .435 .49529 .44555 .49183 .43987 .46869 Mtetra
.58 .47 .693 r
.43987 .46869 .44555 .49183 .45623 .48454 .4504 .46693 Mtetra
.622 .534 .733 r
.4504 .46693 .45623 .48454 .46694 .4758 .46102 .4633 Mtetra
.664 .613 .788 r
.46102 .4633 .46694 .4758 .47767 .4671 .47169 .45863 Mtetra
.689 .702 .857 r
.47169 .45863 .47767 .4671 .48838 .45959 .4824 .45391 Mtetra
.682 .786 .928 r
.4824 .45391 .48838 .45959 .4991 .45402 .49313 .44969 Mtetra
.641 .826 .972 r
.49313 .44969 .4991 .45402 .50983 .45056 .5039 .44621 Mtetra
.599 .813 .982 r
.5039 .44621 .50983 .45056 .52061 .44922 .51471 .44346 Mtetra
.592 .756 .956 r
.51471 .44346 .52061 .44922 .53144 .44983 .52557 .44123 Mtetra
.61 .672 .884 r
.52557 .44123 .53144 .44983 .54235 .45167 .53648 .43894 Mtetra
.632 .598 .797 r
.53648 .43894 .54235 .45167 .55334 .45355 .54743 .43562 Mtetra
.646 .547 .728 r
.54743 .43562 .55334 .45355 .5644 .45399 .55841 .4304 Mtetra
.666 .524 .682 r
.55841 .4304 .5644 .45399 .57546 .45057 .56937 .42183 Mtetra
.675 .51 .655 r
.56937 .42183 .57546 .45057 .58649 .44273 .58029 .41018 Mtetra
.681 .504 .64 r
.58029 .41018 .58649 .44273 .59742 .42996 .59115 .39603 Mtetra
.681 .5 .635 r
.59115 .39603 .59742 .42996 .60825 .41401 .60197 .38125 Mtetra
.667 .493 .641 r
.60197 .38125 .60825 .41401 .61904 .39792 .61282 .36892 Mtetra
.65 .492 .657 r
.61282 .36892 .61904 .39792 .62983 .38326 .62376 .35996 Mtetra
.617 .495 .691 r
.62376 .35996 .62983 .38326 .64071 .37198 .63486 .35544 Mtetra
.57 .516 .756 r
.63486 .35544 .64071 .37198 .65171 .36408 .64613 .35449 Mtetra
.469 .578 .882 r
.64613 .35449 .65171 .36408 .66287 .35934 .65756 .35574 Mtetra
.1 .574 .91 r
.65756 .35574 .66287 .35934 .67419 .35717 .66913 .35822 Mtetra
.33 0 0 r
.66913 .35822 .67419 .35717 .68566 .35701 .6808 .36083 Mtetra
.419 0 0 r
.6808 .36083 .68566 .35701 .69727 .35801 .69253 .36297 Mtetra
.385 0 0 r
.69253 .36297 .69727 .35801 .70897 .35916 .70429 .36385 Mtetra
.302 0 0 r
.70429 .36385 .70897 .35916 .72073 .35998 .71604 .36341 Mtetra
.126 0 0 r
.71604 .36341 .72073 .35998 .73251 .35979 .72778 .36146 Mtetra
0 0 0 r
.72778 .36146 .73251 .35979 .74429 .35859 .73949 .35829 Mtetra
.442 .878 .883 r
.73949 .35829 .74429 .35859 .75606 .35627 .75119 .35416 Mtetra
.618 .923 .973 r
.75119 .35416 .75606 .35627 .76783 .35308 .76288 .34938 Mtetra
.682 .889 .974 r
.76288 .34938 .76783 .35308 .77959 .34921 .7746 .34429 Mtetra
.702 .848 .953 r
.7746 .34429 .77959 .34921 .79136 .34487 .78634 .33904 Mtetra
.701 .815 .935 r
.78634 .33904 .79136 .34487 .80316 .34029 .79813 .33386 Mtetra
.699 .793 .923 r
.79813 .33386 .80316 .34029 .81498 .33555 .80996 .32873 Mtetra
.695 .779 .916 r
.80996 .32873 .81498 .33555 .82685 .33076 .82184 .32369 Mtetra
.689 .77 .913 r
.82184 .32369 .82685 .33076 .83876 .32602 .83378 .31877 Mtetra
.626 .744 .932 r
.19348 .52013 .20012 .52592 .20961 .52373 .20302 .51764 Mtetra
.619 .732 .927 r
.20302 .51764 .20961 .52373 .21914 .52165 .21259 .5153 Mtetra
.61 .721 .924 r
.21259 .5153 .21914 .52165 .2287 .51967 .22217 .51316 Mtetra
.598 .712 .924 r
.22217 .51316 .2287 .51967 .23829 .51775 .23178 .51129 Mtetra
.578 .708 .931 r
.23178 .51129 .23829 .51775 .24793 .5159 .2414 .50977 Mtetra
.558 .713 .944 r
.2414 .50977 .24793 .5159 .25761 .5139 .25104 .50852 Mtetra
.527 .731 .967 r
.25104 .50852 .25761 .5139 .26736 .51162 .26071 .50753 Mtetra
.489 .769 .994 r
.26071 .50753 .26736 .51162 .2772 .50871 .27043 .50652 Mtetra
.404 .805 .984 r
.27043 .50652 .2772 .50871 .28715 .50489 .28021 .50528 Mtetra
.245 .759 .819 r
.28021 .50528 .28715 .50489 .2972 .49989 .2901 .50336 Mtetra
0 0 0 r
.2901 .50336 .2972 .49989 .30738 .49341 .30009 .50038 Mtetra
.07 0 0 r
.30009 .50038 .30738 .49341 .31766 .48565 .31023 .49595 Mtetra
.105 0 0 r
.31023 .49595 .31766 .48565 .32802 .47666 .3205 .48966 Mtetra
.108 0 .027 r
.3205 .48966 .32802 .47666 .33841 .46718 .33091 .48159 Mtetra
.061 0 .034 r
.33091 .48159 .33841 .46718 .3488 .45781 .34142 .47171 Mtetra
0 0 0 r
.34142 .47171 .3488 .45781 .35913 .44963 .35198 .46089 Mtetra
.35198 .46089 .35913 .44963 .36937 .44358 .36255 .44971 Mtetra
.614 .893 .584 r
.36255 .44971 .36937 .44358 .37947 .44102 .37311 .43855 Mtetra
.866 .888 .849 r
.37311 .43855 .37947 .44102 .38943 .44284 .38364 .42789 Mtetra
.727 .61 .727 r
.38364 .42789 .38943 .44284 .39933 .44798 .39412 .41815 Mtetra
.642 .483 .652 r
.39412 .41815 .39933 .44798 .40924 .45557 .40455 .4099 Mtetra
.59 .415 .613 r
.40455 .4099 .40924 .45557 .41928 .46258 .41489 .40456 Mtetra
.557 .378 .595 r
.41489 .40456 .41928 .46258 .42949 .46714 .42514 .40281 Mtetra
.536 .358 .587 r
.42514 .40281 .42949 .46714 .43987 .46869 .43536 .40415 Mtetra
.519 .346 .585 r
.43536 .40415 .43987 .46869 .4504 .46693 .44559 .40796 Mtetra
.514 .346 .591 r
.44559 .40796 .4504 .46693 .46102 .4633 .45589 .41227 Mtetra
.517 .356 .602 r
.45589 .41227 .46102 .4633 .47169 .45863 .4663 .41581 Mtetra
.531 .378 .619 r
.4663 .41581 .47169 .45863 .4824 .45391 .47682 .4175 Mtetra
.557 .409 .636 r
.47682 .4175 .4824 .45391 .49313 .44969 .48745 .41666 Mtetra
.588 .439 .646 r
.48745 .41666 .49313 .44969 .5039 .44621 .49816 .41313 Mtetra
.615 .457 .645 r
.49816 .41313 .5039 .44621 .51471 .44346 .50892 .4069 Mtetra
.63 .459 .633 r
.50892 .4069 .51471 .44346 .52557 .44123 .51971 .39812 Mtetra
.63 .449 .618 r
.51971 .39812 .52557 .44123 .53648 .43894 .53051 .38747 Mtetra
.622 .433 .605 r
.53051 .38747 .53648 .43894 .54743 .43562 .5413 .376 Mtetra
.609 .416 .595 r
.5413 .376 .54743 .43562 .55841 .4304 .55208 .36502 Mtetra
.591 .399 .589 r
.55208 .36502 .55841 .4304 .56937 .42183 .56288 .35652 Mtetra
.575 .387 .589 r
.56288 .35652 .56937 .42183 .58029 .41018 .57374 .35112 Mtetra
.556 .378 .595 r
.57374 .35112 .58029 .41018 .59115 .39603 .5847 .34936 Mtetra
.536 .377 .613 r
.5847 .34936 .59115 .39603 .60197 .38125 .59578 .35056 Mtetra
.513 .396 .657 r
.59578 .35056 .60197 .38125 .61282 .36892 .60698 .35329 Mtetra
.441 .45 .773 r
.60698 .35329 .61282 .36892 .62376 .35996 .6183 .35698 Mtetra
0 .4 .762 r
.6183 .35698 .62376 .35996 .63486 .35544 .62974 .3612 Mtetra
.546 .053 .037 r
.62974 .3612 .63486 .35544 .64613 .35449 .64127 .36548 Mtetra
.555 .138 .205 r
.64127 .36548 .64613 .35449 .65756 .35574 .6529 .36941 Mtetra
.538 .147 .248 r
.6529 .36941 .65756 .35574 .66913 .35822 .66459 .3724 Mtetra
.499 .114 .242 r
.66459 .3724 .66913 .35822 .6808 .36083 .67628 .37356 Mtetra
.444 .049 .194 r
.67628 .37356 .6808 .36083 .69253 .36297 .68797 .37289 Mtetra
.344 0 .083 r
.68797 .37289 .69253 .36297 .70429 .36385 .69962 .37031 Mtetra
.154 0 0 r
.69962 .37031 .70429 .36385 .71604 .36341 .71125 .36623 Mtetra
0 0 0 r
.71125 .36623 .71604 .36341 .72778 .36146 .72285 .36104 Mtetra
.596 .948 .904 r
.72285 .36104 .72778 .36146 .73949 .35829 .73444 .35514 Mtetra
.721 .919 .96 r
.73444 .35514 .73949 .35829 .75119 .35416 .74605 .349 Mtetra
.736 .848 .933 r
.74605 .349 .75119 .35416 .76288 .34938 .75769 .34282 Mtetra
.724 .796 .908 r
.75769 .34282 .76288 .34938 .7746 .34429 .76938 .3369 Mtetra
.712 .766 .895 r
.76938 .3369 .7746 .34429 .78634 .33904 .78113 .33125 Mtetra
.699 .75 .891 r
.78113 .33125 .78634 .33904 .79813 .33386 .79294 .32596 Mtetra
.69 .744 .893 r
.79294 .32596 .79813 .33386 .80996 .32873 .80482 .32094 Mtetra
.684 .746 .898 r
.80482 .32094 .80996 .32873 .82184 .32369 .81676 .31613 Mtetra
.679 .752 .906 r
.81676 .31613 .82184 .32369 .83378 .31877 .82876 .31146 Mtetra
.656 .751 .92 r
.18679 .51429 .19348 .52013 .20302 .51764 .19642 .51112 Mtetra
.651 .728 .905 r
.19642 .51112 .20302 .51764 .21259 .5153 .20607 .50805 Mtetra
.642 .704 .891 r
.20607 .50805 .21259 .5153 .22217 .51316 .21574 .50519 Mtetra
.629 .679 .879 r
.21574 .50519 .22217 .51316 .23178 .51129 .22541 .50265 Mtetra
.611 .656 .869 r
.22541 .50265 .23178 .51129 .2414 .50977 .23509 .50056 Mtetra
.592 .634 .862 r
.23509 .50056 .2414 .50977 .25104 .50852 .24477 .49898 Mtetra
.568 .616 .861 r
.24477 .49898 .25104 .50852 .26071 .50753 .25444 .498 Mtetra
.547 .608 .866 r
.25444 .498 .26071 .50753 .27043 .50652 .26412 .49751 Mtetra
.521 .61 .882 r
.26412 .49751 .27043 .50652 .28021 .50528 .27383 .49746 Mtetra
.502 .637 .914 r
.27383 .49746 .28021 .50528 .2901 .50336 .28358 .4975 Mtetra
.473 .694 .964 r
.28358 .4975 .2901 .50336 .30009 .50038 .2934 .49735 Mtetra
.416 .783 .994 r
.2934 .49735 .30009 .50038 .31023 .49595 .30333 .49646 Mtetra
.252 .765 .813 r
.30333 .49646 .31023 .49595 .3205 .48966 .31339 .49434 Mtetra
0 0 0 r
.31339 .49434 .3205 .48966 .33091 .48159 .32359 .49062 Mtetra
.085 0 0 r
.32359 .49062 .33091 .48159 .34142 .47171 .33394 .4849 Mtetra
.146 0 .049 r
.33394 .4849 .34142 .47171 .35198 .46089 .34442 .47736 Mtetra
.159 0 .119 r
.34442 .47736 .35198 .46089 .36255 .44971 .35501 .46799 Mtetra
.129 0 .132 r
.35501 .46799 .36255 .44971 .37311 .43855 .36568 .45676 Mtetra
.054 0 .097 r
.36568 .45676 .37311 .43855 .38364 .42789 .37643 .44385 Mtetra
0 0 .013 r
.37643 .44385 .38364 .42789 .39412 .41815 .38717 .43053 Mtetra
0 0 0 r
.38717 .43053 .39412 .41815 .40455 .4099 .39786 .41787 Mtetra
.39786 .41787 .40455 .4099 .41489 .40456 .40844 .40788 Mtetra
.425 .841 .672 r
.40844 .40788 .41489 .40456 .42514 .40281 .41889 .4016 Mtetra
.512 .888 .969 r
.41889 .4016 .42514 .40281 .43536 .40415 .42928 .39847 Mtetra
.49 .712 .969 r
.42928 .39847 .43536 .40415 .44559 .40796 .43963 .39797 Mtetra
.509 .584 .865 r
.43963 .39797 .44559 .40796 .45589 .41227 .45003 .39835 Mtetra
.536 .525 .79 r
.45003 .39835 .45589 .41227 .4663 .41581 .46049 .39857 Mtetra
.563 .502 .745 r
.46049 .39857 .4663 .41581 .47682 .4175 .47103 .39788 Mtetra
.588 .497 .719 r
.47103 .39788 .47682 .4175 .48745 .41666 .48165 .39578 Mtetra
.61 .502 .706 r
.48165 .39578 .48745 .41666 .49816 .41313 .49234 .39221 Mtetra
.632 .516 .703 r
.49234 .39221 .49816 .41313 .50892 .4069 .50308 .38717 Mtetra
.656 .538 .708 r
.50308 .38717 .50892 .4069 .51971 .39812 .51386 .38071 Mtetra
.68 .569 .723 r
.51386 .38071 .51971 .39812 .53051 .38747 .52466 .37332 Mtetra
.704 .613 .753 r
.52466 .37332 .53051 .38747 .5413 .376 .53548 .36576 Mtetra
.719 .679 .81 r
.53548 .36576 .5413 .376 .55208 .36502 .54632 .35907 Mtetra
.672 .779 .93 r
.54632 .35907 .55208 .36502 .56288 .35652 .55721 .35503 Mtetra
.26 .75 .916 r
.55721 .35503 .56288 .35652 .57374 .35112 .56818 .35417 Mtetra
.45 0 0 r
.56818 .35417 .57374 .35112 .5847 .34936 .57928 .3571 Mtetra
.596 .143 .147 r
.57928 .3571 .5847 .34936 .59578 .35056 .59053 .36275 Mtetra
.605 .203 .254 r
.59053 .36275 .59578 .35056 .60698 .35329 .6019 .36911 Mtetra
.592 .217 .3 r
.6019 .36911 .60698 .35329 .6183 .35698 .61338 .37509 Mtetra
.563 .202 .315 r
.61338 .37509 .6183 .35698 .62974 .3612 .62492 .37938 Mtetra
.531 .173 .304 r
.62492 .37938 .62974 .3612 .64127 .36548 .6365 .38179 Mtetra
.492 .124 .268 r
.6365 .38179 .64127 .36548 .6529 .36941 .6481 .38236 Mtetra
.426 .033 .188 r
.6481 .38236 .6529 .36941 .66459 .3724 .6597 .38106 Mtetra
.274 0 .004 r
.6597 .38106 .66459 .3724 .67628 .37356 .67128 .37771 Mtetra
0 0 0 r
.67128 .37771 .67628 .37356 .68797 .37289 .68282 .37271 Mtetra
.614 .956 .896 r
.68282 .37271 .68797 .37289 .69962 .37031 .69433 .36643 Mtetra
.765 .898 .936 r
.69433 .36643 .69962 .37031 .71125 .36623 .70583 .35937 Mtetra
.759 .793 .881 r
.70583 .35937 .71125 .36623 .72285 .36104 .71734 .3521 Mtetra
.739 .731 .844 r
.71734 .3521 .72285 .36104 .73444 .35514 .72888 .3449 Mtetra
.718 .694 .826 r
.72888 .3449 .73444 .35514 .74605 .349 .74048 .33816 Mtetra
.703 .676 .821 r
.74048 .33816 .74605 .349 .75769 .34282 .75214 .33191 Mtetra
.689 .669 .826 r
.75214 .33191 .75769 .34282 .76938 .3369 .76388 .32628 Mtetra
.678 .671 .836 r
.76388 .32628 .76938 .3369 .78113 .33125 .77569 .32117 Mtetra
.669 .679 .85 r
.77569 .32117 .78113 .33125 .79294 .32596 .78759 .31652 Mtetra
.663 .692 .867 r
.78759 .31652 .79294 .32596 .80482 .32094 .79956 .3122 Mtetra
.658 .709 .885 r
.79956 .3122 .80482 .32094 .81676 .31613 .8116 .3081 Mtetra
.656 .73 .904 r
.8116 .3081 .81676 .31613 .82876 .31146 .82371 .3041 Mtetra
.688 .758 .905 r
.18006 .50842 .18679 .51429 .19642 .51112 .18979 .5044 Mtetra
.684 .731 .886 r
.18979 .5044 .19642 .51112 .20607 .50805 .19955 .50038 Mtetra
.675 .703 .868 r
.19955 .50038 .20607 .50805 .21574 .50519 .20933 .49648 Mtetra
.663 .674 .85 r
.20933 .49648 .21574 .50519 .22541 .50265 .21912 .49282 Mtetra
.648 .643 .832 r
.21912 .49282 .22541 .50265 .23509 .50056 .22891 .48951 Mtetra
.628 .612 .815 r
.22891 .48951 .23509 .50056 .24477 .49898 .2387 .4867 Mtetra
.606 .581 .799 r
.2387 .4867 .24477 .49898 .25444 .498 .24846 .48456 Mtetra
.583 .553 .786 r
.24846 .48456 .25444 .498 .26412 .49751 .25821 .48318 Mtetra
.558 .527 .777 r
.25821 .48318 .26412 .49751 .27383 .49746 .26794 .48267 Mtetra
.535 .509 .774 r
.26794 .48267 .27383 .49746 .28358 .4975 .27766 .48294 Mtetra
.51 .498 .779 r
.27766 .48294 .28358 .4975 .2934 .49735 .28739 .48396 Mtetra
.488 .504 .8 r
.28739 .48396 .2934 .49735 .30333 .49646 .29715 .48542 Mtetra
.458 .533 .846 r
.29715 .48542 .30333 .49646 .31339 .49434 .30697 .48705 Mtetra
.396 .609 .934 r
.30697 .48705 .31339 .49434 .32359 .49062 .31687 .48841 Mtetra
.139 .652 .896 r
.31687 .48841 .32359 .49062 .33394 .4849 .32688 .48908 Mtetra
.254 0 0 r
.32688 .48908 .33394 .4849 .34442 .47736 .33703 .48844 Mtetra
.35 0 .108 r
.33703 .48844 .34442 .47736 .35501 .46799 .34733 .48599 Mtetra
.38 .032 .244 r
.34733 .48599 .35501 .46799 .36568 .45676 .35777 .48186 Mtetra
.396 .084 .314 r
.35777 .48186 .36568 .45676 .37643 .44385 .36831 .47615 Mtetra
.424 .132 .362 r
.36831 .47615 .37643 .44385 .38717 .43053 .3789 .47 Mtetra
.448 .167 .394 r
.3789 .47 .38717 .43053 .39786 .41787 .38951 .46391 Mtetra
.455 .184 .412 r
.38951 .46391 .39786 .41787 .40844 .40788 .40016 .4572 Mtetra
.452 .185 .417 r
.40016 .4572 .40844 .40788 .41889 .4016 .41087 .44954 Mtetra
.434 .168 .41 r
.41087 .44954 .41889 .4016 .42928 .39847 .42164 .44031 Mtetra
.398 .129 .385 r
.42164 .44031 .42928 .39847 .43963 .39797 .43247 .42955 Mtetra
.34 .058 .331 r
.43247 .42955 .43963 .39797 .45003 .39835 .44329 .4185 Mtetra
.221 0 .204 r
.44329 .4185 .45003 .39835 .46049 .39857 .45409 .40804 Mtetra
0 0 0 r
.45409 .40804 .46049 .39857 .47103 .39788 .46486 .39934 Mtetra
.575 .94 .832 r
.46486 .39934 .47103 .39788 .48165 .39578 .47559 .39304 Mtetra
.609 .881 .991 r
.47559 .39304 .48165 .39578 .49234 .39221 .48632 .38945 Mtetra
.375 .779 .984 r
.48632 .38945 .49234 .39221 .50308 .38717 .49707 .38857 Mtetra
.286 0 0 r
.49707 .38857 .50308 .38717 .51386 .38071 .50786 .39012 Mtetra
.54 .107 .168 r
.50786 .39012 .51386 .38071 .52466 .37332 .51873 .39345 Mtetra
.558 .211 .336 r
.51873 .39345 .52466 .37332 .53548 .36576 .52969 .3974 Mtetra
.55 .242 .398 r
.52969 .3974 .53548 .36576 .54632 .35907 .54075 .40108 Mtetra
.535 .247 .424 r
.54075 .40108 .54632 .35907 .55721 .35503 .55189 .40324 Mtetra
.523 .245 .433 r
.55189 .40324 .55721 .35503 .56818 .35417 .56309 .40383 Mtetra
.517 .24 .434 r
.56309 .40383 .56818 .35417 .57928 .3571 .57436 .40348 Mtetra
.51 .231 .427 r
.57436 .40348 .57928 .3571 .59053 .36275 .58568 .4025 Mtetra
.506 .218 .411 r
.58568 .4025 .59053 .36275 .6019 .36911 .59707 .40159 Mtetra
.494 .193 .384 r
.59707 .40159 .6019 .36911 .61338 .37509 .60851 .40024 Mtetra
.456 .137 .336 r
.60851 .40024 .61338 .37509 .62492 .37938 .61997 .39728 Mtetra
.379 .032 .246 r
.61997 .39728 .62492 .37938 .6365 .38179 .63143 .3926 Mtetra
.181 0 .03 r
.63143 .3926 .6365 .38179 .6481 .38236 .64286 .38606 Mtetra
0 0 0 r
.64286 .38606 .6481 .38236 .6597 .38106 .65426 .37816 Mtetra
.811 .933 .912 r
.65426 .37816 .6597 .38106 .67128 .37771 .66565 .36953 Mtetra
.781 .76 .834 r
.66565 .36953 .67128 .37771 .68282 .37271 .67703 .3606 Mtetra
.739 .668 .781 r
.67703 .3606 .68282 .37271 .69433 .36643 .68844 .35183 Mtetra
.712 .622 .755 r
.68844 .35183 .69433 .36643 .70583 .35937 .69988 .34349 Mtetra
.691 .597 .746 r
.69988 .34349 .70583 .35937 .71734 .3521 .71138 .33592 Mtetra
.677 .587 .747 r
.71138 .33592 .71734 .3521 .72888 .3449 .72295 .32914 Mtetra
.664 .585 .756 r
.72295 .32914 .72888 .3449 .74048 .33816 .73461 .32326 Mtetra
.654 .59 .77 r
.73461 .32326 .74048 .33816 .75214 .33191 .74636 .31815 Mtetra
.646 .601 .789 r
.74636 .31815 .75214 .33191 .76388 .32628 .75821 .31373 Mtetra
.639 .617 .811 r
.75821 .31373 .76388 .32628 .77569 .32117 .77014 .30983 Mtetra
.635 .637 .836 r
.77014 .30983 .77569 .32117 .78759 .31652 .78215 .30629 Mtetra
.63 .659 .86 r
.78215 .30629 .78759 .31652 .79956 .3122 .79424 .30301 Mtetra
.627 .684 .884 r
.79424 .30301 .79956 .3122 .8116 .3081 .80639 .29985 Mtetra
.626 .711 .907 r
.80639 .29985 .8116 .3081 .82371 .3041 .81861 .29669 Mtetra
.706 .762 .895 r
.17328 .5025 .18006 .50842 .18979 .5044 .18309 .4979 Mtetra
.706 .744 .882 r
.18309 .4979 .18979 .5044 .19955 .50038 .19294 .49321 Mtetra
.702 .725 .868 r
.19294 .49321 .19955 .50038 .20933 .49648 .20282 .4885 Mtetra
.695 .702 .853 r
.20282 .4885 .20933 .49648 .21912 .49282 .21271 .48385 Mtetra
.685 .677 .836 r
.21271 .48385 .21912 .49282 .22891 .48951 .22263 .4793 Mtetra
.67 .646 .817 r
.22263 .4793 .22891 .48951 .2387 .4867 .23255 .47503 Mtetra
.652 .613 .798 r
.23255 .47503 .2387 .4867 .24846 .48456 .24246 .47118 Mtetra
.63 .578 .777 r
.24246 .47118 .24846 .48456 .25821 .48318 .25236 .46795 Mtetra
.605 .543 .758 r
.25236 .46795 .25821 .48318 .26794 .48267 .26223 .46552 Mtetra
.58 .509 .74 r
.26223 .46552 .26794 .48267 .27766 .48294 .27207 .46402 Mtetra
.555 .479 .724 r
.27207 .46402 .27766 .48294 .28739 .48396 .28188 .46358 Mtetra
.533 .455 .713 r
.28188 .46358 .28739 .48396 .29715 .48542 .29168 .46413 Mtetra
.513 .436 .706 r
.29168 .46413 .29715 .48542 .30697 .48705 .30147 .46567 Mtetra
.498 .426 .706 r
.30147 .46567 .30697 .48705 .31687 .48841 .31128 .46787 Mtetra
.485 .424 .714 r
.31128 .46787 .31687 .48841 .32688 .48908 .32114 .47048 Mtetra
.485 .441 .733 r
.32114 .47048 .32688 .48908 .33703 .48844 .33109 .47284 Mtetra
.493 .479 .77 r
.33109 .47284 .33703 .48844 .34733 .48599 .34116 .47448 Mtetra
.488 .543 .839 r
.34116 .47448 .34733 .48599 .35777 .48186 .35133 .47554 Mtetra
.434 .667 .96 r
.35133 .47554 .35777 .48186 .36831 .47615 .36159 .47597 Mtetra
.041 .61 .744 r
.36159 .47597 .36831 .47615 .3789 .47 .37195 .47581 Mtetra
.295 0 0 r
.37195 .47581 .3789 .47 .38951 .46391 .38241 .47484 Mtetra
.312 0 .079 r
.38241 .47484 .38951 .46391 .40016 .4572 .39301 .47167 Mtetra
.264 0 .132 r
.39301 .47167 .40016 .4572 .41087 .44954 .40376 .4657 Mtetra
.2 0 .132 r
.40376 .4657 .41087 .44954 .42164 .44031 .41461 .45728 Mtetra
.142 0 .119 r
.41461 .45728 .42164 .44031 .43247 .42955 .42554 .44695 Mtetra
.15 0 .13 r
.42554 .44695 .43247 .42955 .44329 .4185 .43646 .43645 Mtetra
.202 0 .163 r
.43646 .43645 .44329 .4185 .45409 .40804 .44736 .42685 Mtetra
.278 0 .209 r
.44736 .42685 .45409 .40804 .46486 .39934 .45823 .41892 Mtetra
.354 .018 .25 r
.45823 .41892 .46486 .39934 .47559 .39304 .46908 .41313 Mtetra
.414 .076 .28 r
.46908 .41313 .47559 .39304 .48632 .38945 .47992 .40954 Mtetra
.462 .12 .299 r
.47992 .40954 .48632 .38945 .49707 .38857 .49079 .40814 Mtetra
.503 .155 .309 r
.49079 .40814 .49707 .38857 .50786 .39012 .5017 .40891 Mtetra
.532 .177 .311 r
.5017 .40891 .50786 .39012 .51873 .39345 .51267 .41136 Mtetra
.547 .187 .307 r
.51267 .41136 .51873 .39345 .52969 .3974 .52373 .41475 Mtetra
.544 .18 .299 r
.52373 .41475 .52969 .3974 .54075 .40108 .53488 .418 Mtetra
.507 .14 .278 r
.53488 .418 .54075 .40108 .55189 .40324 .54612 .41933 Mtetra
.448 .079 .244 r
.54612 .41933 .55189 .40324 .56309 .40383 .5574 .4182 Mtetra
.352 0 .177 r
.5574 .4182 .56309 .40383 .57436 .40348 .56872 .41422 Mtetra
.18 0 .017 r
.56872 .41422 .57436 .40348 .58568 .4025 .58004 .40801 Mtetra
0 0 0 r
.58004 .40801 .58568 .4025 .59707 .40159 .59137 .40097 Mtetra
.737 .981 .913 r
.59137 .40097 .59707 .40159 .60851 .40024 .60271 .39331 Mtetra
.782 .79 .86 r
.60271 .39331 .60851 .40024 .61997 .39728 .61406 .38499 Mtetra
.739 .664 .776 r
.61406 .38499 .61997 .39728 .63143 .3926 .62539 .37606 Mtetra
.716 .603 .729 r
.62539 .37606 .63143 .3926 .64286 .38606 .63671 .36636 Mtetra
.699 .569 .705 r
.63671 .36636 .64286 .38606 .65426 .37816 .64803 .3564 Mtetra
.683 .547 .693 r
.64803 .3564 .65426 .37816 .66565 .36953 .65937 .34683 Mtetra
.671 .534 .689 r
.65937 .34683 .66565 .36953 .67703 .3606 .67074 .33792 Mtetra
.66 .528 .692 r
.67074 .33792 .67703 .3606 .68844 .35183 .68217 .33001 Mtetra
.651 .527 .7 r
.68217 .33001 .68844 .35183 .69988 .34349 .69367 .3231 Mtetra
.641 .531 .713 r
.69367 .3231 .69988 .34349 .71138 .33592 .70527 .31729 Mtetra
.634 .54 .731 r
.70527 .31729 .71138 .33592 .72295 .32914 .71696 .31243 Mtetra
.626 .554 .754 r
.71696 .31243 .72295 .32914 .73461 .32326 .72874 .3084 Mtetra
.62 .572 .779 r
.72874 .3084 .73461 .32326 .74636 .31815 .74062 .305 Mtetra
.615 .595 .807 r
.74062 .305 .74636 .31815 .75821 .31373 .75258 .30204 Mtetra
.61 .618 .835 r
.75258 .30204 .75821 .31373 .77014 .30983 .76462 .29938 Mtetra
.607 .644 .861 r
.76462 .29938 .77014 .30983 .78215 .30629 .77674 .29683 Mtetra
.605 .667 .883 r
.77674 .29683 .78215 .30629 .79424 .30301 .78892 .29433 Mtetra
.603 .689 .903 r
.78892 .29433 .79424 .30301 .80639 .29985 .80117 .29182 Mtetra
.604 .709 .919 r
.80117 .29182 .80639 .29985 .81861 .29669 .81347 .28921 Mtetra
.71 .762 .893 r
.16646 .49655 .17328 .5025 .18309 .4979 .1763 .4918 Mtetra
.714 .759 .888 r
.1763 .4918 .18309 .4979 .19294 .49321 .1862 .48689 Mtetra
.717 .754 .882 r
.1862 .48689 .19294 .49321 .20282 .4885 .19613 .48182 Mtetra
.718 .744 .872 r
.19613 .48182 .20282 .4885 .21271 .48385 .2061 .47659 Mtetra
.719 .729 .859 r
.2061 .47659 .21271 .48385 .22263 .4793 .21612 .47117 Mtetra
.714 .707 .842 r
.21612 .47117 .22263 .4793 .23255 .47503 .22617 .46569 Mtetra
.704 .677 .821 r
.22617 .46569 .23255 .47503 .24246 .47118 .23624 .4602 Mtetra
.688 .641 .798 r
.23624 .4602 .24246 .47118 .25236 .46795 .24631 .45492 Mtetra
.667 .602 .773 r
.24631 .45492 .25236 .46795 .26223 .46552 .25638 .45 Mtetra
.643 .561 .747 r
.25638 .45 .26223 .46552 .27207 .46402 .26644 .44569 Mtetra
.617 .521 .723 r
.26644 .44569 .27207 .46402 .28188 .46358 .27646 .44218 Mtetra
.593 .485 .701 r
.27646 .44218 .28188 .46358 .29168 .46413 .28645 .43959 Mtetra
.57 .454 .681 r
.28645 .43959 .29168 .46413 .30147 .46567 .29641 .43809 Mtetra
.552 .429 .665 r
.29641 .43809 .30147 .46567 .31128 .46787 .30635 .43755 Mtetra
.538 .409 .653 r
.30635 .43755 .31128 .46787 .32114 .47048 .31629 .43796 Mtetra
.527 .395 .644 r
.31629 .43796 .32114 .47048 .33109 .47284 .32624 .43918 Mtetra
.518 .386 .64 r
.32624 .43918 .33109 .47284 .34116 .47448 .33622 .4411 Mtetra
.508 .38 .641 r
.33622 .4411 .34116 .47448 .35133 .47554 .34623 .44368 Mtetra
.5 .38 .647 r
.34623 .44368 .35133 .47554 .36159 .47597 .3563 .44671 Mtetra
.51 .396 .66 r
.3563 .44671 .36159 .47597 .37195 .47581 .36649 .44894 Mtetra
.533 .422 .673 r
.36649 .44894 .37195 .47581 .38241 .47484 .37683 .44963 Mtetra
.561 .448 .682 r
.37683 .44963 .38241 .47484 .39301 .47167 .3873 .44865 Mtetra
.588 .477 .695 r
.3873 .44865 .39301 .47167 .40376 .4657 .39789 .44609 Mtetra
.594 .503 .721 r
.39789 .44609 .40376 .4657 .41461 .45728 .40853 .44355 Mtetra
.588 .562 .792 r
.40853 .44355 .41461 .45728 .42554 .44695 .41919 .44178 Mtetra
.494 .744 .984 r
.41919 .44178 .42554 .44695 .43646 .43645 .42989 .44085 Mtetra
.287 0 0 r
.42989 .44085 .43646 .43645 .44736 .42685 .44062 .44057 Mtetra
.439 .05 .202 r
.44062 .44057 .44736 .42685 .45823 .41892 .45143 .43977 Mtetra
.452 .112 .297 r
.45143 .43977 .45823 .41892 .46908 .41313 .46233 .43786 Mtetra
.436 .115 .321 r
.46233 .43786 .46908 .41313 .47992 .40954 .4733 .43427 Mtetra
.404 .086 .31 r
.4733 .43427 .47992 .40954 .49079 .40814 .48435 .42899 Mtetra
.349 .019 .258 r
.48435 .42899 .49079 .40814 .5017 .40891 .49543 .42258 Mtetra
.216 0 .098 r
.49543 .42258 .5017 .40891 .51267 .41136 .50655 .41565 Mtetra
0 0 0 r
.50655 .41565 .51267 .41136 .52373 .41475 .51768 .40936 Mtetra
.718 .819 .928 r
.51768 .40936 .52373 .41475 .53488 .418 .52884 .4039 Mtetra
.652 .595 .778 r
.52884 .4039 .53488 .418 .54612 .41933 .54004 .39921 Mtetra
.627 .523 .716 r
.54004 .39921 .54612 .41933 .5574 .4182 .55128 .39455 Mtetra
.637 .508 .689 r
.55128 .39455 .5574 .4182 .56872 .41422 .56254 .38828 Mtetra
.649 .504 .673 r
.56254 .38828 .56872 .41422 .58004 .40801 .5738 .38029 Mtetra
.658 .504 .663 r
.5738 .38029 .58004 .40801 .59137 .40097 .58505 .37072 Mtetra
.657 .495 .652 r
.58505 .37072 .59137 .40097 .60271 .39331 .59629 .36031 Mtetra
.645 .479 .643 r
.59629 .36031 .60271 .39331 .61406 .38499 .60753 .35034 Mtetra
.635 .468 .639 r
.60753 .35034 .61406 .38499 .62539 .37606 .6188 .34103 Mtetra
.628 .462 .638 r
.6188 .34103 .62539 .37606 .63671 .36636 .6301 .33241 Mtetra
.623 .461 .642 r
.6301 .33241 .63671 .36636 .64803 .3564 .64144 .32461 Mtetra
.619 .465 .65 r
.64144 .32461 .64803 .3564 .65937 .34683 .65284 .31775 Mtetra
.615 .471 .662 r
.65284 .31775 .65937 .34683 .67074 .33792 .6643 .31189 Mtetra
.61 .48 .679 r
.6643 .31189 .67074 .33792 .68217 .33001 .67586 .30714 Mtetra
.604 .493 .699 r
.67586 .30714 .68217 .33001 .69367 .3231 .68751 .30333 Mtetra
.598 .51 .726 r
.68751 .30333 .69367 .3231 .70527 .31729 .69925 .30036 Mtetra
.593 .533 .757 r
.69925 .30036 .70527 .31729 .71696 .31243 .71108 .298 Mtetra
.588 .561 .791 r
.71108 .298 .71696 .31243 .72874 .3084 .72301 .29603 Mtetra
.583 .592 .827 r
.72301 .29603 .72874 .3084 .74062 .305 .73501 .29428 Mtetra
.582 .625 .859 r
.73501 .29428 .74062 .305 .75258 .30204 .74708 .29253 Mtetra
.581 .654 .887 r
.74708 .29253 .75258 .30204 .76462 .29938 .75922 .29072 Mtetra
.584 .68 .906 r
.75922 .29072 .76462 .29938 .77674 .29683 .77141 .2887 Mtetra
.587 .698 .919 r
.77141 .2887 .77674 .29683 .78892 .29433 .78365 .28653 Mtetra
.591 .711 .927 r
.78365 .28653 .78892 .29433 .80117 .29182 .79595 .28419 Mtetra
.596 .72 .931 r
.79595 .28419 .80117 .29182 .81347 .28921 .8083 .28168 Mtetra
.693 .759 .903 r
.15958 .49055 .16646 .49655 .1763 .4918 .1694 .48629 Mtetra
.7 .778 .912 r
.1694 .48629 .1763 .4918 .1862 .48689 .17926 .48187 Mtetra
.709 .797 .919 r
.17926 .48187 .1862 .48689 .19613 .48182 .18918 .47722 Mtetra
.72 .813 .923 r
.18918 .47722 .19613 .48182 .2061 .47659 .19915 .47228 Mtetra
.733 .826 .922 r
.19915 .47228 .2061 .47659 .21612 .47117 .20919 .46696 Mtetra
.744 .831 .918 r
.20919 .46696 .21612 .47117 .22617 .46569 .21928 .46131 Mtetra
.753 .826 .909 r
.21928 .46131 .22617 .46569 .23624 .4602 .22943 .45531 Mtetra
.756 .81 .895 r
.22943 .45531 .23624 .4602 .24631 .45492 .23961 .4491 Mtetra
.752 .78 .876 r
.23961 .4491 .24631 .45492 .25638 .45 .24983 .44278 Mtetra
.737 .739 .852 r
.24983 .44278 .25638 .45 .26644 .44569 .26006 .43655 Mtetra
.715 .688 .823 r
.26006 .43655 .26644 .44569 .27646 .44218 .27028 .4306 Mtetra
.687 .634 .791 r
.27028 .4306 .27646 .44218 .28645 .43959 .28049 .42514 Mtetra
.656 .58 .758 r
.28049 .42514 .28645 .43959 .29641 .43809 .29068 .42035 Mtetra
.627 .533 .728 r
.29068 .42035 .29641 .43809 .30635 .43755 .30085 .41633 Mtetra
.601 .492 .702 r
.30085 .41633 .30635 .43755 .31629 .43796 .31099 .41319 Mtetra
.578 .458 .68 r
.31099 .41319 .31629 .43796 .32624 .43918 .3211 .4111 Mtetra
.557 .431 .663 r
.3211 .4111 .32624 .43918 .33622 .4411 .3312 .41014 Mtetra
.544 .412 .651 r
.3312 .41014 .33622 .4411 .34623 .44368 .3413 .41004 Mtetra
.535 .398 .641 r
.3413 .41004 .34623 .44368 .3563 .44671 .35143 .41055 Mtetra
.54 .395 .633 r
.35143 .41055 .3563 .44671 .36649 .44894 .36164 .41066 Mtetra
.549 .398 .628 r
.36164 .41066 .36649 .44894 .37683 .44963 .37196 .4099 Mtetra
.55 .395 .624 r
.37196 .4099 .37683 .44963 .3873 .44865 .38234 .40906 Mtetra
.546 .393 .625 r
.38234 .40906 .3873 .44865 .39789 .44609 .39276 .40859 Mtetra
.532 .388 .63 r
.39276 .40859 .39789 .44609 .40853 .44355 .4032 .40941 Mtetra
.512 .382 .64 r
.4032 .40941 .40853 .44355 .41919 .44178 .41366 .4117 Mtetra
.502 .389 .657 r
.41366 .4117 .41919 .44178 .42989 .44085 .42418 .41444 Mtetra
.502 .404 .677 r
.42418 .41444 .42989 .44085 .44062 .44057 .43479 .41685 Mtetra
.526 .435 .695 r
.43479 .41685 .44062 .44057 .45143 .43977 .44553 .41779 Mtetra
.565 .471 .706 r
.44553 .41779 .45143 .43977 .46233 .43786 .45638 .4166 Mtetra
.607 .502 .708 r
.45638 .4166 .46233 .43786 .4733 .43427 .46734 .41297 Mtetra
.643 .524 .703 r
.46734 .41297 .4733 .43427 .48435 .42899 .47837 .40689 Mtetra
.667 .533 .692 r
.47837 .40689 .48435 .42899 .49543 .42258 .48946 .39866 Mtetra
.675 .529 .679 r
.48946 .39866 .49543 .42258 .50655 .41565 .50057 .38893 Mtetra
.667 .512 .665 r
.50057 .38893 .50655 .41565 .51768 .40936 .51169 .37885 Mtetra
.65 .488 .651 r
.51169 .37885 .51768 .40936 .52884 .4039 .5228 .36919 Mtetra
.626 .46 .639 r
.5228 .36919 .52884 .4039 .54004 .39921 .53393 .36101 Mtetra
.607 .44 .63 r
.53393 .36101 .54004 .39921 .55128 .39455 .54507 .35412 Mtetra
.6 .431 .625 r
.54507 .35412 .55128 .39455 .56254 .38828 .55625 .34759 Mtetra
.601 .431 .624 r
.55625 .34759 .56254 .38828 .5738 .38029 .56745 .34097 Mtetra
.61 .44 .627 r
.56745 .34097 .5738 .38029 .58505 .37072 .57866 .33345 Mtetra
.617 .449 .632 r
.57866 .33345 .58505 .37072 .59629 .36031 .58988 .32551 Mtetra
.617 .454 .639 r
.58988 .32551 .59629 .36031 .60753 .35034 .60113 .31818 Mtetra
.614 .46 .649 r
.60113 .31818 .60753 .35034 .6188 .34103 .61242 .31172 Mtetra
.608 .465 .661 r
.61242 .31172 .6188 .34103 .6301 .33241 .62379 .30641 Mtetra
.603 .475 .678 r
.62379 .30641 .6301 .33241 .64144 .32461 .63522 .30215 Mtetra
.598 .49 .702 r
.63522 .30215 .64144 .32461 .65284 .31775 .64674 .29881 Mtetra
.592 .512 .733 r
.64674 .29881 .65284 .31775 .6643 .31189 .65834 .29626 Mtetra
.583 .541 .773 r
.65834 .29626 .6643 .31189 .67586 .30714 .67003 .2944 Mtetra
.572 .578 .82 r
.67003 .2944 .67586 .30714 .68751 .30333 .68182 .29305 Mtetra
.557 .62 .871 r
.68182 .29305 .68751 .30333 .69925 .30036 .69368 .29199 Mtetra
.539 .664 .918 r
.69368 .29199 .69925 .30036 .71108 .298 .70563 .29104 Mtetra
.526 .705 .953 r
.70563 .29104 .71108 .298 .72301 .29603 .71765 .28998 Mtetra
.518 .736 .973 r
.71765 .28998 .72301 .29603 .73501 .29428 .72972 .28871 Mtetra
.527 .76 .982 r
.72972 .28871 .73501 .29428 .74708 .29253 .74184 .28708 Mtetra
.542 .773 .983 r
.74184 .28708 .74708 .29253 .75922 .29072 .75401 .28511 Mtetra
.566 .779 .979 r
.75401 .28511 .75922 .29072 .77141 .2887 .76621 .28274 Mtetra
.586 .775 .97 r
.76621 .28274 .77141 .2887 .78365 .28653 .77846 .28008 Mtetra
.603 .765 .957 r
.77846 .28008 .78365 .28653 .79595 .28419 .79074 .27717 Mtetra
.614 .751 .943 r
.79074 .27717 .79595 .28419 .8083 .28168 .80308 .27409 Mtetra
.657 .752 .92 r
.15266 .48451 .15958 .49055 .1694 .48629 .1624 .48119 Mtetra
.66 .786 .941 r
.1624 .48119 .1694 .48629 .17926 .48187 .17218 .47775 Mtetra
.665 .824 .96 r
.17218 .47775 .17926 .48187 .18918 .47722 .18202 .47409 Mtetra
.67 .863 .973 r
.18202 .47409 .18918 .47722 .19915 .47228 .19193 .4701 Mtetra
.677 .899 .976 r
.19193 .4701 .19915 .47228 .20919 .46696 .20191 .46569 Mtetra
.683 .929 .969 r
.20191 .46569 .20919 .46696 .21928 .46131 .21197 .46081 Mtetra
.692 .952 .954 r
.21197 .46081 .21928 .46131 .22943 .45531 .22211 .45538 Mtetra
.702 .965 .938 r
.22211 .45538 .22943 .45531 .23961 .4491 .23231 .44943 Mtetra
.722 .973 .927 r
.23231 .44943 .23961 .4491 .24983 .44278 .24259 .44295 Mtetra
.747 .974 .925 r
.24259 .44295 .24983 .44278 .26006 .43655 .25292 .43608 Mtetra
.776 .962 .927 r
.25292 .43608 .26006 .43655 .27028 .4306 .26329 .4289 Mtetra
.793 .926 .924 r
.26329 .4289 .27028 .4306 .28049 .42514 .27368 .4216 Mtetra
.79 .863 .904 r
.27368 .4216 .28049 .42514 .29068 .42035 .28408 .41434 Mtetra
.765 .782 .867 r
.28408 .41434 .29068 .42035 .30085 .41633 .29448 .40734 Mtetra
.728 .699 .822 r
.29448 .40734 .30085 .41633 .31099 .41319 .30487 .40079 Mtetra
.689 .625 .779 r
.30487 .40079 .31099 .41319 .3211 .4111 .31524 .39489 Mtetra
.652 .562 .74 r
.31524 .39489 .3211 .4111 .3312 .41014 .32558 .38978 Mtetra
.629 .515 .706 r
.32558 .38978 .3312 .41014 .3413 .41004 .33592 .38503 Mtetra
.612 .48 .677 r
.33592 .38503 .3413 .41004 .35143 .41055 .34629 .38045 Mtetra
.597 .451 .654 r
.34629 .38045 .35143 .41055 .36164 .41066 .35668 .3762 Mtetra
.584 .43 .638 r
.35668 .3762 .36164 .41066 .37196 .4099 .36707 .37247 Mtetra
.564 .409 .629 r
.36707 .37247 .37196 .4099 .38234 .40906 .37743 .37032 Mtetra
.542 .391 .625 r
.37743 .37032 .38234 .40906 .39276 .40859 .38776 .37012 Mtetra
.529 .383 .626 r
.38776 .37012 .39276 .40859 .4032 .40941 .3981 .37104 Mtetra
.524 .379 .626 r
.3981 .37104 .4032 .40941 .41366 .4117 .4085 .37245 Mtetra
.533 .384 .625 r
.4085 .37245 .41366 .4117 .42418 .41444 .419 .37308 Mtetra
.547 .39 .62 r
.419 .37308 .42418 .41444 .43479 .41685 .42961 .37231 Mtetra
.557 .392 .614 r
.42961 .37231 .43479 .41685 .44553 .41779 .44031 .37037 Mtetra
.564 .393 .608 r
.44031 .37037 .44553 .41779 .45638 .4166 .45109 .36735 Mtetra
.568 .394 .605 r
.45109 .36735 .45638 .4166 .46734 .41297 .46193 .36365 Mtetra
.573 .398 .606 r
.46193 .36365 .46734 .41297 .47837 .40689 .47283 .35928 Mtetra
.583 .407 .609 r
.47283 .35928 .47837 .40689 .48946 .39866 .48377 .35381 Mtetra
.595 .419 .614 r
.48377 .35381 .48946 .39866 .50057 .38893 .49477 .34716 Mtetra
.61 .435 .62 r
.49477 .34716 .50057 .38893 .51169 .37885 .50579 .3391 Mtetra
.62 .445 .624 r
.50579 .3391 .51169 .37885 .5228 .36919 .51683 .33023 Mtetra
.618 .445 .626 r
.51683 .33023 .5228 .36919 .53393 .36101 .52788 .32184 Mtetra
.608 .438 .626 r
.52788 .32184 .53393 .36101 .54507 .35412 .53895 .31457 Mtetra
.59 .425 .626 r
.53895 .31457 .54507 .35412 .55625 .34759 .55005 .30926 Mtetra
.577 .418 .63 r
.55005 .30926 .55625 .34759 .56745 .34097 .56121 .30556 Mtetra
.575 .424 .639 r
.56121 .30556 .56745 .34097 .57866 .33345 .57242 .30238 Mtetra
.577 .437 .655 r
.57242 .30238 .57866 .33345 .58988 .32551 .58369 .29953 Mtetra
.581 .46 .679 r
.58369 .29953 .58988 .32551 .60113 .31818 .59501 .29686 Mtetra
.583 .487 .712 r
.59501 .29686 .60113 .31818 .61242 .31172 .6064 .29457 Mtetra
.573 .517 .754 r
.6064 .29457 .61242 .31172 .62379 .30641 .61788 .29308 Mtetra
.557 .558 .811 r
.61788 .29308 .62379 .30641 .63522 .30215 .62944 .29226 Mtetra
.527 .613 .882 r
.62944 .29226 .63522 .30215 .64674 .29881 .64109 .29192 Mtetra
.47 .677 .955 r
.64109 .29192 .64674 .29881 .65834 .29626 .65282 .29185 Mtetra
.372 .724 .989 r
.65282 .29185 .65834 .29626 .67003 .2944 .66464 .29184 Mtetra
.255 .722 .946 r
.66464 .29184 .67003 .2944 .68182 .29305 .67653 .29171 Mtetra
.175 .699 .87 r
.67653 .29171 .68182 .29305 .69368 .29199 .68849 .29128 Mtetra
.155 .693 .827 r
.68849 .29128 .69368 .29199 .70563 .29104 .7005 .29044 Mtetra
.197 .724 .836 r
.7005 .29044 .70563 .29104 .71765 .28998 .71255 .28906 Mtetra
.278 .776 .881 r
.71255 .28906 .71765 .28998 .72972 .28871 .72464 .28716 Mtetra
.385 .83 .939 r
.72464 .28716 .72972 .28871 .74184 .28708 .73676 .28468 Mtetra
.484 .862 .981 r
.73676 .28468 .74184 .28708 .75401 .28511 .74891 .28171 Mtetra
.563 .866 .996 r
.74891 .28171 .75401 .28511 .76621 .28274 .76108 .2783 Mtetra
.612 .848 .988 r
.76108 .2783 .76621 .28274 .77846 .28008 .77329 .27455 Mtetra
.64 .818 .968 r
.77329 .27455 .77846 .28008 .79074 .27717 .78554 .27056 Mtetra
.653 .784 .944 r
.78554 .27056 .79074 .27717 .80308 .27409 .79782 .26643 Mtetra
.607 .738 .938 r
.14569 .47843 .15266 .48451 .1624 .48119 .15533 .47616 Mtetra
.599 .775 .964 r
.15533 .47616 .1624 .48119 .17218 .47775 .16501 .47384 Mtetra
.589 .816 .986 r
.16501 .47384 .17218 .47775 .18202 .47409 .17475 .47137 Mtetra
.572 .856 .996 r
.17475 .47137 .18202 .47409 .19193 .4701 .18456 .46867 Mtetra
.542 .888 .984 r
.18456 .46867 .19193 .4701 .20191 .46569 .19444 .46564 Mtetra
.494 .896 .933 r
.19444 .46564 .20191 .46569 .21197 .46081 .2044 .46219 Mtetra
.431 .873 .841 r
.2044 .46219 .21197 .46081 .22211 .45538 .21444 .45821 Mtetra
.356 .817 .719 r
.21444 .45821 .22211 .45538 .23231 .44943 .22458 .45365 Mtetra
0 0 0 r
.22458 .45365 .23231 .44943 .24259 .44295 .2348 .44845 Mtetra
.2348 .44845 .24259 .44295 .25292 .43608 .2451 .44263 Mtetra
.2451 .44263 .25292 .43608 .26329 .4289 .25547 .43619 Mtetra
.25547 .43619 .26329 .4289 .27368 .4216 .26591 .42926 Mtetra
.26591 .42926 .27368 .4216 .28408 .41434 .27639 .42195 Mtetra
.27639 .42195 .28408 .41434 .29448 .40734 .2869 .41446 Mtetra
.2869 .41446 .29448 .40734 .30487 .40079 .29742 .40694 Mtetra
.29742 .40694 .30487 .40079 .31524 .39489 .30796 .39954 Mtetra
.43 .828 .618 r
.30796 .39954 .31524 .39489 .32558 .38978 .31849 .39236 Mtetra
.609 .95 .801 r
.31849 .39236 .32558 .38978 .33592 .38503 .32904 .3852 Mtetra
.743 .98 .916 r
.32904 .3852 .33592 .38503 .34629 .38045 .3396 .37804 Mtetra
.761 .914 .942 r
.3396 .37804 .34629 .38045 .35668 .3762 .35015 .37158 Mtetra
.725 .832 .931 r
.35015 .37158 .35668 .3762 .36707 .37247 .36065 .36623 Mtetra
.67 .765 .921 r
.36065 .36623 .36707 .37247 .37743 .37032 .37112 .36232 Mtetra
.615 .692 .898 r
.37112 .36232 .37743 .37032 .38776 .37012 .38157 .3598 Mtetra
.614 .634 .847 r
.38157 .3598 .38776 .37012 .3981 .37104 .39206 .35726 Mtetra
.624 .579 .783 r
.39206 .35726 .3981 .37104 .4085 .37245 .40263 .35398 Mtetra
.628 .531 .726 r
.40263 .35398 .4085 .37245 .419 .37308 .41328 .34962 Mtetra
.626 .498 .687 r
.41328 .34962 .419 .37308 .42961 .37231 .424 .3442 Mtetra
.613 .469 .663 r
.424 .3442 .42961 .37231 .44031 .37037 .43475 .33878 Mtetra
.599 .449 .649 r
.43475 .33878 .44031 .37037 .45109 .36735 .44552 .33391 Mtetra
.584 .433 .643 r
.44552 .33391 .45109 .36735 .46193 .36365 .4563 .33016 Mtetra
.571 .424 .643 r
.4563 .33016 .46193 .36365 .47283 .35928 .4671 .32755 Mtetra
.566 .426 .65 r
.4671 .32755 .47283 .35928 .48377 .35381 .47795 .32548 Mtetra
.569 .441 .665 r
.47795 .32548 .48377 .35381 .49477 .34716 .48885 .32342 Mtetra
.592 .476 .691 r
.48885 .32342 .49477 .34716 .50579 .3391 .49981 .3203 Mtetra
.622 .528 .727 r
.49981 .3203 .50579 .3391 .51683 .33023 .51083 .31609 Mtetra
.656 .595 .775 r
.51083 .31609 .51683 .33023 .52788 .32184 .52189 .31113 Mtetra
.677 .661 .827 r
.52189 .31113 .52788 .32184 .53895 .31457 .53298 .30614 Mtetra
.647 .703 .888 r
.53298 .30614 .53895 .31457 .55005 .30926 .54412 .30256 Mtetra
.581 .732 .946 r
.54412 .30256 .55005 .30926 .56121 .30556 .55533 .30045 Mtetra
.482 .749 .988 r
.55533 .30045 .56121 .30556 .57242 .30238 .5666 .29946 Mtetra
.3 .738 .967 r
.5666 .29946 .57242 .30238 .58369 .29953 .57796 .2992 Mtetra
.06 .624 .761 r
.57796 .2992 .58369 .29953 .59501 .29686 .58939 .29895 Mtetra
.153 0 0 r
.58939 .29895 .59501 .29686 .6064 .29457 .60089 .29872 Mtetra
.287 0 0 r
.60089 .29872 .6064 .29457 .61788 .29308 .61248 .29873 Mtetra
.347 0 0 r
.61248 .29873 .61788 .29308 .62944 .29226 .62415 .29888 Mtetra
.371 0 0 r
.62415 .29888 .62944 .29226 .64109 .29192 .63589 .29902 Mtetra
.372 0 0 r
.63589 .29902 .64109 .29192 .65282 .29185 .64771 .29897 Mtetra
.355 0 0 r
.64771 .29897 .65282 .29185 .66464 .29184 .65959 .29854 Mtetra
.32 0 0 r
.65959 .29854 .66464 .29184 .67653 .29171 .67153 .29762 Mtetra
.259 0 0 r
.67153 .29762 .67653 .29171 .68849 .29128 .68351 .29606 Mtetra
.169 0 0 r
.68351 .29606 .68849 .29128 .7005 .29044 .69552 .29387 Mtetra
.034 0 0 r
.69552 .29387 .7005 .29044 .71255 .28906 .70756 .29101 Mtetra
0 0 0 r
.70756 .29101 .71255 .28906 .72464 .28716 .71962 .28755 Mtetra
.346 .824 .809 r
.71962 .28755 .72464 .28716 .73676 .28468 .73171 .28354 Mtetra
.512 .905 .933 r
.73171 .28354 .73676 .28468 .74891 .28171 .74381 .27909 Mtetra
.616 .915 .979 r
.74381 .27909 .74891 .28171 .76108 .2783 .75594 .27428 Mtetra
.668 .886 .978 r
.75594 .27428 .76108 .2783 .77329 .27455 .7681 .26922 Mtetra
.689 .845 .958 r
.7681 .26922 .77329 .27455 .78554 .27056 .78029 .264 Mtetra
.694 .804 .933 r
.78029 .264 .78554 .27056 .79782 .26643 .79252 .25872 Mtetra
.556 .722 .951 r
.13868 .4723 .14569 .47843 .15533 .47616 .14823 .4709 Mtetra
.538 .749 .973 r
.14823 .4709 .15533 .47616 .16501 .47384 .15782 .46953 Mtetra
.515 .778 .992 r
.15782 .46953 .16501 .47384 .17475 .47137 .16747 .46814 Mtetra
.48 .806 1 r
.16747 .46814 .17475 .47137 .18456 .46867 .17717 .46665 Mtetra
.424 .822 .982 r
.17717 .46665 .18456 .46867 .19444 .46564 .18694 .46503 Mtetra
.34 .81 .914 r
.18694 .46503 .19444 .46564 .2044 .46219 .19678 .46317 Mtetra
.228 .748 .778 r
.19678 .46317 .2044 .46219 .21444 .45821 .20669 .46097 Mtetra
0 0 0 r
.20669 .46097 .21444 .45821 .22458 .45365 .21669 .45834 Mtetra
.21669 .45834 .22458 .45365 .2348 .44845 .22679 .45517 Mtetra
.079 0 0 r
.22679 .45517 .2348 .44845 .2451 .44263 .23697 .45143 Mtetra
.134 0 0 r
.23697 .45143 .2451 .44263 .25547 .43619 .24725 .44704 Mtetra
.175 0 0 r
.24725 .44704 .25547 .43619 .26591 .42926 .2576 .44205 Mtetra
.203 0 .044 r
.2576 .44205 .26591 .42926 .27639 .42195 .26804 .43647 Mtetra
.225 0 .092 r
.26804 .43647 .27639 .42195 .2869 .41446 .27853 .4304 Mtetra
.24 0 .126 r
.27853 .4304 .2869 .41446 .29742 .40694 .28908 .42393 Mtetra
.246 0 .146 r
.28908 .42393 .29742 .40694 .30796 .39954 .29968 .41707 Mtetra
.245 0 .154 r
.29968 .41707 .30796 .39954 .31849 .39236 .31032 .40989 Mtetra
.24 0 .152 r
.31032 .40989 .31849 .39236 .32904 .3852 .32099 .40255 Mtetra
.239 0 .15 r
.32099 .40255 .32904 .3852 .3396 .37804 .33167 .39521 Mtetra
.265 0 .162 r
.33167 .39521 .3396 .37804 .35015 .37158 .34233 .38859 Mtetra
.3 0 .177 r
.34233 .38859 .35015 .37158 .36065 .36623 .35296 .38293 Mtetra
.303 0 .175 r
.35296 .38293 .36065 .36623 .37112 .36232 .3636 .37745 Mtetra
.264 0 .131 r
.3636 .37745 .37112 .36232 .38157 .3598 .3743 .37162 Mtetra
.104 0 0 r
.3743 .37162 .38157 .3598 .39206 .35726 .38508 .36444 Mtetra
0 0 0 r
.38508 .36444 .39206 .35726 .40263 .35398 .39594 .35566 Mtetra
.772 .997 .84 r
.39594 .35566 .40263 .35398 .41328 .34962 .40683 .34629 Mtetra
.833 .888 .882 r
.40683 .34629 .41328 .34962 .424 .3442 .41772 .33705 Mtetra
.773 .768 .848 r
.41772 .33705 .424 .3442 .43475 .33878 .42858 .32912 Mtetra
.709 .691 .83 r
.42858 .32912 .43475 .33878 .44552 .33391 .4394 .32312 Mtetra
.647 .643 .832 r
.4394 .32312 .44552 .33391 .4563 .33016 .45019 .31935 Mtetra
.578 .611 .849 r
.45019 .31935 .4563 .33016 .4671 .32755 .46099 .31779 Mtetra
.492 .594 .884 r
.46099 .31779 .4671 .32755 .47795 .32548 .4718 .31819 Mtetra
.357 .6 .939 r
.4718 .31819 .47795 .32548 .48885 .32342 .48267 .31991 Mtetra
.109 .594 .909 r
.48267 .31991 .48885 .32342 .49981 .3203 .49363 .32179 Mtetra
.255 0 0 r
.49363 .32179 .49981 .3203 .51083 .31609 .50467 .32309 Mtetra
.358 0 0 r
.50467 .32309 .51083 .31609 .52189 .31113 .51579 .32279 Mtetra
.38 0 .12 r
.51579 .32279 .52189 .31113 .53298 .30614 .52699 .32113 Mtetra
.405 .023 .197 r
.52699 .32113 .53298 .30614 .54412 .30256 .53825 .31912 Mtetra
.423 .052 .227 r
.53825 .31912 .54412 .30256 .55533 .30045 .54957 .3173 Mtetra
.449 .078 .241 r
.54957 .3173 .55533 .30045 .5666 .29946 .56096 .31647 Mtetra
.466 .094 .249 r
.56096 .31647 .5666 .29946 .57796 .2992 .57243 .31636 Mtetra
.467 .096 .25 r
.57243 .31636 .57796 .2992 .58939 .29895 .58398 .31629 Mtetra
.464 .094 .251 r
.58398 .31629 .58939 .29895 .60089 .29872 .5956 .31605 Mtetra
.457 .087 .248 r
.5956 .31605 .60089 .29872 .61248 .29873 .60728 .3155 Mtetra
.445 .072 .236 r
.60728 .3155 .61248 .29873 .62415 .29888 .61903 .31456 Mtetra
.429 .048 .213 r
.61903 .31456 .62415 .29888 .63589 .29902 .63084 .31321 Mtetra
.404 .012 .179 r
.63084 .31321 .63589 .29902 .64771 .29897 .6427 .31136 Mtetra
.365 0 .126 r
.6427 .31136 .64771 .29897 .65959 .29854 .65461 .30891 Mtetra
.308 0 .05 r
.65461 .30891 .65959 .29854 .67153 .29762 .66654 .30584 Mtetra
.22 0 0 r
.66654 .30584 .67153 .29762 .68351 .29606 .67851 .30211 Mtetra
.09 0 0 r
.67851 .30211 .68351 .29606 .69552 .29387 .69049 .29777 Mtetra
0 0 0 r
.69049 .29777 .69552 .29387 .70756 .29101 .7025 .29288 Mtetra
.325 .794 .689 r
.7025 .29288 .70756 .29101 .71962 .28755 .71452 .28752 Mtetra
.525 .92 .87 r
.71452 .28752 .71962 .28755 .73171 .28354 .72656 .28181 Mtetra
.647 .949 .951 r
.72656 .28181 .73171 .28354 .74381 .27909 .73862 .27583 Mtetra
.702 .924 .966 r
.73862 .27583 .74381 .27909 .75594 .27428 .75071 .2697 Mtetra
.723 .884 .955 r
.75071 .2697 .75594 .27428 .7681 .26922 .76283 .26347 Mtetra
.727 .844 .936 r
.76283 .26347 .7681 .26922 .78029 .264 .77499 .2572 Mtetra
.724 .808 .917 r
.77499 .2572 .78029 .264 .79252 .25872 .78718 .25095 Mtetra
.538 .715 .954 r
.13161 .46613 .13868 .4723 .14823 .4709 .14114 .465 Mtetra
.527 .721 .962 r
.14114 .465 .14823 .4709 .15782 .46953 .15072 .46395 Mtetra
.514 .729 .971 r
.15072 .46395 .15782 .46953 .16747 .46814 .16033 .46297 Mtetra
.498 .74 .981 r
.16033 .46297 .16747 .46814 .17717 .46665 .16999 .46205 Mtetra
.474 .753 .991 r
.16999 .46205 .17717 .46665 .18694 .46503 .1797 .46119 Mtetra
.444 .77 .997 r
.1797 .46119 .18694 .46503 .19678 .46317 .18946 .4603 Mtetra
.399 .785 .99 r
.18946 .4603 .19678 .46317 .20669 .46097 .19928 .45932 Mtetra
.33 .786 .949 r
.19928 .45932 .20669 .46097 .21669 .45834 .20918 .45815 Mtetra
.232 .749 .848 r
.20918 .45815 .21669 .45834 .22679 .45517 .21915 .45671 Mtetra
0 0 0 r
.21915 .45671 .22679 .45517 .23697 .45143 .2292 .45489 Mtetra
.008 0 0 r
.2292 .45489 .23697 .45143 .24725 .44704 .23935 .45262 Mtetra
.106 0 0 r
.23935 .45262 .24725 .44704 .2576 .44205 .24958 .44986 Mtetra
.173 0 0 r
.24958 .44986 .2576 .44205 .26804 .43647 .2599 .44655 Mtetra
.222 0 0 r
.2599 .44655 .26804 .43647 .27853 .4304 .2703 .44271 Mtetra
.254 0 .058 r
.2703 .44271 .27853 .4304 .28908 .42393 .28078 .43834 Mtetra
.276 0 .114 r
.28078 .43834 .28908 .42393 .29968 .41707 .29133 .43344 Mtetra
.291 0 .155 r
.29133 .43344 .29968 .41707 .31032 .40989 .30195 .42804 Mtetra
.311 0 .191 r
.30195 .42804 .31032 .40989 .32099 .40255 .31262 .42245 Mtetra
.335 0 .223 r
.31262 .42245 .32099 .40255 .33167 .39521 .3233 .4169 Mtetra
.362 .025 .253 r
.3233 .4169 .33167 .39521 .34233 .38859 .334 .41166 Mtetra
.382 .05 .274 r
.334 .41166 .34233 .38859 .35296 .38293 .34471 .40676 Mtetra
.37 .044 .275 r
.34471 .40676 .35296 .38293 .3636 .37745 .35549 .40113 Mtetra
.34 .016 .262 r
.35549 .40113 .3636 .37745 .3743 .37162 .36637 .39429 Mtetra
.297 0 .235 r
.36637 .39429 .3743 .37162 .38508 .36444 .37732 .38621 Mtetra
.258 0 .211 r
.37732 .38621 .38508 .36444 .39594 .35566 .38832 .37713 Mtetra
.265 0 .212 r
.38832 .37713 .39594 .35566 .40683 .34629 .39932 .36837 Mtetra
.303 0 .235 r
.39932 .36837 .40683 .34629 .41772 .33705 .4103 .3606 Mtetra
.352 .028 .269 r
.4103 .3606 .41772 .33705 .42858 .32912 .42124 .35413 Mtetra
.396 .073 .297 r
.42124 .35413 .42858 .32912 .4394 .32312 .43217 .34912 Mtetra
.425 .104 .314 r
.43217 .34912 .4394 .32312 .45019 .31935 .44311 .34534 Mtetra
.448 .124 .322 r
.44311 .34534 .45019 .31935 .46099 .31779 .45405 .3428 Mtetra
.47 .14 .324 r
.45405 .3428 .46099 .31779 .4718 .31819 .46503 .34173 Mtetra
.489 .151 .32 r
.46503 .34173 .4718 .31819 .48267 .31991 .47605 .34197 Mtetra
.504 .158 .313 r
.47605 .34197 .48267 .31991 .49363 .32179 .48713 .34322 Mtetra
.509 .159 .309 r
.48713 .34322 .49363 .32179 .50467 .32309 .49828 .34481 Mtetra
.492 .144 .305 r
.49828 .34481 .50467 .32309 .51579 .32279 .50953 .34542 Mtetra
.472 .13 .305 r
.50953 .34542 .51579 .32279 .52699 .32113 .52086 .34478 Mtetra
.453 .117 .306 r
.52086 .34478 .52699 .32113 .53825 .31912 .53225 .34291 Mtetra
.44 .106 .302 r
.53225 .34291 .53825 .31912 .54957 .3173 .54371 .34032 Mtetra
.444 .106 .297 r
.54371 .34032 .54957 .3173 .56096 .31647 .55522 .33807 Mtetra
.444 .099 .285 r
.55522 .33807 .56096 .31647 .57243 .31636 .5668 .33615 Mtetra
.437 .083 .265 r
.5668 .33615 .57243 .31636 .58398 .31629 .57844 .33427 Mtetra
.423 .059 .239 r
.57844 .33427 .58398 .31629 .5956 .31605 .59014 .3322 Mtetra
.397 .021 .204 r
.59014 .3322 .5956 .31605 .60728 .3155 .60189 .32962 Mtetra
.361 0 .156 r
.60189 .32962 .60728 .3155 .61903 .31456 .61369 .3265 Mtetra
.31 0 .088 r
.61369 .3265 .61903 .31456 .63084 .31321 .62553 .32284 Mtetra
.233 0 0 r
.62553 .32284 .63084 .31321 .6427 .31136 .6374 .31862 Mtetra
.113 0 0 r
.6374 .31862 .6427 .31136 .65461 .30891 .6493 .31385 Mtetra
0 0 0 r
.6493 .31385 .65461 .30891 .66654 .30584 .66122 .30855 Mtetra
.66122 .30855 .66654 .30584 .67851 .30211 .67316 .30278 Mtetra
.514 .913 .828 r
.67316 .30278 .67851 .30211 .69049 .29777 .68513 .29661 Mtetra
.654 .96 .931 r
.68513 .29661 .69049 .29777 .7025 .29288 .69711 .29014 Mtetra
.718 .942 .957 r
.69711 .29014 .7025 .29288 .71452 .28752 .70911 .28346 Mtetra
.741 .904 .951 r
.70911 .28346 .71452 .28752 .72656 .28181 .72114 .27668 Mtetra
.746 .869 .937 r
.72114 .27668 .72656 .28181 .73862 .27583 .73319 .26986 Mtetra
.743 .84 .924 r
.73319 .26986 .73862 .27583 .75071 .2697 .74529 .26309 Mtetra
.739 .818 .913 r
.74529 .26309 .75071 .2697 .76283 .26347 .75742 .25636 Mtetra
.735 .802 .905 r
.75742 .25636 .76283 .26347 .77499 .2572 .76959 .2497 Mtetra
.73 .789 .9 r
.76959 .2497 .77499 .2572 .78718 .25095 .7818 .24311 Mtetra
.558 .722 .95 r
.12449 .45992 .13161 .46613 .14114 .465 .13408 .45845 Mtetra
.554 .71 .944 r
.13408 .45845 .14114 .465 .15072 .46395 .1437 .45709 Mtetra
.549 .698 .938 r
.1437 .45709 .15072 .46395 .16033 .46297 .15335 .45588 Mtetra
.541 .688 .935 r
.15335 .45588 .16033 .46297 .16999 .46205 .16304 .45483 Mtetra
.529 .68 .934 r
.16304 .45483 .16999 .46205 .1797 .46119 .17275 .454 Mtetra
.518 .677 .937 r
.17275 .454 .1797 .46119 .18946 .4603 .1825 .45333 Mtetra
.504 .68 .945 r
.1825 .45333 .18946 .4603 .19928 .45932 .19229 .45282 Mtetra
.489 .69 .957 r
.19229 .45282 .19928 .45932 .20918 .45815 .20212 .45238 Mtetra
.468 .71 .974 r
.20212 .45238 .20918 .45815 .21915 .45671 .21202 .45196 Mtetra
.439 .737 .99 r
.21202 .45196 .21915 .45671 .2292 .45489 .22197 .45147 Mtetra
.389 .764 .992 r
.22197 .45147 .2292 .45489 .23935 .45262 .232 .4508 Mtetra
.303 .768 .944 r
.232 .4508 .23935 .45262 .24958 .44986 .24211 .44989 Mtetra
.176 .711 .807 r
.24211 .44989 .24958 .44986 .2599 .44655 .2523 .44863 Mtetra
0 0 0 r
.2523 .44863 .2599 .44655 .2703 .44271 .26257 .44699 Mtetra
.095 0 0 r
.26257 .44699 .2703 .44271 .28078 .43834 .27293 .44492 Mtetra
.185 0 0 r
.27293 .44492 .28078 .43834 .29133 .43344 .28338 .44244 Mtetra
.248 0 0 r
.28338 .44244 .29133 .43344 .30195 .42804 .29389 .43957 Mtetra
.306 0 .065 r
.29389 .43957 .30195 .42804 .31262 .42245 .30446 .43659 Mtetra
.35 0 .145 r
.30446 .43659 .31262 .42245 .3233 .4169 .31508 .43363 Mtetra
.373 .001 .198 r
.31508 .43363 .3233 .4169 .334 .41166 .32575 .43044 Mtetra
.379 .021 .226 r
.32575 .43044 .334 .41166 .34471 .40676 .3365 .42682 Mtetra
.359 .011 .232 r
.3365 .42682 .34471 .40676 .35549 .40113 .34735 .42209 Mtetra
.333 0 .229 r
.34735 .42209 .35549 .40113 .36637 .39429 .3583 .41612 Mtetra
.337 .002 .24 r
.3583 .41612 .36637 .39429 .37732 .38621 .36929 .40995 Mtetra
.365 .036 .268 r
.36929 .40995 .37732 .38621 .38832 .37713 .38028 .40418 Mtetra
.411 .091 .31 r
.38028 .40418 .38832 .37713 .39932 .36837 .39126 .39961 Mtetra
.449 .138 .346 r
.39126 .39961 .39932 .36837 .4103 .3606 .40222 .3964 Mtetra
.464 .163 .369 r
.40222 .3964 .4103 .3606 .42124 .35413 .41322 .3936 Mtetra
.469 .174 .382 r
.41322 .3936 .42124 .35413 .43217 .34912 .42427 .39069 Mtetra
.463 .172 .386 r
.42427 .39069 .43217 .34912 .44311 .34534 .4354 .38692 Mtetra
.453 .164 .383 r
.4354 .38692 .44311 .34534 .45405 .3428 .44659 .3823 Mtetra
.448 .156 .375 r
.44659 .3823 .45405 .3428 .46503 .34173 .45783 .37757 Mtetra
.445 .146 .363 r
.45783 .37757 .46503 .34173 .47605 .34197 .46909 .37324 Mtetra
.453 .142 .347 r
.46909 .37324 .47605 .34197 .48713 .34322 .48039 .37028 Mtetra
.462 .136 .328 r
.48039 .37028 .48713 .34322 .49828 .34481 .49172 .36853 Mtetra
.46 .121 .305 r
.49172 .36853 .49828 .34481 .50953 .34542 .50311 .3672 Mtetra
.449 .103 .285 r
.50311 .3672 .50953 .34542 .52086 .34478 .51457 .36568 Mtetra
.42 .071 .266 r
.51457 .36568 .52086 .34478 .53225 .34291 .52609 .36289 Mtetra
.389 .039 .245 r
.52609 .36289 .53225 .34291 .54371 .34032 .53766 .35899 Mtetra
.368 .012 .222 r
.53766 .35899 .54371 .34032 .55522 .33807 .54928 .35464 Mtetra
.34 0 .183 r
.54928 .35464 .55522 .33807 .5668 .33615 .56095 .35005 Mtetra
.304 0 .122 r
.56095 .35005 .5668 .33615 .57844 .33427 .57266 .34549 Mtetra
.245 0 .034 r
.57266 .34549 .57844 .33427 .59014 .3322 .58441 .34081 Mtetra
.141 0 0 r
.58441 .34081 .59014 .3322 .60189 .32962 .5962 .33572 Mtetra
0 0 0 r
.5962 .33572 .60189 .32962 .61369 .3265 .60802 .3302 Mtetra
.60802 .3302 .61369 .3265 .62553 .32284 .61986 .32423 Mtetra
.486 .895 .784 r
.61986 .32423 .62553 .32284 .6374 .31862 .63173 .31786 Mtetra
.66 .965 .92 r
.63173 .31786 .6374 .31862 .6493 .31385 .64362 .31112 Mtetra
.737 .942 .951 r
.64362 .31112 .6493 .31385 .66122 .30855 .65552 .30412 Mtetra
.759 .891 .937 r
.65552 .30412 .66122 .30855 .67316 .30278 .66745 .29692 Mtetra
.76 .843 .914 r
.66745 .29692 .67316 .30278 .68513 .29661 .67941 .28964 Mtetra
.754 .807 .895 r
.67941 .28964 .68513 .29661 .69711 .29014 .69139 .28235 Mtetra
.746 .781 .881 r
.69139 .28235 .69711 .29014 .70911 .28346 .7034 .27513 Mtetra
.738 .764 .874 r
.7034 .27513 .70911 .28346 .72114 .27668 .71545 .26806 Mtetra
.732 .755 .871 r
.71545 .26806 .72114 .27668 .73319 .26986 .72754 .26115 Mtetra
.726 .752 .873 r
.72754 .26115 .73319 .26986 .74529 .26309 .73968 .25445 Mtetra
.722 .753 .877 r
.73968 .25445 .74529 .26309 .75742 .25636 .75186 .24791 Mtetra
.719 .758 .883 r
.75186 .24791 .75742 .25636 .76959 .2497 .76409 .24151 Mtetra
.717 .766 .891 r
.76409 .24151 .76959 .2497 .7818 .24311 .77637 .23521 Mtetra
.611 .739 .937 r
.11732 .45366 .12449 .45992 .13408 .45845 .12704 .45124 Mtetra
.609 .708 .915 r
.12704 .45124 .13408 .45845 .1437 .45709 .13679 .44891 Mtetra
.604 .678 .894 r
.13679 .44891 .1437 .45709 .15335 .45588 .14656 .44674 Mtetra
.596 .65 .875 r
.14656 .44674 .15335 .45588 .16304 .45483 .15635 .44478 Mtetra
.585 .625 .858 r
.15635 .44478 .16304 .45483 .17275 .454 .16616 .44309 Mtetra
.575 .602 .843 r
.16616 .44309 .17275 .454 .1825 .45333 .17599 .44167 Mtetra
.564 .583 .83 r
.17599 .44167 .1825 .45333 .19229 .45282 .18584 .44055 Mtetra
.556 .568 .821 r
.18584 .44055 .19229 .45282 .20212 .45238 .19572 .43967 Mtetra
.548 .557 .815 r
.19572 .43967 .20212 .45238 .21202 .45196 .20563 .43901 Mtetra
.544 .551 .812 r
.20563 .43901 .21202 .45196 .22197 .45147 .21558 .43849 Mtetra
.541 .549 .813 r
.21558 .43849 .22197 .45147 .232 .4508 .22558 .43805 Mtetra
.541 .554 .817 r
.22558 .43805 .232 .4508 .24211 .44989 .23564 .4376 Mtetra
.543 .564 .826 r
.23564 .4376 .24211 .44989 .2523 .44863 .24577 .43704 Mtetra
.547 .58 .839 r
.24577 .43704 .2523 .44863 .26257 .44699 .25597 .43631 Mtetra
.553 .603 .858 r
.25597 .43631 .26257 .44699 .27293 .44492 .26625 .43536 Mtetra
.558 .633 .882 r
.26625 .43536 .27293 .44492 .28338 .44244 .27661 .4342 Mtetra
.56 .671 .912 r
.27661 .4342 .28338 .44244 .29389 .43957 .28703 .43282 Mtetra
.55 .716 .949 r
.28703 .43282 .29389 .43957 .30446 .43659 .29752 .43135 Mtetra
.526 .762 .983 r
.29752 .43135 .30446 .43659 .31508 .43363 .30807 .42983 Mtetra
.52 .814 .999 r
.30807 .42983 .31508 .43363 .32575 .43044 .3187 .4278 Mtetra
.53 .859 .996 r
.3187 .4278 .32575 .43044 .3365 .42682 .32943 .42507 Mtetra
.55 .893 .982 r
.32943 .42507 .3365 .42682 .34735 .42209 .34025 .42158 Mtetra
.525 .908 .942 r
.34025 .42158 .34735 .42209 .3583 .41612 .35115 .41753 Mtetra
.283 .782 .764 r
.35115 .41753 .3583 .41612 .36929 .40995 .36205 .4142 Mtetra
.102 0 0 r
.36205 .4142 .36929 .40995 .38028 .40418 .37295 .41212 Mtetra
.339 0 0 r
.37295 .41212 .38028 .40418 .39126 .39961 .38384 .41127 Mtetra
.43 .007 .132 r
.38384 .41127 .39126 .39961 .40222 .3964 .39476 .4113 Mtetra
.438 .046 .197 r
.39476 .4113 .40222 .3964 .41322 .3936 .40577 .41082 Mtetra
.417 .044 .22 r
.40577 .41082 .41322 .3936 .42427 .39069 .41689 .40904 Mtetra
.371 .009 .214 r
.41689 .40904 .42427 .39069 .4354 .38692 .42813 .40527 Mtetra
.313 0 .189 r
.42813 .40527 .4354 .38692 .44659 .3823 .43948 .3995 Mtetra
.253 0 .147 r
.43948 .3995 .44659 .3823 .45783 .37757 .45088 .39242 Mtetra
.185 0 .078 r
.45088 .39242 .45783 .37757 .46909 .37324 .46232 .38481 Mtetra
.132 0 0 r
.46232 .38481 .46909 .37324 .48039 .37028 .47376 .37808 Mtetra
.048 0 0 r
.47376 .37808 .48039 .37028 .49172 .36853 .48522 .37257 Mtetra
0 0 0 r
.48522 .37257 .49172 .36853 .50311 .3672 .49671 .36834 Mtetra
.285 .783 .767 r
.49671 .36834 .50311 .3672 .51457 .36568 .50823 .36482 Mtetra
.505 .9 .939 r
.50823 .36482 .51457 .36568 .52609 .36289 .51981 .36073 Mtetra
.627 .92 .977 r
.51981 .36073 .52609 .36289 .53766 .35899 .53143 .35587 Mtetra
.692 .91 .971 r
.53143 .35587 .53766 .35899 .54928 .35464 .54309 .35029 Mtetra
.726 .876 .951 r
.54309 .35029 .54928 .35464 .56095 .35005 .55479 .34419 Mtetra
.73 .826 .925 r
.55479 .34419 .56095 .35005 .57266 .34549 .56651 .33802 Mtetra
.725 .775 .893 r
.56651 .33802 .57266 .34549 .58441 .34081 .57827 .33175 Mtetra
.72 .732 .86 r
.57827 .33175 .58441 .34081 .5962 .33572 .59006 .32525 Mtetra
.714 .698 .833 r
.59006 .32525 .5962 .33572 .60802 .3302 .60188 .31851 Mtetra
.709 .673 .813 r
.60188 .31851 .60802 .3302 .61986 .32423 .61372 .31154 Mtetra
.705 .655 .797 r
.61372 .31154 .61986 .32423 .63173 .31786 .62558 .30438 Mtetra
.701 .641 .786 r
.62558 .30438 .63173 .31786 .64362 .31112 .63746 .2971 Mtetra
.698 .632 .78 r
.63746 .2971 .64362 .31112 .65552 .30412 .64937 .28979 Mtetra
.694 .627 .777 r
.64937 .28979 .65552 .30412 .66745 .29692 .66132 .28255 Mtetra
.692 .625 .777 r
.66132 .28255 .66745 .29692 .67941 .28964 .67329 .27544 Mtetra
.689 .627 .781 r
.67329 .27544 .67941 .28964 .69139 .28235 .68531 .26855 Mtetra
.687 .632 .789 r
.68531 .26855 .69139 .28235 .7034 .27513 .69737 .2619 Mtetra
.685 .64 .799 r
.69737 .2619 .7034 .27513 .71545 .26806 .70949 .25554 Mtetra
.684 .652 .812 r
.70949 .25554 .71545 .26806 .72754 .26115 .72166 .24945 Mtetra
.683 .667 .828 r
.72166 .24945 .72754 .26115 .73968 .25445 .73388 .24365 Mtetra
.683 .686 .847 r
.73388 .24365 .73968 .25445 .75186 .24791 .74617 .23805 Mtetra
.685 .709 .867 r
.74617 .23805 .75186 .24791 .76409 .24151 .75851 .2326 Mtetra
.686 .736 .888 r
.75851 .2326 .76409 .24151 .77637 .23521 .7709 .22725 Mtetra
.667 .754 .915 r
.1101 .44736 .11732 .45366 .12704 .45124 .12 .44364 Mtetra
.661 .714 .888 r
.12 .44364 .12704 .45124 .13679 .44891 .12992 .43999 Mtetra
.652 .677 .862 r
.12992 .43999 .13679 .44891 .14656 .44674 .13986 .43647 Mtetra
.64 .643 .838 r
.13986 .43647 .14656 .44674 .15635 .44478 .14981 .43314 Mtetra
.627 .612 .816 r
.14981 .43314 .15635 .44478 .16616 .44309 .15978 .43008 Mtetra
.614 .583 .796 r
.15978 .43008 .16616 .44309 .17599 .44167 .16975 .4273 Mtetra
.6 .558 .778 r
.16975 .4273 .17599 .44167 .18584 .44055 .17973 .42486 Mtetra
.589 .536 .763 r
.17973 .42486 .18584 .44055 .19572 .43967 .18972 .42275 Mtetra
.578 .516 .749 r
.18972 .42275 .19572 .43967 .20563 .43901 .19972 .42096 Mtetra
.57 .501 .738 r
.19972 .42096 .20563 .43901 .21558 .43849 .20975 .41946 Mtetra
.563 .488 .729 r
.20975 .41946 .21558 .43849 .22558 .43805 .2198 .4182 Mtetra
.558 .479 .722 r
.2198 .4182 .22558 .43805 .23564 .4376 .2299 .4171 Mtetra
.555 .473 .717 r
.2299 .4171 .23564 .4376 .24577 .43704 .24004 .41611 Mtetra
.554 .469 .713 r
.24004 .41611 .24577 .43704 .25597 .43631 .25023 .41517 Mtetra
.553 .467 .712 r
.25023 .41517 .25597 .43631 .26625 .43536 .26048 .41423 Mtetra
.554 .468 .713 r
.26048 .41423 .26625 .43536 .27661 .4342 .27078 .41328 Mtetra
.555 .471 .715 r
.27078 .41328 .27661 .4342 .28703 .43282 .28115 .41228 Mtetra
.557 .475 .719 r
.28115 .41228 .28703 .43282 .29752 .43135 .29159 .41119 Mtetra
.561 .481 .722 r
.29159 .41119 .29752 .43135 .30807 .42983 .30209 .40993 Mtetra
.572 .49 .724 r
.30209 .40993 .30807 .42983 .3187 .4278 .31269 .40815 Mtetra
.584 .5 .726 r
.31269 .40815 .3187 .4278 .32943 .42507 .32338 .40576 Mtetra
.586 .505 .73 r
.32338 .40576 .32943 .42507 .34025 .42158 .33413 .40332 Mtetra
.581 .511 .742 r
.33413 .40332 .34025 .42158 .35115 .41753 .3449 .40123 Mtetra
.553 .516 .769 r
.3449 .40123 .35115 .41753 .36205 .4142 .35567 .40039 Mtetra
.501 .523 .811 r
.35567 .40039 .36205 .4142 .37295 .41212 .36642 .40104 Mtetra
.452 .551 .866 r
.36642 .40104 .37295 .41212 .38384 .41127 .37723 .40233 Mtetra
.416 .59 .914 r
.37723 .40233 .38384 .41127 .39476 .4113 .38811 .40361 Mtetra
.463 .654 .943 r
.38811 .40361 .39476 .4113 .40577 .41082 .39911 .40372 Mtetra
.557 .717 .947 r
.39911 .40372 .40577 .41082 .41689 .40904 .41025 .40202 Mtetra
.651 .756 .926 r
.41025 .40202 .41689 .40904 .42813 .40527 .42153 .39822 Mtetra
.72 .776 .896 r
.42153 .39822 .42813 .40527 .43948 .3995 .4329 .39232 Mtetra
.764 .782 .868 r
.4329 .39232 .43948 .3995 .45088 .39242 .44436 .38458 Mtetra
.782 .769 .841 r
.44436 .38458 .45088 .39242 .46232 .38481 .45586 .37566 Mtetra
.769 .736 .822 r
.45586 .37566 .46232 .38481 .47376 .37808 .46738 .3667 Mtetra
.737 .683 .799 r
.46738 .3667 .47376 .37808 .48522 .37257 .4789 .35838 Mtetra
.689 .62 .774 r
.4789 .35838 .48522 .37257 .49671 .36834 .49041 .35155 Mtetra
.652 .571 .751 r
.49041 .35155 .49671 .36834 .50823 .36482 .50195 .34597 Mtetra
.636 .543 .733 r
.50195 .34597 .50823 .36482 .51981 .36073 .51352 .34074 Mtetra
.632 .532 .723 r
.51352 .34074 .51981 .36073 .53143 .35587 .52513 .33545 Mtetra
.64 .533 .718 r
.52513 .33545 .53143 .35587 .54309 .35029 .53678 .32953 Mtetra
.646 .535 .714 r
.53678 .32953 .54309 .35029 .55479 .34419 .54846 .32307 Mtetra
.647 .533 .711 r
.54846 .32307 .55479 .34419 .56651 .33802 .56016 .31644 Mtetra
.646 .53 .707 r
.56016 .31644 .56651 .33802 .57827 .33175 .5719 .3097 Mtetra
.645 .526 .704 r
.5719 .3097 .57827 .33175 .59006 .32525 .58367 .3029 Mtetra
.644 .524 .702 r
.58367 .3029 .59006 .32525 .60188 .31851 .59546 .29608 Mtetra
.644 .523 .701 r
.59546 .29608 .60188 .31851 .61372 .31154 .60729 .28924 Mtetra
.644 .524 .703 r
.60729 .28924 .61372 .31154 .62558 .30438 .61915 .28244 Mtetra
.644 .527 .706 r
.61915 .28244 .62558 .30438 .63746 .2971 .63104 .27574 Mtetra
.644 .531 .711 r
.63104 .27574 .63746 .2971 .64937 .28979 .64297 .2692 Mtetra
.643 .536 .718 r
.64297 .2692 .64937 .28979 .66132 .28255 .65494 .2629 Mtetra
.643 .544 .727 r
.65494 .2629 .66132 .28255 .67329 .27544 .66696 .25688 Mtetra
.643 .553 .738 r
.66696 .25688 .67329 .27544 .68531 .26855 .67904 .2512 Mtetra
.642 .565 .753 r
.67904 .2512 .68531 .26855 .69737 .2619 .69117 .24584 Mtetra
.642 .58 .769 r
.69117 .24584 .69737 .2619 .70949 .25554 .70338 .24082 Mtetra
.642 .597 .789 r
.70338 .24082 .70949 .25554 .72166 .24945 .71564 .2361 Mtetra
.642 .619 .811 r
.71564 .2361 .72166 .24945 .73388 .24365 .72798 .23166 Mtetra
.643 .644 .836 r
.72798 .23166 .73388 .24365 .74617 .23805 .74038 .2274 Mtetra
.644 .674 .864 r
.74038 .2274 .74617 .23805 .75851 .2326 .75285 .22328 Mtetra
.644 .708 .893 r
.75285 .22328 .75851 .2326 .7709 .22725 .76539 .21923 Mtetra
.71 .762 .893 r
.10283 .44102 .1101 .44736 .12 .44364 .1129 .43602 Mtetra
.702 .725 .868 r
.1129 .43602 .12 .44364 .12992 .43999 .123 .43104 Mtetra
.691 .69 .845 r
.123 .43104 .12992 .43999 .13986 .43647 .13312 .42615 Mtetra
.678 .658 .823 r
.13312 .42615 .13986 .43647 .14981 .43314 .14325 .42139 Mtetra
.664 .627 .802 r
.14325 .42139 .14981 .43314 .15978 .43008 .15339 .41682 Mtetra
.65 .598 .783 r
.15339 .41682 .15978 .43008 .16975 .4273 .16353 .4125 Mtetra
.636 .571 .765 r
.16353 .4125 .16975 .4273 .17973 .42486 .17368 .40848 Mtetra
.622 .547 .748 r
.17368 .40848 .17973 .42486 .18972 .42275 .18382 .40475 Mtetra
.61 .524 .733 r
.18382 .40475 .18972 .42275 .19972 .42096 .19397 .40137 Mtetra
.599 .505 .719 r
.19397 .40137 .19972 .42096 .20975 .41946 .20413 .39829 Mtetra
.589 .488 .707 r
.20413 .39829 .20975 .41946 .2198 .4182 .2143 .39552 Mtetra
.581 .473 .696 r
.2143 .39552 .2198 .4182 .2299 .4171 .2245 .39299 Mtetra
.575 .461 .687 r
.2245 .39299 .2299 .4171 .24004 .41611 .23472 .39068 Mtetra
.57 .451 .679 r
.23472 .39068 .24004 .41611 .25023 .41517 .24497 .38853 Mtetra
.566 .444 .672 r
.24497 .38853 .25023 .41517 .26048 .41423 .25527 .38651 Mtetra
.563 .437 .667 r
.25527 .38651 .26048 .41423 .27078 .41328 .2656 .38456 Mtetra
.562 .433 .662 r
.2656 .38456 .27078 .41328 .28115 .41228 .27599 .38264 Mtetra
.562 .429 .658 r
.27599 .38264 .28115 .41228 .29159 .41119 .28644 .38062 Mtetra
.563 .427 .654 r
.28644 .38062 .29159 .41119 .30209 .40993 .29696 .37841 Mtetra
.567 .427 .65 r
.29696 .37841 .30209 .40993 .31269 .40815 .30754 .37587 Mtetra
.57 .427 .647 r
.30754 .37587 .31269 .40815 .32338 .40576 .3182 .37301 Mtetra
.564 .422 .646 r
.3182 .37301 .32338 .40576 .33413 .40332 .32889 .37051 Mtetra
.555 .415 .646 r
.32889 .37051 .33413 .40332 .3449 .40123 .33958 .36876 Mtetra
.542 .407 .647 r
.33958 .36876 .3449 .40123 .35567 .40039 .35028 .36799 Mtetra
.529 .399 .648 r
.35028 .36799 .35567 .40039 .36642 .40104 .36099 .36814 Mtetra
.531 .399 .646 r
.36099 .36814 .36642 .40104 .37723 .40233 .37178 .36818 Mtetra
.539 .401 .642 r
.37178 .36818 .37723 .40233 .38811 .40361 .38267 .36754 Mtetra
.551 .404 .635 r
.38267 .36754 .38811 .40361 .39911 .40372 .39367 .36588 Mtetra
.563 .409 .63 r
.39367 .36588 .39911 .40372 .41025 .40202 .40477 .36301 Mtetra
.572 .412 .627 r
.40477 .36301 .41025 .40202 .42153 .39822 .41596 .35915 Mtetra
.581 .419 .627 r
.41596 .35915 .42153 .39822 .4329 .39232 .42723 .3543 Mtetra
.595 .431 .63 r
.42723 .3543 .4329 .39232 .44436 .38458 .43857 .34824 Mtetra
.607 .444 .634 r
.43857 .34824 .44436 .38458 .45586 .37566 .44997 .34113 Mtetra
.618 .455 .64 r
.44997 .34113 .45586 .37566 .46738 .3667 .4614 .33334 Mtetra
.622 .461 .644 r
.4614 .33334 .46738 .3667 .4789 .35838 .47286 .32541 Mtetra
.614 .457 .646 r
.47286 .32541 .4789 .35838 .49041 .35155 .48432 .3184 Mtetra
.603 .449 .646 r
.48432 .3184 .49041 .35155 .50195 .34597 .4958 .31238 Mtetra
.594 .442 .645 r
.4958 .31238 .50195 .34597 .51352 .34074 .50731 .3071 Mtetra
.59 .439 .645 r
.50731 .3071 .51352 .34074 .52513 .33545 .51886 .30219 Mtetra
.594 .443 .646 r
.51886 .30219 .52513 .33545 .53678 .32953 .53044 .29695 Mtetra
.599 .448 .649 r
.53044 .29695 .53678 .32953 .54846 .32307 .54207 .29136 Mtetra
.603 .454 .652 r
.54207 .29136 .54846 .32307 .56016 .31644 .55374 .28557 Mtetra
.606 .459 .656 r
.55374 .28557 .56016 .31644 .5719 .3097 .56543 .27968 Mtetra
.607 .463 .66 r
.56543 .27968 .5719 .3097 .58367 .3029 .57717 .27381 Mtetra
.609 .467 .664 r
.57717 .27381 .58367 .3029 .59546 .29608 .58894 .268 Mtetra
.61 .472 .669 r
.58894 .268 .59546 .29608 .60729 .28924 .60076 .26231 Mtetra
.611 .478 .676 r
.60076 .26231 .60729 .28924 .61915 .28244 .61262 .25678 Mtetra
.611 .485 .684 r
.61262 .25678 .61915 .28244 .63104 .27574 .62452 .25147 Mtetra
.612 .493 .693 r
.62452 .25147 .63104 .27574 .64297 .2692 .63648 .2464 Mtetra
.612 .502 .704 r
.63648 .2464 .64297 .2692 .65494 .2629 .64849 .24165 Mtetra
.611 .512 .717 r
.64849 .24165 .65494 .2629 .66696 .25688 .66057 .23721 Mtetra
.61 .525 .733 r
.66057 .23721 .66696 .25688 .67904 .2512 .67272 .23311 Mtetra
.61 .539 .75 r
.67272 .23311 .67904 .2512 .69117 .24584 .68494 .22933 Mtetra
.608 .556 .771 r
.68494 .22933 .69117 .24584 .70338 .24082 .69723 .22585 Mtetra
.607 .576 .793 r
.69723 .22585 .70338 .24082 .71564 .2361 .7096 .22262 Mtetra
.606 .599 .818 r
.7096 .22262 .71564 .2361 .72798 .23166 .72204 .21959 Mtetra
.604 .625 .845 r
.72204 .21959 .72798 .23166 .74038 .2274 .73456 .21671 Mtetra
.602 .654 .874 r
.73456 .21671 .74038 .2274 .75285 .22328 .74716 .21391 Mtetra
.6 .687 .904 r
.74716 .21391 .75285 .22328 .76539 .21923 .75983 .21113 Mtetra
.738 .766 .876 r
.09551 .43462 .10283 .44102 .1129 .43602 .10574 .4286 Mtetra
.73 .738 .857 r
.10574 .4286 .1129 .43602 .123 .43104 .11599 .42255 Mtetra
.721 .71 .84 r
.11599 .42255 .123 .43104 .13312 .42615 .12626 .41652 Mtetra
.71 .683 .822 r
.12626 .41652 .13312 .42615 .14325 .42139 .13655 .41056 Mtetra
.699 .657 .805 r
.13655 .41056 .14325 .42139 .15339 .41682 .14685 .40469 Mtetra
.686 .631 .789 r
.14685 .40469 .15339 .41682 .16353 .4125 .15716 .39898 Mtetra
.673 .606 .772 r
.15716 .39898 .16353 .4125 .17368 .40848 .16746 .39347 Mtetra
.659 .582 .757 r
.16746 .39347 .17368 .40848 .18382 .40475 .17777 .38819 Mtetra
.646 .558 .742 r
.17777 .38819 .18382 .40475 .19397 .40137 .18808 .38318 Mtetra
.634 .537 .727 r
.18808 .38318 .19397 .40137 .20413 .39829 .1984 .37844 Mtetra
.622 .517 .714 r
.1984 .37844 .20413 .39829 .2143 .39552 .20871 .37399 Mtetra
.612 .5 .702 r
.20871 .37399 .2143 .39552 .2245 .39299 .21904 .3698 Mtetra
.602 .484 .691 r
.21904 .3698 .2245 .39299 .23472 .39068 .22938 .36586 Mtetra
.595 .471 .681 r
.22938 .36586 .23472 .39068 .24497 .38853 .23973 .36213 Mtetra
.589 .459 .672 r
.23973 .36213 .24497 .38853 .25527 .38651 .25012 .35857 Mtetra
.584 .45 .664 r
.25012 .35857 .25527 .38651 .2656 .38456 .26053 .3551 Mtetra
.581 .442 .657 r
.26053 .3551 .2656 .38456 .27599 .38264 .27099 .35168 Mtetra
.579 .436 .651 r
.27099 .35168 .27599 .38264 .28644 .38062 .28149 .34819 Mtetra
.578 .431 .645 r
.28149 .34819 .28644 .38062 .29696 .37841 .29204 .34458 Mtetra
.576 .426 .64 r
.29204 .34458 .29696 .37841 .30754 .37587 .30265 .3409 Mtetra
.574 .421 .636 r
.30265 .3409 .30754 .37587 .3182 .37301 .31329 .33726 Mtetra
.567 .414 .633 r
.31329 .33726 .3182 .37301 .32889 .37051 .32394 .33416 Mtetra
.558 .406 .632 r
.32394 .33416 .32889 .37051 .33958 .36876 .33459 .33178 Mtetra
.553 .402 .63 r
.33459 .33178 .33958 .36876 .35028 .36799 .34528 .32973 Mtetra
.552 .398 .626 r
.34528 .32973 .35028 .36799 .36099 .36814 .35602 .32769 Mtetra
.559 .399 .62 r
.35602 .32769 .36099 .36814 .37178 .36818 .36686 .32483 Mtetra
.566 .398 .613 r
.36686 .32483 .37178 .36818 .38267 .36754 .3778 .32094 Mtetra
.567 .394 .606 r
.3778 .32094 .38267 .36754 .39367 .36588 .3888 .31659 Mtetra
.566 .389 .601 r
.3888 .31659 .39367 .36588 .40477 .36301 .39985 .31212 Mtetra
.56 .383 .598 r
.39985 .31212 .40477 .36301 .41596 .35915 .41091 .3082 Mtetra
.555 .379 .598 r
.41091 .3082 .41596 .35915 .42723 .3543 .42201 .30482 Mtetra
.557 .383 .601 r
.42201 .30482 .42723 .3543 .43857 .34824 .43316 .30132 Mtetra
.563 .391 .606 r
.43316 .30132 .43857 .34824 .44997 .34113 .44437 .29736 Mtetra
.575 .405 .613 r
.44437 .29736 .44997 .34113 .4614 .33334 .45565 .29236 Mtetra
.586 .418 .62 r
.45565 .29236 .4614 .33334 .47286 .32541 .46698 .28654 Mtetra
.589 .424 .626 r
.46698 .28654 .47286 .32541 .48432 .3184 .47835 .28072 Mtetra
.588 .426 .63 r
.47835 .28072 .48432 .3184 .4958 .31238 .48975 .27522 Mtetra
.581 .423 .632 r
.48975 .27522 .4958 .31238 .50731 .3071 .50118 .27044 Mtetra
.576 .421 .633 r
.50118 .27044 .50731 .3071 .51886 .30219 .51265 .26622 Mtetra
.577 .423 .636 r
.51265 .26622 .51886 .30219 .53044 .29695 .52417 .26203 Mtetra
.579 .427 .64 r
.52417 .26203 .53044 .29695 .54207 .29136 .53573 .25777 Mtetra
.583 .434 .645 r
.53573 .25777 .54207 .29136 .55374 .28557 .54734 .25338 Mtetra
.586 .44 .65 r
.54734 .25338 .55374 .28557 .56543 .27968 .559 .24892 Mtetra
.588 .447 .657 r
.559 .24892 .56543 .27968 .57717 .27381 .5707 .2445 Mtetra
.589 .453 .664 r
.5707 .2445 .57717 .27381 .58894 .268 .58246 .24017 Mtetra
.59 .46 .672 r
.58246 .24017 .58894 .268 .60076 .26231 .59427 .23602 Mtetra
.59 .468 .681 r
.59427 .23602 .60076 .26231 .61262 .25678 .60613 .23208 Mtetra
.59 .476 .692 r
.60613 .23208 .61262 .25678 .62452 .25147 .61806 .2284 Mtetra
.589 .486 .704 r
.61806 .2284 .62452 .25147 .63648 .2464 .63005 .22498 Mtetra
.588 .497 .718 r
.63005 .22498 .63648 .2464 .64849 .24165 .64211 .22185 Mtetra
.587 .509 .735 r
.64211 .22185 .64849 .24165 .66057 .23721 .65425 .21901 Mtetra
.584 .523 .753 r
.65425 .21901 .66057 .23721 .67272 .23311 .66646 .21645 Mtetra
.582 .539 .773 r
.66646 .21645 .67272 .23311 .68494 .22933 .67875 .21413 Mtetra
.579 .557 .794 r
.67875 .21413 .68494 .22933 .69723 .22585 .69113 .21203 Mtetra
.575 .577 .817 r
.69113 .21203 .69723 .22585 .7096 .22262 .70358 .21008 Mtetra
.572 .599 .841 r
.70358 .21008 .7096 .22262 .72204 .21959 .71612 .20825 Mtetra
.568 .622 .866 r
.71612 .20825 .72204 .21959 .73456 .21671 .72874 .20648 Mtetra
.564 .647 .891 r
.72874 .20648 .73456 .21671 .74716 .21391 .74144 .20474 Mtetra
.558 .674 .916 r
.74144 .20474 .74716 .21391 .75983 .21113 .75422 .20298 Mtetra
.747 .767 .869 r
.08813 .42819 .09551 .43462 .10574 .4286 .09844 .42173 Mtetra
.745 .756 .861 r
.09844 .42173 .10574 .4286 .11599 .42255 .10878 .41522 Mtetra
.742 .744 .853 r
.10878 .41522 .11599 .42255 .12626 .41652 .11914 .40867 Mtetra
.737 .731 .845 r
.11914 .40867 .12626 .41652 .13655 .41056 .12952 .40212 Mtetra
.732 .717 .836 r
.12952 .40212 .13655 .41056 .14685 .40469 .13992 .39558 Mtetra
.725 .701 .827 r
.13992 .39558 .14685 .40469 .15716 .39898 .15033 .3891 Mtetra
.716 .683 .817 r
.15033 .3891 .15716 .39898 .16746 .39347 .16075 .38272 Mtetra
.707 .664 .806 r
.16075 .38272 .16746 .39347 .17777 .38819 .17118 .37648 Mtetra
.695 .644 .794 r
.17118 .37648 .17777 .38819 .18808 .38318 .18161 .37042 Mtetra
.684 .623 .782 r
.18161 .37042 .18808 .38318 .1984 .37844 .19204 .36457 Mtetra
.672 .603 .77 r
.19204 .36457 .1984 .37844 .20871 .37399 .20248 .35894 Mtetra
.661 .583 .758 r
.20248 .35894 .20871 .37399 .21904 .3698 .21292 .35353 Mtetra
.65 .565 .746 r
.21292 .35353 .21904 .3698 .22938 .36586 .22337 .34835 Mtetra
.64 .548 .734 r
.22337 .34835 .22938 .36586 .23973 .36213 .23383 .34337 Mtetra
.631 .532 .724 r
.23383 .34337 .23973 .36213 .25012 .35857 .24431 .33855 Mtetra
.624 .518 .714 r
.24431 .33855 .25012 .35857 .26053 .3551 .25481 .33386 Mtetra
.618 .506 .704 r
.25481 .33386 .26053 .3551 .27099 .35168 .26534 .32925 Mtetra
.613 .496 .696 r
.26534 .32925 .27099 .35168 .28149 .34819 .2759 .3247 Mtetra
.609 .487 .689 r
.2759 .3247 .28149 .34819 .29204 .34458 .28649 .32019 Mtetra
.603 .479 .684 r
.28649 .32019 .29204 .34458 .30265 .3409 .2971 .31588 Mtetra
.597 .472 .681 r
.2971 .31588 .30265 .3409 .31329 .33726 .30773 .31186 Mtetra
.588 .465 .679 r
.30773 .31186 .31329 .33726 .32394 .33416 .31837 .30836 Mtetra
.58 .458 .678 r
.31837 .30836 .32394 .33416 .33459 .33178 .32902 .30533 Mtetra
.583 .457 .674 r
.32902 .30533 .33459 .33178 .34528 .32973 .33974 .30201 Mtetra
.59 .456 .667 r
.33974 .30201 .34528 .32973 .35602 .32769 .35055 .29799 Mtetra
.601 .456 .656 r
.35055 .29799 .35602 .32769 .36686 .32483 .36145 .29281 Mtetra
.607 .453 .646 r
.36145 .29281 .36686 .32483 .3778 .32094 .37245 .28657 Mtetra
.601 .442 .638 r
.37245 .28657 .3778 .32094 .3888 .31659 .38347 .28037 Mtetra
.591 .43 .632 r
.38347 .28037 .3888 .31659 .39985 .31212 .39449 .27487 Mtetra
.573 .415 .629 r
.39449 .27487 .39985 .31212 .41091 .3082 .40548 .2709 Mtetra
.556 .403 .629 r
.40548 .2709 .41091 .3082 .42201 .30482 .41646 .26844 Mtetra
.549 .4 .632 r
.41646 .26844 .42201 .30482 .43316 .30132 .42748 .26669 Mtetra
.549 .406 .639 r
.42748 .26669 .43316 .30132 .44437 .29736 .43856 .26499 Mtetra
.565 .424 .648 r
.43856 .26499 .44437 .29736 .45565 .29236 .44973 .26224 Mtetra
.583 .444 .657 r
.44973 .26224 .45565 .29236 .46698 .28654 .46097 .25831 Mtetra
.596 .46 .666 r
.46097 .25831 .46698 .28654 .47835 .28072 .47228 .25368 Mtetra
.602 .469 .672 r
.47228 .25368 .47835 .28072 .48975 .27522 .48363 .24875 Mtetra
.597 .469 .676 r
.48363 .24875 .48975 .27522 .50118 .27044 .49502 .2443 Mtetra
.591 .466 .679 r
.49502 .2443 .50118 .27044 .51265 .26622 .50645 .24036 Mtetra
.587 .466 .681 r
.50645 .24036 .51265 .26622 .52417 .26203 .51793 .23672 Mtetra
.585 .467 .685 r
.51793 .23672 .52417 .26203 .53573 .25777 .52946 .23328 Mtetra
.586 .473 .691 r
.52946 .23328 .53573 .25777 .54734 .25338 .54104 .2299 Mtetra
.587 .48 .699 r
.54104 .2299 .54734 .25338 .559 .24892 .55268 .22656 Mtetra
.588 .488 .708 r
.55268 .22656 .559 .24892 .5707 .2445 .56438 .22331 Mtetra
.589 .497 .718 r
.56438 .22331 .5707 .2445 .58246 .24017 .57614 .22019 Mtetra
.588 .507 .73 r
.57614 .22019 .58246 .24017 .59427 .23602 .58796 .21724 Mtetra
.587 .517 .743 r
.58796 .21724 .59427 .23602 .60613 .23208 .59984 .2145 Mtetra
.584 .528 .758 r
.59984 .2145 .60613 .23208 .61806 .2284 .6118 .21199 Mtetra
.581 .54 .774 r
.6118 .21199 .61806 .2284 .63005 .22498 .62383 .2097 Mtetra
.577 .553 .792 r
.62383 .2097 .63005 .22498 .64211 .22185 .63593 .20766 Mtetra
.572 .568 .81 r
.63593 .20766 .64211 .22185 .65425 .21901 .64812 .20584 Mtetra
.566 .582 .829 r
.64812 .20584 .65425 .21901 .66646 .21645 .66039 .2042 Mtetra
.56 .597 .847 r
.66039 .2042 .66646 .21645 .67875 .21413 .67274 .20272 Mtetra
.555 .613 .865 r
.67274 .20272 .67875 .21413 .69113 .21203 .68517 .20134 Mtetra
.549 .628 .882 r
.68517 .20134 .69113 .21203 .70358 .21008 .69769 .20003 Mtetra
.545 .642 .897 r
.69769 .20003 .70358 .21008 .71612 .20825 .71029 .19874 Mtetra
.541 .656 .91 r
.71029 .19874 .71612 .20825 .72874 .20648 .72297 .19745 Mtetra
.538 .669 .922 r
.72297 .19745 .72874 .20648 .74144 .20474 .73573 .19613 Mtetra
.535 .681 .932 r
.73573 .19613 .74144 .20474 .75422 .20298 .74857 .19475 Mtetra
.744 .767 .872 r
.0807 .4217 .08813 .42819 .09844 .42173 .09102 .41538 Mtetra
.746 .772 .874 r
.09102 .41538 .09844 .42173 .10878 .41522 .10136 .40898 Mtetra
.749 .776 .875 r
.10136 .40898 .10878 .41522 .11914 .40867 .11174 .40252 Mtetra
.751 .779 .876 r
.11174 .40252 .11914 .40867 .12952 .40212 .12215 .39598 Mtetra
.753 .781 .876 r
.12215 .39598 .12952 .40212 .13992 .39558 .13258 .38938 Mtetra
.753 .78 .875 r
.13258 .38938 .13992 .39558 .15033 .3891 .14304 .38275 Mtetra
.751 .776 .873 r
.14304 .38275 .15033 .3891 .16075 .38272 .15352 .37611 Mtetra
.748 .77 .87 r
.15352 .37611 .16075 .38272 .17118 .37648 .16401 .36952 Mtetra
.743 .76 .866 r
.16401 .36952 .17118 .37648 .18161 .37042 .17452 .36301 Mtetra
.737 .748 .861 r
.17452 .36301 .18161 .37042 .19204 .36457 .18504 .35662 Mtetra
.729 .733 .854 r
.18504 .35662 .19204 .36457 .20248 .35894 .19556 .35037 Mtetra
.72 .717 .846 r
.19556 .35037 .20248 .35894 .21292 .35353 .20609 .34427 Mtetra
.711 .699 .837 r
.20609 .34427 .21292 .35353 .22337 .34835 .21663 .33834 Mtetra
.702 .681 .827 r
.21663 .33834 .22337 .34835 .23383 .34337 .22718 .33256 Mtetra
.692 .662 .816 r
.22718 .33256 .23383 .34337 .24431 .33855 .23774 .32692 Mtetra
.683 .645 .805 r
.23774 .32692 .24431 .33855 .25481 .33386 .24832 .32142 Mtetra
.675 .628 .795 r
.24832 .32142 .25481 .33386 .26534 .32925 .25892 .31604 Mtetra
.666 .613 .786 r
.25892 .31604 .26534 .32925 .2759 .3247 .26954 .31084 Mtetra
.658 .6 .779 r
.26954 .31084 .2759 .3247 .28649 .32019 .28017 .30584 Mtetra
.647 .589 .775 r
.28017 .30584 .28649 .32019 .2971 .31588 .29081 .30121 Mtetra
.636 .579 .774 r
.29081 .30121 .2971 .31588 .30773 .31186 .30146 .29699 Mtetra
.629 .573 .773 r
.30146 .29699 .30773 .31186 .31837 .30836 .31212 .29307 Mtetra
.625 .566 .768 r
.31212 .29307 .31837 .30836 .32902 .30533 .32282 .28921 Mtetra
.638 .564 .755 r
.32282 .28921 .32902 .30533 .33974 .30201 .33362 .28457 Mtetra
.653 .559 .737 r
.33362 .28457 .33974 .30201 .35055 .29799 .34451 .27877 Mtetra
.662 .549 .717 r
.34451 .27877 .35055 .29799 .36145 .29281 .35551 .27179 Mtetra
.664 .538 .701 r
.35551 .27179 .36145 .29281 .37245 .28657 .36656 .26399 Mtetra
.65 .52 .692 r
.36656 .26399 .37245 .28657 .38347 .28037 .37762 .25668 Mtetra
.629 .5 .687 r
.37762 .25668 .38347 .28037 .39449 .27487 .38863 .25063 Mtetra
.597 .477 .687 r
.38863 .25063 .39449 .27487 .40548 .2709 .39959 .2466 Mtetra
.563 .456 .69 r
.39959 .2466 .40548 .2709 .41646 .26844 .41053 .24462 Mtetra
.541 .445 .695 r
.41053 .24462 .41646 .26844 .42748 .26669 .42147 .2439 Mtetra
.532 .446 .704 r
.42147 .2439 .42748 .26669 .43856 .26499 .43247 .24369 Mtetra
.549 .468 .716 r
.43247 .24369 .43856 .26499 .44973 .26224 .44357 .24266 Mtetra
.575 .498 .731 r
.44357 .24266 .44973 .26224 .46097 .25831 .45476 .24046 Mtetra
.603 .531 .746 r
.45476 .24046 .46097 .25831 .47228 .25368 .46604 .23708 Mtetra
.624 .556 .758 r
.46604 .23708 .47228 .25368 .48363 .24875 .47737 .23291 Mtetra
.625 .566 .768 r
.47737 .23291 .48363 .24875 .49502 .2443 .48876 .22881 Mtetra
.62 .568 .775 r
.48876 .22881 .49502 .2443 .50645 .24036 .50019 .225 Mtetra
.611 .566 .779 r
.50019 .225 .50645 .24036 .51793 .23672 .51167 .22162 Mtetra
.602 .565 .785 r
.51167 .22162 .51793 .23672 .52946 .23328 .5232 .21861 Mtetra
.598 .569 .793 r
.5232 .21861 .52946 .23328 .54104 .2299 .53479 .21581 Mtetra
.595 .577 .803 r
.53479 .21581 .54104 .2299 .55268 .22656 .54644 .21319 Mtetra
.592 .588 .817 r
.54644 .21319 .55268 .22656 .56438 .22331 .55816 .2107 Mtetra
.589 .6 .831 r
.55816 .2107 .56438 .22331 .57614 .22019 .56994 .20835 Mtetra
.584 .614 .848 r
.56994 .20835 .57614 .22019 .58796 .21724 .58179 .20615 Mtetra
.579 .628 .865 r
.58179 .20615 .58796 .21724 .59984 .2145 .59371 .20411 Mtetra
.571 .641 .881 r
.59371 .20411 .59984 .2145 .6118 .21199 .6057 .20224 Mtetra
.562 .654 .898 r
.6057 .20224 .6118 .21199 .62383 .2097 .61778 .20054 Mtetra
.552 .666 .913 r
.61778 .20054 .62383 .2097 .63593 .20766 .62993 .19899 Mtetra
.542 .677 .926 r
.62993 .19899 .63593 .20766 .64812 .20584 .64216 .19756 Mtetra
.533 .686 .936 r
.64216 .19756 .64812 .20584 .66039 .2042 .65447 .19623 Mtetra
.526 .693 .944 r
.65447 .19623 .66039 .2042 .67274 .20272 .66686 .19494 Mtetra
.523 .699 .95 r
.66686 .19494 .67274 .20272 .68517 .20134 .67933 .19366 Mtetra
.522 .702 .952 r
.67933 .19366 .68517 .20134 .69769 .20003 .69188 .19236 Mtetra
.524 .705 .953 r
.69188 .19236 .69769 .20003 .71029 .19874 .70452 .19098 Mtetra
.528 .705 .952 r
.70452 .19098 .71029 .19874 .72297 .19745 .71722 .18955 Mtetra
.532 .703 .949 r
.71722 .18955 .72297 .19745 .73573 .19613 .73001 .18804 Mtetra
.537 .701 .945 r
.73001 .18804 .73573 .19613 .74857 .19475 .74288 .18646 Mtetra
.723 .764 .886 r
.07322 .41517 .0807 .4217 .09102 .41538 .08345 .40964 Mtetra
.729 .79 .9 r
.08345 .40964 .09102 .41538 .10136 .40898 .09372 .40402 Mtetra
.736 .816 .914 r
.09372 .40402 .10136 .40898 .11174 .40252 .10403 .39831 Mtetra
.741 .843 .927 r
.10403 .39831 .11174 .40252 .12215 .39598 .11438 .3925 Mtetra
.746 .868 .937 r
.11438 .3925 .12215 .39598 .13258 .38938 .12477 .38656 Mtetra
.747 .891 .944 r
.12477 .38656 .13258 .38938 .14304 .38275 .13519 .38053 Mtetra
.746 .912 .949 r
.13519 .38053 .14304 .38275 .15352 .37611 .14565 .37442 Mtetra
.741 .928 .952 r
.14565 .37442 .15352 .37611 .16401 .36952 .15613 .36826 Mtetra
.734 .941 .952 r
.15613 .36826 .16401 .36952 .17452 .36301 .16665 .36209 Mtetra
.724 .95 .951 r
.16665 .36209 .17452 .36301 .18504 .35662 .17718 .35595 Mtetra
.713 .955 .95 r
.17718 .35595 .18504 .35662 .19556 .35037 .18773 .34986 Mtetra
.702 .958 .948 r
.18773 .34986 .19556 .35037 .20609 .34427 .1983 .34385 Mtetra
.692 .958 .947 r
.1983 .34385 .20609 .34427 .21663 .33834 .20888 .33794 Mtetra
.682 .957 .947 r
.20888 .33794 .21663 .33834 .22718 .33256 .21948 .33213 Mtetra
.674 .956 .948 r
.21948 .33213 .22718 .33256 .23774 .32692 .2301 .32644 Mtetra
.665 .953 .95 r
.2301 .32644 .23774 .32692 .24832 .32142 .24073 .32087 Mtetra
.655 .95 .952 r
.24073 .32087 .24832 .32142 .25892 .31604 .25138 .31545 Mtetra
.642 .947 .953 r
.25138 .31545 .25892 .31604 .26954 .31084 .26205 .31021 Mtetra
.627 .942 .954 r
.26205 .31021 .26954 .31084 .28017 .30584 .27273 .30516 Mtetra
.611 .937 .955 r
.27273 .30516 .28017 .30584 .29081 .30121 .28343 .30033 Mtetra
.605 .932 .96 r
.28343 .30033 .29081 .30121 .30146 .29699 .29416 .29565 Mtetra
.636 .932 .969 r
.29416 .29565 .30146 .29699 .31212 .29307 .30493 .29079 Mtetra
.691 .92 .97 r
.30493 .29079 .31212 .29307 .32282 .28921 .31578 .28544 Mtetra
.753 .881 .937 r
.31578 .28544 .32282 .28921 .33362 .28457 .32672 .27897 Mtetra
.782 .823 .885 r
.32672 .27897 .33362 .28457 .34451 .27877 .33778 .2712 Mtetra
.78 .768 .842 r
.33778 .2712 .34451 .27877 .35551 .27179 .34889 .2626 Mtetra
.769 .729 .815 r
.34889 .2626 .35551 .27179 .36656 .26399 .36004 .25373 Mtetra
.742 .7 .811 r
.36004 .25373 .36656 .26399 .37762 .25668 .37114 .24582 Mtetra
.703 .675 .82 r
.37114 .24582 .37762 .25668 .38863 .25063 .38219 .23957 Mtetra
.647 .649 .837 r
.38219 .23957 .38863 .25063 .39959 .2466 .39316 .23552 Mtetra
.577 .616 .855 r
.39316 .23552 .39959 .2466 .41053 .24462 .4041 .23366 Mtetra
.51 .586 .867 r
.4041 .23366 .41053 .24462 .42147 .2439 .41504 .23348 Mtetra
.458 .574 .883 r
.41504 .23348 .42147 .2439 .43247 .24369 .42601 .23428 Mtetra
.458 .602 .906 r
.42601 .23428 .43247 .24369 .44357 .24266 .43708 .23482 Mtetra
.479 .662 .942 r
.43708 .23482 .44357 .24266 .45476 .24046 .44825 .23453 Mtetra
.522 .75 .979 r
.44825 .23453 .45476 .24046 .46604 .23708 .45952 .23294 Mtetra
.551 .83 .997 r
.45952 .23294 .46604 .23708 .47737 .23291 .47087 .23023 Mtetra
.531 .871 .991 r
.47087 .23023 .47737 .23291 .48876 .22881 .48229 .22702 Mtetra
.498 .881 .969 r
.48229 .22702 .48876 .22881 .50019 .225 .49377 .22363 Mtetra
.456 .869 .95 r
.49377 .22363 .50019 .225 .51167 .22162 .5053 .2204 Mtetra
.422 .855 .937 r
.5053 .2204 .51167 .22162 .5232 .21861 .51689 .21739 Mtetra
.4 .843 .932 r
.51689 .21739 .5232 .21861 .53479 .21581 .52853 .21457 Mtetra
.38 .832 .927 r
.52853 .21457 .53479 .21581 .54644 .21319 .54024 .21195 Mtetra
.363 .823 .923 r
.54024 .21195 .54644 .21319 .55816 .2107 .55201 .20947 Mtetra
.347 .814 .917 r
.55201 .20947 .55816 .2107 .56994 .20835 .56385 .20713 Mtetra
.332 .805 .912 r
.56385 .20713 .56994 .20835 .58179 .20615 .57575 .20491 Mtetra
.32 .798 .909 r
.57575 .20491 .58179 .20615 .59371 .20411 .58773 .20279 Mtetra
.313 .793 .91 r
.58773 .20279 .59371 .20411 .6057 .20224 .59978 .20079 Mtetra
.314 .791 .916 r
.59978 .20079 .6057 .20224 .61778 .20054 .6119 .19886 Mtetra
.322 .793 .927 r
.6119 .19886 .61778 .20054 .62993 .19899 .62409 .197 Mtetra
.341 .798 .943 r
.62409 .197 .62993 .19899 .64216 .19756 .63636 .19516 Mtetra
.368 .804 .961 r
.63636 .19516 .64216 .19756 .65447 .19623 .64871 .19332 Mtetra
.401 .81 .979 r
.64871 .19332 .65447 .19623 .66686 .19494 .66113 .19144 Mtetra
.438 .812 .993 r
.66113 .19144 .66686 .19494 .67933 .19366 .67362 .18948 Mtetra
.474 .808 .999 r
.67362 .18948 .67933 .19366 .69188 .19236 .68618 .18743 Mtetra
.508 .799 .998 r
.68618 .18743 .69188 .19236 .70452 .19098 .69882 .18525 Mtetra
.534 .782 .989 r
.69882 .18525 .70452 .19098 .71722 .18955 .71152 .18296 Mtetra
.555 .762 .974 r
.71152 .18296 .71722 .18955 .73001 .18804 .72429 .18057 Mtetra
.569 .739 .956 r
.72429 .18057 .73001 .18804 .74288 .18646 .73713 .1781 Mtetra
.684 .758 .907 r
.06568 .40859 .07322 .41517 .08345 .40964 .07577 .40425 Mtetra
.69 .798 .932 r
.07577 .40425 .08345 .40964 .09372 .40402 .0859 .39983 Mtetra
.691 .839 .954 r
.0859 .39983 .09372 .40402 .10403 .39831 .09609 .3953 Mtetra
.687 .88 .97 r
.09609 .3953 .10403 .39831 .11438 .3925 .10632 .39065 Mtetra
.675 .916 .975 r
.10632 .39065 .11438 .3925 .12477 .38656 .1166 .38585 Mtetra
.65 .939 .964 r
.1166 .38585 .12477 .38656 .13519 .38053 .12693 .3809 Mtetra
.61 .947 .933 r
.12693 .3809 .13519 .38053 .14565 .37442 .13731 .37582 Mtetra
.555 .933 .882 r
.13731 .37582 .14565 .37442 .15613 .36826 .14774 .37062 Mtetra
.489 .9 .814 r
.14774 .37062 .15613 .36826 .16665 .36209 .1582 .36534 Mtetra
.417 .853 .737 r
.1582 .36534 .16665 .36209 .17718 .35595 .1687 .36 Mtetra
.346 .797 .658 r
.1687 .36 .17718 .35595 .18773 .34986 .17924 .35464 Mtetra
0 0 0 r
.17924 .35464 .18773 .34986 .1983 .34385 .1898 .34927 Mtetra
.1898 .34927 .1983 .34385 .20888 .33794 .20039 .34393 Mtetra
.20039 .34393 .20888 .33794 .21948 .33213 .21101 .33863 Mtetra
.21101 .33863 .21948 .33213 .2301 .32644 .22165 .33341 Mtetra
.22165 .33341 .2301 .32644 .24073 .32087 .23232 .32828 Mtetra
.23232 .32828 .24073 .32087 .25138 .31545 .243 .32327 Mtetra
.012 0 0 r
.243 .32327 .25138 .31545 .26205 .31021 .25372 .31837 Mtetra
.042 0 0 r
.25372 .31837 .26205 .31021 .27273 .30516 .26445 .31357 Mtetra
.054 0 0 r
.26445 .31357 .27273 .30516 .28343 .30033 .27523 .30872 Mtetra
.041 0 0 r
.27523 .30872 .28343 .30033 .29416 .29565 .28606 .3037 Mtetra
0 0 0 r
.28606 .3037 .29416 .29565 .30493 .29079 .29697 .29808 Mtetra
.29697 .29808 .30493 .29079 .31578 .28544 .30797 .29162 Mtetra
.30797 .29162 .31578 .28544 .32672 .27897 .31906 .28406 Mtetra
.5 .865 .632 r
.31906 .28406 .32672 .27897 .33778 .2712 .33024 .27546 Mtetra
.579 .917 .699 r
.33024 .27546 .33778 .2712 .34889 .2626 .34145 .26661 Mtetra
.566 .913 .705 r
.34145 .26661 .34889 .2626 .36004 .25373 .35265 .25811 Mtetra
.433 .836 .637 r
.35265 .25811 .36004 .25373 .37114 .24582 .3638 .25075 Mtetra
0 0 0 r
.3638 .25075 .37114 .24582 .38219 .23957 .3749 .24497 Mtetra
.3749 .24497 .38219 .23957 .39316 .23552 .38595 .24089 Mtetra
.127 0 0 r
.38595 .24089 .39316 .23552 .4041 .23366 .39698 .23853 Mtetra
.23 0 0 r
.39698 .23853 .4041 .23366 .41504 .23348 .408 .23775 Mtetra
.291 0 0 r
.408 .23775 .41504 .23348 .42601 .23428 .41905 .23814 Mtetra
.301 0 0 r
.41905 .23814 .42601 .23428 .43708 .23482 .43017 .23888 Mtetra
.29 0 0 r
.43017 .23888 .43708 .23482 .44825 .23453 .44138 .23938 Mtetra
.247 0 0 r
.44138 .23938 .44825 .23453 .45952 .23294 .45269 .23886 Mtetra
.211 0 0 r
.45269 .23886 .45952 .23294 .47087 .23023 .4641 .23723 Mtetra
.196 0 0 r
.4641 .23723 .47087 .23023 .48229 .22702 .4756 .23474 Mtetra
.187 0 0 r
.4756 .23474 .48229 .22702 .49377 .22363 .48716 .23167 Mtetra
.188 0 0 r
.48716 .23167 .49377 .22363 .5053 .2204 .49878 .22841 Mtetra
.186 0 0 r
.49878 .22841 .5053 .2204 .51689 .21739 .51045 .22511 Mtetra
.183 0 0 r
.51045 .22511 .51689 .21739 .52853 .21457 .52219 .22191 Mtetra
.177 0 0 r
.52219 .22191 .52853 .21457 .54024 .21195 .53398 .21882 Mtetra
.168 0 0 r
.53398 .21882 .54024 .21195 .55201 .20947 .54584 .21586 Mtetra
.155 0 0 r
.54584 .21586 .55201 .20947 .56385 .20713 .55776 .21299 Mtetra
.138 0 0 r
.55776 .21299 .56385 .20713 .57575 .20491 .56974 .2102 Mtetra
.115 0 0 r
.56974 .2102 .57575 .20491 .58773 .20279 .58178 .20746 Mtetra
.085 0 0 r
.58178 .20746 .58773 .20279 .59978 .20079 .5939 .20475 Mtetra
.045 0 0 r
.5939 .20475 .59978 .20079 .6119 .19886 .60608 .20204 Mtetra
0 0 0 r
.60608 .20204 .6119 .19886 .62409 .197 .61832 .1993 Mtetra
.61832 .1993 .62409 .197 .63636 .19516 .63064 .1965 Mtetra
.63064 .1965 .63636 .19516 .64871 .19332 .64301 .19362 Mtetra
.257 .768 .795 r
.64301 .19362 .64871 .19332 .66113 .19144 .65545 .19062 Mtetra
.36 .828 .891 r
.65545 .19062 .66113 .19144 .67362 .18948 .66795 .18748 Mtetra
.452 .862 .958 r
.66795 .18748 .67362 .18948 .68618 .18743 .68051 .18419 Mtetra
.526 .867 .992 r
.68051 .18419 .68618 .18743 .69882 .18525 .69313 .18074 Mtetra
.576 .848 .996 r
.69313 .18074 .69882 .18525 .71152 .18296 .70581 .17715 Mtetra
.606 .816 .98 r
.70581 .17715 .71152 .18296 .72429 .18057 .71855 .17346 Mtetra
.622 .778 .956 r
.71855 .17346 .72429 .18057 .73713 .1781 .73134 .16968 Mtetra
.627 .744 .931 r
.05808 .40196 .06568 .40859 .07577 .40425 .068 .39901 Mtetra
.623 .79 .962 r
.068 .39901 .07577 .40425 .0859 .39983 .07796 .39598 Mtetra
.61 .837 .986 r
.07796 .39598 .0859 .39983 .09609 .3953 .08798 .39286 Mtetra
.583 .877 .993 r
.08798 .39286 .09609 .3953 .10632 .39065 .09806 .38961 Mtetra
.536 .897 .971 r
.09806 .38961 .10632 .39065 .1166 .38585 .10821 .38619 Mtetra
.464 .886 .91 r
.10821 .38619 .1166 .38585 .12693 .3809 .11841 .38261 Mtetra
.372 .838 .81 r
.11841 .38261 .12693 .3809 .13731 .37582 .12867 .37887 Mtetra
.269 .761 .685 r
.12867 .37887 .13731 .37582 .14774 .37062 .139 .37497 Mtetra
0 0 0 r
.139 .37497 .14774 .37062 .1582 .36534 .14937 .37094 Mtetra
.14937 .37094 .1582 .36534 .1687 .36 .1598 .36681 Mtetra
.1598 .36681 .1687 .36 .17924 .35464 .17027 .36258 Mtetra
.052 0 0 r
.17027 .36258 .17924 .35464 .1898 .34927 .18079 .3583 Mtetra
.101 0 0 r
.18079 .3583 .1898 .34927 .20039 .34393 .19135 .35398 Mtetra
.142 0 0 r
.19135 .35398 .20039 .34393 .21101 .33863 .20195 .34963 Mtetra
.175 0 0 r
.20195 .34963 .21101 .33863 .22165 .33341 .21259 .34527 Mtetra
.201 0 0 r
.21259 .34527 .22165 .33341 .23232 .32828 .22327 .34091 Mtetra
.222 0 .011 r
.22327 .34091 .23232 .32828 .243 .32327 .23399 .33655 Mtetra
.237 0 .035 r
.23399 .33655 .243 .32327 .25372 .31837 .24475 .33218 Mtetra
.247 0 .052 r
.24475 .33218 .25372 .31837 .26445 .31357 .25555 .32776 Mtetra
.251 0 .062 r
.25555 .32776 .26445 .31357 .27523 .30872 .2664 .32322 Mtetra
.249 0 .067 r
.2664 .32322 .27523 .30872 .28606 .3037 .2773 .31849 Mtetra
.242 0 .07 r
.2773 .31849 .28606 .3037 .29697 .29808 .28827 .31345 Mtetra
.239 0 .079 r
.28827 .31345 .29697 .29808 .30797 .29162 .2993 .30807 Mtetra
.253 0 .105 r
.2993 .30807 .30797 .29162 .31906 .28406 .31037 .30251 Mtetra
.285 0 .15 r
.31037 .30251 .31906 .28406 .33024 .27546 .32148 .29697 Mtetra
.336 0 .209 r
.32148 .29697 .33024 .27546 .34145 .26661 .33258 .29198 Mtetra
.381 .043 .261 r
.33258 .29198 .34145 .26661 .35265 .25811 .34369 .28768 Mtetra
.408 .083 .299 r
.34369 .28768 .35265 .25811 .3638 .25075 .35481 .28378 Mtetra
.423 .106 .321 r
.35481 .28378 .3638 .25075 .3749 .24497 .36598 .28007 Mtetra
.423 .111 .329 r
.36598 .28007 .3749 .24497 .38595 .24089 .37721 .27599 Mtetra
.418 .106 .328 r
.37721 .27599 .38595 .24089 .39698 .23853 .3885 .27156 Mtetra
.415 .099 .318 r
.3885 .27156 .39698 .23853 .408 .23775 .39983 .2673 Mtetra
.411 .085 .299 r
.39983 .2673 .408 .23775 .41905 .23814 .41119 .26346 Mtetra
.407 .066 .272 r
.41119 .26346 .41905 .23814 .43017 .23888 .42258 .26031 Mtetra
.401 .042 .236 r
.42258 .26031 .43017 .23888 .44138 .23938 .434 .25771 Mtetra
.382 .006 .194 r
.434 .25771 .44138 .23938 .45269 .23886 .44549 .25514 Mtetra
.36 0 .156 r
.44549 .25514 .45269 .23886 .4641 .23723 .45704 .25239 Mtetra
.338 0 .127 r
.45704 .25239 .4641 .23723 .4756 .23474 .46865 .24929 Mtetra
.32 0 .108 r
.46865 .24929 .4756 .23474 .48716 .23167 .48033 .24589 Mtetra
.309 0 .097 r
.48033 .24589 .48716 .23167 .49878 .22841 .49207 .24229 Mtetra
.3 0 .087 r
.49207 .24229 .49878 .22841 .51045 .22511 .50387 .23857 Mtetra
.293 0 .075 r
.50387 .23857 .51045 .22511 .52219 .22191 .51572 .23481 Mtetra
.283 0 .058 r
.51572 .23481 .52219 .22191 .53398 .21882 .52762 .23103 Mtetra
.271 0 .037 r
.52762 .23103 .53398 .21882 .54584 .21586 .53958 .22724 Mtetra
.255 0 .009 r
.53958 .22724 .54584 .21586 .55776 .21299 .5516 .22346 Mtetra
.234 0 0 r
.5516 .22346 .55776 .21299 .56974 .2102 .56367 .21966 Mtetra
.207 0 0 r
.56367 .21966 .56974 .2102 .58178 .20746 .5758 .21584 Mtetra
.172 0 0 r
.5758 .21584 .58178 .20746 .5939 .20475 .58799 .21197 Mtetra
.126 0 0 r
.58799 .21197 .5939 .20475 .60608 .20204 .60024 .20804 Mtetra
.064 0 0 r
.60024 .20804 .60608 .20204 .61832 .1993 .61254 .20402 Mtetra
0 0 0 r
.61254 .20402 .61832 .1993 .63064 .1965 .62489 .19988 Mtetra
.62489 .19988 .63064 .1965 .64301 .19362 .6373 .19561 Mtetra
.241 .741 .671 r
.6373 .19561 .64301 .19362 .65545 .19062 .64976 .19117 Mtetra
.375 .84 .809 r
.64976 .19117 .65545 .19062 .66795 .18748 .66227 .18655 Mtetra
.495 .901 .915 r
.66227 .18655 .66795 .18748 .68051 .18419 .67482 .18176 Mtetra
.587 .917 .971 r
.67482 .18176 .68051 .18419 .69313 .18074 .68742 .1768 Mtetra
.642 .896 .984 r
.68742 .1768 .69313 .18074 .70581 .17715 .70007 .1717 Mtetra
.67 .855 .97 r
.70007 .1717 .70581 .17715 .71855 .17346 .71276 .16648 Mtetra
.68 .808 .944 r
.71276 .16648 .71855 .17346 .73134 .16968 .7255 .16118 Mtetra
.553 .721 .951 r
.05043 .39529 .05808 .40196 .068 .39901 .06017 .39368 Mtetra
.536 .763 .981 r
.06017 .39368 .068 .39901 .07796 .39598 .06996 .392 Mtetra
.507 .801 .999 r
.06996 .392 .07796 .39598 .08798 .39286 .07982 .39024 Mtetra
.46 .828 .993 r
.07982 .39024 .08798 .39286 .09806 .38961 .08975 .38836 Mtetra
.394 .83 .951 r
.08975 .38836 .09806 .38961 .10821 .38619 .09974 .38631 Mtetra
.307 .798 .866 r
.09974 .38631 .10821 .38619 .11841 .38261 .10981 .38411 Mtetra
.209 .733 .746 r
.10981 .38411 .11841 .38261 .12867 .37887 .11995 .38173 Mtetra
0 0 0 r
.11995 .38173 .12867 .37887 .139 .37497 .13015 .37918 Mtetra
.13015 .37918 .139 .37497 .14937 .37094 .14042 .37648 Mtetra
.048 0 0 r
.14042 .37648 .14937 .37094 .1598 .36681 .15076 .37363 Mtetra
.107 0 0 r
.15076 .37363 .1598 .36681 .17027 .36258 .16115 .37067 Mtetra
.155 0 0 r
.16115 .37067 .17027 .36258 .18079 .3583 .17161 .3676 Mtetra
.192 0 0 r
.17161 .3676 .18079 .3583 .19135 .35398 .18212 .36443 Mtetra
.222 0 0 r
.18212 .36443 .19135 .35398 .20195 .34963 .19269 .36118 Mtetra
.245 0 0 r
.19269 .36118 .20195 .34963 .21259 .34527 .20331 .35783 Mtetra
.262 0 .027 r
.20331 .35783 .21259 .34527 .22327 .34091 .21399 .35436 Mtetra
.273 0 .053 r
.21399 .35436 .22327 .34091 .23399 .33655 .22472 .35077 Mtetra
.28 0 .073 r
.22472 .35077 .23399 .33655 .24475 .33218 .23552 .34702 Mtetra
.284 0 .086 r
.23552 .34702 .24475 .33218 .25555 .32776 .24637 .3431 Mtetra
.287 0 .097 r
.24637 .3431 .25555 .32776 .2664 .32322 .25728 .33904 Mtetra
.293 0 .108 r
.25728 .33904 .2664 .32322 .2773 .31849 .26824 .33492 Mtetra
.308 0 .126 r
.26824 .33492 .2773 .31849 .28827 .31345 .27923 .33097 Mtetra
.337 0 .157 r
.27923 .33097 .28827 .31345 .2993 .30807 .29023 .32744 Mtetra
.382 .01 .202 r
.29023 .32744 .2993 .30807 .31037 .30251 .30122 .32485 Mtetra
.427 .069 .252 r
.30122 .32485 .31037 .30251 .32148 .29697 .31218 .32344 Mtetra
.464 .12 .298 r
.31218 .32344 .32148 .29697 .33258 .29198 .32312 .32331 Mtetra
.484 .154 .331 r
.32312 .32331 .33258 .29198 .34369 .28768 .33408 .32407 Mtetra
.48 .162 .35 r
.33408 .32407 .34369 .28768 .35481 .28378 .34515 .32426 Mtetra
.465 .157 .357 r
.34515 .32426 .35481 .28378 .36598 .28007 .35639 .32291 Mtetra
.436 .135 .354 r
.35639 .32291 .36598 .28007 .37721 .27599 .36782 .31885 Mtetra
.403 .106 .343 r
.36782 .31885 .37721 .27599 .3885 .27156 .37943 .31205 Mtetra
.375 .078 .327 r
.37943 .31205 .3885 .27156 .39983 .2673 .39114 .30372 Mtetra
.349 .047 .304 r
.39114 .30372 .39983 .2673 .41119 .26346 .40289 .29479 Mtetra
.339 .025 .278 r
.40289 .29479 .41119 .26346 .42258 .26031 .41462 .28674 Mtetra
.334 .003 .246 r
.41462 .28674 .42258 .26031 .434 .25771 .42633 .27996 Mtetra
.33 0 .21 r
.42633 .27996 .434 .25771 .44549 .25514 .43804 .27438 Mtetra
.329 0 .177 r
.43804 .27438 .44549 .25514 .45704 .25239 .44977 .26973 Mtetra
.322 0 .149 r
.44977 .26973 .45704 .25239 .46865 .24929 .46153 .26551 Mtetra
.315 0 .129 r
.46153 .26551 .46865 .24929 .48033 .24589 .47334 .26146 Mtetra
.305 0 .114 r
.47334 .26146 .48033 .24589 .49207 .24229 .4852 .25735 Mtetra
.294 0 .101 r
.4852 .25735 .49207 .24229 .50387 .23857 .49712 .2531 Mtetra
.28 0 .085 r
.49712 .2531 .50387 .23857 .51572 .23481 .5091 .24867 Mtetra
.264 0 .065 r
.5091 .24867 .51572 .23481 .52762 .23103 .52112 .24407 Mtetra
.244 0 .039 r
.52112 .24407 .52762 .23103 .53958 .22724 .53319 .23934 Mtetra
.22 0 .005 r
.53319 .23934 .53958 .22724 .5516 .22346 .54532 .23449 Mtetra
.19 0 0 r
.54532 .23449 .5516 .22346 .56367 .21966 .55749 .22954 Mtetra
.153 0 0 r
.55749 .22954 .56367 .21966 .5758 .21584 .56971 .22449 Mtetra
.105 0 0 r
.56971 .22449 .5758 .21584 .58799 .21197 .58198 .21934 Mtetra
.044 0 0 r
.58198 .21934 .58799 .21197 .60024 .20804 .59429 .21406 Mtetra
0 0 0 r
.59429 .21406 .60024 .20804 .61254 .20402 .60665 .20866 Mtetra
.60665 .20866 .61254 .20402 .62489 .19988 .61905 .20311 Mtetra
.61905 .20311 .62489 .19988 .6373 .19561 .63149 .19739 Mtetra
.382 .833 .729 r
.63149 .19739 .6373 .19561 .64976 .19117 .64398 .19148 Mtetra
.508 .912 .847 r
.64398 .19148 .64976 .19117 .66227 .18655 .65649 .18539 Mtetra
.608 .948 .926 r
.65649 .18539 .66227 .18655 .67482 .18176 .66905 .17911 Mtetra
.676 .944 .961 r
.66905 .17911 .67482 .18176 .68742 .1768 .68164 .17266 Mtetra
.712 .913 .964 r
.68164 .17266 .68742 .1768 .70007 .1717 .69426 .16607 Mtetra
.726 .869 .948 r
.69426 .16607 .70007 .1717 .71276 .16648 .70692 .15938 Mtetra
.728 .823 .924 r
.70692 .15938 .71276 .16648 .7255 .16118 .71961 .15261 Mtetra
.482 .694 .961 r
.04273 .38856 .05043 .39529 .06017 .39368 .05233 .38795 Mtetra
.462 .722 .981 r
.05233 .38795 .06017 .39368 .06996 .392 .06199 .38728 Mtetra
.435 .748 .993 r
.06199 .38728 .06996 .392 .07982 .39024 .07173 .38653 Mtetra
.401 .768 .993 r
.07173 .38653 .07982 .39024 .08975 .38836 .08153 .38567 Mtetra
.359 .779 .976 r
.08153 .38567 .08975 .38836 .09974 .38631 .09142 .38466 Mtetra
.306 .775 .936 r
.09142 .38466 .09974 .38631 .10981 .38411 .10138 .38349 Mtetra
.246 .754 .874 r
.10138 .38349 .10981 .38411 .11995 .38173 .11142 .38215 Mtetra
.18 .715 .79 r
.11142 .38215 .11995 .38173 .13015 .37918 .12153 .38063 Mtetra
0 0 0 r
.12153 .38063 .13015 .37918 .14042 .37648 .13172 .37895 Mtetra
.13172 .37895 .14042 .37648 .15076 .37363 .14198 .37712 Mtetra
.01 0 0 r
.14198 .37712 .15076 .37363 .16115 .37067 .15232 .37513 Mtetra
.06 0 0 r
.15232 .37513 .16115 .37067 .17161 .3676 .16272 .37302 Mtetra
.102 0 0 r
.16272 .37302 .17161 .3676 .18212 .36443 .17319 .37077 Mtetra
.136 0 0 r
.17319 .37077 .18212 .36443 .19269 .36118 .18373 .36839 Mtetra
.164 0 0 r
.18373 .36839 .19269 .36118 .20331 .35783 .19433 .36588 Mtetra
.183 0 0 r
.19433 .36588 .20331 .35783 .21399 .35436 .205 .3632 Mtetra
.197 0 0 r
.205 .3632 .21399 .35436 .22472 .35077 .21574 .36032 Mtetra
.205 0 0 r
.21574 .36032 .22472 .35077 .23552 .34702 .22655 .35722 Mtetra
.211 0 0 r
.22655 .35722 .23552 .34702 .24637 .3431 .23744 .35389 Mtetra
.219 0 0 r
.23744 .35389 .24637 .3431 .25728 .33904 .24838 .35041 Mtetra
.234 0 0 r
.24838 .35041 .25728 .33904 .26824 .33492 .25938 .34691 Mtetra
.267 0 .012 r
.25938 .34691 .26824 .33492 .27923 .33097 .27039 .34377 Mtetra
.315 0 .058 r
.27039 .34377 .27923 .33097 .29023 .32744 .2814 .34133 Mtetra
.382 0 .117 r
.2814 .34133 .29023 .32744 .30122 .32485 .29237 .34024 Mtetra
.443 .038 .175 r
.29237 .34024 .30122 .32485 .31218 .32344 .3033 .34073 Mtetra
.486 .094 .222 r
.3033 .34073 .31218 .32344 .32312 .32331 .3142 .34268 Mtetra
.506 .126 .254 r
.3142 .34268 .32312 .32331 .33408 .32407 .32515 .34548 Mtetra
.488 .118 .264 r
.32515 .34548 .33408 .32407 .34515 .32426 .33624 .34725 Mtetra
.446 .086 .259 r
.33624 .34725 .34515 .32426 .35639 .32291 .34756 .34679 Mtetra
.371 .02 .234 r
.34756 .34679 .35639 .32291 .36782 .31885 .35914 .34272 Mtetra
.28 0 .196 r
.35914 .34272 .36782 .31885 .37943 .31205 .37094 .33503 Mtetra
.205 0 .156 r
.37094 .33503 .37943 .31205 .39114 .30372 .38287 .32509 Mtetra
.146 0 .114 r
.38287 .32509 .39114 .30372 .40289 .29479 .39485 .31409 Mtetra
.136 0 .086 r
.39485 .31409 .40289 .29479 .41462 .28674 .4068 .30392 Mtetra
.149 0 .062 r
.4068 .30392 .41462 .28674 .42633 .27996 .41871 .29521 Mtetra
.174 0 .041 r
.41871 .29521 .42633 .27996 .43804 .27438 .43058 .28808 Mtetra
.199 0 .022 r
.43058 .28808 .43804 .27438 .44977 .26973 .44245 .2823 Mtetra
.206 0 0 r
.44245 .2823 .44977 .26973 .46153 .26551 .45434 .27723 Mtetra
.204 0 0 r
.45434 .27723 .46153 .26551 .47334 .26146 .46627 .27252 Mtetra
.186 0 0 r
.46627 .27252 .47334 .26146 .4852 .25735 .47825 .26778 Mtetra
.162 0 0 r
.47825 .26778 .4852 .25735 .49712 .2531 .49028 .26289 Mtetra
.13 0 0 r
.49028 .26289 .49712 .2531 .5091 .24867 .50236 .25776 Mtetra
.093 0 0 r
.50236 .25776 .5091 .24867 .52112 .24407 .51449 .25239 Mtetra
.051 0 0 r
.51449 .25239 .52112 .24407 .53319 .23934 .52666 .24682 Mtetra
.001 0 0 r
.52666 .24682 .53319 .23934 .54532 .23449 .53888 .24107 Mtetra
0 0 0 r
.53888 .24107 .54532 .23449 .55749 .22954 .55114 .23518 Mtetra
.55114 .23518 .55749 .22954 .56971 .22449 .56344 .22914 Mtetra
.56344 .22914 .56971 .22449 .58198 .21934 .57578 .22295 Mtetra
.57578 .22295 .58198 .21934 .59429 .21406 .58816 .21662 Mtetra
.38 .822 .685 r
.58816 .21662 .59429 .21406 .60665 .20866 .60058 .21013 Mtetra
.475 .889 .777 r
.60058 .21013 .60665 .20866 .61905 .20311 .61303 .20347 Mtetra
.564 .937 .854 r
.61303 .20347 .61905 .20311 .63149 .19739 .62551 .19662 Mtetra
.637 .962 .909 r
.62551 .19662 .63149 .19739 .64398 .19148 .63803 .18959 Mtetra
.692 .964 .94 r
.63803 .18959 .64398 .19148 .65649 .18539 .65057 .18235 Mtetra
.728 .948 .951 r
.65057 .18235 .65649 .18539 .66905 .17911 .66314 .17495 Mtetra
.749 .921 .948 r
.66314 .17495 .66905 .17911 .68164 .17266 .67573 .16737 Mtetra
.759 .889 .936 r
.67573 .16737 .68164 .17266 .69426 .16607 .68835 .15966 Mtetra
.76 .854 .92 r
.68835 .15966 .69426 .16607 .70692 .15938 .701 .15185 Mtetra
.757 .82 .902 r
.701 .15185 .70692 .15938 .71961 .15261 .71368 .14397 Mtetra
.433 .673 .963 r
.03496 .38178 .04273 .38856 .05233 .38795 .04449 .38176 Mtetra
.42 .689 .974 r
.04449 .38176 .05233 .38795 .06199 .38728 .05408 .38167 Mtetra
.408 .705 .983 r
.05408 .38167 .06199 .38728 .07173 .38653 .06374 .38151 Mtetra
.395 .721 .989 r
.06374 .38151 .07173 .38653 .08153 .38567 .07348 .38124 Mtetra
.382 .736 .991 r
.07348 .38124 .08153 .38567 .09142 .38466 .0833 .38083 Mtetra
.367 .75 .989 r
.0833 .38083 .09142 .38466 .10138 .38349 .0932 .38027 Mtetra
.351 .761 .981 r
.0932 .38027 .10138 .38349 .11142 .38215 .10318 .37955 Mtetra
.33 .768 .966 r
.10318 .37955 .11142 .38215 .12153 .38063 .11324 .37867 Mtetra
.306 .77 .944 r
.11324 .37867 .12153 .38063 .13172 .37895 .12338 .37762 Mtetra
.277 .765 .914 r
.12338 .37762 .13172 .37895 .14198 .37712 .1336 .37641 Mtetra
.246 .754 .876 r
.1336 .37641 .14198 .37712 .15232 .37513 .1439 .37506 Mtetra
.213 .736 .831 r
.1439 .37506 .15232 .37513 .16272 .37302 .15427 .37355 Mtetra
.178 .714 .782 r
.15427 .37355 .16272 .37302 .17319 .37077 .16471 .3719 Mtetra
.146 .689 .731 r
.16471 .3719 .17319 .37077 .18373 .36839 .17523 .3701 Mtetra
0 0 0 r
.17523 .3701 .18373 .36839 .19433 .36588 .18582 .36815 Mtetra
.18582 .36815 .19433 .36588 .205 .3632 .19649 .366 Mtetra
.19649 .366 .205 .3632 .21574 .36032 .20723 .36365 Mtetra
.20723 .36365 .21574 .36032 .22655 .35722 .21805 .36106 Mtetra
.21805 .36106 .22655 .35722 .23744 .35389 .22895 .35824 Mtetra
.22895 .35824 .23744 .35389 .24838 .35041 .23991 .35526 Mtetra
.005 0 0 r
.23991 .35526 .24838 .35041 .25938 .34691 .25093 .35226 Mtetra
.071 0 0 r
.25093 .35226 .25938 .34691 .27039 .34377 .26197 .34962 Mtetra
.157 0 0 r
.26197 .34962 .27039 .34377 .2814 .34133 .273 .34768 Mtetra
.269 0 0 r
.273 .34768 .2814 .34133 .29237 .34024 .28401 .34699 Mtetra
.367 0 0 r
.28401 .34699 .29237 .34024 .3033 .34073 .29498 .34776 Mtetra
.432 0 0 r
.29498 .34776 .3033 .34073 .3142 .34268 .30595 .34976 Mtetra
.459 0 0 r
.30595 .34976 .3142 .34268 .32515 .34548 .31696 .35237 Mtetra
.405 0 0 r
.31696 .35237 .32515 .34548 .33624 .34725 .32814 .35388 Mtetra
.276 0 0 r
.32814 .35388 .33624 .34725 .34756 .34679 .33954 .3532 Mtetra
.019 0 0 r
.33954 .3532 .34756 .34679 .35914 .34272 .3512 .34911 Mtetra
0 0 0 r
.3512 .34911 .35914 .34272 .37094 .33503 .36308 .3416 Mtetra
.36308 .3416 .37094 .33503 .38287 .32509 .3751 .33187 Mtetra
.487 .827 .541 r
.3751 .33187 .38287 .32509 .39485 .31409 .38717 .32103 Mtetra
0 0 0 r
.38717 .32103 .39485 .31409 .4068 .30392 .39922 .31077 Mtetra
.39922 .31077 .4068 .30392 .41871 .29521 .41124 .30174 Mtetra
.41124 .30174 .41871 .29521 .43058 .28808 .42322 .29415 Mtetra
.42322 .29415 .43058 .28808 .44245 .2823 .43519 .28783 Mtetra
.43519 .28783 .44245 .2823 .45434 .27723 .44718 .28221 Mtetra
.44718 .28221 .45434 .27723 .46627 .27252 .45921 .27694 Mtetra
.45921 .27694 .46627 .27252 .47825 .26778 .47128 .27165 Mtetra
.47128 .27165 .47825 .26778 .49028 .26289 .4834 .2662 Mtetra
.4834 .2662 .49028 .26289 .50236 .25776 .49556 .26049 Mtetra
.357 .811 .689 r
.49556 .26049 .50236 .25776 .51449 .25239 .50777 .25454 Mtetra
.417 .854 .742 r
.50777 .25454 .51449 .25239 .52666 .24682 .52003 .24837 Mtetra
.476 .891 .791 r
.52003 .24837 .52666 .24682 .53888 .24107 .53232 .242 Mtetra
.529 .921 .835 r
.53232 .242 .53888 .24107 .55114 .23518 .54465 .23545 Mtetra
.579 .943 .872 r
.54465 .23545 .55114 .23518 .56344 .22914 .55702 .22874 Mtetra
.623 .958 .903 r
.55702 .22874 .56344 .22914 .57578 .22295 .56942 .22188 Mtetra
.662 .964 .926 r
.56942 .22188 .57578 .22295 .58816 .21662 .58186 .21485 Mtetra
.694 .963 .941 r
.58186 .21485 .58816 .21662 .60058 .21013 .59433 .20765 Mtetra
.72 .956 .948 r
.59433 .20765 .60058 .21013 .61303 .20347 .60683 .20027 Mtetra
.74 .943 .949 r
.60683 .20027 .61303 .20347 .62551 .19662 .61935 .19271 Mtetra
.754 .927 .946 r
.61935 .19271 .62551 .19662 .63803 .18959 .63191 .18496 Mtetra
.764 .908 .938 r
.63191 .18496 .63803 .18959 .65057 .18235 .64448 .17704 Mtetra
.77 .889 .929 r
.64448 .17704 .65057 .18235 .66314 .17495 .65708 .16894 Mtetra
.774 .869 .919 r
.65708 .16894 .66314 .17495 .67573 .16737 .6697 .16068 Mtetra
.774 .849 .908 r
.6697 .16068 .67573 .16737 .68835 .15966 .68234 .1523 Mtetra
.773 .83 .897 r
.68234 .1523 .68835 .15966 .701 .15185 .69501 .14381 Mtetra
.77 .811 .886 r
.69501 .14381 .701 .15185 .71368 .14397 .70769 .13525 Mtetra
.426 .67 .963 r
.02714 .37496 .03496 .38178 .04449 .38176 .03666 .37499 Mtetra
.43 .674 .965 r
.03666 .37499 .04449 .38176 .05408 .38167 .04626 .37495 Mtetra
.436 .679 .966 r
.04626 .37495 .05408 .38167 .06374 .38151 .05592 .37482 Mtetra
.444 .684 .967 r
.05592 .37482 .06374 .38151 .07348 .38124 .06567 .37458 Mtetra
.453 .69 .968 r
.06567 .37458 .07348 .38124 .0833 .38083 .07549 .37421 Mtetra
.462 .696 .969 r
.07549 .37421 .0833 .38083 .0932 .38027 .0854 .37371 Mtetra
.471 .703 .97 r
.0854 .37371 .0932 .38027 .10318 .37955 .09538 .37307 Mtetra
.48 .71 .971 r
.09538 .37307 .10318 .37955 .11324 .37867 .10544 .37228 Mtetra
.488 .718 .973 r
.10544 .37228 .11324 .37867 .12338 .37762 .11559 .37134 Mtetra
.495 .725 .974 r
.11559 .37134 .12338 .37762 .1336 .37641 .12581 .37025 Mtetra
.503 .733 .976 r
.12581 .37025 .1336 .37641 .1439 .37506 .1361 .36902 Mtetra
.509 .741 .978 r
.1361 .36902 .1439 .37506 .15427 .37355 .14648 .36765 Mtetra
.516 .749 .98 r
.14648 .36765 .15427 .37355 .16471 .3719 .15692 .36614 Mtetra
.522 .757 .982 r
.15692 .36614 .16471 .3719 .17523 .3701 .16745 .36448 Mtetra
.529 .765 .984 r
.16745 .36448 .17523 .3701 .18582 .36815 .17805 .36266 Mtetra
.537 .774 .985 r
.17805 .36266 .18582 .36815 .19649 .366 .18872 .36068 Mtetra
.545 .783 .987 r
.18872 .36068 .19649 .366 .20723 .36365 .19947 .35851 Mtetra
.554 .794 .988 r
.19947 .35851 .20723 .36365 .21805 .36106 .2103 .35613 Mtetra
.562 .805 .99 r
.2103 .35613 .21805 .36106 .22895 .35824 .2212 .35356 Mtetra
.565 .815 .992 r
.2212 .35356 .22895 .35824 .23991 .35526 .23217 .35084 Mtetra
.561 .824 .995 r
.23217 .35084 .23991 .35526 .25093 .35226 .2432 .34806 Mtetra
.54 .824 .998 r
.2432 .34806 .25093 .35226 .26197 .34962 .25426 .34548 Mtetra
.506 .813 1 r
.25426 .34548 .26197 .34962 .273 .34768 .26535 .34331 Mtetra
.452 .783 .998 r
.26535 .34331 .273 .34768 .28401 .34699 .27645 .34188 Mtetra
.405 .736 .992 r
.27645 .34188 .28401 .34699 .29498 .34776 .28754 .34131 Mtetra
.396 .685 .977 r
.28754 .34131 .29498 .34776 .30595 .34976 .29866 .3414 Mtetra
.427 .637 .944 r
.29866 .3414 .30595 .34976 .31696 .35237 .30983 .34176 Mtetra
.503 .611 .893 r
.30983 .34176 .31696 .35237 .32814 .35388 .32114 .34131 Mtetra
.568 .601 .846 r
.32114 .34131 .32814 .35388 .33954 .3532 .33262 .33939 Mtetra
.63 .61 .811 r
.33262 .33939 .33954 .3532 .3512 .34911 .34429 .33526 Mtetra
.679 .633 .796 r
.34429 .33526 .3512 .34911 .36308 .3416 .35612 .32892 Mtetra
.717 .668 .801 r
.35612 .32892 .36308 .3416 .3751 .33187 .36807 .32109 Mtetra
.748 .713 .819 r
.36807 .32109 .3751 .33187 .38717 .32103 .38008 .31243 Mtetra
.763 .766 .855 r
.38008 .31243 .38717 .32103 .39922 .31077 .39209 .30403 Mtetra
.763 .817 .895 r
.39209 .30403 .39922 .31077 .41124 .30174 .4041 .29628 Mtetra
.744 .854 .931 r
.4041 .29628 .41124 .30174 .42322 .29415 .41611 .28938 Mtetra
.717 .872 .954 r
.41611 .28938 .42322 .29415 .43519 .28783 .42812 .28323 Mtetra
.699 .875 .964 r
.42812 .28323 .43519 .28783 .44718 .28221 .44017 .27749 Mtetra
.69 .87 .966 r
.44017 .27749 .44718 .28221 .45921 .27694 .45225 .27193 Mtetra
.694 .863 .963 r
.45225 .27193 .45921 .27694 .47128 .27165 .46437 .26632 Mtetra
.701 .856 .956 r
.46437 .26632 .47128 .27165 .4834 .2662 .47654 .26055 Mtetra
.709 .848 .949 r
.47654 .26055 .4834 .2662 .49556 .26049 .48876 .25456 Mtetra
.716 .842 .942 r
.48876 .25456 .49556 .26049 .50777 .25454 .50102 .24836 Mtetra
.722 .837 .936 r
.50102 .24836 .50777 .25454 .52003 .24837 .51332 .24196 Mtetra
.727 .833 .93 r
.51332 .24196 .52003 .24837 .53232 .242 .52566 .23538 Mtetra
.732 .828 .925 r
.52566 .23538 .53232 .242 .54465 .23545 .53804 .22863 Mtetra
.735 .824 .92 r
.53804 .22863 .54465 .23545 .55702 .22874 .55045 .22172 Mtetra
.739 .82 .915 r
.55045 .22172 .55702 .22874 .56942 .22188 .5629 .21465 Mtetra
.742 .816 .91 r
.5629 .21465 .56942 .22188 .58186 .21485 .57538 .20742 Mtetra
.745 .812 .905 r
.57538 .20742 .58186 .21485 .59433 .20765 .58789 .20003 Mtetra
.748 .809 .901 r
.58789 .20003 .59433 .20765 .60683 .20027 .60044 .19247 Mtetra
.751 .806 .896 r
.60044 .19247 .60683 .20027 .61935 .19271 .61301 .18475 Mtetra
.754 .803 .892 r
.61301 .18475 .61935 .19271 .63191 .18496 .6256 .17686 Mtetra
.757 .801 .888 r
.6256 .17686 .63191 .18496 .64448 .17704 .63822 .1688 Mtetra
.76 .8 .885 r
.63822 .1688 .64448 .17704 .65708 .16894 .65087 .16059 Mtetra
.762 .798 .882 r
.65087 .16059 .65708 .16894 .6697 .16068 .66353 .15224 Mtetra
.765 .797 .88 r
.66353 .15224 .6697 .16068 .68234 .1523 .67622 .14375 Mtetra
.766 .796 .877 r
.67622 .14375 .68234 .1523 .69501 .14381 .68893 .13516 Mtetra
.768 .795 .875 r
.68893 .13516 .69501 .14381 .70769 .13525 .70165 .12647 Mtetra
.472 .69 .962 r
.01926 .36808 .02714 .37496 .03666 .37499 .02888 .36753 Mtetra
.491 .678 .949 r
.02888 .36753 .03666 .37499 .04626 .37495 .03858 .36687 Mtetra
.507 .666 .934 r
.03858 .36687 .04626 .37495 .05592 .37482 .04834 .36609 Mtetra
.52 .652 .918 r
.04834 .36609 .05592 .37482 .06567 .37458 .05819 .36519 Mtetra
.531 .639 .902 r
.05819 .36519 .06567 .37458 .07549 .37421 .06811 .36418 Mtetra
.54 .627 .887 r
.06811 .36418 .07549 .37421 .0854 .37371 .0781 .36305 Mtetra
.547 .616 .873 r
.0781 .36305 .0854 .37371 .09538 .37307 .08817 .3618 Mtetra
.553 .605 .859 r
.08817 .3618 .09538 .37307 .10544 .37228 .0983 .36044 Mtetra
.558 .596 .848 r
.0983 .36044 .10544 .37228 .11559 .37134 .10852 .35895 Mtetra
.563 .588 .837 r
.10852 .35895 .11559 .37134 .12581 .37025 .1188 .35734 Mtetra
.567 .581 .827 r
.1188 .35734 .12581 .37025 .1361 .36902 .12915 .35561 Mtetra
.57 .574 .818 r
.12915 .35561 .1361 .36902 .14648 .36765 .13958 .35375 Mtetra
.573 .569 .81 r
.13958 .35375 .14648 .36765 .15692 .36614 .15008 .35177 Mtetra
.576 .563 .802 r
.15008 .35177 .15692 .36614 .16745 .36448 .16065 .34967 Mtetra
.579 .559 .796 r
.16065 .34967 .16745 .36448 .17805 .36266 .17128 .34744 Mtetra
.581 .555 .789 r
.17128 .34744 .17805 .36266 .18872 .36068 .18199 .34509 Mtetra
.584 .551 .784 r
.18199 .34509 .18872 .36068 .19947 .35851 .19276 .34261 Mtetra
.586 .549 .78 r
.19276 .34261 .19947 .35851 .2103 .35613 .2036 .34 Mtetra
.589 .548 .777 r
.2036 .34 .2103 .35613 .2212 .35356 .21451 .33726 Mtetra
.591 .548 .775 r
.21451 .33726 .2212 .35356 .23217 .35084 .22549 .3344 Mtetra
.594 .548 .773 r
.22549 .3344 .23217 .35084 .2432 .34806 .23653 .3314 Mtetra
.596 .547 .77 r
.23653 .3314 .2432 .34806 .25426 .34548 .24763 .32827 Mtetra
.597 .542 .763 r
.24763 .32827 .25426 .34548 .26535 .34331 .2588 .32502 Mtetra
.596 .53 .751 r
.2588 .32502 .26535 .34331 .27645 .34188 .27003 .32163 Mtetra
.593 .51 .73 r
.27003 .32163 .27645 .34188 .28754 .34131 .28133 .31811 Mtetra
.587 .484 .705 r
.28133 .31811 .28754 .34131 .29866 .3414 .29268 .31446 Mtetra
.579 .458 .679 r
.29268 .31446 .29866 .3414 .30983 .34176 .3041 .31067 Mtetra
.573 .435 .656 r
.3041 .31067 .30983 .34176 .32114 .34131 .31558 .30675 Mtetra
.568 .42 .641 r
.31558 .30675 .32114 .34131 .33262 .33939 .32712 .3027 Mtetra
.566 .413 .633 r
.32712 .3027 .33262 .33939 .34429 .33526 .33871 .29851 Mtetra
.567 .414 .633 r
.33871 .29851 .34429 .33526 .35612 .32892 .35036 .29419 Mtetra
.572 .423 .641 r
.35036 .29419 .35612 .32892 .36807 .32109 .36207 .28973 Mtetra
.58 .441 .656 r
.36207 .28973 .36807 .32109 .38008 .31243 .37384 .28513 Mtetra
.592 .466 .678 r
.37384 .28513 .38008 .31243 .39209 .30403 .38565 .28041 Mtetra
.604 .495 .703 r
.38565 .28041 .39209 .30403 .4041 .29628 .39753 .27554 Mtetra
.617 .524 .727 r
.39753 .27554 .4041 .29628 .41611 .28938 .40945 .27054 Mtetra
.627 .548 .745 r
.40945 .27054 .41611 .28938 .42812 .28323 .42143 .2654 Mtetra
.634 .562 .756 r
.42143 .2654 .42812 .28323 .44017 .27749 .43345 .26012 Mtetra
.639 .57 .762 r
.43345 .26012 .44017 .27749 .45225 .27193 .44553 .25471 Mtetra
.642 .574 .763 r
.44553 .25471 .45225 .27193 .46437 .26632 .45765 .24916 Mtetra
.645 .577 .764 r
.45765 .24916 .46437 .26632 .47654 .26055 .46982 .24347 Mtetra
.648 .58 .765 r
.46982 .24347 .47654 .26055 .48876 .25456 .48204 .23764 Mtetra
.651 .584 .766 r
.48204 .23764 .48876 .25456 .50102 .24836 .4943 .23168 Mtetra
.655 .589 .769 r
.4943 .23168 .50102 .24836 .51332 .24196 .50661 .22558 Mtetra
.659 .595 .772 r
.50661 .22558 .51332 .24196 .52566 .23538 .51896 .21934 Mtetra
.663 .602 .776 r
.51896 .21934 .52566 .23538 .53804 .22863 .53134 .21296 Mtetra
.668 .61 .781 r
.53134 .21296 .53804 .22863 .55045 .22172 .54377 .20645 Mtetra
.673 .618 .786 r
.54377 .20645 .55045 .22172 .5629 .21465 .55624 .1998 Mtetra
.678 .628 .791 r
.55624 .1998 .5629 .21465 .57538 .20742 .56875 .19301 Mtetra
.684 .637 .797 r
.56875 .19301 .57538 .20742 .58789 .20003 .58129 .18608 Mtetra
.69 .648 .803 r
.58129 .18608 .58789 .20003 .60044 .19247 .59386 .17902 Mtetra
.696 .659 .81 r
.59386 .17902 .60044 .19247 .61301 .18475 .60647 .17182 Mtetra
.703 .672 .817 r
.60647 .17182 .61301 .18475 .6256 .17686 .61911 .16448 Mtetra
.71 .686 .825 r
.61911 .16448 .6256 .17686 .63822 .1688 .63179 .15701 Mtetra
.717 .701 .834 r
.63179 .15701 .63822 .1688 .65087 .16059 .64449 .1494 Mtetra
.725 .718 .843 r
.64449 .1494 .65087 .16059 .66353 .15224 .65722 .14165 Mtetra
.733 .735 .853 r
.65722 .14165 .66353 .15224 .67622 .14375 .66998 .13377 Mtetra
.741 .753 .862 r
.66998 .13377 .67622 .14375 .68893 .13516 .68276 .12576 Mtetra
.749 .771 .872 r
.68276 .12576 .68893 .13516 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`03oko5gol0003ooooo01Gooooo00?o
0000ooooooooool0DOooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`?o_lGO00?o
0000oko5goooool05Oooool00ol0003oooooooooo`1@ooooo`00H?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Looooo`;o0000IOooool00onm`=co_lGOoko5g`02oko5g`03o`000?o4
bmoooooo01Cooooo00?o0000ooooool00000DOooool0063ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo0ol0001Vooooo`?o_L3L0onoaMl00ol0003oa<_O
olC;g`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000J?ooool5okg0g003oko5goo4bmoo000000?o
a<_O5_ooool00ol0003oooooooooo`1>ooooo`00H?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oMgMgolc<c?l000005Oooool3o`0000;ooooo00?o0000ooooooooool0Hoooool00onk_=[o
_L3Lokg0g003okg0g004olC;h?o4bmooa<_Oo`0000;oa<_O00?oaLoRooooooooool05?ooool00ol0
003oooooooooo`1>ooooo`00H?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000004oooool2o`0006Wooooo1?nk_=X3okg0g0?oa<_P00?oa<_Oo`000?o4bml00oo5cn8Foooo
o`03o`000?oooooooooo04gooooo001Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`0?ooooo`?o0000JOooool00oni]mOo^kcJok^lfP04ok^lfP03okg0g?o4bn3oa<_P
00?oa<_P00?o0000olG?h_o5cn800oo5cn8Fooooo`03o`000?oooooooooo04cooooo0022ooooo`;o
0000Joooool3okVge`Co^kcJ00?o`lcQolC;h?o4bn000oo4bn000oo5e>Go0000olG?hP03olG?hP03
ol7Ai_oooooooooo01Cooooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`00
0?oooooooooo06Oooooo1?ni]mL3ok^lfP?o`lcQ0oo4bn02olGDi@03o`000?o5e>GoaLoR00Co`M7V
5?ooool3o`0004gooooo001looooo`?o0000KOooool00ong/mGo^KOGokVge`04okVge`03ok^lf_o3
c>7o`lcQ00?o`lcQ00Koa<_PolGDiOo5e>GoaMCUo`000?o2f^/5ol7AiQOooooo00?o0000oooooooo
ool0B_ooool007[ooooo0_l0001^ooooo`Co]k?E1?ni]mL6ol?<h@;oa]WX0oo5e>D00oo2f^_o0000
ol;Jj`03ol7AiP;o^];/5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`0006kooooo00?o
]JoCokNceOng/mD01?ng/mD00oni]mOo`lcQol?<h@04ol?<h@Goa]WX00KoaMCUol;Jjoo2f^_o0000
ol;Jjoo1dNH5ok[Bk1Kooooo00?o0000ooooooooool0BOooool007Gooooo0_l00002ooooo`03o`00
0?oooooooooo06[ooooo1?ne[m<4okNce@03ol;<h_o3c>7o`lcQ00?o`lcQ0_o6g^/4olKIj005ol;S
koo2f^_o`][[ol;Jjol000000_nig_84ok[Bk003ojk>lOoooooooooo01Gooooo00?o0000oooooooo
ool0B?ooool007;ooooo0ol00005ooooo`03o`000?oooooooooo06Oooooo00?o/jcAokF_done[m<0
0one[m<3okNce@?o`/cR0oo3c>44olKNj`03olKIj?o2hnoo`^?_00;o`^?_00?o`][[okWNl_l00000
0onig_800onjd^co[/kaojk>l@02ojk>lAKooooo00?o0000ooooooooool0B?ooool0073ooooo0_l0
001aooooo`?o/jcA1One[m<00ong/mGo`/cRol;<hP03ol;<hP03ol?<hOo6g^_oa]k[00;oa]k[00?o
_n_bol;Skoo2hnl00_o2hnl2okKYmP04okWNl_l0003o^MkbokWNlP;oZm[h1On^c_4Fooooo`03o`00
0?oooooooooo04Oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000Pooooo`?o0000L_ooool4ok>/d@Co]JoC0_o1cN<4ol;<hP;oaN?]0oo6g^/3oko[lP03ol;S
konfjOKo]^Wf00?o]^Wf00?o0000oj_Jn?n[f_P00on[f_P2ojk>l@;oWlOd5Oooool3o`0004Sooooo
000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00Nooooo`;o00000oooool00ol0003oooooooooo`1]ooooo`03ok:Xconc[=7o/jcA00Co
/jcA00?o]JoCol7=hoo1cN<00oo1cN<00oo2c>;oaN?]olGSk@03olGSk@04olKNjonojo;o_n_boko[
lP?o[O7f0_nfjOH2ojCUn`04o`000?nTiO_oZm[hoj_Jn0;oVm3j1OnOao@Fooooo`03o`000?oooooo
oooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo02Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP0Looooo`?o0000Loooool4ok:Xc`Co/jcA00?o`LgTol7=hoo1cN<00oo1cN<2ol?Xl0CoaN?]0_nj
l_<00onojo;o[O7fojgamP02ojgamP;oU^[h0onTiO/00ol0003oTmWnoi?IoP04oi_@nPGoWlOd5_oo
ool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool0:_ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^01Sooooo0ol0001dooooo`03ok2UcOnbZ<oo/ZS?00?o/ZS?0onc[=43ol7=i0?o`LgS
1?o3j?001?o5hngo^_;cok[blonjl_<3oi_bk@03ojgam_nFj_SoU^[h00?oU^[h00?oY>Gkoi?Io_l0
00000onCfOh4oi_@nP;oWlOd0onA_O@Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go0000:oooool003Sooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo01Gooooo0ol0001dooooo`Co/:G=1OnbZ<l00onc[=7o`LgTol7=i003ol7=
i003ol7=hoo3j?3o`nS`00;o`nS`0_nam_001?njl_?oVo;]oi_bkOnKl^d4ogkVjP;oU^[h1?n6gOd0
0ol0003oTmWnohS8o@02ohS8o@CoS/?i1OnA_O@Eooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002cooooo000hooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`0Aooooo`?o00000oooool00ol0003ooooo
ooooo`1_ooooo`03ojnSc?n`YLgo/:G=00?o/:G=1?nbZ<l2ol3>i@Co`LgT0oo1kO801?o3j?3o/OK`
ok7fl?nam_02oh;Yf0?oGmO?0_mni^X4og?Lm@;oQ]gm0_n2c?l00ol0003oR<SmohS8o@03ohS8o@Co
S/?i0_nA_O@2ohVclAKooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo0000;?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool2o`0007Oooooo0on_Xl`5ok2Uc@03ok:Xcoo0
c^Go`<kU00?o`<kU00?o`LgTol7]l_o1kO800_o1kO82oj?fj003ok7fl?n2jMSoP^WH00?oGmO?0_mL
dn@3og3?oPGoNLko0_n2c?l01?l0003oP/coohS8oOn8b?d2ohNdl`GoR;?b1?n9/o4Fooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000002co
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00kooooo0ol0001hooooo`Co[j?<1?n`YLd00onocnKo`<kUol3>i@03ol3>i@;o_O7b0oo1kO82oj?f
j003of7E^_lm_J_o?Kf[00;o@LC;1?mVcoX4og3?oP;oNLko0_n5/o<2ohJdl`03o`000?n6]??oQ[Cc
00CoQkCc1On8/o84ohVclACooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000/ooooo`00FOooool3o`0007Sooooo00?o[J3:ojnSc?n_Xl`00on_Xl`3ok2U
c@?o_loV0oo0c^D4okgalP03ol7]l_nSm^SoXoKX00;oElca1?mNcOH2ofK?nP;oQ[7a1On5/_<4ohFc
l`03ohJdlol0003oQ[Cc00;oQ[Cc1?n7]?<2ohRclP;oRJ_/1?n8[^hCooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02_ooooo001F
ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co[J3:1On_Xl`00on`YLgo_loVoko?iP03
oko?iP03ol3>iOnmlO;o_O7b00;o_O7b0_n@kmX4ohZ]k@GoR:o_1?n6/O45ohFbl`CoQK?c00Co0000
ohJdlon;Y>GoRjCU1?n:YnP5ohV[k0CoR:k^5_ooool00ol0003oooooooooo`10ooooo`00E?ooool2
o`0007[ooooo00?o[9k9ojfPb_n]X<X00on]X<X4ojnSc0;o_/oW1?nocnH3okSdlP03okgal_n@km[o
T>oJ00?oSJ[Y1?n:[Nd5ohR_k`CoQ[7a0_n5/_<2ohjLg@CoS:3Q00?o0000oh^TiOn;Y>D00_n;Y>D4
ohZWj0CoRJ_/1?n8[^hFooooo`03o`000?oooooooooo043ooooo001Aooooo`?o0000N_ooool4ojbN
b@Go[J3:00?o[j?<okk?ionncnL00onncnL00onocnKo^?CbokSdlP02okSdlP03ogWSa_n?YnGoSjOU
00GoSJ[Y1?n:[Nd2ohR_k`;oT9CD1?n?V=P4ohjLg@CoS:3Q00?o0000oh^TiOn;Y>D00_n;Y>D4ohZW
j0;oRJ_/0_n@YN@5ohj/jQKooooo00?o0000ooooooooool0?oooool004kooooo1Ol0001iooooo`03
oj^Laon/W/Wo[9k900?o[9k91?n]X<X2okg@j0Co_/oW0onam_000onhm?;oTZCQohnWi@04ohnWi@;o
SJ[Y0_nCSLX4oi:Ac`GoT9CD1?n?V=P4ohjLg@?oS:3Q00?o0000oh^TiOn;Y>D00_nBVML4oi6Og@Go
T:GT1On>[>XFooooo`03o`000?oooooooooo03kooooo001<ooooo`;o00001Oooool00ol0003ooooo
ooooo`1dooooo`CoZic71On/W/T00on]X<[o_M3Xokg@j003okg@j003okk?ionam_3o/OK`00;o/OK`
1?nBY>42ohnWi@;oU8[61OnCSLX4oi:Ac`CoT9CD1On?V=P3ohjLg@;oS:3Q00?oTi?Ao`000?nBVML0
1?nBVML4oi6Og@GoT:GT0_n>[>X2oiV_iaKooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0
001jooooo`;o;P0000?oZI[6oj^Laon[W<L00on[W<L4ojbNb@03okgAj_nmd>So_M3X00?o_M3X0onY
m^d00onam_3oU:3MoiJ4_P04oiF7`PGoU8[61?nCSLX4oi:Ac`GoT9CD0_n?V=P2oiB9a@?oU8k;1?nC
Tm400ol0003oTYWGoi:Ie`02oi:Ie`GoTIoM0_n@YN@2oiZWg`GoVJoW5?ooool3o`0003oooooo000R
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool2o`0007[ooooo00?o;`00obh00?l^00001?nY
V/H4oj^La`?o[9k90onmdNX3okg@j0?oZOK]00?oUX6joiJ4__nFQ;h00_nFQ;h4oiF7`PCoU8[61?nC
SLX5oi:Ac`;oT9CD0_nEQL04oiB9a@CoU8k;0onCTm400ol0003oTYWGoi:Ie`03oi:Ie`;oTIoM0_nJ
WmP5oiZWg`GoVJoW5Oooool00ol0003oooooooooo`0mooooo`008_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01gooooo0ol00002ooooo`03o`000?oooooooooo07?ooooo0_l`0003obl00003ojRHaOnY
V/KoZI[600?oZI[61On[W<L00on/W/Wo_M7ZokgAjP03okgAjP03okg@j?nYm^goZOK]00CoUX6j0onF
Q;h4oiF7`PCoU8[61OnCSLX2oi:Ac`;oUX:l1OnEQL04oiB9a@?oU8k;0onCTm401?l0003oTi?Aoi:I
eonBVML2oi^Id@GoVYoH1OnJYml2oiV_i`?oY;GT5Oooool00ol0003oooooooooo`0looooo`008_oo
ool01Ol@413ooooooooooooooooo410@01_ooooo0_l0001gooooo`;o;`000ol`0002obl000CoZ9S5
1?nYV/H4oj^La`;o_=;[1?nmdNX2oioei`;oUWng1?nFPKX3oiJ4_PCoUHO21OnDR/H2oi>=bP;oUWng
1OnFP[`4oiF5`0CoU8W51?nDS//2oi>Cd@03o`000?nKTl_oViWA00CoViWA1OnJWmP2oiZWg`;oY:cM
1_nT]N@Eooooo`03o`000?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool00000
6?ooool3o`0007Kooooo00?o<P00obl00?l_00000_l_0002oc000003obl00?nWU/CoZ9S500CoZ9S5
1OnYV/H00on[W<Oo_=;[okcBj`03okcBj`03okgAj_nOmNOoWoGW00CoUWng1?nFPKX4oiJ4_PCoUHO2
0_nDR/H2oiIl]0GoUWng1?nFP[`4oiF5`0CoU8W50_nDS//2oi^>a@;oVi?;00?o0000oi^CbonKTl/0
1?nKVM44oiZOf003ojBTe_nT[=goY:cM00?oY:cM1?nT]N@00on__>?oooooooooo`0Cooooo`03o`00
0?oooooooooo03_ooooo000Rooooo`05o`000?ooooooooooooooool000005_ooool3o`0007Cooooo
0_lf0003oc8000?o;`0000?o<000odl06?nWU/@00onWU/@4ojRHa@CoZI[60_nkdn`4okcBj`;oU?7O
0_nFO;D4oiIo]`GoUX6j0onFQ;h2oiF7`P;oUgVa1OnFO;@4oiIo]`CoUX:l1OnEQL02oiB9a@03oib9
_onKS/GoVhk500?oVhk500CoVi?;o`000?nKTl_oVi?;1OnKVM400onJWmSoY:CFojBTeP02ojBTePGo
Y:cM00?oY;GTojnlhon__><00_n__><Eooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@
4?ooooooooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0GOooool00olP003o
>P00ocX00002ocX000?oBP002Oooool2ocl000?o=P000olb00001Ol_003oD@0Koe406om?01SoYYG4
00GoYiK41OnXV<D00onYV/Ko^m?/ok_Ck003ok_Ck004okcBjonDlMooU?7OoiIj/P?oUWbe1OnFOkL4
oiJ1^P;oUXBn00?oUgN^oiMi/OnGNK400_nGNK45oiIl]0CoUWng1OnFP[`3oiF5`003oib6^onLRKoo
W8Vo00;oW8Vo1?nKS/D00onKTl_o0000oi^Cb`02oi^Cb`;oViWA0_nTW/l5ojBTePCoY:cM00?o[kGM
ojnlhon__><00on__><Fooooo`03o`000?oooooooooo03Wooooo000Rooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04?ooool3o`00067ooooo0_l00002ob0000Co>P000om:0004odd000?oBP001?lo0003
ocH00003oc800?mF023oEP0P00?oD@0K1?nVUL@4ojNFa0CoZ9S50_njeNh4ok_Ck0;oQn_E0onFN[83
oiIl]@GoUWng0_nFPKX2oiMe[0CoUgN^1?nGNK44oiIl]0GoUWng1?nFP[`00onEQL3oW8Jkoib6^`02
oib6^`?oW8Vo1?nKS/D01OnKTl_o0000oi^CbonKTl_oY9S900GoY9k?1OnTY=H00onT[=go[kGMojne
g@02ojneg@?o[kcS0_nga>@Dooooo`;o0000>oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0>ooooo`;o0000HOooool4o`000003ob000?m[6e?oJQUA00?oJQUA0omY5D`4ofP@A@?oIPXl1?mQ
0C43oe`09`CoEP0P00?oD@0KojFD`onVUL@01?nVUL@5ojNFa003ojRHaOnjeNko^]G^00?o^]G^00Co
^m?/ohO[eOn7jmGoUWV`1?nFN[84oiIl]@?oUWng00?oUW>YoiMe[?nGMJ`00_nGMJ`4oiMg[PCoUgVa
1OnFO;@4oiIo]`;oUX:l0_nLPkL5oib6^`?oW8Vo1OnKS/D00ol0003oY9S9ojBHb@02ojBHb@CoY9k?
1?nTY=H00on^[mSo[kGMojneg@04ojneg@03ojnlhonga>Co]lCT00;o]lCT5Oooool00ol0003ooooo
ooooo`0hooooo`00<_ooool5o`00063ooooo0_l00002of`LE0?oJa]C1?mZ6E43ofTEC0CoJ1150omV
2S`4of41<@?oG00W0omF0204ojFD``CoYYG41?nWU/@2okSFk`Co^]G^0_mii<X3oiIi/0GoUWZb0onF
O;D01?nFOkOoUW>YoiIcZOnFLjT5oiMe[0?oUgN^1?nGNK45oiIl]0;oUWng0_nLP;@5oib3]`CoW8Jk
1?nLRKl2oi^>a@03ojBDa?l0003o000000CoY9S91OnTW/l00onTY=Ko[ZoHojj_f002ojj_f0Co[kGM
00?o^<;RokO4i?nga>@00_nga>@00onjbNKoooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo
000`ooooo`;o0000Hoooool00om^eZ?oK1]Bof`LE003of`LE0?oJa]C0omZ6E44ofTEC0?oJ1150omV
2S`4of41<@?oG00W00?oEP0PojFC`onUTl<01OnUU<<5ojJEa003ojNFa?nhe^oo^=K_00?o^=K_00Co
^]G^ogWTb_mii<[oUGN_1?nFNK05oiIj/P;oUWbe00?oUW:XoiIcZOnFLjT00onFLjT4oiMe[0CoUgN^
1?nGNK43oiIl]003oian/OnLP;CoW82d00;oW82d1OnLPkL5oib6^`;oW8Vo00KoY930o`000?l0003o
0000ojBDa?l00005ojBHb@;oY9k?0_n^Z]<6ojj_f003ojnegOnh`^;o^<;R00;o^<;R00?o]lCTok[9
i_njbNH00_njbNHEooooo`03o`000?oooooooooo03Oooooo000]ooooo`?o0000I?ooool00om^eZ?o
K1]Bof`KDP04of`LE0;oJa]C1?mZ6E43ofTEC0CoJ1150omV2S`4of41<@03oe`09onTT/?oYI?300Co
YI?31?nUU<<4ojJEa0;o]mOa1?nhe^l00omZf[goUWN^oiEg[`02oiEg[`GoUWV`0onFN[801?nFL:Ko
UW:XoiIbZ?nFLZP5oiIcZ@CoUgF/1?nGMjh4oiMi/@04oiIl]?nLO[7oW7jaoian/@GoW82d1?nLPkL5
oib6^`?o000000?oY930ojBDa?nTU<@00_nTU<@01Ol0003oY9S9ojBHbOnTV<Wo[jK?00Go[Z[C1?n^
[mP00onh`>3o^<;RokS2hP02okS2hP03okc=ionjbNKo^/WV00Co^/WV5Oooool00ol0003ooooooooo
o`0fooooo`00;?ooool2o`0006Gooooo00CoJ1E<of`KD_m/6e;oK1]B0om/75@3of/KD`CoJQUA0omY
5D`3ofP@A@CoIPXl1?mQ0C43ojBB``CoYI?31OnUU<<00onVULCo]mOaokOGl@03okOGl@03okSFkonF
MjkoUWN^00;oUWN^1?nEMjl4oiIi/004oiIj/_nFL:KoUW2VoiI`YPCoUW:X1?nFLjT4oiMe[0CoUgN^
0onGNK400onLO:ooW7jaoian/@03oian/@CoW82d1OnLPkL01?nLQ[_o0000o`000?l00004ojB@`0Go
Y9C400?o0000ojnVcon_Y/l00_n_Y/l5ojjZd`03ojj_f?nh`>3o^<3P00;o^<3P0_nh`^83okc=i`Co
^/WV0_nic^XEooooo`03o`000?oooooooooo03Gooooo000/ooooo`?o0000H_ooool3ofPEC0;oK1]B
1?m/75@3of/KD`?oJQUA1?mY5D`3ofP@A@?oIPXl0_mQ0C400omD03GoXi73ojBB``03ojBB``CoYI?3
1?nUU<<2okGIlPCo]mOa00?oFln`oiMg[OnFMjh00onFMjh4oiEg[`;oUWV`0_nEKjD5oiI`YP?oUW:X
1?nFLjT5oiMe[0CoUgN^00?oUgVaoial[onLO:l01OnLO[44oib0]0?oW8>g0ol00004ojB=_0?oY930
1?nTU<@00on_Xlco[jK?o`000003ojnVc`Co[Z[C00?o^L3OokS0h?nh`>000onh`>000onh`^;o_<gW
okc=i`03okc=i`03ok[9i_nic^[o^LkZ00?o^LkZ5?ooool00ol0003oooooooooo`0eooooo`00;?oo
ool01?l0003oooooo`000?l0001Pooooo`CoJ1E<0_m/6e84of`LE0;oJa]C1?mZ6E44ofTEC0?oJ115
00CoIPXloeD0?_mE03koE00e1?nSTL<4ojBB``CoYI?300?oYIC3okGIl_nefO800onefO800ongeo7o
Fln`oiMg[@02oiMg[@CoUWN^0_nEMjl2oiA]X`CoUFnU1OnFL:H3oiIbZ0CoUW>Y1OnGMJ`2oiMg[P;o
W7Z]1?nLO:l4oian/@CoW82d0ol000000onLPkOoY8^jojB=_004ojB=_0CoY93000?oY9C4ojnSc?n_
Xl`00_n_Xl`00ol0003o[jK?ojnVc`02ojnVc`03ojjZdoni`=oo^L3O00;o^L3O0onh`>02okgAj@Co
_<gW0_njf>l4okW>jP03ok7=k_oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool0
02cooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00CoH@]2ofPEC?mX5DcoJ1E<0om/6e83
of`LE0?oJa]C1?mZ6E43ofTEC0;oJ11500?oEPI7oeD0?_mE03h00_nRSl45oj>A``CoY9;30onUTl<3
ok?Km0?o]MWb00?o0000oiQh[OnGMjd01?nGMjd2oiIg[P03oi=/X_nDKJ?oU6fS00;oU6fS1OnEKjD4
oiI`YP?oUW:X1OnFLjT3oiMe[003oiahZonLNZgoW7Z]00;oW7Z]1?nLO:l4oian/@06oib0]?l0003o
0000o`000?nLP;CoW8>g1?nTRkX4ojB=_0?oY93000?o[j79ojnSc?n_Xl`00on_Xl`01On_Y/oo0000
ojnVcon_Y/oo^l7N00Ko^L3O00?o^<3PokgAjOnmdNT00_nmdNT00onlcNOo^]S_ok[Hk`03ok[Hk`03
okW>j_nacNko/Lg^00;o/Lg^5Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Iooooo`00:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo0_mQ2d83ofPEC0;oK1]B1?m/75@3of/K
D`?oJQUA0_mY5D`2oeT<C@;oEPI700?oX8bnoj:?`OnRSl400onRSl44oj>A``GoY9;300?oYI?3ok?K
m?ncfo@00oncfo@00onefO;oV7R]oiQh[@02oiQh[@CoUgN]00?oUWN^oi=/X_nCK:801?nDKJ<5oiE_
Y@CoUW2V0onFLZP5oiIcZ@04oiMe[?nLN:_oW7R[oiahZ`GoW7Z]0onLO:l3oian/@;o00000onLP;@0
0onTRKOoY8^jojB;^P03ojB;^PGoY8fl00CoY930ojnQbOn_XLWo[j791On_Xl`00on_Y/oo0000ok_1
gP02ok_1gPCo^L3O00?o_]O/okgAjOnmdNT00_nmdNT2okWRm0Co^]S_00?o/=Seok7=k_nacNh00ona
cNhEooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000006Oooool002_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Gooooo`03oeH0=OmQ2d;oH@]200CoJ1E<0_m/6e84of`LE0;oJa]C0_mZ6E42oelCD`CoF@a=
1?nPS;h4oj:?`@GoXi730onTT/<3ok7LmP;o/m_d0onJN:`4oiQh[@;oUgN]0_nCJj83oi=/XPGoU6fS
1?nEKjD4oiI`YPCoUW:X0onFLjT00onKMjWoW7R[oiahZ`03oiahZ`CoW7Z]0onLO:l3o`0000;oW7ja
00?oW82dojB9]onTRKL00_nTRKL4ojB;^PCoY8fl00?o/:37ojnQbOn_XLT00_n_XLT4ojnSc003okc3
gonk`Mko000000Co^l7N00?o^L3OokkGk?nnen`00_nnen`00onmdNWo^N;dokWRm003okWRm003ok[H
kon`f?Go/=Se00;o/=Se0_nacNh3ojO8lAGooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Go
oooo00?o0000ooooooooool0EOooool2oeH0=@;oH@]20omX5D`3of`KDPCoK1aD00?oJa]CofLKEomO
4e<00omO4e<2oeT<C@03oif6^_nPS;koX8bn00?oX8bn1?nRSl45oj>A``03ojBB`onag?Ko/Mcf00;o
/Mcf0_nHMJX5oiYh[0;oV7R]00?oU6bQoi=[X_nCJj800_nCJj84oi=/XPCoU6fS1?nEKjD5oiI`YP?o
UW:X00CoUW>Yoi]gZOnKMjWoVgNY1OnLN:/4oiaj[@?o000000GoW7b_oian/OnLO[7oW7jaojB7]P05
ojB9]`GoY8^j0_nTSK`3ok2Pa`?o[j790on_Xl`3okc3g`05ok_1g_l0003o^l7Nok_1g_nng^l01?nn
en`3ok?/m`;o^N;d0on[h_X2ok3Hm@?oXm7g1OnWb?4Eooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool002_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Cooooo`;oEP0e0omQ2d83ofPEC0?oK1]B
0om/75@00om[6e?oIa]GofLKE`04oelCD`CoWHJj1?nPS;h5oj:?`@;oXi731?n`g_L00onag?KoV7FZ
oiQeZP03oiQeZPCoVWR/00?oV7R]oiA/XOnDK:401?nCJj84oi=/XPCoU6fS1?nEKjD5oiI`YP;oUW:X
00?oVgJXoi]gZOnKMjT00onKMjT4oiahZ`04oiaj[Ol0003o0000o`0000CoW7b_00?oW7jaojB7]_nT
QkH00_nTQkH4ojB9]`GoY8^j00?oY8flok2Paon`X<L00_n`X<L4ojnQb@03ojnSc?nl`moo_<?O00?o
_<?O00?o^l7No`000?nng^l00_nng^l00onnenco/ncgok?/m`02ok?/m`;oWN[j0on[h_X2oicIo0Go
Xm7g0_nWb?42oig0lAGooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool06oooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1@ooooo`04odP09_mF03GoEP0eoeH0=@;oH@]21?mX5D`2of`KDP;oK1aD0_m_8UX3ofLK
E`;oGa=C00?oVWjcoif6^_nMQ[X00onMQ[X5oj2<_P?oXXo10_nbgoH4ok3Nm`;oUG6X1OnHMJX2oiYh
[0;oUVfQ0onDK:45oi=[XP?oTfbR1?nDKJ<5oiE_Y@CoUW2V00?oUW:Xoi]fZ?nKMZP01OnKMjT2oiah
Z`?o00001?nLNZd2oial[`03ojB6]?nTQkKoY8Nf00?oY8Nf1OnTRKL3ojB;^P03ok6Oa_n`X<Oo/:37
00?o/:370on_XLT2okk7h@Co_<?O0_nmio<00onng^oo0000okkNk`03ojGbl`03ok?/monMj_[oWN[j
00?oWN[j00?oZn;joicIo?nLfO`00_nLfO`2oj?Am`?oV/?d1?nM`?4Cooooo`?o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06oooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1=ooooo`?oB00V0omF03D2of4;@P?oJ1E<0_m/6e80
0omg:5_oKb9JoflRFP02oflRFP;oIa]G00?oUgN]oiYn/onJO[<00_nJO[<4oif6^PGoX8bn00?oXXo1
ok;Om_nbgoH00onbgoH00on`g_OoT6bUoiEaZ003oiEaZ0?oV7FZ00?oUVbPoiI]XOnFKJ400_nFKJ44
oiA/X@CoTf^R0onCK:84oiA]X`GoUFnU0onFL:H00onKMJOoVgJXoi]fZ002oi]fZ0?oVgNY0ol00002
oiahZ`GoW7Z]00?oW7b_ojB6]?nTQ[@01OnTQkH5ojB9]`03ojB;^_naWlKo/Io600;o/Io61On`X<L0
0on_XLWo_/OQokk7h@02okk7h@03okc3gonmio?o_NOc00?o_NOc00?o0000ojGblonUl_<01?n3inh2
oigZnP?oT=gn0_nLfO`3oiK6n0GoV/?d1?nM`?4Eooooo`09o`000?ooooooooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol0
003oooooooooo`1;ooooo`?oB00V0omF03D3of4;@P;oJ1E<00CoNRUIogLXFomg:5_oMbQK1?m_8UX3
oiMg[@CoVWjc1OnMQ[X3oj2<_P;o]mod1?nbgoH4oi1/Y@?oUG6X00CoV7FZoiI/X?nFK:3oUVbP1?nF
KJ44oiA/X@CoTf^R0onCK:85oiA]X`CoUFnU00CoUW2Voi]eYonKMJOoVgFW1?nKMZP3o`000003oi]g
ZOnLN:_oW7R[00?oW7R[0onLNZd00onTQ[?oY8JdojB6]002ojB6]0GoY8Nf0onTRKL00onaX<Ko/Io6
ok6OaP03ok6OaPCo/:3700?o`LkUokk7hOnnan400_nnan43okOam0;o_NOc00GoQ^_NoeSBcomHd/oo
0000oeSBc`02oh?WkP?oNmck0_n@gOh3oi37nPGoU/Kh0_nJ`o@2oiNfk@CoV;S^5Oooool00ol0003o
ooooooooo`0_ooooo`002?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo00?o0000od006_m8
02H00_m802H3oeH0=@;oH@]200CoJ1E<ogXYFOmj:EWoNRUI0omg:5/00om_8U[oU72WoiA`Y`05oiMg
[@?oVWjc1OnMQ[X00onPS;ko]modokOOm003okOOm003ok;Om_n<Ij?oT6bU00CoT6bU0_nELJP00onF
JikoUVbPoiI/X002oiI/X0CoUVfQ1?nDK:44oi=[XPCoTfbR1?nDKJ<3oiE_Y@03oiYdY_nKMJOoVgFW
00?oVgFW00?oVgJXo`000?l000001?nKMjT5oiahZ`04oiaj[OnTQ[?oY8JcojB6/`CoY8Jd1OnTQkH0
0onTRKOo/J36ok6PaP02ok6PaPGo/Io600?o/:37ol7>iOo1c^D00_o1c^D00onnan7o]o7dokOam002
okOam003oe?;/?l0003oAlKQ00?oAlKQ00CoH]C`o`000?n6`__oQ/;k1On:aO/4oi37nP;oU/Kh0_nF
/^/5oiNfk@CoV;S^5Oooool00ol0003oooooooooo`0^ooooo`004?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04Kooooo00?o0000od006_m802H00_m802H4oeH0=@03of4;@_mk9eCoNRUI00?oNRUI
00?oMbQKoi9/Y?nDL:L00onDL:L5oiMg[@CoVWjc0onMQ[X2okkJkPCo]mod1?n<Ij<4oi1/Y@03oiEa
Z?nFJikoUV^N00GoUVbP0onFKJ44oiA/X@CoTf^R1?nCK:84oiA]X`04oiE_YOnJM:KoVWBVoiYdYP?o
VgFW0ol00002oi]fZ0GoVgNY0onLN:/00onTQK?oY8JcojB6/`03ojB6/`?oY8Jd1?nTQkH00onbXLOo
/J36ok6PaP03ok6PaPCo/Io60_o2enT3ol7>i@?oYoG^00?o]o7doe?;/?mCbk000on6]?<3ohBln@03
ohK2nol0003oQ/;k00;oQ/;k0_n:aO/2oiBWh`GoUJkW1?nF/^/4oiNfk@;oV;S^0onJ]N/Eooooo`03
o`000?oooooooooo02gooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgo
EEEEooooool00006ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@oooool01?l0
003o?@0Dod006_m001X3odP09P03oeH0=Omf7TcoMQi<00?oNbMD0omj:ET3oi9/Y0GoU72W1?nGMjd4
oiYn/`03oif6^_nnf^ko_][^00?o_][^00Co]modohaVXOn<IZ7oS6JQ0on<Ij<3oi1/Y@04oi=WW?nF
JikoUV^NoiI[WPGoUVbP1?nFKJ43oiA/X@GoTf^R0onCK:82oiA]X`;oVG:V1?nJM:H3o`0000;oVgFW
0onKMZP5oi]gZ@04oiahZonTQK?oY8FcojB5/`GoY8Jc1?nTQ[@2ojB7]P?o/Z771OnaX<H00onaWlKo
`]OYol;Gj@03ol;Gj@04ol7>iOnWmNkoYoG^ojOekP?oRJW[1On6]?<3ohBln@04ohK2nol0003oU9oK
oiBOf`GoU:OS1OnE[^L3oiJbj`;oUkK]0onJ/>L5oiZejaCooooo00?o0000ooooooooool0;Oooool0
013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000?
ooooo`;o0000@?ooool00ol:003o0000ocd05002ocd050;o@00J00?oB00VofdA@?mf7T`00omf7T`3
og/WE003ogXYFOnAJJ;oTVbT00CoTVbT1?nDL:L4oiMg[@CoVWjc0_o3dND3okkJkP03ohiWXOn<IZ7o
S6JQ00;oS6JQ0on<Ij<01?n@K:GoTfNLoi=WW?nCIi`4oiI[WPCoUVbP1?nFKJ43oiA/X@GoTf^R0_nC
K:800onHLJGoVG:VoiUbYP02oiUbYP05oiYdY_l0003o0000o`000?nJM:H01?nKMJL4oi]fZ0?oVgNY
00?oY8JcojB5/onTQK<00onTQK<4ojB6/`CoY8Jd00?oY8Nfok:QaonbXLL00_nbXLL4ok6PaP;o`^C_
1?o2enT2oh?Yd`03ojOek_n>W]koRJW[00CoRJW[0_n6]?<2oiJ?bP?oUIOC0_nDWm/00ol0003oU9oK
oiBOf`05oiBWh`;oUJkW0_nKY=`4oiZZhPGoV[3W0_nJ]N/2oj2fj1Gooooo00?o0000ooooooooool0
;?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`;o2P0000Co?@0Aocd05?lm01Co
?@0D0_m001X00om802KoKA50ofdA@004ogHNC0;oT6VR0onAJJ85oi9/Y0CoU72W1OnGMjd2oiYn/`Co
`m7U00?o_][^ohiWXOn>Ij401?n<IZ42ohaWX`03oi1TVonCIicoTfNL00;oTfNL1?nFJih4oiI/X0Co
UVfQ1?nDK:44oi=[XP03oi=/X_nHLJGoV76U00;oVG:V0ol00004oiYdYPCoVgFW1?nKMZP01?nKMjWo
Y8JcojB6/onTQ[<5ojB5/`GoY8Jc0_nTQ[@00oncY<Wo/Z77ok:Qa`03ok:Qa`?o/J361?o2i>l01?o2
enWoPnWCoh?YdonBTm44ohjNgP;oRJW[0_nGR<44oiJ?bPCoUIOC0_nDWm/00ol0003oU9oKoiBOf`02
oiBWh`;oW9kE1OnKY=`4oiZZhP;oV[3W0_nP[n85oj2fj1?ooooo0_l0000^ooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Sooooo00?o3@00o`X00?l:00000_lm0142ocd050;o@00J00?oH@8c
ofdA@?m]4D000_mf7T`00onAJjCoT6VRoi1YXP02oi1YXP?oTFVR1OnBK:@4oiA`Y`GoUgN]00?oVWjc
ol?AiOo3dND00_o3dND01?nBJZ7oSVNQohiWXOn>Ij42ohaVX@;oSV:I0on@I9/5oi=WW0?oUV^N1?nF
K:04oiI]X@CoU6bQ0onCJj800onGL:GoV76UoiQaY@03o`0000?oVG:V1?nJM:H5oi]eY`?oVgJX1OnT
Q[<4ojB5/`GoY8Jc00CoY8Jdok>TbOncY<Wo/jC91OnbXLL00onaX<Ko`^C_ol;Tk`02ol;Tk`05o`00
0?nBTm7oTY?Aoi:CdOnJO[801?nIP[T5oiN8`@CoUXo:1?nEUm<01?nDWm_o0000oifHc_nMV<h4oibN
e@GoVjCL0_nJZ^82oj6Xg0GoX:oR1?nP]^PEooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o
00005?ooool00ol0003oooooooooo`0dooooo`05o`X00?l=003o3@00o`X00?lo01400_lm0143ocd0
50?oH@8c0_m]4D03oi5[Y0CoT6VR1?nAJJ84oi9/Y0GoU72W0onGMjd2ol?4fP?o`m7U0_nBJZ42ohiW
X@03ohiQVOn>HYWoSV:I00;oSV:I0on@I9/5oi=WW0?oUV^N1?nFK:04oiI]X@CoU6bQ00?oTf^RoiM`
YOnGL:D00ol00002oiQaY@CoVG:V1?nJM:H5oi]eY`;oVgJX00?oYHJdojB6/onTQ[<00onTQ[<5ojB5
/`?oY8Jc00?o]:O<ok>TbOncY<T00_ncY<T4ok:Qa`?o_?7c00?o`^C_oiF:aOnER/D00_nER/D00onB
Tm7oVWjboiYn/P05oiV2^@CoUhS11?nFSlX2oiFGd`;oWY;70_nMV<h00ol0003oWIS>oifHcP04oibN
e@?oVjCL00?oXZ?Foj6Xg?nQZ=`00onQZ=`5oj2_hP;oX;KX0_nW^^LEooooo`03o`000?oooooooooo
02[ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool2o`X00003
o`d00?m000oo?`0A00;o?`0A0_lm01400olm01CoEP0Xof42<`02of42<`03ofdA@?nBKjOoTF^T00?o
TF^T1?n@JJ84oi5YXPCoTVbT1OnDL:L00onGMjgo`lCJol?4fP03ol?4fP04ol?AiOnBJZ7oSf:IohmR
V@?oSV6I1?n>HYT4oi1TV`CoTfNL0onFJih5oiI/X0?oUVfQ0_nDK:42oiQaY@04oiM`YOl0003o0000
oiM`Y@CoV76U1?nILZH5oiYdYPCoVgFW00CoVgJXojF6]?nUQ[CoYHJd1?nTQ[<5ojB5/`03ojB6/ond
Ylco]:O<00;o]:O<1?ncY<T00onbXLOo_?7cokcal`02okcal`;oUh>k0_nER/D2oiaj[@CoVWjb1?nI
P[T5oiN8`@;oUXo:00?oX8g1oijBaonNT/L00onNT/L2oifHcP03o`000?nMV<koW9kE00?oW9kE00?o
VjCLoj:Se_nRXmH00_nRXmH5oj6Xg0;oX:oR0_nX]N85ojNjiaCooooo00?o0000ooooooooool0:_oo
ool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0^ooooo`03o`<00?l:003o
2P0000?o@00?0_lo0143ocd04@;oEP0X0_nDMJd3oi9_Y`GoTF^T0on@JJ84oi5YXPGoTVbT0onDL:L0
0ono]]7o`lCJol?4fP03ol?4fP03oi1SVOn?HYWoSf:I00;oSf:I0on>HIT4ohiRV@CoT6BK1?nCIi`3
oiI[WPGoUVbP0_nFKJ400onJLZGoV76UoiQaY@03o`0000CoUg2U0onHLJD4oiUbYPGoVWBV0onKMJL0
0onUQkCoYHJdojF6]002ojF6]0GoY8Jc0onTQK<00one[=3o]:O<okBWc003okBWc0?o/jC90onXmn/0
1OnllO?oUh>koiN3^onGPk_oWGRY00CoW7Z]1?nJO[84oiV2^@CoUhS100?oXXZkoj2=`OnPSL400_nP
SL44oijBa`?oWIS>00Go0000oifHc_nLW]GoW9kEoj>Mc`05oj:SePCoXJSL00?oZK7MojReh_nX]N80
0onX]N83ojNji`;o[L3W5?ooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02[ooooo00Go0000o`<00?l3003o2P00ocl03@03od003`;o?`0A
00Co?@0Aodh08?nFNkCoUW^d1?nDMJd3oi9_Y`GoTF^T0on@JJ84oi5YXPGoTVbT0_nDL:L3oknfd@?o
`lCJ0_n@HiT4ohmRV@?oSV6I1?n>HYT4oi1TV`CoTfNL1?nFJih4oiI/X003oiI]XOnJLZGo000000;o
00000onHLJD4oiM`Y@?oV76U1OnILZH4oiYdYP04oi]eYonUQkCoYHNdojF7]0CoYHJd1OnTQ[<00onT
QK?o]Jc@okF/d002okF/d0Go]:O<00?o/jC9ojSgjonXmn/00onIOK<01?nGPk_oWGRYoiehZOnMN:T5
oiaj[@?oVWjb1OnIP[T00onGR<7oXXZkoj::^`02oj::^`?oX8g11OnNT/L2oifHcP03o`000?nUVLWo
Xig?00?oXig?1OnRXmH00onQZ=coZK7MojVag@02ojVag@CoZ;GR00?oYk[Wojg0ion]`>L00on]`>LD
ooooo`03o`000?oooooooooo02Sooooo000Yooooo`?o00005oooool00ol0003oooooooooo`0Xoooo
o`03o`000?l3003o?00800?o?`0=0_m000l00olo017oB`0KoiN2^P04oiIk]0GoU7F]0onBKjL4oi5[
Y0CoT6VR0onAJJ85oi9/Y003oiA`Yono]]7o_kKA00?o_kKA00Co`lCJoi1SVOn@HiWoT6>I1?n?HYT4
ohiQV@?oSV:I1?n@I9/4oi=WW0CoUV^N0onFK:03o`000003oiYbYOnHLJGoV76U00?oV76U1?nGL:D3
oiQaY@GoVG:V0onJM:H00onUR;KoYHNdojF7]003ojF7]0CoYHJd0onTQ[<00onf/]Go]Jc@okF/d003
okF/d0Co]:O<00CoO>G8oiYi[OnJNJgoVWV]0_nIOK<00onNMjKoWGRYoiehZ@03oiehZ@CoW7Z]1?nJ
O[83oiV2^@03ojB7]_nRR[_oXXZk00?oXXZk0onPSL44oijBa`06ojNGaOnUVLWoYIW9ojFIbOl0003o
YIW91?nSWLl2oj:SeP;oZjgI1OnY/Md2ojRehP?o[kkU1?n]`>L00on`aNWoooooooooo`0Aooooo`;o
0000:_ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`;o0000
0oll00P2ocl03@03od003onHQl3oV8O000?oUh:j1OnFNk@4oiAe[@?oTVnW1?nAJj@4oi1YXPCoTFVR
0onBK:@00ongZlgo_kKAoknfd@04oknfd@04oi5TVon@HiWoT6>Ioi1SV@CoSf:I1?n>HIT3ohiRV@Co
T6BK1?nCIi`4oiI[WP?o000000?oWGBUoiYbYOnJLZD00_nJLZD4oiQaY@CoUg2U1?nHLJD4oiUbYP03
oiYdY_nUR;KoYHRf00;oYHRf1?nUQk@4ojF6]003ojB6/onf/]Go][;E00;o][;E1One[=000ondYlco
O>G8ogcUb004oiYi[@03oiUm/onNMjKoWWNV00GoWGRY1?nLNZd4oiYn/P03oiV2^OnTQkKoY8Nf00;o
Y8Nf1?nRR[/4oj2=`@03oijBaonWUlGoYiO500;oYiO50onUVLT01Ol0003oXig?oj>MconSWLoo[J_F
00GoZjgI0onY/Md00on`_^Co[kkUojnni@04ojnni@03ojg0ion`aNWo/<GY00;o/<GY5?ooool00ol0
003oooooooooo`0Wooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02;ooooo0_l000001_lh
00;o?008oc`02?ll00So?`0=oiR:``CoV8O01?nGP[X4oiIk]0CoU7F]0onBKjL4oi5[Y0CoT6VR1?nA
JJ82oi9/Y0?o]j_=1?no]]42oi5TV`CoT6>I0on?HYT4ohiQV@CoSV:I0on@I9/5oi=WW0?o00001?nM
M:D4oiYbY@CoV76U1?nGL:D4oiQaY@?oVG:V1_nUR;H4ojF7]0CoYHJd1Onf/]D4okF/d003o`000?nK
MjWoVgNY00CoVWV]00?oWgJToiigY_nNMjH00_nNMjH4oiehZ@GoW7Z]0_nJO[800onVQ[?oY8NfojB7
]P03ojB7]PGoXXZk0_nPSL400onYUL7oYiO5ojNGa@03ojNGa@?oYIW900?o0000ojFIbOnSWLl00on]
ZmH5oj^]f@04ojVagOn`_^Co/;kTok2ni0Co[kkU00?o/LOZok35jOn`aNT00on`aNTEooooo`03o`00
0?oooooooooo02Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07oooool00ol0003o<`00ocP00P02ocP00P;oV8c51?nHR/<4oiR7`0?oUh:j1?nFNk@4oiAe[@?o
TVnW1?nAJj@4oi1YXPCoTFVR00?oTVbTokN[cOngZld00_ngZld3oknfd@?oTFBK1?n@HiT3ohmRV@Co
SV6I1?n>HYT3oi1TV`;oTfNL0ol00002oiI[WP03oimfY?nMM:GoWGBU00?oWGBU0onJLZD4oiQaY@Go
Ug2U0onHLJD00onILZKoYHRfojF8]P06ojF8]PGoYHNd0_nUQ[@2okRkg0Go][;E00?o]Jc@oieeY_nK
MjT01?nKMjT2oiYi[@;oWgJT1?nNMjH4oiehZ@GoW7Z]00CoVWjbojJ6/onVQ[?oYXJc1?nTQkH5oj::
^`04oj2=`OnYUL7oZIG1ojVE`@CoYiO51?nUVLT00ol0003o[J_Fojf[eP03ojf[eP;oZjgI0_nb_n@5
ok2ni003ojnniOnaan[o/LOZ00;o/LOZ0_n`aNT3ojo7k1Cooooo00?o0000ooooooooool09_ooool0
00Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06
ooooo`;o00007Oooool00ol0003oooooooooo`0Mooooo`03o`000?lc003o<`0000KoV8c50onHR/<4
oiR7`0?oUh:j1?nFNk@4oiAe[@?oTVnW1OnAJj@3oi1YXP?oTFVR00?o[J;;okN[cOngZld01?ngZld0
0ono]]7oTFBKoi5TV`02oi5TV`CoT6>I0on?HYT4ohiQV@CoSV:I0on@I9/2o`0000?oTfNL00?oUV^N
oimfY?nOMZ@01OnMM:D3oiYbY@GoV76U1?nGL:D2oiQaY@03oj>8]onUR;KoYHRf00SoYHRf1?nUQk@0
1?nUQ[Co^;_LokRkg?nh^m`4okJbe@?oWGFV1OnKMjT00onJNJgoWgJToimfY002oimfY0?oWWNV1OnM
N:T3oiaj[@03ojR7/OnVQ[?oYXJc00;oYXJc1OnTQkH3oj::^`03ojfF_onYUL7oZIG100;oZIG11OnW
UlD01OnUVLWo/:_Cok2[don`Zm?o000000?o[J_F00?o]/CUok:oi?nb_n@00onb_n@2ok2ni0?o//_/
0onaanX2ojo=k`Go[lO/5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01[ooooo00?o0000oiN<a_nGS<H02?nHS<D3oiR:``CoV8O00onGP[X4oiIk]0GoU7F]
0onBKjL4oi5[Y0?oT6VR00?oTFVRojfRbon]X//00_n]X//4okN[c@03o`000?n@IIcoT6FL00?oTFBK
1?n@HiT4ohmRV@?oSV6I1?n>HYT3o`000005oi1TVonCIicoTfNLoi=WW?nNM:<01?nOMZ@4oiedY@?o
VW:U1OnHLJD4oiM`Y@04oiQaYOnSR;OoXhRgoj>8]`WoYHRf0_nUQk@3okW6i0Co^;_L00?o][;Eoied
XonMM:<01?nMMJH3oi]gZ@03oj1fXonOMZCoWgJT00?oWgJT0onNMjH5oiehZ@04oiaj[OnXQk7oZ8Na
ojR7/@CoYXJc1OnTQkH01?nRR[_o[IJoojfF_on]U[l4ojVE`@CoYiO500?o/jgBok2[don`Zm<00on`
Zm<00ol0003o]/CUokK4i@02okK4i@?o/[oT0_ncd>l5ok;;k003ok77j_n_cNoo[lg_00;o[lg_0_n_
an`2oj[5kAGooooo00?o0000ooooooooool09?ooool000kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool07_ooool2o`0001Oooooo00?o
0000oiJ<a_nGS<H01?nGS<H7oiR<a@CoV8[31?nHQl03oiN2^PCoUW^d1?nDMJd3oi9_Y`CoTF^T0_n@
JJ800onQW<oo[J;;ojfRb`03ojfRb`?o]j_=1?n@II`3oi5TV`CoT6>I1?n?HYT3ohiQV@04ohiRVOl0
003o0000o`0000CoT6BK00CoTfNLoiidXonNM:?oWWBS1?nOMZ@4oiedY@CoVW:U1?nHLJD2oiM`Y@;o
XHRi1?nSR;L8ojF8]P03ok[Ck?nia^Co^LKT00Co^LKT0_nh^m`4oiedX`CoWGFV00CoVgNYoj1fXonP
MZ?oX7JS1OnOMZ@3oiigYPCoWGRY00?oZhR`ojR7/OnXQk400onXQk44ojJ6/`?oY8Nf00?o/9RnojfF
_on]U[l00on]U[l4ojVE`@03ojNGaOnc[M;o/jgB00;o/jgB0on`Zm<00onibnSo0000okK4i@04okK4
i@03ok:oi?ncd>oo/m3_00;o/m3_0_nbbn`2ojkDm0Co[lg_0_nYbo44oj[5kA?ooooo0_l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00ooo
ool2o`00027ooooo00?o0000ooooooooool04Oooool2oiJ<a`CoUXc61?nGS<H8oiR<a@?oV8[31?nH
Ql03oiN2^PCoUW^d1?nDMJd3oi9_Y`;oTF^T0_nAVMP4oj6Lc`Go[J;;00?o]j_=ohmVW_n@II`00on@
II`4oi5TV`?oT6>I1?n?HYT01?n>HIWo0000o`000?l00003ohiRV@?oT6BK00?oVg6RoiidXonNM:<0
0_nNM:<4oimfY0CoWGBU1?nJLZD3oiQaY@03oj:;^onQR;WoXHRi00?oXHRi0onSR;L6ojF8]PCo^]?/
1?nia^@3oiebX@GoWGBS0onMMJH5oj1fX`CoWgJT1?nNMjH2oiehZ@;oZhR`1OnXQk44ojJ6/`03ojB7
]_n`V;ko/9Rn00;o/9Rn1?n]U[l3ojVE`@03okNadonc[M;o/jgB00Co/jgB00Go/:_CokW;j?nibnSo
^L_Xo`000002okK4i@;o/mWc1?ncd>l2oj_Ln@Co[]Cd00?o[lg_ojW;lOnYbo400onYbo42oj[5k@;o
Y/;^5?ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`;o00008oooool00ol0003ooooooooo
o`0=ooooo`03oiF=b?nFS<OoUXc700?oUXc70onFS<H4oiN<aPSoV8c50_nHR/<3oh7@o`CoLlSo0omW
_?d3ofF_nP?oKJ?a0on0W>@5oi6If0CoXIc?0on]X//3ohmVWPCoT6FL1?nAI9/3oi1SV@;oSf:I0ol0
0003ohiQV@?oSV:I0_n@I9/2oi]aXPCoWWBS1?nOMZ@5oiedY@?oVW:U00CoV76Uoj:;^onRRk_oXX^k
1OnQR;T4oj>8]`?oYHRf0_nih?<5ok[Ck003okW6i?nLL:3oW72P00?oWG:Q1OnMM:<2oieeYP03oj9g
XonPMZ?oX7JS00?oX7JS1?nOMZ@4oiigYP03oiehZOn[R;3oZhR`00;oZhR`1?nXQk44ojJ6/`Go/9Rn
1?n]U[l00onYUL7o]k7CokNad`02okNad`Co/jgB00?o_=W^okW;j?nibnP00_nibnP00on^hoWo0000
ok?Il`03ok?Il`03ok?@kon[g?WoZmci00?oZmci0_n^e?@2ojO@m@CoZL_a00?oY<G`ojK2k_nV`^h0
0onV`^hDooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000002Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo0_nDSl/3oiB>b@CoUHg81?nFS<L3oiJ<aPGoUhc61OnHS<D4oh[Bo`CoPM3o0_mcb?l0
1OnLO[;oVgb`oi]l/?nCKZGoIkcm00?oIJoj0om]Xo43oh2Li0CoTIWH1OnQW<l00on]X/_oSFFPohmV
WP03ohmVWP?oT6FL1?nAI9/2oi1SV@?o00000_n?HYT4ohiQV@?oSV:I00CoT6BKoi]aX_nKLJ;oVg6R
1?nNM:<4oimfY0GoWGBU0_nJLZD00onVT/3oXX^koj:;^`03oj:;^`CoXHRi1?nSR;L00onUR;Ko^N3c
okWPl`03okWPl`;o^]?/1OnLL:03oiebX@GoWGBS00CoWGFVoj9gXonRMj?oXWNS1?nPMZ<5oimfY0?o
WWNV1On[R;05ojR7/@;oYXJc0_nfWl44ok2H_P?o[IJo00?o_K_HokNadong/M<01?ng/M<00onc[M;o
_=W^okcIkP02okcIkP03okW;j?n^hoWo[^?i00;o[^?i00?o0000ok?IlonRho`00onRho`2oj_Ln@;o
X]Ci1OnWd?D00onYbo7oY<G`ojC5l002ojC5l0?oY/;^00?oXkk]ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Wooooo000Wooooo`03o`000?oooooooooo02Cooooo00Go0000oooooooooooooooooi>@c@05
oiB?b`?oU8k91?nESLP3oiJ<a`CoUXc61?nGS<H2oiR<a@CoSm;n0_n:d_l01?nOQ;KoWX6doij1]?nN
PK@2oian/P;oU6nV0onCKZD4oi=]X`?oTV^R00?oKJ?aoh2Li?n0W>@01OnAVMP2oj6Lc`04oheVXOn=
IJ3oSFFPoheUX0CoSfJN0on@II`3oi5TV`?o00000_n@HiT3ohmRV@CoSV6I0_n>HYT00onHKZ7oVg6R
oi]aXP03oi]aXPCoWWBS1?nOMZ@4oiedY@04oiYbYOnVT/3oYY;0ojJB`0CoXX^k1OnQR;T2oj>8]`;o
/NSh1?nih?<4oiU^W`CoW72P0onMLZ45oiedX`CoXWNS1?nPMZ<5oimfY0;oWWNV00?o[Xbaoj^8/?n[
R;000on[R;05ojR7/@04ojJ6/onfWl7o]Yo1okJO`@Go/9Rn00Co[IJookfkf?nm^mSo_K_H1?ng/M<0
0onhjoGo_=W^okcIkP02okcIkP?oW^ci0_n^hoT00on>i_[o0000ohkVnP02oj;So0;oVMOm1OnRe?T2
ojO@m@;oX/Kb1OnTaO000onV`^koXkk]oj>nk@02oj>nkACooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`009ooo
ool2o`0002;ooooo0_nAT]43oi:Ac`CoTi3=1?nDSl/3oiB>b@CoUHg81?nFS<L2oiJ<aP?oSlkm1?n@
d?d2ohoBoP;oXHRi0onOQ;H2oij1]003oiAaZ?nDKjKoU6nV00;oU6nV0onCKZD4oi=]X`?oTV^R1?nA
JJ82oi6If003ohiWXOn=IZ7oSFJQ00;oSFJQ0on=IJ04ohmVWP?oT6FL00CoTFBKo`000?l0003oTFBK
1?n@HiT3ohmRV@CoSV6I00?oSV:IoiQ^XOnHKZ401OnKLJ84oiidX`CoWgJT0onMM:D00on`W/KoYY;0
ojJB`002ojJB`0CoXX^k1OnQR;T00onSR;Oo/NShok7Xn002ok7Xn003okWPlonIKYooVFjO00CoVFjO
1?nLL:04oiebX@?oWGBS00?oYGZToj9gXonRMj<00_nRMj<4oj1fX`GoWgJT00CoWWNVojj</On^S;7o
[Xba1?n[R;04ojR7/@03okf[aonfWl7o]Yo100;o]Yo11?n`V;h00oo2bn7o_K_Hokfkf003okfkf003
okNadonhjoGo^>_e00;o^>_e00Co_=W^oik/nOnNk?WoW^ci0omZfnX2ohkVnP04ohkFool0003oS]Ko
ohkFo`?oVMOm0_nRe?T4oik6m0?oX/Kb0_nTaO03oj6nk@CoXkk]5Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo
000Wooooo`03o`000?oooooooooo01kooooo00?oTICCoi6BdOnAT]400onAT]43oi:Ac`?oTi3=1?nD
Sl/3oiB>b@GoUHg80_nFS<L2ohg;o0GoSlkm0_n@d?d00onSS;_oXHRioj68^@02oj68^@;oWhBf00Co
UG>YoiAaZ?nDLJSoU76X1?nDKjH3oi=^Y@CoTffS1?nBJj83oi5YXP?oSVNQ1?n=IZ43oheUX0CoSfJN
00CoT6FLo`000?l0003o00000onAI9/4oi1SV@?oSf:I0_n>HIT2oiA[X0?oV6jQ1OnKLJ84oiidX`Co
WgJT00?oWGBUok2Na_n`W/H00_n`W/H3ojJB`0GoXX^k0onQR;T3oj3[nP;o/NSh2?nIKYl4oia`X0Co
WG:Q0_nMM:<2ojEjY0CoXWNS1OnPMZ<3oimfY003ok:A]?n^S;7o[Xba00;o[Xba1On[R;02ojR7/@;o
_J_71OnfWl400on`V;ko`/_Qol;;h@02ol;;h@?o_K_H0onHl^L2okS[m@03og7Ph_lm`Loo?L7?00;o
?L7?0_mZfnX3oh3Ao`;oS]Ko00?o0000oiNnl_nJ`o@01?nJ`o@2oik6m0;oWk[[1?nP_>d5oj6nk@;o
Xkk]0_nR_>/Booooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000009ooooo`009oooool00ol0003oooooooooo`0Gooooo`;oSYSI0on@U]H4oi6D
d`CoTI;A0onBTLl3oi>@c@GoU8o;0onDS/T2oiF=b0?oRlSl1?n=bo`2oho>o@03ojJ@__nSS;_oXhbk
00;oXhbk0_nQR;T2oiIe[0?oUG>Y1?nDLJP3oiA_YP?oTfjU1?nCKJ<4oi9[XP?oTFVR1?n>Ij43oheV
X@CoSFFP00CoSfJNo`000?l0003o00000on@II`3oi5TV`CoT6>I0_n?HYT00onBJJ3oU6^PoiA[X002
oiA[X0CoV6jQ1?nKLJ84oiidX`?oWgJT00?o_:k<ok2Na_n`W/H00on`W/H4ojJB`0CoXX^k00KoXHRi
oj3[n_nPjo[oX>_joiiaX?nKL:02oi]`X@SoVFjO1?nLL:04oiebX@03oiedXonUNZCoYGZT00;oYGZT
1?nRMj<4oj1fX`;oWgJT0_nbTK@4ojj</@GoZhR`00?oZ8Naokf[aonmZlL00_nmZlL3okJO`@;o`nG_
1?o2bn401?nm^mSoV?;WoiSbionHl^L2ohJ`l0CoNkkl1?mjb_l2oh3Ao`;oUKC]0_nG__800ol0003o
UkkboiNnlP02oi[3m0;oW[GX1OnO^^/4oj2lk@;oXKk]0_nR^NT5oj:ljaCooooo00Wo0000oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo
000Vooooo`?o00003oooool01?n:X>?oS9gOohbMgon<WMl4ohfJf`CoSYSI0on@U]H3oi6Dd`CoTI;A
1?nBTLl3oi>@c@;oU8o;0on7`o/5ohW6o0?oRlSl0_n=bo`00onYUL;oYY2nojJ@_P02ojJ@_P;oXhbk
00?oV7R^oiIe[?nFMJ`00_nFMJ`3oiEcZ@CoU76X0onDKjH4oi=^Y@?oTffS1?nBJj84oi5YXP?oSVNQ
0on=IZ42oheUX0?o00000_n?IYh4oi1UW0?oTFBK0_n@HiT2oi1XX@?oTVVP1?nDJj04oiQ^X@CoVg6R
1?nNM:<2oimfY0?o_:k<1?n`W/H4ojJB`0;oXX^k0_n1i_001OnNLIooWW6PoiiaX?nNLJ3oX7FS00?o
Vg2Q2?nIKYl5oia`X0?oWG:Q1OnUNZ@4oj9gX`CoX7JS00?oWgJTok:A]?nbTK@00_nbTK@4ojj</@?o
ZhR`00?oal;Eokf[aonmZlL00onmZlL2okJO`@Co`nG_0_o2bn400ol0003oT9kMoi2Ng@05ohJ`l0;o
Nkkl00?oV9gFoiNYhonGZN<00onGZN<4oiFdk@;oUkkb00?o0000oij_honN]NP01?nN]NP4oinjj`;o
X;c]0_nR]^L5oj:ij@;oX[c[0_nU_>XEooooo`03o`000?oooooooooo01kooooo000Vooooo`03o`00
0?oooooooooo00Gooooo0_n1Z^l3ohFVj`?oQj?V1?n:X><3ohbMg`CoSI[K0on>V=T3oi2FePCoTICC
1?nAT]42oi:Ac`;oQ;oj1?n5`O/4ohO3n`;oRLKl1?n/V/D5ojVE`P;oYY2n00CoVW^`oiQh[_nHN:ko
V7R^1?nFMJ`3oiEcZ@CoU76X1?nDKjH3oi=^Y@CoTffS0onBJj84oi5YXP?oSVNQ0_n=IZ43o`0000;o
SFFP0on?IYh4oi1UW0;oTFBK00?oSFNRoi1XXOn@J:400_n@J:43oi9YX0GoU6^P0onHKZ45oi]aXP?o
WWBS00?oWgJTokb^c?nl[/`00_nl[/`5ok2NaP;oYY;00_m8b<@4oiiaW`04oiiaX?nPMJ?oX7FSoj1e
X`CoVg2Q1onIKYl5oia`X0;oWG:Q00?oZ7jVojEjY?nUNZ@00onUNZ@4oj9gX`CoX7JS1OnbTK@4ojj<
/@03oj^8/?o7`]Goal;E00;oal;E1?nmZlL00onfWl7o`nG_ol?Uk`02ol?Uk`?oVI;;1?n@W]d2ohJ`
l0;oW9?:1?nHWMH5oiNYh`;oUKC]00KoWjSLoij_honN[n?oWZoSo`000?nN[n<4oijej0;oWk[[0onR
/^<4oj:fi`;oX[WY0onU^NP4ojFljQCooooo00?o0000ooooooooool07_ooool001_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooN;3f00;oN;3f0omm[O83oh6Zk`?oQJK[0on7
XnH3ohZPh`CoS9gO1?n=V]/3ohjHf@?oT9KF0_nAU=<3oh2kn@?oP[gj1?n4_oX4ohG1n`;oQl?k00Co
_;oLojnOb?n_WlSo[io80on/V/D5ojVE`P03ojJ@__nJNk3oVW^`00CoV7R^0onFMJ`4oiEcZ@?oU76X
1?nDKjH3oi=^Y@CoTffS0onBJj84oi5YXP;oSVNQ0ol000000on:J:GoQfJUohMVY@05ohMVY@CoRFJT
0on=Ij84oi1XX@CoTVVP1?nDJj03oiQ^X@GoVg6R0_nNM:<2olBldPGo_:k<0_n`W/H2oiQ[W@GoW6nN
0onNLIl4oj1eX`CoVg2Q1onIKYl5oia`X004oiebXOnXOZKoZ7jVojQnYPCoYGZT1?nRMj<4oj1fX`Go
/Y6d1?n^S;46olO2e@;o_J_70onMm>D00oo3iNooX8ZloiVBb`03oiVBb`;oT9kM0_nQSKl5oibCbPCo
V9gF0_nGZN<2oj:Re0CoWjSL0onN[n<01?l0003oWZoSoijej?nN]NP2oj>]g`GoX[;S0_nR]^L2ojFg
i@GoYKWX0_nU_>X2ojNmjACooooo00?o0000ooooooooool07Oooool001_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?oN;3f0omm[O83oh6Zk`?oQJK[0on7XnH3ohZP
h`CoS9gO0_n=V]/2ogZen0?oO;Oi1?mn^OT4oh2kn@?oP[gj0_n4_oX3obffb0?o_/;M00?o/JC;ojnO
b?n_WlP00_n_WlP4ojbJa@;oZIG20_nLOk<4oiYk/0?oV7R^1?nFMJ`3oiEcZ@?oU76X1?nDKjH3oi=^
Y@CoTffS0onBJj82oi5YXP05oi1/YOl0003o0000o`000?n>JZD00on:J:D7ohMVY@CoRFJT0on=Ij84
oi1XX@CoTVVP1?nDJj03oiQ^X@GoVg6R00?oWWBSolBld_o4_=800_o4_=83okb^c003oiEXVonHJigo
V6^M00;oV6^M1OnLKih2oiiaW`03ojIlY_nPMJ?oX7FS00?oX7FS0onKL:48oiU^W`?oW72P00?oZ86Y
ojQnY_nXOZH00_nXOZH4ojEjY0GoXWNS0_nPMZ<2okNJ^PGo/Y6d0_n^S;42olo^j@Coal;E0_l00002
oigdi@CoX8Zl0onIT//00onVRkSoXHfooj6=_`03oj6=_`CoW9?:0_nHWMH2ojJMc0GoXZ;D1?nOZ=`2
oij_h`03o`000?nTZM[oXjgO00CoXjgO0_nR/^<2ojJdhPGoYKOU0_nU^NP2ojNkj0GoYkgY4oooool2
o`0001kooooo000Kooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo0om]ZoH3
ofj/m`?oKjgg1?ma[oL3og>`m`?oM[;h0omh/oP4ogZen0?oO;Oi1?mn^OT2oh2kn@;o?/7P0_nnjO80
0onmkO?o_lGNoko5gP03oko5gP04okk2gOnaY<_o/JC;ok6Tb`Co[io80_n/V/D00onOQ;KoW7ncoiao
/`02oiao/`CoVW^`0onHN:h4oiIe[0?oUG>Y1?nDLJP3oiA_YP?oTfjU0_nCKJ<2oi5]YP?oTFfU0ol0
00001?n@K:GoSVZUohiZYOn>JZD4ohYXY@KoQfJU1?n9IZ@4oheWXP?oT6RQ1?nBJJ04oiA[X0CoV6jQ
0onKLJ800oo8a=Ooa;cBolBldP04olBldP04okb^c?nEJ9_oUFRKoiEXV`?oV6^M1OnLKih00onNLIoo
YWbVojIlYP05oj1eX`?oVg2Q2?nIKYl2oia`X0;oZ86Y1?nXOZH5ojEjY0CoXWNS00CoX7JSokNJ^_ng
V[[o]iZj1OnbTK@00on^S;7ocnkYolo^j@02olo^j@03olO2eOnENK7o[8R^00CoYXNc1OnPR[`01?nI
T/_oYX^hojJ;^?nVRkP4oj6=_`?oW9?:00?oZY[6ojJMc?nVWL`00onVWL`4oj:Re0;oWjSL0_nWYM@3
ojBYfP03o`000?nTZM[oXjgO00;oXjgO00?oZ;7OojJdh_nV]>800onV]>83ojFgi@03ojRji_nW^nSo
Yk_X00?oYk_X0onW_NT00onY`>[oooooooooo`0@ooooo`03o`000?oooooo000001kooooo000Koooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`?oKJ_f0om^[?L3
ofn]m`CoLJog0omc/?L3ogJbn0?oN;?h0_mj]OP4oeC4m`;oC/Ga0ol00004okkYlP;o`<KO1?noaMh0
0ondZLko/JC;ok6Tb`02ok6Tb`?o[io800CoXXVjoin4]_nOQ;KoWhBf1?nLOk<4oiYk/0?oV7R^1?nF
MJ`3oiEcZ@CoU76X0onDKjH2oi=^Y@03oi1]YonAKJKoTFfV00;oTFfV00?oTFfUo`000?l000001?n@
K:D4ohiZY@?oRVRU1on7IZD3ohUVY0CoSFNR0on@J:44oi9YX0CoU6^P1?nHKZ42oi]aXP?ob<CG1?o4
_=800onBII_oUFRKoiEXV`02oiEXV`CoV6^M1?nLKih4ojIlYPCoX7FS0onKL:48oiU^W`03oia`X?nX
PJWoZ86Y00;oZ86Y0onXOZH5ojEjY0?oXWNS00?o_JW6okNJ^_ngV[X00_ngV[X4ok:A]0;o00000_o?
k^T00onJMJOoUGVaoiEi/@03ojb8[P?oYXNc1?nPR[`00on/S;CoYX^hojJ;^002ojJ;^0GoXHfo00Co
W9?:ojZJa_nZV/KoZY[61?nVWL`3oj:Re003ojZSd?nWYMCoYjGD00?oYjGD0onTZMX00ol0003oXjgO
ojRag`03ojRag`CoY[CR00?oYKOUojRji_nX^^H00_nX^^H4ojNkj003ojNmjOnY`>[oZL3Z00;oZL3Z
5?ooool00ol0003oooooooooo`0Kooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00oooool4ofj/mP?oJk3i0omX]?/3ofFho@CoHKcm0omM_od2oeW2n`?o?/7O
0_le^kh00omOe/ooY_3fojK`mP04okoTl@03okkYl_o0a]oo`<KO00;o`<KO00?o_lGNokBYc_ndZLh0
0_ndZLh4ok6Tb`03ojnOb?nRRK[oXXVj00CoWhBf1?nLOk<3oiYk/0?oV7R^1?nFMJ`3oiEcZ@CoU76X
0_nDKjH01?n?KJSoT6fWoi1]Yon@KJL2oi5]YP?o00000onAKJD3oi1/Y@CoSVZU0on:J:D7ohMVY@?o
RFJT1?n=Ij84oi1XX@?oTVVP1?nDJj04oiQ^X@03oi]aX_o8a=Oob<CG00?ob<CG00Coa;cBoi9UVonB
II_oTVFK1?nEJ9/4oiQ[W@?oW6nN00?oZX>ZojIlY_nVO:H00_nVO:H4oj1eX`?oVg2Q1onIKYl00onV
PJcoZ86YojR1Z@03ojR1Z@?oZ7jV1OnUNZ@00onRMj?o_JW6okfYaP02okfYaPCo]iZj0_nbTK@2o`00
00CoVWFW00?oUGVaojb8[_n/R:h00_n/R:h4ojJ7/`03oj2:_?n/S;Co[8bd00;o[8bd0onVRkP4oj6=
_`03ok2K`_nZV/KoZY[600;oZY[61OnVWL`01?nRX]CoZZ?@ojZSd?nZXm05ojNUe0;oY:WJ00?o0000
oj^`g?nX/Ml01?nX/Ml2ojJdhP;oZ[WT1OnX^^H2ojNkj0;oZ[oY0onY`>X00onZ`^_oooooooooo`0C
ooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`05ooooo`CoKZcf0om[/?T3ofRdn`?oIKSm0_mQ_?d4oe_7n@;oC/K_0om>c=d0
1?mfh^SoY_3fojK`m_nVl?H4okoTl@;o`<OO0oo0a]l00ong[]7o]:W>okBYcP04okBYcP;o/JC;00?o
YHjmoj:9^_nRRKX00_nRRKX3oin4]PCoW7nc1?nJNk03oiQh[P?oUWF/0_nELjT00on@Kj[oSfjYohm^
Z@02ohm^Z@?oSffX0_n@KJL3o`0000;oTFfV1?nAKJD3oi1/Y@CoSVZU0on:J:D7ohMVY@CoRFJT0on=
Ij84oi1XX@?oTVVP1OnDJj03oiQ^X@Gob<CG00?oTFBJoi9UVonBII/00_nBII/4oiEXV`CoV6^M0_nL
Kih2ojZ3ZPCoYWbV1?nPMJ<4oi]`X@GoVFjO0_nVPJ`5ojR1Z@CoZ7jV0onUNZ@00oo8b]co_JW6okfY
aP03okfYaPCo]iZj00Co/Y6doimdX_nOM:;oWgBR1?nJMJL5ojb8[PCoYXNc1On/S;@4ojJ;^003oj6=
_on`Vl;o/9_200;o/9_21?nZV/H2ojJMc0;o[jC=1OnZXm02ojNUe0;o[[7J0on[/=`01?l0003oZk3L
ojRagonX/Ml2ojbih`GoZ[WT0_nX^^H2oj^oj0GoZ[oY00CoZL3Zoj[2jonZ`^_oZ/;[5?ooool00ol0
003oooooooooo`0Jooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00007oooo
o`;oKZcf0_mk/OH3ogJhn`GoKkon0_mVa?h3ogGCoP;oI=Cc0on9iOP3ojcZn@?o_]k_00?o_nCaol37
goo0aml00oo0aml01?o0a]oo]jkAokN^dOng[]44okBYcP03ojRD`OnUS[goYHjm00;oYHjm0onRRKX3
oin4]PCoW7nc1?nJNk03oiQh[P;oUWF/00CoT76/oi1_Z_n@Kj[oT6nZ1?n?KZT2ohm]Z0?o00000_n@
KJL3oi5]YPCoTFfU1?n@K:D3ohiZY@?oRVRU1on7IZD4ohUVY0?oSFNR1?n@J:43oi9YX0GoU6^P0_nH
KZ42ol?8gP?ob<CG0onAI9X3oi9UV`CoUFRK1?nHJid01?nLKikoZX>ZojZ3Z_nZPjX4ojIlYPCoX7FS
1?nKL:43oiU^W`03oj>2/?nVPJcoYX6/00;oYX6/1?nXPJT4ojQnYP;oYGZT0oo8b]`4okfYaP?o]iZj
00?oYGRQoimdX_nOM:800onOM:82oiYeY`03ok:<[On/R:ko[8R^00Co[8R^0_nVQk<00oncT[Co[8bd
ojb<]003ojb<]0CoYX^h1On`Vl83ojZJaP03okFYcOn_Y<go[jC=00?o[jC=0onZXm000onb/mWo[[7J
ojjafP03ojjafP?oZk3L00?o0000ojbihon/^N<00on/^N<2ojZii0;o[<3X1On[_nP2ojZoj@;oZl?[
1OnZ`^/Dooooo`03o`000?oooooooooo01Wooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`07ooooo`CoNk7f0omf^?/2ofnooPCoPLgo0_medoh3oiGPoPCo[n7h
00Co[>[iokkNkonng^oo_]k_0oo0an03ol37g`03okVcdong[]7o]jkA00?o]jkA00?o]:W>ojRD`OnX
U<400_nXU<43ojF>_@?oXXVj1?nOQ;H3oiao/`;oVW^`0_nCMZl3oi5c[@?oT76/1?n@KjX2ohm^Z@?o
00000_n?KJP3oi1]Y`CoTFfV0onAKJD4oi1/Y@?oSVZU1?n:J:D6ohMVY@CoRFJT0on=Ij84oi1XX@Co
TVVP1?nDJj000onHKZ7o`lSNol?8gP02ol?8gP03olS4eonAI9[oTFBJ00;oTFBJ0onBII/4oiEXV`?o
V6^M00?o[8N]ojZ3Z_nZPjX00_nZPjX4ojIlYPGoX7FS0onKL:401?nIKYooXh:`oj>2/?nSP[04ojJ1
[0CoZ86Y1?nXOZH00onUNZCob<[LolS:g002olS:g0Go_JW600Co]iZjojEhXOnUN:7oYGRQ1?nOM:80
1?nJMJOo/Xb]ok:<[OnbS:d5ojb8[P04ojJ7/oncT[Co/i:dok>B]0Go[8bd0_nVRkP2okJO`@Go/9_2
00CoZY[6okFYcOneZLgo]JW=1?n_Y<d00onZXm3o/[?Iok:cf@02ok:cf@Co[[7J00GoZk3Lojnkhon_
^n?o[k_So`000003ojbih`03ojk3jOn/`>So[<3X00?o[<3X0_n[_nP3oj_4k0CoZl?[1?nZ`^/Doooo
o`03o`000?oooooooooo01Wooooo000Uooooo`03o`000?oooooooooo00Sooooo0_mk/OH3ohfhl`Co
RL?k0_n1cOl4oicFo003oiGPo_n_hOSo[n7h00;o[n7h0onmend00onng^oo`<OPol37h003ol37h004
ol37goni/m?o^K?CokVcd`?o]jkA00?o[9_5ojRD`OnXU<400onXU<43ojF>_@CoXXVj0onOQ;H2oiao
/`03oiAi/_nCMZooTgJ_00;oTgJ_0onALjd4oi1a[0;oT6nZ0ol000000on?KZWoSffXohm]Z002ohm]
Z0?oT6fW1?nAKJH3oi5]Y@CoT6bU1?n>JZD3ohYXY@OoQfJU0on9IZ@4oheWXP?oT6RQ1?nBJJ03oiA[
X0;o^<KU0oo3b=h2oi1TV`CoTFBJ1?nBII/3oiEXV`;oV6^M0_n/Qjd5ojZ3ZPCoYWbV1?nPMJ<2oi]`
X@03oj25]onSP[3oXh:`00?oXh:`0onVPJ`5ojR1Z@;oZ7jV0_nlnnT5olS:g0;o_JW60_n`PZ@4ojEh
X@CoWgBR1?nbS:d5ojb8[PCo/i:d1On/S;@01?nVRkSo]Yo1okJO`OnfWl44ok2K`P03okfedOneZLgo
]JW=00;o]JW=0on_Y<d00ong^]co/[?Iok:cf@04ok:cf@;o[[7J0_nb`ND3ojnkh`03o`000?n_^n?o
[;WS00?o[/?Y0on/`>P2oj_6k@GoZlC/0_n[`n/2oj[4k0CoZ/;[4_ooool00ol0003oooooo`00000J
ooooo`009Oooool00ol0003oooooooooo`0:ooooo`CoSKSc0_n9`o/4oio:mP;oW=Kl0on`e_@00on_
hOSo_MO]okgGk@02okgGk@Ko`<OP00?o^kOFokVcdoni/m<00oni/m<01?ng[]7o[9_5ojbKaOn/VlD4
ojRD`@CoYHjm0onRRKX2oin4]P04oiIl]?nDNK;oU7VboiAi/PCoTgJ_1?nALjd2oi1a[0?o000000?o
T6nZohm^ZOn?KZT00_n?KZT3ohm]Z0?oT6fW1?nAKJH4oi5]Y@?oT6bU1?n>JZD3ohYXY@OoQfJU0on9
IZ@4oheWXP?oT6RQ1?nBJJ000onDJj3o^<KUokS6i@03okS6i@04ol?8g_n@I9_oT6BKoi1TV`CoTFBJ
1?nBII/3oiEXV`03oiQ[WOn/Qjgo[8N]00;o[8N]1?nZPjX4ojIlYPCoX7FS00?oVg2Qoj25]onPQKL0
1OnSP[03ojJ1[0GoZ86Y00?oZ7jVokckjOnlnnT00_nlnnT2olS:g0;oZWjT1?n`PZ@4ojEhX@CoWgBR
1?nbS:d4ojb8[P;o`:6j0oncT[@4ojb<]003okn[aOnfWl7o]Yo100;o]Yo10on`Vl82okfed@Go]JW=
00Co[jC=okNjg?ng^]co]k[L1?nb/mT00ondbNWo//7Uok;1i@03ok;1i@;o[k_S00?o[/O/o`000?n^
`nT01?n^`nT00on/`>SoZlK]oj_6k@02oj_6k@;oZlC/0_nZaNh5oj[4k0;oZ/;[0_nX`^`Dooooo`03
o`000?oooooooooo01Oooooo000Uooooo`;o00003?ooool2ohfhl`?oX;k^0_nOb_H4ok3<kP;o/=Kd
1?nld>T00onmengo`<OPol37h003ol37h0Co^kOF0oni/m<00on_XLWo[9_5ojbKa@02ojbKa@GoZ9C1
0onUS[d2oj:9^P04oiV1^?nFO;CoUWbdoiIl]0CoU7Vb0onCMZl4oi5c[@;o000000CoT76/oi1_Z_n@
Kj[oT6nZ1?n?KZT3ohm]Z0CoT6fW0onAKJH4oi5]Y@?oT6bU1?n>JZD2ohYXY@04ohf4a?n0QLooP8G?
oh25c`?oLhgM00CoQfJUohUVY?n9IZCoRFJT1?n=Ij83oi1XX@;oTVVP0onV`Nd4okS6i@;oSVBM0on@
I9/4oi5TVPCoTVFK0_nEJ9/00onZR;7o[8N]ojb7[@03ojb7[@CoZX>Z1?nVO:H2oj1eX`;oYYS71?nP
QKL4oj>2/0?oYX6/1?nXPJT3o`0000;o_?_Y1OnZOZ@4ok22Y0CoYGRQ0onOM:82okbE/0Co/Xb]0_n/
R:h3ol2Q^PCo/i:d0_n/S;@3okn[a@Co]Yo100?o/9_2okfedOnm]M400_nm]M43okFYc@03ok_6hong
^]co]k[L00?o]k[L00?o/[?IokC9jOndbNT00_ndbNT3ok;1i@03ojo=l?n^anco[/O/00;o[/O/00?o
0000ojk3jOn^`nT00_n/b_04oj_6k@03ojW7konZaNkoZ/G^00?oZ/G^0_nZa>`2ojS3k@GoZ<;/4ooo
ool00ol0003oooooooooo`0Gooooo`009?ooool00ol0003oooooooooo`0=ooooo`?oX;k^0on_`^P3
ok3<kP;o^/[V1?nld>T2oko6g`?o`<OP0onl^mP4ok^geP04okVcdon_XLWo[j79ojnQb@?o[9_51OnX
U<42ojF>_@03oib6^onIPKSoVH6h00;oVH6h0onFO;@3oiAi/PCoTgJ_0ol00003oi1a[0?oT6nZ1?n?
KZT4ohm]Z0?oT6fW0onAKJH4oi5]Y@;oT6bU00?oUX6joiB2_OnDP[d00_nDP[d4ohf4a0?oP8G?0omc
SMd3ofZGj@CoMZOa1?n>]o85ojK1k@03okS6iOn<HikoSVBM00;oSVBM1?n@I9/3oi5TVPCoTVFK00?o
UFRKojZ8/OnZR;401On/Qjd4ojZ3ZP?oYWbV00?o]m7]ojJHaonVV<L00_nVV<L4oj25]`CoXh:`1?nV
PJ`2ojR1Z@;o[X6S1?n^Oj84ojYnY0;o`YV^0on`PZ@5ojEhX@04oimdX_nlUK3o_9F`okbE/0Co/Xb]
00?o[8R^ol2Q^_o0XKX00_o0XKX4ok>B]003ojb<]?noZlGo_j_500;o_j_50onfWl400oo6c=oo_KGA
okfed@03okfed@03okFYcOnka^?o^lKS00;o^lKS0ong^]`2okGHlPCo]<WY00?o//7Uojo=l?n_cO00
0_n_cO02ojk7k0;oZLoc00?o0000ojc:l?n/b_000_n/b_000on[a^goZLO_ojW7k`02ojW7k`;oZ/G^
0onXaNh4ojS3k@;oZ<;/0_nW`N`Dooooo`03o`000?oooooooooo01Kooooo000Tooooo`03o`000?oo
oooooooo00kooooo00?oX;k^ojo2j?n_`^P00on_`^P00on`c>ko^/[Vok[:iP02ok[:iP03okc@jOno
a]oo_lKO00?o_lKO00?o`<OPokbkf?nl^mP00onl^mP2ok^geP03ok:Xc_n_XLWo[j7900;o[j791?n/
VlD2ojRD`@;oWhbo1?nLQ[/3oiV1^0?oUWbd0onDNK801?nCMZoo0000o`000?l00003oi5c[@?oT76/
1?n@KjX3ohm^Z@CoSffX0on@KJL3oi5]YP;oTFfU0_nEOkT4oiJ1^PCoU8:m0on=Q<@4oh25c`?oLhgM
0omZUnT4ogJWl@CoS[Ob0_nV`Nd01?n8HYooS6>NohaSW_n<Hih4ohiTW@?oT6BK0onAI9X3oi9UV`03
ojB6/onZR;7oZXRa00;oZXRa1?n/Qjd4ojZ3ZP03ojIlY_ngdNgo]m7]00;o]m7]0onVV<L4oj25]`Co
Xh:`1?nVPJ`00onXPJWo[X6Sojj1X`02ojj1X`Co[WnR0_nZOZ@3ol:I[P?o/8:T1OnUN:401?nOM:;o
_9F`okbE/?nlUK04ok:<[@Ko`:6j0_ncT[@00oo8`]Co_j_5okn[a@04okn[a@04okJO`Oo6c=ooa/cO
olK<g`?o_KGA0_nkg?45ok_6h`03okNjg?nef?;o]MSb00;o]MSb0_ndbNT3oj[EmP;o[lg`0_nUe?P3
ojW?l`04o`000?nYco?o[<[`ojc:l0?oYl[b0_nYanl2ojK6l0GoZ<G^0_nX`nd2ojO1k@CoYl7/5?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool3o`0000oooooo1?n_`^P2okW3hP?o^/[V0onnaMl3
oko6g`;o_KkJ1?nl^mP00one[];o/ZS>ok:XcP02ok:XcPCo[j790_n/VlD00onRT/?oWhbooin<_`02
oin<_`CoW8Jk0onIPKP3oiIl]004oiAi/_l0003o0000o`0000?oTgJ_1?nALjd3oi1a[0?oT6nZ0on?
KZT4ohm]Z0;oT6fW00CoSg^hoi9m^OnBOKWoTWfi1OnEOkT3oiJ1^PCoU8:m0on=Q<@5oh25c`?oLhgM
0omZUnT4ogJWl@;oS[Ob1?n8HYl3ohaSWPCoSVBM0on@I9/3oi5TVP04oi9UVonTQ[?oY8JcojB6/`Co
ZXRa1On/Qjd2ojZ3ZP;o00001?ngdNd4ojJHa`?oX8Fg1OnSP[02ojJ1[003oi=SU_n^PJ?o[X6S00?o
[X6S1?n^Oj82ojYnY0?o`YV^0on`PZ@5ojEhX@Co_9F`1?nbS:d00ooEb<go`:6jol2Q^P03ol2Q^P04
ok>B]?o8`]Cob<;DolS2e0Co_j_500?o_oK_olK<goo6c=l00oo6c=l00onm]M7o^mcaok_Ll@02ok_L
l@;o^lKS0onWi_/2okGHlP?oWmcl0_nZeOH2oicGo0GoYMCh0_nYco<00onTc?Co0000ojC<m002ojO:
lP;oY<Oa1OnVa_02ojS5kP;oY/;]1OnW`Nd2ojO1k0;oY/3/4_ooool2o`0000Wooooo1?l000000ol@
413oooooooooo`07ooooo`009?ooool00ol0003oooooooooo`0@ooooo`03ojo2j?ni`n;o^L?R00?o
^L?R00?o^/[Vokk5gonnaMl00onnaMl00onoa]oo_KkJokfnfP02okfnfP03okbkf?ne[];o]JkB00;o
]JkB1?nbZ<h2ojnQb@03ojJIb?nRT/?oXY;300;oXY;31?nOS;l3oib6^`CoVH6h0ol00003oiAi/P?o
TgJ_1?nALjd3oi1a[0;oT6nZ00CoSGNfohih]on>N;OoSWRg1?n>NKP3ohmk^0CoTWfi1?nEOkT3oiJ1
^PCoU8:m1?n=Q<@2oh25c`03ohaUX?n<IIooS6FO00;oS6FO0on;I9l3ohQSX@?oPf6S0on0HjP01?n8
HYooS6>NohaSW_n<Hih4ohiTW@?oT6BK0_nAI9X00onKP;GoY8JcojB6/`03ojB6/`?oZXRa1On/Qjd0
0onZPj[oXGFRoj5eXP02oj5eXP?o]m7]1?nVV<L4oj25]`CoXh:`00?oYX6/oi=SU_nCHiH01On^PJ<4
ojioXP03ojYnY?o2VJko`YV^00;o`YV^1?n`PZ@3ojEhX@03olFW^onlUK3o_9F`00?o_9F`0_nbS:d2
omG8c@Co`:6j00?oaOC^olS2e?o8`]@00oo8`]@00onoZlGo_oK_okofk`02okofk`;oa/cO0onIk?L2
ok_Ll@?oLn3/0_nWi_/4ohGLoP;oWmcl0_n>eOl4oicGo0;oYMCh0onOc?L2ojC<m003oj;6l_l0003o
X/Kb00CoY<Oa0_nVa_02ojG2kPGoY/;]0_nW`Nd2ojJok0GoY/3/4oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01;ooooo0oni`n82okk4g`Co_/GO0_nn`M`3
okfnfP03okReeone[];o]JkB00?o]JkB0onbZ<h00onYX<goYYW8ojJIb002ojJIb0?oXY;31?nOS;l4
oib6^`?o00000onFO;@3oiAi/P;oTgJ_00?oSWVgoheh]_n=N;H00_n=N;H6oheg]P?oSWRg1On>NKP3
ohmk^0?oTWfi1?nEOkT4oiJ1^PCoU8:m0_n=Q<@01?n:IJ;oS6FPohaUX?n<IJ04ohaUW`?oRfBO0on8
Hj43oh=QX`CoP6>X0on0Ijd3ohI_/@04ohiTWOn@I9_oT6BKoi1h]0?oVh2e1OnTQ[<4ojZ8/@?o[8N]
0_nMM:D4oj5eXP?oXG:N00Co]m7]ojJHaonVV<OoYYS71?nPQKL2oj>2/0;oUfJF0_nCHiH00on/PZOo
[X6Sojj1X`03ojj1X`Co[WnR1Oo2VJh4ok22Y0;oYGRQ0_o5Yk/5okbE/004ok:<[OoEb<goeLS=omG8
c@?o`:6j0oo5m>h3olS2e0?o00000_nom^l3o`0000;oVNcg00CoE;7kod^nmOm;__GoBkke1?mNcOL2
ohGLoP?oP/oo1?n>eOl2oicGo0?oV/_i0_nOc?L2oio4lP;oX/Kb00?o0000oj;6l_nRa_800_nTao42
ojC1kPCoYL;^0_nV`^d2ojFok0GoY[o/0_nV`>`2ojJojaCooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Cooooo`03okW3h_nn
a=oo_/CO00;o_/CO00?o_/GOokk1g?nn`M`00onn`M`01?nm_][o^;GGokReeonh]ML5okF^dP04ok:X
c_nYX<goZJ3=ojVPc@?oYYW80onRT/<4oin<_`04oib6^ol0003o0000o`0000;oVH6h00CoTH2loi1l
^_n@O;[oT7bj0on>N[P3ohii]`CoSGRf1on=MkH3ohih]`CoSWVh0on?NkP3oi9m^@GoUGni0onFPKX2
oiB2_@03ohKXlOn8IJCoRVFR00;oRVFR1?n<IJ03ohaUW`?oRfBO1?n8Hj43oh=QX`?oP6>X0on0Ijd4
ohI_/@?oT7Rd1?nKP;D4ojB6/`CoZXRa00?o[8N]oiedYOnMM:D00_nMM:D4oj5eXPCoXG:N1?nOKYX3
oi]ZV0CoUfJF00CoTf>Fojb2Yon/PZOo[8:W1?n^PJ<4ojioXP03onkYa_o2VJko`YV^00?o`YV^0on`
PZ@00onUN:7oaJNkolFW^`02olFW^`?o_9F`0_n5fHl4omG8c@03ol2Q^_o5m>koaOC^00;oaOC^00?o
b<;DoiRIdonHVM<01?nHVM<2ogjXk`03oinIc_nAX^3oTJ;P00;oTJ;P1On5/o<3og_1o@;oP/oo0onC
__@4oiC5n0;oV/_i0_nM_o05oio4lP;oX/Kb00?o0000oj>okOnT`Nh01?nT`Nh2ojG2kP;oYKk/1?nU
_n`2ojJok0?oY[k[1?nV_n/Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool05Oooool3okk4g`?o_lCN0onn`M`00onj_=_o^;GGokRee`03okRee`;o]JkB0_n]
Z=84ojVPc@?oYYW81?nRT/<2oin<_`;o00000onCQ;l4oi60_0?oT7bj0on>N[P3ohii]`?oSGRf1on=
MkH3ohih]`CoSWVh0on?NkP4oi9m^@CoUGni0_nFPKX2ohcTn`?oR6FT0on:IJ84ohaUX0?oS6FO0on;
I9l4ohQSX@?oPf6S1?n0HjP3oh1W[@?oQVna1?n@N;@3oi^0]@GoY8Jc0_nZR;43oiI`Y@?oWGBU1?nQ
MJ84oj5bWPCoWfjJ0onKJYP3oiMVUP03ojZ6[_n/PZOo[8:W00;o[8:W1On^PJ<2ojioXP;ok^W61Oo2
VJh2ok22Y003om7LhOo5Yk_oaJNk00?oaJNk0_nlUK04ohGIS`;oeLS=1?nMQk/4ojRD`@CoV9WC00?o
[9S2oinIc_nOVLh00_nOVLh4oi6Rh0;oQK?c0_nNZ]l4oiJcj`GoTkkd0_nDaOP2oibhk0CoWKo`0_nO
a?82oj:lk0?oXko]00Co0000oj>okOnT`NkoY<7^0_nT_N/5ojFnk0;oYKo/1onV_^/4ojJoja?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`0001Kooooo00?o_/COoko4g_noa=h0
0onoa=h01?nn`Mco^[cKokZlfonj_=/3okRee`03ok2`f?n]Z=;o[JSB00?o[JSB0onYX<d4ojJIb0;o
XY;30ol00002oiJ9``?oThBo1?nAP;`3oi1l^P?oSWZh0on>NKL4oheh]PKoSGNf0on>N;L5ohii^0?o
Sg^h0onBOKT2oiEo^@CoQm_n00?oS>Ckoh]YY_n8IJ@00_n8IJ@3ohYUXPCoS6FP0on<IIl3oh]TW`Co
R6>Q0on3HJ<4oh1SZ0?oP6N]0on6Kk44oi1h]0?oVh2e1OnTQ[<00onZR;7oSVRRoiI`Y@02oiI`Y@Co
WGBU0onQMJ84oj5bWPCoWfjJ0onKJYP2oiMVUP;oZXJ^1?n/PZL5ojj1X`04ojioX_o^jLKok^W6onkY
aPGo`YV^00Co/8:Tom7LhOoAg>7odMcQ1?o5Yk/00onlUK3oZXbfojZ<]P05oj^9/@?oWHNk0_nfV;P4
ojRD`@04oiRIdon/V<;o[9S2ojbH`PGoWiW>0_nAX^000onWXm;oWZ[OoijZg`03oijZg`CoU[?[0_nC
__@2oinai@GoW;S/0_nM_o02oj:hj0CoX[c/0_nS_nd00onT^nWo0000ojBkj@04ojBmj`;oYKk/0_nV
_NX7ojJnj`;oY[kZ1OnV_n/Aooooo`?o00001oooool00ol0003oooooooooo`09ooooo`002Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooooooo
o`0Hooooo`?o_lCN00?o_<CPokZlfonj_=/00onj_=/01?nh]MOo/;3Hok2`f?n`/=P4ojfXdPCoZJ3=
0_nVVLP3o`0000;oVHk70onFRL<3oi>4_`CoTH2l0on@O;X3ohij^0?oSWVg1?n=N;H7oheg]P?oSWRg
1?n>NKP3ohmk^0;oTWfi1?n5d?l2ohOKoP?oRfVV1?n8IJ@2ohYUXPCoS6FP1?n<IIl3oh]TW`?oR6>Q
0on3HJ<4oh1SZ0?oP6N]1?n6Kk43oi1h]0CoVh2e0onTQ[<3ohiXXP?oUW2U1?nMM:D3oj5eXPCoXG:N
1?nOKYX3oi]ZV003oiMVU_nZQZkoZXJ^00;oZXJ^0on/PZL5ojj1X`03ojioX_o^jLKok^W600;ok^W6
0oo2VJh00onSO:WodMcQom7Lh@02om7Lh@?oaJNk00?o/Hb_ojZ<]_nZS;H00_njU;05oj^9/@04oif7
^onfV;So]YRhokJH^0CoZ9C11On/V<83oinIcP03ok2Rb_nWXm;oYj?B00;oYj?B1?nNZ]l2oiJcj`?o
Xj[L1?nO/ND2oibhk0;oY;CT1OnR^>P2oj:lk0;oYKSW0_nT^nT00ol0003oY;_YojBkj@02ojBmj`;o
Y[_X1?nV_NX2ojJnj`;oYkgY1OnV_^X2ojJoj`;oYko[3_ooool4o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool02Oooool000Wooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01?noa=ko_<CPokc4h?nla>03okZl
f`03ok>ig_n`/=So/;3H00?o/;3H1?n]Z=82ojVPc@?o00000_nMUL/3oiV>a`?oUXW31?nCQ;l4oi60
_0?oT7bj0on>N[P3ohii]`?oSGRf1on=MkH3ohih]`;oSWVh0on<]o84ohK3n`;oQM3o00?oTgF^ohi^
ZOn>KZT00_n>KZT2oh]YYPCoR6FT0on:IJ83ohaUX0CoS6FO0on;I9l3ohQSX@?oPf6S1?n0HjP3oh1W
[@CoQVna1?n@N;@3oi^0]@03ojB6/on7H9koSVRR00?oSVRR0onFL:D4oiedY@CoXGFR0onQLYh4oim^
VP;oVfZH00?oYHbjojZ6[_nZQZh00onZQZh3ojb2Y`Go[X6S00OoZXVbokJ<ZonfS:_o]Xb[onkYa_o2
VJko[8:W00?oXgbY1?oAg>401?o5Yk_o/Hb_ok6<[onZS;H3okZD/0GoZhVa1?nfV;P3ojRD`@;o]ibm
1?n/V<801?nOVLko/:;:ok2Rb_n`X/X5ojNSdP;oWZ[O0_nYYm@5oj>Zg0;oWk7U0_nW/=l4ojBdi0;o
X[SX0_nV]N<5ojFhi`;oY;_Y00?o0000ojNjionV^nP01?nV^nP2ojJmjP;oYkcY1?nW_NT2ojJnjP;o
YkkZ1OnW_n/:ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000_o
oooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo0_l0000Kooooo`Co_<CP00Co^[cKok>ig_nc^Mko/kWN1On`/=P2ojfXdP?o00000_nPW=03
oifEb`?oVHk71?nFRL<3oi>4_`CoTH2l0on@O;X3ohij^0?oSWVg0on=N;H2oheg]P;oSI[K0on>X^44
ohn[j@GoS;Ob0_n6`o/2oiUm/`?oTgF^0on>KZT3oh]YYP?oR6FT0on:IJ83ohaUX0CoS6FO0on;I9l4
ohQSX@?oPf6S1?n0HjP3oh1W[@?oQVna1?n@N;@2oi^0]@?oQf2N1?n>J:83oiI`Y@CoWGBU1?nQMJ83
oj5bWP;oWfjJ0_nQVL`3ojF<^PGoZXJ^1?n/PZL3ojj1X`03ojb6[OnfS:_o]Xb[00;o]Xb[1?n/PZL2
oj=lZ@?o^YB`1?naS:l4okZD/0CoZhVa00?o_YniokJH^?nfV;P00onfV;P01?nXU<7o]ibmokNL_Ong
W;d4ojbH`PGo/:;:0onWXm800onaZ<ooZJODojVWe003ojVWe0;oXj[L0_n/[mX5ojN`g`;oY;CT00?o
ZK?PojJehonV]N<00onV]N<3ojFhi`06ojRhiOnW^^OoYk[WojNjiol0003oYk[W0onV^nP00onW^nOo
YkcYojNlj@03ojNlj@;oYkgY0_nW_^T4ojNnjP;oYko[0_nX_n/6ooooo`Co00002?ooool00ol0003o
ooooooooo`0Aooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo01_ooooo0_nla>02okG3i0Co/kWN0_n`/=P01?nV
[Mco0000o`000?l00002oj>TeP?oX9c@1?nMUL/3oiV>a`?oUXW30onCQ;l2oi60_0;oRhg?0on:S=03
ohZ=d@?oRi3C1?n<U=H4ohfJf`?oSZ;Q1?n?ZnT2ohbglP;oSFfZ1?n9J:L3ohIUY0?oSVjY0on;JJH3
ohQUY0?oRVFR0on<IJ04ohaUW`?oRfBO1?n8Hj43oh=QX`CoP6>X0on0Ijd3ohI_/@;oT7Rd00CoPeRG
ohAKV_n4Fi[oQ5^J0on7H9h4ohiXXPCoUW2U0onMM:D4oj5eXP;oXG:N00?oW:cRoj6Ic?nQVL`00onQ
VL`3ojF<^PCoZXJ^1?n/PZL2ojj1X`03ojb6[OnnW;Go]Xb[00?o]Xb[1?n/PZL00onSO:Wo^YB`okZD
/002okZD/0Co/Hb_00?oaJFhokZD/?njU;000_njU;02oj^9/@?o_Yni0onfV;P00oo6[<7o]ibmokNL
_@02okNL_@?o[9S20_nkZ<H4ok2RbP03ojNSd_naZ<oo/JS?00;o/JS?0onYYm@00ona/=Oo[:oJojb_
fP03ojb_fP?oYk3O00?o[;?MojVch?nY/n000_nY/n04ojJeh`03ojFhionX^>GoZ;SU00;oZ;SU0_nW
^^L00ol0003oYk[WojJkj004ojNki`?oYkcY00?oZ;gYojNnjOnW_^T00onW_^T2ojNnjP;oZ;oZ1?nX
_n/2ooooo`?o00003?ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0M
ooooo`Co]L?T0_nc^Mh01?nY]^?o0000o`000?l00002ojJ]g0CoXjCF0onPW=02oifEb`04oi>Jeon@
UMCoT9GDoi2Ee0?oSY7B0on<S]05oh^=c`?oRXc@0on:SM43oh^@d`CoS9CF1?n=V]/3ohjRh@;oSj_Y
0_nAM:h3ohe]ZPCoRFRW0on6IJ@3ohARX`?oPV6T0on8IJ@3ohYUXPCoS6FP0on<IIl3oh]TW`CoR6>Q
0_n3HJ<2oiJ?bP?oO[kk0_n9FiH4ohAHU@?oPeRG0on4FiX3ohMPWPGoSVRR0onFL:D3oiedY@;oXGFR
0_nG`O@4oib/hPCoXIW<0onUS;X4ojZ6[PCo[8:W00?o[X6Sojb6[OnnW;D00_nnW;D3okJ<Z`Co[8:W
1_njU;02ok6<[`;oaJFh1?njU;000on[RK7o_YniokjO^@02okjO^@;o]YRh0_o6[<45okNL_@04ojbH
`_nkZ<Ko^jS6ok^XaP?o/:;:00?o^Jk>ok6XconaZ<l01?naZ<l01?nYYmCo/K3Gok6`eona/=L4ojb_
fP03ojN`gon//mgo[;?M00;o[;?M1?nY/n02ojJeh`;oZ[SS1?nX^>D2ojNji`03ojRki_l0003oZ;_V
00CoYk_W00?oYkcYojRmjOnX_NT00_nX_NT3ojNnj@KoZ;oZ0_nX_n/2ojS0j`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool07_ooool2okG3i0;o
Z/7Z0_l00002ojVfh`CoYZgL0_nSY=H01?nHY]ooUIoKoiFOfonEWm/4oi>Je`?oT9GD0on>TM83ohb>
d0CoRhg?0on:S=03ohZ=d@?oRi3C1On<U=H2ohfJf`03okN`d_nMQKWoUgbc00;oUgbc1?nAM:h3ohe]
ZP?oRFRW0on6IJ@3ohARX`?oPV6T0omoHJD3ohYUXPCoS6FP0on<IIl3oh]TW`;oR6>Q0_nHP;P5oiJ?
bP04ogjnnon9FiKoRE^FohUKUPCoQ5RE0on3F9L3ohAKVPCoQf2N1?n>J:83oiI`Y@;oWGBU0_nId?/4
oiO1m0?oW:cR1?nQVL`3ojF<^PGoZXJ^0_n/PZL00on]Qjgo[8J]okjL]@03okjL]@Co]Xb[0_n/PZL2
ol2Q^@Go^YB`00Co/Hb_olFU^?o5YKSoaJFh1?njU;05okjO^@03okJH^?o6[<7oaZc100;oaZc10ong
W;d00oo2/l_o^jS6ok^XaP03ok^XaP04ok2Rb_ni[/ko^Jk>okV^cPCo/JS?00?o^KKFok6`eona/=L0
0ona/=L2ojb_fP;o/KGL1?n//md2ojVch0;o[;SR1OnZ^><2ojRhi@;oZ[[U0onX^nH01?l0003oZ;_V
ojNkionW^nL2ojVmj0CoZ;gY00?oYkkYojRoj_nX_nX01?nX_nX7ojS0ja3ooooo00?o0000oooooooo
ool04?ooool002;ooooo0_l0000Pooooo`?o00000_nZ`NX3ojVfh`;oYZgL00?oVZgToiRVgonHY]l0
0_nHY]l3oiFOf`?oTi[G0on@UM@3ohjAdP?oS8k@1On;SLl3ohZ<d0?oRXgA0on;T=<2ohbDeP;o_;gJ
00?oY8nooif5^OnMQKT00_nMQKT3oiMl/`?oTGB^0on=KJX3ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U
0on2IJP4ohaUX0?oS6FO0_n;I9l00onFN[7oV82hoiR0^003oiR0^0CoUXo:00CoSV2HohUKU_n9FiKo
RE^F1?n4F9D3oh=HU`CoQ5^J0on7H9h4ohiXXP;oUW2U0onTdoP3oiW@n`CoUl7d0_nL[>85oj6Ic0?o
YHbj1?nZQZh00on/PZOo[HN]ojf7[@05okjL]@Co]Xb[00Co[8:Wol2Q^Oo0XKWo`:6i1OnjU;05olFU
^0;o^YB`0_o:]<@4okjO^@GoaZc100?o]ibmol:cboo2/l/00_o2/l/3ok^XaP03olBme?ni[/ko^Jk>
00?o^Jk>00?o/JS?okVfe_ni]]H00_ni]]H3ok6`e`03okFjgOna]Mco/KGL00?o/KGL0_n//md2ojnj
h@Co[;SR0_nZ^><2ojbki@GoZ[[U0_nX^nH00onY_NSo0000ojVmj004ojVmj0;oZ;gY0_nY_nT3ojRo
jP;oZL3[2?nX`>/@ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo01co
oooo0ol000000oooooooZ/7Zoj[1jP02oibmk`CoVkGZ0onJ[N@3oiRVg`CoUIoK0onCV]L3oi2Ee0?o
SY7B0on<S]02oh^=c`?oL;cm1?mS`od2odg4l@?o`<OP00?oZY[5ojB?_onTSkl00_nTSkl3oif5^@?o
Ugbc0onAM:h3ohe]ZP?oRFRW0on6IJ@3ohARX`CoPV6T0_moHJD3oh9UZ0CoR6b/0on?LZh4oiIj/@Co
V82h0onFSlX2ohiPV0?oRE^F1?n4F9D3oh=HU`CoQ5^J0on7H9h2ohiXXPCo[/W]0_nTdoP2oi=]Y0Co
UVnT1?nILJ@00onKLZ?oXIW<oj6Ic002oj6Ic0?oYHbj0_nZQZh2ojb8[`;o[HN]0_o9^l`4okjL]@Co
]Xb[1?o0XKT4okZD/003omO@d_o5YKSoaJFh00?oaJFh00Co^YB`olZda?o:]<Cob[C40onnWkT2om38
d`CoaZc11_o2/l/01?nkZ<Koa;gDolBme?o4_M@3okV^cP03okbog?ni]]Ko^KKF00?o^KKF00?o/K3G
okFjgOne^]d00_ne^]d3ok6eg003ok:nhon_^^7o[k[Q00?o[k[Q0_n/^>82ojjmi@Co[;_U0_nZ^^D2
oj^nj0?oZKgX00Co0000ojVmj?nY_NSoZKgX1onY_nT00onX_n[oZL3[ojW0j`02ojW0j`;oZ<3[0_nX
`N/4ojS0j`oooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool06Oooool3
o`0000Kooooo0onL_Nl4oi^ejP?oVZgT0onHY]l2oiFOf`03ohN^kon4[NooQ:g_00;oQ:g_0on1[_44
ogf`m0CoMkGi0om`_?d2of?3o@?o`LoU00Co`<OPojZJaOnZV/GoZY[51?nTSkl3oif5^@?oUgbc0onA
M:h3ohe]ZPCoRFRW0_n6IJ@3ohARX`CoPV6T0omoHJD2oh9UZ0CoR6b/0on?LZh4oiIj/@GoV82h00Co
UXo:ohiPV?n>H9SoSV2H1?n9FiH3ohAHU@?oPeRG1?n4FiX2ohMPWP;o/;?K1?n^bNd2oi5[Y0CoTffT
0onFKj@4oiUaY004oi]bXonWRkSoYh^hojN;^0CoZHVc1?n/R:l01?n]QjgobK_<olVkc?o9^l`5okjL
]@;o]Xb[0_o5_M<4ol2Q^@;o^YB`0ooGd=83olFU^003olcOi_o:]<Cob[C400?ob[C400Co_Yniom38
doo@b=?od<SC0oo6[<42ol[>g@Co`[?;00?oaMGVolBme?o4_M@00oo4_M@01?ni[/ko_;oLokbog?nl
_m`3okVfeP;o^LCS1?ne^]d00ona]Mco/[kSok:nh`02ok:nh`?o[k[Q00?o[l7WojjmiOn^_ND00on^
_ND2ojbki@;o[;oX1?n[_^P2ojVmj003oj[0jOl0003oZKoY00KoZKoY1_nY`>/6ojS1j`;oZ<3[00?o
Z<7[ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0F
ooooo`?o00002_ooool3oibmk`;oVkGZ0_n=]O43ohbbl0?oR[3_0on7[^l4ohB]k`?oPJka1?mm/?@2
ogNen@;o>koI00Co/O?dol3Cj?o0dnSo`=?X0_o1cnD00on`Y<coZY[5ojZJa@03ojZJa@?oY8no1?nM
QKT3oiMl/`;oTGB^0on=KJX4ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U0on2IJP4ohQ/[0?oSg:^0onF
N[44oiR0^003og=GXonGJYcoSV2H00;oSV2H1?n9FiH3ohAHU@?oPeRG1?n4FiX00on7H9ko/;?Kok2c
f`02ok2cf`03ojk9kOnAK:GoTF^T00?oTF^T0onCKJ@3oiI_Y0;oVG6T0_nSRk/4ojN;^0CoZHVc1?n/
R:l4olVkc0Go_Ybe00Co]Xb[olFmdoo5_M?oaKgC1?o0XKT00onjU;3oem3BomO@dP02omO@dP;oaJFh
0oo<gnH3olZda003ojogk_o@b=?od<SC00?od<SC00CoaZc1ol[>gOo:c]gob/kM0oo2/l/3olGEiP?o
a;gD00?o_M;Zokbog?nl_m`00onl_m`00oni]]Ko^LCSokW4h`02okW4h`;o]K[M0_nca>L4ok:nh`03
ojnjhOn_`NOo[l7W00;o[l7W0on^_ND00on]`^Wo[;oXojboj003ojboj0;oZkkX0_n[`NX3oj[0j@03
o`000?nY_nWoZKoY00;oZL7[1_nY`>/<ojS1j`kooooo00?o0000ooooooooool04?ooool002;ooooo
0_l0000Dooooo`?o00003_ooool3ohjhl`CoSKGa0on</_03ohZ`k`?oQjk_0_n4[Nl4og75o`;oI/Sm
0_lj_lL3ojk]n005ok7cm?o0dnSo`=?Xol3Cj?nd[M801?n`Y<`4ojZJa@CoY8no0onMQKT3oiMl/`?o
TGB^0on=KJX3ohUXY`?oQVFT0on4HZ<3oh9QY0?oOf6U0on2IJP4ohQ/[0?oSg:^1?nFN[42oiR0^0?o
LeNS0on>H9P4ohUKUP?oQ5RE0on3F9L2ohAKVP?oZIc90on`/m/3oi5/Y@CoTF^T0onCKJ@2oiI_Y003
oij8_?nSRk_oXh^k00?oXh^k0onWRkP5ojV9/`;o[8R_0_o7l^h4olVkc0;o_Ybe0_nYkoP4olFmd`?o
`:6i0_moi;/4omO@dP03olFU^?o<gnKoc=oV00?oc=oV00Cob[C4ojogk_n_mnko[oO^0oo@b=<2ojW^
n0Cob/kM00?o`[?;olGEi_o5eNH00_o5eNH00oo4_MCo_M;ZokgBjP02okgBjP;o_;oL0_nfdNh4okW4
h`03ok7>konca>Oo/lCW00?o/lCW0_nb_^<2ok36jPCo[l7W00?o[[gUojg2jOn]`^T00_n]`^T2ojbo
j0;oZl?[1On[`NX2oj[0j@03ojW2jol0003oZL7[00?oZL7[0_nY`>/2ojW1j`CoZ<7[00?oZ<7/ojS1
jonX`N/01onX`N/=ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o00004_ooool3o`0001;o
oooo0on>^?<2ohfel@;oQ[Sf0on3^_P4ognmn`CoNL3m0_maaOl2oeO?j@03ogkUk_n^kOSo[^gh00;o
[^gh0onne>/01?o0dnSo]:gBokB]d_nd[M83ok2Tc0CoZY[50_nTSkl2oiB2_@?oSWZi0on8M;H3oh=_
]0?oSFfZ0on9J:L3ohIUY0?oQ6:S0on2HJ@3ogmQY@?oPVFX1?n8K:`3ohmb[PCoUWZa00?oV82hofmE
Y?m_EJ@00_mcEj<3ogaNY@CoRE^F0on4F9D2oh=HU`03oin8^onYW<WoZIc900CoZIc900?o/;?KoiIc
ZOnAK:D00_nAK:D4oi5[Y0;oTffT00?oVH>joij8_?nNR;`00_nNR;`4oj>;^`CoYh^h1?nYRK<00on/
R:ooao;^olObkP02olObkP;obK_<0_nOUl`01?lF003oZNohojW_n?nYkoP4olFmd`05ol2Q^OnNW]?o
[IW2ojJKbomoi;/00_oGd=800onVVl_oS9kOohbNg`02olcOiP?oUZCO1?n_mnh00oo@b=?oZNkhojW^
n002ojW^n0;ob/kM0onJjoT2olGEiP?oX^7l0_nmd^X2oj;Mo0Co]]7^00?o^LCSok7>konac^l00_na
c^l2ok?4i`;o[Lc`1On`a^X2ojo1i`;o[<G/0on]`^T2oj[5k@CoZl?[0_n[`NX2ojW3k0?oZL;[00Co
0000ojW2jonY`N_oZL7[0_nY`^`4ojW1j`03ojS1jonX`NcoZ<7/00;oZ<7/2OnX`N/<ooooo`03o`00
0?oooooooooo013ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00oooooo0_l0000Fooooo`?oRKOd
1?n6^?H3oh>jn0;oOkgk1?mjc_l2ofcBn`;oR^?k0on]i_T2ok_Ck0?o_]C[00?o][CGokB]d_nd[M80
0_nd[M84ok2Tc0;oZY[500?oVX_2oiB2_OnDP[d00_nDP[d3ohij^@?oR7Bf0on3Kk@3ogm]]0?oRFRW
0on6IJ@3ohARX`CoPV6T0_moHJD3oh9UZ0CoR6b/1?n?LZh2oiIj/@04ogMNZOm_EJCoKeFTofmEY0;o
LeNS0omlGZD3ohMYZP04ohUKU_n4F9GoQ5REoiAh/@CoWhRk1?nYW<T3ohE^/@?oSGBc1?nCO;L4oiV3
^P?oWXRl1?nSRk/4ojN;^0;oZHVc0_nSSKh4ojB@_`CoY9?300CoWiO<ojbF_on/U[oo[9Jo1OnZVLD0
1?nNW]?o[IW2ojfI`_n]VL84ojJKb`CoZ:3>1?nFY=l2of>Um@;oUZCO1?mcZ?82odZ/n@04o`VGd_m8
`ngoB<?]odS3k@;oX^7l0ombdod4oj;Mo0;o]]7^0onTe?P2ok7>k`;oY=3g1?n]c?02ok36jP;oZ/W`
1On/aN`00on]`^WoZ/G]oj[5k@02oj[5k@;oZl?[0_nYa>d4ojW3k0;oZL;[00?oZ<?]o`000?nY`^`0
1?nY`^`2ojW1j`?oZ<;/1?nX`N`6ojS1j`;oZ<3[3Oooool00ol0003oooooooooo`0?ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03?ooool3o`0001Wooooo0on9]o@2ohJhmP?oRKoi1?n3aod2og[>o`;oT]_n
0on[g?T00on]i_Wo^m?/ok_Ck003ok_Ck004okkDjonf]=Oo][CGokJde`Co]:gB0_n`Y<`00onQTlKo
VX_2oiZ;`P02oiZ;`P?oU8:m0on>N[T3ohQd]P?oPfnd0omoKK@3oga/]P?oO72k0on4HZ<4oh9QY0?o
Of6U0on2IJP4ohQ/[0?oSg:^00CoUWZaogMNZOmgGZWoMejY0_m_EJ@3og=GX`;oO5jU1?n7JJX4oiAh
/@?oWhRk0onYW<T01?n1Jk7oQFjaohE^/On5K[43ohed/`GoTgbg0onIPkX3oij8_0GoXh^k0_nWRkP0
0onPS;koXhfnoj>=_P03oj>=_PCoY92o0_nTTl<00on/Tkgo[9JoojbF_`02ojbF_`CoZYW500?o/YVn
ojfI`_n]VL800_n]VL83ojJKb`;o/j351?nXX<h2oiJTg`;oZj??1?nFY=l4og>XlP?oBZci1?lk/O82
og;Co@;oL<Go1?n8dOl2ojCDn0;oU]3l1OnTd?L2ojg<l0;oYL_d1?nZbO02ojc5k0?oZ<O`0_nZaNd2
ojO5k`GoZLC]0_nY`n`5ojS3k@03o`000?nY`^coZL;/00OoZ<;/1OnX`N`4ojS1j`CoZ<3[3?ooool0
0ol0003oooooooooo`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005
ooooo`;o00002_ooool3o`0001gooooo1On>^?<3ohVon@;oPlOm0onFd?`01?nBfokoZmcioj_LnOn[
g?T4okS@k0;o^m?/0_nh^]/4okJde`;o]:gB00?oYYc<oj6Ca_nQTlH00_nQTlH3oiZ;`PCoU8:m0on>
N[T3ohQd]P?oPfnd0omoKK@3oga/]P;oO72k0omnN/D4oh9QY0?oOf6U0on2IJP4ohQ/[0;oSg:^00?o
M5FPofMAY?mWDJ@00_mgGZT2ofmEY0?oLeNS0omlGZD3ohMYZPCoU7Ra1?nOR;/01?nYW<WoPF^aoh5[
/On1Jk43ohE^/@?oSGBc1?nCO;L3oiV3^PCoWXRl0onSRk/00onNS<7oX8bnoj2<_P02oj2<_PCoXhfn
0onTT;l00onYTKgo[9>mojbC_@02ojbC_@Co[9Jo00CoZYW5ok:I__nbVKko/YVn1On]VL801?nVVl_o
/j35ok>PaOncX<D3ojRPcP03okBSaon[XlooZj??00?oZj??0_nFY=l00onYYmGoVJ[SoiVZh`02oiVZ
h`GoP;3c0omX]O`4og35o`;oR=7o0on3aod3oiK@o0;oY=3g0_nLboP5ojG;m0;oZ/W`0onUbO82ojS7
l0;oYLK`1?nWaNl2ojW4k@;oYlC^1onX`nd00ol0003oZ<;]ojS2k008ojS2k0CoZ<7/1OnX`N/2ojS0
j`;oYl3[2oooool00ol0003oooooooooo`0?ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`06ooooo`?o00008Oooool2
ohjhl`?oVkc`1?nIa_H2oiK@o0?oZ];e00?oZmciokS@k?nhd>`00_nhd>`00ong_]oo^;[KokRjf`03
okRjf`;o][CG00?oZjGAojJLc?nVW<`00_nVW<`3oj6CaP?oVX_21?nDP[d3ohij^@?oR7Bf0on3Kk@3
ogm]]0?oO6bf0omlL;/2ogija@GoO8_F0om_Z_D01?nGN[7oRVVXohYYZ?n:JJP3ogmNXP;oM5FP1?mW
DJ@2ofmEY0?oLeNS0omlGZD4ohMYZP?oU7Ra1?nOR;/01?n1L;OoPF^aoh5[/On1Jk43ohE^/@?oSGBc
1?nCO;L4oiV3^P?oWXRl00?oXh^koif?aOnNS<400_nNS<43oj2<_PCoXhfn00?oY92oojVA_OnYTKd0
0_nYTKd3ojbC_@?o[9Jo1_nbVKh3ojfI`P03okNP`_ncX<Go/j3500?o/j3500CoZ:3>okBSaondXlOo
]:?70on[Xll00oneZLgoZJOEojVWe@02ojVWe@CoVJ[S0_n0/?<2oiV]i@GoR;;a0on1_OX2oh?7o@;o
SKog1OnCaoT3oic;n0;oYL_d0onPb?D2ojG9lP;oX/Kb1OnUa_02ojO5k`;oY/C_1?nWa>h2ojS3k@;o
Yl?]0onX`^d01?l0003oZ<;]ojS2k?nX`^`3ojO2k0;oZ<;/0_nW`N`4ojS1k0;oZ<7[1onW`>/:oooo
o`03o`000?oooooooooo00oooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo00?ooooo0ol0000Vooooo`CoVkc`0_nIa_H3
ojS9l0;oZ];e0onec>/00onhd>co]kkOokNng`02okNng`?o^;[K00?o[jgFoj^UdOn[YM400_n[YM43
ojJLc0?oXI?61?nJRl83oiB2_@?oSWZi0on8M;H3oh=_]0?oOffd0omlK;H3oga`^`?oOW[51OmlRmH0
0om_Z_GoUgZaoiMj/@03ohYYZ0?oOejR0omdEJ03ofMAY003odU?]_m_EJCoKeFT00;oLeNS0omlGZD4
ohMYZPCoU7Ra0_nOR;/00omcH[7oPG2goh5[/@02oh5[/@?oQFja0on=M;<5oi=l]`?oVH>j0_nNR;`3
oif?a@?oWXc11?nPS;h2oj>=_P03ojF?__nYTKgoZI6m00?oZI6m1?n/Tkd00on/U[oo/YVnok:I_P05
ok:I_P03ojfI`_ngX<;o]j3200;o]j320oncX<D00onjY/Go]:?7okBSa`03okBSa`04oj^SconeZLgo
]JW=okFYc@CoZJOE0_nIZ^<2ojV[f@CoVJgU0_n8/_42oi^bi`GoT[Sa0on=_oL2oi?7n@;oUl7d1OnJ
aOH2oj38m@;oWlCb1?nRa_82ojG6l0;oY<C`1OnVa>l2ojO4kP;oY/?^1?nW`nd2ojS2k@03ojO2kOl0
003oYl;/00?oYl;/1_nW`N`2ojS1k003ojO0k?nW`>_oYl3[00OoYl3[2_ooool00ol0003ooooooooo
o`0?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Ooo
ool01?l0003oooooooooooooool3o`0002[ooooo0_nK_?02ojS0j`?oZ<W`0_ncanT3okG<j`?o]l7Q
1?ng_]l01?nh^]_o[jgFojn]e_n_[MH3oj^Ud@CoYYc<0onQTlH2oiZ;`P04ohj6a_n8P/KoR8;6ohR2
aP?oPWo70on8M;H4oh=_]0?oOffd0omlK;H2oga`^`CoOW[50_mlRmH3oh1_]`?oUgZa0_n:JJP3ogmN
XP?oM5FP0omWDJ@2odU?]P03ofmEY?mcEj?oLeNS00?oO5jU1?n7JJX4oiAh/@04oin8^omcH[7oLf:a
og=R/@CoPF^a0on5K[43ohed/`CoTgbg0_nIPkX3oj6Hc0?oWHo50onNS<43oj2<_P03oj2<_onUSkko
YHnn00;oYHnn1?nYTKd3ojbC_@03ok6J`?nbVKko/YVn00Go/YVn00?o^:?3okNP`_ngX<800ongX<80
1?ncX<Go^ZK5okZVaOnjY/D4okBSa`03ok^[b_neZLgo]JW=00?o]JW=0_nYYmD2ok:[d@CoZJ_I0_nI
[ND2ojJ_gPCoVk;W0_nB^?42oijej@CoV;[`1?nG`O@2oi[5mP;oWL3a1OnOa?82oj;6lP;oX/?`1?nT
a?02ojK4k`;oYL;^1OnV`nh2ojO3k@;oY/;]0onW`^d00ol0003oYl;/ojO1k007ojO1k0CoYl3/2OnW
`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00oo^k^koA4A4o`000005ooooo`Co0000;_ooool4ojS0j`03ojS9l?ncanWo/lOY00;o/lOY00?o
]Lc[okO1hOng`N400ong`N42okNng`03ok6cf_n_[MKo[jgF00;o[jgF1?n[YM42ojJLc004oi^Dc?nE
SLWoUHg9oiF=b@CoSXK60on8P/H2oh9oa`?oO87<0omeR=P01?n3KkCoOffdogm]]?moKK@3oga/]P?o
O72k0_mnN/D3oi61_`?oP6ng0omdI;83ohYYZ0;oOejR0omdEJ03ofMAY0?oBDnf0omcEj<2ogaNY@Go
QfVZ0_nDN;43ogALZ@;oLf:a0omiML801?n1Jk7oQFjaohE^/On5K[43ohed/`;oTgbg0on/[MP4oj6H
c0CoWHo50onNS<401?nPS;koX8booj2<_onPS;l3ojF?_PGoZI6m00Co[9>mok6J`?naV/3o/I[01Onb
VKh3okRS``Co]j321OnjY/D2okBSa`;o^j_:1?neZLd00onk[lko/Z_Aok:[d@03ok:[d@;oZJ_I0_na
/=L4ojJ_gP;oVk;W0_nV/^44oijej@CoV;[`0_nG`O@2oiflkPCoWL3a0_nOa?82oj71k`GoX/?`0_nT
a?02ojC2kPCoYL;^0_nV`nh7ojK2k@;oYl;]00Co0000ojO1k?nW`NcoYl7/0_nW`>`5ojO1k0;oYl3/
2_nW`>/9ooooo`03o`000?oooooooooo00oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3Oooool00omgMgOo0000ooooo`04ooooo`;o0000<Oooool2ojS0j`?o/L;W0_ncanT2okK2h`Co]l7Q
00?o/kWNok6cf_na/mX00_na/mX4ojn]eP;oZjGA00?oX9c@oi^Dc?nKU<`00_nKU<`3oiF=b@?oSXK6
0on8P/H3oh9oa`?oO87<1?meR=P4ofFKk`03ob>ViOna[MCo/JgD00?oXIK90onAPKl3oh1_]`?oM6Bb
0_mXG;400on:JJSoOejRogmNXP03ogAEX0CoIe6T1?m9CkH01?mcEj?oO5jUogaNYOmlGZD4ohMYZP03
oiAh/OmmHj[oM5bY00;oM5bY0omcH[43ogUe`PGoOYkV00CoJ=?hokoAionodNOo_m7W0on/[MP3oj6H
c0;oWHo50_nFQl83oi^9`0CoX8bo0onUSkh4ojVA_@03ojfI`_naV/3o/I[000;o/I[01?nbVKh4okRS
``?o]j320_nmZ/L4okZVa@03okBSaonkZl[o^j_:00;o^j_:0_neZLd3ok^_cP?o/Z_A00?o^;;Cok6`
eona/=L00ona/=L2ojJ_gP03ojjbfonV/^7oY[;Q00?oY[;Q0_nN]NT2ojJfi0CoX;SY1?nM_>h2oig0
l@;oXKg]1?nQ`Nl2oj;3l0;oXl3^1OnT`^h2ojG2kP;oYL7]1_nV`^d3ojK1k0;oYl7/00?o0000ojO0
k?nW`>`00onW`>`2ojO1k0ooYl3[2?ooool00ol0003oooooooooo`0?ooooo`008_ooool00ol0003o
ooooooooo`0_ooooo`?o/L;W0_ne`n@4okK2h`03okO1hOnc^Mko/kWN00;o/kWN1?na/mX2ojn]eP03
ojFTe?nPW=3oX9c@00;oX9c@0onKU<`3oiF=b@?oSXK60on8P/H3oh9oa`?oO87<1OmeR=P2ofFKk`04
okg3gona[MCo/JgDok6]e0?oXIK91?nAPKl2oh1_]`?oM6Bb0omXG;43ogmNXP;oM5FP1?mWDJ@3odU?
]P;oSHc=0omlGZD2ohMYZP04ohad/ommHj[oOF>ZogeSZP?oM5bY0omcH[44ogUe`P?oOYkV0_oBn>@2
okoAi`04oibMe?nDS/_oU8k;oiB>b`?oThS51?nFQl84oi^9`0?oX8bo1?nUSkh01?nYTKgo[IW2ojfI
`_n]VL84ok6J`0?o/YVn0_nhYLH4okRS``04okNP`_nmZ/Oo_J[7okfZa`?o^ZK500?o_[3<ok^[b_nk
ZlX00onkZlX00oneZLgo^jo>ok^_cP02ok^_cP03ok:[dOnh/]?o^;;C00;o^;;C0ona/=L00onf]=Oo
[[;Kojjbf`02ojjbf`?oY[;Q00?o[;GOojJfi?nV]^@00onV]^@2oj2hj@03ojJhi_nS^^[oXk[Z00;o
Xk[Z1OnQ_Nd2oj71k`;oXkk/1?nS`>h2ojC2kP;oYL3/1OnU`Nd2ojK2k@;oY/3/0_nV`N`5ojO0k004
o`000?nW`>coYl3/ojO0k1;oYl3[2Oooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003o
ooooooooo`0_ooooo`03ok72ione`nCo]L?T00;o]L?T0_nf`^<3okBnh@Co/kWN0_na/mX00onY[=Wo
YJCDojFTe002ojFTe0?oX9c@1?nKU<`3oiF=b@?oSXK60on8P/H3oh9oa`?oO87<0_meR=P2od33d0Co
_L?O0ona[M@3oj6Fb@?oTH6o0on0KkL2ogAT/P?oJ5ba0_mZI;T01?moGZ;oM5FPogAEX?mdEJ03ofMA
Y004odU?]_nMdO[o_LORokg7hP;oSHc=0omgKKX2of]P]0CoOF>Z0_mdG:T3og=R/@CoNGG200?oOYkV
ojW^n?oBn>@00_na^n44oibMe0?oU8k;0onCR<D4oiJ7`P?oVhW01?nPS;l2ojF?_P03ojRHaOn]VL;o
[IW200?o[IW21?naV/001?nbVKko^:G6okRUa_nhYLH3okRS``03okf_c?nmZ/Oo_J[700?o_J[700Co
^ZK5okj`c?nn/<co_[3<0onkZlX2okjdd0?o^jo>00?o_KODokRbdonh/]<00onh/]<00ona/=Oo][CG
okJde`02okJde`Co[[;K00CoY[;Qojbegon/]Moo[;GO0onV]^@00on[]n;oY[SVojJhiP02ojJhiPCo
Xk[Z0_nQ_Nd2ojBljPGoXkk/0_nS`>h3ojFnj`?oYL3/0_nU`Nd3ojJok0;oY/3/0_nW_n/6ojO0k003
o`000?nW_n_oYl3[00KoYl3[0_nW_n/<ojO0j`Sooooo00?o0000ooooooooool03_ooool002Cooooo
00?o0000ooooooooool0;oooool3okG3i0;o]<?U1Ond_^42ok>igP03ojbcg_nY[=WoZJcI00;oZJcI
1?nUY=@3oj2Ld0;oViC<00CoTIgLohbKgOn<VmgoS9_M0on5W>44oh2Sj@CoNK7f0_mZb?h4ol?Di`;o
_L?O00CoXIK9oiF6`OnEQ/7oUHK10on7N;`3oga_^@?oP6ng0omdI;83ofQL/@;oJVBi0omdEJ02ofMA
Y0?oWM7j0_n8N[h2ofaQ]@?oMffj0_m[H;@3og1W^@04ogeSZ_mdG:WoM5bYogALZ@?oLf:a0_miML82
ojW^n003olSSjona^n7o/K_Q00;o/K_Q0onLWM@3oiB>b`?oThS51?nFQl84oi^9`0;oX8bo00?oXYC6
ojRHaOnXV<D00_nXV<D4ojfI`P?o/I[000?o]JO;okRUa_nhYLH00onhYLH01?nhXl?o_Jo<okf_c?nm
[l`3okfZa`03oknfdOnn/<co_[3<00?o_[3<00?o^j_:okjdd?nn]=000_nn]=001?nk[lko_KODokfg
e?nm]m@3okRbd`03okZheonf]=Oo][CG00?o][CG0_n^/]/2ok:fg0Go[;GO00CoY[KToj^gh_n[]n;o
ZkOR1?nV^>H2oj>jjP;oY[[W1?nT_>X2oj>nk0?oY[cZ0_nU_^/2ojJmjPGoY[k[0_nV_n`00onW_^_o
Yko[ojNoj`03ojNoj`;oYl3/1?nW_n/01?l0003oYko[ojO0jonW`>/7ojNoj`;oYl3[00?oYko[ojO0
jonW`>/01onW`>/7ooooo`03o`000?oooooooooo00kooooo000Uooooo`;o0000<?ooool00one`nCo
]<?UokC3i@02okC3i@;o];kQ0on_^n83ojbcgPCoZJcI0_nUY=@01?nLYmkoUj;LoiNRg?nGX]`4oi6M
g0?oS9_M0on5W>44oh2Sj@;oNK7f00?oL=k4ol?OkOo3gnd00oo3e>L00on/Y]7oXIK9oj6Fb@02oj6F
b@?oUHK10on7N;`2oga_^@;oKVRk00CoP6ngogAT/_mdI;;oM6Bb0omXG;42ofYT^@CoNH7?0onMdOX3
ohQj_P?oK66e0_mgKKX3of]P]0?oL6Ni0on2OlP2og=R/@?oV:kV00CoZNkholSSjoo8hn_ob>?[0ona
^n44oibMe0?oU8k;0onCR<D3oiJ7`P;oVhW00_nLT<L4oj:DaP?oZ9S51?n]VL800onaV/3o]JO;okFW
b`02okFWb`?o^:G600?o^kGCokf_c?nm[l`00onm[l`01?nmZ/Oo_kKAoknfdOno]]43okj`c003ol2k
eOnn]=3o_[C@00?o_[C@1Onm]m@01?nh/]?o^[SGokZheonj^=L3okJde`;o]k[K1?nb]]`2ojbeg`;o
/;SO1On[]n82ojJhiP03ojZii?nV^^OoY[[W00?oY[[W0_nT_>X3ojNkj0;oY[cZ0_nW_>P4ojJmjP;o
Y[k[0_nW_^X4ojNnj`;oYko[0_nW_nX7ojNoj`03o`000?nW_n_oYko[00_oYko[2OnW`>/6ooooo`03
o`000?oooooooooo00kooooo000Wooooo`03o`000?oooooooooo02kooooo0ond`nD3ok32i`Co[k_R
0on//mh2ojV/f@;oXJgQ0onLYmh3oiNRg0CoTIgL0on<Vmd3ohFLh@;oP:?Y00?oO>KVojOgjOnWmnT0
1?o3gnd01?o3e>Oo[:KAojbVdOn/Y]43oj6Fb@?oUHK10on7N;`3oga_^@;oKVRk0omdI;83ofQL/@?o
JVBi1?miPLl00onMdO[oYj3?ojNPc`03ohQj_P;oK66e0_mTH;P00omgKK[oJf2dof]P]003og1W^@Co
PWo80onH[^H2omOkgP;ob>?[00CoY:WJoi>BconCT/ooTi;?1?n:Q/T3ohZ3aP?oSXK60onDRlH4oib@
a`CoXYC61?nXV<D2ojfI`P03ok6Xd?neYl_o]JO;00?o]JO;00?o^:G6ok^edonk]M<00_nk]M<3okf_
c003okbmf_no]]7o_kKA00?o_kKA00Co_[3<ol2keOo0^mGo`;_E0onn]=02okjmf0?o_KOD00?o_KkK
okZheonj^=L00onj^=L00onf]=Oo]k[KokNjf`02okNjf`;o/[KL0_nd^]h4ok2hg`;oZkOR0_n]^N84
ojZii0;oY[[W0_nY^^H4ojNkj003ojVlionW_>SoYkcX00?oYkcX0_nV_NX2ojRmj@CoYkkZ0_nW_^/2
ojNnjPCoYkoZ0_nW_n/2ojNojP?oYko[00?o0000ojNojonW_n/02onW_n/8ojO0j`Kooooo00?o0000
ooooooooool03_ooool002Sooooo00?o0000ooooooooool0;_ooool00ond`nGo/<;Wok32i`03ok32
i`;o[k_R00?oY[[WojBdi?nT]>@00_nT]>@4oj6]h@?oW:ON0onGX]`2oi6Mg0;oQ[_g1?mma?h01?mW
c__oWO7aoigalOnMlO43okgRlP;o`mo]00?o];CIojbVdOn/Y]400_n/Y]43oj6Fb@?oUHK10on7N;`3
oga_^@;oKVRk0omQKLP4ofQL/@;oJVBi0omiPLl01?o:cmgoYj3?ojNPconWX<l3ohQj_P?oK66e0_mT
H;P2of]P]0CoL6Ni1?n2OlP01?nH[^Koeo_NomOkg_o2cN<4ojBYfP?oTi;?0on:Q/T4ohZ3aP?oSXK6
0onDRlH4oib@a`?oXYC60onXV<D00on/Z=?o/JS@ok6Xd002ok6Xd0?o]JO;00?o]k[Kok^edonk]M<0
0onk]M<00onm[lco_;gJokbmfP02okbmfP?o_kKA00?o_/?Nol2keOo0^mD00oo0^mD00onn]=3o_[gH
okjmf002okjmf004okfge?nm_]_o_KkKokfnf`?o^[SG0_nj_]d3okNjf`03okNngond^]ko];[N00?o
];[N0_n`^=l2ok6kh@Co[KWR0_nZ^N@2ojbji0CoZK[V00?oYk_XojVlionY_>L00_nY_>L2ojNlj0;o
ZKgX1OnX_NT2ojNnjP03ojRnjOnW_^[oYkkZ00?oYkkZ0_nW_nX2ojRnjPCoYkoZ0_nW_n/00ol0003o
Z;o[ojNoj`0<ojNoj`SoYl3[1Oooool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003ooooo
ooooo`0_ooooo`;o/<;W0onW`>/3ojJji`CoY;CT0_nQ[N42oiVfk0?oTkG^1?n>]_43ohJkm`;oOLCn
00?oQN;joigalOnMlO401?nmh_800onh`>3o];CIokBdf@02okBdf@Co[:KA0onQU/T3oiF6`@?oQgRl
0_mlKkT3ofiX^`?oHFg80_leQ^/01OmXG;7oJVBiofYT^OmZI;WoNH7?00;ob/oM0onWX<l3ohQj_P?o
K66e0_mTH;P2ofQbbP04of]P]?m`IkWoL6Niog1W^@?oPWo800?o[_[DomOkg_oGnmh00oo2cN<3ojBY
fP?oTi;?1?n:Q/T3ohZ3aP?oSXK60onDRlH4oib@a`CoXYC600CoZ9S5ojbXdon/Z=?o[:SC1?naZ=00
1?neYl_o]k[KokNjfong^]/3ok^ed`03okS3honl_M[o_;gJ00?o_;gJ00?o_kKAokk3g_nn`mh00_nn
`mh2ol2ke@;o_LCO1?nn_MP00onla>7o_KkKokfnf`03okfnf`03okZheonj_]go^[kM00;o^[kM00Co
]k[KokNngong_]oo]kkO0ond^]h00ond_N7o/K_Qok6kh@03ok6kh@;o[KWR0_n_^n<4ojbji0;oZK[V
0_n[_>H3ojVli`;oZ[cW1?nY_NP2ojRmj@;oZKgX1?nX_^T2ojNnjP;oZ;kY1OnX_^X2ojNojP06ojRo
j_nX_n_oZ;o[ojRojol0003oZ;o[0_nW_n/2ojRoj`KoYko[2onW`>/4ooooo`03o`000?oooooooooo
00kooooo000Zooooo`;o0000<Oooool4ojO0j`?oY[[W0_nT]>@2oibhk0CoVKK/0onC]Nh2ohjfl@?o
T<km0_n;f?l2oi_ZnP?o]n7d00?o_N;bokS0h?nh`>000_nh`>04okBdf@;o[:KA00CoVIO@ohf;c?n=
RlcoSH_<0on3Pl/3ogMnc@?oO6ni0_m^J;/4of5]b005ocF6jonjn[oofoCOom_dgong_n000onJVm<3
ogQjb0;oK6g20_n8N[h2ofaQ]@?oI62h0_mXL/X3og1W^@05oh9ob?n^n]Co[_[Dom;ocOoFk^<01Oo2
cN<3ojBYfP?oTi;?0on:Q/T3ohZ3aP?oSXK61?nDRlH3oib@a`;oXYC60_nVY]H5ojbXd`;o/JS@0_nb
_N84okNjf`04ok^edonh`n?o^<?SokS3h`?o_;gJ0_nhbNL3okk3gP;o^<[X1?nma=l00onn_MSo_<CQ
okc4h@02okc4h@;o_KkK0_nj`n44okZng@03okS2h_ng_]oo]kkO00;o]kkO00?o];[NokBmhOnd_N40
0_nd_N42ok6kh@;o/KkS1On_^n<2ojbji003ojfliOn[_>KoZkcV00?oZkcV00?oZKcWojZlionZ_>L0
0_nZ_>L2ojVmj0;oZ[gX1?nY_NP2ojRnj@;oZKkY1?nX_^T2ojRnjPKoZ;oZ0onX_n/00ol0003oZ;o[
ojRoj`03ojRoj`;oYko[0_nX_n/=ojO0j`?ooooo00?o0000ooooooooool03_ooool002cooooo00?o
0000ooooooooool0;oooool2ojO0j`;oX;k^0onN^nd4oibhk0;oVKK/0_nF`_D4oi;6n@;oT<km0_nI
h?d3ok3LmP;o]n7d0_nhb>H5okS0h0;o];CI00?oXZ;DoiVGd?nIUm000_nIUm03ohf;c0?oPh?;0_mg
O/d3ogB7e`?oKVRk0_mQKLP01?n7h__o^_Zoom_dgooKm=l3okNoh0?oVY_C0omhN/P3ofa]`P?oK66e
0_mTH;P4ofQbbP04ogFcn?n^n]Co[_[Dom;oc@?oe^kS0_o2cN<2oj:Zg0?oS9;D0on4R<l3oh>6c@Co
RX?60on>Q/H2oiB;aP04oiNIe?nOXMKoWj7FoinQePGoYZKF0on/Z=<00on/_^Oo/[gRok:mhP03ok:m
hP;o]k[K0_nbb>/4okS3h`03okbmf_nhbNOo^<WW00;o^<WW00?o_/?NokS:j?nhb^P00_nhb^P2okg4
g`;o]l[Y0onla>42okO8j0Co^/?Q00?o^[kMokS2h_nh`^800_nh`^82okNng`;o]L7S0ond_N42ok;1
i0Co/KkS0_n_^n<2ojnni@Co[KcU0_n[_>H2ojbmiPCoZ[cW00?oZkkWojZmj?nZ_NP00onZ_NP2ojVm
j0KoZKkY0_nX_^T2ojRoj@SoZ;oZ0onX_n/00ol0003oZ;o[ojRoj`07ojRoj`;oYl3[0_nX`>/9ojO0
j`?ooooo00?o0000ooooooooool03Oooool002gooooo00?o0000ooooooooool0;oooool4oj2nkP?o
W[_]0_nL^>`2oiRolPCoU/;e0_nBa_T3oiWFo@04oiWPoOn`g?Ko/=cfok3LmP;o]/_Z1?nhb>H2okS0
h0;oZJcI1?nRX]@3oiVGd0?oSH_<0on3Pl/3ogMnc@?oM8OG0omhY>h00ol0003ob?oLolSog002olSK
i`Co]koP0_nJVm<3ogQjb0?oK6g20omXKlL2ofAP^0?oJ7;:0on^fOH01?oBolgoe^kSomK^hooFk^<2
ok[8i@CoXZ[L0on<T]@3ohB8c`;oPhK=1?n8R/l3oi2Bd@CoUiWD0onOXMH4ojJVeP03ojbXdon/_^Oo
[;kW00;o[;kW0_nb_N82ojc<l0Go//S[0_nh`n<3ok7?l0;o^<WW0_n_co43okS:j0;o/<o`1?ngb^T0
0onla>7o]lSXokO8j002okO8j0;o^/?Q0_neanL3okS2hP;o]<GW1?ne`N<00ond_N7o//7Tok;1i002
ok;1i0;o/KkS0_n``>H4ojnni@;o[KcU0_n]_^H4ojbmiP03ojZlion[_^OoZkkW00;oZkkW0_nZ_NP2
ojZnj0KoZKkY0_nY_nT5ojRoj@SoZ;oZ0_nX_n/00ol0003oZ;o[ojRoj`05ojRoj`OoZ<3[2?nW`>/3
ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_nP_^h2oibm
k`CoV[ga0onH_o82oiK2m@?oV/kj0_nIe_d3oj_FmP03ok3Lm_nfbn[o]/_Z00;o]/_Z0_nhb>H2ojne
gPCoZJcI1?nRX]@3oiVGd0?oSH_<0_n3Pl/3ogMnc@CoM8OG00CoN:C^ojKhf?o8omcob?oL1?o8fnL2
okNoh004oiBDdOmoOlWoOgo9ogmob@;oN7[80om/KL83ofQ_a`?oO9;N00GoJ7;:ojkIm_n^fOKo[]Wf
ol[of@02omWlg003om3SiOnjb>Go^/SU00;o^/SU0onRZ]`3ohbBe0?oQ8S?0on3Q/d4ohR:c`?oT9;A
1?nGVM@3oinQeP;oYZKF0_nW_>P3ojbni`;oZ<gc1?n/c?02ok;8j`?oZ=;f0_naco02ojOBmPGo[loa
00?o^<[Xok3?l?n`co000_n`co02okO:j@?o/<c_0_ngb>P00onabngo]LOWokG7i`03okG7i`03okS2
h_ndaNOo]<GW00;o]<GW0_ne`N<00onba>Oo//7Tok;1i002ok;1i003ok32ion``>Ko/<3V00?o/<3V
0_n__^D2ojk0i`Co[KkV0_n/_NH2ojbni`?oZkkW0_n[_nP4ojZnj0;oZKkY1_nY_nT2ojRoj@;oZKoZ
1_nX_nX2ojS0j`?oZ;o[00Co0000ojRojonX_n_oZ;o[2onX`>/8ojO0j`;ooooo00?o0000oooooooo
ool03Oooool002oooooo00?o0000ooooooooool0;oooool4oibmk`;oV[ga0_nL`O84oi_7mP;oV/kj
0onWcoD2oj_FmP?o/lc]0_nfbnX2ok2khPCo[kGN0onY[=T2oj:Re0;oUY[F0on>U=H3oh>Bf@?oOIWT
0omgO/d2ogB7e`03ofCClonQkOSo]ocQ00?ocN_Z0_o8fnL00on/[]WoU9CAoiBDd@02oiBDd@;oOgo9
0omXLLP3ofa]`P?oJ6o71?mlT]h01?n^fOKob_oIomWlg?oIo=`3om3Si@;o^/SU00CoWjWMohjFe_n>
U]KoSYKF0on1RM<01?n<T]CoQ8S?ohB8con4R<l3oh>6c@?oR8[?1?n@T]42oiNIe0;oVk3V0onR^>P4
ojNlj003ojbnionXcO?oZ<gc00;oZ<gc0_n/c?03oj?Dn@;oZ=;f0_nQdoX4ojOBmP;o[loa0onVdOH2
ok3?l0;oZ<kd1?n`c>l00onYc?;o/L_]ok7;k@02ok7;k@;o]LOW0on`b>`2okC5i`;o/<K[1?nba>L0
0onb`NCo/<;Wok32i`02ok32i`;o/<3V0_n_`^P5ojk0i`;o[KkV00?o[L3Xojbnion/_^L00on/_^L0
0on[_^OoZkoXoj^oj002oj^oj0;oZ[kX00?oZ[oYojVojOnY_nT01OnY_nT6ojVojP;oZ;oZ1_nX`>/2
ojRoj`03ojS0jol0003oZ<3[00coZ<3[2?nW`>/2ooooo`03o`000?oooooooooo00gooooo000`oooo
o`;o0000<?ooool2oibmk`;oW[g_1?nL`O82oi_7mP?oYLWb0_nWcoD2ojo:kP?o/lc]0_na_nD4ok2k
hP;o[kGN00CoY:WJoijReonNX]OoWZ;G1?nFV]H4ohjDeP?oPi;I1?mmVN@2og>_m`;oXNgh00Go]ocQ
olg[j_o=jn[ocN_Zokg7hP04ojb^f@?oU9CA0omoOlT2ofQab0?oJGoF0omXKlL2ogbBgP03oioal_o:
omWob_oI00;ofOcL0oo@hnD00oni`n;oWjWMoinYg@02oinYg@?oSYKF0on1RM<3ogn9d`?oQ8oG0on;
VM`4oiBVh@GoVk3V0onR^>P2ojNlj0?oYLcd0_nXcO<3oj7EnP;oXmCi0_nNe?/4oj7CnP;oYm;f0onO
d_T2ojKAmP;oXLoh1?nXc_@00on`c>ooZLcbojW<lP02ojW<lP;o/L_]0_n[b_03ok38k0;o[<S^1?n`
a^/2ok;4i`;o[lGZ0on``^L2ojk4jPCo[l;X0_n^`>L2ojg1j0Co[L3X0_n/_^L3ojc0j0;oZkoX0_n[
`>T4ojZoj@;oZKoY0_nY`>X7ojVojP03ojW0j_nX`>_oZ<3[00WoZ<3[00?o0000ojS0jonX`>/03?nX
`>/8ojO0j`03ooooool0003ooooo00kooooo000booooo`03o`000?oooooooooo02kooooo1?nN_Nl2
oic1lP?oY<?`0_nUbO82ojc7k@Co[l[^00?o/lc]ok6oiOna_nD00_na_nD2ok2khP03ojV`gOnTZM[o
Y:WJ00;oY:WJ0onNX]L4oiJJeP?oSYCF1?n3T]T2ogfIi0?oTm7m00GoXNghol?_l?o3ko3o`no`olg[
jP03okg7hPCo[:kI0_nDU=43ogmob@?oJ7780omYOmH3ohB`lP?o`Noa00God_gNomOahooGlN?oeo7S
om3Si@03okW3hPCoWjWM0_n>U]H4oh69d`?oOhWC0on4SmL3oh^Ig0CoU:KQ0_nK/>H2oj33l@GoXlWc
0_nUc?@3oj;EnP;oXMGj0_nOe_/4oikDn`;oXM?j0onLd_/2oioBn@?oWLoi0onQcoP2ojS>m0?oXlgf
0_nYc?82ojG;l`CoZl[`00?o/<S/ojc8k_n/b>h00_n/b>h2ok36j`;o[LO]1?n_aNX00on``^Oo[/CZ
ojk4jP02ojk4jP;o[l;X0_n]`nX4ojg1j0;o[L3X0_n/`NT3ojc0j0;oZl7Z1?n[`>T2ojZoj@;oZ/3Z
1?nY`>X2ojVojPKoZL3Z2?nX`>/01?nX`N_oZ<3[ojS0jol0000;ojS0j`[oYl3[00?oooooo`000?oo
ool03_ooool003?ooooo00?o0000ooooooooool0;_ooool2oijmk`?oY;o]0_nT`o02oj[3k0Co[<O]
0_n_b^h3ok31i`;o/KoU00?o[;KPojV`gOnY/=d00_nY/=d4ojBYfP?oWZ;G0onFV]H2ohjDeP;oSZ_Y
1On<]o<2oi?Ao@04oj?cl_o3ko3o`no`ol?_l0?o`]OY0onman82ojb^f@04oiBKeomnRMCoOXWDogj9
e0?oOgo90_mXLLP4ofUoeP05ohB`l_o1ko7o`Noaol7_lOoBoMh00ooGlN<3ol_Ki@?o^L?R0_nOZMd0
1?n>W=coPi;Ioh>BfOn3T]T3oh69d`CoOhWC0on4SmL3oh^Ig0;oU:KQ0_nK^^h4oj33l@;oXlWc0onS
e?T2oj;EnP?oXMKj0_nOe_/2oioCnPKoW=;k0onLcoT2oig?n@;oW<ch1?nNc?L2oj?=mP;oXL[e1OnU
bo<2oj_:l0?oYlWa0_n/b>h00onYao3o[LO]ojg7k@03ojg7k@;o[lGZ0on/aN`2ojk4jP03ojc4k?n]
`n[o[L?Z00?o[L?Z0_n]`NP00on/`^[o[<7Yojc1j@03ojc1j@03ojc0j?n[`N[oZl7Z00;oZl7Z0_n[
`>T00onZ`N[oZ/3Zoj[0jP03oj[0jP;oZL3Z0_nY`N/6ojW0jP;oZL7[1OnX`>/4ojS1j`;oZ<3[00?o
0000ojS1jonX`>/01onX`>/<ojO0j`03o`000?oooooooooo00gooooo000dooooo`03o`000?oooooo
oooo02kooooo0onT_nd2ojW0jPCoZ/?/0_n/and2ojo2j0?o/<7W00?o[K[Sojbfh?n/]^000_n/]^04
ojV`g@;oY:WJ00?oWJ_QoiRXhOnHZ>400_nHZ>43oi6Vi0CoSZ_Y0_n<]o<3oi_Ro@;o^N[e00?o`no`
ol;GjOo2enT00_o2enT01?na_N;oYJgMojF]gOnU[Md4oiBKe`;oOXWD0omgQ]H3ogRBh0;oJGoF0onD
__@01Oo1ko7o]o7dolgbj_o=l^[oeo7S00?obm_U00?o]lCUojB_h?nT[n000_nT[n03ohjLg0;oPi;I
0omnSmX4oh:Eg@?oRZ7S1?nB[^T4oi^jkP;oX<?a0onSdOP2oj?Dn@?oY=Ki0_nQe_X3oj;Dn@?oWm?j
0_nLd_/3oig?n@;oW<oi0_nMc?P4oic<n0;oW/cg0onNbOH3oj7:m@;oYL_c0onSbO<2ojO9l@;oYLSb
1?nYao02ojg7k@?oZ/K^0_n/aN`2oj[5k@Co[<C/0_n]`nX2oj_3j`Co[<;Z0_n/`NT3oj_2jP;oZl7Z
0_nZ`^/4oj[1jP;oZ/3Z1onY`N/2ojW0jPKoZL7[0_nX`>/9ojS1j`05o`000?nX`N_oZ<3[ojS0jonX
`N/01OnX`>/:ojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool00onT_ngoZL3Z
ojW0jP02ojW0jP;oZ/?/0_n^`^T4ojo2j004ok31ion]^^?o[K[Sojfjh`Co[;KP0_nY/=d2oj:_h@?o
WJ_Q1?nHZ>43oi6Vi0;oSZ_Y0onFc_/01?nKh_go^N[eokWZmOnij_D3ol7Pk`03ol;GjOna_N;o/KgR
00;o/KgR0onU[Md3oiBKe`?oOXWD0omgQ]H4ogRBh0;oU;kd0_nglO@2olgbjP?ocnSX00Cobm_UokO4
iOnga>Go]lCU1?nT[n02ohjLg0?oPi;I0omnSmX4oh:Eg@?oRZ7S1?nB[^T2oi^jkP?oXL_f0_nSdOP3
ojKEn0;oY=Ki0onUeOP2oj;Dn@03ojCAmonPd?SoX=3h00?oX=3h0_nMcoT3oio<m`?oWLch0_nLc?P3
oig9mP;oW/Wf0_nNao@4oj38m0;oXlWc0_nRao<4ojG8lP;oZLO`0onVao02oj[6kP;oZ<K_1?nZaNd2
ojc4k0;oZ/C]1?n[`n/2ojc2jP?oZl?[0_n[`^X6oj[2j`;oZ/7Z0_nY`^/>ojW1j`GoZ<7[0_nX`N`6
ojS1j`03o`000?nX`NcoZ<7[00?oZ<7[0_nX`>/8ojO0j`Kooooo00?o0000ooooooooool03?ooool0
03Oooooo00?o0000ooooooooool0;_ooool2ojW0jP;o[<7Y1?n^`^T2ojo2j0;o[KgU1?n]^^<2ojbf
h0;oY[CS1?nR[n43oif[h@;oV:SQ0_nG]nh4oi>nm0;oU/kk0_n/goT3okOPm0;o`N3_0_nhbNL4ok6m
hP?oYJgM1?nDVmL3ogj9e0?oMhKF0_mhT^03oi[9n003okOam?o=l^[ocO;Z00?ocnSX00?oa=GWokO4
iOnga>D00_nga>D2ojB_h0;oUZ?N0on6Umd3oh>Bf@?oOXoJ0on2UMd4ohZQh`;oTZkY0_nK`O82oj7;
mP?oY];g0_nVeOP3ojSFm`;oYMGh0_nWd_H4ojCAm`;oX=3h0onRc?H2oio<m`;oXLWd1?nOb?D2oig9
mP;oWlKd1OnNao@2oj38m003oj36lonRao?oX/Oc00?oX/Oc0_nUb?83ojC6l@;oY/O`00?oYLG`ojS6
konXa^l00onXa^l2oj[5k@03ojS5k_nZa>goZ/C]00?oZ/C]0_n[`n/3oj[3k0;oZl?[00?oZL?/oj[2
jonZ`^/01OnZ`^/00onY`^coZL;[ojW2j`03ojW2j`;oZL7[0_nY`^/6ojW1j`?oZ<7/0_nX`N/6ojS1
k0;oZ<7[1?nX`N`01?l0003oZ<7/ojS1jonX`N/2ojO1k0KoYl3[2Oooool00ol0003oooooooooo`0<
ooooo`00>?ooool00ol0003oooooooooo`0^ooooo`Co[<7Y0_n^`^T2ojfoi`Co[KgU0_n]^^<2ojRh
i0CoY[CS0_nR[n400onN]>SoV[CZoiZdjP02oiZdjPCoUkO^0_nC__@3oj?Bn004ojcOnOngh?Co]n3d
okOPm0;o^=3/1?nhbNL2ok6mhP04oj:[gOnDW][oU9kJoiBNfPCoRIGI0omjTMh4oh6TjP?oV/Wh0_nm
iO82ol[[k003oloXj?o4eNOoa=GW00;oa=GW0_nga>D2ojFbhPCoUZ?N0on6Umd3oh6FgP?oPY_R0on8
Y^P4oi>dkP;oVl7b0_nRboD3ojKBm`;oZMCg0onXe_L2ojWCmPCoYm;f0_nTdOL3ojG=m@;oX/cf0_nS
bO<4oj79m0;oWlSe0onPa_<3oio6m0;oW/Od0onPaO<3oj36l`;oX/Oc0onRaO82ojC6l@;oXlGa1?nU
aO02ojS6k`;oY/G_1?nXaNh2oj[4k@?oZ<C]0_nZ`n`2ojW4k@CoZL?/0_nZ`^/2ojW3k0CoZL;/0_nY
`^/2ojW2k0GoZL;[0_nY`N/2ojW2k0;oZ<7/0_nX`^`>ojS1k003ojO1k?l0003oYl7/00CoYl7/0_nW
`>/<ooooo`03o`000?oooooooooo00cooooo000iooooo`03o`000?oooooooooo02kooooo0_n/`NT2
ojg1j@Co[KoW0_n]_ND2ojZkiPCoZ;ST0_nV]><2oj6fi`?oW[CX1?nJ]>X2oiNgkP?oWlSe0_nSd_P3
ojoKmP03okOPm?nhd>co^=3/00;o^=3/0_nhbNL2ojbgh@?oXZ_M0onDW]X4ohVEf@?oNY7N1?n1Y>X0
0onJbOSo_NGbol[[k002ol[[k0?obMoY0_o4eNL2okK3i0CoYK;R0onFXmh4ohJGg@?oPIKN0on2Vn83
ohRVj0;oTkC^0_nL`_84oj;;m@03ojKBmonYe?OoZMCg00;oZMCg00?oZ=KgojWCm_nYdoH00_nYdoH2
ojOBmP?oZ<kd0_nUcOD2ojK:l`CoXlWc0_nQbO@3oj;6lP;oX<Kc0_nRa?44oj35lP;oX<Gc0_nQa?44
oj75lP;oX/Gb0_nRa?44oj?5l@;oYLG`0_nUa?04ojK5k`;oZ<G^0onWa>h2ojS4k@;oZ<C^1?nYa>d2
ojW3k0;oZ<?]1?nY`n`2ojW2k0;oZL?/1?nY`^`2ojW2j`GoZL;/1_nX`^`2ojS1k0;oZ<;/1_nX`N`5
ojO1k003o`000?nW`NcoYl7/013ooooo00?o0000ooooooooool03?ooool003[ooooo0_l0000_oooo
o`Co[L7Y0_n]_nL2oj^nj0CoZ[_V0_nX^>@2ojBhi`CoXKKW0onN]>P2oiZdjP?oWL7b0_nOb?D3ojSD
m`;o[m_f0oned^l2okS@k0;o/;oU1?n/]n43oj:[g@?oU9kJ0on9UMT2ogZAgP;oS:k]0onObOH3okGP
m@04ol[[k?o9gnWobMoYolWOj@;o`=7W1?nf`n@2ojFbhP04oiVZh_n>XN7oSZ7QohjQh@CoQIcR0on5
X>D4oh^YjPCoTkK_0onL`_82oj;;m@?oYm7f0_nYe?L3oj_Cm@;oZM?f0onZd?<2ojS>m0;oZ<_b1?nV
b_<2oj?9l`?oY<Oa0_nRa_800onSa?7oX/Caoj;4l@03oj;4l@;oX<Gb00?oX/?aoj74lOnQa?400onQ
a?42oj75lP03oj;3lOnRa?7oX/Ca00?oX/Ca0_nSaO42oj?4l0CoYLC`0_nVaNl3ojK4k`;oYlC^00?o
Y/C^ojS4k_nXa>h00onXa>h2ojW4k@KoZ<?]0_nY`n`00onX`ngoZL?/ojW3k003ojW3k0;oZL;/0onX
`n`2ojW2k0koZ<;/0_nX`N`8ojO1k003o`000?oooooooooo013ooooo00?o0000ooooooooool03?oo
ool003cooooo00?o0000ooooooooool0;Oooool2ojg1j@;oZl7Z1?n[_^P2ojZkiP;oY[_X1?nT^>L2
oj6fi`;oX;c]1?nN_^l2oig1lP?oY<ge0_nXe?L3ok3Al@;o]M;_0_nca^T4ok2oi@;o[;OQ00?oXJkQ
oiRWh?nHYn000_nHYn03ohjQh@?oRZ?U1?n<[^d01?nObOKo]N3eokGPmOneh?D3ol3Ok`03olWOjOo0
dNOo`=7W00;o`=7W0_nf`n@2ojRgi0?oVJ[R0on>XN44ohFLhP?oQJ3U1?n;ZNX2oi>fk`03oic2lonS
boCoXl_d00?oXl_d0_nWdOH3oj_Am0;oZm?e0_n/d?<2oj[@l`?oZlca0_nXbo82ojS8l0CoY/Oa0_nT
ao42ojG5l0CoXlCa0_nRa?42oj?3l0CoX/?a0_nQa?42oj;3l0CoX/?a0_nRa?43oj?3l0CoXlC`0_nU
a?02ojG4k`;oY/C_0_nU`nl4ojK4kP;oZ<C^0_nW`nh<ojS3k@;oZL?/0onX`nd2ojS3k0;oZ<?]1_nX
`^`2ojS2k@KoZ<;/0_nW`^`6ojO1k0Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZl7Z0_n[_^P2ojNnj@CoY[_X0_nT^>L2
oj:lk0CoX;c]0_nN_^l3oj;7l`;oY<ge0_n/cO83ok3Al@;o/LW/1?nca^T2ok2oi@;oYkKS0onQ[^44
oiRWh0?oSZ7Q0on:XnD2ohb^k@?oX/_e00Co]N3eol3Okoo0gnoo`=o_0onof>`2ol3Ai`;o]<CV1?nX
]n@3oiVZhP?oSZ7Q0on5W>83ohFPi@;oRjWZ0_nD]nl4oic2l`;oXl_d0onXc_@2oj_Am0Go[=3c0_n/
cO43oj_<l@;oZ/W`1?nXb?02ojK7l@;oYlG_1?nUaO02oj?4l@?oY<?_0onS`o02oj;3l@?oXl;_0onR
`o02oj;3l@GoXl?`0_nS`nl4ojC3k`;oYLC_1_nU`nl2ojK4kP;oY/?^1?nW`nh2ojS3k@?oYl?^4?nX
`nd2ojS2k0;oZ<?]1?nX`^d2ojS2k0?oYl;]0onW`^`2ojO1k0Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0<ooooo`00?_ooool00ol0003oooooooooo`0]ooooo`;oZl7Z0onX`>/3
ojNnj@;oY[_X0_nS_N`4oj:lk0;oX;c]0onQ`o42oj;7l`;oZ<[a1?n/cO800on`dO7o/LW/ok79k002
ok79k0;o/lKY0_n/_>D4ojNfh`?oXJkQ0_nHYn000onFZ^GoT:cYoi2/j@02oi2/j@CoUKS`0_nRboD3
okCGlP04ol3Okonof>co_mS/okoHk0;o^LgY1?nda>H2ojRgi003oin`honCYn?oTjOS00;oTjOS0on<
Xn@3ohVUi`CoS:c[0onD]nl2oic2l`?oXlSc0_nXc_@3oj_?l`;o[=3c0_n]c_44ojc=l@03oj_<lOnZ
bO3oZ/W`00;oZ/W`0_nXb?02ojS6k`CoYlG_0_nUaO03ojK3k`;oY<?_00?oYL;^ojC2konT`^l00onT
`^l2oj?2k`03ojC2k_nS`^ooXl;_00?oXl;_0_nS`o02ojC2k`CoXl?_0_nT`nl2ojC2k`KoYL?_0_nU
`nh4ojK3kPSoYl?^1OnW`nd2ojS3k@03ojO3kOnX`ngoZ<?]00_oZ<?]0_nX`^d4ojO2kA3ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo0_nX`>/2
ojFok0CoY;k/0onS_N`2oj:lk0?oX/7_0_nQ`o42ojK6l@CoZ<[a0_n/cO83ojo:kP;o/LW/0_n]`>P4
ojbli@;oYkKS00?oXK3Soi^/honK[><00_nK[><3oiJZi@CoT:cY0_nE^?03ojG9l`;o]=Ob0onkfNl0
0onof>co^LgYokW=j@02okW=j@;o]<CV00?oZK[Uoin`honO/><00_nO/><4oi>Wh`?oS:?T0on9YNL2
ohb/j`;oU;O_1?nL`?42oj?8l`;oYlcc0on[co<2ojc>l@Co[Lka0_n/cO43ojc;l0;oZ/W`00?oZ/O_
ojS6konXa^l00onXa^l2ojO5k`;oYlC^0_nV`nl2ojK2kPCoYL;^0_nT`^l2ojG2kPCoY<;^0_nS`^l2
ojC2kPGoY<;_0_nS`nl00onT`^koY<;_ojC2k`03ojC2k`;oYL?_00?oYL;^ojG3k_nU`nh00onU`nh4
ojK3kPSoYl?^0_nW`nd2ojO3kPCoYl?]0_nX`nd2ojO3k@KoZ<?]0onW`nd2ojO2kACooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`0]oooo
o`CoYKo/0_nT_^`2oj>ok@CoXl3^0_nR`Nl2ojG4k`CoY/Ka0_nXb_43oj_8k`;o[l[^0_n^`nT4ojg0
j0;o[;cU0_nV]N@3oj6`h`CoVjcS0onFZ^D2oi2/j@?oVkg_0_nUbO<3ojoClP;o^mW_0onjd^`2okW=
j@03ok73ionY^^GoZK[U00;oZK[U1?nO/><2oi>Wh`03oi6Yi_n?Z^SoSj[X00;oSj[X0on?[^/4oiBg
k`;oW<3a0_nRa_84ojO<l`03oj_?lon/c_7o[<ka00;o[<ka0_n]c_43ojg<l0;o[<_`00?oZlS_oj[7
konZanl00_nZanl2ojS6k`?oZ<C^0_nWa>h2ojO3k@CoY/;^0_nU`^h2ojG2k@CoYL;^0_nT`^h2ojG1
kPCoY<;^0_nT`^l6ojC2kP;oY<;_1_nU`^h2ojG3kPOoY/?^3?nW`nh8ojO3k@;oZ<?]1OnW`ndHoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool004;ooooo00?o0000oooooooo
ool0;Oooool2ojFok0;oY;o]1?nS_nd2oj?0kP;oY<;^1?nUa>l2ojK6l@?oZLO_0_n[b>l2ojc4j`Co
[/?Y0_n]`>P2ojVii@CoY[GT0onQ/><2oi^/h`;oV[;X1?nJ]^/2oi^mk`;oY/Wb0on_do82okCAk`;o
^];/0_neb^T4ok73i`;oZK[U0_nR]>H3oiZ^i@CoTJWV1?n?Z^P3ohn^j`;oU;O_0_nK_o44oj;6lP;o
Ylcc0onZc?82ojc>l@Co[Lc`0_n/bNl4oj_8k`;oZ/O_0onYaNh2ojS4kP;oZ<?]1?nW`nd2ojK2kP;o
Y/;]1?nU`^d2ojG2kP;oYL7]1?nU`Nh2ojC2kP?oYL7^1OnT`^h;ojG2kP;oY/?^00?oY/;^ojK3k_nV
`nh00onV`nh<ojO3kP[oYl?]7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo0013ooooo`03o`000?oooooooooo02gooooo1?nT_nd2oj>ok@;oY<3]1?nT`^h2ojG4k`?oYlG^
0_nYanl2oj_4k0Co[<C[0_n^`nT2oj^mi`CoZKWU0_nV]N@2oj:eiP?oW[?V1?nJ/^P2oiZfj`03oj31
l?nVbO;oY/Wb00?oY/Wb00?o[m?bokCAkonddNl00_ndcNd4okG:j@;o/L?W0_nZ_>H4oj:diP?oVZkU
0_nAZNH2oi>^j@?oTk7[1?nF]nh4oi^ol@;oX/Kb0_nVbO42oj[<lP?oZl_`0_n]c?02ojc:k`Co[<W_
0_n[b>l3oj_6kP;oZLG^0_nYa>d4ojS3k@;oYl?]0_nW`^d4ojK2k@;oYL;]0onV`Nd3ojG1k@;oYL7^
0onU`Nd2ojG1kPGoYL7]0_nU`^h2ojG1k@KoYL;^1_nV`^h2ojK3kP;oY/;^4OnW`nh2ojO3kB3ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00A?ooool00ol0003ooooooooo
o`0]ooooo`;oY;o]0_nU_n`4ojC0k@;oY<;^0onV`nh2ojO5kP;oZL?/1?n[a>`2ojc4j`;oZkoX1?n[
_NL2ojVii@;oYKSV1?nR]NH3oijciP;oV[;X00?oWK_]oj31l?nP`O000_nP`O02ojK9lP?o[/g`00?o
]=7_okC=kOndcNd00_ndcNd2okG:j@;o[l;X1?nZ_>H2oj:diP;oWK;V0onH[nL4oi>^j@?oTk7[0_nF
]nh2oibmk`CoXL?a0_nVbO43ojW9l@;oZl_`1_n/b^l2ojc9k`?o[<O^0_n[a^h2oj[5k@CoZLC]0_nX
`nd2ojS2k@CoYl;]0_nV`^d2ojO1k@;oY/7]0_nV`N`4ojK1k@;oYL7]0_nV`Nd<ojG1k@;oYL;^0_nV
`^d6ojK2kP;oY/;]1?nV`^h?ojO3kRCooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`00AOooool2o`0002oooooo0onU_n`2ojC0k@?oY/7]0_nV`nh2ojS2k0CoZL?/0_n[a>`2
oj_0j@CoZkoX0_n[_NL00onW^^OoYKSVojFhiP03ojFhiP;oX[GV00?oX;OYoinhj_nO^>X00_nO^>X3
oifkk@;oX<7`0onWb?02ojk=l0?o/Lg^0_ndcNd2ok77jPCo[l;X0_nZ_>H2ojBgiPCoWK;V0onH[nL2
oi>^j@;oUk?[0onH^>h4oibmk`;oXL?a0onUa_42ojW9l@;oZ/W`1_n/b^l3ojc8kP;o[<O^00?oZlK]
oj[5kOnZaNd00onZaNd2ojW4k@;oZL?/0_nX`^d2ojS2k0CoYl7/0_nW`Nd2ojO1k0CoY/7/0_nV`Nd2
ojK1k0CoY/7]0_nU`Nd2ojK1k@KoYL7]0_nV`Nd4ojK2k@;oY/;^1_nV`^d2ojK2kP?oY/;]0_nW`nh0
0onW`ngoYl?^ojO3kP04ojO3kRWooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`CoY[o/0_nV`Nd2ojS1k0CoZ<;/0_nY`n`2oj[1
jPCoZl3Y0_n[_nP00onX_>SoYk[WojNji`02ojNji`;oYKSV0_nS^>P4oj2gj@;oWkSZ0_nR_^d4oj?2
k`;oYlS`0on/bo02ok7=kP;o/<W/1?naanX2ojo2j0;oZKgW1?nT]nH2oifbiP;oW;?X0onH/^T4oiNc
j`?oV;S^0_nL_Nl3oj72l0;oYLKa0_nWao04oj[9l0;o[<[_0_n/b>l2ojc8kPKoZlK]0_nZaNd3ojW4
k@;oZL?/1_nX`^`8ojO1k0SoY/7/0_nV`Nd2ojK1k0CoY/7]0_nU`Nd6ojK1k@;oY/;]0_nV`Nd:ojK2
k@;oYl;]1?nW`nd2ojO3kRcooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`00B?ooool00ol0003oooooooooo`0]ooooo`;oY[o/0_nW`>/4ojS1k0;oZ<;/0_nY`N/4oj[1jP;o
Zl3Y00?oZKkXojRlj?nX_>P00_nX_>P2ojNji`;oYKWX1?nS^>P2oj2gj@;oX[c/1?nR_^d2oj?2k`;o
Z<O`0on/bo02ojk9kPCo/<W/0_naanX3ojg1j@?oZKgW0_nT]nH2oj6fi`CoW;?X0onH/^T2oiNcj`;o
V[S]1?nM_Nl2oj72l003ojC4l?nWao3oYlO`00?oYlO`0_nZbO02oj_8k`;o[<S_0_n[anh6oj_6k@?o
Z/C]0_nYa>d2ojW3k0KoZ<;/0_nX`N`7ojO1k0OoY/7/0_nV`>`4ojK1k0;oY/7]0_nV`N`2ojK1k@;o
Y/7/2?nV`Nd6ojK2k@KoYl;]0_nW`nd`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojO0j`;oZ<7/1_nY`N/2oj[1jP?oZKoY
0_nY_^P2ojRlj0;oY[_X1?nU^NP2oj>hj0;oXk_[1?nR_>`2oj:nk@;oYL?_1?nXao000on/bo3o[/W^
ojk9kP02ojk9kP;o/<W/0on^aN/2ojg1j@03ojVmj?nU^^SoYK[X00;oYK[X1?nQ]^L2oibcj004oibe
jOnJ]^_oV[K[oiZfj`GoV[S]0_nM_Nl00onQ`>ooY<C`ojC4l002ojC4l0;oYlO`0onYanl2oj_8k`Ko
ZlO^0_n[a^d3oj_5k@;oZ/C]0_nZ`n`4ojW3k0?oZ<;/1OnX`N`7ojO1k0;oY/7/0onW`>`2ojK0k0;o
Yl3/1?nV`>`8ojK1k0;oY/7]0_nW`N`4ojK1k@;oY/;]2?nW`^ddooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`;oYl3[0_nX`>/6ojW1j`?oZKoZ
0_nY_nT00onX_^WoZ;cXojRlj002ojRlj0?oY[_X0_nU^NP2ojBkjPCoXk_[0_nR_>`3ojC1kP?oYL?_
0_nXao03oj_7kP;o[/W^0on]a^`2ojk5j`03oj_1jOnY_NSoZKgX00;oZKgX1?nU^^P2oj6fi`03oinf
j?nL]NWoW;GY00;oW;GY0onJ]^/2oiZhk@;oW[c^1?nQ`>l2ojC4l0?oYlG_0_nYanl2oj[7k`KoZlO^
0on[a^d2oj_5k@03oj[4kOnZ`ncoZ/?/00?oZ/?/0_nY`n`00onY`^coZ<;/ojS2k002ojS2k0GoZ<7/
1OnW`N`;ojO0k0;oY/3/00?oYl3/ojK1k?nV`N`01OnV`N`6ojO1k0;oY/7]00?oYl7]ojO2kOnW`^d0
1?nW`^diooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004cooooo00?o
0000ooooooooool0;?ooool4ojS0j`;oZL7[0onY`>X2ojVojP03ojRojOnX_^WoZ;kY00;oZ;kY0_nX
_>P2ojJmj@CoYKcY0onT^nX2oj>kj`?oY;o]0_nT`Nh2ojK3kPCoZ<G^0_n[anh3ojc6k@;o[LK/00?o
[<?[oj_1jOn[`NT00_n[`NT2ojVmj0;oY[_X0onS^>P4oinfj0;oW;GY0_nM^>/4oifik0?oW[c^0_nQ
`>l3ojC3k`;oYlG_0_nXa^l4oj[7k`;oZlO^0on[a^h2oj_6k@03oj[5kOnZa>goZ/C]00;oZ/C]0_nZ
`n`2ojW3k0CoZL;/0_nX`^`7ojS1k0CoYl7/3onW`>`2ojK1k0_oYl7/0onW`Nd2ojO2kCcooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00COooool00ol0003oooooooooo`0/
ooooo`;oZ<3[0onY`>/2ojW0jP03ojVoj_nX_nWoZ;oY00;oZ;oY0_nX_^T2ojNnjPCoY[gY0_nU_>T2
ojFnj`CoY;k/0_nT_nd2ojG2k@CoY/?^0_nXaNh3oj[6kP;o[<K]00?o[<C/ojc3jon/`n/00_n/`n/2
oj_1j@;oZ;gY1?nV^nP3oj>hj0;oWkKX0_nO^>X4oifhj`;oWKW/0_nP_Nd4oj6okP;oY<?_0_nVa>l4
ojS6k`;oZ/O_0_nZa^h2oj_6kPKoZ/G]0_nZa>d6ojW3k0;oZL;/0onX`^`8ojS1k0;oYl7/4OnW`>`;
ojO1k4?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00C_ooool00ol0
003oooooooooo`0]ooooo`;oZL3[00?oZ<3[ojVoj_nY_nX00_nY_nX2ojRoj@KoYkkZ0_nV_NT6ojFn
j`;oY;k/0_nU`>d4ojG2k@;oY/?^0onXa>h2oj[6kP03oj[4k?n/a>co[<C/00;o[<C/0_n/`n/2ojW0
jPCoZ;gY0_nV^nP2ojBjj@CoXKSY0onO^>X2oifhj`;oWk_/1?nP_Nd2oj6okP;oY<7^1?nVa>l2ojS6
k`;oZLG^0_nZa^h8oj[5k@?oZ/C/1OnY`n`3ojW2k0;oZ<;/2?nX`N`00onW`NcoYl3/ojO0k00BojO0
k0OoYl7/Aoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo001?ooooo`;o
0000;_ooool3ojS0j`;oZKoZ0_nX_n/6ojNnjP;oY[k[1_nU_^/2ojFok0CoYL3]0_nU`^d3ojO3kP;o
Z<C^00?oZLC]oj[4k?nZa>`00_nZa>`2ojc4k0;oZ/7[1?nY`>X2ojRmj@;oY[cY1?nT^^T2oj6hj@;o
XKWZ1?nP^^/3oinkk0;oX;g]0_nR_nh4ojC1kP;oY/C_0_nWa>h4ojW5kPKoZ/G]0onZa>d2oj[4k0Ko
ZL?/0_nY`^`00onX`^coZ<7/ojS1k006ojS1k0CoYl7/0_nW`>`3ojO0j`ooYl3/0_nW`Na<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0057ooooo00?o0000ooooooooool0
;?ooool3ojS0j`CoZ;o[0_nW_^X2ojNoj`CoY[k[0_nU_^/6ojFok0;oYL3]0onV`^d2ojO3kP03ojS3
kOnYa>goZLC]00;oZLC]0_nZa>`2oj[2j`CoZ/7[0_nY`>X2ojRnj@CoY[cY0_nT^^T2oj>jj@CoXKWZ
0_nP^^/00onQ_>coXKg]oj6mk@02oj6mk@CoX[o^0_nT`Nh2ojG3kP;oYlC^0_nXa>h4ojW5kPGoZ/G]
0_nZa>d00onYa>goZL?/ojW3k004ojW3k0;oZL;/1?nX`^`8ojS1k0;oYl7/2_nW`>/:ojO0k4oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`00D_ooool00ol0003ooooooooo
o`0[ooooo`CoZ<3[0_nX_n/6ojNoj`;oY[k[0onV_n`5ojFok0?oY/7]0_nV`^d00onW`^goZ<?]ojS3
k@02ojS3k@;oZLC]0_nY`n`4oj[2j`;oZ/7[0onY_nX3ojRnj@;oY[cY0_nU^nT4oj>jj@;oXKWZ00?o
X[_[oj6lk?nQ_>`00_nQ_>`2oj6mk@;oXko]1?nT`Nh2ojG3kP;oYl?^1?nXa>h2ojW5kP?oZLG]0_nZ
aNd5ojW4k@;oZL?/1_nY`^`2ojS2k0SoZ<7/0onX`N/;ojO0j`KoYl3/Doooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00[ooooo001Cooooo`03o`000?oooooooooo02_ooooo0_nX`>/3
ojO0j`;oYko[2?nV_n`6ojK0k0;oY/7]1OnW`^d2ojS3k@KoZL?/0_nZ`^/3ojW0j`;oZKoZ0_nW_^X4
ojJlj@?oYK_Y0_nS^^T00onS^n[oX[_[oj:kj`02oj:kj`;oXKc/0_nR_^d4oj>ok@;oY<7^0_nU`^h4
ojO3kPGoZ<C^0_nYaNd7ojW4k@;oZL?/1_nY`^`3ojS2k0OoZ<7/0_nX`N/>ojO0j`;oYl3/Eoooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo001Dooooo`;o0000;Oooool2ojO0
j`SoY[o/2?nV`>`00onV`NgoYl;]ojO2k@04ojO2k@?oZ<;/1OnY`n`3ojW1j`;oZL3[0_nX_nX4ojNn
jP;oY[cY00?oYKcZojBlj_nT_>X00_nT_>X3oj>kjP;oX[_[0_nR_N`4oj:nk@;oXko]0onT`Nd3ojG2
kP;oYl?^0_nWa>h2ojS4kP;oZ<C]1_nYa>d2ojW3k@CoZL?/0_nY`^`5ojS2k0WoZ<7/3_nW`>]Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool005Kooooo00?o0000oooooooo
ool0:oooool8ojJok0KoY/3/0_nV`N`3ojK1k@;oYl;]0onW`^`2ojS2k0;oZ<7/1_nY`N/2ojS0j`Co
Z;oZ0_nW_^X00onV_N[oYKcZojFljP02ojFljP;oY;cZ0_nT_>/4oj>lj`?oX[g/0_nR_^d3ojBok@;o
Y<7]00?oYL;^ojK3k_nV`nh00_nV`nh2ojO4kP;oZ<C^1?nXa>d5ojW4k@?oZL?]0_nY`n`3ojW2k0?o
Z<;/3?nX`N`2ojO0j`?oYl3/1OnW`>]Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool005Oooooo00?o0000ooooooooool0:oooool8ojJok0GoY/3/0onV`N`01?nV`NgoYl7/
ojO1k?nW`N`2ojO2k0KoZ<7/0_nY`N/6ojS0j`;oZ;oZ00?oYkkZojJmj_nV_NX00_nV_NX2ojFljP;o
YKgZ1?nT_>/2oj>lj`;oY;k/1?nS_^`2ojBok@03ojG1kOnU`^koYL;^00;oYL;^0_nV`nh2ojO3kPCo
Z<C^1OnXa>d2ojW4k@03ojS3kOnY`ngoZL?]00;oZL?]0_nY`^`6ojS2k0[oZ<7/0_nW`N`2ojO0k6Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00F?ooool00ol0003ooooo
ooooo`0/ooooo`GoY[o/1OnV`>`00onW`>coYl7/ojO1k006ojO1k0KoZ<7/0_nX`N/6ojS0j`03ojNo
j_nW_^[oYkkZ00;oYkkZ1?nV_NX4ojFmjP;oY;c[0_nT_N/4ojBnk0;oXkk/00?oY<3]ojG1kOnU`Nd0
0_nU`Nd2ojG2kP;oY/;^1?nW`nh2ojS4kPGoZ<C]1OnX`nd2ojW3k@SoZ<;/2?nX`N`4ojO1k6[ooooo
00Go0000ooooooooooooooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`CoY[o/
0onV`>`4ojO0k0SoYl7/0_nX`N`6ojS1j`;oZ<3[0_nX_n/3ojNojP;oYkkZ0onV_^X3ojJmjP;oYKgZ
0onU_N/3ojBmj`;oY;k/0_nT_n`3ojC0k@;oYL7]0onU`^d3ojK2kPGoYl?^0_nXa>d:ojS3k@SoZ<;/
0_nX`N`7ojO1k6gooooo00Go0000ooooooooooooooooo`00000;ooooo`00F_ooool2o`0002gooooo
0_nV_n`2ojO0k0?oY/3/1?nW`>`6ojO1k0?oZ<7/1OnX`N/2ojS0j`;oZ;o[0_nW_n/4ojNnjP;oY[kZ
0_nV_^/6ojFmj`03ojFnk?nT_^coY;k/00;oY;k/0_nT_n`2ojG0k@CoYL7]0_nU`^d2ojK2kPKoYl?^
00?oYl?]ojS3kOnX`nd02onX`nd6ojS2k003ojO2k?nW`NcoYl7/00CoYl7/LOooool01?l0003ooooo
ooooool0000;ooooo`00G?ooool00ol0003oooooooooo`0[ooooo`CoYl3/00?oY/3/ojO0k?nW`>`0
1?nW`>`5ojO1k0;oZ<7/1onX`>/6ojNoj`;oYkkZ1_nV_^/2ojFmj`03ojFnjonU_^coYKk/00;oYKk/
0_nT_^`2ojFok0CoYL3]0_nU`Nd2ojK2k@CoY/;^0onW`nh4ojO3k@goZ<?]0_nX`^`00onW`^goYl;/
ojO2k002ojO2k0;oYl7/MOooool00ol0003oooooo`00000;ooooo`00GOooool00ol0003ooooooooo
o`0[ooooo`;oYl3/0_nW`>/2ojO0k0KoYl3[0_nW`N`8ojS0j`03ojRojonW_n_oYko[00KoYko[1onV
_^/4ojFnj`;oYKk/1_nU_n`2ojG0k@;oYL7]1?nV`^d2ojK2kP;oY/?^0onW`nh5ojO3k@[oZ<?]1OnW
`^d2ojO2k7Sooooo00Co0000oooooooooooo00002_ooool005kooooo00?o0000ooooooooool0:ooo
ool<ojO0j`OoZ<3[1?nX_n/8ojNoj`OoY[k[0_nU_^/8ojFok0KoYL7]1?nV`^d2ojK3kPKoYl?^0onW
`nd6ojS3k@?oYl?]1OnW`^elooooo`03o`000?oooooo000000[ooooo001Oooooo`;o0000;?ooool<
ojO0j`OoZ<3[0_nX_n/7ojNoj`CoY[o[00?oY[k[ojJojonV_n/01?nV_n`2ojFok0KoYL3/0_nU`Nd0
0onV`NgoY/;]ojK2k@04ojK2k@;oY/?^2?nW`nh3ojO3k@;oZ<?]1OnW`nf3ooooo`;o00002_ooool0
067ooooo00?o0000ooooooooool0:_ooool:ojO0j`CoZ<3[0_nW`>/<ojNoj`OoY[o[1?nV_n`6ojG0
k0GoY/7]1?nV`^d4ojK3kPSoYl?^1_nW`nf5ooooo`?o00002_ooool006;ooooo00?o0000oooooooo
ool0:oooool8ojO0j`03ojS0jonW`>_oYl3[00CoYl3[2onW_n/6ojJoj`KoY[o/0_nU`>`7ojK1k@Ko
Y/;]0_nV`nh:ojO3kP;oYl?]Q?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo
3OnW`>/=ojNoj`;oY[o[2?nV_n`2ojK0k0SoY/7]1?nV`^d4ojO2k@WoYl?^Poooool4o`00017ooooo
001Tooooo`;o0000;?ooool<ojO0j`_oYko[1?nV_n/2ojJok0OoY/3/0_nV`N`6ojK1k@KoY/;]0_nW
`^d2ojO3k@GoYl?^Poooool3o`0001Gooooo001Vooooo`03o`000?oooooooooo02_ooooo2onW`>/;
ojNoj`;oY[o[2?nV`>`5ojK1k0GoY/7]1OnV`^d2ojO2k@;oYl?]QOooool4o`0001Sooooo001Woooo
o`03o`000?oooooooooo02[ooooo3?nW`>/2ojNoj`03ojO0jonW_n_oYko[00CoYko[0_nW`>`8ojK0
k0GoY/7/1OnV`Nd7ojO2kHCooooo1?l0000Looooo`00J?ooool00ol0003oooooooooo`0Zooooo`oo
Yl3[0_nW_n/3ojO0j`?oYl3/0_nV`>`2ojO0k0;oY/3/1_nW`N`2ojK1k@03ojO1kOnW`^goYl;]00Co
Yl;]Poooool4o`00023ooooo001Yooooo`;o0000;?oooolCojO0j`OoYl3/1onW`N`4ojO1k@;oYl;]
P_ooool4o`0002Cooooo001[ooooo`03o`000?oooooooooo02[ooooo4onW`>/7ojO0k0OoYl7/0_nW
`Nf2ooooo`?o0000:?ooool006cooooo00?o0000ooooooooool0:_oooolAojO0j`OoYl3/1OnW`Nb3
ooooo`Co0000:oooool006gooooo00?o0000ooooooooool0:oooool>ojO0j`SoYl3/0_nW`Nb2oooo
o`Co0000;oooool006kooooo00?o0000ooooooooool0:_ooool?ojO0j`KoYl3/POooool4o`0003?o
oooo001_ooooo`;o0000:oooool?ojO0j`;oYl3/P?ooool4o`0003Oooooo001aooooo`03o`000?oo
oooooooo02[ooooo2OnW`>^2ooooo`Co0000>oooool007;ooooo00?o0000ooooooooool0:_ooool5
ojO0jh;ooooo0ol0000oooooo`00Loooool00ol0003oooooooooo`0Zooooo`03ojO0jooooooooooo
07oooooo1?l00012ooooo`00M?ooool2o`0002[ooooo00?o0000ooooooooool0Noooool4o`0004Ko
oooo001fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004[ooooo
001gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004kooooo001h
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`0005;ooooo001ioooo
o`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000EOooool007_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1Yooooo`Co0000FOooool007cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1Uooooo`Co0000GOooool007gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Qooooo`Co0000HOooool007kooooo0_l0000Oooooo`03o`000?oooooo
oooo05gooooo1?l0001Uooooo`00P?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
05[ooooo0ol0001Yooooo`00POooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Ko
oooo1?l0001/ooooo`00P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo
1?l0001`ooooo`00Poooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0
001dooooo`00Q?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007Sooooo0026oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007cooooo0027ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`00083ooooo0028ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0008?ooooo0029ooooo`;o00005?oo
ool00ol0003oooooooooo`0kooooo`Co0000Qoooool008_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0gooooo`Co0000Roooool008cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0cooooo`Co0000Soooool008gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0`ooooo`?o0000Toooool008kooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo
1?l0002Fooooo`00T?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0
002Jooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo1?l0002N
ooooo`00T_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Roooo
o`00Toooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:Kooooo002Eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:[ooooo002Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:gooooo002Gooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;7ooooo002Hooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool4o`000;Gooooo002Iooooo`;o00000oooool00ol0003o
ooooooooo`0:ooooo`Co0000^Oooool009_ooooo00Co0000oooooooooooo00002Oooool3o`000;go
oooo002Looooo`03o`000?oooooo000000Gooooo1?l00030ooooo`00WOooool2o`000003ooooool0
003o000000;o0000a?ooool009kooooo0_l00038ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z_ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?l@413oc<c<1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Cooooo`00Z_oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo
00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
09?ooooo002Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00002Cooooo`00Z_ooool00ol0
003oooooooooo`04ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B402oooool01Olb<S;oV9RHoooooonHV9So<S8b09?ooooo002Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<00_ooooo00Go
c<c<o`000?l0003o0000olc<c02Cooooo`00Z?ooool00ol@413o0000o`000003o`0000gooooo00?o
0000ooooooooool00_ooool00omEEEGoQhN7ooooo`0=ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
Toooool00:[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03omgMgOl@
413oV9RH00gooooo00Go0000okZj^_oooooo^[Zjo`00002Cooooo`00Z_ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Gooooo00Coc<c<odA4A?l0003o410@2oooool01OnYZJWo410@
o`000?l@413oZJVY09?ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -17 0 ]
[.5 .82364 17 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02145 .28182 -24 -2.75643 ]
[.02145 .28182 0 6.24357 ]
[.01431 .32657 -24 -2.7943 ]
[.01431 .32657 0 6.2057 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00061 .42007 -18 -2.87377 ]
[-0.00061 .42007 0 6.12623 ]
[-0.00841 .46894 -18 -2.91549 ]
[-0.00841 .46894 0 6.08451 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03368 .27708 m
.0398 .27471 L
s
[(-0.4)] .02145 .28182 1 -0.38746 Mshowa
.02658 .32192 m
.03271 .3196 L
s
[(-0.2)] .01431 .32657 1 -0.37904 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.01173 .41561 m
.0179 .41338 L
s
[(0.2)] -0.00061 .42007 1 -0.36138 Mshowa
.00397 .46458 m
.01016 .4624 L
s
[(0.4)] -0.00841 .46894 1 -0.35211 Mshowa
.125 Mabswid
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02837 .31059 m
.03205 .30919 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.00981 .42772 m
.01352 .42639 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.03543 .26607 m
.0391 .26464 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .92 r
.39636 .6972 .40169 .70185 .41061 .69934 .4053 .69468 Mtetra
.655 .752 .921 r
.4053 .69468 .41061 .69934 .41957 .69681 .41427 .69215 Mtetra
.41427 .69215 .41957 .69681 .42855 .69428 .42327 .68961 Mtetra
.42327 .68961 .42855 .69428 .43756 .69174 .4323 .68706 Mtetra
.655 .753 .922 r
.4323 .68706 .43756 .69174 .4466 .68919 .44137 .68451 Mtetra
.44137 .68451 .4466 .68919 .45567 .68663 .45046 .68195 Mtetra
.655 .754 .922 r
.45046 .68195 .45567 .68663 .46478 .68407 .45958 .67937 Mtetra
.45958 .67937 .46478 .68407 .47391 .68149 .46873 .67678 Mtetra
.656 .754 .922 r
.46873 .67678 .47391 .68149 .48307 .67891 .47791 .67418 Mtetra
.657 .754 .922 r
.47791 .67418 .48307 .67891 .49227 .67632 .48713 .67154 Mtetra
.658 .753 .92 r
.48713 .67154 .49227 .67632 .50149 .67371 .49638 .66886 Mtetra
.66 .752 .918 r
.49638 .66886 .50149 .67371 .51075 .6711 .50565 .66614 Mtetra
.663 .748 .914 r
.50565 .66614 .51075 .6711 .52004 .66849 .51496 .66335 Mtetra
.665 .743 .908 r
.51496 .66335 .52004 .66849 .52936 .66586 .5243 .66049 Mtetra
.668 .736 .901 r
.5243 .66049 .52936 .66586 .53871 .66322 .53367 .65755 Mtetra
.671 .726 .891 r
.53367 .65755 .53871 .66322 .54809 .66058 .54307 .65453 Mtetra
.672 .715 .88 r
.54307 .65453 .54809 .66058 .55751 .65792 .5525 .65142 Mtetra
.673 .701 .868 r
.5525 .65142 .55751 .65792 .56695 .65526 .56196 .64826 Mtetra
.672 .687 .856 r
.56196 .64826 .56695 .65526 .57643 .65259 .57145 .64507 Mtetra
.669 .672 .844 r
.57145 .64507 .57643 .65259 .58595 .6499 .58097 .64189 Mtetra
.665 .659 .834 r
.58097 .64189 .58595 .6499 .59549 .64721 .59052 .63877 Mtetra
.66 .648 .827 r
.59052 .63877 .59549 .64721 .60507 .64451 .6001 .63575 Mtetra
.655 .639 .822 r
.6001 .63575 .60507 .64451 .61468 .6418 .60972 .63288 Mtetra
.651 .634 .821 r
.60972 .63288 .61468 .6418 .62432 .63908 .61938 .63016 Mtetra
.647 .633 .822 r
.61938 .63016 .62432 .63908 .634 .63636 .62907 .62757 Mtetra
.645 .635 .826 r
.62907 .62757 .634 .63636 .64371 .63362 .6388 .62508 Mtetra
.644 .641 .832 r
.6388 .62508 .64371 .63362 .65345 .63087 .64857 .62262 Mtetra
.646 .649 .839 r
.64857 .62262 .65345 .63087 .66323 .62811 .65837 .6201 Mtetra
.65 .657 .843 r
.65837 .6201 .66323 .62811 .67304 .62535 .66821 .61746 Mtetra
.655 .662 .845 r
.66821 .61746 .67304 .62535 .68289 .62257 .67807 .61466 Mtetra
.659 .664 .844 r
.67807 .61466 .68289 .62257 .69277 .61979 .68796 .61171 Mtetra
.661 .661 .839 r
.68796 .61171 .69277 .61979 .70269 .61699 .69787 .60863 Mtetra
.662 .656 .833 r
.69787 .60863 .70269 .61699 .71264 .61418 .70782 .6055 Mtetra
.659 .648 .827 r
.70782 .6055 .71264 .61418 .72262 .61137 .71781 .60239 Mtetra
.656 .64 .823 r
.71781 .60239 .72262 .61137 .73264 .60854 .72783 .59938 Mtetra
.651 .635 .821 r
.72783 .59938 .73264 .60854 .7427 .60571 .7379 .59651 Mtetra
.647 .633 .822 r
.7379 .59651 .7427 .60571 .75279 .60286 .74801 .59378 Mtetra
.644 .634 .826 r
.74801 .59378 .75279 .60286 .76291 .60001 .75817 .5912 Mtetra
.641 .639 .833 r
.75817 .5912 .76291 .60001 .77308 .59714 .76838 .58873 Mtetra
.64 .648 .842 r
.76838 .58873 .77308 .59714 .78328 .59427 .77863 .58632 Mtetra
.64 .66 .854 r
.77863 .58632 .78328 .59427 .79351 .59138 .78892 .58393 Mtetra
.641 .674 .866 r
.78892 .58393 .79351 .59138 .80378 .58849 .79925 .5815 Mtetra
.643 .69 .879 r
.79925 .5815 .80378 .58849 .81409 .58558 .80961 .57902 Mtetra
.645 .704 .89 r
.80961 .57902 .81409 .58558 .82443 .58267 .82001 .57645 Mtetra
.647 .718 .9 r
.82001 .57645 .82443 .58267 .83482 .57974 .83045 .5738 Mtetra
.649 .729 .908 r
.83045 .5738 .83482 .57974 .84523 .5768 .84091 .57107 Mtetra
.651 .738 .914 r
.84091 .57107 .84523 .5768 .85569 .57385 .85141 .56826 Mtetra
.652 .745 .918 r
.85141 .56826 .85569 .57385 .86618 .57089 .86194 .56538 Mtetra
.654 .75 .92 r
.86194 .56538 .86618 .57089 .87672 .56792 .87251 .56245 Mtetra
.654 .752 .922 r
.87251 .56245 .87672 .56792 .88729 .56494 .88311 .55948 Mtetra
.655 .754 .922 r
.88311 .55948 .88729 .56494 .89789 .56195 .89374 .55648 Mtetra
.656 .754 .922 r
.89374 .55648 .89789 .56195 .90854 .55895 .90442 .55345 Mtetra
.90442 .55345 .90854 .55895 .91923 .55594 .91513 .55041 Mtetra
.91513 .55041 .91923 .55594 .92995 .55292 .92588 .54736 Mtetra
.656 .753 .922 r
.92588 .54736 .92995 .55292 .94071 .54988 .93667 .54429 Mtetra
.656 .753 .921 r
.93667 .54429 .94071 .54988 .95152 .54684 .94751 .54121 Mtetra
.94751 .54121 .95152 .54684 .96236 .54378 .95838 .53812 Mtetra
.656 .752 .921 r
.95838 .53812 .96236 .54378 .97324 .54071 .96929 .53503 Mtetra
.656 .752 .92 r
.96929 .53503 .97324 .54071 .98416 .53763 .98024 .53192 Mtetra
.655 .751 .921 r
.391 .69252 .39636 .6972 .4053 .69468 .39996 .68999 Mtetra
.655 .752 .921 r
.39996 .68999 .4053 .69468 .41427 .69215 .40895 .68746 Mtetra
.40895 .68746 .41427 .69215 .42327 .68961 .41797 .68491 Mtetra
.655 .752 .922 r
.41797 .68491 .42327 .68961 .4323 .68706 .42702 .68236 Mtetra
.655 .753 .922 r
.42702 .68236 .4323 .68706 .44137 .68451 .4361 .6798 Mtetra
.4361 .6798 .44137 .68451 .45046 .68195 .44521 .67723 Mtetra
.655 .754 .922 r
.44521 .67723 .45046 .68195 .45958 .67937 .45435 .67465 Mtetra
.45435 .67465 .45958 .67937 .46873 .67678 .46352 .67204 Mtetra
.656 .754 .922 r
.46352 .67204 .46873 .67678 .47791 .67418 .47273 .66941 Mtetra
.658 .754 .921 r
.47273 .66941 .47791 .67418 .48713 .67154 .48196 .66672 Mtetra
.661 .754 .919 r
.48196 .66672 .48713 .67154 .49638 .66886 .49123 .66397 Mtetra
.664 .752 .916 r
.49123 .66397 .49638 .66886 .50565 .66614 .50053 .66113 Mtetra
.669 .749 .911 r
.50053 .66113 .50565 .66614 .51496 .66335 .50986 .65818 Mtetra
.673 .745 .905 r
.50986 .65818 .51496 .66335 .5243 .66049 .51922 .6551 Mtetra
.679 .739 .896 r
.51922 .6551 .5243 .66049 .53367 .65755 .52861 .65185 Mtetra
.683 .73 .886 r
.52861 .65185 .53367 .65755 .54307 .65453 .53803 .64846 Mtetra
.686 .719 .874 r
.53803 .64846 .54307 .65453 .5525 .65142 .54747 .64491 Mtetra
.687 .706 .862 r
.54747 .64491 .5525 .65142 .56196 .64826 .55694 .64127 Mtetra
.686 .693 .851 r
.55694 .64127 .56196 .64826 .57145 .64507 .56644 .63757 Mtetra
.682 .678 .84 r
.56644 .63757 .57145 .64507 .58097 .64189 .57597 .6339 Mtetra
.676 .665 .832 r
.57597 .6339 .58097 .64189 .59052 .63877 .58553 .63037 Mtetra
.668 .653 .826 r
.58553 .63037 .59052 .63877 .6001 .63575 .59512 .62706 Mtetra
.659 .643 .823 r
.59512 .62706 .6001 .63575 .60972 .63288 .60475 .62404 Mtetra
.65 .636 .823 r
.60475 .62404 .60972 .63288 .61938 .63016 .61442 .62134 Mtetra
.642 .634 .827 r
.61442 .62134 .61938 .63016 .62907 .62757 .62413 .61894 Mtetra
.636 .636 .833 r
.62413 .61894 .62907 .62757 .6388 .62508 .63388 .61673 Mtetra
.635 .642 .84 r
.63388 .61673 .6388 .62508 .64857 .62262 .64367 .61459 Mtetra
.638 .652 .847 r
.64367 .61459 .64857 .62262 .65837 .6201 .6535 .61233 Mtetra
.645 .662 .852 r
.6535 .61233 .65837 .6201 .66821 .61746 .66336 .60985 Mtetra
.655 .671 .853 r
.66336 .60985 .66821 .61746 .67807 .61466 .67323 .60703 Mtetra
.665 .674 .849 r
.67323 .60703 .67807 .61466 .68796 .61171 .68313 .60388 Mtetra
.67 .672 .843 r
.68313 .60388 .68796 .61171 .69787 .60863 .69305 .6005 Mtetra
.672 .666 .836 r
.69305 .6005 .69787 .60863 .70782 .6055 .703 .597 Mtetra
.668 .657 .829 r
.703 .597 .70782 .6055 .71781 .60239 .71298 .59357 Mtetra
.662 .647 .825 r
.71298 .59357 .71781 .60239 .72783 .59938 .72301 .59032 Mtetra
.653 .639 .823 r
.72301 .59032 .72783 .59938 .7379 .59651 .73308 .58738 Mtetra
.644 .634 .825 r
.73308 .58738 .7379 .59651 .74801 .59378 .74322 .58476 Mtetra
.636 .633 .83 r
.74322 .58476 .74801 .59378 .75817 .5912 .75341 .58244 Mtetra
.63 .636 .838 r
.75341 .58244 .75817 .5912 .76838 .58873 .76366 .58035 Mtetra
.626 .644 .848 r
.76366 .58035 .76838 .58873 .77863 .58632 .77396 .57839 Mtetra
.624 .655 .859 r
.77396 .57839 .77863 .58632 .78892 .58393 .78431 .57648 Mtetra
.625 .669 .872 r
.78431 .57648 .78892 .58393 .79925 .5815 .79469 .5745 Mtetra
.628 .684 .884 r
.79469 .5745 .79925 .5815 .80961 .57902 .80512 .57243 Mtetra
.632 .7 .894 r
.80512 .57243 .80961 .57902 .82001 .57645 .81557 .57021 Mtetra
.636 .714 .903 r
.81557 .57021 .82001 .57645 .83045 .5738 .82605 .56783 Mtetra
.641 .726 .91 r
.82605 .56783 .83045 .5738 .84091 .57107 .83656 .56529 Mtetra
.645 .736 .915 r
.83656 .56529 .84091 .57107 .85141 .56826 .8471 .56261 Mtetra
.648 .743 .919 r
.8471 .56261 .85141 .56826 .86194 .56538 .85767 .55981 Mtetra
.651 .748 .921 r
.85767 .55981 .86194 .56538 .87251 .56245 .86827 .55692 Mtetra
.653 .751 .922 r
.86827 .55692 .87251 .56245 .88311 .55948 .8789 .55397 Mtetra
.655 .753 .922 r
.8789 .55397 .88311 .55948 .89374 .55648 .88956 .55096 Mtetra
.656 .754 .922 r
.88956 .55096 .89374 .55648 .90442 .55345 .90027 .54791 Mtetra
.90027 .54791 .90442 .55345 .91513 .55041 .91101 .54484 Mtetra
.91101 .54484 .91513 .55041 .92588 .54736 .92179 .54176 Mtetra
.92179 .54176 .92588 .54736 .93667 .54429 .93261 .53866 Mtetra
.656 .753 .921 r
.93261 .53866 .93667 .54429 .94751 .54121 .94347 .53555 Mtetra
.94347 .53555 .94751 .54121 .95838 .53812 .95436 .53243 Mtetra
.656 .752 .921 r
.95436 .53243 .95838 .53812 .96929 .53503 .9653 .5293 Mtetra
.656 .752 .92 r
.9653 .5293 .96929 .53503 .98024 .53192 .97628 .52616 Mtetra
.655 .751 .921 r
.38561 .68781 .391 .69252 .39996 .68999 .39458 .68528 Mtetra
.654 .752 .921 r
.39458 .68528 .39996 .68999 .40895 .68746 .40359 .68274 Mtetra
.654 .752 .922 r
.40359 .68274 .40895 .68746 .41797 .68491 .41263 .68019 Mtetra
.41263 .68019 .41797 .68491 .42702 .68236 .4217 .67763 Mtetra
.654 .753 .922 r
.4217 .67763 .42702 .68236 .4361 .6798 .4308 .67507 Mtetra
.654 .753 .923 r
.4308 .67507 .4361 .6798 .44521 .67723 .43993 .67249 Mtetra
.655 .754 .923 r
.43993 .67249 .44521 .67723 .45435 .67465 .44909 .6699 Mtetra
.656 .754 .922 r
.44909 .6699 .45435 .67465 .46352 .67204 .45828 .66727 Mtetra
.657 .754 .922 r
.45828 .66727 .46352 .67204 .47273 .66941 .4675 .6646 Mtetra
.66 .754 .92 r
.4675 .6646 .47273 .66941 .48196 .66672 .47676 .66186 Mtetra
.663 .754 .918 r
.47676 .66186 .48196 .66672 .49123 .66397 .48605 .65904 Mtetra
.668 .753 .914 r
.48605 .65904 .49123 .66397 .50053 .66113 .49537 .65608 Mtetra
.674 .75 .908 r
.49537 .65608 .50053 .66113 .50986 .65818 .50472 .65297 Mtetra
.681 .747 .901 r
.50472 .65297 .50986 .65818 .51922 .6551 .5141 .64966 Mtetra
.688 .741 .892 r
.5141 .64966 .51922 .6551 .52861 .65185 .52351 .64613 Mtetra
.694 .733 .881 r
.52351 .64613 .52861 .65185 .53803 .64846 .53295 .64238 Mtetra
.698 .724 .869 r
.53295 .64238 .53803 .64846 .54747 .64491 .54241 .63842 Mtetra
.7 .712 .858 r
.54241 .63842 .54747 .64491 .55694 .64127 .5519 .63432 Mtetra
.698 .699 .847 r
.5519 .63432 .55694 .64127 .56644 .63757 .56141 .63015 Mtetra
.693 .686 .838 r
.56141 .63015 .56644 .63757 .57597 .6339 .57095 .62604 Mtetra
.686 .672 .831 r
.57095 .62604 .57597 .6339 .58553 .63037 .58052 .62213 Mtetra
.675 .66 .828 r
.58052 .62213 .58553 .63037 .59512 .62706 .59012 .61856 Mtetra
.662 .649 .827 r
.59012 .61856 .59512 .62706 .60475 .62404 .59976 .61545 Mtetra
.648 .642 .83 r
.59976 .61545 .60475 .62404 .61442 .62134 .60944 .61282 Mtetra
.635 .638 .836 r
.60944 .61282 .61442 .62134 .62413 .61894 .61917 .61066 Mtetra
.626 .64 .845 r
.61917 .61066 .62413 .61894 .63388 .61673 .62895 .60878 Mtetra
.622 .648 .854 r
.62895 .60878 .63388 .61673 .64367 .61459 .63877 .60702 Mtetra
.628 .66 .862 r
.63877 .60702 .64367 .61459 .6535 .61233 .64862 .60507 Mtetra
.64 .674 .867 r
.64862 .60507 .6535 .61233 .66336 .60985 .6585 .60275 Mtetra
.657 .687 .866 r
.6585 .60275 .66336 .60985 .67323 .60703 .6684 .59992 Mtetra
.672 .693 .861 r
.6684 .59992 .67323 .60703 .68313 .60388 .67831 .59656 Mtetra
.682 .691 .852 r
.67831 .59656 .68313 .60388 .69305 .6005 .68823 .59283 Mtetra
.685 .684 .843 r
.68823 .59283 .69305 .6005 .703 .597 .69817 .58891 Mtetra
.679 .672 .835 r
.69817 .58891 .703 .597 .71298 .59357 .70815 .5851 Mtetra
.67 .659 .831 r
.70815 .5851 .71298 .59357 .72301 .59032 .71818 .58157 Mtetra
.657 .648 .829 r
.71818 .58157 .72301 .59032 .73308 .58738 .72827 .57852 Mtetra
.643 .64 .832 r
.72827 .57852 .73308 .58738 .74322 .58476 .73842 .57595 Mtetra
.63 .635 .837 r
.73842 .57595 .74322 .58476 .75341 .58244 .74864 .57384 Mtetra
.62 .636 .845 r
.74864 .57384 .75341 .58244 .76366 .58035 .75893 .57209 Mtetra
.613 .641 .855 r
.75893 .57209 .76366 .58035 .77396 .57839 .76928 .57054 Mtetra
.609 .651 .866 r
.76928 .57054 .77396 .57839 .78431 .57648 .77968 .56907 Mtetra
.61 .664 .878 r
.77968 .56907 .78431 .57648 .79469 .5745 .79012 .56752 Mtetra
.613 .679 .889 r
.79012 .56752 .79469 .5745 .80512 .57243 .80059 .56583 Mtetra
.619 .695 .898 r
.80059 .56583 .80512 .57243 .81557 .57021 .8111 .56393 Mtetra
.626 .71 .906 r
.8111 .56393 .81557 .57021 .82605 .56783 .82163 .56181 Mtetra
.633 .723 .912 r
.82163 .56181 .82605 .56783 .83656 .56529 .83218 .55946 Mtetra
.639 .733 .916 r
.83218 .55946 .83656 .56529 .8471 .56261 .84276 .55691 Mtetra
.644 .741 .919 r
.84276 .55691 .8471 .56261 .85767 .55981 .85336 .5542 Mtetra
.649 .747 .921 r
.85336 .5542 .85767 .55981 .86827 .55692 .864 .55135 Mtetra
.652 .75 .922 r
.864 .55135 .86827 .55692 .8789 .55397 .87466 .54841 Mtetra
.654 .753 .922 r
.87466 .54841 .8789 .55397 .88956 .55096 .88536 .5454 Mtetra
.655 .754 .922 r
.88536 .5454 .88956 .55096 .90027 .54791 .89609 .54234 Mtetra
.656 .754 .922 r
.89609 .54234 .90027 .54791 .91101 .54484 .90686 .53924 Mtetra
.657 .754 .922 r
.90686 .53924 .91101 .54484 .92179 .54176 .91767 .53613 Mtetra
.91767 .53613 .92179 .54176 .93261 .53866 .92851 .533 Mtetra
.657 .754 .921 r
.92851 .533 .93261 .53866 .94347 .53555 .9394 .52986 Mtetra
.657 .753 .921 r
.9394 .52986 .94347 .53555 .95436 .53243 .95033 .52671 Mtetra
.95033 .52671 .95436 .53243 .9653 .5293 .96129 .52354 Mtetra
.657 .752 .92 r
.96129 .52354 .9653 .5293 .97628 .52616 .9723 .52037 Mtetra
.654 .751 .921 r
.38018 .68308 .38561 .68781 .39458 .68528 .38917 .68054 Mtetra
.654 .751 .922 r
.38917 .68054 .39458 .68528 .40359 .68274 .3982 .678 Mtetra
.654 .752 .922 r
.3982 .678 .40359 .68274 .41263 .68019 .40726 .67545 Mtetra
.654 .753 .922 r
.40726 .67545 .41263 .68019 .4217 .67763 .41634 .67289 Mtetra
.654 .753 .923 r
.41634 .67289 .4217 .67763 .4308 .67507 .42546 .67032 Mtetra
.654 .754 .923 r
.42546 .67032 .4308 .67507 .43993 .67249 .43461 .66773 Mtetra
.655 .754 .923 r
.43461 .66773 .43993 .67249 .44909 .6699 .44379 .66512 Mtetra
.656 .754 .922 r
.44379 .66512 .44909 .6699 .45828 .66727 .453 .66247 Mtetra
.658 .755 .921 r
.453 .66247 .45828 .66727 .4675 .6646 .46225 .65976 Mtetra
.662 .755 .919 r
.46225 .65976 .4675 .6646 .47676 .66186 .47153 .65697 Mtetra
.666 .754 .916 r
.47153 .65697 .47676 .66186 .48605 .65904 .48084 .65405 Mtetra
.672 .753 .911 r
.48084 .65405 .48605 .65904 .49537 .65608 .49018 .65098 Mtetra
.68 .751 .905 r
.49018 .65098 .49537 .65608 .50472 .65297 .49955 .6477 Mtetra
.688 .748 .897 r
.49955 .6477 .50472 .65297 .5141 .64966 .50896 .64418 Mtetra
.696 .743 .887 r
.50896 .64418 .5141 .64966 .52351 .64613 .51839 .64038 Mtetra
.703 .736 .877 r
.51839 .64038 .52351 .64613 .53295 .64238 .52785 .63631 Mtetra
.709 .727 .865 r
.52785 .63631 .53295 .64238 .54241 .63842 .53733 .63197 Mtetra
.71 .717 .854 r
.53733 .63197 .54241 .63842 .5519 .63432 .54683 .62747 Mtetra
.709 .706 .845 r
.54683 .62747 .5519 .63432 .56141 .63015 .55636 .62287 Mtetra
.704 .694 .838 r
.55636 .62287 .56141 .63015 .57095 .62604 .56591 .61839 Mtetra
.694 .682 .833 r
.56591 .61839 .57095 .62604 .58052 .62213 .57549 .61417 Mtetra
.681 .67 .833 r
.57549 .61417 .58052 .62213 .59012 .61856 .5851 .61043 Mtetra
.663 .659 .835 r
.5851 .61043 .59012 .61856 .59976 .61545 .59476 .60729 Mtetra
.645 .651 .842 r
.59476 .60729 .59976 .61545 .60944 .61282 .60446 .6048 Mtetra
.625 .647 .851 r
.60446 .6048 .60944 .61282 .61917 .61066 .61421 .60294 Mtetra
.612 .649 .863 r
.61421 .60294 .61917 .61066 .62895 .60878 .62401 .60147 Mtetra
.605 .658 .876 r
.62401 .60147 .62895 .60878 .63877 .60702 .63386 .60014 Mtetra
.613 .676 .886 r
.63386 .60014 .63877 .60702 .64862 .60507 .64375 .59855 Mtetra
.631 .695 .891 r
.64375 .59855 .64862 .60507 .6585 .60275 .65366 .59644 Mtetra
.658 .712 .888 r
.65366 .59644 .6585 .60275 .6684 .59992 .66357 .59358 Mtetra
.682 .721 .879 r
.66357 .59358 .6684 .59992 .67831 .59656 .67349 .58998 Mtetra
.696 .719 .867 r
.67349 .58998 .67831 .59656 .68823 .59283 .68342 .58585 Mtetra
.701 .709 .854 r
.68342 .58585 .68823 .59283 .69817 .58891 .69336 .58145 Mtetra
.694 .694 .846 r
.69336 .58145 .69817 .58891 .70815 .5851 .70334 .57719 Mtetra
.682 .678 .84 r
.70334 .57719 .70815 .5851 .71818 .58157 .71336 .57332 Mtetra
.663 .663 .839 r
.71336 .57332 .71818 .58157 .72827 .57852 .72346 .57007 Mtetra
.644 .651 .842 r
.72346 .57007 .72827 .57852 .73842 .57595 .73362 .56749 Mtetra
.626 .642 .847 r
.73362 .56749 .73842 .57595 .74864 .57384 .74387 .56553 Mtetra
.61 .639 .855 r
.74387 .56553 .74864 .57384 .75893 .57209 .75419 .56404 Mtetra
.6 .642 .864 r
.75419 .56404 .75893 .57209 .76928 .57054 .76458 .56284 Mtetra
.594 .649 .874 r
.76458 .56284 .76928 .57054 .77968 .56907 .77503 .56175 Mtetra
.595 .661 .884 r
.77503 .56175 .77968 .56907 .79012 .56752 .78552 .56057 Mtetra
.599 .675 .894 r
.78552 .56057 .79012 .56752 .80059 .56583 .79604 .55923 Mtetra
.607 .691 .902 r
.79604 .55923 .80059 .56583 .8111 .56393 .8066 .55762 Mtetra
.615 .705 .909 r
.8066 .55762 .8111 .56393 .82163 .56181 .81717 .55574 Mtetra
.625 .719 .914 r
.81717 .55574 .82163 .56181 .83218 .55946 .82777 .55357 Mtetra
.633 .73 .918 r
.82777 .55357 .83218 .55946 .84276 .55691 .83839 .55115 Mtetra
.64 .738 .92 r
.83839 .55115 .84276 .55691 .85336 .5542 .84903 .54853 Mtetra
.646 .745 .921 r
.84903 .54853 .85336 .5542 .864 .55135 .8597 .54573 Mtetra
.65 .749 .922 r
.8597 .54573 .864 .55135 .87466 .54841 .87039 .54281 Mtetra
.653 .752 .922 r
.87039 .54281 .87466 .54841 .88536 .5454 .88112 .5398 Mtetra
.655 .754 .922 r
.88112 .5398 .88536 .5454 .89609 .54234 .89188 .53673 Mtetra
.656 .755 .922 r
.89188 .53673 .89609 .54234 .90686 .53924 .90268 .53361 Mtetra
.657 .755 .922 r
.90268 .53361 .90686 .53924 .91767 .53613 .91352 .53047 Mtetra
.91352 .53047 .91767 .53613 .92851 .533 .92439 .52731 Mtetra
.657 .754 .921 r
.92439 .52731 .92851 .533 .9394 .52986 .93531 .52413 Mtetra
.93531 .52413 .9394 .52986 .95033 .52671 .94626 .52095 Mtetra
.657 .753 .921 r
.94626 .52095 .95033 .52671 .96129 .52354 .95726 .51775 Mtetra
.657 .753 .92 r
.95726 .51775 .96129 .52354 .9723 .52037 .96829 .51454 Mtetra
.653 .751 .921 r
.37472 .67831 .38018 .68308 .38917 .68054 .38373 .67578 Mtetra
.653 .751 .922 r
.38373 .67578 .38917 .68054 .3982 .678 .39277 .67324 Mtetra
.653 .752 .923 r
.39277 .67324 .3982 .678 .40726 .67545 .40185 .67069 Mtetra
.653 .753 .923 r
.40185 .67069 .40726 .67545 .41634 .67289 .41096 .66812 Mtetra
.41096 .66812 .41634 .67289 .42546 .67032 .42009 .66555 Mtetra
.654 .754 .923 r
.42009 .66555 .42546 .67032 .43461 .66773 .42926 .66295 Mtetra
.655 .755 .923 r
.42926 .66295 .43461 .66773 .44379 .66512 .43846 .66032 Mtetra
.657 .755 .922 r
.43846 .66032 .44379 .66512 .453 .66247 .4477 .65764 Mtetra
.659 .755 .921 r
.4477 .65764 .453 .66247 .46225 .65976 .45696 .65488 Mtetra
.664 .755 .918 r
.45696 .65488 .46225 .65976 .47153 .65697 .46626 .65202 Mtetra
.669 .754 .914 r
.46626 .65202 .47153 .65697 .48084 .65405 .47559 .64901 Mtetra
.677 .753 .909 r
.47559 .64901 .48084 .65405 .49018 .65098 .48496 .64581 Mtetra
.685 .751 .902 r
.48496 .64581 .49018 .65098 .49955 .6477 .49435 .64237 Mtetra
.694 .748 .893 r
.49435 .64237 .49955 .6477 .50896 .64418 .50378 .63864 Mtetra
.703 .744 .883 r
.50378 .63864 .50896 .64418 .51839 .64038 .51323 .6346 Mtetra
.711 .738 .872 r
.51323 .6346 .51839 .64038 .52785 .63631 .52271 .63024 Mtetra
.717 .731 .862 r
.52271 .63024 .52785 .63631 .53733 .63197 .53221 .62558 Mtetra
.719 .723 .852 r
.53221 .62558 .53733 .63197 .54683 .62747 .54174 .62074 Mtetra
.718 .713 .845 r
.54174 .62074 .54683 .62747 .55636 .62287 .55128 .61582 Mtetra
.712 .703 .84 r
.55128 .61582 .55636 .62287 .56591 .61839 .56085 .61105 Mtetra
.701 .693 .839 r
.56085 .61105 .56591 .61839 .57549 .61417 .57044 .60662 Mtetra
.685 .682 .841 r
.57044 .60662 .57549 .61417 .5851 .61043 .58007 .60279 Mtetra
.663 .672 .848 r
.58007 .60279 .5851 .61043 .59476 .60729 .58974 .59971 Mtetra
.638 .664 .859 r
.58974 .59971 .59476 .60729 .60446 .6048 .59947 .59747 Mtetra
.609 .66 .874 r
.59947 .59747 .60446 .6048 .61421 .60294 .60924 .59601 Mtetra
.588 .663 .89 r
.60924 .59601 .61421 .60294 .62401 .60147 .61908 .59503 Mtetra
.575 .675 .907 r
.61908 .59503 .62401 .60147 .63386 .60014 .62896 .59423 Mtetra
.586 .699 .92 r
.62896 .59423 .63386 .60014 .64375 .59855 .63888 .59307 Mtetra
.615 .727 .926 r
.63888 .59307 .64375 .59855 .65366 .59644 .64882 .59119 Mtetra
.656 .752 .92 r
.64882 .59119 .65366 .59644 .66357 .59358 .65876 .58832 Mtetra
.694 .764 .905 r
.65876 .58832 .66357 .59358 .67349 .58998 .6687 .58444 Mtetra
.715 .76 .888 r
.6687 .58444 .67349 .58998 .68342 .58585 .67863 .57985 Mtetra
.723 .747 .871 r
.67863 .57985 .68342 .58585 .69336 .58145 .68857 .57488 Mtetra
.714 .727 .861 r
.68857 .57488 .69336 .58145 .70334 .57719 .69854 .57007 Mtetra
.697 .706 .854 r
.69854 .57007 .70334 .57719 .71336 .57332 .70856 .56576 Mtetra
.673 .686 .854 r
.70856 .56576 .71336 .57332 .72346 .57007 .71866 .56223 Mtetra
.648 .668 .856 r
.71866 .56223 .72346 .57007 .73362 .56749 .72884 .55954 Mtetra
.623 .655 .861 r
.72884 .55954 .73362 .56749 .74387 .56553 .73911 .55762 Mtetra
.602 .647 .867 r
.73911 .55762 .74387 .56553 .75419 .56404 .74946 .55631 Mtetra
.588 .646 .875 r
.74946 .55631 .75419 .56404 .76458 .56284 .75988 .55535 Mtetra
.58 .65 .884 r
.75988 .55535 .76458 .56284 .77503 .56175 .77037 .55456 Mtetra
.581 .66 .892 r
.77037 .55456 .77503 .56175 .78552 .56057 .7809 .55369 Mtetra
.585 .672 .9 r
.7809 .55369 .78552 .56057 .79604 .55923 .79147 .55263 Mtetra
.595 .687 .906 r
.79147 .55263 .79604 .55923 .8066 .55762 .80207 .55128 Mtetra
.606 .701 .911 r
.80207 .55128 .8066 .55762 .81717 .55574 .81269 .54961 Mtetra
.617 .715 .915 r
.81269 .54961 .81717 .55574 .82777 .55357 .82333 .54761 Mtetra
.627 .726 .918 r
.82333 .54761 .82777 .55357 .83839 .55115 .83398 .54532 Mtetra
.636 .735 .92 r
.83398 .54532 .83839 .55115 .84903 .54853 .84466 .54279 Mtetra
.643 .743 .921 r
.84466 .54279 .84903 .54853 .8597 .54573 .85536 .54005 Mtetra
.648 .748 .922 r
.85536 .54005 .8597 .54573 .87039 .54281 .8661 .53717 Mtetra
.652 .751 .922 r
.8661 .53717 .87039 .54281 .88112 .5398 .87685 .53417 Mtetra
.654 .754 .923 r
.87685 .53417 .88112 .5398 .89188 .53673 .88765 .53109 Mtetra
.656 .755 .923 r
.88765 .53109 .89188 .53673 .90268 .53361 .89848 .52796 Mtetra
.657 .755 .922 r
.89848 .52796 .90268 .53361 .91352 .53047 .90934 .52479 Mtetra
.658 .755 .922 r
.90934 .52479 .91352 .53047 .92439 .52731 .92025 .52159 Mtetra
.92025 .52159 .92439 .52731 .93531 .52413 .93119 .51838 Mtetra
.658 .755 .921 r
.93119 .51838 .93531 .52413 .94626 .52095 .94217 .51515 Mtetra
.658 .754 .921 r
.94217 .51515 .94626 .52095 .95726 .51775 .95319 .51191 Mtetra
.658 .753 .92 r
.95319 .51191 .95726 .51775 .96829 .51454 .96426 .50866 Mtetra
.652 .751 .922 r
.36922 .67351 .37472 .67831 .38373 .67578 .37825 .67099 Mtetra
.652 .751 .923 r
.37825 .67099 .38373 .67578 .39277 .67324 .38732 .66845 Mtetra
.652 .752 .923 r
.38732 .66845 .39277 .67324 .40185 .67069 .39641 .6659 Mtetra
.652 .753 .924 r
.39641 .6659 .40185 .67069 .41096 .66812 .40553 .66334 Mtetra
.652 .754 .924 r
.40553 .66334 .41096 .66812 .42009 .66555 .41469 .66077 Mtetra
.653 .755 .924 r
.41469 .66077 .42009 .66555 .42926 .66295 .42388 .65816 Mtetra
.655 .755 .924 r
.42388 .65816 .42926 .66295 .43846 .66032 .4331 .65551 Mtetra
.657 .756 .922 r
.4331 .65551 .43846 .66032 .4477 .65764 .44235 .65279 Mtetra
.661 .756 .921 r
.44235 .65279 .4477 .65764 .45696 .65488 .45164 .64998 Mtetra
.666 .756 .917 r
.45164 .64998 .45696 .65488 .46626 .65202 .46096 .64704 Mtetra
.673 .755 .913 r
.46096 .64704 .46626 .65202 .47559 .64901 .47032 .64393 Mtetra
.681 .754 .907 r
.47032 .64393 .47559 .64901 .48496 .64581 .4797 .6406 Mtetra
.69 .752 .899 r
.4797 .6406 .48496 .64581 .49435 .64237 .48912 .63699 Mtetra
.7 .749 .89 r
.48912 .63699 .49435 .64237 .50378 .63864 .49857 .63307 Mtetra
.71 .745 .88 r
.49857 .63307 .50378 .63864 .51323 .6346 .50805 .6288 Mtetra
.717 .74 .869 r
.50805 .6288 .51323 .6346 .52271 .63024 .51755 .62419 Mtetra
.724 .734 .86 r
.51755 .62419 .52271 .63024 .53221 .62558 .52707 .61927 Mtetra
.726 .728 .852 r
.52707 .61927 .53221 .62558 .54174 .62074 .53662 .61418 Mtetra
.725 .721 .846 r
.53662 .61418 .54174 .62074 .55128 .61582 .54618 .60903 Mtetra
.718 .713 .845 r
.54618 .60903 .55128 .61582 .56085 .61105 .55577 .60409 Mtetra
.706 .705 .847 r
.55577 .60409 .56085 .61105 .57044 .60662 .56538 .59958 Mtetra
.686 .697 .855 r
.56538 .59958 .57044 .60662 .58007 .60279 .57503 .59579 Mtetra
.659 .689 .867 r
.57503 .59579 .58007 .60279 .58974 .59971 .58472 .5929 Mtetra
.625 .682 .884 r
.58472 .5929 .58974 .59971 .59947 .59747 .59447 .59098 Mtetra
.583 .677 .904 r
.59447 .59098 .59947 .59747 .60924 .59601 .60427 .59 Mtetra
.548 .68 .925 r
.60427 .59 .60924 .59601 .61908 .59503 .61414 .5896 Mtetra
.525 .693 .945 r
.61414 .5896 .61908 .59503 .62896 .59423 .62406 .58939 Mtetra
.539 .725 .96 r
.62406 .58939 .62896 .59423 .63888 .59307 .63402 .58869 Mtetra
.583 .764 .965 r
.63402 .58869 .63888 .59307 .64882 .59119 .64399 .58709 Mtetra
.648 .799 .955 r
.64399 .58709 .64882 .59119 .65876 .58832 .65396 .58419 Mtetra
.705 .814 .933 r
.65396 .58419 .65876 .58832 .6687 .58444 .66391 .58001 Mtetra
.736 .809 .909 r
.66391 .58001 .6687 .58444 .67863 .57985 .67385 .57491 Mtetra
.748 .792 .889 r
.67385 .57491 .67863 .57985 .68857 .57488 .68379 .56931 Mtetra
.738 .768 .877 r
.68379 .56931 .68857 .57488 .69854 .57007 .69376 .56389 Mtetra
.717 .742 .871 r
.69376 .56389 .69854 .57007 .70856 .56576 .70378 .55905 Mtetra
.688 .717 .871 r
.70378 .55905 .70856 .56576 .71866 .56223 .71388 .55515 Mtetra
.656 .694 .874 r
.71388 .55515 .71866 .56223 .72884 .55954 .72407 .55223 Mtetra
.624 .675 .878 r
.72407 .55223 .72884 .55954 .73911 .55762 .73435 .55023 Mtetra
.598 .661 .883 r
.73435 .55023 .73911 .55762 .74946 .55631 .74472 .54896 Mtetra
.58 .655 .888 r
.74472 .54896 .74946 .55631 .75988 .55535 .75518 .54814 Mtetra
.569 .655 .894 r
.75518 .54814 .75988 .55535 .77037 .55456 .7657 .54753 Mtetra
.569 .661 .899 r
.7657 .54753 .77037 .55456 .7809 .55369 .77627 .54688 Mtetra
.574 .671 .905 r
.77627 .54688 .7809 .55369 .79147 .55263 .78688 .54605 Mtetra
.585 .684 .91 r
.78688 .54605 .79147 .55263 .80207 .55128 .79751 .54491 Mtetra
.597 .698 .914 r
.79751 .54491 .80207 .55128 .81269 .54961 .80817 .54344 Mtetra
.61 .711 .917 r
.80817 .54344 .81269 .54961 .82333 .54761 .81885 .5416 Mtetra
.621 .723 .919 r
.81885 .5416 .82333 .54761 .83398 .54532 .82955 .53945 Mtetra
.631 .733 .921 r
.82955 .53945 .83398 .54532 .84466 .54279 .84027 .53701 Mtetra
.64 .741 .922 r
.84027 .53701 .84466 .54279 .85536 .54005 .85101 .53434 Mtetra
.646 .747 .923 r
.85101 .53434 .85536 .54005 .8661 .53717 .86177 .5315 Mtetra
.651 .751 .923 r
.86177 .5315 .8661 .53717 .87685 .53417 .87256 .52851 Mtetra
.654 .754 .923 r
.87256 .52851 .87685 .53417 .88765 .53109 .88339 .52543 Mtetra
.656 .755 .923 r
.88339 .52543 .88765 .53109 .89848 .52796 .89424 .52228 Mtetra
.657 .756 .923 r
.89424 .52228 .89848 .52796 .90934 .52479 .90514 .51908 Mtetra
.658 .756 .922 r
.90514 .51908 .90934 .52479 .92025 .52159 .91607 .51585 Mtetra
.91607 .51585 .92025 .52159 .93119 .51838 .92704 .5126 Mtetra
.659 .755 .921 r
.92704 .5126 .93119 .51838 .94217 .51515 .93805 .50933 Mtetra
.659 .754 .921 r
.93805 .50933 .94217 .51515 .95319 .51191 .9491 .50605 Mtetra
.659 .754 .92 r
.9491 .50605 .95319 .51191 .96426 .50866 .9602 .50275 Mtetra
.651 .75 .922 r
.36369 .66869 .36922 .67351 .37825 .67099 .37274 .66617 Mtetra
.651 .751 .923 r
.37274 .66617 .37825 .67099 .38732 .66845 .38182 .66364 Mtetra
.651 .752 .924 r
.38182 .66364 .38732 .66845 .39641 .6659 .39093 .66111 Mtetra
.651 .753 .924 r
.39093 .66111 .39641 .6659 .40553 .66334 .40008 .65855 Mtetra
.652 .754 .925 r
.40008 .65855 .40553 .66334 .41469 .66077 .40925 .65597 Mtetra
.653 .755 .925 r
.40925 .65597 .41469 .66077 .42388 .65816 .41846 .65336 Mtetra
.655 .756 .924 r
.41846 .65336 .42388 .65816 .4331 .65551 .4277 .65069 Mtetra
.658 .757 .923 r
.4277 .65069 .4331 .65551 .44235 .65279 .43698 .64794 Mtetra
.662 .757 .921 r
.43698 .64794 .44235 .65279 .45164 .64998 .44628 .64507 Mtetra
.669 .757 .917 r
.44628 .64507 .45164 .64998 .46096 .64704 .45563 .64205 Mtetra
.676 .757 .912 r
.45563 .64205 .46096 .64704 .47032 .64393 .465 .63883 Mtetra
.685 .755 .905 r
.465 .63883 .47032 .64393 .4797 .6406 .47441 .63536 Mtetra
.695 .753 .896 r
.47441 .63536 .4797 .6406 .48912 .63699 .48386 .63158 Mtetra
.705 .75 .887 r
.48386 .63158 .48912 .63699 .49857 .63307 .49333 .62746 Mtetra
.715 .746 .877 r
.49333 .62746 .49857 .63307 .50805 .6288 .50283 .62298 Mtetra
.723 .742 .867 r
.50283 .62298 .50805 .6288 .51755 .62419 .51235 .61817 Mtetra
.728 .738 .859 r
.51235 .61817 .51755 .62419 .52707 .61927 .5219 .61307 Mtetra
.73 .733 .853 r
.5219 .61307 .52707 .61927 .53662 .61418 .53147 .60783 Mtetra
.729 .729 .85 r
.53147 .60783 .53662 .61418 .54618 .60903 .54105 .60259 Mtetra
.721 .725 .853 r
.54105 .60259 .54618 .60903 .55577 .60409 .55066 .59763 Mtetra
.707 .721 .86 r
.55066 .59763 .55577 .60409 .56538 .59958 .5603 .5932 Mtetra
.683 .717 .874 r
.5603 .5932 .56538 .59958 .57503 .59579 .56997 .58959 Mtetra
.648 .712 .894 r
.56997 .58959 .57503 .59579 .58472 .5929 .57968 .58701 Mtetra
.6 .706 .918 r
.57968 .58701 .58472 .5929 .59447 .59098 .58946 .58555 Mtetra
.536 .698 .944 r
.58946 .58555 .59447 .59098 .60427 .59 .5993 .58513 Mtetra
.475 .696 .965 r
.5993 .58513 .60427 .59 .61414 .5896 .6092 .58536 Mtetra
.428 .705 .98 r
.6092 .58536 .61414 .5896 .62406 .58939 .61917 .5858 Mtetra
.444 .745 .992 r
.61917 .5858 .62406 .58939 .63402 .58869 .62917 .58563 Mtetra
.512 .801 .998 r
.62917 .58563 .63402 .58869 .64399 .58709 .63918 .58432 Mtetra
.618 .855 .988 r
.63918 .58432 .64399 .58709 .65396 .58419 .64918 .58141 Mtetra
.708 .878 .96 r
.64918 .58141 .65396 .58419 .66391 .58001 .65915 .57689 Mtetra
.757 .871 .931 r
.65915 .57689 .66391 .58001 .67385 .57491 .6691 .57123 Mtetra
.775 .849 .907 r
.6691 .57123 .67385 .57491 .68379 .56931 .67904 .56495 Mtetra
.765 .82 .896 r
.67904 .56495 .68379 .56931 .69376 .56389 .68901 .55885 Mtetra
.742 .79 .891 r
.68901 .55885 .69376 .56389 .70378 .55905 .69903 .55341 Mtetra
.707 .759 .893 r
.69903 .55341 .70378 .55905 .71388 .55515 .70913 .54901 Mtetra
.668 .73 .896 r
.70913 .54901 .71388 .55515 .72407 .55223 .71932 .54574 Mtetra
.63 .704 .899 r
.71932 .54574 .72407 .55223 .73435 .55023 .72961 .54351 Mtetra
.597 .683 .901 r
.72961 .54351 .73435 .55023 .74472 .54896 .74 .54212 Mtetra
.575 .67 .903 r
.74 .54212 .74472 .54896 .75518 .54814 .75047 .54127 Mtetra
.562 .664 .905 r
.75047 .54127 .75518 .54814 .7657 .54753 .76102 .54071 Mtetra
.561 .665 .907 r
.76102 .54071 .7657 .54753 .77627 .54688 .77161 .54017 Mtetra
.565 .672 .91 r
.77161 .54017 .77627 .54688 .78688 .54605 .78226 .5395 Mtetra
.576 .683 .913 r
.78226 .5395 .78688 .54605 .79751 .54491 .79293 .53853 Mtetra
.588 .695 .916 r
.79293 .53853 .79751 .54491 .80817 .54344 .80363 .53722 Mtetra
.602 .708 .919 r
.80363 .53722 .80817 .54344 .81885 .5416 .81435 .53555 Mtetra
.615 .72 .921 r
.81435 .53555 .81885 .5416 .82955 .53945 .82509 .53353 Mtetra
.626 .731 .922 r
.82509 .53353 .82955 .53945 .84027 .53701 .83584 .5312 Mtetra
.636 .74 .923 r
.83584 .5312 .84027 .53701 .85101 .53434 .84662 .52861 Mtetra
.643 .746 .924 r
.84662 .52861 .85101 .53434 .86177 .5315 .85742 .52581 Mtetra
.649 .751 .924 r
.85742 .52581 .86177 .5315 .87256 .52851 .86824 .52284 Mtetra
.653 .754 .924 r
.86824 .52284 .87256 .52851 .88339 .52543 .8791 .51976 Mtetra
.656 .756 .924 r
.8791 .51976 .88339 .52543 .89424 .52228 .88999 .51659 Mtetra
.657 .757 .923 r
.88999 .51659 .89424 .52228 .90514 .51908 .90091 .51336 Mtetra
.659 .757 .923 r
.90091 .51336 .90514 .51908 .91607 .51585 .91187 .51009 Mtetra
.659 .757 .922 r
.91187 .51009 .91607 .51585 .92704 .5126 .92287 .50679 Mtetra
.66 .756 .921 r
.92287 .50679 .92704 .5126 .93805 .50933 .93391 .50347 Mtetra
.66 .755 .921 r
.93391 .50347 .93805 .50933 .9491 .50605 .94498 .50014 Mtetra
.66 .754 .92 r
.94498 .50014 .9491 .50605 .9602 .50275 .9561 .4968 Mtetra
.65 .75 .923 r
.35813 .66383 .36369 .66869 .37274 .66617 .36719 .66132 Mtetra
.649 .751 .924 r
.36719 .66132 .37274 .66617 .38182 .66364 .37629 .65881 Mtetra
.65 .752 .924 r
.37629 .65881 .38182 .66364 .39093 .66111 .38542 .65628 Mtetra
.65 .753 .925 r
.38542 .65628 .39093 .66111 .40008 .65855 .39458 .65373 Mtetra
.651 .754 .925 r
.39458 .65373 .40008 .65855 .40925 .65597 .40378 .65116 Mtetra
.652 .756 .925 r
.40378 .65116 .40925 .65597 .41846 .65336 .41301 .64854 Mtetra
.654 .757 .925 r
.41301 .64854 .41846 .65336 .4277 .65069 .42227 .64586 Mtetra
.658 .758 .923 r
.42227 .64586 .4277 .65069 .43698 .64794 .43156 .64308 Mtetra
.664 .759 .921 r
.43156 .64308 .43698 .64794 .44628 .64507 .44089 .64017 Mtetra
.671 .759 .917 r
.44089 .64017 .44628 .64507 .45563 .64205 .45026 .63707 Mtetra
.68 .759 .911 r
.45026 .63707 .45563 .64205 .465 .63883 .45966 .63374 Mtetra
.69 .758 .904 r
.45966 .63374 .465 .63883 .47441 .63536 .46909 .63013 Mtetra
.701 .756 .895 r
.46909 .63013 .47441 .63536 .48386 .63158 .47856 .62618 Mtetra
.711 .753 .885 r
.47856 .62618 .48386 .63158 .49333 .62746 .48806 .62187 Mtetra
.72 .749 .875 r
.48806 .62187 .49333 .62746 .50283 .62298 .49758 .6172 Mtetra
.727 .745 .866 r
.49758 .6172 .50283 .62298 .51235 .61817 .50713 .61221 Mtetra
.732 .741 .859 r
.50713 .61221 .51235 .61817 .5219 .61307 .5167 .60698 Mtetra
.732 .738 .856 r
.5167 .60698 .5219 .61307 .53147 .60783 .52629 .60168 Mtetra
.729 .736 .857 r
.52629 .60168 .53147 .60783 .54105 .60259 .5359 .59649 Mtetra
.72 .736 .864 r
.5359 .59649 .54105 .60259 .55066 .59763 .54553 .59168 Mtetra
.702 .737 .878 r
.54553 .59168 .55066 .59763 .5603 .5932 .55519 .58751 Mtetra
.672 .738 .9 r
.55519 .58751 .5603 .5932 .56997 .58959 .56489 .58427 Mtetra
.625 .737 .928 r
.56489 .58427 .56997 .58959 .57968 .58701 .57463 .58215 Mtetra
.554 .73 .957 r
.57463 .58215 .57968 .58701 .58946 .58555 .58444 .58121 Mtetra
.455 .713 .979 r
.58444 .58121 .58946 .58555 .5993 .58513 .59431 .58138 Mtetra
.353 .692 .982 r
.59431 .58138 .5993 .58513 .6092 .58536 .60426 .58224 Mtetra
.276 .68 .97 r
.60426 .58224 .6092 .58536 .61917 .5858 .61426 .58329 Mtetra
.301 .723 .973 r
.61426 .58329 .61917 .5858 .62917 .58563 .6243 .5836 Mtetra
.406 .802 .986 r
.6243 .5836 .62917 .58563 .63918 .58432 .63436 .58257 Mtetra
.569 .886 .99 r
.63436 .58257 .63918 .58432 .64918 .58141 .64439 .57965 Mtetra
.701 .923 .967 r
.64439 .57965 .64918 .58141 .65915 .57689 .65439 .57482 Mtetra
.769 .92 .937 r
.65439 .57482 .65915 .57689 .6691 .57123 .66436 .56864 Mtetra
.797 .899 .914 r
.66436 .56864 .6691 .57123 .67904 .56495 .67431 .5617 Mtetra
.79 .871 .908 r
.67431 .5617 .67904 .56495 .68901 .55885 .68429 .55494 Mtetra
.767 .841 .908 r
.68429 .55494 .68901 .55885 .69903 .55341 .69431 .54887 Mtetra
.729 .81 .914 r
.69431 .54887 .69903 .55341 .70913 .54901 .70441 .5439 Mtetra
.686 .776 .919 r
.70441 .5439 .70913 .54901 .71932 .54574 .7146 .54012 Mtetra
.642 .742 .922 r
.7146 .54012 .71932 .54574 .72961 .54351 .72489 .53749 Mtetra
.604 .712 .921 r
.72489 .53749 .72961 .54351 .74 .54212 .73528 .53579 Mtetra
.577 .69 .918 r
.73528 .53579 .74 .54212 .75047 .54127 .74576 .53475 Mtetra
.56 .676 .916 r
.74576 .53475 .75047 .54127 .76102 .54071 .75632 .53411 Mtetra
.556 .672 .915 r
.75632 .53411 .76102 .54071 .77161 .54017 .76695 .53358 Mtetra
.558 .674 .916 r
.76695 .53358 .77161 .54017 .78226 .5395 .77762 .533 Mtetra
.568 .682 .917 r
.77762 .533 .78226 .5395 .79293 .53853 .78833 .53216 Mtetra
.58 .693 .92 r
.78833 .53216 .79293 .53853 .80363 .53722 .79906 .53102 Mtetra
.594 .707 .922 r
.79906 .53102 .80363 .53722 .81435 .53555 .80982 .5295 Mtetra
.608 .719 .924 r
.80982 .5295 .81435 .53555 .82509 .53353 .8206 .52762 Mtetra
.621 .731 .925 r
.8206 .52762 .82509 .53353 .83584 .5312 .83139 .5254 Mtetra
.632 .74 .926 r
.83139 .5254 .83584 .5312 .84662 .52861 .8422 .52288 Mtetra
.64 .747 .926 r
.8422 .52288 .84662 .52861 .85742 .52581 .85304 .52012 Mtetra
.647 .752 .926 r
.85304 .52012 .85742 .52581 .86824 .52284 .8639 .51717 Mtetra
.652 .756 .925 r
.8639 .51717 .86824 .52284 .8791 .51976 .87478 .51407 Mtetra
.656 .757 .925 r
.87478 .51407 .8791 .51976 .88999 .51659 .8857 .51088 Mtetra
.658 .758 .924 r
.8857 .51088 .88999 .51659 .90091 .51336 .89665 .50761 Mtetra
.66 .758 .923 r
.89665 .50761 .90091 .51336 .91187 .51009 .90764 .50429 Mtetra
.66 .758 .922 r
.90764 .50429 .91187 .51009 .92287 .50679 .91867 .50095 Mtetra
.661 .757 .921 r
.91867 .50095 .92287 .50679 .93391 .50347 .92973 .49758 Mtetra
.661 .756 .92 r
.92973 .49758 .93391 .50347 .94498 .50014 .94084 .49419 Mtetra
.661 .755 .92 r
.94084 .49419 .94498 .50014 .9561 .4968 .95198 .4908 Mtetra
.649 .75 .923 r
.35253 .65894 .35813 .66383 .36719 .66132 .36161 .65644 Mtetra
.648 .751 .924 r
.36161 .65644 .36719 .66132 .37629 .65881 .37073 .65394 Mtetra
.648 .752 .925 r
.37073 .65394 .37629 .65881 .38542 .65628 .37988 .65142 Mtetra
.649 .753 .925 r
.37988 .65142 .38542 .65628 .39458 .65373 .38906 .64889 Mtetra
.649 .754 .926 r
.38906 .64889 .39458 .65373 .40378 .65116 .39827 .64633 Mtetra
.651 .756 .926 r
.39827 .64633 .40378 .65116 .41301 .64854 .40752 .64372 Mtetra
.654 .757 .926 r
.40752 .64372 .41301 .64854 .42227 .64586 .4168 .64104 Mtetra
.658 .759 .924 r
.4168 .64104 .42227 .64586 .43156 .64308 .42611 .63824 Mtetra
.664 .761 .922 r
.42611 .63824 .43156 .64308 .44089 .64017 .43547 .6353 Mtetra
.673 .762 .918 r
.43547 .6353 .44089 .64017 .45026 .63707 .44485 .63214 Mtetra
.683 .763 .912 r
.44485 .63214 .45026 .63707 .45966 .63374 .45428 .62871 Mtetra
.694 .762 .904 r
.45428 .62871 .45966 .63374 .46909 .63013 .46374 .62496 Mtetra
.706 .761 .895 r
.46374 .62496 .46909 .63013 .47856 .62618 .47323 .62083 Mtetra
.717 .757 .884 r
.47323 .62083 .47856 .62618 .48806 .62187 .48275 .61633 Mtetra
.726 .753 .874 r
.48275 .61633 .48806 .62187 .49758 .6172 .4923 .61147 Mtetra
.731 .749 .866 r
.4923 .61147 .49758 .6172 .50713 .61221 .50187 .60634 Mtetra
.734 .745 .861 r
.50187 .60634 .50713 .61221 .5167 .60698 .51146 .60103 Mtetra
.732 .743 .861 r
.51146 .60103 .5167 .60698 .52629 .60168 .52108 .59578 Mtetra
.726 .744 .866 r
.52108 .59578 .52629 .60168 .5359 .59649 .53071 .59078 Mtetra
.712 .748 .88 r
.53071 .59078 .5359 .59649 .54553 .59168 .54037 .58631 Mtetra
.688 .755 .902 r
.54037 .58631 .54553 .59168 .55519 .58751 .55006 .58262 Mtetra
.647 .762 .933 r
.55006 .58262 .55519 .58751 .56489 .58427 .55978 .57994 Mtetra
.576 .764 .968 r
.55978 .57994 .56489 .58427 .57463 .58215 .56956 .57843 Mtetra
.464 .748 .991 r
.56956 .57843 .57463 .58215 .58444 .58121 .5794 .5781 Mtetra
.308 .699 .978 r
.5794 .5781 .58444 .58121 .59431 .58138 .58931 .57884 Mtetra
.159 .635 .927 r
.58931 .57884 .59431 .58138 .60426 .58224 .59929 .58025 Mtetra
.064 .591 .869 r
.59929 .58025 .60426 .58224 .61426 .58329 .60934 .58182 Mtetra
.112 .641 .87 r
.60934 .58182 .61426 .58329 .6243 .5836 .61943 .58254 Mtetra
.262 .754 .912 r
.61943 .58254 .6243 .5836 .63436 .58257 .62952 .58176 Mtetra
.493 .887 .956 r
.62952 .58176 .63436 .58257 .64439 .57965 .6396 .57882 Mtetra
.677 .952 .953 r
.6396 .57882 .64439 .57965 .65439 .57482 .64963 .57371 Mtetra
.77 .958 .931 r
.64963 .57371 .65439 .57482 .66436 .56864 .65962 .56709 Mtetra
.809 .943 .913 r
.65962 .56709 .66436 .56864 .67431 .5617 .66959 .5596 Mtetra
.808 .922 .913 r
.66959 .5596 .67431 .5617 .68429 .55494 .67958 .55225 Mtetra
.788 .898 .921 r
.67958 .55225 .68429 .55494 .69431 .54887 .68961 .54556 Mtetra
.752 .869 .933 r
.68961 .54556 .69431 .54887 .70441 .5439 .69971 .53995 Mtetra
.708 .832 .941 r
.69971 .53995 .70441 .5439 .7146 .54012 .7099 .53552 Mtetra
.661 .791 .944 r
.7099 .53552 .7146 .54012 .72489 .53749 .72019 .53227 Mtetra
.619 .751 .941 r
.72019 .53227 .72489 .53749 .73528 .53579 .73057 .53005 Mtetra
.587 .718 .934 r
.73057 .53005 .73528 .53579 .74576 .53475 .74105 .52862 Mtetra
.565 .694 .928 r
.74105 .52862 .74576 .53475 .75632 .53411 .75162 .52774 Mtetra
.555 .681 .923 r
.75162 .52774 .75632 .53411 .76695 .53358 .76226 .52713 Mtetra
.553 .678 .921 r
.76226 .52713 .76695 .53358 .77762 .533 .77296 .52658 Mtetra
.56 .683 .922 r
.77296 .52658 .77762 .533 .78833 .53216 .7837 .52585 Mtetra
.57 .693 .924 r
.7837 .52585 .78833 .53216 .79906 .53102 .79447 .52487 Mtetra
.585 .706 .926 r
.79447 .52487 .79906 .53102 .80982 .5295 .80527 .52351 Mtetra
.6 .719 .928 r
.80527 .52351 .80982 .5295 .8206 .52762 .81609 .52177 Mtetra
.615 .732 .929 r
.81609 .52177 .8206 .52762 .83139 .5254 .82692 .51964 Mtetra
.627 .742 .929 r
.82692 .51964 .83139 .5254 .8422 .52288 .83777 .51719 Mtetra
.638 .749 .929 r
.83777 .51719 .8422 .52288 .85304 .52012 .84863 .51446 Mtetra
.646 .754 .928 r
.84863 .51446 .85304 .52012 .8639 .51717 .85952 .5115 Mtetra
.652 .757 .927 r
.85952 .5115 .8639 .51717 .87478 .51407 .87044 .50838 Mtetra
.656 .759 .925 r
.87044 .50838 .87478 .51407 .8857 .51088 .88138 .50514 Mtetra
.659 .759 .924 r
.88138 .50514 .8857 .51088 .89665 .50761 .89236 .50183 Mtetra
.661 .759 .923 r
.89236 .50183 .89665 .50761 .90764 .50429 .90338 .49846 Mtetra
.661 .758 .922 r
.90338 .49846 .90764 .50429 .91867 .50095 .91443 .49506 Mtetra
.662 .757 .921 r
.91443 .49506 .91867 .50095 .92973 .49758 .92553 .49164 Mtetra
.662 .756 .92 r
.92553 .49164 .92973 .49758 .94084 .49419 .93666 .48821 Mtetra
.662 .755 .919 r
.93666 .48821 .94084 .49419 .95198 .4908 .94784 .48476 Mtetra
.648 .749 .924 r
.34689 .65403 .35253 .65894 .36161 .65644 .356 .65153 Mtetra
.647 .75 .924 r
.356 .65153 .36161 .65644 .37073 .65394 .36513 .64903 Mtetra
.647 .751 .925 r
.36513 .64903 .37073 .65394 .37988 .65142 .37429 .64652 Mtetra
.647 .752 .925 r
.37429 .64652 .37988 .65142 .38906 .64889 .38349 .64399 Mtetra
.648 .753 .926 r
.38349 .64399 .38906 .64889 .39827 .64633 .39273 .64145 Mtetra
.65 .755 .926 r
.39273 .64145 .39827 .64633 .40752 .64372 .40199 .63885 Mtetra
.652 .757 .926 r
.40199 .63885 .40752 .64372 .4168 .64104 .41129 .63619 Mtetra
.657 .759 .925 r
.41129 .63619 .4168 .64104 .42611 .63824 .42063 .6334 Mtetra
.664 .762 .923 r
.42063 .6334 .42611 .63824 .43547 .6353 .43 .63045 Mtetra
.673 .765 .919 r
.43 .63045 .43547 .6353 .44485 .63214 .43941 .62726 Mtetra
.685 .767 .914 r
.43941 .62726 .44485 .63214 .45428 .62871 .44886 .62376 Mtetra
.698 .768 .906 r
.44886 .62376 .45428 .62871 .46374 .62496 .45834 .6199 Mtetra
.711 .767 .896 r
.45834 .6199 .46374 .62496 .47323 .62083 .46786 .61562 Mtetra
.722 .764 .886 r
.46786 .61562 .47323 .62083 .48275 .61633 .47741 .61094 Mtetra
.732 .76 .876 r
.47741 .61094 .48275 .61633 .4923 .61147 .48698 .60588 Mtetra
.736 .755 .868 r
.48698 .60588 .4923 .61147 .50187 .60634 .49658 .60059 Mtetra
.737 .751 .864 r
.49658 .60059 .50187 .60634 .51146 .60103 .5062 .59523 Mtetra
.731 .749 .867 r
.5062 .59523 .51146 .60103 .52108 .59578 .51583 .59008 Mtetra
.719 .75 .877 r
.51583 .59008 .52108 .59578 .53071 .59078 .52549 .58538 Mtetra
.697 .756 .897 r
.52549 .58538 .53071 .59078 .54037 .58631 .53517 .58142 Mtetra
.66 .767 .929 r
.53517 .58142 .54037 .58631 .55006 .58262 .54489 .57843 Mtetra
.596 .778 .967 r
.54489 .57843 .55006 .58262 .55978 .57994 .55465 .57653 Mtetra
.482 .772 .995 r
.55465 .57653 .55978 .57994 .56956 .57843 .56447 .57578 Mtetra
.312 .724 .977 r
.56447 .57578 .56956 .57843 .5794 .5781 .57434 .57608 Mtetra
.118 .629 .895 r
.57434 .57608 .5794 .5781 .58931 .57884 .58429 .57726 Mtetra
0 .54 .804 r
.58429 .57726 .58931 .57884 .59929 .58025 .59431 .57899 Mtetra
0 .507 .756 r
.59431 .57899 .59929 .58025 .60934 .58182 .60439 .58077 Mtetra
.027 .589 .802 r
.60439 .58077 .60934 .58182 .61943 .58254 .61451 .58165 Mtetra
.224 .734 .887 r
.61451 .58165 .61943 .58254 .62952 .58176 .62464 .58096 Mtetra
.49 .886 .954 r
.62464 .58096 .62952 .58176 .6396 .57882 .63476 .57801 Mtetra
.682 .954 .951 r
.63476 .57801 .6396 .57882 .64963 .57371 .64482 .57277 Mtetra
.772 .965 .927 r
.64482 .57277 .64963 .57371 .65962 .56709 .65486 .56597 Mtetra
.811 .959 .909 r
.65486 .56597 .65962 .56709 .66959 .5596 .66486 .55823 Mtetra
.812 .952 .91 r
.66486 .55823 .66959 .5596 .67958 .55225 .67488 .55053 Mtetra
.797 .94 .921 r
.67488 .55053 .67958 .55225 .68961 .54556 .68493 .54337 Mtetra
.77 .921 .937 r
.68493 .54337 .68961 .54556 .69971 .53995 .69504 .53708 Mtetra
.733 .888 .951 r
.69504 .53708 .69971 .53995 .7099 .53552 .70522 .53184 Mtetra
.689 .842 .957 r
.70522 .53184 .7099 .53552 .72019 .53227 .71549 .52776 Mtetra
.646 .793 .953 r
.71549 .52776 .72019 .53227 .73057 .53005 .72586 .52479 Mtetra
.606 .747 .944 r
.72586 .52479 .73057 .53005 .74105 .52862 .73634 .52281 Mtetra
.576 .713 .936 r
.73634 .52281 .74105 .52862 .75162 .52774 .74691 .52158 Mtetra
.557 .692 .929 r
.74691 .52158 .75162 .52774 .76226 .52713 .75756 .52082 Mtetra
.548 .683 .927 r
.75756 .52082 .76226 .52713 .77296 .52658 .76828 .52029 Mtetra
.551 .685 .928 r
.76828 .52029 .77296 .52658 .7837 .52585 .77905 .51968 Mtetra
.559 .694 .93 r
.77905 .51968 .7837 .52585 .79447 .52487 .78987 .51886 Mtetra
.575 .708 .933 r
.78987 .51886 .79447 .52487 .80527 .52351 .8007 .51764 Mtetra
.592 .722 .934 r
.8007 .51764 .80527 .52351 .81609 .52177 .81156 .51603 Mtetra
.609 .735 .935 r
.81156 .51603 .81609 .52177 .82692 .51964 .82243 .51398 Mtetra
.624 .745 .934 r
.82243 .51398 .82692 .51964 .83777 .51719 .83331 .51155 Mtetra
.637 .752 .932 r
.83331 .51155 .83777 .51719 .84863 .51446 .84421 .50881 Mtetra
.647 .757 .93 r
.84421 .50881 .84863 .51446 .85952 .5115 .85512 .50582 Mtetra
.653 .759 .927 r
.85512 .50582 .85952 .5115 .87044 .50838 .86607 .50266 Mtetra
.658 .76 .925 r
.86607 .50266 .87044 .50838 .88138 .50514 .87704 .49936 Mtetra
.66 .759 .923 r
.87704 .49936 .88138 .50514 .89236 .50183 .88805 .49599 Mtetra
.662 .759 .922 r
.88805 .49599 .89236 .50183 .90338 .49846 .89909 .49257 Mtetra
.662 .758 .921 r
.89909 .49257 .90338 .49846 .91443 .49506 .91017 .48912 Mtetra
.663 .757 .92 r
.91017 .48912 .91443 .49506 .92553 .49164 .92129 .48565 Mtetra
.663 .756 .919 r
.92129 .48565 .92553 .49164 .93666 .48821 .93245 .48217 Mtetra
.663 .755 .919 r
.93245 .48217 .93666 .48821 .94784 .48476 .94366 .47868 Mtetra
.648 .749 .924 r
.34122 .64908 .34689 .65403 .356 .65153 .35034 .64657 Mtetra
.647 .749 .924 r
.35034 .64657 .356 .65153 .36513 .64903 .3595 .64406 Mtetra
.647 .75 .924 r
.3595 .64406 .36513 .64903 .37429 .64652 .36868 .64155 Mtetra
.647 .75 .925 r
.36868 .64155 .37429 .64652 .38349 .64399 .3779 .63903 Mtetra
.646 .751 .926 r
.3779 .63903 .38349 .64399 .39273 .64145 .38715 .6365 Mtetra
.648 .753 .926 r
.38715 .6365 .39273 .64145 .40199 .63885 .39643 .63393 Mtetra
.65 .755 .926 r
.39643 .63393 .40199 .63885 .41129 .63619 .40575 .6313 Mtetra
.655 .758 .926 r
.40575 .6313 .41129 .63619 .42063 .6334 .41511 .62855 Mtetra
.661 .762 .925 r
.41511 .62855 .42063 .6334 .43 .63045 .4245 .62564 Mtetra
.672 .767 .922 r
.4245 .62564 .43 .63045 .43941 .62726 .43393 .62246 Mtetra
.685 .771 .917 r
.43393 .62246 .43941 .62726 .44886 .62376 .4434 .61895 Mtetra
.7 .774 .91 r
.4434 .61895 .44886 .62376 .45834 .6199 .45291 .61502 Mtetra
.716 .776 .9 r
.45291 .61502 .45834 .6199 .46786 .61562 .46245 .61061 Mtetra
.728 .774 .889 r
.46245 .61061 .46786 .61562 .47741 .61094 .47203 .60576 Mtetra
.739 .77 .878 r
.47203 .60576 .47741 .61094 .48698 .60588 .48163 .60049 Mtetra
.742 .764 .871 r
.48163 .60049 .48698 .60588 .49658 .60059 .49125 .59504 Mtetra
.74 .759 .868 r
.49125 .59504 .49658 .60059 .5062 .59523 .5009 .5896 Mtetra
.728 .755 .874 r
.5009 .5896 .5062 .59523 .51583 .59008 .51056 .58456 Mtetra
.708 .755 .889 r
.51056 .58456 .51583 .59008 .52549 .58538 .52024 .58026 Mtetra
.673 .762 .918 r
.52024 .58026 .52549 .58538 .53517 .58142 .52995 .57697 Mtetra
.609 .771 .958 r
.52995 .57697 .53517 .58142 .54489 .57843 .53969 .57491 Mtetra
.499 .775 .994 r
.53969 .57491 .54489 .57843 .55465 .57653 .54949 .57402 Mtetra
.309 .729 .974 r
.54949 .57402 .55465 .57653 .56447 .57578 .55934 .57421 Mtetra
.091 .624 .864 r
.55934 .57421 .56447 .57578 .57434 .57608 .56926 .57513 Mtetra
0 .518 .74 r
.56926 .57513 .57434 .57608 .58429 .57726 .57924 .57652 Mtetra
.128 0 0 r
.57924 .57652 .58429 .57726 .59431 .57899 .58928 .57818 Mtetra
0 .49 .708 r
.58928 .57818 .59431 .57899 .60439 .58077 .59939 .57971 Mtetra
.063 .616 .822 r
.59939 .57971 .60439 .58077 .61451 .58165 .60954 .58034 Mtetra
.293 .767 .934 r
.60954 .58034 .61451 .58165 .62464 .58096 .6197 .57953 Mtetra
.544 .89 .982 r
.6197 .57953 .62464 .58096 .63476 .57801 .62985 .57656 Mtetra
.702 .938 .962 r
.62985 .57656 .63476 .57801 .64482 .57277 .63996 .57142 Mtetra
.771 .951 .934 r
.63996 .57142 .64482 .57277 .65486 .56597 .65005 .56482 Mtetra
.802 .959 .914 r
.65005 .56482 .65486 .56597 .66486 .55823 .66011 .55731 Mtetra
.802 .968 .91 r
.66011 .55731 .66486 .55823 .67488 .55053 .67017 .54965 Mtetra
.79 .97 .914 r
.67017 .54965 .67488 .55053 .68493 .54337 .68026 .54225 Mtetra
.776 .963 .926 r
.68026 .54225 .68493 .54337 .69504 .53708 .69038 .53529 Mtetra
.759 .939 .943 r
.69038 .53529 .69504 .53708 .70522 .53184 .70055 .52907 Mtetra
.725 .893 .956 r
.70055 .52907 .70522 .53184 .71549 .52776 .7108 .52394 Mtetra
.683 .836 .957 r
.7108 .52394 .71549 .52776 .72586 .52479 .72115 .51998 Mtetra
.634 .778 .95 r
.72115 .51998 .72586 .52479 .73634 .52281 .73161 .51728 Mtetra
.592 .732 .941 r
.73161 .51728 .73634 .52281 .74691 .52158 .74217 .51561 Mtetra
.561 .702 .935 r
.74217 .51561 .74691 .52158 .75756 .52082 .75284 .51469 Mtetra
.542 .688 .934 r
.75284 .51469 .75756 .52082 .76828 .52029 .76359 .51419 Mtetra
.54 .689 .936 r
.76359 .51419 .76828 .52029 .77905 .51968 .7744 .51372 Mtetra
.546 .697 .939 r
.7744 .51372 .77905 .51968 .78987 .51886 .78525 .51306 Mtetra
.564 .713 .942 r
.78525 .51306 .78987 .51886 .8007 .51764 .79613 .51199 Mtetra
.583 .728 .943 r
.79613 .51199 .8007 .51764 .81156 .51603 .80702 .51046 Mtetra
.605 .742 .942 r
.80702 .51046 .81156 .51603 .82243 .51398 .81792 .50844 Mtetra
.623 .752 .939 r
.81792 .50844 .82243 .51398 .83331 .51155 .82883 .50599 Mtetra
.638 .757 .935 r
.82883 .50599 .83331 .51155 .84421 .50881 .83975 .50319 Mtetra
.648 .76 .931 r
.83975 .50319 .84421 .50881 .85512 .50582 .85069 .50013 Mtetra
.655 .761 .927 r
.85069 .50013 .85512 .50582 .86607 .50266 .86166 .49688 Mtetra
.66 .76 .924 r
.86166 .49688 .86607 .50266 .87704 .49936 .87266 .49351 Mtetra
.662 .759 .922 r
.87266 .49351 .87704 .49936 .88805 .49599 .88369 .49008 Mtetra
.663 .758 .921 r
.88369 .49008 .88805 .49599 .89909 .49257 .89476 .48659 Mtetra
.663 .757 .92 r
.89476 .48659 .89909 .49257 .91017 .48912 .90587 .4831 Mtetra
.663 .756 .919 r
.90587 .4831 .91017 .48912 .92129 .48565 .91702 .47959 Mtetra
.663 .755 .918 r
.91702 .47959 .92129 .48565 .93245 .48217 .92822 .47607 Mtetra
.92822 .47607 .93245 .48217 .94366 .47868 .93945 .47256 Mtetra
.648 .749 .923 r
.33552 .6441 .34122 .64908 .35034 .64657 .34466 .64156 Mtetra
.647 .749 .923 r
.34466 .64156 .35034 .64657 .3595 .64406 .35383 .63903 Mtetra
.647 .748 .923 r
.35383 .63903 .3595 .64406 .36868 .64155 .36303 .6365 Mtetra
.646 .748 .924 r
.36303 .6365 .36868 .64155 .3779 .63903 .37227 .63397 Mtetra
.646 .749 .924 r
.37227 .63397 .3779 .63903 .38715 .6365 .38154 .63145 Mtetra
.646 .75 .925 r
.38154 .63145 .38715 .6365 .39643 .63393 .39084 .62891 Mtetra
.647 .752 .925 r
.39084 .62891 .39643 .63393 .40575 .6313 .40018 .62632 Mtetra
.651 .755 .925 r
.40018 .62632 .40575 .6313 .41511 .62855 .40955 .62363 Mtetra
.657 .76 .925 r
.40955 .62363 .41511 .62855 .4245 .62564 .41896 .62079 Mtetra
.668 .766 .924 r
.41896 .62079 .4245 .62564 .43393 .62246 .42841 .61769 Mtetra
.682 .773 .92 r
.42841 .61769 .43393 .62246 .4434 .61895 .4379 .61424 Mtetra
.699 .78 .914 r
.4379 .61424 .4434 .61895 .45291 .61502 .44744 .61033 Mtetra
.718 .784 .905 r
.44744 .61033 .45291 .61502 .46245 .61061 .457 .60586 Mtetra
.733 .785 .894 r
.457 .60586 .46245 .61061 .47203 .60576 .46661 .60088 Mtetra
.746 .783 .883 r
.46661 .60088 .47203 .60576 .48163 .60049 .47624 .59541 Mtetra
.749 .778 .876 r
.47624 .59541 .48163 .60049 .49125 .59504 .48589 .58976 Mtetra
.746 .771 .874 r
.48589 .58976 .49125 .59504 .5009 .5896 .49556 .58418 Mtetra
.728 .764 .881 r
.49556 .58418 .5009 .5896 .51056 .58456 .50525 .5792 Mtetra
.696 .759 .901 r
.50525 .5792 .51056 .58456 .52024 .58026 .51495 .57527 Mtetra
.64 .759 .935 r
.51495 .57527 .52024 .58026 .52995 .57697 .52468 .57271 Mtetra
.533 .754 .977 r
.52468 .57271 .52995 .57697 .53969 .57491 .53446 .57174 Mtetra
.353 .724 .987 r
.53446 .57174 .53969 .57491 .54949 .57402 .54429 .57206 Mtetra
.084 .608 .876 r
.54429 .57206 .54949 .57402 .55934 .57421 .55418 .57338 Mtetra
0 .488 .706 r
.55418 .57338 .55934 .57421 .56926 .57513 .56413 .5749 Mtetra
.142 0 0 r
.56413 .5749 .56926 .57513 .57924 .57652 .57414 .57615 Mtetra
.085 0 0 r
.57414 .57615 .57924 .57652 .58928 .57818 .58421 .57713 Mtetra
.079 .629 .829 r
.58421 .57713 .58928 .57818 .59939 .57971 .59432 .57762 Mtetra
.314 .752 .967 r
.59432 .57762 .59939 .57971 .60954 .58034 .60448 .57735 Mtetra
.499 .805 1 r
.60448 .57735 .60954 .58034 .6197 .57953 .61466 .57601 Mtetra
.634 .831 .976 r
.61466 .57601 .6197 .57953 .62985 .57656 .62484 .57302 Mtetra
.714 .851 .947 r
.62484 .57302 .62985 .57656 .63996 .57142 .635 .56838 Mtetra
.753 .88 .936 r
.635 .56838 .63996 .57142 .65005 .56482 .64516 .56265 Mtetra
.776 .92 .933 r
.64516 .56265 .65005 .56482 .66011 .55731 .6553 .55615 Mtetra
.78 .96 .925 r
.6553 .55615 .66011 .55731 .67017 .54965 .66544 .54914 Mtetra
.773 .98 .911 r
.66544 .54914 .67017 .54965 .68026 .54225 .67558 .54184 Mtetra
.78 .984 .903 r
.67558 .54184 .68026 .54225 .69038 .53529 .68572 .53426 Mtetra
.79 .968 .916 r
.68572 .53426 .69038 .53529 .70055 .52907 .69588 .52686 Mtetra
.77 .925 .938 r
.69588 .52686 .70055 .52907 .7108 .52394 .7061 .52046 Mtetra
.728 .864 .945 r
.7061 .52046 .7108 .52394 .72115 .51998 .71642 .51536 Mtetra
.667 .799 .945 r
.71642 .51536 .72115 .51998 .73161 .51728 .72686 .51187 Mtetra
.609 .746 .942 r
.72686 .51187 .73161 .51728 .74217 .51561 .73742 .50979 Mtetra
.562 .71 .94 r
.73742 .50979 .74217 .51561 .75284 .51469 .74811 .50876 Mtetra
.53 .692 .942 r
.74811 .50876 .75284 .51469 .76359 .51419 .75889 .50838 Mtetra
.523 .694 .946 r
.75889 .50838 .76359 .51419 .7744 .51372 .76974 .50807 Mtetra
.529 .704 .951 r
.76974 .50807 .7744 .51372 .78525 .51306 .78063 .50758 Mtetra
.552 .722 .953 r
.78063 .50758 .78525 .51306 .79613 .51199 .79154 .50659 Mtetra
.576 .737 .952 r
.79154 .50659 .79613 .51199 .80702 .51046 .80246 .50508 Mtetra
.604 .751 .948 r
.80246 .50508 .80702 .51046 .81792 .50844 .81339 .50301 Mtetra
.625 .758 .942 r
.81339 .50301 .81792 .50844 .82883 .50599 .82432 .50046 Mtetra
.641 .761 .935 r
.82432 .50046 .82883 .50599 .83975 .50319 .83527 .49754 Mtetra
.652 .762 .93 r
.83527 .49754 .83975 .50319 .85069 .50013 .84623 .49435 Mtetra
.658 .76 .925 r
.84623 .49435 .85069 .50013 .86166 .49688 .85722 .491 Mtetra
.662 .759 .922 r
.85722 .491 .86166 .49688 .87266 .49351 .86824 .48755 Mtetra
.664 .757 .92 r
.86824 .48755 .87266 .49351 .88369 .49008 .8793 .48404 Mtetra
.664 .756 .918 r
.8793 .48404 .88369 .49008 .89476 .48659 .8904 .48051 Mtetra
.664 .755 .918 r
.8904 .48051 .89476 .48659 .90587 .4831 .90154 .47698 Mtetra
.664 .754 .917 r
.90154 .47698 .90587 .4831 .91702 .47959 .91272 .47345 Mtetra
.663 .754 .918 r
.91272 .47345 .91702 .47959 .92822 .47607 .92394 .46992 Mtetra
.662 .754 .918 r
.92394 .46992 .92822 .47607 .93945 .47256 .93521 .46639 Mtetra
.649 .75 .923 r
.32977 .63908 .33552 .6441 .34466 .64156 .33893 .6365 Mtetra
.649 .748 .922 r
.33893 .6365 .34466 .64156 .35383 .63903 .34813 .63392 Mtetra
.648 .747 .922 r
.34813 .63392 .35383 .63903 .36303 .6365 .35735 .63135 Mtetra
.647 .746 .922 r
.35735 .63135 .36303 .6365 .37227 .63397 .36661 .6288 Mtetra
.646 .745 .922 r
.36661 .6288 .37227 .63397 .38154 .63145 .37589 .62627 Mtetra
.645 .745 .922 r
.37589 .62627 .38154 .63145 .39084 .62891 .38521 .62373 Mtetra
.645 .747 .923 r
.38521 .62373 .39084 .62891 .40018 .62632 .39457 .62119 Mtetra
.647 .75 .924 r
.39457 .62119 .40018 .62632 .40955 .62363 .40396 .61859 Mtetra
.651 .755 .925 r
.40396 .61859 .40955 .62363 .41896 .62079 .41339 .61587 Mtetra
.661 .763 .925 r
.41339 .61587 .41896 .62079 .42841 .61769 .42286 .61292 Mtetra
.675 .772 .924 r
.42286 .61292 .42841 .61769 .4379 .61424 .43237 .60962 Mtetra
.693 .783 .92 r
.43237 .60962 .4379 .61424 .44744 .61033 .44192 .60584 Mtetra
.716 .793 .912 r
.44192 .60584 .44744 .61033 .457 .60586 .45151 .60142 Mtetra
.736 .799 .902 r
.45151 .60142 .457 .60586 .46661 .60088 .46114 .59639 Mtetra
.753 .8 .89 r
.46114 .59639 .46661 .60088 .47624 .59541 .4708 .59075 Mtetra
.759 .795 .882 r
.4708 .59075 .47624 .59541 .48589 .58976 .48049 .58486 Mtetra
.755 .786 .879 r
.48049 .58486 .48589 .58976 .49556 .58418 .49019 .57901 Mtetra
.731 .774 .887 r
.49019 .57901 .49556 .58418 .50525 .5792 .4999 .57396 Mtetra
.686 .762 .909 r
.4999 .57396 .50525 .5792 .51495 .57527 .50963 .57029 Mtetra
.603 .748 .947 r
.50963 .57029 .51495 .57527 .52468 .57271 .51938 .56844 Mtetra
.434 .712 .982 r
.51938 .56844 .52468 .57271 .53446 .57174 .52918 .56868 Mtetra
.165 .619 .935 r
.52918 .56868 .53446 .57174 .54429 .57206 .53904 .5704 Mtetra
0 .433 .721 r
.53904 .5704 .54429 .57206 .55418 .57338 .54897 .57306 Mtetra
.234 0 0 r
.54897 .57306 .55418 .57338 .56413 .5749 .55896 .5751 Mtetra
.119 0 0 r
.55896 .5751 .56413 .5749 .57414 .57615 .56899 .57577 Mtetra
.128 .674 .809 r
.56899 .57577 .57414 .57615 .58421 .57713 .57907 .57526 Mtetra
.446 .83 .987 r
.57907 .57526 .58421 .57713 .59432 .57762 .58918 .57365 Mtetra
.591 .796 .978 r
.58918 .57365 .59432 .57762 .60448 .57735 .59932 .57156 Mtetra
.632 .734 .922 r
.59932 .57156 .60448 .57735 .61466 .57601 .60949 .56915 Mtetra
.656 .707 .885 r
.60949 .56915 .61466 .57601 .62484 .57302 .6197 .56614 Mtetra
.675 .714 .878 r
.6197 .56614 .62484 .57302 .635 .56838 .62991 .56253 Mtetra
.688 .753 .901 r
.62991 .56253 .635 .56838 .64516 .56265 .64016 .55859 Mtetra
.706 .829 .941 r
.64016 .55859 .64516 .56265 .6553 .55615 .65041 .55416 Mtetra
.731 .925 .956 r
.65041 .55416 .6553 .55615 .66544 .54914 .66066 .54862 Mtetra
.744 .977 .921 r
.66066 .54862 .66544 .54914 .67558 .54184 .67087 .54188 Mtetra
.786 .992 .881 r
.67087 .54188 .67558 .54184 .68572 .53426 .68103 .53374 Mtetra
.827 .981 .882 r
.68103 .53374 .68572 .53426 .69588 .52686 .69117 .52495 Mtetra
.816 .938 .908 r
.69117 .52495 .69588 .52686 .7061 .52046 .70136 .51709 Mtetra
.772 .877 .923 r
.70136 .51709 .7061 .52046 .71642 .51536 .71165 .51073 Mtetra
.697 .809 .934 r
.71165 .51073 .71642 .51536 .72686 .51187 .72207 .50647 Mtetra
.622 .753 .94 r
.72207 .50647 .72686 .51187 .73742 .50979 .73265 .50408 Mtetra
.557 .714 .945 r
.73265 .50408 .73742 .50979 .74811 .50876 .74336 .50309 Mtetra
.509 .694 .952 r
.74336 .50309 .74811 .50876 .75889 .50838 .75419 .50294 Mtetra
.499 .699 .959 r
.75419 .50294 .75889 .50838 .76974 .50807 .76508 .50284 Mtetra
.507 .713 .964 r
.76508 .50284 .76974 .50807 .78063 .50758 .77601 .50248 Mtetra
.54 .735 .965 r
.77601 .50248 .78063 .50758 .79154 .50659 .78695 .50151 Mtetra
.574 .751 .961 r
.78695 .50151 .79154 .50659 .80246 .50508 .79789 .49991 Mtetra
.608 .762 .953 r
.79789 .49991 .80246 .50508 .81339 .50301 .80884 .49766 Mtetra
.632 .766 .944 r
.80884 .49766 .81339 .50301 .82432 .50046 .81979 .49491 Mtetra
.648 .765 .934 r
.81979 .49491 .82432 .50046 .83527 .49754 .83075 .4918 Mtetra
.658 .762 .927 r
.83075 .4918 .83527 .49754 .84623 .49435 .84173 .48844 Mtetra
.663 .758 .921 r
.84173 .48844 .84623 .49435 .85722 .491 .85274 .48497 Mtetra
.665 .756 .918 r
.85274 .48497 .85722 .491 .86824 .48755 .86378 .48142 Mtetra
.665 .753 .916 r
.86378 .48142 .86824 .48755 .8793 .48404 .87487 .47786 Mtetra
.665 .752 .915 r
.87487 .47786 .8793 .48404 .8904 .48051 .88599 .4743 Mtetra
.664 .751 .915 r
.88599 .4743 .8904 .48051 .90154 .47698 .89717 .47076 Mtetra
.663 .751 .916 r
.89717 .47076 .90154 .47698 .91272 .47345 .90838 .46722 Mtetra
.662 .752 .917 r
.90838 .46722 .91272 .47345 .92394 .46992 .91964 .4637 Mtetra
.661 .753 .918 r
.91964 .4637 .92394 .46992 .93521 .46639 .93095 .46018 Mtetra
.652 .75 .922 r
.32399 .63404 .32977 .63908 .33893 .6365 .33318 .63139 Mtetra
.651 .748 .921 r
.33318 .63139 .33893 .6365 .34813 .63392 .34239 .62875 Mtetra
.65 .746 .92 r
.34239 .62875 .34813 .63392 .35735 .63135 .35163 .62612 Mtetra
.649 .744 .919 r
.35163 .62612 .35735 .63135 .36661 .6288 .36091 .62352 Mtetra
.647 .743 .919 r
.36091 .62352 .36661 .6288 .37589 .62627 .37022 .62094 Mtetra
.646 .741 .919 r
.37022 .62094 .37589 .62627 .38521 .62373 .37956 .6184 Mtetra
.644 .741 .92 r
.37956 .6184 .38521 .62373 .39457 .62119 .38893 .61588 Mtetra
.644 .743 .921 r
.38893 .61588 .39457 .62119 .40396 .61859 .39834 .61334 Mtetra
.645 .746 .923 r
.39834 .61334 .40396 .61859 .41339 .61587 .40778 .61076 Mtetra
.652 .754 .924 r
.40778 .61076 .41339 .61587 .42286 .61292 .41727 .60799 Mtetra
.664 .765 .925 r
.41727 .60799 .42286 .61292 .43237 .60962 .42679 .60494 Mtetra
.683 .78 .924 r
.42679 .60494 .43237 .60962 .44192 .60584 .43636 .6014 Mtetra
.708 .795 .919 r
.43636 .6014 .44192 .60584 .45151 .60142 .44598 .59719 Mtetra
.733 .808 .911 r
.44598 .59719 .45151 .60142 .46114 .59639 .45563 .59227 Mtetra
.757 .815 .899 r
.45563 .59227 .46114 .59639 .4708 .59075 .46532 .58657 Mtetra
.768 .815 .89 r
.46532 .58657 .4708 .59075 .48049 .58486 .47504 .58045 Mtetra
.769 .807 .884 r
.47504 .58045 .48049 .58486 .49019 .57901 .48477 .57423 Mtetra
.742 .791 .893 r
.48477 .57423 .49019 .57901 .4999 .57396 .49452 .5689 Mtetra
.686 .771 .916 r
.49452 .5689 .4999 .57396 .50963 .57029 .50427 .56521 Mtetra
.576 .737 .952 r
.50427 .56521 .50963 .57029 .51938 .56844 .51404 .56385 Mtetra
.348 .656 .97 r
.51404 .56385 .51938 .56844 .52918 .56868 .52386 .56517 Mtetra
.015 .5 .872 r
.52386 .56517 .52918 .56868 .53904 .5704 .53374 .56838 Mtetra
.302 0 0 r
.53374 .56838 .53904 .5704 .54897 .57306 .54371 .5726 Mtetra
.284 0 0 r
.54371 .5726 .54897 .57306 .55896 .5751 .55373 .5752 Mtetra
.027 .599 .715 r
.55373 .5752 .55896 .5751 .56899 .57577 .56379 .57491 Mtetra
.488 .883 .958 r
.56379 .57491 .56899 .57577 .57907 .57526 .57387 .57205 Mtetra
.726 .865 .947 r
.57387 .57205 .57907 .57526 .58918 .57365 .58395 .56711 Mtetra
.718 .737 .866 r
.58395 .56711 .58918 .57365 .59932 .57156 .59405 .56208 Mtetra
.678 .651 .816 r
.59405 .56208 .59932 .57156 .60949 .56915 .6042 .55787 Mtetra
.643 .603 .795 r
.6042 .55787 .60949 .56915 .6197 .56614 .6144 .55484 Mtetra
.614 .589 .802 r
.6144 .55484 .6197 .56614 .62991 .56253 .62469 .55297 Mtetra
.59 .611 .841 r
.62469 .55297 .62991 .56253 .64016 .55859 .63504 .55194 Mtetra
.577 .686 .915 r
.63504 .55194 .64016 .55859 .65041 .55416 .64544 .55083 Mtetra
.635 .846 .981 r
.64544 .55083 .65041 .55416 .66066 .54862 .65581 .54762 Mtetra
.711 .959 .946 r
.65581 .54762 .66066 .54862 .67087 .54188 .66611 .54182 Mtetra
.813 .991 .875 r
.66611 .54182 .67087 .54188 .68103 .53374 .6763 .53308 Mtetra
.873 .969 .852 r
.6763 .53308 .68103 .53374 .69117 .52495 .68641 .52267 Mtetra
.855 .919 .874 r
.68641 .52267 .69117 .52495 .70136 .51709 .69657 .51327 Mtetra
.802 .861 .893 r
.69657 .51327 .70136 .51709 .71165 .51073 .70683 .50576 Mtetra
.716 .801 .918 r
.70683 .50576 .71165 .51073 .72207 .50647 .71725 .50098 Mtetra
.623 .751 .938 r
.71725 .50098 .72207 .50647 .73265 .50408 .72786 .49856 Mtetra
.538 .714 .954 r
.72786 .49856 .73265 .50408 .74336 .50309 .73861 .49782 Mtetra
.474 .695 .965 r
.73861 .49782 .74336 .50309 .75419 .50294 .74949 .498 Mtetra
.467 .707 .973 r
.74949 .498 .75419 .50294 .76508 .50284 .76042 .49809 Mtetra
.487 .727 .977 r
.76042 .49809 .76508 .50284 .77601 .50248 .77138 .49776 Mtetra
.537 .752 .975 r
.77138 .49776 .77601 .50248 .78695 .50151 .78234 .49664 Mtetra
.581 .766 .966 r
.78234 .49664 .78695 .50151 .79789 .49991 .7933 .49479 Mtetra
.619 .771 .953 r
.7933 .49479 .79789 .49991 .80884 .49766 .80425 .49224 Mtetra
.644 .77 .939 r
.80425 .49224 .80884 .49766 .81979 .49491 .81521 .4892 Mtetra
.657 .764 .928 r
.81521 .4892 .81979 .49491 .83075 .4918 .82618 .48585 Mtetra
.665 .759 .92 r
.82618 .48585 .83075 .4918 .84173 .48844 .83717 .48231 Mtetra
.666 .753 .915 r
.83717 .48231 .84173 .48844 .85274 .48497 .8482 .47872 Mtetra
.667 .75 .913 r
.8482 .47872 .85274 .48497 .86378 .48142 .85927 .47511 Mtetra
.665 .748 .912 r
.85927 .47511 .86378 .48142 .87487 .47786 .87039 .47153 Mtetra
.664 .748 .912 r
.87039 .47153 .87487 .47786 .88599 .4743 .88155 .46796 Mtetra
.663 .748 .913 r
.88155 .46796 .88599 .4743 .89717 .47076 .89276 .46443 Mtetra
.661 .749 .915 r
.89276 .46443 .89717 .47076 .90838 .46722 .90401 .46092 Mtetra
.66 .75 .916 r
.90401 .46092 .90838 .46722 .91964 .4637 .91531 .45742 Mtetra
.66 .751 .918 r
.91531 .45742 .91964 .4637 .93095 .46018 .92665 .45393 Mtetra
.654 .751 .921 r
.31818 .62896 .32399 .63404 .33318 .63139 .32738 .62624 Mtetra
.654 .749 .92 r
.32738 .62624 .33318 .63139 .34239 .62875 .33662 .62352 Mtetra
.653 .746 .918 r
.33662 .62352 .34239 .62875 .35163 .62612 .34589 .62081 Mtetra
.652 .743 .917 r
.34589 .62081 .35163 .62612 .36091 .62352 .35518 .61812 Mtetra
.65 .741 .916 r
.35518 .61812 .36091 .62352 .37022 .62094 .36451 .61547 Mtetra
.648 .738 .915 r
.36451 .61547 .37022 .62094 .37956 .6184 .37387 .61287 Mtetra
.645 .736 .915 r
.37387 .61287 .37956 .6184 .38893 .61588 .38327 .61032 Mtetra
.643 .735 .916 r
.38327 .61032 .38893 .61588 .39834 .61334 .39269 .60781 Mtetra
.64 .736 .918 r
.39269 .60781 .39834 .61334 .40778 .61076 .40215 .60535 Mtetra
.643 .742 .921 r
.40215 .60535 .40778 .61076 .41727 .60799 .41164 .6028 Mtetra
.65 .752 .925 r
.41164 .6028 .41727 .60799 .42679 .60494 .42118 .60007 Mtetra
.667 .77 .927 r
.42118 .60007 .42679 .60494 .43636 .6014 .43076 .59691 Mtetra
.692 .792 .926 r
.43076 .59691 .43636 .6014 .44598 .59719 .44039 .59311 Mtetra
.722 .814 .922 r
.44039 .59311 .44598 .59719 .45563 .59227 .45007 .58849 Mtetra
.755 .831 .91 r
.45007 .58849 .45563 .59227 .46532 .58657 .45979 .58292 Mtetra
.775 .837 .9 r
.45979 .58292 .46532 .58657 .47504 .58045 .46954 .57665 Mtetra
.785 .832 .889 r
.46954 .57665 .47504 .58045 .48477 .57423 .47931 .56996 Mtetra
.76 .814 .895 r
.47931 .56996 .48477 .57423 .49452 .5689 .48909 .56409 Mtetra
.702 .785 .916 r
.48909 .56409 .49452 .5689 .50427 .56521 .49887 .55996 Mtetra
.574 .73 .948 r
.49887 .55996 .50427 .56521 .51404 .56385 .50867 .55867 Mtetra
.306 .608 .953 r
.50867 .55867 .51404 .56385 .52386 .56517 .5185 .56078 Mtetra
0 .403 .831 r
.5185 .56078 .52386 .56517 .53374 .56838 .5284 .56543 Mtetra
.395 0 0 r
.5284 .56543 .53374 .56838 .54371 .5726 .53839 .57146 Mtetra
.283 0 0 r
.53839 .57146 .54371 .5726 .55373 .5752 .54845 .5747 Mtetra
.288 .781 .887 r
.54845 .5747 .55373 .5752 .56379 .57491 .55853 .57315 Mtetra
.76 .929 .943 r
.55853 .57315 .56379 .57491 .57387 .57205 .5686 .56705 Mtetra
.828 .802 .827 r
.5686 .56705 .57387 .57205 .58395 .56711 .57864 .55735 Mtetra
.765 .68 .769 r
.57864 .55735 .58395 .56711 .59405 .56208 .58867 .54809 Mtetra
.696 .596 .74 r
.58867 .54809 .59405 .56208 .6042 .55787 .59876 .54126 Mtetra
.626 .534 .731 r
.59876 .54126 .6042 .55787 .6144 .55484 .60896 .5382 Mtetra
.555 .492 .74 r
.60896 .5382 .6144 .55484 .62469 .55297 .61931 .5389 Mtetra
.481 .476 .775 r
.61931 .5389 .62469 .55297 .63504 .55194 .62979 .54206 Mtetra
.402 .505 .849 r
.62979 .54206 .63504 .55194 .64544 .55083 .64036 .54568 Mtetra
.479 .703 .967 r
.64036 .54568 .64544 .55083 .65581 .54762 .65088 .54571 Mtetra
.672 .919 .975 r
.65088 .54571 .65581 .54762 .66611 .54182 .66127 .54114 Mtetra
.847 .974 .873 r
.66127 .54114 .66611 .54182 .6763 .53308 .67148 .53172 Mtetra
.906 .934 .82 r
.67148 .53172 .6763 .53308 .68641 .52267 .68156 .51945 Mtetra
.873 .878 .837 r
.68156 .51945 .68641 .52267 .69657 .51327 .69169 .50854 Mtetra
.812 .828 .863 r
.69169 .50854 .69657 .51327 .70683 .50576 .70194 .5002 Mtetra
.717 .78 .902 r
.70194 .5002 .70683 .50576 .71725 .50098 .71239 .4953 Mtetra
.605 .738 .939 r
.71239 .4953 .71725 .50098 .72786 .49856 .72305 .49328 Mtetra
.498 .708 .964 r
.72305 .49328 .72786 .49856 .73861 .49782 .73386 .49306 Mtetra
.418 .691 .976 r
.73386 .49306 .73861 .49782 .74949 .498 .7448 .49369 Mtetra
.427 .718 .985 r
.7448 .49369 .74949 .498 .76042 .49809 .75576 .49389 Mtetra
.474 .747 .989 r
.75576 .49389 .76042 .49809 .77138 .49776 .76675 .49339 Mtetra
.546 .774 .983 r
.76675 .49339 .77138 .49776 .78234 .49664 .77771 .49191 Mtetra
.601 .782 .967 r
.77771 .49191 .78234 .49664 .7933 .49479 .78867 .4896 Mtetra
.639 .778 .947 r
.78867 .4896 .7933 .49479 .80425 .49224 .79962 .48663 Mtetra
.66 .769 .931 r
.79962 .48663 .80425 .49224 .81521 .4892 .81057 .4832 Mtetra
.667 .758 .919 r
.81057 .4832 .81521 .4892 .82618 .48585 .82155 .47959 Mtetra
.67 .751 .911 r
.82155 .47959 .82618 .48585 .83717 .48231 .83256 .47588 Mtetra
.668 .745 .908 r
.83256 .47588 .83717 .48231 .8482 .47872 .84362 .47222 Mtetra
.666 .743 .907 r
.84362 .47222 .8482 .47872 .85927 .47511 .85472 .46859 Mtetra
.664 .742 .908 r
.85472 .46859 .85927 .47511 .87039 .47153 .86587 .46503 Mtetra
.662 .742 .91 r
.86587 .46503 .87039 .47153 .88155 .46796 .87707 .4615 Mtetra
.66 .744 .912 r
.87707 .4615 .88155 .46796 .89276 .46443 .88831 .45801 Mtetra
.659 .746 .914 r
.88831 .45801 .89276 .46443 .90401 .46092 .8996 .45454 Mtetra
.658 .748 .916 r
.8996 .45454 .90401 .46092 .91531 .45742 .91094 .45109 Mtetra
.657 .75 .918 r
.91094 .45109 .91531 .45742 .92665 .45393 .92232 .44763 Mtetra
.656 .751 .92 r
.31232 .62385 .31818 .62896 .32738 .62624 .32155 .62106 Mtetra
.656 .75 .919 r
.32155 .62106 .32738 .62624 .33662 .62352 .33081 .61826 Mtetra
.656 .747 .917 r
.33081 .61826 .33662 .62352 .34589 .62081 .3401 .61547 Mtetra
.655 .745 .916 r
.3401 .61547 .34589 .62081 .35518 .61812 .34942 .61269 Mtetra
.654 .742 .914 r
.34942 .61269 .35518 .61812 .36451 .61547 .35877 .60993 Mtetra
.651 .738 .913 r
.35877 .60993 .36451 .61547 .37387 .61287 .36816 .60722 Mtetra
.648 .734 .911 r
.36816 .60722 .37387 .61287 .38327 .61032 .37757 .60458 Mtetra
.644 .73 .911 r
.37757 .60458 .38327 .61032 .39269 .60781 .38702 .60203 Mtetra
.638 .727 .912 r
.38702 .60203 .39269 .60781 .40215 .60535 .39649 .59961 Mtetra
.637 .729 .915 r
.39649 .59961 .40215 .60535 .41164 .6028 .406 .59721 Mtetra
.637 .735 .919 r
.406 .59721 .41164 .6028 .42118 .60007 .41555 .59479 Mtetra
.649 .75 .924 r
.41555 .59479 .42118 .60007 .43076 .59691 .42514 .59206 Mtetra
.669 .773 .928 r
.42514 .59206 .43076 .59691 .44039 .59311 .43478 .58882 Mtetra
.701 .803 .929 r
.43478 .58882 .44039 .59311 .45007 .58849 .44447 .58476 Mtetra
.74 .833 .922 r
.44447 .58476 .45007 .58849 .45979 .58292 .45421 .57963 Mtetra
.774 .853 .91 r
.45421 .57963 .45979 .58292 .46954 .57665 .46399 .57347 Mtetra
.799 .858 .894 r
.46399 .57347 .46954 .57665 .47931 .56996 .47381 .5664 Mtetra
.783 .844 .898 r
.47381 .5664 .47931 .56996 .48909 .56409 .48362 .55983 Mtetra
.733 .814 .915 r
.48362 .55983 .48909 .56409 .49887 .55996 .49344 .55483 Mtetra
.603 .746 .945 r
.49344 .55483 .49887 .55996 .50867 .55867 .50326 .55294 Mtetra
.334 .601 .945 r
.50326 .55294 .50867 .55867 .5185 .56078 .51311 .55508 Mtetra
0 .367 .829 r
.51311 .55508 .5185 .56078 .5284 .56543 .52302 .56076 Mtetra
0 .122 .598 r
.52302 .56076 .5284 .56543 .53839 .57146 .53302 .56867 Mtetra
0 .358 .726 r
.53302 .56867 .53839 .57146 .54845 .5747 .54311 .57285 Mtetra
.527 .868 .992 r
.54311 .57285 .54845 .5747 .55853 .57315 .55322 .57037 Mtetra
.852 .88 .859 r
.55322 .57037 .55853 .57315 .5686 .56705 .56329 .56079 Mtetra
.867 .766 .748 r
.56329 .56079 .5686 .56705 .57864 .55735 .57327 .54553 Mtetra
.798 .665 .717 r
.57327 .54553 .57864 .55735 .58867 .54809 .58324 .53116 Mtetra
.717 .583 .704 r
.58324 .53116 .58867 .54809 .59876 .54126 .59326 .52103 Mtetra
.617 .504 .702 r
.59326 .52103 .59876 .54126 .60896 .5382 .60344 .51793 Mtetra
.496 .429 .71 r
.60344 .51793 .60896 .5382 .61931 .5389 .61384 .52187 Mtetra
.355 .365 .732 r
.61384 .52187 .61931 .5389 .62979 .54206 .62445 .53011 Mtetra
.174 .321 .773 r
.62445 .53011 .62979 .54206 .64036 .54568 .63521 .53928 Mtetra
.273 .541 .921 r
.63521 .53928 .64036 .54568 .65088 .54571 .64587 .54276 Mtetra
.647 .87 .982 r
.64587 .54276 .65088 .54571 .66127 .54114 .65634 .5391 Mtetra
.873 .922 .856 r
.65634 .5391 .66127 .54114 .67148 .53172 .66655 .52869 Mtetra
.911 .869 .785 r
.66655 .52869 .67148 .53172 .68156 .51945 .67659 .51447 Mtetra
.864 .818 .803 r
.67659 .51447 .68156 .51945 .69169 .50854 .68671 .50249 Mtetra
.797 .783 .839 r
.68671 .50249 .69169 .50854 .70194 .5002 .69699 .49407 Mtetra
.696 .756 .897 r
.69699 .49407 .70194 .5002 .71239 .4953 .7075 .48973 Mtetra
.559 .724 .951 r
.7075 .48973 .71239 .4953 .72305 .49328 .71824 .48858 Mtetra
.427 .7 .978 r
.71824 .48858 .72305 .49328 .73386 .49306 .72912 .48902 Mtetra
.342 .686 .98 r
.72912 .48902 .73386 .49306 .7448 .49369 .74011 .49 Mtetra
.399 .735 .991 r
.74011 .49 .7448 .49369 .75576 .49389 .7511 .49005 Mtetra
.49 .774 .995 r
.7511 .49005 .75576 .49389 .76675 .49339 .76208 .48906 Mtetra
.58 .792 .98 r
.76208 .48906 .76675 .49339 .77771 .49191 .77304 .48697 Mtetra
.634 .787 .955 r
.77304 .48697 .77771 .49191 .78867 .4896 .78398 .48403 Mtetra
.661 .772 .932 r
.78398 .48403 .78867 .4896 .79962 .48663 .79492 .48057 Mtetra
.673 .759 .915 r
.79492 .48057 .79962 .48663 .81057 .4832 .80587 .47679 Mtetra
.673 .747 .906 r
.80587 .47679 .81057 .4832 .82155 .47959 .81687 .47298 Mtetra
.672 .741 .902 r
.81687 .47298 .82155 .47959 .83256 .47588 .8279 .46918 Mtetra
.667 .737 .902 r
.8279 .46918 .83256 .47588 .84362 .47222 .83899 .46552 Mtetra
.664 .736 .904 r
.83899 .46552 .84362 .47222 .85472 .46859 .85013 .46195 Mtetra
.661 .738 .907 r
.85013 .46195 .85472 .46859 .86587 .46503 .86132 .45845 Mtetra
.659 .74 .91 r
.86132 .45845 .86587 .46503 .87707 .4615 .87255 .45499 Mtetra
.657 .743 .913 r
.87255 .45499 .87707 .4615 .88831 .45801 .88384 .45156 Mtetra
.656 .745 .915 r
.88384 .45156 .88831 .45801 .8996 .45454 .89517 .44814 Mtetra
.656 .747 .917 r
.89517 .44814 .8996 .45454 .91094 .45109 .90654 .44471 Mtetra
.656 .749 .919 r
.90654 .44471 .91094 .45109 .92232 .44763 .91796 .44128 Mtetra
.657 .752 .92 r
.30643 .61871 .31232 .62385 .32155 .62106 .31568 .61587 Mtetra
.658 .751 .919 r
.31568 .61587 .32155 .62106 .33081 .61826 .32496 .61302 Mtetra
.658 .749 .917 r
.32496 .61302 .33081 .61826 .3401 .61547 .33427 .61015 Mtetra
.658 .747 .916 r
.33427 .61015 .3401 .61547 .34942 .61269 .34362 .60728 Mtetra
.658 .745 .914 r
.34362 .60728 .34942 .61269 .35877 .60993 .353 .60439 Mtetra
.657 .74 .911 r
.353 .60439 .35877 .60993 .36816 .60722 .36241 .60152 Mtetra
.655 .735 .908 r
.36241 .60152 .36816 .60722 .37757 .60458 .37185 .59871 Mtetra
.65 .728 .906 r
.37185 .59871 .37757 .60458 .38702 .60203 .38131 .59602 Mtetra
.642 .721 .905 r
.38131 .59602 .38702 .60203 .39649 .59961 .39081 .5935 Mtetra
.636 .717 .906 r
.39081 .5935 .39649 .59961 .406 .59721 .40034 .59112 Mtetra
.629 .716 .909 r
.40034 .59112 .406 .59721 .41555 .59479 .40989 .5889 Mtetra
.631 .724 .915 r
.40989 .5889 .41555 .59479 .42514 .59206 .41949 .5866 Mtetra
.64 .743 .924 r
.41949 .5866 .42514 .59206 .43478 .58882 .42913 .58406 Mtetra
.667 .778 .933 r
.42913 .58406 .43478 .58882 .44447 .58476 .43883 .58083 Mtetra
.708 .821 .935 r
.43883 .58083 .44447 .58476 .45421 .57963 .44858 .57654 Mtetra
.758 .863 .927 r
.44858 .57654 .45421 .57963 .46399 .57347 .45839 .57089 Mtetra
.804 .883 .903 r
.45839 .57089 .46399 .57347 .47381 .5664 .46824 .5637 Mtetra
.807 .879 .899 r
.46824 .5637 .47381 .5664 .48362 .55983 .4781 .55639 Mtetra
.778 .851 .906 r
.4781 .55639 .48362 .55983 .49344 .55483 .48796 .55002 Mtetra
.667 .781 .934 r
.48796 .55002 .49344 .55483 .50326 .55294 .49782 .54672 Mtetra
.44 .636 .939 r
.49782 .54672 .50326 .55294 .51311 .55508 .50769 .5478 Mtetra
.08 .387 .848 r
.50769 .5478 .51311 .55508 .52302 .56076 .5176 .55374 Mtetra
0 .114 .649 r
.5176 .55374 .52302 .56076 .53302 .56867 .52761 .56342 Mtetra
0 .366 .821 r
.52761 .56342 .53302 .56867 .54311 .57285 .53771 .56897 Mtetra
.618 .812 .975 r
.53771 .56897 .54311 .57285 .55322 .57037 .54785 .56634 Mtetra
.876 .827 .796 r
.54785 .56634 .55322 .57037 .56329 .56079 .55793 .55366 Mtetra
.889 .746 .699 r
.55793 .55366 .56329 .56079 .57327 .54553 .56788 .53255 Mtetra
.825 .665 .684 r
.56788 .53255 .57327 .54553 .58324 .53116 .57777 .51256 Mtetra
.742 .587 .683 r
.57777 .51256 .58324 .53116 .59326 .52103 .58772 .49865 Mtetra
.613 .49 .689 r
.58772 .49865 .59326 .52103 .60344 .51793 .59787 .49551 Mtetra
.428 .371 .692 r
.59787 .49551 .60344 .51793 .61384 .52187 .60833 .50318 Mtetra
.192 .242 .686 r
.60833 .50318 .61384 .52187 .62445 .53011 .61907 .51698 Mtetra
0 .113 .656 r
.61907 .51698 .62445 .53011 .63521 .53928 .62999 .53198 Mtetra
.072 .381 .844 r
.62999 .53198 .63521 .53928 .64587 .54276 .64078 .53855 Mtetra
.662 .82 .959 r
.64078 .53855 .64587 .54276 .65634 .5391 .65128 .535 Mtetra
.872 .845 .815 r
.65128 .535 .65634 .5391 .66655 .52869 .66148 .52317 Mtetra
.891 .797 .749 r
.66148 .52317 .66655 .52869 .67659 .51447 .67148 .50712 Mtetra
.834 .754 .775 r
.67148 .50712 .67659 .51447 .68671 .50249 .68162 .49482 Mtetra
.759 .73 .826 r
.68162 .49482 .68671 .50249 .69699 .49407 .69198 .48743 Mtetra
.647 .722 .903 r
.69198 .48743 .69699 .49407 .7075 .48973 .7026 .4845 Mtetra
.465 .697 .968 r
.7026 .4845 .7075 .48973 .71824 .48858 .71344 .48469 Mtetra
.31 .676 .976 r
.71344 .48469 .71824 .48858 .72912 .48902 .7244 .48586 Mtetra
.259 .679 .965 r
.7244 .48586 .72912 .48902 .74011 .49 .73543 .48692 Mtetra
.403 .767 .994 r
.73543 .48692 .74011 .49 .7511 .49005 .74642 .48642 Mtetra
.545 .81 .995 r
.74642 .48642 .7511 .49005 .76208 .48906 .75737 .48451 Mtetra
.63 .803 .966 r
.75737 .48451 .76208 .48906 .77304 .48697 .76829 .48153 Mtetra
.669 .781 .933 r
.76829 .48153 .77304 .48697 .78398 .48403 .7792 .47783 Mtetra
.678 .757 .91 r
.7792 .47783 .78398 .48403 .79492 .48057 .79014 .47388 Mtetra
.68 .741 .897 r
.79014 .47388 .79492 .48057 .80587 .47679 .8011 .46985 Mtetra
.674 .732 .893 r
.8011 .46985 .80587 .47679 .81687 .47298 .81212 .46597 Mtetra
.669 .728 .894 r
.81212 .46597 .81687 .47298 .8279 .46918 .82319 .46223 Mtetra
.663 .728 .898 r
.82319 .46223 .8279 .46918 .83899 .46552 .83432 .45868 Mtetra
.658 .731 .903 r
.83432 .45868 .83899 .46552 .85013 .46195 .8455 .45524 Mtetra
.656 .735 .908 r
.8455 .45524 .85013 .46195 .86132 .45845 .85673 .45185 Mtetra
.654 .739 .912 r
.85673 .45185 .86132 .45845 .87255 .45499 .86801 .44849 Mtetra
.654 .743 .915 r
.86801 .44849 .87255 .45499 .88384 .45156 .87933 .44511 Mtetra
.654 .746 .917 r
.87933 .44511 .88384 .45156 .89517 .44814 .8907 .44172 Mtetra
.654 .748 .919 r
.8907 .44172 .89517 .44814 .90654 .44471 .90211 .43832 Mtetra
.654 .75 .92 r
.90211 .43832 .90654 .44471 .91796 .44128 .91357 .43489 Mtetra
.657 .752 .92 r
.3005 .61354 .30643 .61871 .31568 .61587 .30977 .61069 Mtetra
.658 .752 .92 r
.30977 .61069 .31568 .61587 .32496 .61302 .31907 .60782 Mtetra
.659 .752 .919 r
.31907 .60782 .32496 .61302 .33427 .61015 .3284 .60492 Mtetra
.66 .752 .918 r
.3284 .60492 .33427 .61015 .34362 .60728 .33777 .60197 Mtetra
.662 .751 .916 r
.33777 .60197 .34362 .60728 .353 .60439 .34717 .59898 Mtetra
.662 .748 .914 r
.34717 .59898 .353 .60439 .36241 .60152 .35661 .59596 Mtetra
.662 .743 .91 r
.35661 .59596 .36241 .60152 .37185 .59871 .36608 .59294 Mtetra
.658 .735 .906 r
.36608 .59294 .37185 .59871 .38131 .59602 .37558 .59001 Mtetra
.652 .726 .903 r
.37558 .59001 .38131 .59602 .39081 .5935 .3851 .58724 Mtetra
.643 .715 .9 r
.3851 .58724 .39081 .5935 .40034 .59112 .39465 .58469 Mtetra
.631 .706 .9 r
.39465 .58469 .40034 .59112 .40989 .5889 .40423 .58242 Mtetra
.623 .703 .902 r
.40423 .58242 .40989 .5889 .41949 .5866 .41383 .58034 Mtetra
.616 .708 .911 r
.41383 .58034 .41949 .5866 .42913 .58406 .42347 .5784 Mtetra
.629 .735 .924 r
.42347 .5784 .42913 .58406 .43883 .58083 .43317 .57609 Mtetra
.658 .779 .938 r
.43317 .57609 .43883 .58083 .44858 .57654 .44291 .57301 Mtetra
.719 .842 .94 r
.44291 .57301 .44858 .57654 .45839 .57089 .45273 .56839 Mtetra
.789 .889 .917 r
.45273 .56839 .45839 .57089 .46824 .5637 .46261 .56174 Mtetra
.817 .909 .903 r
.46261 .56174 .46824 .5637 .4781 .55639 .47252 .55411 Mtetra
.819 .897 .897 r
.47252 .55411 .4781 .55639 .48796 .55002 .48244 .54636 Mtetra
.747 .843 .923 r
.48244 .54636 .48796 .55002 .49782 .54672 .49234 .54094 Mtetra
.581 .717 .936 r
.49234 .54094 .49782 .54672 .50769 .5478 .50224 .53956 Mtetra
.242 .458 .869 r
.50224 .53956 .50769 .5478 .5176 .55374 .51216 .54436 Mtetra
0 .16 .7 r
.51216 .54436 .5176 .55374 .52761 .56342 .52216 .55486 Mtetra
.068 .339 .816 r
.52216 .55486 .52761 .56342 .53771 .56897 .53227 .56206 Mtetra
.575 .679 .91 r
.53227 .56206 .53771 .56897 .54785 .56634 .54243 .56098 Mtetra
.867 .789 .772 r
.54243 .56098 .54785 .56634 .55793 .55366 .55254 .54722 Mtetra
.91 .754 .676 r
.55254 .54722 .55793 .55366 .56788 .53255 .5625 .52211 Mtetra
.869 .702 .672 r
.5625 .52211 .56788 .53255 .57777 .51256 .57237 .49775 Mtetra
.794 .637 .688 r
.57237 .49775 .57777 .51256 .58772 .49865 .58227 .48053 Mtetra
.622 .52 .717 r
.58227 .48053 .58772 .49865 .59787 .49551 .59241 .47736 Mtetra
.276 .302 .708 r
.59241 .47736 .59787 .49551 .60833 .50318 .60292 .48828 Mtetra
0 .033 .595 r
.60292 .48828 .60833 .50318 .61907 .51698 .61375 .50641 Mtetra
0 0 .435 r
.61375 .50641 .61907 .51698 .62999 .53198 .62477 .52539 Mtetra
0 .296 .789 r
.62477 .52539 .62999 .53198 .64078 .53855 .6356 .533 Mtetra
.724 .784 .9 r
.6356 .533 .64078 .53855 .65128 .535 .64607 .52785 Mtetra
.848 .76 .764 r
.64607 .52785 .65128 .535 .66148 .52317 .65624 .5143 Mtetra
.855 .728 .723 r
.65624 .5143 .66148 .52317 .67148 .50712 .66624 .49738 Mtetra
.792 .698 .761 r
.66624 .49738 .67148 .50712 .68162 .49482 .67646 .48618 Mtetra
.698 .686 .835 r
.67646 .48618 .68162 .49482 .69198 .48743 .68697 .48125 Mtetra
.549 .699 .938 r
.68697 .48125 .69198 .48743 .7026 .4845 .69773 .48042 Mtetra
.283 .652 .969 r
.69773 .48042 .7026 .4845 .71344 .48469 .70867 .48199 Mtetra
.164 .638 .929 r
.70867 .48199 .71344 .48469 .7244 .48586 .71968 .48345 Mtetra
.243 .702 .95 r
.71968 .48345 .7244 .48586 .73543 .48692 .73071 .48392 Mtetra
.49 .815 1 r
.73071 .48392 .73543 .48692 .74642 .48642 .74166 .48232 Mtetra
.633 .824 .974 r
.74166 .48232 .74642 .48642 .75737 .48451 .75256 .47914 Mtetra
.679 .787 .931 r
.75256 .47914 .75737 .48451 .76829 .48153 .76345 .47516 Mtetra
.692 .756 .901 r
.76345 .47516 .76829 .48153 .7792 .47783 .77434 .4708 Mtetra
.685 .733 .887 r
.77434 .4708 .7792 .47783 .79014 .47388 .78528 .46658 Mtetra
.678 .722 .883 r
.78528 .46658 .79014 .47388 .8011 .46985 .79627 .46254 Mtetra
.668 .719 .887 r
.79627 .46254 .8011 .46985 .81212 .46597 .80733 .4588 Mtetra
.661 .721 .894 r
.80733 .4588 .81212 .46597 .82319 .46223 .81845 .45528 Mtetra
.655 .727 .902 r
.81845 .45528 .82319 .46223 .83432 .45868 .82963 .45193 Mtetra
.651 .732 .909 r
.82963 .45193 .83432 .45868 .8455 .45524 .84086 .44866 Mtetra
.651 .739 .914 r
.84086 .44866 .8455 .45524 .85673 .45185 .85213 .44539 Mtetra
.651 .744 .918 r
.85213 .44539 .85673 .45185 .86801 .44849 .86345 .4421 Mtetra
.652 .748 .92 r
.86345 .4421 .86801 .44849 .87933 .44511 .87481 .43874 Mtetra
.653 .75 .921 r
.87481 .43874 .87933 .44511 .8907 .44172 .88622 .43535 Mtetra
.654 .751 .921 r
.88622 .43535 .8907 .44172 .90211 .43832 .89766 .43192 Mtetra
.655 .751 .921 r
.89766 .43192 .90211 .43832 .91357 .43489 .90915 .42846 Mtetra
.29453 .60833 .3005 .61354 .30977 .61069 .30382 .60552 Mtetra
.655 .753 .922 r
.30382 .60552 .30977 .61069 .31907 .60782 .31313 .60268 Mtetra
.657 .756 .923 r
.31313 .60268 .31907 .60782 .3284 .60492 .32249 .5998 Mtetra
.659 .758 .923 r
.32249 .5998 .3284 .60492 .33777 .60197 .33187 .59685 Mtetra
.663 .759 .922 r
.33187 .59685 .33777 .60197 .34717 .59898 .3413 .5938 Mtetra
.666 .758 .919 r
.3413 .5938 .34717 .59898 .35661 .59596 .35076 .59067 Mtetra
.669 .756 .915 r
.35076 .59067 .35661 .59596 .36608 .59294 .36026 .58744 Mtetra
.669 .749 .91 r
.36026 .58744 .36608 .59294 .37558 .59001 .36979 .58421 Mtetra
.666 .738 .904 r
.36979 .58421 .37558 .59001 .3851 .58724 .37935 .58103 Mtetra
.658 .723 .897 r
.37935 .58103 .3851 .58724 .39465 .58469 .38894 .57806 Mtetra
.645 .706 .891 r
.38894 .57806 .39465 .58469 .40423 .58242 .39854 .57541 Mtetra
.628 .689 .888 r
.39854 .57541 .40423 .58242 .41383 .58034 .40817 .57322 Mtetra
.605 .677 .892 r
.40817 .57322 .41383 .58034 .42347 .5784 .41781 .5716 Mtetra
.596 .684 .903 r
.41781 .5716 .42347 .5784 .43317 .57609 .4275 .57013 Mtetra
.596 .714 .927 r
.4275 .57013 .43317 .57609 .44291 .57301 .43723 .56851 Mtetra
.652 .789 .948 r
.43723 .56851 .44291 .57301 .45273 .56839 .44704 .5655 Mtetra
.739 .873 .943 r
.44704 .5655 .45273 .56839 .46261 .56174 .45692 .56029 Mtetra
.801 .932 .919 r
.45692 .56029 .46261 .56174 .47252 .55411 .46686 .55312 Mtetra
.845 .941 .886 r
.46686 .55312 .47252 .55411 .48244 .54636 .47684 .54434 Mtetra
.825 .909 .896 r
.47684 .54434 .48244 .54636 .49234 .54094 .48681 .53634 Mtetra
.739 .807 .906 r
.48681 .53634 .49234 .54094 .50224 .53956 .49677 .53103 Mtetra
.45 .567 .881 r
.49677 .53103 .50224 .53956 .51216 .54436 .50671 .53288 Mtetra
.061 .257 .75 r
.50671 .53288 .51216 .54436 .52216 .55486 .51669 .54257 Mtetra
.162 .308 .766 r
.51669 .54257 .52216 .55486 .53227 .56206 .52679 .55143 Mtetra
.452 .519 .837 r
.52679 .55143 .53227 .56206 .54243 .56098 .53697 .55402 Mtetra
.827 .752 .781 r
.53697 .55402 .54243 .56098 .55254 .54722 .54714 .54234 Mtetra
.927 .777 .674 r
.54714 .54234 .55254 .54722 .5625 .52211 .55715 .51663 Mtetra
.924 .768 .67 r
.55715 .51663 .5625 .52211 .57237 .49775 .56705 .49046 Mtetra
.881 .747 .709 r
.56705 .49046 .57237 .49775 .58227 .48053 .57697 .47118 Mtetra
.652 .645 .83 r
.57697 .47118 .58227 .48053 .59241 .47736 .58712 .46799 Mtetra
0 .058 .621 r
.58712 .46799 .59241 .47736 .60292 .48828 .59766 .48092 Mtetra
.75 .312 0 r
.59766 .48092 .60292 .48828 .61375 .50641 .60852 .50083 Mtetra
.799 .34 0 r
.60852 .50083 .61375 .50641 .62477 .52539 .61956 .52037 Mtetra
0 .391 .836 r
.61956 .52037 .62477 .52539 .6356 .533 .63033 .52584 Mtetra
.791 .751 .817 r
.63033 .52584 .6356 .533 .64607 .52785 .6407 .51693 Mtetra
.819 .69 .722 r
.6407 .51693 .64607 .52785 .65624 .5143 .65084 .50165 Mtetra
.809 .667 .707 r
.65084 .50165 .65624 .5143 .66624 .49738 .66089 .48548 Mtetra
.732 .643 .76 r
.66089 .48548 .66624 .49738 .67646 .48618 .67126 .47724 Mtetra
.58 .628 .864 r
.67126 .47724 .67646 .48618 .68697 .48125 .68198 .47625 Mtetra
.327 .636 .963 r
.68198 .47625 .68697 .48125 .69773 .48042 .6929 .47803 Mtetra
0 .528 .844 r
.6929 .47803 .69773 .48042 .70867 .48199 .70393 .48061 Mtetra
.064 .611 .838 r
.70393 .48061 .70867 .48199 .71968 .48345 .71495 .48155 Mtetra
.35 .787 .964 r
.71495 .48155 .71968 .48345 .73071 .48392 .72592 .48052 Mtetra
.623 .853 .986 r
.72592 .48052 .73071 .48392 .74166 .48232 .73681 .47722 Mtetra
.706 .807 .928 r
.73681 .47722 .74166 .48232 .75256 .47914 .74763 .47249 Mtetra
.706 .753 .888 r
.74763 .47249 .75256 .47914 .76345 .47516 .75848 .46761 Mtetra
.697 .722 .869 r
.75848 .46761 .76345 .47516 .77434 .4708 .76938 .46287 Mtetra
.678 .705 .868 r
.76938 .46287 .77434 .4708 .78528 .46658 .78035 .45872 Mtetra
.665 .702 .875 r
.78035 .45872 .78528 .46658 .79627 .46254 .7914 .45503 Mtetra
.655 .709 .887 r
.7914 .45503 .79627 .46254 .80733 .4588 .80252 .45168 Mtetra
.647 .718 .9 r
.80252 .45168 .80733 .4588 .81845 .45528 .8137 .44853 Mtetra
.644 .73 .911 r
.8137 .44853 .81845 .45528 .82963 .45193 .82493 .44545 Mtetra
.643 .74 .919 r
.82493 .44545 .82963 .45193 .84086 .44866 .83621 .44235 Mtetra
.646 .748 .924 r
.83621 .44235 .84086 .44866 .85213 .44539 .84753 .43916 Mtetra
.649 .753 .926 r
.84753 .43916 .85213 .44539 .86345 .4421 .85889 .43588 Mtetra
.652 .756 .926 r
.85889 .43588 .86345 .4421 .87481 .43874 .87028 .43249 Mtetra
.654 .756 .925 r
.87028 .43249 .87481 .43874 .88622 .43535 .88171 .42903 Mtetra
.656 .756 .923 r
.88171 .42903 .88622 .43535 .89766 .43192 .89318 .42552 Mtetra
.657 .754 .922 r
.89318 .42552 .89766 .43192 .90915 .42846 .90469 .42197 Mtetra
.651 .75 .922 r
.28853 .60308 .29453 .60833 .30382 .60552 .29782 .60034 Mtetra
.651 .753 .924 r
.29782 .60034 .30382 .60552 .31313 .60268 .30715 .59757 Mtetra
.653 .757 .926 r
.30715 .59757 .31313 .60268 .32249 .5998 .31652 .59476 Mtetra
.655 .761 .927 r
.31652 .59476 .32249 .5998 .33187 .59685 .32593 .59187 Mtetra
.66 .765 .928 r
.32593 .59187 .33187 .59685 .3413 .5938 .33537 .58886 Mtetra
.665 .769 .927 r
.33537 .58886 .3413 .5938 .35076 .59067 .34485 .58571 Mtetra
.672 .771 .924 r
.34485 .58571 .35076 .59067 .36026 .58744 .35438 .58239 Mtetra
.677 .769 .92 r
.35438 .58239 .36026 .58744 .36979 .58421 .36394 .57893 Mtetra
.681 .762 .912 r
.36394 .57893 .36979 .58421 .37935 .58103 .37354 .57535 Mtetra
.678 .748 .903 r
.37354 .57535 .37935 .58103 .38894 .57806 .38317 .57184 Mtetra
.67 .728 .893 r
.38317 .57184 .38894 .57806 .39854 .57541 .39282 .56853 Mtetra
.648 .701 .885 r
.39282 .56853 .39854 .57541 .40817 .57322 .40248 .56577 Mtetra
.616 .673 .882 r
.40248 .56577 .40817 .57322 .41781 .5716 .41215 .56388 Mtetra
.587 .654 .883 r
.41215 .56388 .41781 .5716 .4275 .57013 .42184 .56271 Mtetra
.554 .65 .898 r
.42184 .56271 .4275 .57013 .43723 .56851 .43155 .56221 Mtetra
.578 .698 .924 r
.43155 .56221 .43723 .56851 .44704 .5655 .44133 .56098 Mtetra
.646 .789 .951 r
.44133 .56098 .44704 .5655 .45692 .56029 .4512 .55806 Mtetra
.742 .903 .95 r
.4512 .55806 .45692 .56029 .46686 .55312 .46115 .5526 Mtetra
.831 .96 .894 r
.46115 .5526 .46686 .55312 .47684 .54434 .47117 .54418 Mtetra
.866 .962 .863 r
.47117 .54418 .47684 .54434 .48681 .53634 .48121 .53429 Mtetra
.859 .9 .863 r
.48121 .53429 .48681 .53634 .49677 .53103 .49125 .52465 Mtetra
.649 .723 .903 r
.49125 .52465 .49677 .53103 .50671 .53288 .50123 .52179 Mtetra
.278 .406 .813 r
.50123 .52179 .50671 .53288 .51669 .54257 .51122 .52783 Mtetra
.242 .32 .744 r
.51122 .52783 .51669 .54257 .52679 .55143 .52129 .53683 Mtetra
.319 .372 .76 r
.52129 .53683 .52679 .55143 .53697 .55402 .53147 .54413 Mtetra
.71 .661 .8 r
.53147 .54413 .53697 .55402 .54714 .54234 .54169 .53822 Mtetra
.922 .803 .71 r
.54169 .53822 .54714 .54234 .55715 .51663 .55181 .51756 Mtetra
.976 .885 .674 r
.55181 .51756 .55715 .51663 .56705 .49046 .56183 .49445 Mtetra
.933 .959 .651 r
.56183 .49445 .56705 .49046 .57697 .47118 .57184 .47598 Mtetra
.134 0 0 r
.57184 .47598 .57697 .47118 .58712 .46799 .58205 .47278 Mtetra
.754 .319 .218 r
.58205 .47278 .58712 .46799 .59766 .48092 .59261 .48488 Mtetra
.81 .387 .24 r
.59261 .48488 .59766 .48092 .60852 .50083 .60342 .50168 Mtetra
.801 .328 .1 r
.60342 .50168 .60852 .50083 .61956 .52037 .61433 .51611 Mtetra
.461 .742 .989 r
.61433 .51611 .61956 .52037 .63033 .52584 .62495 .51572 Mtetra
.814 .7 .739 r
.62495 .51572 .63033 .52584 .6407 .51693 .63518 .502 Mtetra
.783 .636 .698 r
.63518 .502 .6407 .51693 .65084 .50165 .64532 .48652 Mtetra
.755 .621 .71 r
.64532 .48652 .65084 .50165 .66089 .48548 .65554 .474 Mtetra
.649 .611 .798 r
.65554 .474 .66089 .48548 .67126 .47724 .66613 .47048 Mtetra
.295 .546 .919 r
.66613 .47048 .67126 .47724 .68198 .47625 .67708 .47386 Mtetra
0 .427 .767 r
.67708 .47386 .68198 .47625 .6929 .47803 .68812 .47751 Mtetra
.186 0 0 r
.68812 .47751 .6929 .47803 .70393 .48061 .69917 .4797 Mtetra
.216 .73 .876 r
.69917 .4797 .70393 .48061 .71495 .48155 .71013 .47886 Mtetra
.606 .878 .991 r
.71013 .47886 .71495 .48155 .72592 .48052 .721 .47543 Mtetra
.721 .812 .922 r
.721 .47543 .72592 .48052 .73681 .47722 .7318 .47027 Mtetra
.732 .752 .868 r
.7318 .47027 .73681 .47722 .74763 .47249 .74258 .46435 Mtetra
.706 .71 .851 r
.74258 .46435 .74763 .47249 .75848 .46761 .75343 .4591 Mtetra
.685 .693 .852 r
.75343 .4591 .75848 .46761 .76938 .46287 .76437 .4546 Mtetra
.661 .69 .866 r
.76437 .4546 .76938 .46287 .78035 .45872 .77541 .45098 Mtetra
.644 .698 .885 r
.77541 .45098 .78035 .45872 .7914 .45503 .78653 .44794 Mtetra
.636 .715 .905 r
.78653 .44794 .7914 .45503 .80252 .45168 .79773 .4451 Mtetra
.631 .732 .92 r
.79773 .4451 .80252 .45168 .8137 .44853 .80897 .44233 Mtetra
.634 .747 .93 r
.80897 .44233 .8137 .44853 .82493 .44545 .82025 .43943 Mtetra
.638 .757 .934 r
.82025 .43943 .82493 .44545 .83621 .44235 .83157 .4364 Mtetra
.645 .762 .934 r
.83157 .4364 .83621 .44235 .84753 .43916 .84292 .43317 Mtetra
.65 .764 .933 r
.84292 .43317 .84753 .43916 .85889 .43588 .85431 .4298 Mtetra
.654 .764 .93 r
.85431 .4298 .85889 .43588 .87028 .43249 .86572 .42631 Mtetra
.657 .762 .927 r
.86572 .42631 .87028 .43249 .88171 .42903 .87718 .42273 Mtetra
.659 .759 .924 r
.87718 .42273 .88171 .42903 .89318 .42552 .88867 .4191 Mtetra
.66 .756 .921 r
.88867 .4191 .89318 .42552 .90469 .42197 .90021 .41544 Mtetra
.647 .749 .924 r
.28248 .59781 .28853 .60308 .29782 .60034 .29179 .59512 Mtetra
.646 .752 .926 r
.29179 .59512 .29782 .60034 .30715 .59757 .30113 .59245 Mtetra
.647 .756 .929 r
.30113 .59245 .30715 .59757 .31652 .59476 .31051 .58974 Mtetra
.649 .762 .932 r
.31051 .58974 .31652 .59476 .32593 .59187 .31993 .58698 Mtetra
.652 .768 .934 r
.31993 .58698 .32593 .59187 .33537 .58886 .32939 .58412 Mtetra
.658 .776 .936 r
.32939 .58412 .33537 .58886 .34485 .58571 .33889 .5811 Mtetra
.667 .784 .936 r
.33889 .5811 .34485 .58571 .35438 .58239 .34843 .57786 Mtetra
.678 .79 .934 r
.34843 .57786 .35438 .58239 .36394 .57893 .35802 .57435 Mtetra
.692 .791 .927 r
.35802 .57435 .36394 .57893 .37354 .57535 .36766 .57049 Mtetra
.698 .783 .916 r
.36766 .57049 .37354 .57535 .38317 .57184 .37733 .56643 Mtetra
.701 .764 .901 r
.37733 .56643 .38317 .57184 .39282 .56853 .38704 .56225 Mtetra
.683 .732 .887 r
.38704 .56225 .39282 .56853 .40248 .56577 .39675 .5585 Mtetra
.652 .692 .875 r
.39675 .5585 .40248 .56577 .41215 .56388 .40647 .5556 Mtetra
.608 .649 .865 r
.40647 .5556 .41215 .56388 .42184 .56271 .41619 .55391 Mtetra
.549 .61 .866 r
.41619 .55391 .42184 .56271 .43155 .56221 .4259 .55375 Mtetra
.524 .608 .879 r
.4259 .55375 .43155 .56221 .44133 .56098 .43565 .55406 Mtetra
.518 .653 .919 r
.43565 .55406 .44133 .56098 .4512 .55806 .44547 .55406 Mtetra
.607 .803 .975 r
.44547 .55406 .4512 .55806 .46115 .5526 .45538 .55166 Mtetra
.748 .952 .943 r
.45538 .55166 .46115 .5526 .47117 .54418 .46541 .54551 Mtetra
.847 .995 .835 r
.46541 .54551 .47117 .54418 .48121 .53429 .47551 .53533 Mtetra
.919 .962 .792 r
.47551 .53533 .48121 .53429 .49125 .52465 .48564 .52197 Mtetra
.839 .883 .873 r
.48564 .52197 .49125 .52465 .50123 .52179 .49571 .5131 Mtetra
.576 .627 .866 r
.49571 .5131 .50123 .52179 .51122 .52783 .50574 .51224 Mtetra
.358 .383 .75 r
.50574 .51224 .51122 .52783 .52129 .53683 .5158 .51896 Mtetra
.207 .261 .698 r
.5158 .51896 .52129 .53683 .53147 .54413 .52595 .53076 Mtetra
.463 .479 .789 r
.52595 .53076 .53147 .54413 .54169 .53822 .5362 .53387 Mtetra
.83 .831 .849 r
.5362 .53387 .54169 .53822 .55181 .51756 .54646 .52458 Mtetra
.608 .833 .447 r
.54646 .52458 .55181 .51756 .56183 .49445 .55666 .51048 Mtetra
.059 0 .137 r
.55666 .51048 .56183 .49445 .57184 .47598 .56684 .4966 Mtetra
.465 .153 .352 r
.56684 .4966 .57184 .47598 .58205 .47278 .57716 .4934 Mtetra
.622 .297 .4 r
.57716 .4934 .58205 .47278 .59261 .48488 .58772 .5009 Mtetra
.636 .288 .365 r
.58772 .5009 .59261 .48488 .60342 .50168 .59839 .50865 Mtetra
.545 .098 .14 r
.59839 .50865 .60342 .50168 .61433 .51611 .60905 .51161 Mtetra
.833 .837 .849 r
.60905 .51161 .61433 .51611 .62495 .51572 .61944 .50209 Mtetra
.815 .661 .692 r
.61944 .50209 .62495 .51572 .63518 .502 .62955 .48377 Mtetra
.74 .591 .69 r
.62955 .48377 .63518 .502 .64532 .48652 .63977 .47053 Mtetra
.665 .566 .733 r
.63977 .47053 .64532 .48652 .65554 .474 .65027 .46495 Mtetra
.426 .547 .875 r
.65027 .46495 .65554 .474 .66613 .47048 .66113 .46748 Mtetra
.4 0 0 r
.66113 .46748 .66613 .47048 .67708 .47386 .67227 .4746 Mtetra
.441 0 0 r
.67227 .4746 .67708 .47386 .68812 .47751 .68336 .47852 Mtetra
.098 0 0 r
.68336 .47852 .68812 .47751 .69917 .4797 .69434 .47835 Mtetra
.577 .916 .968 r
.69434 .47835 .69917 .4797 .71013 .47886 .70517 .47435 Mtetra
.764 .844 .912 r
.70517 .47435 .71013 .47886 .721 .47543 .7159 .46789 Mtetra
.747 .74 .846 r
.7159 .46789 .721 .47543 .7318 .47027 .72663 .4611 Mtetra
.722 .693 .821 r
.72663 .4611 .7318 .47027 .74258 .46435 .7374 .45478 Mtetra
.685 .669 .829 r
.7374 .45478 .74258 .46435 .75343 .4591 .74831 .45002 Mtetra
.655 .668 .85 r
.74831 .45002 .75343 .4591 .76437 .4546 .75934 .4465 Mtetra
.63 .682 .881 r
.75934 .4465 .76437 .4546 .77541 .45098 .77048 .44386 Mtetra
.611 .704 .911 r
.77048 .44386 .77541 .45098 .78653 .44794 .7817 .44168 Mtetra
.61 .735 .934 r
.7817 .44168 .78653 .44794 .79773 .4451 .79297 .43935 Mtetra
.614 .757 .947 r
.79297 .43935 .79773 .4451 .80897 .44233 .80427 .43683 Mtetra
.627 .773 .951 r
.80427 .43683 .80897 .44233 .82025 .43943 .81559 .43395 Mtetra
.638 .779 .949 r
.81559 .43395 .82025 .43943 .83157 .4364 .82694 .43079 Mtetra
.649 .779 .943 r
.82694 .43079 .83157 .4364 .84292 .43317 .83831 .42739 Mtetra
.656 .776 .937 r
.83831 .42739 .84292 .43317 .85431 .4298 .8497 .42381 Mtetra
.66 .771 .932 r
.8497 .42381 .85431 .4298 .86572 .42631 .86114 .42015 Mtetra
.662 .766 .927 r
.86114 .42015 .86572 .42631 .87718 .42273 .87261 .41641 Mtetra
.663 .762 .923 r
.87261 .41641 .87718 .42273 .88867 .4191 .88413 .41263 Mtetra
.663 .758 .921 r
.88413 .41263 .88867 .4191 .90021 .41544 .89569 .40886 Mtetra
.646 .749 .924 r
.27639 .59249 .28248 .59781 .29179 .59512 .28572 .58983 Mtetra
.644 .75 .926 r
.28572 .58983 .29179 .59512 .30113 .59245 .29508 .58719 Mtetra
.643 .752 .928 r
.29508 .58719 .30113 .59245 .31051 .58974 .30447 .58456 Mtetra
.643 .755 .931 r
.30447 .58456 .31051 .58974 .31993 .58698 .3139 .58192 Mtetra
.642 .76 .934 r
.3139 .58192 .31993 .58698 .32939 .58412 .32337 .57925 Mtetra
.646 .77 .938 r
.32337 .57925 .32939 .58412 .33889 .5811 .33288 .57647 Mtetra
.653 .781 .942 r
.33288 .57647 .33889 .5811 .34843 .57786 .34243 .57351 Mtetra
.666 .796 .944 r
.34243 .57351 .34843 .57786 .35802 .57435 .35203 .57021 Mtetra
.686 .81 .941 r
.35203 .57021 .35802 .57435 .36766 .57049 .36169 .56644 Mtetra
.705 .817 .935 r
.36169 .56644 .36766 .57049 .37733 .56643 .37139 .5622 Mtetra
.724 .813 .92 r
.37139 .5622 .37733 .56643 .38704 .56225 .38115 .55742 Mtetra
.722 .791 .907 r
.38115 .55742 .38704 .56225 .39675 .5585 .39094 .55266 Mtetra
.704 .753 .89 r
.39094 .55266 .39675 .5585 .40647 .5556 .40073 .54831 Mtetra
.658 .696 .873 r
.40073 .54831 .40647 .5556 .41619 .55391 .41051 .54518 Mtetra
.591 .631 .86 r
.41051 .54518 .41619 .55391 .4259 .55375 .42026 .54394 Mtetra
.527 .576 .848 r
.42026 .54394 .4259 .55375 .43565 .55406 .43001 .54444 Mtetra
.451 .542 .859 r
.43001 .54444 .43565 .55406 .44547 .55406 .43978 .5465 Mtetra
.474 .613 .908 r
.43978 .5465 .44547 .55406 .45538 .55166 .44964 .54743 Mtetra
.59 .789 .975 r
.44964 .54743 .45538 .55166 .46541 .54551 .45962 .54535 Mtetra
.789 .976 .909 r
.45962 .54535 .46541 .54551 .47551 .53533 .46973 .5378 Mtetra
.903 .985 .763 r
.46973 .5378 .47551 .53533 .48564 .52197 .47993 .52422 Mtetra
.902 .985 .769 r
.47993 .52422 .48564 .52197 .49571 .5131 .4901 .51088 Mtetra
.849 .901 .873 r
.4901 .51088 .49571 .5131 .50574 .51224 .50022 .50166 Mtetra
.52 .558 .835 r
.50022 .50166 .50574 .51224 .5158 .51896 .5103 .50249 Mtetra
.175 .255 .707 r
.5103 .50249 .5158 .51896 .52595 .53076 .52042 .51395 Mtetra
.254 .304 .722 r
.52042 .51395 .52595 .53076 .5362 .53387 .53067 .52391 Mtetra
.37 .493 .852 r
.53067 .52391 .5362 .53387 .54646 .52458 .541 .5277 Mtetra
.109 0 0 r
.541 .5277 .54646 .52458 .55666 .51048 .55137 .52578 Mtetra
.334 0 .237 r
.55137 .52578 .55666 .51048 .56684 .4966 .56175 .51951 Mtetra
.473 .168 .367 r
.56175 .51951 .56684 .4966 .57716 .4934 .57218 .51631 Mtetra
.522 .212 .382 r
.57218 .51631 .57716 .4934 .58772 .5009 .58271 .51619 Mtetra
.391 .05 .262 r
.58271 .51619 .58772 .5009 .59839 .50865 .59321 .51171 Mtetra
.701 .96 .705 r
.59321 .51171 .59839 .50865 .60905 .51161 .6036 .50147 Mtetra
.836 .706 .72 r
.6036 .50147 .60905 .51161 .61944 .50209 .61383 .48499 Mtetra
.785 .622 .679 r
.61383 .48499 .61944 .50209 .62955 .48377 .62396 .46695 Mtetra
.685 .57 .72 r
.62396 .46695 .62955 .48377 .63977 .47053 .63439 .45961 Mtetra
.445 .514 .836 r
.63439 .45961 .63977 .47053 .65027 .46495 .64521 .46244 Mtetra
.445 0 0 r
.64521 .46244 .65027 .46495 .66113 .46748 .65628 .46947 Mtetra
.641 .109 0 r
.65628 .46947 .66113 .46748 .67227 .4746 .66746 .47679 Mtetra
.325 0 0 r
.66746 .47679 .67227 .4746 .68336 .47852 .67848 .478 Mtetra
.544 .921 .929 r
.67848 .478 .68336 .47852 .69434 .47835 .68929 .47364 Mtetra
.789 .84 .891 r
.68929 .47364 .69434 .47835 .70517 .47435 .69998 .46619 Mtetra
.776 .734 .814 r
.69998 .46619 .70517 .47435 .7159 .46789 .71061 .45757 Mtetra
.726 .672 .797 r
.71061 .45757 .7159 .46789 .72663 .4611 .72134 .45054 Mtetra
.69 .652 .808 r
.72134 .45054 .72663 .4611 .7374 .45478 .73221 .44527 Mtetra
.648 .655 .843 r
.73221 .44527 .7374 .45478 .74831 .45002 .74323 .44194 Mtetra
.609 .674 .887 r
.74323 .44194 .74831 .45002 .75934 .4465 .75439 .43988 Mtetra
.584 .71 .93 r
.75439 .43988 .75934 .4465 .77048 .44386 .76563 .43824 Mtetra
.568 .742 .958 r
.76563 .43824 .77048 .44386 .7817 .44168 .77694 .43662 Mtetra
.586 .774 .969 r
.77694 .43662 .7817 .44168 .79297 .43935 .78825 .43445 Mtetra
.607 .791 .969 r
.78825 .43445 .79297 .43935 .80427 .43683 .79958 .43179 Mtetra
.632 .796 .961 r
.79958 .43179 .80427 .43683 .81559 .43395 .81091 .42864 Mtetra
.65 .793 .951 r
.81091 .42864 .81559 .43395 .82694 .43079 .82226 .42515 Mtetra
.659 .784 .94 r
.82226 .42515 .82694 .43079 .83831 .42739 .83364 .42145 Mtetra
.665 .776 .932 r
.83364 .42145 .83831 .42739 .8497 .42381 .84505 .41764 Mtetra
.666 .768 .926 r
.84505 .41764 .8497 .42381 .86114 .42015 .85651 .41379 Mtetra
.666 .763 .922 r
.85651 .41379 .86114 .42015 .87261 .41641 .868 .40993 Mtetra
.666 .759 .92 r
.868 .40993 .87261 .41641 .88413 .41263 .87954 .40607 Mtetra
.664 .756 .919 r
.87954 .40607 .88413 .41263 .89569 .40886 .89113 .40224 Mtetra
.648 .749 .924 r
.27027 .58715 .27639 .59249 .28572 .58983 .27962 .58442 Mtetra
.645 .747 .923 r
.27962 .58442 .28572 .58983 .29508 .58719 .289 .58174 Mtetra
.643 .745 .923 r
.289 .58174 .29508 .58719 .30447 .58456 .29841 .5791 Mtetra
.64 .745 .925 r
.29841 .5791 .30447 .58456 .3139 .58192 .30785 .57652 Mtetra
.635 .747 .929 r
.30785 .57652 .3139 .58192 .32337 .57925 .31733 .57403 Mtetra
.634 .754 .935 r
.31733 .57403 .32337 .57925 .33288 .57647 .32684 .57153 Mtetra
.633 .765 .943 r
.32684 .57153 .33288 .57647 .34243 .57351 .33639 .56901 Mtetra
.641 .786 .951 r
.33639 .56901 .34243 .57351 .35203 .57021 .34598 .56622 Mtetra
.658 .812 .957 r
.34598 .56622 .35203 .57021 .36169 .56644 .35564 .563 Mtetra
.686 .84 .957 r
.35564 .563 .36169 .56644 .37139 .5622 .36536 .55911 Mtetra
.723 .861 .946 r
.36536 .55911 .37139 .5622 .38115 .55742 .37515 .55431 Mtetra
.747 .862 .933 r
.37515 .55431 .38115 .55742 .39094 .55266 .38499 .54888 Mtetra
.762 .837 .909 r
.38499 .54888 .39094 .55266 .40073 .54831 .39488 .54294 Mtetra
.734 .777 .887 r
.39488 .54294 .40073 .54831 .41051 .54518 .40475 .53764 Mtetra
.678 .697 .861 r
.40475 .53764 .41051 .54518 .42026 .54394 .41461 .53382 Mtetra
.588 .6 .832 r
.41461 .53382 .42026 .54394 .43001 .54444 .42441 .53269 Mtetra
.468 .506 .815 r
.42441 .53269 .43001 .54444 .43978 .5465 .43417 .53501 Mtetra
.409 .479 .821 r
.43417 .53501 .43978 .5465 .44964 .54743 .44396 .53854 Mtetra
.374 .522 .877 r
.44396 .53854 .44964 .54743 .45962 .54535 .45384 .54159 Mtetra
.56 .802 .989 r
.45384 .54159 .45962 .54535 .46973 .5378 .46389 .53972 Mtetra
.772 .997 .824 r
.46389 .53972 .46973 .5378 .47993 .52422 .47408 .53065 Mtetra
.731 .916 .556 r
.47408 .53065 .47993 .52422 .4901 .51088 .48435 .51621 Mtetra
.884 .964 .635 r
.48435 .51621 .4901 .51088 .50022 .50166 .49461 .49915 Mtetra
.825 .898 .892 r
.49461 .49915 .50022 .50166 .5103 .50249 .50476 .49096 Mtetra
.362 .451 .818 r
.50476 .49096 .5103 .50249 .52042 .51395 .51489 .49558 Mtetra
.228 .271 .699 r
.51489 .49558 .52042 .51395 .53067 .52391 .5251 .50704 Mtetra
.043 .163 .665 r
.5251 .50704 .53067 .52391 .541 .5277 .53545 .52161 Mtetra
0 .042 .558 r
.53545 .52161 .541 .5277 .55137 .52578 .54592 .53189 Mtetra
.531 .066 .094 r
.54592 .53189 .55137 .52578 .56175 .51951 .55645 .53469 Mtetra
.423 .075 .268 r
.55645 .53469 .56175 .51951 .57218 .51631 .56698 .53149 Mtetra
.224 0 .186 r
.56698 .53149 .57218 .51631 .58271 .51619 .57745 .52226 Mtetra
.786 .921 .543 r
.57745 .52226 .58271 .51619 .59321 .51171 .58779 .5055 Mtetra
.907 .775 .704 r
.58779 .5055 .59321 .51171 .6036 .50147 .59798 .48437 Mtetra
.785 .622 .679 r
.59798 .48437 .6036 .50147 .61383 .48499 .60817 .46631 Mtetra
.718 .576 .695 r
.60817 .46631 .61383 .48499 .62396 .46695 .61851 .45512 Mtetra
.496 .526 .818 r
.61851 .45512 .62396 .46695 .63439 .45961 .62924 .45685 Mtetra
.642 .096 0 r
.62924 .45685 .63439 .45961 .64521 .46244 .64037 .46758 Mtetra
.673 .208 .139 r
.64037 .46758 .64521 .46244 .65628 .46947 .65153 .47571 Mtetra
.522 .053 .083 r
.65153 .47571 .65628 .46947 .66746 .47679 .66258 .47842 Mtetra
.334 .803 .713 r
.66258 .47842 .66746 .47679 .67848 .478 .67338 .47381 Mtetra
.84 .861 .86 r
.67338 .47381 .67848 .478 .68929 .47364 .68398 .46417 Mtetra
.784 .709 .781 r
.68398 .46417 .68929 .47364 .69998 .46619 .69455 .45401 Mtetra
.74 .649 .76 r
.69455 .45401 .69998 .46619 .71061 .45757 .70518 .44507 Mtetra
.68 .617 .778 r
.70518 .44507 .71061 .45757 .72134 .45054 .71602 .43965 Mtetra
.627 .617 .821 r
.71602 .43965 .72134 .45054 .73221 .44527 .72707 .43699 Mtetra
.575 .653 .889 r
.72707 .43699 .73221 .44527 .74323 .44194 .73826 .43585 Mtetra
.516 .699 .953 r
.73826 .43585 .74323 .44194 .75439 .43988 .74956 .43537 Mtetra
.5 .759 .988 r
.74956 .43537 .75439 .43988 .76563 .43824 .76088 .43438 Mtetra
.517 .798 .997 r
.76088 .43438 .76563 .43824 .77694 .43662 .77222 .43274 Mtetra
.578 .825 .991 r
.77222 .43274 .77694 .43662 .78825 .43445 .78354 .43016 Mtetra
.626 .827 .978 r
.78354 .43016 .78825 .43445 .79958 .43179 .79486 .4269 Mtetra
.656 .812 .959 r
.79486 .4269 .79958 .43179 .81091 .42864 .80618 .42318 Mtetra
.67 .795 .942 r
.80618 .42318 .81091 .42864 .82226 .42515 .81753 .41918 Mtetra
.673 .778 .929 r
.81753 .41918 .82226 .42515 .83364 .42145 .82891 .41514 Mtetra
.673 .766 .921 r
.82891 .41514 .83364 .42145 .84505 .41764 .84034 .41109 Mtetra
.669 .758 .917 r
.84034 .41109 .84505 .41764 .85651 .41379 .85181 .40714 Mtetra
.667 .754 .915 r
.85181 .40714 .85651 .41379 .868 .40993 .86334 .40323 Mtetra
.665 .752 .916 r
.86334 .40323 .868 .40993 .87954 .40607 .87492 .39938 Mtetra
.663 .753 .917 r
.87492 .39938 .87954 .40607 .89113 .40224 .88655 .39556 Mtetra
.654 .751 .921 r
.2641 .58177 .27027 .58715 .27962 .58442 .27348 .57889 Mtetra
.652 .746 .918 r
.27348 .57889 .27962 .58442 .289 .58174 .28289 .57604 Mtetra
.649 .74 .916 r
.28289 .57604 .289 .58174 .29841 .5791 .29233 .57327 Mtetra
.644 .734 .915 r
.29233 .57327 .29841 .5791 .30785 .57652 .3018 .5706 Mtetra
.636 .73 .916 r
.3018 .5706 .30785 .57652 .31733 .57403 .31129 .5681 Mtetra
.63 .728 .918 r
.31129 .5681 .31733 .57403 .32684 .57153 .32081 .56575 Mtetra
.621 .731 .926 r
.32081 .56575 .32684 .57153 .33639 .56901 .33035 .56356 Mtetra
.62 .744 .935 r
.33035 .56356 .33639 .56901 .34598 .56622 .33994 .56133 Mtetra
.623 .767 .949 r
.33994 .56133 .34598 .56622 .35564 .563 .34958 .55892 Mtetra
.645 .807 .961 r
.34958 .55892 .35564 .563 .36536 .55911 .35928 .55594 Mtetra
.682 .854 .964 r
.35928 .55594 .36536 .55911 .37515 .55431 .36906 .55201 Mtetra
.726 .896 .956 r
.36906 .55201 .37515 .55431 .38499 .54888 .37892 .54695 Mtetra
.779 .912 .931 r
.37892 .54695 .38499 .54888 .39488 .54294 .38886 .54051 Mtetra
.794 .892 .914 r
.38886 .54051 .39488 .54294 .40475 .53764 .39884 .53361 Mtetra
.78 .831 .892 r
.39884 .53361 .40475 .53764 .41461 .53382 .40882 .52692 Mtetra
.695 .722 .87 r
.40882 .52692 .41461 .53382 .42441 .53269 .41873 .5226 Mtetra
.564 .591 .839 r
.41873 .5226 .42441 .53269 .43417 .53501 .42857 .52214 Mtetra
.457 .482 .797 r
.42857 .52214 .43417 .53501 .44396 .53854 .43837 .52501 Mtetra
.347 .407 .781 r
.43837 .52501 .44396 .53854 .45384 .54159 .44818 .53066 Mtetra
.383 .478 .833 r
.44818 .53066 .45384 .54159 .46389 .53972 .45812 .53445 Mtetra
.547 .734 .962 r
.45812 .53445 .46389 .53972 .47408 .53065 .46822 .53332 Mtetra
.741 .987 .779 r
.46822 .53332 .47408 .53065 .48435 .51621 .47849 .52388 Mtetra
.78 .909 .517 r
.47849 .52388 .48435 .51621 .49461 .49915 .48884 .50628 Mtetra
.668 .872 .493 r
.48884 .50628 .49461 .49915 .50476 .49096 .49912 .49175 Mtetra
.66 .972 .883 r
.49912 .49175 .50476 .49096 .51489 .49558 .50933 .48542 Mtetra
.361 .483 .848 r
.50933 .48542 .51489 .49558 .5251 .50704 .51954 .48936 Mtetra
.137 .218 .685 r
.51954 .48936 .5251 .50704 .53545 .52161 .52984 .50246 Mtetra
.216 .257 .69 r
.52984 .50246 .53545 .52161 .54592 .53189 .54029 .51477 Mtetra
.388 .39 .741 r
.54029 .51477 .54592 .53189 .55645 .53469 .55082 .52122 Mtetra
.634 .578 .774 r
.55082 .52122 .55645 .53469 .56698 .53149 .56135 .51799 Mtetra
.773 .645 .721 r
.56135 .51799 .56698 .53149 .57745 .52226 .57179 .50504 Mtetra
.789 .624 .676 r
.57179 .50504 .57745 .52226 .58779 .5055 .5821 .48618 Mtetra
.781 .608 .666 r
.5821 .48618 .58779 .5055 .59798 .48437 .59233 .46646 Mtetra
.716 .58 .702 r
.59233 .46646 .59798 .48437 .60817 .46631 .60272 .45592 Mtetra
.553 .586 .841 r
.60272 .45592 .60817 .46631 .61851 .45512 .61338 .45573 Mtetra
.653 .107 0 r
.61338 .45573 .61851 .45512 .62924 .45685 .62435 .46384 Mtetra
.72 .293 .234 r
.62435 .46384 .62924 .45685 .64037 .46758 .63554 .4751 Mtetra
.542 .096 .142 r
.63554 .4751 .64037 .46758 .65153 .47571 .64657 .47813 Mtetra
.325 .782 .642 r
.64657 .47813 .65153 .47571 .66258 .47842 .65734 .47273 Mtetra
.834 .81 .827 r
.65734 .47273 .66258 .47842 .67338 .47381 .66793 .4623 Mtetra
.789 .679 .743 r
.66793 .4623 .67338 .47381 .68398 .46417 .67842 .44995 Mtetra
.731 .621 .736 r
.67842 .44995 .68398 .46417 .69455 .45401 .68903 .44041 Mtetra
.686 .606 .761 r
.68903 .44041 .69455 .45401 .70518 .44507 .69982 .43426 Mtetra
.614 .613 .826 r
.69982 .43426 .70518 .44507 .71602 .43965 .71087 .43205 Mtetra
.506 .641 .915 r
.71087 .43205 .71602 .43965 .72707 .43699 .72211 .4323 Mtetra
.401 .701 .982 r
.72211 .4323 .72707 .43699 .73826 .43585 .73344 .43276 Mtetra
.335 .736 .982 r
.73344 .43276 .73826 .43585 .74956 .43537 .74481 .43277 Mtetra
.427 .809 .991 r
.74481 .43277 .74956 .43537 .76088 .43438 .75615 .43136 Mtetra
.544 .849 .998 r
.75615 .43136 .76088 .43438 .77222 .43274 .76746 .42878 Mtetra
.634 .844 .981 r
.76746 .42878 .77222 .43274 .78354 .43016 .77875 .42522 Mtetra
.674 .818 .952 r
.77875 .42522 .78354 .43016 .79486 .4269 .79003 .42105 Mtetra
.684 .787 .928 r
.79003 .42105 .79486 .4269 .80618 .42318 .80134 .41671 Mtetra
.685 .766 .912 r
.80134 .41671 .80618 .42318 .81753 .41918 .81268 .41231 Mtetra
.678 .75 .905 r
.81268 .41231 .81753 .41918 .82891 .41514 .82408 .40808 Mtetra
.673 .743 .903 r
.82408 .40808 .82891 .41514 .84034 .41109 .83554 .404 Mtetra
.667 .74 .905 r
.83554 .404 .84034 .41109 .85181 .40714 .84705 .40008 Mtetra
.663 .74 .908 r
.84705 .40008 .85181 .40714 .86334 .40323 .85862 .39628 Mtetra
.66 .743 .912 r
.85862 .39628 .86334 .40323 .87492 .39938 .87025 .39254 Mtetra
.658 .747 .916 r
.87025 .39254 .87492 .39938 .88655 .39556 .88193 .38884 Mtetra
.662 .753 .918 r
.25789 .57635 .2641 .58177 .27348 .57889 .26731 .57325 Mtetra
.662 .746 .912 r
.26731 .57325 .27348 .57889 .28289 .57604 .27675 .57014 Mtetra
.659 .737 .907 r
.27675 .57014 .28289 .57604 .29233 .57327 .28623 .5671 Mtetra
.654 .727 .903 r
.28623 .5671 .29233 .57327 .3018 .5706 .29573 .56418 Mtetra
.646 .717 .899 r
.29573 .56418 .3018 .5706 .31129 .5681 .30525 .56144 Mtetra
.635 .706 .898 r
.30525 .56144 .31129 .5681 .32081 .56575 .3148 .55896 Mtetra
.62 .698 .9 r
.3148 .55896 .32081 .56575 .33035 .56356 .32435 .55685 Mtetra
.607 .697 .907 r
.32435 .55685 .33035 .56356 .33994 .56133 .33393 .55502 Mtetra
.59 .705 .923 r
.33393 .55502 .33994 .56133 .34958 .55892 .34354 .55348 Mtetra
.59 .738 .946 r
.34354 .55348 .34958 .55892 .35928 .55594 .3532 .55176 Mtetra
.6 .793 .973 r
.3532 .55176 .35928 .55594 .36906 .55201 .36293 .54954 Mtetra
.641 .876 .985 r
.36293 .54954 .36906 .55201 .37892 .54695 .37275 .54605 Mtetra
.712 .946 .956 r
.37275 .54605 .37892 .54695 .38886 .54051 .38269 .54066 Mtetra
.771 .978 .914 r
.38269 .54066 .38886 .54051 .39884 .53361 .39272 .53351 Mtetra
.839 .966 .886 r
.39272 .53351 .39884 .53361 .40882 .52692 .40282 .52465 Mtetra
.828 .896 .889 r
.40282 .52465 .40882 .52692 .41873 .5226 .4129 .5164 Mtetra
.744 .756 .863 r
.4129 .5164 .41873 .5226 .42857 .52214 .42293 .5104 Mtetra
.599 .579 .802 r
.42293 .5104 .42857 .52214 .43837 .52501 .43285 .50884 Mtetra
.444 .431 .75 r
.43285 .50884 .43837 .52501 .44818 .53066 .44267 .51296 Mtetra
.359 .362 .727 r
.44267 .51296 .44818 .53066 .45812 .53445 .45251 .52012 Mtetra
.258 .341 .758 r
.45251 .52012 .45812 .53445 .46822 .53332 .46244 .52798 Mtetra
.379 .657 .967 r
.46244 .52798 .46822 .53332 .47849 .52388 .47257 .52906 Mtetra
0 0 0 r
.47257 .52906 .47849 .52388 .48884 .50628 .4829 .5201 Mtetra
.4829 .5201 .48884 .50628 .49912 .49175 .49329 .50488 Mtetra
.49329 .50488 .49912 .49175 .50933 .48542 .50366 .48681 Mtetra
.861 .995 .816 r
.50366 .48681 .50933 .48542 .51954 .48936 .51396 .47566 Mtetra
.597 .552 .775 r
.51396 .47566 .51954 .48936 .52984 .50246 .52424 .47408 Mtetra
.531 .414 .665 r
.52424 .47408 .52984 .50246 .54029 .51477 .53459 .47622 Mtetra
.534 .39 .632 r
.53459 .47622 .54029 .51477 .55082 .52122 .54501 .47878 Mtetra
.585 .42 .625 r
.54501 .47878 .55082 .52122 .56135 .51799 .55545 .47549 Mtetra
.627 .45 .623 r
.55545 .47549 .56135 .51799 .57179 .50504 .56585 .46634 Mtetra
.63 .458 .63 r
.56585 .46634 .57179 .50504 .5821 .48618 .57627 .45758 Mtetra
.617 .471 .661 r
.57627 .45758 .5821 .48618 .59233 .46646 .58676 .45255 Mtetra
.41 .444 .785 r
.58676 .45255 .59233 .46646 .60272 .45592 .5975 .45716 Mtetra
.75 .251 .04 r
.5975 .45716 .60272 .45592 .61338 .45573 .6085 .46879 Mtetra
.655 .279 .322 r
.6085 .46879 .61338 .45573 .62435 .46384 .61957 .47759 Mtetra
.547 .176 .289 r
.61957 .47759 .62435 .46384 .63554 .4751 .63055 .48009 Mtetra
0 0 0 r
.63055 .48009 .63554 .4751 .64657 .47813 .64126 .4724 Mtetra
.881 .806 .772 r
.64126 .4724 .64657 .47813 .65734 .47273 .65171 .45782 Mtetra
.772 .635 .709 r
.65171 .45782 .65734 .47273 .66793 .4623 .66216 .44389 Mtetra
.717 .58 .7 r
.66216 .44389 .66793 .4623 .67842 .44995 .67272 .43304 Mtetra
.651 .554 .732 r
.67272 .43304 .67842 .44995 .68903 .44041 .68355 .42797 Mtetra
.567 .561 .806 r
.68355 .42797 .68903 .44041 .69982 .43426 .69465 .42743 Mtetra
.397 .611 .936 r
.69465 .42743 .69982 .43426 .71087 .43205 .70595 .42921 Mtetra
.057 .562 .883 r
.70595 .42921 .71087 .43205 .72211 .4323 .71736 .43165 Mtetra
0 .574 .756 r
.71736 .43165 .72211 .4323 .73344 .43276 .72875 .43233 Mtetra
.176 .71 .824 r
.72875 .43233 .73344 .43276 .74481 .43277 .7401 .43122 Mtetra
.491 .878 .967 r
.7401 .43122 .74481 .43277 .75615 .43136 .75137 .42815 Mtetra
.66 .886 .98 r
.75137 .42815 .75615 .43136 .76746 .42878 .76259 .42376 Mtetra
.704 .825 .94 r
.76259 .42376 .76746 .42878 .77875 .42522 .77381 .41884 Mtetra
.709 .777 .905 r
.77381 .41884 .77875 .42522 .79003 .42105 .78505 .41373 Mtetra
.695 .742 .887 r
.78505 .41373 .79003 .42105 .80134 .41671 .79635 .40892 Mtetra
.685 .725 .88 r
.79635 .40892 .80134 .41671 .81268 .41231 .80771 .4044 Mtetra
.673 .717 .882 r
.80771 .4044 .81268 .41231 .82408 .40808 .81915 .40024 Mtetra
.664 .716 .887 r
.81915 .40024 .82408 .40808 .83554 .404 .83066 .39636 Mtetra
.658 .721 .895 r
.83066 .39636 .83554 .404 .84705 .40008 .84223 .39266 Mtetra
.654 .726 .902 r
.84223 .39266 .84705 .40008 .85862 .39628 .85386 .38909 Mtetra
.651 .734 .91 r
.85386 .38909 .85862 .39628 .87025 .39254 .86554 .38558 Mtetra
.65 .742 .916 r
.86554 .38558 .87025 .39254 .88193 .38884 .87727 .38207 Mtetra
.669 .754 .915 r
.25164 .57089 .25789 .57635 .26731 .57325 .26109 .56761 Mtetra
.67 .749 .91 r
.26109 .56761 .26731 .57325 .27675 .57014 .27057 .56428 Mtetra
.669 .742 .904 r
.27057 .56428 .27675 .57014 .28623 .5671 .28009 .56095 Mtetra
.666 .732 .899 r
.28009 .56095 .28623 .5671 .29573 .56418 .28963 .55769 Mtetra
.662 .721 .893 r
.28963 .55769 .29573 .56418 .30525 .56144 .2992 .55453 Mtetra
.651 .705 .886 r
.2992 .55453 .30525 .56144 .3148 .55896 .30878 .55162 Mtetra
.636 .688 .882 r
.30878 .55162 .3148 .55896 .32435 .55685 .31838 .54911 Mtetra
.617 .67 .879 r
.31838 .54911 .32435 .55685 .33393 .55502 .32798 .54709 Mtetra
.59 .655 .882 r
.32798 .54709 .33393 .55502 .34354 .55348 .33759 .54575 Mtetra
.572 .654 .892 r
.33759 .54575 .34354 .55348 .3532 .55176 .34722 .54478 Mtetra
.552 .67 .916 r
.34722 .54478 .3532 .55176 .36293 .54954 .35689 .54407 Mtetra
.57 .732 .952 r
.35689 .54407 .36293 .54954 .37275 .54605 .36663 .54266 Mtetra
.618 .834 .983 r
.36663 .54266 .37275 .54605 .38269 .54066 .37649 .53983 Mtetra
.686 .945 .96 r
.37649 .53983 .38269 .54066 .39272 .53351 .38648 .53476 Mtetra
.767 .994 .873 r
.38648 .53476 .39272 .53351 .40282 .52465 .3966 .52678 Mtetra
.805 1 .825 r
.3966 .52678 .40282 .52465 .4129 .5164 .40679 .51713 Mtetra
.866 .979 .85 r
.40679 .51713 .4129 .5164 .42293 .5104 .417 .50676 Mtetra
.799 .851 .889 r
.417 .50676 .42293 .5104 .43285 .50884 .42712 .49936 Mtetra
.617 .631 .843 r
.42712 .49936 .43285 .50884 .44267 .51296 .43711 .49725 Mtetra
.454 .444 .757 r
.43711 .49725 .44267 .51296 .45251 .52012 .447 .5009 Mtetra
.314 .32 .706 r
.447 .5009 .45251 .52012 .46244 .52798 .45687 .50994 Mtetra
.335 .345 .722 r
.45687 .50994 .46244 .52798 .47257 .52906 .46687 .51789 Mtetra
.435 .507 .834 r
.46687 .51789 .47257 .52906 .4829 .5201 .47704 .52066 Mtetra
.698 .98 .898 r
.47704 .52066 .4829 .5201 .49329 .50488 .4874 .51395 Mtetra
.618 .812 .396 r
.4874 .51395 .49329 .50488 .50366 .48681 .49786 .4974 Mtetra
0 0 0 r
.49786 .4974 .50366 .48681 .51396 .47566 .50828 .48022 Mtetra
.809 .968 .656 r
.50828 .48022 .51396 .47566 .52424 .47408 .51864 .46634 Mtetra
.789 .736 .803 r
.51864 .46634 .52424 .47408 .53459 .47622 .52898 .45707 Mtetra
.635 .524 .711 r
.52898 .45707 .53459 .47622 .54501 .47878 .53934 .4526 Mtetra
.603 .469 .672 r
.53934 .4526 .54501 .47878 .55545 .47549 .54975 .44927 Mtetra
.588 .46 .673 r
.54975 .44927 .55545 .47549 .56585 .46634 .5602 .44708 Mtetra
.505 .445 .723 r
.5602 .44708 .56585 .46634 .57627 .45758 .57077 .44972 Mtetra
.005 .329 .814 r
.57077 .44972 .57627 .45758 .58676 .45255 .5815 .45702 Mtetra
.726 .267 .161 r
.5815 .45702 .58676 .45255 .5975 .45716 .59241 .46768 Mtetra
.683 .288 .292 r
.59241 .46768 .5975 .45716 .6085 .46879 .60344 .47776 Mtetra
.456 .03 .14 r
.60344 .47776 .6085 .46879 .61957 .47759 .61432 .47793 Mtetra
.807 .997 .858 r
.61432 .47793 .61957 .47759 .63055 .48009 .62499 .4685 Mtetra
.81 .686 .727 r
.62499 .4685 .63055 .48009 .64126 .4724 .63547 .45378 Mtetra
.761 .603 .682 r
.63547 .45378 .64126 .4724 .65171 .45782 .64589 .43792 Mtetra
.703 .563 .693 r
.64589 .43792 .65171 .45782 .66216 .44389 .65648 .42752 Mtetra
.645 .555 .739 r
.65648 .42752 .66216 .44389 .67272 .43304 .66732 .42295 Mtetra
.508 .575 .858 r
.66732 .42295 .67272 .43304 .68355 .42797 .67845 .4238 Mtetra
.035 .493 .883 r
.67845 .4238 .68355 .42797 .69465 .42743 .68981 .42769 Mtetra
.337 0 0 r
.68981 .42769 .69465 .42743 .70595 .42921 .70123 .43088 Mtetra
.299 0 0 r
.70123 .43088 .70595 .42921 .71736 .43165 .71264 .43238 Mtetra
0 0 0 r
.71264 .43238 .71736 .43165 .72875 .43233 .72395 .43089 Mtetra
.543 .905 .966 r
.72395 .43089 .72875 .43233 .7401 .43122 .73516 .42709 Mtetra
.714 .863 .952 r
.73516 .42709 .7401 .43122 .75137 .42815 .74632 .42182 Mtetra
.735 .786 .894 r
.74632 .42182 .75137 .42815 .76259 .42376 .75746 .41582 Mtetra
.717 .732 .863 r
.75746 .41582 .76259 .42376 .77381 .41884 .76865 .41008 Mtetra
.701 .705 .85 r
.76865 .41008 .77381 .41884 .78505 .41373 .7799 .40472 Mtetra
.682 .692 .853 r
.7799 .40472 .78505 .41373 .79635 .40892 .79124 .40005 Mtetra
.669 .69 .861 r
.79124 .40005 .79635 .40892 .80771 .4044 .80266 .39589 Mtetra
.658 .696 .873 r
.80266 .39589 .80771 .4044 .81915 .40024 .81417 .39213 Mtetra
.65 .704 .886 r
.81417 .39213 .81915 .40024 .83066 .39636 .82574 .38864 Mtetra
.647 .715 .897 r
.82574 .38864 .83066 .39636 .84223 .39266 .83737 .38526 Mtetra
.644 .724 .907 r
.83737 .38526 .84223 .39266 .85386 .38909 .84906 .38194 Mtetra
.643 .733 .914 r
.84906 .38194 .85386 .38909 .86554 .38558 .8608 .37862 Mtetra
.644 .741 .919 r
.8608 .37862 .86554 .38558 .87727 .38207 .87259 .37524 Mtetra
.671 .755 .914 r
.24535 .5654 .25164 .57089 .26109 .56761 .25482 .56205 Mtetra
.674 .754 .911 r
.25482 .56205 .26109 .56761 .27057 .56428 .26434 .5586 Mtetra
.677 .751 .907 r
.26434 .5586 .27057 .56428 .28009 .56095 .27389 .55507 Mtetra
.678 .745 .902 r
.27389 .55507 .28009 .56095 .28963 .55769 .28347 .55148 Mtetra
.679 .735 .893 r
.28347 .55148 .28963 .55769 .2992 .55453 .29309 .54782 Mtetra
.674 .719 .883 r
.29309 .54782 .2992 .55453 .30878 .55162 .30273 .54425 Mtetra
.664 .698 .871 r
.30273 .54425 .30878 .55162 .31838 .54911 .3124 .5409 Mtetra
.645 .669 .859 r
.3124 .5409 .31838 .54911 .32798 .54709 .32206 .53806 Mtetra
.617 .639 .85 r
.32206 .53806 .32798 .54709 .33759 .54575 .33172 .53601 Mtetra
.585 .609 .843 r
.33172 .53601 .33759 .54575 .34722 .54478 .34136 .53486 Mtetra
.542 .586 .848 r
.34136 .53486 .34722 .54478 .35689 .54407 .351 .53484 Mtetra
.515 .59 .867 r
.351 .53484 .35689 .54407 .36663 .54266 .36066 .5353 Mtetra
.484 .63 .917 r
.36066 .5353 .36663 .54266 .37649 .53983 .37038 .53582 Mtetra
.501 .77 .992 r
.37038 .53582 .37649 .53983 .38648 .53476 .38022 .53479 Mtetra
.52 .911 .926 r
.38022 .53479 .38648 .53476 .3966 .52678 .39023 .53099 Mtetra
.469 .849 .625 r
.39023 .53099 .3966 .52678 .40679 .51713 .4004 .52356 Mtetra
.6 .871 .541 r
.4004 .52356 .40679 .51713 .417 .50676 .41072 .512 Mtetra
.753 .956 .651 r
.41072 .512 .417 .50676 .42712 .49936 .42106 .49951 Mtetra
.886 .96 .841 r
.42106 .49951 .42712 .49936 .43711 .49725 .43135 .48832 Mtetra
.723 .686 .814 r
.43135 .48832 .43711 .49725 .447 .5009 .44149 .48213 Mtetra
.537 .466 .723 r
.44149 .48213 .447 .5009 .45687 .50994 .4515 .48315 Mtetra
.43 .35 .665 r
.4515 .48315 .45687 .50994 .46687 .51789 .46145 .49067 Mtetra
.328 .279 .65 r
.46145 .49067 .46687 .51789 .47704 .52066 .47142 .50297 Mtetra
.323 .343 .727 r
.47142 .50297 .47704 .52066 .4874 .51395 .48158 .51107 Mtetra
.385 .77 .99 r
.48158 .51107 .4874 .51395 .49786 .4974 .49194 .51047 Mtetra
.087 0 .063 r
.49194 .51047 .49786 .4974 .50828 .48022 .50241 .50054 Mtetra
.016 0 .15 r
.50241 .50054 .50828 .48022 .51864 .46634 .51292 .48293 Mtetra
0 0 .056 r
.51292 .48293 .51864 .46634 .52898 .45707 .52337 .46628 Mtetra
0 0 0 r
.52337 .46628 .52898 .45707 .53934 .4526 .53379 .45478 Mtetra
.53379 .45478 .53934 .4526 .54975 .44927 .54424 .45143 Mtetra
.557 .012 0 r
.54424 .45143 .54975 .44927 .5602 .44708 .55481 .45627 Mtetra
.691 .286 .275 r
.55481 .45627 .5602 .44708 .57077 .44972 .56554 .4663 Mtetra
.668 .315 .366 r
.56554 .4663 .57077 .44972 .5815 .45702 .57641 .47734 Mtetra
.563 .23 .363 r
.57641 .47734 .5815 .45702 .59241 .46768 .58727 .4807 Mtetra
.288 0 .163 r
.58727 .4807 .59241 .46768 .60344 .47776 .59801 .47465 Mtetra
.913 .872 .784 r
.59801 .47465 .60344 .47776 .61432 .47793 .60855 .4598 Mtetra
.787 .62 .673 r
.60855 .4598 .61432 .47793 .62499 .4685 .61893 .44064 Mtetra
.7 .528 .652 r
.61893 .44064 .62499 .4685 .63547 .45378 .62941 .42629 Mtetra
.646 .494 .663 r
.62941 .42629 .63547 .45378 .64589 .43792 .64008 .41849 Mtetra
.567 .485 .722 r
.64008 .41849 .64589 .43792 .65648 .42752 .65106 .41803 Mtetra
.307 .476 .863 r
.65106 .41803 .65648 .42752 .66732 .42295 .66231 .42269 Mtetra
.505 0 0 r
.66231 .42269 .66732 .42295 .67845 .4238 .67372 .4287 Mtetra
.58 .083 .04 r
.67372 .4287 .67845 .4238 .68981 .42769 .6852 .4338 Mtetra
.434 0 .008 r
.6852 .4338 .68981 .42769 .70123 .43088 .69656 .43468 Mtetra
.094 0 0 r
.69656 .43468 .70123 .43088 .71264 .43238 .70779 .43185 Mtetra
.623 .954 .921 r
.70779 .43185 .71264 .43238 .72395 .43089 .7189 .42616 Mtetra
.781 .853 .905 r
.7189 .42616 .72395 .43089 .73516 .42709 .72993 .41886 Mtetra
.749 .735 .839 r
.72993 .41886 .73516 .42709 .74632 .42182 .74099 .41161 Mtetra
.721 .682 .811 r
.74099 .41161 .74632 .42182 .75746 .41582 .7521 .40484 Mtetra
.692 .655 .809 r
.7521 .40484 .75746 .41582 .76865 .41008 .76332 .39923 Mtetra
.672 .648 .818 r
.76332 .39923 .76865 .41008 .7799 .40472 .77464 .39455 Mtetra
.655 .655 .837 r
.77464 .39455 .7799 .40472 .79124 .40005 .78607 .39068 Mtetra
.643 .668 .859 r
.78607 .39068 .79124 .40005 .80266 .39589 .79759 .38734 Mtetra
.638 .687 .88 r
.79759 .38734 .80266 .39589 .81417 .39213 .80917 .38422 Mtetra
.634 .704 .897 r
.80917 .38422 .81417 .39213 .82574 .38864 .82082 .38121 Mtetra
.636 .72 .909 r
.82082 .38121 .82574 .38864 .83737 .38526 .83251 .37811 Mtetra
.637 .731 .917 r
.83251 .37811 .83737 .38526 .84906 .38194 .84425 .37496 Mtetra
.639 .739 .921 r
.84425 .37496 .84906 .38194 .8608 .37862 .85604 .37172 Mtetra
.642 .743 .923 r
.85604 .37172 .8608 .37862 .87259 .37524 .86786 .36837 Mtetra
.665 .754 .916 r
.23902 .55988 .24535 .5654 .25482 .56205 .2485 .55665 Mtetra
.669 .76 .918 r
.2485 .55665 .25482 .56205 .26434 .5586 .25802 .55332 Mtetra
.674 .766 .92 r
.25802 .55332 .26434 .5586 .27389 .55507 .26759 .54985 Mtetra
.68 .77 .919 r
.26759 .54985 .27389 .55507 .28347 .55148 .2772 .5462 Mtetra
.689 .771 .913 r
.2772 .5462 .28347 .55148 .29309 .54782 .28686 .5423 Mtetra
.693 .764 .906 r
.28686 .5423 .29309 .54782 .30273 .54425 .29655 .53827 Mtetra
.696 .749 .893 r
.29655 .53827 .30273 .54425 .3124 .5409 .30629 .5341 Mtetra
.684 .722 .878 r
.30629 .5341 .3124 .5409 .32206 .53806 .31604 .53016 Mtetra
.665 .686 .86 r
.31604 .53016 .32206 .53806 .33172 .53601 .32579 .52669 Mtetra
.631 .64 .841 r
.32579 .52669 .33172 .53601 .34136 .53486 .33552 .52417 Mtetra
.585 .591 .825 r
.33552 .52417 .34136 .53486 .351 .53484 .34522 .52303 Mtetra
.54 .548 .812 r
.34522 .52303 .351 .53484 .36066 .5353 .35489 .52327 Mtetra
.484 .515 .814 r
.35489 .52327 .36066 .5353 .37038 .53582 .36455 .52501 Mtetra
.466 .53 .839 r
.36455 .52501 .37038 .53582 .38022 .53479 .37426 .52685 Mtetra
.47 .608 .906 r
.37426 .52685 .38022 .53479 .39023 .53099 .38409 .52774 Mtetra
.562 .828 .995 r
.38409 .52774 .39023 .53099 .4004 .52356 .39409 .52554 Mtetra
.632 .962 .828 r
.39409 .52554 .4004 .52356 .41072 .512 .40431 .51871 Mtetra
0 0 0 r
.40431 .51871 .41072 .512 .42106 .49951 .41466 .50799 Mtetra
.568 .811 .428 r
.41466 .50799 .42106 .49951 .43135 .48832 .42511 .49408 Mtetra
.722 .935 .61 r
.42511 .49408 .43135 .48832 .44149 .48213 .4355 .48124 Mtetra
.84 .951 .889 r
.4355 .48124 .44149 .48213 .4515 .48315 .44578 .47232 Mtetra
.598 .599 .823 r
.44578 .47232 .4515 .48315 .46145 .49067 .45591 .4707 Mtetra
.397 .369 .71 r
.45591 .4707 .46145 .49067 .47142 .50297 .46593 .47738 Mtetra
.378 .322 .667 r
.46593 .47738 .47142 .50297 .48158 .51107 .47602 .48684 Mtetra
.389 .337 .678 r
.47602 .48684 .48158 .51107 .49194 .51047 .48623 .49541 Mtetra
.511 .49 .77 r
.48623 .49541 .49194 .51047 .50241 .50054 .49662 .497 Mtetra
.778 .871 .917 r
.49662 .497 .50241 .50054 .51292 .48293 .50712 .49023 Mtetra
0 0 0 r
.50712 .49023 .51292 .48293 .52337 .46628 .51765 .48099 Mtetra
.213 0 .156 r
.51765 .48099 .52337 .46628 .53379 .45478 .52818 .47243 Mtetra
.428 .091 .29 r
.52818 .47243 .53379 .45478 .54424 .45143 .53874 .46908 Mtetra
.538 .193 .331 r
.53874 .46908 .54424 .45143 .55481 .45627 .54937 .47096 Mtetra
.547 .181 .298 r
.54937 .47096 .55481 .45627 .56554 .4663 .56009 .47354 Mtetra
.424 0 .057 r
.56009 .47354 .56554 .4663 .57641 .47734 .57086 .47366 Mtetra
.815 .876 .891 r
.57086 .47366 .57641 .47734 .58727 .4807 .58155 .46535 Mtetra
.781 .636 .7 r
.58155 .46535 .58727 .4807 .59801 .47465 .5921 .44998 Mtetra
.729 .557 .658 r
.5921 .44998 .59801 .47465 .60855 .4598 .60259 .43367 Mtetra
.701 .534 .659 r
.60259 .43367 .60855 .4598 .61893 .44064 .61311 .42013 Mtetra
.638 .52 .704 r
.61311 .42013 .61893 .44064 .62941 .42629 .62386 .41498 Mtetra
.461 .524 .836 r
.62386 .41498 .62941 .42629 .64008 .41849 .6349 .41724 Mtetra
.475 0 0 r
.6349 .41724 .64008 .41849 .65106 .41803 .64617 .42352 Mtetra
.647 .173 .115 r
.64617 .42352 .65106 .41803 .66231 .42269 .65759 .43092 Mtetra
.568 .127 .162 r
.65759 .43092 .66231 .42269 .67372 .4287 .66899 .43511 Mtetra
.409 0 .006 r
.66899 .43511 .67372 .4287 .6852 .4338 .6803 .43534 Mtetra
.318 .795 .714 r
.6803 .43534 .6852 .4338 .69656 .43468 .69144 .43082 Mtetra
.795 .886 .911 r
.69144 .43082 .69656 .43468 .70779 .43185 .70244 .42311 Mtetra
.771 .73 .815 r
.70244 .42311 .70779 .43185 .7189 .42616 .7134 .41442 Mtetra
.74 .663 .775 r
.7134 .41442 .7189 .42616 .72993 .41886 .72437 .40581 Mtetra
.704 .628 .769 r
.72437 .40581 .72993 .41886 .74099 .41161 .73545 .39873 Mtetra
.68 .619 .78 r
.73545 .39873 .74099 .41161 .7521 .40484 .74665 .39305 Mtetra
.657 .625 .806 r
.74665 .39305 .7521 .40484 .76332 .39923 .75799 .38881 Mtetra
.638 .642 .837 r
.75799 .38881 .76332 .39923 .77464 .39455 .76944 .38555 Mtetra
.627 .67 .872 r
.76944 .38555 .77464 .39455 .78607 .39068 .78098 .38277 Mtetra
.617 .697 .901 r
.78098 .38277 .78607 .39068 .79759 .38734 .7926 .38023 Mtetra
.619 .723 .921 r
.7926 .38023 .79759 .38734 .80917 .38422 .80426 .37756 Mtetra
.622 .741 .932 r
.80426 .37756 .80917 .38422 .82082 .38121 .81596 .37474 Mtetra
.63 .753 .936 r
.81596 .37474 .82082 .38121 .83251 .37811 .82769 .37166 Mtetra
.637 .757 .935 r
.82769 .37166 .83251 .37811 .84425 .37496 .83946 .36839 Mtetra
.643 .756 .931 r
.83946 .36839 .84425 .37496 .85604 .37172 .85126 .36497 Mtetra
.647 .753 .927 r
.85126 .36497 .85604 .37172 .86786 .36837 .8631 .36144 Mtetra
.651 .75 .922 r
.23264 .55431 .23902 .55988 .2485 .55665 .24212 .55139 Mtetra
.652 .762 .93 r
.24212 .55139 .2485 .55665 .25802 .55332 .25163 .54841 Mtetra
.658 .777 .937 r
.25163 .54841 .25802 .55332 .26759 .54985 .26119 .54528 Mtetra
.667 .793 .942 r
.26119 .54528 .26759 .54985 .2772 .5462 .27081 .54189 Mtetra
.681 .807 .942 r
.27081 .54189 .2772 .5462 .28686 .5423 .28048 .53816 Mtetra
.697 .817 .939 r
.28048 .53816 .28686 .5423 .29655 .53827 .29021 .53403 Mtetra
.716 .816 .927 r
.29021 .53403 .29655 .53827 .30629 .5341 .3 .52939 Mtetra
.725 .8 .911 r
.3 .52939 .30629 .5341 .31604 .53016 .30984 .52446 Mtetra
.726 .767 .886 r
.30984 .52446 .31604 .53016 .32579 .52669 .31971 .51932 Mtetra
.703 .713 .857 r
.31971 .51932 .32579 .52669 .33552 .52417 .32959 .5146 Mtetra
.666 .65 .825 r
.32959 .5146 .33552 .52417 .34522 .52303 .33944 .51077 Mtetra
.613 .579 .792 r
.33944 .51077 .34522 .52303 .35489 .52327 .34924 .50857 Mtetra
.55 .513 .767 r
.34924 .50857 .35489 .52327 .36455 .52501 .35896 .50867 Mtetra
.497 .463 .75 r
.35896 .50867 .36455 .52501 .37426 .52685 .36865 .51081 Mtetra
.431 .427 .754 r
.36865 .51081 .37426 .52685 .38409 .52774 .37831 .51492 Mtetra
.393 .451 .802 r
.37831 .51492 .38409 .52774 .39409 .52554 .38806 .51892 Mtetra
.32 .58 .935 r
.38806 .51892 .39409 .52554 .40431 .51871 .39796 .52121 Mtetra
0 0 0 r
.39796 .52121 .40431 .51871 .41466 .50799 .40808 .51903 Mtetra
.047 0 0 r
.40808 .51903 .41466 .50799 .42511 .49408 .41845 .51064 Mtetra
.033 0 .088 r
.41845 .51064 .42511 .49408 .4355 .48124 .42895 .4976 Mtetra
0 0 0 r
.42895 .4976 .4355 .48124 .44578 .47232 .43953 .4812 Mtetra
.618 .826 .425 r
.43953 .4812 .44578 .47232 .45591 .4707 .45004 .46564 Mtetra
.851 .806 .806 r
.45004 .46564 .45591 .4707 .46593 .47738 .46043 .45399 Mtetra
.611 .486 .685 r
.46043 .45399 .46593 .47738 .47602 .48684 .47068 .4503 Mtetra
.491 .362 .633 r
.47068 .4503 .47602 .48684 .48623 .49541 .48085 .45584 Mtetra
.432 .314 .619 r
.48085 .45584 .48623 .49541 .49662 .497 .49105 .4666 Mtetra
.344 .279 .639 r
.49105 .4666 .49662 .497 .50712 .49023 .50137 .47952 Mtetra
0 .24 .751 r
.50137 .47952 .50712 .49023 .51765 .48099 .51184 .4891 Mtetra
.553 .116 .164 r
.51184 .4891 .51765 .48099 .52818 .47243 .52245 .49248 Mtetra
.441 .115 .315 r
.52245 .49248 .52818 .47243 .53874 .46908 .53311 .48913 Mtetra
.272 0 .251 r
.53311 .48913 .53874 .46908 .54937 .47096 .54379 .47904 Mtetra
.635 .83 .423 r
.54379 .47904 .54937 .47096 .56009 .47354 .5544 .46269 Mtetra
.852 .706 .699 r
.5544 .46269 .56009 .47354 .57086 .47366 .56493 .44293 Mtetra
.711 .528 .639 r
.56493 .44293 .57086 .47366 .58155 .46535 .57543 .4253 Mtetra
.65 .469 .625 r
.57543 .4253 .58155 .46535 .5921 .44998 .58597 .41289 Mtetra
.584 .428 .636 r
.58597 .41289 .5921 .44998 .60259 .43367 .5967 .40977 Mtetra
.471 .396 .69 r
.5967 .40977 .60259 .43367 .61311 .42013 .60768 .41473 Mtetra
0 .145 .639 r
.60768 .41473 .61311 .42013 .62386 .41498 .61888 .42368 Mtetra
.684 .263 .24 r
.61888 .42368 .62386 .41498 .6349 .41724 .63023 .43353 Mtetra
.607 .245 .33 r
.63023 .43353 .6349 .41724 .64617 .42352 .6416 .44001 Mtetra
.529 .172 .306 r
.6416 .44001 .64617 .42352 .65759 .43092 .65289 .44178 Mtetra
.298 0 .112 r
.65289 .44178 .65759 .43092 .66899 .43511 .664 .4372 Mtetra
.657 .957 .745 r
.664 .4372 .66899 .43511 .6803 .43534 .67493 .42805 Mtetra
.823 .777 .809 r
.67493 .42805 .6803 .43534 .69144 .43082 .68578 .41712 Mtetra
.755 .644 .738 r
.68578 .41712 .69144 .43082 .70244 .42311 .69661 .40605 Mtetra
.705 .586 .72 r
.69661 .40605 .70244 .42311 .7134 .41442 .70755 .39697 Mtetra
.675 .567 .726 r
.70755 .39697 .7134 .41442 .72437 .40581 .71863 .38999 Mtetra
.646 .566 .75 r
.71863 .38999 .72437 .40581 .73545 .39873 .72987 .38537 Mtetra
.622 .583 .789 r
.72987 .38537 .73545 .39873 .74665 .39305 .74127 .38242 Mtetra
.603 .62 .842 r
.74127 .38242 .74665 .39305 .75799 .38881 .75278 .3804 Mtetra
.583 .666 .895 r
.75278 .3804 .75799 .38881 .76944 .38555 .76439 .37882 Mtetra
.579 .719 .939 r
.76439 .37882 .76944 .38555 .78098 .38277 .77604 .37703 Mtetra
.579 .757 .963 r
.77604 .37703 .78098 .38277 .7926 .38023 .78773 .37493 Mtetra
.597 .784 .97 r
.78773 .37493 .7926 .38023 .80426 .37756 .79943 .37231 Mtetra
.616 .795 .968 r
.79943 .37231 .80426 .37756 .81596 .37474 .81116 .36927 Mtetra
.635 .795 .959 r
.81116 .36927 .81596 .37474 .82769 .37166 .8229 .36586 Mtetra
.648 .788 .949 r
.8229 .36586 .82769 .37166 .83946 .36839 .83466 .3622 Mtetra
.656 .778 .938 r
.83466 .3622 .83946 .36839 .85126 .36497 .84646 .35836 Mtetra
.659 .765 .928 r
.84646 .35836 .85126 .36497 .8631 .36144 .85831 .35446 Mtetra
.635 .746 .928 r
.22623 .54871 .23264 .55431 .24212 .55139 .23569 .54612 Mtetra
.633 .758 .938 r
.23569 .54612 .24212 .55139 .25163 .54841 .24519 .54353 Mtetra
.634 .774 .948 r
.24519 .54353 .25163 .54841 .26119 .54528 .25474 .54086 Mtetra
.639 .795 .957 r
.25474 .54086 .26119 .54528 .27081 .54189 .26433 .538 Mtetra
.648 .818 .965 r
.26433 .538 .27081 .54189 .28048 .53816 .27399 .53485 Mtetra
.664 .846 .97 r
.27399 .53485 .28048 .53816 .29021 .53403 .28371 .53126 Mtetra
.69 .873 .967 r
.28371 .53126 .29021 .53403 .3 .52939 .2935 .52703 Mtetra
.717 .892 .96 r
.2935 .52703 .3 .52939 .30984 .52446 .30337 .52213 Mtetra
.751 .896 .943 r
.30337 .52213 .30984 .52446 .31971 .51932 .31332 .51643 Mtetra
.765 .875 .927 r
.31332 .51643 .31971 .51932 .32959 .5146 .3233 .51037 Mtetra
.764 .825 .9 r
.3233 .51037 .32959 .5146 .33944 .51077 .33332 .50417 Mtetra
.724 .743 .867 r
.33332 .50417 .33944 .51077 .34924 .50857 .34331 .49883 Mtetra
.661 .646 .825 r
.34331 .49883 .34924 .50857 .35896 .50867 .35323 .49513 Mtetra
.586 .548 .779 r
.35323 .49513 .35896 .50867 .36865 .51081 .36307 .49386 Mtetra
.505 .463 .743 r
.36307 .49386 .36865 .51081 .37831 .51492 .37281 .49576 Mtetra
.452 .41 .721 r
.37281 .49576 .37831 .51492 .38806 .51892 .38252 .49998 Mtetra
.399 .379 .72 r
.38252 .49998 .38806 .51892 .39796 .52121 .39225 .50589 Mtetra
.412 .427 .765 r
.39225 .50589 .39796 .52121 .40808 .51903 .40212 .51029 Mtetra
.495 .601 .888 r
.40212 .51029 .40808 .51903 .41845 .51064 .41221 .5109 Mtetra
.567 .934 .916 r
.41221 .5109 .41845 .51064 .42895 .4976 .42252 .50621 Mtetra
0 0 0 r
.42252 .50621 .42895 .4976 .43953 .4812 .43303 .49541 Mtetra
.43303 .49541 .43953 .4812 .45004 .46564 .44363 .48063 Mtetra
.44363 .48063 .45004 .46564 .46043 .45399 .45423 .46411 Mtetra
.45423 .46411 .46043 .45399 .47068 .4503 .46472 .45196 Mtetra
.444 .875 .787 r
.46472 .45196 .47068 .4503 .48085 .45584 .47507 .44702 Mtetra
.424 .562 .889 r
.47507 .44702 .48085 .45584 .49105 .4666 .48538 .44898 Mtetra
.341 .356 .731 r
.48538 .44898 .49105 .4666 .50137 .47952 .4957 .4564 Mtetra
.421 .366 .691 r
.4957 .4564 .50137 .47952 .51184 .4891 .50614 .46313 Mtetra
.511 .411 .678 r
.50614 .46313 .51184 .4891 .52245 .49248 .5167 .46596 Mtetra
.6 .468 .673 r
.5167 .46596 .52245 .49248 .53311 .48913 .52733 .46256 Mtetra
.666 .511 .664 r
.52733 .46256 .53311 .48913 .54379 .47904 .53797 .45294 Mtetra
.702 .535 .659 r
.53797 .45294 .54379 .47904 .5544 .46269 .54859 .43937 Mtetra
.72 .557 .667 r
.54859 .43937 .5544 .46269 .56493 .44293 .55918 .42507 Mtetra
.697 .573 .711 r
.55918 .42507 .56493 .44293 .57543 .4253 .56981 .41624 Mtetra
.601 .648 .868 r
.56981 .41624 .57543 .4253 .58597 .41289 .58057 .41435 Mtetra
.552 0 0 r
.58057 .41435 .58597 .41289 .5967 .40977 .59153 .41976 Mtetra
.679 .272 .268 r
.59153 .41976 .5967 .40977 .60768 .41473 .6027 .42963 Mtetra
.634 .263 .323 r
.6027 .42963 .60768 .41473 .61888 .42368 .61396 .43779 Mtetra
.571 .194 .287 r
.61396 .43779 .61888 .42368 .63023 .43353 .62521 .44194 Mtetra
.344 0 .05 r
.62521 .44194 .63023 .43353 .6416 .44001 .63635 .43988 Mtetra
.72 .984 .897 r
.63635 .43988 .6416 .44001 .65289 .44178 .64734 .43242 Mtetra
.803 .725 .779 r
.64734 .43242 .65289 .44178 .664 .4372 .65819 .42107 Mtetra
.755 .62 .71 r
.65819 .42107 .664 .4372 .67493 .42805 .66896 .40814 Mtetra
.712 .57 .694 r
.66896 .40814 .67493 .42805 .68578 .41712 .67979 .39691 Mtetra
.684 .553 .699 r
.67979 .39691 .68578 .41712 .69661 .40605 .69074 .38805 Mtetra
.653 .55 .726 r
.69074 .38805 .69661 .40605 .70755 .39697 .70187 .38242 Mtetra
.622 .567 .772 r
.70187 .38242 .70755 .39697 .71863 .38999 .71318 .37929 Mtetra
.585 .61 .844 r
.71318 .37929 .71863 .38999 .72987 .38537 .72464 .37785 Mtetra
.53 .668 .925 r
.72464 .37785 .72987 .38537 .74127 .38242 .73623 .3773 Mtetra
.482 .737 .983 r
.73623 .3773 .74127 .38242 .75278 .3804 .74787 .37663 Mtetra
.45 .779 .998 r
.74787 .37663 .75278 .3804 .76439 .37882 .75956 .37558 Mtetra
.484 .819 .999 r
.75956 .37558 .76439 .37882 .77604 .37703 .77125 .37371 Mtetra
.536 .842 .999 r
.77125 .37371 .77604 .37703 .78773 .37493 .78295 .37115 Mtetra
.594 .848 .993 r
.78295 .37115 .78773 .37493 .79943 .37231 .79464 .36792 Mtetra
.633 .84 .98 r
.79464 .36792 .79943 .37231 .81116 .36927 .80635 .36422 Mtetra
.655 .822 .963 r
.80635 .36422 .81116 .36927 .8229 .36586 .81808 .36023 Mtetra
.668 .804 .948 r
.81808 .36023 .8229 .36586 .83466 .3622 .82984 .35603 Mtetra
.673 .787 .935 r
.82984 .35603 .83466 .3622 .84646 .35836 .84163 .35172 Mtetra
.672 .771 .924 r
.84163 .35172 .84646 .35836 .85831 .35446 .85348 .34743 Mtetra
.624 .743 .932 r
.21976 .54307 .22623 .54871 .23569 .54612 .22923 .54069 Mtetra
.617 .75 .941 r
.22923 .54069 .23569 .54612 .24519 .54353 .23872 .53841 Mtetra
.612 .76 .95 r
.23872 .53841 .24519 .54353 .25474 .54086 .24825 .53616 Mtetra
.608 .776 .961 r
.24825 .53616 .25474 .54086 .26433 .538 .25782 .53388 Mtetra
.6 .799 .976 r
.25782 .53388 .26433 .538 .27399 .53485 .26744 .53157 Mtetra
.599 .834 .988 r
.26744 .53157 .27399 .53485 .28371 .53126 .27711 .52898 Mtetra
.599 .874 .993 r
.27711 .52898 .28371 .53126 .2935 .52703 .28685 .52595 Mtetra
.607 .916 .977 r
.28685 .52595 .2935 .52703 .30337 .52213 .29668 .52216 Mtetra
.632 .95 .943 r
.29668 .52216 .30337 .52213 .31332 .51643 .30662 .51731 Mtetra
.669 .971 .906 r
.30662 .51731 .31332 .51643 .3233 .51037 .31664 .51134 Mtetra
.748 .987 .896 r
.31664 .51134 .3233 .51037 .33332 .50417 .32677 .50405 Mtetra
.807 .968 .906 r
.32677 .50405 .33332 .50417 .34331 .49883 .33694 .49612 Mtetra
.821 .88 .888 r
.33694 .49612 .34331 .49883 .35323 .49513 .34714 .48796 Mtetra
.756 .736 .834 r
.34714 .48796 .35323 .49513 .36307 .49386 .35729 .48093 Mtetra
.667 .599 .769 r
.35729 .48093 .36307 .49386 .37281 .49576 .36734 .47612 Mtetra
.585 .49 .713 r
.36734 .47612 .37281 .49576 .38252 .49998 .37728 .47449 Mtetra
.514 .412 .676 r
.37728 .47449 .38252 .49998 .39225 .50589 .3871 .47687 Mtetra
.463 .363 .656 r
.3871 .47687 .39225 .50589 .40212 .51029 .39686 .4826 Mtetra
.403 .328 .657 r
.39686 .4826 .40212 .51029 .41221 .5109 .40662 .49106 Mtetra
.343 .336 .707 r
.40662 .49106 .41221 .5109 .42252 .50621 .4165 .499 Mtetra
.084 .419 .866 r
.4165 .499 .42252 .50621 .43303 .49541 .42658 .50409 Mtetra
.46 .025 .125 r
.42658 .50409 .43303 .49541 .44363 .48063 .43686 .50465 Mtetra
.416 .107 .331 r
.43686 .50465 .44363 .48063 .45423 .46411 .44735 .49933 Mtetra
.37 .101 .37 r
.44735 .49933 .45423 .46411 .46472 .45196 .45799 .48765 Mtetra
.277 .025 .34 r
.45799 .48765 .46472 .45196 .47507 .44702 .46872 .47027 Mtetra
.006 0 .16 r
.46872 .47027 .47507 .44702 .48538 .44898 .47943 .45069 Mtetra
.961 .933 .714 r
.47943 .45069 .48538 .44898 .4957 .4564 .49007 .43158 Mtetra
.719 .549 .659 r
.49007 .43158 .4957 .4564 .50614 .46313 .50062 .41652 Mtetra
.618 .436 .614 r
.50062 .41652 .50614 .46313 .5167 .46596 .51111 .40726 Mtetra
.571 .39 .598 r
.51111 .40726 .5167 .46596 .52733 .46256 .5216 .4038 Mtetra
.534 .363 .596 r
.5216 .4038 .52733 .46256 .53797 .45294 .53214 .40615 Mtetra
.477 .336 .609 r
.53214 .40615 .53797 .45294 .54859 .43937 .54279 .41435 Mtetra
.304 .278 .664 r
.54279 .41435 .54859 .43937 .55918 .42507 .5536 .42666 Mtetra
.767 .281 .078 r
.5536 .42666 .55918 .42507 .56981 .41624 .56456 .4395 Mtetra
.639 .308 .395 r
.56456 .4395 .56981 .41624 .58057 .41435 .57564 .45019 Mtetra
.568 .273 .428 r
.57564 .45019 .58057 .41435 .59153 .41976 .58674 .45515 Mtetra
.507 .22 .412 r
.58674 .45515 .59153 .41976 .6027 .42963 .59781 .4537 Mtetra
.384 .082 .324 r
.59781 .4537 .6027 .42963 .61396 .43779 .60878 .44628 Mtetra
0 0 0 r
.60878 .44628 .61396 .43779 .62521 .44194 .61963 .43424 Mtetra
.861 .768 .758 r
.61963 .43424 .62521 .44194 .63635 .43988 .63038 .41927 Mtetra
.747 .586 .677 r
.63038 .41927 .63635 .43988 .64734 .43242 .64107 .40372 Mtetra
.685 .516 .652 r
.64107 .40372 .64734 .43242 .65819 .42107 .65183 .39092 Mtetra
.651 .49 .652 r
.65183 .39092 .65819 .42107 .66896 .40814 .66271 .38153 Mtetra
.62 .482 .672 r
.66271 .38153 .66896 .40814 .67979 .39691 .67379 .37622 Mtetra
.589 .492 .713 r
.67379 .37622 .67979 .39691 .69074 .38805 .68507 .37416 Mtetra
.541 .531 .793 r
.68507 .37416 .69074 .38805 .70187 .38242 .69652 .3744 Mtetra
.438 .604 .916 r
.69652 .3744 .70187 .38242 .71318 .37929 .70812 .37582 Mtetra
.231 .664 .957 r
.70812 .37582 .71318 .37929 .72464 .37785 .71978 .37702 Mtetra
.033 .599 .784 r
.71978 .37702 .72464 .37785 .73623 .3773 .73149 .37756 Mtetra
.056 .622 .715 r
.73149 .37756 .73623 .3773 .74787 .37663 .74318 .37676 Mtetra
.192 .723 .783 r
.74318 .37676 .74787 .37663 .75956 .37558 .75486 .37479 Mtetra
.398 .849 .909 r
.75486 .37479 .75956 .37558 .77125 .37371 .76652 .37173 Mtetra
.555 .901 .977 r
.76652 .37173 .77125 .37371 .78295 .37115 .77816 .36787 Mtetra
.639 .888 .986 r
.77816 .36787 .78295 .37115 .79464 .36792 .78982 .36355 Mtetra
.675 .857 .969 r
.78982 .36355 .79464 .36792 .80635 .36422 .80149 .35894 Mtetra
.684 .824 .951 r
.80149 .35894 .80635 .36422 .81808 .36023 .8132 .35427 Mtetra
.686 .801 .936 r
.8132 .35427 .81808 .36023 .82984 .35603 .82496 .34958 Mtetra
.685 .783 .925 r
.82496 .34958 .82984 .35603 .84163 .35172 .83676 .34492 Mtetra
.681 .77 .918 r
.83676 .34492 .84163 .35172 .85348 .34743 .84861 .34035 Mtetra
.629 .745 .931 r
.21326 .53739 .21976 .54307 .22923 .54069 .22275 .53489 Mtetra
.623 .739 .93 r
.22275 .53489 .22923 .54069 .23872 .53841 .23227 .53251 Mtetra
.616 .734 .931 r
.23227 .53251 .23872 .53841 .24825 .53616 .24181 .53028 Mtetra
.607 .733 .934 r
.24181 .53028 .24825 .53616 .25782 .53388 .25139 .52821 Mtetra
.592 .737 .944 r
.25139 .52821 .25782 .53388 .26744 .53157 .26098 .52637 Mtetra
.583 .752 .958 r
.26098 .52637 .26744 .53157 .27711 .52898 .27061 .52458 Mtetra
.569 .78 .978 r
.27061 .52458 .27711 .52898 .28685 .52595 .28029 .52277 Mtetra
.563 .83 .996 r
.28029 .52277 .28685 .52595 .29668 .52216 .29004 .52055 Mtetra
.553 .885 .988 r
.29004 .52055 .29668 .52216 .30662 .51731 .29988 .51763 Mtetra
.534 .919 .92 r
.29988 .51763 .30662 .51731 .31664 .51134 .30983 .51355 Mtetra
.527 .917 .805 r
.30983 .51355 .31664 .51134 .32677 .50405 .31991 .50789 Mtetra
.522 .893 .694 r
.31991 .50789 .32677 .50405 .33694 .49612 .3301 .50067 Mtetra
.603 .92 .676 r
.3301 .50067 .33694 .49612 .34714 .48796 .3404 .49178 Mtetra
.707 .971 .744 r
.3404 .49178 .34714 .48796 .35729 .48093 .35074 .48225 Mtetra
.825 .994 .859 r
.35074 .48225 .35729 .48093 .36734 .47612 .36107 .47279 Mtetra
.807 .865 .891 r
.36107 .47279 .36734 .47612 .37728 .47449 .37132 .46503 Mtetra
.688 .667 .824 r
.37132 .46503 .37728 .47449 .3871 .47687 .38146 .46023 Mtetra
.57 .506 .744 r
.38146 .46023 .3871 .47687 .39686 .4826 .39145 .45946 Mtetra
.476 .399 .69 r
.39145 .45946 .39686 .4826 .40662 .49106 .40133 .4634 Mtetra
.437 .351 .661 r
.40133 .4634 .40662 .49106 .4165 .499 .41119 .47015 Mtetra
.416 .332 .654 r
.41119 .47015 .4165 .499 .42658 .50409 .42111 .4783 Mtetra
.423 .352 .672 r
.42111 .4783 .42658 .50409 .43686 .50465 .43117 .4853 Mtetra
.468 .423 .724 r
.43117 .4853 .43686 .50465 .44735 .49933 .44141 .48894 Mtetra
.63 .63 .832 r
.44141 .48894 .44735 .49933 .45799 .48765 .45189 .48612 Mtetra
.861 .932 .87 r
.45189 .48612 .45799 .48765 .46872 .47027 .46255 .47596 Mtetra
.767 .946 .614 r
.46255 .47596 .46872 .47027 .47943 .45069 .47327 .46161 Mtetra
0 0 0 r
.47327 .46161 .47943 .45069 .49007 .43158 .48398 .44557 Mtetra
.48398 .44557 .49007 .43158 .50062 .41652 .49463 .43222 Mtetra
.222 0 .165 r
.49463 .43222 .50062 .41652 .51111 .40726 .50522 .42366 Mtetra
.405 .055 .255 r
.50522 .42366 .51111 .40726 .5216 .4038 .51581 .4202 Mtetra
.525 .168 .303 r
.51581 .4202 .5216 .4038 .53214 .40615 .52644 .42184 Mtetra
.609 .245 .326 r
.52644 .42184 .53214 .40615 .54279 .41435 .53717 .4283 Mtetra
.653 .277 .321 r
.53717 .4283 .54279 .41435 .5536 .42666 .54802 .43751 Mtetra
.638 .235 .263 r
.54802 .43751 .5536 .42666 .56456 .4395 .55898 .44507 Mtetra
.525 .034 .034 r
.55898 .44507 .56456 .4395 .57564 .45019 .57 .44843 Mtetra
.594 .911 .979 r
.57 .44843 .57564 .45019 .58674 .45515 .58098 .44439 Mtetra
.776 .691 .769 r
.58098 .44439 .58674 .45515 .59781 .4537 .59187 .4338 Mtetra
.738 .585 .685 r
.59187 .4338 .59781 .4537 .60878 .44628 .60268 .41977 Mtetra
.713 .541 .655 r
.60268 .41977 .60878 .44628 .61963 .43424 .61342 .40453 Mtetra
.689 .516 .648 r
.61342 .40453 .61963 .43424 .63038 .41927 .62417 .39069 Mtetra
.67 .507 .655 r
.62417 .39069 .63038 .41927 .64107 .40372 .63498 .37967 Mtetra
.638 .503 .683 r
.63498 .37967 .64107 .40372 .65183 .39092 .64598 .37343 Mtetra
.594 .52 .741 r
.64598 .37343 .65183 .39092 .66271 .38153 .65717 .37132 Mtetra
.495 .574 .864 r
.65717 .37132 .66271 .38153 .67379 .37622 .66855 .37225 Mtetra
.122 .572 .921 r
.66855 .37225 .67379 .37622 .68507 .37416 .68009 .37492 Mtetra
.327 0 0 r
.68009 .37492 .68507 .37416 .69652 .3744 .69173 .3777 Mtetra
.406 0 0 r
.69173 .3777 .69652 .3744 .70812 .37582 .70343 .37984 Mtetra
.332 0 0 r
.70343 .37984 .70812 .37582 .71978 .37702 .71512 .38027 Mtetra
.18 0 0 r
.71512 .38027 .71978 .37702 .73149 .37756 .72678 .3791 Mtetra
0 0 0 r
.72678 .3791 .73149 .37756 .74318 .37676 .7384 .37629 Mtetra
.454 .883 .899 r
.7384 .37629 .74318 .37676 .75486 .37479 .74999 .37229 Mtetra
.639 .916 .979 r
.74999 .37229 .75486 .37479 .76652 .37173 .76157 .36755 Mtetra
.698 .871 .963 r
.76157 .36755 .76652 .37173 .77816 .36787 .77316 .36237 Mtetra
.705 .822 .938 r
.77316 .36237 .77816 .36787 .78982 .36355 .78478 .35717 Mtetra
.703 .79 .919 r
.78478 .35717 .78982 .36355 .80149 .35894 .79645 .35201 Mtetra
.693 .77 .91 r
.79645 .35201 .80149 .35894 .8132 .35427 .80818 .34708 Mtetra
.687 .76 .907 r
.80818 .34708 .8132 .35427 .82496 .34958 .81996 .34232 Mtetra
.682 .756 .908 r
.81996 .34232 .82496 .34958 .83676 .34492 .8318 .3377 Mtetra
.677 .757 .911 r
.8318 .3377 .83676 .34492 .84861 .34035 .8437 .33321 Mtetra
.649 .75 .923 r
.20671 .53168 .21326 .53739 .22275 .53489 .21626 .52872 Mtetra
.645 .734 .914 r
.21626 .52872 .22275 .53489 .23227 .53251 .22584 .52586 Mtetra
.637 .716 .905 r
.22584 .52586 .23227 .53251 .24181 .53028 .23543 .52321 Mtetra
.624 .7 .899 r
.23543 .52321 .24181 .53028 .25139 .52821 .24504 .52085 Mtetra
.606 .685 .898 r
.24504 .52085 .25139 .52821 .26098 .52637 .25466 .51891 Mtetra
.588 .676 .901 r
.25466 .51891 .26098 .52637 .27061 .52458 .26428 .51738 Mtetra
.561 .675 .915 r
.26428 .51738 .27061 .52458 .28029 .52277 .27392 .51635 Mtetra
.538 .693 .939 r
.27392 .51635 .28029 .52277 .29004 .52055 .28358 .51554 Mtetra
.498 .733 .977 r
.28358 .51554 .29004 .52055 .29988 .51763 .29329 .51486 Mtetra
.436 .798 .996 r
.29329 .51486 .29988 .51763 .30983 .51355 .30307 .51372 Mtetra
.284 .784 .85 r
.30307 .51372 .30983 .51355 .31991 .50789 .31296 .5117 Mtetra
0 0 0 r
.31296 .5117 .31991 .50789 .3301 .50067 .32299 .50816 Mtetra
.002 0 0 r
.32299 .50816 .3301 .50067 .3404 .49178 .33318 .50249 Mtetra
.025 0 0 r
.33318 .50249 .3404 .49178 .35074 .48225 .34351 .49464 Mtetra
0 0 0 r
.34351 .49464 .35074 .48225 .36107 .47279 .35397 .48444 Mtetra
.35397 .48444 .36107 .47279 .37132 .46503 .36449 .47287 Mtetra
.544 .821 .469 r
.36449 .47287 .37132 .46503 .38146 .46023 .37503 .46064 Mtetra
.887 .964 .838 r
.37503 .46064 .38146 .46023 .39145 .45946 .38552 .44916 Mtetra
.764 .68 .77 r
.38552 .44916 .39145 .45946 .40133 .4634 .39593 .4396 Mtetra
.64 .503 .679 r
.39593 .4396 .40133 .4634 .41119 .47015 .40621 .4334 Mtetra
.57 .416 .633 r
.40621 .4334 .41119 .47015 .42111 .4783 .41637 .43151 Mtetra
.533 .373 .61 r
.41637 .43151 .42111 .4783 .43117 .4853 .42646 .43327 Mtetra
.505 .347 .6 r
.42646 .43327 .43117 .4853 .44141 .48894 .43654 .43848 Mtetra
.475 .327 .6 r
.43654 .43848 .44141 .48894 .45189 .48612 .44663 .44681 Mtetra
.418 .304 .617 r
.44663 .44681 .45189 .48612 .46255 .47596 .45678 .45772 Mtetra
.114 .203 .679 r
.45678 .45772 .46255 .47596 .47327 .46161 .46704 .47056 Mtetra
.731 .33 .291 r
.46704 .47056 .47327 .46161 .48398 .44557 .47743 .4837 Mtetra
.602 .307 .441 r
.47743 .4837 .48398 .44557 .49463 .43222 .48801 .49329 Mtetra
.551 .285 .465 r
.48801 .49329 .49463 .43222 .50522 .42366 .49876 .49712 Mtetra
.513 .26 .468 r
.49876 .49712 .50522 .42366 .51581 .4202 .50963 .4937 Mtetra
.472 .226 .459 r
.50963 .4937 .51581 .4202 .52644 .42184 .52056 .48302 Mtetra
.413 .17 .433 r
.52056 .48302 .52644 .42184 .53717 .4283 .53147 .46651 Mtetra
.26 .018 .343 r
.53147 .46651 .53717 .4283 .54802 .43751 .54232 .44639 Mtetra
.727 .858 .432 r
.54232 .44639 .54802 .43751 .55898 .44507 .55311 .42651 Mtetra
.778 .614 .677 r
.55311 .42651 .55898 .44507 .57 .44843 .56385 .40852 Mtetra
.668 .481 .622 r
.56385 .40852 .57 .44843 .58098 .44439 .57457 .39309 Mtetra
.628 .438 .606 r
.57457 .39309 .58098 .44439 .59187 .4338 .58532 .38079 Mtetra
.606 .42 .604 r
.58532 .38079 .59187 .4338 .60268 .41977 .59612 .37195 Mtetra
.587 .412 .612 r
.59612 .37195 .60268 .41977 .61342 .40453 .60703 .36681 Mtetra
.558 .408 .634 r
.60703 .36681 .61342 .40453 .62417 .39069 .6181 .36604 Mtetra
.509 .418 .688 r
.6181 .36604 .62417 .39069 .63498 .37967 .62935 .36871 Mtetra
.333 .464 .843 r
.62935 .36871 .63498 .37967 .64598 .37343 .64076 .37337 Mtetra
.472 0 0 r
.64076 .37337 .64598 .37343 .65717 .37132 .6523 .37882 Mtetra
.573 .113 .124 r
.6523 .37882 .65717 .37132 .66855 .37225 .66392 .38363 Mtetra
.546 .136 .215 r
.66392 .38363 .66855 .37225 .68009 .37492 .67559 .38705 Mtetra
.491 .09 .207 r
.67559 .38705 .68009 .37492 .69173 .3777 .68723 .38809 Mtetra
.408 0 .131 r
.68723 .38809 .69173 .3777 .70343 .37984 .69884 .38688 Mtetra
.228 0 0 r
.69884 .38688 .70343 .37984 .71512 .38027 .71038 .38348 Mtetra
0 0 0 r
.71038 .38348 .71512 .38027 .72678 .3791 .72187 .37851 Mtetra
.615 .953 .916 r
.72187 .37851 .72678 .3791 .7384 .37629 .73335 .37261 Mtetra
.742 .9 .949 r
.73335 .37261 .7384 .37629 .74999 .37229 .74482 .36624 Mtetra
.739 .812 .909 r
.74482 .36624 .74999 .37229 .76157 .36755 .75633 .35997 Mtetra
.723 .759 .881 r
.75633 .35997 .76157 .36755 .77316 .36237 .76789 .35394 Mtetra
.704 .728 .869 r
.76789 .35394 .77316 .36237 .78478 .35717 .77952 .34841 Mtetra
.691 .715 .868 r
.77952 .34841 .78478 .35717 .79645 .35201 .79123 .3433 Mtetra
.678 .712 .874 r
.79123 .3433 .79645 .35201 .80818 .34708 .80301 .33862 Mtetra
.67 .716 .883 r
.80301 .33862 .80818 .34708 .81996 .34232 .81486 .33425 Mtetra
.665 .726 .895 r
.81486 .33425 .81996 .34232 .8318 .3377 .82678 .33008 Mtetra
.661 .739 .908 r
.82678 .33008 .8318 .3377 .8437 .33321 .83876 .32602 Mtetra
.674 .756 .912 r
.20012 .52592 .20671 .53168 .21626 .52872 .20974 .52234 Mtetra
.671 .735 .898 r
.20974 .52234 .21626 .52872 .22584 .52586 .2194 .51877 Mtetra
.664 .712 .884 r
.2194 .51877 .22584 .52586 .23543 .52321 .22908 .51536 Mtetra
.652 .688 .871 r
.22908 .51536 .23543 .52321 .24504 .52085 .23877 .51222 Mtetra
.636 .663 .859 r
.23877 .51222 .24504 .52085 .25466 .51891 .24846 .50947 Mtetra
.617 .636 .848 r
.24846 .50947 .25466 .51891 .26428 .51738 .25815 .50726 Mtetra
.592 .611 .84 r
.25815 .50726 .26428 .51738 .27392 .51635 .26782 .50574 Mtetra
.568 .59 .836 r
.26782 .50574 .27392 .51635 .28358 .51554 .27749 .5049 Mtetra
.538 .576 .841 r
.27749 .5049 .28358 .51554 .29329 .51486 .28715 .50482 Mtetra
.517 .58 .857 r
.28715 .50482 .29329 .51486 .30307 .51372 .29684 .50513 Mtetra
.491 .606 .894 r
.29684 .50513 .30307 .51372 .31296 .5117 .30658 .50563 Mtetra
.477 .685 .958 r
.30658 .50563 .31296 .5117 .32299 .50816 .31641 .50556 Mtetra
.429 .804 .993 r
.31641 .50556 .32299 .50816 .33318 .50249 .32637 .50432 Mtetra
.246 .752 .716 r
.32637 .50432 .33318 .50249 .34351 .49464 .33649 .50116 Mtetra
0 0 0 r
.33649 .50116 .34351 .49464 .35397 .48444 .34678 .49539 Mtetra
.008 0 0 r
.34678 .49539 .35397 .48444 .36449 .47287 .35723 .48709 Mtetra
.008 0 .009 r
.35723 .48709 .36449 .47287 .37503 .46064 .36781 .47622 Mtetra
0 0 .022 r
.36781 .47622 .37503 .46064 .38552 .44916 .37846 .46363 Mtetra
0 0 0 r
.37846 .46363 .38552 .44916 .39593 .4396 .38913 .45011 Mtetra
.38913 .45011 .39593 .4396 .40621 .4334 .39972 .43791 Mtetra
.604 .914 .657 r
.39972 .43791 .40621 .4334 .41637 .43151 .4102 .42851 Mtetra
.76 .889 .936 r
.4102 .42851 .41637 .43151 .42646 .43327 .42057 .42232 Mtetra
.612 .61 .824 r
.42057 .42232 .42646 .43327 .43654 .43848 .43086 .42004 Mtetra
.485 .441 .732 r
.43086 .42004 .43654 .43848 .44663 .44681 .44106 .42271 Mtetra
.397 .343 .68 r
.44106 .42271 .44663 .44681 .45678 .45772 .45123 .43021 Mtetra
.368 .307 .657 r
.45123 .43021 .45678 .45772 .46704 .47056 .46147 .44011 Mtetra
.385 .307 .645 r
.46147 .44011 .46704 .47056 .47743 .4837 .47182 .45028 Mtetra
.457 .348 .642 r
.47182 .45028 .47743 .4837 .48801 .49329 .48235 .45711 Mtetra
.53 .392 .637 r
.48235 .45711 .48801 .49329 .49876 .49712 .49304 .45881 Mtetra
.582 .424 .632 r
.49304 .45881 .49876 .49712 .50963 .4937 .50384 .45534 Mtetra
.626 .454 .63 r
.50384 .45534 .50963 .4937 .52056 .48302 .5147 .44668 Mtetra
.668 .487 .631 r
.5147 .44668 .52056 .48302 .53147 .46651 .52557 .43284 Mtetra
.698 .513 .633 r
.52557 .43284 .53147 .46651 .54232 .44639 .53639 .41561 Mtetra
.707 .525 .64 r
.53639 .41561 .54232 .44639 .55311 .42651 .54717 .39861 Mtetra
.702 .529 .651 r
.54717 .39861 .55311 .42651 .56385 .40852 .55793 .38398 Mtetra
.674 .524 .673 r
.55793 .38398 .56385 .40852 .57457 .39309 .56872 .3742 Mtetra
.636 .532 .719 r
.56872 .3742 .57457 .39309 .58532 .38079 .57959 .36941 Mtetra
.564 .585 .832 r
.57959 .36941 .58532 .38079 .59612 .37195 .59059 .36857 Mtetra
.072 .562 .895 r
.59059 .36857 .59612 .37195 .60703 .36681 .60172 .37102 Mtetra
.575 .062 0 r
.60172 .37102 .60703 .36681 .6181 .36604 .61302 .37633 Mtetra
.617 .198 .226 r
.61302 .37633 .6181 .36604 .62935 .36871 .62447 .38302 Mtetra
.593 .209 .285 r
.62447 .38302 .62935 .36871 .64076 .37337 .63601 .3888 Mtetra
.562 .187 .288 r
.63601 .3888 .64076 .37337 .6523 .37882 .6476 .39285 Mtetra
.507 .123 .246 r
.6476 .39285 .6523 .37882 .66392 .38363 .65917 .39429 Mtetra
.41 0 .136 r
.65917 .39429 .66392 .38363 .67559 .38705 .67072 .39314 Mtetra
.149 0 0 r
.67072 .39314 .67559 .38705 .68723 .38809 .68219 .38932 Mtetra
.461 .882 .78 r
.68219 .38932 .68723 .38809 .69884 .38688 .69361 .38351 Mtetra
.765 .913 .939 r
.69361 .38351 .69884 .38688 .71038 .38348 .705 .37648 Mtetra
.767 .787 .869 r
.705 .37648 .71038 .38348 .72187 .37851 .71637 .36885 Mtetra
.738 .71 .825 r
.71637 .36885 .72187 .37851 .73335 .37261 .72777 .36139 Mtetra
.717 .671 .804 r
.72777 .36139 .73335 .37261 .74482 .36624 .73922 .35433 Mtetra
.697 .651 .8 r
.73922 .35433 .74482 .36624 .75633 .35997 .75075 .34804 Mtetra
.682 .644 .805 r
.75075 .34804 .75633 .35997 .76789 .35394 .76236 .34245 Mtetra
.669 .646 .818 r
.76236 .34245 .76789 .35394 .77952 .34841 .77407 .33758 Mtetra
.659 .654 .834 r
.77407 .33758 .77952 .34841 .79123 .3433 .78586 .33325 Mtetra
.651 .668 .853 r
.78586 .33325 .79123 .3433 .80301 .33862 .79774 .32934 Mtetra
.645 .685 .873 r
.79774 .32934 .80301 .33862 .81486 .33425 .80969 .32571 Mtetra
.641 .703 .892 r
.80969 .32571 .81486 .33425 .82678 .33008 .82171 .32223 Mtetra
.64 .724 .909 r
.82171 .32223 .82678 .33008 .83876 .32602 .83378 .31877 Mtetra
.695 .76 .902 r
.19348 .52013 .20012 .52592 .20974 .52234 .20318 .51595 Mtetra
.694 .742 .887 r
.20318 .51595 .20974 .52234 .2194 .51877 .21292 .51169 Mtetra
.69 .721 .873 r
.21292 .51169 .2194 .51877 .22908 .51536 .22269 .50744 Mtetra
.682 .697 .857 r
.22269 .50744 .22908 .51536 .23877 .51222 .23248 .5033 Mtetra
.672 .67 .84 r
.23248 .5033 .23877 .51222 .24846 .50947 .24229 .49933 Mtetra
.655 .638 .821 r
.24229 .49933 .24846 .50947 .25815 .50726 .25209 .49575 Mtetra
.634 .605 .803 r
.25209 .49575 .25815 .50726 .26782 .50574 .26188 .49273 Mtetra
.609 .57 .785 r
.26188 .49273 .26782 .50574 .27749 .5049 .27165 .4905 Mtetra
.58 .536 .771 r
.27165 .4905 .27749 .5049 .28715 .50482 .28139 .48927 Mtetra
.552 .507 .76 r
.28139 .48927 .28715 .50482 .29684 .50513 .2911 .48909 Mtetra
.52 .484 .757 r
.2911 .48909 .29684 .50513 .30658 .50563 .30079 .49006 Mtetra
.493 .474 .765 r
.30079 .49006 .30658 .50563 .31641 .50556 .31049 .49185 Mtetra
.458 .48 .794 r
.31049 .49185 .31641 .50556 .32637 .50432 .32022 .49424 Mtetra
.416 .531 .865 r
.32022 .49424 .32637 .50432 .33649 .50116 .33003 .49646 Mtetra
.269 .64 .965 r
.33003 .49646 .33649 .50116 .34678 .49539 .33996 .49787 Mtetra
.212 0 0 r
.33996 .49787 .34678 .49539 .35723 .48709 .35003 .49778 Mtetra
.359 0 .111 r
.35003 .49778 .35723 .48709 .36781 .47622 .36027 .49555 Mtetra
.384 .048 .267 r
.36027 .49555 .36781 .47622 .37846 .46363 .37067 .49092 Mtetra
.384 .084 .328 r
.37067 .49092 .37846 .46363 .38913 .45011 .38121 .48365 Mtetra
.381 .1 .356 r
.38121 .48365 .38913 .45011 .39972 .43791 .39186 .47414 Mtetra
.365 .092 .361 r
.39186 .47414 .39972 .43791 .4102 .42851 .40258 .4627 Mtetra
.328 .057 .341 r
.40258 .4627 .4102 .42851 .42057 .42232 .41334 .44984 Mtetra
.241 0 .276 r
.41334 .44984 .42057 .42232 .43086 .42004 .42411 .43602 Mtetra
0 0 .017 r
.42411 .43602 .43086 .42004 .44106 .42271 .43487 .42187 Mtetra
.921 .918 .796 r
.43487 .42187 .44106 .42271 .45123 .43021 .4456 .4075 Mtetra
.739 .57 .664 r
.4456 .4075 .45123 .43021 .46147 .44011 .45634 .39119 Mtetra
.661 .464 .606 r
.45634 .39119 .46147 .44011 .47182 .45028 .46706 .3735 Mtetra
.614 .41 .581 r
.46706 .3735 .47182 .45028 .48235 .45711 .4777 .35802 Mtetra
.584 .379 .569 r
.4777 .35802 .48235 .45711 .49304 .45881 .48825 .34696 Mtetra
.554 .353 .562 r
.48825 .34696 .49304 .45881 .50384 .45534 .49873 .34337 Mtetra
.527 .332 .56 r
.49873 .34337 .50384 .45534 .5147 .44668 .50922 .34727 Mtetra
.507 .32 .562 r
.50922 .34727 .5147 .44668 .52557 .43284 .51978 .35564 Mtetra
.484 .313 .572 r
.51978 .35564 .52557 .43284 .53639 .41561 .53047 .36626 Mtetra
.464 .321 .602 r
.53047 .36626 .53639 .41561 .54717 .39861 .54129 .37555 Mtetra
.398 .354 .692 r
.54129 .37555 .54717 .39861 .55793 .38398 .55223 .38291 Mtetra
.553 0 0 r
.55223 .38291 .55793 .38398 .56872 .3742 .56328 .39009 Mtetra
.609 .239 .315 r
.56328 .39009 .56872 .3742 .57959 .36941 .57445 .39699 Mtetra
.578 .259 .391 r
.57445 .39699 .57959 .36941 .59059 .36857 .58571 .40293 Mtetra
.56 .257 .412 r
.58571 .40293 .59059 .36857 .60172 .37102 .59706 .40748 Mtetra
.541 .245 .414 r
.59706 .40748 .60172 .37102 .61302 .37633 .60845 .41008 Mtetra
.518 .219 .399 r
.60845 .41008 .61302 .37633 .62447 .38302 .61987 .41042 Mtetra
.476 .166 .361 r
.61987 .41042 .62447 .38302 .63601 .3888 .63128 .40808 Mtetra
.394 .058 .274 r
.63128 .40808 .63601 .3888 .6476 .39285 .64265 .40327 Mtetra
.153 0 .015 r
.64265 .40327 .6476 .39285 .65917 .39429 .65398 .39626 Mtetra
.615 .944 .753 r
.65398 .39626 .65917 .39429 .67072 .39314 .66526 .38769 Mtetra
.82 .842 .866 r
.66526 .38769 .67072 .39314 .68219 .38932 .67651 .37828 Mtetra
.762 .692 .784 r
.67651 .37828 .68219 .38932 .69361 .38351 .68776 .36866 Mtetra
.72 .621 .746 r
.68776 .36866 .69361 .38351 .705 .37648 .69904 .35965 Mtetra
.694 .588 .732 r
.69904 .35965 .705 .37648 .71637 .36885 .71038 .35145 Mtetra
.674 .572 .732 r
.71038 .35145 .71637 .36885 .72777 .36139 .72182 .34445 Mtetra
.66 .568 .741 r
.72182 .34445 .72777 .36139 .73922 .35433 .73334 .3385 Mtetra
.647 .573 .757 r
.73334 .3385 .73922 .35433 .75075 .34804 .74498 .3336 Mtetra
.638 .585 .778 r
.74498 .3336 .75075 .34804 .76236 .34245 .75671 .32951 Mtetra
.631 .603 .804 r
.75671 .32951 .76236 .34245 .77407 .33758 .76854 .326 Mtetra
.625 .624 .83 r
.76854 .326 .77407 .33758 .78586 .33325 .78045 .3229 Mtetra
.622 .648 .855 r
.78045 .3229 .78586 .33325 .79774 .32934 .79243 .31997 Mtetra
.619 .671 .878 r
.79243 .31997 .79774 .32934 .80969 .32571 .80448 .31715 Mtetra
.617 .694 .898 r
.80448 .31715 .80969 .32571 .82171 .32223 .8166 .31435 Mtetra
.618 .715 .915 r
.8166 .31435 .82171 .32223 .83378 .31877 .82876 .31146 Mtetra
.699 .761 .899 r
.18679 .51429 .19348 .52013 .20318 .51595 .19653 .50996 Mtetra
.703 .757 .894 r
.19653 .50996 .20318 .51595 .21292 .51169 .20632 .50546 Mtetra
.706 .751 .887 r
.20632 .50546 .21292 .51169 .22269 .50744 .21614 .50084 Mtetra
.706 .74 .878 r
.21614 .50084 .22269 .50744 .23248 .5033 .226 .49612 Mtetra
.706 .724 .864 r
.226 .49612 .23248 .5033 .24229 .49933 .2359 .49127 Mtetra
.698 .7 .848 r
.2359 .49127 .24229 .49933 .25209 .49575 .24582 .48649 Mtetra
.685 .669 .828 r
.24582 .48649 .25209 .49575 .26188 .49273 .25575 .48188 Mtetra
.664 .631 .806 r
.25575 .48188 .26188 .49273 .27165 .4905 .26568 .47773 Mtetra
.638 .589 .783 r
.26568 .47773 .27165 .4905 .28139 .48927 .27558 .4743 Mtetra
.608 .546 .759 r
.27558 .4743 .28139 .48927 .2911 .48909 .28544 .47185 Mtetra
.575 .504 .738 r
.28544 .47185 .2911 .48909 .30079 .49006 .29526 .47068 Mtetra
.544 .468 .72 r
.29526 .47068 .30079 .49006 .31049 .49185 .30504 .47083 Mtetra
.514 .437 .707 r
.30504 .47083 .31049 .49185 .32022 .49424 .31479 .47245 Mtetra
.491 .418 .701 r
.31479 .47245 .32022 .49424 .33003 .49646 .32453 .47514 Mtetra
.47 .408 .705 r
.32453 .47514 .33003 .49646 .33996 .49787 .33431 .47862 Mtetra
.46 .418 .725 r
.33431 .47862 .33996 .49787 .35003 .49778 .34416 .48212 Mtetra
.456 .454 .768 r
.34416 .48212 .35003 .49778 .36027 .49555 .35413 .485 Mtetra
.453 .542 .858 r
.35413 .485 .36027 .49555 .37067 .49092 .36423 .48666 Mtetra
.407 .733 .991 r
.36423 .48666 .37067 .49092 .38121 .48365 .37449 .48648 Mtetra
0 0 0 r
.37449 .48648 .38121 .48365 .39186 .47414 .38492 .48364 Mtetra
.106 0 0 r
.38492 .48364 .39186 .47414 .40258 .4627 .39552 .47766 Mtetra
.172 0 .103 r
.39552 .47766 .40258 .4627 .41334 .44984 .40623 .46921 Mtetra
.192 0 .18 r
.40623 .46921 .41334 .44984 .42411 .43602 .41702 .45853 Mtetra
.175 0 .207 r
.41702 .45853 .42411 .43602 .43487 .42187 .42788 .4454 Mtetra
.124 0 .196 r
.42788 .4454 .43487 .42187 .4456 .4075 .43879 .42995 Mtetra
.017 0 .141 r
.43879 .42995 .4456 .4075 .45634 .39119 .4497 .41218 Mtetra
0 0 .092 r
.4497 .41218 .45634 .39119 .46706 .3735 .46059 .39344 Mtetra
.034 0 .127 r
.46059 .39344 .46706 .3735 .4777 .35802 .47137 .37784 Mtetra
.227 0 .211 r
.47137 .37784 .4777 .35802 .48825 .34696 .48203 .36748 Mtetra
.423 .092 .297 r
.48203 .36748 .48825 .34696 .49873 .34337 .49263 .36389 Mtetra
.55 .209 .343 r
.49263 .36389 .49873 .34337 .50922 .34727 .50322 .36708 Mtetra
.622 .275 .361 r
.50322 .36708 .50922 .34727 .51978 .35564 .51388 .37556 Mtetra
.656 .309 .372 r
.51388 .37556 .51978 .35564 .53047 .36626 .52466 .38723 Mtetra
.643 .298 .373 r
.52466 .38723 .53047 .36626 .54129 .37555 .53559 .39799 Mtetra
.614 .275 .372 r
.53559 .39799 .54129 .37555 .55223 .38291 .54664 .40644 Mtetra
.585 .251 .369 r
.54664 .40644 .55223 .38291 .56328 .39009 .55779 .41261 Mtetra
.554 .217 .352 r
.55779 .41261 .56328 .39009 .57445 .39699 .56903 .41632 Mtetra
.517 .168 .313 r
.56903 .41632 .57445 .39699 .58571 .40293 .58032 .41778 Mtetra
.448 .072 .232 r
.58032 .41778 .58571 .40293 .59706 .40748 .59164 .41676 Mtetra
.243 0 .008 r
.59164 .41676 .59706 .40748 .60845 .41008 .60295 .41254 Mtetra
.465 .869 .703 r
.60295 .41254 .60845 .41008 .61987 .41042 .61422 .4056 Mtetra
.812 .858 .883 r
.61422 .4056 .61987 .41042 .63128 .40808 .62546 .39677 Mtetra
.766 .687 .776 r
.62546 .39677 .63128 .40808 .64265 .40327 .63667 .38667 Mtetra
.729 .608 .722 r
.63667 .38667 .64265 .40327 .65398 .39626 .64785 .37591 Mtetra
.704 .566 .696 r
.64785 .37591 .65398 .39626 .66526 .38769 .65903 .36514 Mtetra
.684 .542 .686 r
.65903 .36514 .66526 .38769 .67651 .37828 .67024 .35517 Mtetra
.67 .53 .686 r
.67024 .35517 .67651 .37828 .68776 .36866 .68151 .34627 Mtetra
.655 .526 .694 r
.68151 .34627 .68776 .36866 .69904 .35965 .69287 .33887 Mtetra
.644 .529 .708 r
.69287 .33887 .69904 .35965 .71038 .35145 .70432 .33283 Mtetra
.633 .538 .729 r
.70432 .33283 .71038 .35145 .72182 .34445 .71589 .3281 Mtetra
.623 .554 .756 r
.71589 .3281 .72182 .34445 .73334 .3385 .72756 .32438 Mtetra
.615 .577 .788 r
.72756 .32438 .73334 .3385 .74498 .3336 .73934 .3214 Mtetra
.607 .603 .822 r
.73934 .3214 .74498 .3336 .75671 .32951 .7512 .3189 Mtetra
.603 .633 .854 r
.7512 .3189 .75671 .32951 .76854 .326 .76314 .31658 Mtetra
.599 .661 .881 r
.76314 .31658 .76854 .326 .78045 .3229 .77515 .31434 Mtetra
.601 .686 .901 r
.77515 .31434 .78045 .3229 .79243 .31997 .78721 .31197 Mtetra
.603 .704 .915 r
.78721 .31197 .79243 .31997 .80448 .31715 .79933 .30949 Mtetra
.606 .717 .923 r
.79933 .30949 .80448 .31715 .8166 .31435 .81149 .30688 Mtetra
.61 .726 .928 r
.81149 .30688 .8166 .31435 .82876 .31146 .82371 .3041 Mtetra
.688 .758 .906 r
.18006 .50842 .18679 .51429 .19653 .50996 .18979 .5044 Mtetra
.694 .771 .911 r
.18979 .5044 .19653 .50996 .20632 .50546 .19957 .5002 Mtetra
.703 .783 .914 r
.19957 .5002 .20632 .50546 .21614 .50084 .2094 .49577 Mtetra
.713 .792 .913 r
.2094 .49577 .21614 .50084 .226 .49612 .21928 .49105 Mtetra
.726 .795 .907 r
.21928 .49105 .226 .49612 .2359 .49127 .22923 .48594 Mtetra
.733 .788 .896 r
.22923 .48594 .2359 .49127 .24582 .48649 .23923 .48051 Mtetra
.737 .768 .878 r
.23923 .48051 .24582 .48649 .25575 .48188 .24928 .47476 Mtetra
.731 .735 .855 r
.24928 .47476 .25575 .48188 .26568 .47773 .25936 .46892 Mtetra
.715 .691 .825 r
.25936 .46892 .26568 .47773 .27558 .4743 .26946 .46312 Mtetra
.689 .637 .792 r
.26946 .46312 .27558 .4743 .28544 .47185 .27955 .45769 Mtetra
.658 .583 .759 r
.27955 .45769 .28544 .47185 .29526 .47068 .28962 .45293 Mtetra
.625 .53 .726 r
.28962 .45293 .29526 .47068 .30504 .47083 .29965 .44914 Mtetra
.592 .483 .698 r
.29965 .44914 .30504 .47083 .31479 .47245 .30963 .44666 Mtetra
.564 .444 .674 r
.30963 .44666 .31479 .47245 .32453 .47514 .31956 .44561 Mtetra
.538 .412 .656 r
.31956 .44561 .32453 .47514 .33431 .47862 .32945 .44616 Mtetra
.522 .392 .644 r
.32945 .44616 .33431 .47862 .34416 .48212 .33933 .44796 Mtetra
.509 .378 .638 r
.33933 .44796 .34416 .48212 .35413 .485 .34922 .45079 Mtetra
.497 .37 .638 r
.34922 .45079 .35413 .485 .36423 .48666 .35915 .45445 Mtetra
.486 .369 .645 r
.35915 .45445 .36423 .48666 .37449 .48648 .36914 .45864 Mtetra
.484 .384 .665 r
.36914 .45864 .37449 .48648 .38492 .48364 .37923 .46242 Mtetra
.484 .42 .71 r
.37923 .46242 .38492 .48364 .39552 .47766 .38945 .46531 Mtetra
.419 .488 .824 r
.38945 .46531 .39552 .47766 .40623 .46921 .39974 .46819 Mtetra
.274 0 0 r
.39974 .46819 .40623 .46921 .41702 .45853 .41012 .47121 Mtetra
.519 .125 .233 r
.41012 .47121 .41702 .45853 .42788 .4454 .4206 .4733 Mtetra
.521 .206 .375 r
.4206 .4733 .42788 .4454 .43879 .42995 .43119 .47438 Mtetra
.534 .25 .43 r
.43119 .47438 .43879 .42995 .4497 .41218 .44183 .47626 Mtetra
.54 .273 .459 r
.44183 .47626 .4497 .41218 .46059 .39344 .45253 .47918 Mtetra
.538 .282 .474 r
.45253 .47918 .46059 .39344 .47137 .37784 .46332 .48197 Mtetra
.532 .282 .482 r
.46332 .48197 .47137 .37784 .48203 .36748 .47421 .48331 Mtetra
.517 .272 .483 r
.47421 .48331 .48203 .36748 .49263 .36389 .48524 .4798 Mtetra
.5 .258 .479 r
.48524 .4798 .49263 .36389 .50322 .36708 .49635 .47143 Mtetra
.49 .247 .473 r
.49635 .47143 .50322 .36708 .51388 .37556 .50749 .46157 Mtetra
.479 .233 .462 r
.50749 .46157 .51388 .37556 .52466 .38723 .51862 .45157 Mtetra
.466 .211 .442 r
.51862 .45157 .52466 .38723 .53559 .39799 .52976 .4426 Mtetra
.441 .17 .406 r
.52976 .4426 .53559 .39799 .54664 .40644 .54091 .4344 Mtetra
.358 .063 .322 r
.54091 .4344 .54664 .40644 .55779 .41261 .55207 .42517 Mtetra
.043 0 .008 r
.55207 .42517 .55779 .41261 .56903 .41632 .56322 .41498 Mtetra
.846 .964 .88 r
.56322 .41498 .56903 .41632 .58032 .41778 .57438 .4049 Mtetra
.751 .657 .757 r
.57438 .4049 .58032 .41778 .59164 .41676 .58553 .39479 Mtetra
.698 .553 .686 r
.58553 .39479 .59164 .41676 .60295 .41254 .59667 .38374 Mtetra
.672 .509 .655 r
.59667 .38374 .60295 .41254 .61422 .4056 .60779 .37226 Mtetra
.653 .483 .641 r
.60779 .37226 .61422 .4056 .62546 .39677 .61891 .36129 Mtetra
.641 .47 .636 r
.61891 .36129 .62546 .39677 .63667 .38667 .63005 .35114 Mtetra
.632 .464 .637 r
.63005 .35114 .63667 .38667 .64785 .37591 .64124 .34203 Mtetra
.625 .463 .642 r
.64124 .34203 .64785 .37591 .65903 .36514 .65248 .33418 Mtetra
.616 .465 .654 r
.65248 .33418 .65903 .36514 .67024 .35517 .66381 .32796 Mtetra
.608 .473 .672 r
.66381 .32796 .67024 .35517 .68151 .34627 .67525 .3232 Mtetra
.6 .488 .697 r
.67525 .3232 .68151 .34627 .69287 .33887 .68679 .31979 Mtetra
.592 .51 .731 r
.68679 .31979 .69287 .33887 .70432 .33283 .69844 .31739 Mtetra
.583 .542 .774 r
.69844 .31739 .70432 .33283 .71589 .3281 .71019 .31567 Mtetra
.574 .582 .823 r
.71019 .31567 .71589 .3281 .72756 .32438 .72202 .31434 Mtetra
.567 .628 .872 r
.72202 .31434 .72756 .32438 .73934 .3214 .73394 .31307 Mtetra
.561 .672 .913 r
.73394 .31307 .73934 .3214 .7512 .3189 .74591 .3117 Mtetra
.564 .711 .94 r
.74591 .3117 .7512 .3189 .76314 .31658 .75793 .31 Mtetra
.571 .738 .954 r
.75793 .31 .76314 .31658 .77515 .31434 .76999 .30798 Mtetra
.587 .754 .958 r
.76999 .30798 .77515 .31434 .78721 .31197 .78209 .30556 Mtetra
.601 .759 .954 r
.78209 .30556 .78721 .31197 .79933 .30949 .79422 .30282 Mtetra
.613 .756 .947 r
.79422 .30282 .79933 .30949 .81149 .30688 .80639 .29985 Mtetra
.622 .749 .937 r
.80639 .29985 .81149 .30688 .82371 .3041 .81861 .29669 Mtetra
.657 .752 .92 r
.17328 .5025 .18006 .50842 .18979 .5044 .18295 .49926 Mtetra
.66 .781 .938 r
.18295 .49926 .18979 .5044 .19957 .5002 .19267 .4959 Mtetra
.667 .814 .954 r
.19267 .4959 .19957 .5002 .2094 .49577 .20245 .49229 Mtetra
.677 .848 .965 r
.20245 .49229 .2094 .49577 .21928 .49105 .21229 .48834 Mtetra
.691 .88 .969 r
.21229 .48834 .21928 .49105 .22923 .48594 .22221 .48393 Mtetra
.706 .908 .966 r
.22221 .48393 .22923 .48594 .23923 .48051 .2322 .479 Mtetra
.727 .927 .957 r
.2322 .479 .23923 .48051 .24928 .47476 .24227 .47347 Mtetra
.747 .935 .948 r
.24227 .47347 .24928 .47476 .25936 .46892 .25241 .46741 Mtetra
.771 .929 .937 r
.25241 .46741 .25936 .46892 .26946 .46312 .2626 .46085 Mtetra
.784 .903 .925 r
.2626 .46085 .26946 .46312 .27955 .45769 .27284 .45401 Mtetra
.783 .853 .903 r
.27284 .45401 .27955 .45769 .28962 .45293 .2831 .44708 Mtetra
.76 .78 .87 r
.2831 .44708 .28962 .45293 .29965 .44914 .29336 .44039 Mtetra
.722 .698 .826 r
.29336 .44039 .29965 .44914 .30963 .44666 .3036 .43425 Mtetra
.676 .615 .78 r
.3036 .43425 .30963 .44666 .31956 .44561 .3138 .42905 Mtetra
.631 .544 .739 r
.3138 .42905 .31956 .44561 .32945 .44616 .32395 .42513 Mtetra
.595 .489 .703 r
.32395 .42513 .32945 .44616 .33933 .44796 .33405 .42251 Mtetra
.566 .447 .677 r
.33405 .42251 .33933 .44796 .34922 .45079 .34412 .42128 Mtetra
.543 .416 .657 r
.34412 .42128 .34922 .45079 .35915 .45445 .35417 .42144 Mtetra
.524 .392 .643 r
.35417 .42144 .35915 .45445 .36914 .45864 .36422 .42298 Mtetra
.514 .379 .634 r
.36422 .42298 .36914 .45864 .37923 .46242 .37429 .42538 Mtetra
.507 .371 .63 r
.37429 .42538 .37923 .46242 .38945 .46531 .38441 .42843 Mtetra
.494 .362 .63 r
.38441 .42843 .38945 .46531 .39974 .46819 .39458 .43249 Mtetra
.479 .354 .633 r
.39458 .43249 .39974 .46819 .41012 .47121 .40479 .43759 Mtetra
.471 .355 .64 r
.40479 .43759 .41012 .47121 .4206 .4733 .41509 .44293 Mtetra
.458 .358 .653 r
.41509 .44293 .4206 .4733 .43119 .47438 .42549 .44856 Mtetra
.38 .326 .671 r
.42549 .44856 .43119 .47438 .44183 .47626 .43591 .45686 Mtetra
.216 .265 .699 r
.43591 .45686 .44183 .47626 .45253 .47918 .44639 .46754 Mtetra
.01 .252 .757 r
.44639 .46754 .45253 .47918 .46332 .48197 .45704 .4768 Mtetra
0 .383 .814 r
.45704 .4768 .46332 .48197 .47421 .48331 .46789 .48189 Mtetra
.53 .895 .971 r
.46789 .48189 .47421 .48331 .48524 .4798 .47897 .47836 Mtetra
.888 .938 .842 r
.47897 .47836 .48524 .4798 .49635 .47143 .49018 .46618 Mtetra
.896 .819 .764 r
.49018 .46618 .49635 .47143 .50749 .46157 .5014 .44978 Mtetra
.835 .699 .713 r
.5014 .44978 .50749 .46157 .51862 .45157 .51259 .4319 Mtetra
.753 .597 .684 r
.51259 .4319 .51862 .45157 .52976 .4426 .52373 .41638 Mtetra
.695 .532 .662 r
.52373 .41638 .52976 .4426 .54091 .4344 .53484 .4035 Mtetra
.675 .504 .647 r
.53484 .4035 .54091 .4344 .55207 .42517 .54593 .39089 Mtetra
.662 .487 .637 r
.54593 .39089 .55207 .42517 .56322 .41498 .55701 .37849 Mtetra
.648 .472 .632 r
.55701 .37849 .56322 .41498 .57438 .4049 .56808 .36711 Mtetra
.637 .462 .629 r
.56808 .36711 .57438 .4049 .58553 .39479 .57916 .35673 Mtetra
.632 .458 .629 r
.57916 .35673 .58553 .39479 .59667 .38374 .59026 .34699 Mtetra
.627 .457 .633 r
.59026 .34699 .59667 .38374 .60779 .37226 .60138 .33812 Mtetra
.621 .459 .641 r
.60138 .33812 .60779 .37226 .61891 .36129 .61254 .33062 Mtetra
.615 .465 .654 r
.61254 .33062 .61891 .36129 .63005 .35114 .62377 .32454 Mtetra
.608 .475 .674 r
.62377 .32454 .63005 .35114 .64124 .34203 .63508 .31987 Mtetra
.6 .493 .703 r
.63508 .31987 .64124 .34203 .65248 .33418 .64649 .31654 Mtetra
.586 .519 .746 r
.64649 .31654 .65248 .33418 .66381 .32796 .65799 .31451 Mtetra
.567 .56 .805 r
.65799 .31451 .66381 .32796 .67525 .3232 .66961 .31346 Mtetra
.536 .618 .881 r
.66961 .31346 .67525 .3232 .68679 .31979 .68132 .31298 Mtetra
.483 .683 .954 r
.68132 .31298 .68679 .31979 .69844 .31739 .69312 .31276 Mtetra
.415 .735 .991 r
.69312 .31276 .69844 .31739 .71019 .31567 .70499 .31245 Mtetra
.354 .759 .983 r
.70499 .31245 .71019 .31567 .72202 .31434 .71692 .31188 Mtetra
.345 .78 .967 r
.71692 .31188 .72202 .31434 .73394 .31307 .72889 .31078 Mtetra
.378 .805 .968 r
.72889 .31078 .73394 .31307 .74591 .3117 .7409 .30914 Mtetra
.449 .836 .984 r
.7409 .30914 .74591 .3117 .75793 .31 .75293 .30688 Mtetra
.519 .852 .996 r
.75293 .30688 .75793 .31 .76999 .30798 .76499 .30408 Mtetra
.58 .85 .995 r
.76499 .30408 .76999 .30798 .78209 .30556 .77706 .30079 Mtetra
.62 .833 .982 r
.77706 .30079 .78209 .30556 .79422 .30282 .78916 .29715 Mtetra
.643 .808 .962 r
.78916 .29715 .79422 .30282 .80639 .29985 .8013 .29325 Mtetra
.653 .779 .941 r
.8013 .29325 .80639 .29985 .81861 .29669 .81347 .28921 Mtetra
.61 .739 .937 r
.16646 .49655 .17328 .5025 .18295 .49926 .17604 .49428 Mtetra
.603 .774 .962 r
.17604 .49428 .18295 .49926 .19267 .4959 .18568 .49197 Mtetra
.594 .813 .983 r
.18568 .49197 .19267 .4959 .20245 .49229 .19536 .48951 Mtetra
.582 .854 .995 r
.19536 .48951 .20245 .49229 .21229 .48834 .20512 .48679 Mtetra
.56 .889 .987 r
.20512 .48679 .21229 .48834 .22221 .48393 .21494 .4837 Mtetra
.527 .908 .946 r
.21494 .4837 .22221 .48393 .2322 .479 .22485 .48012 Mtetra
.487 .902 .872 r
.22485 .48012 .2322 .479 .24227 .47347 .23486 .47588 Mtetra
.444 .874 .778 r
.23486 .47588 .24227 .47347 .25241 .46741 .24495 .47093 Mtetra
.424 .847 .697 r
.24495 .47093 .25241 .46741 .2626 .46085 .25514 .46517 Mtetra
.424 .833 .645 r
.25514 .46517 .2626 .46085 .27284 .45401 .26541 .45865 Mtetra
.468 .854 .643 r
.26541 .45865 .27284 .45401 .2831 .44708 .27576 .45138 Mtetra
.549 .903 .692 r
.27576 .45138 .2831 .44708 .29336 .44039 .28616 .44355 Mtetra
.673 .97 .79 r
.28616 .44355 .29336 .44039 .3036 .43425 .2966 .43531 Mtetra
.782 .991 .885 r
.2966 .43531 .3036 .43425 .3138 .42905 .30706 .42703 Mtetra
.815 .915 .906 r
.30706 .42703 .3138 .42905 .32395 .42513 .3175 .419 Mtetra
.775 .779 .856 r
.3175 .419 .32395 .42513 .33405 .42251 .32793 .41148 Mtetra
.715 .655 .789 r
.32793 .41148 .33405 .42251 .34412 .42128 .33832 .40474 Mtetra
.665 .565 .732 r
.33832 .40474 .34412 .42128 .35417 .42144 .34869 .39876 Mtetra
.627 .501 .689 r
.34869 .39876 .35417 .42144 .36422 .42298 .35904 .39362 Mtetra
.598 .454 .657 r
.35904 .39362 .36422 .42298 .37429 .42538 .36937 .38951 Mtetra
.577 .422 .634 r
.36937 .38951 .37429 .42538 .38441 .42843 .37969 .38647 Mtetra
.566 .402 .619 r
.37969 .38647 .38441 .42843 .39458 .43249 .39002 .38395 Mtetra
.559 .388 .606 r
.39002 .38395 .39458 .43249 .40479 .43759 .40039 .38176 Mtetra
.552 .375 .595 r
.40039 .38176 .40479 .43759 .41509 .44293 .41079 .38005 Mtetra
.545 .364 .586 r
.41079 .38005 .41509 .44293 .42549 .44856 .42122 .37913 Mtetra
.53 .348 .579 r
.42122 .37913 .42549 .44856 .43591 .45686 .43164 .3806 Mtetra
.518 .335 .573 r
.43164 .3806 .43591 .45686 .44639 .46754 .44208 .38424 Mtetra
.523 .336 .569 r
.44208 .38424 .44639 .46754 .45704 .4768 .45262 .38704 Mtetra
.536 .343 .567 r
.45262 .38704 .45704 .4768 .46789 .48189 .4633 .38741 Mtetra
.552 .354 .566 r
.4633 .38741 .46789 .48189 .47897 .47836 .4741 .38377 Mtetra
.569 .367 .567 r
.4741 .38377 .47897 .47836 .49018 .46618 .48501 .37612 Mtetra
.58 .377 .57 r
.48501 .37612 .49018 .46618 .5014 .44978 .49595 .36601 Mtetra
.587 .384 .574 r
.49595 .36601 .5014 .44978 .51259 .4319 .50689 .35503 Mtetra
.582 .383 .578 r
.50689 .35503 .51259 .4319 .52373 .41638 .51782 .34621 Mtetra
.574 .381 .582 r
.51782 .34621 .52373 .41638 .53484 .4035 .52877 .33979 Mtetra
.573 .385 .588 r
.52877 .33979 .53484 .4035 .54593 .39089 .53974 .33416 Mtetra
.575 .392 .596 r
.53974 .33416 .54593 .39089 .55701 .37849 .55075 .32901 Mtetra
.578 .402 .606 r
.55075 .32901 .55701 .37849 .56808 .36711 .56179 .32419 Mtetra
.58 .412 .619 r
.56179 .32419 .56808 .36711 .57916 .35673 .57288 .31989 Mtetra
.576 .421 .634 r
.57288 .31989 .57916 .35673 .59026 .34699 .58404 .31668 Mtetra
.571 .436 .658 r
.58404 .31668 .59026 .34699 .60138 .33812 .59526 .31451 Mtetra
.566 .462 .695 r
.59526 .31451 .60138 .33812 .61254 .33062 .60657 .31321 Mtetra
.554 .501 .751 r
.60657 .31321 .61254 .33062 .62377 .32454 .61796 .31269 Mtetra
.52 .561 .838 r
.61796 .31269 .62377 .32454 .63508 .31987 .62945 .31298 Mtetra
.421 .646 .951 r
.62945 .31298 .63508 .31987 .64649 .31654 .64104 .3138 Mtetra
.15 .645 .915 r
.64104 .3138 .64649 .31654 .65799 .31451 .65272 .3149 Mtetra
.143 0 0 r
.65272 .3149 .65799 .31451 .66961 .31346 .66449 .31597 Mtetra
.257 0 0 r
.66449 .31597 .66961 .31346 .68132 .31298 .67632 .31663 Mtetra
.276 0 0 r
.67632 .31663 .68132 .31298 .69312 .31276 .6882 .31672 Mtetra
.239 0 0 r
.6882 .31672 .69312 .31276 .70499 .31245 .70012 .31606 Mtetra
.164 0 0 r
.70012 .31606 .70499 .31245 .71692 .31188 .71208 .31462 Mtetra
.035 0 0 r
.71208 .31462 .71692 .31188 .72889 .31078 .72404 .31233 Mtetra
0 0 0 r
.72404 .31233 .72889 .31078 .7409 .30914 .73602 .3093 Mtetra
.345 .823 .827 r
.73602 .3093 .7409 .30914 .75293 .30688 .74802 .3056 Mtetra
.512 .902 .942 r
.74802 .3056 .75293 .30688 .76499 .30408 .76002 .30137 Mtetra
.615 .91 .982 r
.76002 .30137 .76499 .30408 .77706 .30079 .77205 .29675 Mtetra
.666 .881 .978 r
.77205 .29675 .77706 .30079 .78916 .29715 .7841 .29185 Mtetra
.687 .841 .957 r
.7841 .29185 .78916 .29715 .8013 .29325 .79618 .28679 Mtetra
.692 .801 .933 r
.79618 .28679 .8013 .29325 .81347 .28921 .8083 .28168 Mtetra
.572 .727 .947 r
.15958 .49055 .16646 .49655 .17604 .49428 .16912 .48895 Mtetra
.559 .748 .966 r
.16912 .48895 .17604 .49428 .18568 .49197 .17869 .48739 Mtetra
.545 .773 .983 r
.17869 .48739 .18568 .49197 .19536 .48951 .18831 .4858 Mtetra
.526 .802 .996 r
.18831 .4858 .19536 .48951 .20512 .48679 .19799 .4841 Mtetra
.497 .83 .999 r
.19799 .4841 .20512 .48679 .21494 .4837 .20772 .48225 Mtetra
.455 .851 .975 r
.20772 .48225 .21494 .4837 .22485 .48012 .21754 .48007 Mtetra
.391 .845 .904 r
.21754 .48007 .22485 .48012 .23486 .47588 .22743 .47746 Mtetra
.305 .796 .774 r
.22743 .47746 .23486 .47588 .24495 .47093 .23742 .47425 Mtetra
0 0 0 r
.23742 .47425 .24495 .47093 .25514 .46517 .24751 .47031 Mtetra
.24751 .47031 .25514 .46517 .26541 .45865 .2577 .46556 Mtetra
.2577 .46556 .26541 .45865 .27576 .45138 .26799 .45992 Mtetra
.26799 .45992 .27576 .45138 .28616 .44355 .27837 .45343 Mtetra
.27837 .45343 .28616 .44355 .2966 .43531 .28882 .44608 Mtetra
.28882 .44608 .2966 .43531 .30706 .42703 .29934 .43809 Mtetra
.29934 .43809 .30706 .42703 .3175 .419 .3099 .42964 Mtetra
.3099 .42964 .3175 .419 .32793 .41148 .32048 .42105 Mtetra
.32048 .42105 .32793 .41148 .33832 .40474 .33105 .4126 Mtetra
.33105 .4126 .33832 .40474 .34869 .39876 .34163 .40422 Mtetra
.437 .812 .561 r
.34163 .40422 .34869 .39876 .35904 .39362 .35221 .39599 Mtetra
.645 .965 .812 r
.35221 .39599 .35904 .39362 .36937 .38951 .36276 .38848 Mtetra
.751 .956 .94 r
.36276 .38848 .36937 .38951 .37969 .38647 .37329 .38182 Mtetra
.772 .835 .9 r
.37329 .38182 .37969 .38647 .39002 .38395 .38385 .37496 Mtetra
.745 .708 .817 r
.38385 .37496 .39002 .38395 .40039 .38176 .39444 .36753 Mtetra
.7 .608 .751 r
.39444 .36753 .40039 .38176 .41079 .38005 .40505 .36022 Mtetra
.662 .54 .705 r
.40505 .36022 .41079 .38005 .42122 .37913 .41566 .3533 Mtetra
.631 .49 .671 r
.41566 .3533 .42122 .37913 .43164 .3806 .42628 .34695 Mtetra
.606 .448 .641 r
.42628 .34695 .43164 .3806 .44208 .38424 .4369 .3412 Mtetra
.592 .419 .617 r
.4369 .3412 .44208 .38424 .45262 .38704 .44754 .33542 Mtetra
.581 .4 .601 r
.44754 .33542 .45262 .38704 .4633 .38741 .45821 .32986 Mtetra
.564 .382 .593 r
.45821 .32986 .4633 .38741 .4741 .38377 .46888 .32616 Mtetra
.551 .373 .592 r
.46888 .32616 .4741 .38377 .48501 .37612 .47956 .32431 Mtetra
.552 .379 .6 r
.47956 .32431 .48501 .37612 .49595 .36601 .49029 .32268 Mtetra
.556 .393 .616 r
.49029 .32268 .49595 .36601 .50689 .35503 .50108 .32104 Mtetra
.554 .412 .642 r
.50108 .32104 .50689 .35503 .51782 .34621 .51193 .32 Mtetra
.55 .437 .677 r
.51193 .32 .51782 .34621 .52877 .33979 .52283 .31955 Mtetra
.544 .468 .72 r
.52283 .31955 .52877 .33979 .53974 .33416 .53381 .31951 Mtetra
.535 .521 .786 r
.53381 .31951 .53974 .33416 .55075 .32901 .54485 .31959 Mtetra
.533 .622 .886 r
.54485 .31959 .55075 .32901 .56179 .32419 .55597 .31912 Mtetra
.465 .739 .987 r
.55597 .31912 .56179 .32419 .57288 .31989 .56714 .31843 Mtetra
.123 .659 .857 r
.56714 .31843 .57288 .31989 .58404 .31668 .5784 .31864 Mtetra
.252 0 0 r
.5784 .31864 .58404 .31668 .59526 .31451 .58975 .31959 Mtetra
.391 0 0 r
.58975 .31959 .59526 .31451 .60657 .31321 .60119 .3207 Mtetra
.44 0 .031 r
.60119 .3207 .60657 .31321 .61796 .31269 .61271 .3219 Mtetra
.465 .017 .101 r
.61271 .3219 .61796 .31269 .62945 .31298 .62432 .32326 Mtetra
.47 .036 .133 r
.62432 .32326 .62945 .31298 .64104 .3138 .63601 .3245 Mtetra
.458 .03 .137 r
.63601 .3245 .64104 .3138 .65272 .3149 .64777 .32527 Mtetra
.434 .002 .117 r
.64777 .32527 .65272 .3149 .66449 .31597 .65959 .32539 Mtetra
.391 0 .069 r
.65959 .32539 .66449 .31597 .67632 .31663 .67144 .32465 Mtetra
.327 0 0 r
.67144 .32465 .67632 .31663 .6882 .31672 .68333 .32304 Mtetra
.225 0 0 r
.68333 .32304 .6882 .31672 .70012 .31606 .69523 .3205 Mtetra
.07 0 0 r
.69523 .3205 .70012 .31606 .71208 .31462 .70715 .31713 Mtetra
0 0 0 r
.70715 .31713 .71208 .31462 .72404 .31233 .71907 .313 Mtetra
.392 .849 .8 r
.71907 .313 .72404 .31233 .73602 .3093 .731 .30824 Mtetra
.571 .932 .932 r
.731 .30824 .73602 .3093 .74802 .3056 .74295 .30302 Mtetra
.664 .931 .971 r
.74295 .30302 .74802 .3056 .76002 .30137 .75492 .29746 Mtetra
.702 .897 .967 r
.75492 .29746 .76002 .30137 .77205 .29675 .76691 .29172 Mtetra
.716 .86 .95 r
.76691 .29172 .77205 .29675 .7841 .29185 .77893 .28586 Mtetra
.718 .827 .932 r
.77893 .28586 .7841 .29185 .79618 .28679 .79098 .27995 Mtetra
.715 .798 .916 r
.79098 .27995 .79618 .28679 .8083 .28168 .80308 .27409 Mtetra
.56 .723 .95 r
.15266 .48451 .15958 .49055 .16912 .48895 .16219 .48309 Mtetra
.55 .727 .957 r
.16219 .48309 .16912 .48895 .17869 .48739 .17175 .48177 Mtetra
.539 .733 .964 r
.17175 .48177 .17869 .48739 .18831 .4858 .18135 .48054 Mtetra
.525 .742 .974 r
.18135 .48054 .18831 .4858 .19799 .4841 .19099 .47939 Mtetra
.504 .756 .986 r
.19099 .47939 .19799 .4841 .20772 .48225 .20067 .47832 Mtetra
.477 .777 .997 r
.20067 .47832 .20772 .48225 .21754 .48007 .21041 .47722 Mtetra
.431 .798 .995 r
.21041 .47722 .21754 .48007 .22743 .47746 .2202 .47602 Mtetra
.354 .803 .95 r
.2202 .47602 .22743 .47746 .23742 .47425 .23006 .47459 Mtetra
.232 .751 .818 r
.23006 .47459 .23742 .47425 .24751 .47031 .24001 .4728 Mtetra
0 0 0 r
.24001 .4728 .24751 .47031 .2577 .46556 .25004 .47052 Mtetra
.062 0 0 r
.25004 .47052 .2577 .46556 .26799 .45992 .26017 .46763 Mtetra
.159 0 0 r
.26017 .46763 .26799 .45992 .27837 .45343 .27039 .46406 Mtetra
.218 0 .004 r
.27039 .46406 .27837 .45343 .28882 .44608 .28071 .4597 Mtetra
.258 0 .099 r
.28071 .4597 .28882 .44608 .29934 .43809 .29112 .45456 Mtetra
.281 0 .161 r
.29112 .45456 .29934 .43809 .3099 .42964 .30161 .44862 Mtetra
.302 0 .206 r
.30161 .44862 .3099 .42964 .32048 .42105 .31216 .44215 Mtetra
.319 0 .237 r
.31216 .44215 .32048 .42105 .33105 .4126 .32275 .43533 Mtetra
.324 .001 .254 r
.32275 .43533 .33105 .4126 .34163 .40422 .33339 .42801 Mtetra
.323 .006 .263 r
.33339 .42801 .34163 .40422 .35221 .39599 .34407 .42021 Mtetra
.332 .017 .271 r
.34407 .42021 .35221 .39599 .36276 .38848 .35476 .41256 Mtetra
.34 .024 .274 r
.35476 .41256 .36276 .38848 .37329 .38182 .36545 .40524 Mtetra
.313 0 .258 r
.36545 .40524 .37329 .38182 .38385 .37496 .3762 .39707 Mtetra
.261 0 .225 r
.3762 .39707 .38385 .37496 .39444 .36753 .387 .38763 Mtetra
.215 0 .186 r
.387 .38763 .39444 .36753 .40505 .36022 .39784 .37775 Mtetra
.144 0 .121 r
.39784 .37775 .40505 .36022 .41566 .3533 .40868 .36746 Mtetra
0 0 0 r
.40868 .36746 .41566 .3533 .42628 .34695 .41959 .3553 Mtetra
.557 .814 .444 r
.41959 .3553 .42628 .34695 .4369 .3412 .43052 .34158 Mtetra
.905 .967 .812 r
.43052 .34158 .4369 .3412 .44754 .33542 .44142 .32846 Mtetra
.818 .776 .813 r
.44142 .32846 .44754 .33542 .45821 .32986 .45223 .31795 Mtetra
.642 .616 .808 r
.45223 .31795 .45821 .32986 .46888 .32616 .46291 .31422 Mtetra
.399 .487 .833 r
.46291 .31422 .46888 .32616 .47956 .32431 .47351 .31727 Mtetra
.001 .38 .842 r
.47351 .31727 .47956 .32431 .49029 .32268 .48417 .32296 Mtetra
.562 0 0 r
.48417 .32296 .49029 .32268 .50108 .32104 .49494 .32929 Mtetra
.571 .121 .143 r
.49494 .32929 .50108 .32104 .51193 .32 .50582 .33407 Mtetra
.532 .141 .245 r
.50582 .33407 .51193 .32 .52283 .31955 .51681 .33701 Mtetra
.527 .16 .287 r
.51681 .33701 .52283 .31955 .53381 .31951 .5279 .33954 Mtetra
.521 .169 .31 r
.5279 .33954 .53381 .31951 .54485 .31959 .53907 .34165 Mtetra
.502 .161 .32 r
.53907 .34165 .54485 .31959 .55597 .31912 .55032 .3425 Mtetra
.491 .156 .326 r
.55032 .3425 .55597 .31912 .56714 .31843 .56164 .3425 Mtetra
.497 .164 .332 r
.56164 .3425 .56714 .31843 .5784 .31864 .57303 .34283 Mtetra
.5 .166 .333 r
.57303 .34283 .5784 .31864 .58975 .31959 .58451 .34335 Mtetra
.491 .157 .327 r
.58451 .34335 .58975 .31959 .60119 .3207 .59606 .34338 Mtetra
.481 .143 .315 r
.59606 .34338 .60119 .3207 .61271 .3219 .60767 .34291 Mtetra
.47 .124 .297 r
.60767 .34291 .61271 .3219 .62432 .32326 .61934 .34209 Mtetra
.451 .095 .269 r
.61934 .34209 .62432 .32326 .63601 .3245 .63106 .34074 Mtetra
.417 .046 .224 r
.63106 .34074 .63601 .3245 .64777 .32527 .64283 .33857 Mtetra
.366 0 .154 r
.64283 .33857 .64777 .32527 .65959 .32539 .65462 .3356 Mtetra
.281 0 .04 r
.65462 .3356 .65959 .32539 .67144 .32465 .66644 .33182 Mtetra
.14 0 0 r
.66644 .33182 .67144 .32465 .68333 .32304 .67827 .32732 Mtetra
0 0 0 r
.67827 .32732 .68333 .32304 .69523 .3205 .69011 .32219 Mtetra
.377 .828 .72 r
.69011 .32219 .69523 .3205 .70715 .31713 .70197 .31655 Mtetra
.599 .948 .91 r
.70197 .31655 .70715 .31713 .71907 .313 .71384 .31053 Mtetra
.699 .943 .96 r
.71384 .31053 .71907 .313 .731 .30824 .72574 .30424 Mtetra
.73 .9 .955 r
.72574 .30424 .731 .30824 .74295 .30302 .73766 .29785 Mtetra
.737 .86 .938 r
.73766 .29785 .74295 .30302 .75492 .29746 .74961 .29142 Mtetra
.733 .829 .924 r
.74961 .29142 .75492 .29746 .76691 .29172 .7616 .28505 Mtetra
.729 .808 .914 r
.7616 .28505 .76691 .29172 .77893 .28586 .77363 .27876 Mtetra
.724 .793 .907 r
.77363 .27876 .77893 .28586 .79098 .27995 .7857 .27255 Mtetra
.719 .783 .903 r
.7857 .27255 .79098 .27995 .80308 .27409 .79782 .26643 Mtetra
.593 .734 .942 r
.14569 .47843 .15266 .48451 .16219 .48309 .1553 .47642 Mtetra
.591 .714 .929 r
.1553 .47642 .16219 .48309 .17175 .48177 .16494 .47453 Mtetra
.585 .694 .917 r
.16494 .47453 .17175 .48177 .18135 .48054 .1746 .4728 Mtetra
.577 .676 .907 r
.1746 .4728 .18135 .48054 .19099 .47939 .18429 .47129 Mtetra
.565 .662 .902 r
.18429 .47129 .19099 .47939 .20067 .47832 .194 .47004 Mtetra
.553 .652 .901 r
.194 .47004 .20067 .47832 .21041 .47722 .20373 .46905 Mtetra
.538 .65 .907 r
.20373 .46905 .21041 .47722 .2202 .47602 .21349 .46833 Mtetra
.522 .659 .921 r
.21349 .46833 .2202 .47602 .23006 .47459 .22328 .46779 Mtetra
.5 .68 .946 r
.22328 .46779 .23006 .47459 .24001 .4728 .23312 .46739 Mtetra
.464 .717 .979 r
.23312 .46739 .24001 .4728 .25004 .47052 .24301 .46698 Mtetra
.388 .756 .992 r
.24301 .46698 .25004 .47052 .26017 .46763 .25297 .46647 Mtetra
.23 .736 .894 r
.25297 .46647 .26017 .46763 .27039 .46406 .26301 .4657 Mtetra
0 0 0 r
.26301 .4657 .27039 .46406 .28071 .4597 .27313 .46452 Mtetra
.165 0 0 r
.27313 .46452 .28071 .4597 .29112 .45456 .28335 .46273 Mtetra
.251 0 0 r
.28335 .46273 .29112 .45456 .30161 .44862 .29368 .46016 Mtetra
.305 0 .076 r
.29368 .46016 .30161 .44862 .31216 .44215 .30409 .45695 Mtetra
.337 0 .16 r
.30409 .45695 .31216 .44215 .32275 .43533 .31459 .45317 Mtetra
.35 0 .211 r
.31459 .45317 .32275 .43533 .33339 .42801 .32516 .44864 Mtetra
.357 .018 .246 r
.32516 .44864 .33339 .42801 .34407 .42021 .33582 .44338 Mtetra
.376 .048 .277 r
.33582 .44338 .34407 .42021 .35476 .41256 .34651 .43798 Mtetra
.393 .074 .301 r
.34651 .43798 .35476 .41256 .36545 .40524 .35723 .43265 Mtetra
.391 .08 .313 r
.35723 .43265 .36545 .40524 .3762 .39707 .36802 .42664 Mtetra
.385 .082 .323 r
.36802 .42664 .3762 .39707 .387 .38763 .37887 .41969 Mtetra
.395 .098 .339 r
.37887 .41969 .387 .38763 .39784 .37775 .38975 .41256 Mtetra
.401 .111 .352 r
.38975 .41256 .39784 .37775 .40868 .36746 .40066 .40502 Mtetra
.367 .087 .351 r
.40066 .40502 .40868 .36746 .41959 .3553 .4117 .39441 Mtetra
.329 .059 .343 r
.4117 .39441 .41959 .3553 .43052 .34158 .42283 .38078 Mtetra
.333 .063 .346 r
.42283 .38078 .43052 .34158 .44142 .32846 .43394 .3673 Mtetra
.371 .095 .358 r
.43394 .3673 .44142 .32846 .45223 .31795 .44496 .35638 Mtetra
.465 .174 .387 r
.44496 .35638 .45223 .31795 .46291 .31422 .45581 .35266 Mtetra
.54 .241 .408 r
.45581 .35266 .46291 .31422 .47351 .31727 .46658 .35613 Mtetra
.563 .261 .414 r
.46658 .35613 .47351 .31727 .48417 .32296 .4774 .36221 Mtetra
.564 .262 .415 r
.4774 .36221 .48417 .32296 .49494 .32929 .48833 .36847 Mtetra
.537 .238 .407 r
.48833 .36847 .49494 .32929 .50582 .33407 .4994 .37172 Mtetra
.507 .209 .395 r
.4994 .37172 .50582 .33407 .51681 .33701 .51058 .3719 Mtetra
.501 .197 .384 r
.51058 .3719 .51681 .33701 .5279 .33954 .52183 .37168 Mtetra
.496 .186 .371 r
.52183 .37168 .5279 .33954 .53907 .34165 .53315 .37128 Mtetra
.48 .166 .355 r
.53315 .37128 .53907 .34165 .55032 .3425 .54454 .36995 Mtetra
.465 .146 .339 r
.54454 .36995 .55032 .3425 .56164 .3425 .55598 .36792 Mtetra
.461 .135 .326 r
.55598 .36792 .56164 .3425 .57303 .34283 .56749 .36597 Mtetra
.452 .117 .306 r
.56749 .36597 .57303 .34283 .58451 .34335 .57906 .3639 Mtetra
.426 .081 .275 r
.57906 .3639 .58451 .34335 .59606 .34338 .59067 .36107 Mtetra
.389 .03 .23 r
.59067 .36107 .59606 .34338 .60767 .34291 .60232 .35748 Mtetra
.339 0 .163 r
.60232 .35748 .60767 .34291 .61934 .34209 .61401 .3533 Mtetra
.252 0 .051 r
.61401 .3533 .61934 .34209 .63106 .34074 .62572 .34846 Mtetra
.085 0 0 r
.62572 .34846 .63106 .34074 .64283 .33857 .63745 .34281 Mtetra
0 0 0 r
.63745 .34281 .64283 .33857 .65462 .3356 .64919 .33653 Mtetra
.55 .929 .821 r
.64919 .33653 .65462 .3356 .66644 .33182 .66094 .32981 Mtetra
.726 .958 .945 r
.66094 .32981 .66644 .33182 .67827 .32732 .67271 .32281 Mtetra
.761 .884 .934 r
.67271 .32281 .67827 .32732 .69011 .32219 .68451 .31568 Mtetra
.755 .815 .9 r
.68451 .31568 .69011 .32219 .70197 .31655 .69632 .30855 Mtetra
.741 .767 .874 r
.69632 .30855 .70197 .31655 .71384 .31053 .70818 .30153 Mtetra
.729 .737 .858 r
.70818 .30153 .71384 .31053 .72574 .30424 .72007 .2947 Mtetra
.718 .721 .852 r
.72007 .2947 .72574 .30424 .73766 .29785 .73201 .28813 Mtetra
.71 .714 .852 r
.73201 .28813 .73766 .29785 .74961 .29142 .74401 .28182 Mtetra
.704 .716 .858 r
.74401 .28182 .74961 .29142 .7616 .28505 .75606 .27578 Mtetra
.701 .723 .867 r
.75606 .27578 .7616 .28505 .77363 .27876 .76816 .26995 Mtetra
.699 .735 .879 r
.76816 .26995 .77363 .27876 .7857 .27255 .78032 .26428 Mtetra
.698 .751 .892 r
.78032 .26428 .7857 .27255 .79782 .26643 .79252 .25872 Mtetra
.646 .749 .924 r
.13868 .4723 .14569 .47843 .1553 .47642 .14842 .46919 Mtetra
.642 .714 .9 r
.14842 .46919 .1553 .47642 .16494 .47453 .1582 .46618 Mtetra
.632 .68 .877 r
.1582 .46618 .16494 .47453 .1746 .4728 .16799 .46337 Mtetra
.62 .649 .857 r
.16799 .46337 .1746 .4728 .18429 .47129 .17779 .46083 Mtetra
.605 .62 .84 r
.17779 .46083 .18429 .47129 .194 .47004 .18759 .45869 Mtetra
.588 .595 .827 r
.18759 .45869 .194 .47004 .20373 .46905 .19739 .457 Mtetra
.569 .574 .818 r
.19739 .457 .20373 .46905 .21349 .46833 .20719 .45586 Mtetra
.551 .558 .814 r
.20719 .45586 .21349 .46833 .22328 .46779 .21698 .45525 Mtetra
.531 .547 .816 r
.21698 .45525 .22328 .46779 .23312 .46739 .22678 .45519 Mtetra
.512 .544 .825 r
.22678 .45519 .23312 .46739 .24301 .46698 .23661 .45556 Mtetra
.491 .549 .843 r
.23661 .45556 .24301 .46698 .25297 .46647 .24646 .45629 Mtetra
.469 .567 .872 r
.24646 .45629 .25297 .46647 .26301 .4657 .25636 .45721 Mtetra
.439 .6 .913 r
.25636 .45721 .26301 .4657 .27313 .46452 .26633 .45817 Mtetra
.399 .656 .962 r
.26633 .45817 .27313 .46452 .28335 .46273 .27638 .45886 Mtetra
.328 .716 .982 r
.27638 .45886 .28335 .46273 .29368 .46016 .28654 .45901 Mtetra
.161 .69 .86 r
.28654 .45901 .29368 .46016 .30409 .45695 .29679 .45868 Mtetra
.046 0 0 r
.29679 .45868 .30409 .45695 .31459 .45317 .30714 .45782 Mtetra
.183 0 0 r
.30714 .45782 .31459 .45317 .32516 .44864 .31759 .45632 Mtetra
.263 0 0 r
.31759 .45632 .32516 .44864 .33582 .44338 .32813 .45419 Mtetra
.334 0 .069 r
.32813 .45419 .33582 .44338 .34651 .43798 .33873 .45191 Mtetra
.384 0 .165 r
.33873 .45191 .34651 .43798 .35723 .43265 .34937 .44974 Mtetra
.413 .046 .228 r
.34937 .44974 .35723 .43265 .36802 .42664 .36007 .44758 Mtetra
.438 .092 .281 r
.36007 .44758 .36802 .42664 .37887 .41969 .37081 .44549 Mtetra
.469 .142 .329 r
.37081 .44549 .37887 .41969 .38975 .41256 .38158 .44412 Mtetra
.484 .174 .364 r
.38158 .44412 .38975 .41256 .40066 .40502 .39239 .44307 Mtetra
.457 .164 .378 r
.39239 .44307 .40066 .40502 .4117 .39441 .40338 .43906 Mtetra
.43 .152 .387 r
.40338 .43906 .4117 .39441 .42283 .38078 .41452 .43155 Mtetra
.434 .162 .401 r
.41452 .43155 .42283 .38078 .43394 .3673 .42571 .42304 Mtetra
.449 .181 .414 r
.42571 .42304 .43394 .3673 .44496 .35638 .4369 .41527 Mtetra
.486 .215 .428 r
.4369 .41527 .44496 .35638 .45581 .35266 .448 .41157 Mtetra
.515 .24 .435 r
.448 .41157 .45581 .35266 .46658 .35613 .45907 .41195 Mtetra
.519 .241 .432 r
.45907 .41195 .46658 .35613 .4774 .36221 .4702 .4131 Mtetra
.511 .229 .422 r
.4702 .4131 .4774 .36221 .48833 .36847 .48142 .41325 Mtetra
.476 .191 .401 r
.48142 .41325 .48833 .36847 .4994 .37172 .49275 .40989 Mtetra
.431 .141 .371 r
.49275 .40989 .4994 .37172 .51058 .3719 .50415 .40354 Mtetra
.414 .112 .341 r
.50415 .40354 .51058 .3719 .52183 .37168 .51558 .3975 Mtetra
.4 .081 .304 r
.51558 .3975 .52183 .37168 .53315 .37128 .52704 .39218 Mtetra
.369 .03 .253 r
.52704 .39218 .53315 .37128 .54454 .36995 .53854 .38693 Mtetra
.33 0 .192 r
.53854 .38693 .54454 .36995 .55598 .36792 .55007 .38168 Mtetra
.285 0 .118 r
.55007 .38168 .55598 .36792 .56749 .36597 .56165 .37653 Mtetra
.202 0 .001 r
.56165 .37653 .56749 .36597 .57906 .3639 .57326 .37123 Mtetra
.026 0 0 r
.57326 .37123 .57906 .3639 .59067 .36107 .5849 .36527 Mtetra
0 0 0 r
.5849 .36527 .59067 .36107 .60232 .35748 .59656 .35866 Mtetra
.582 .942 .82 r
.59656 .35866 .60232 .35748 .61401 .3533 .60823 .35149 Mtetra
.756 .964 .933 r
.60823 .35149 .61401 .3533 .62572 .34846 .61991 .3438 Mtetra
.794 .879 .909 r
.61991 .3438 .62572 .34846 .63745 .34281 .6316 .33555 Mtetra
.782 .795 .863 r
.6316 .33555 .63745 .34281 .64919 .33653 .64329 .327 Mtetra
.759 .733 .828 r
.64329 .327 .64919 .33653 .66094 .32981 .655 .31847 Mtetra
.739 .689 .803 r
.655 .31847 .66094 .32981 .67271 .32281 .66674 .31012 Mtetra
.721 .659 .788 r
.66674 .31012 .67271 .32281 .68451 .31568 .67851 .30213 Mtetra
.706 .64 .781 r
.67851 .30213 .68451 .31568 .69632 .30855 .69032 .29457 Mtetra
.693 .628 .779 r
.69032 .29457 .69632 .30855 .70818 .30153 .70219 .28757 Mtetra
.683 .624 .783 r
.70219 .28757 .70818 .30153 .72007 .2947 .71413 .2811 Mtetra
.674 .625 .792 r
.71413 .2811 .72007 .2947 .73201 .28813 .72613 .27519 Mtetra
.669 .633 .805 r
.72613 .27519 .73201 .28813 .74401 .28182 .7382 .26975 Mtetra
.665 .647 .823 r
.7382 .26975 .74401 .28182 .75606 .27578 .75035 .26471 Mtetra
.662 .666 .843 r
.75035 .26471 .75606 .27578 .76816 .26995 .76256 .25996 Mtetra
.662 .691 .867 r
.76256 .25996 .76816 .26995 .78032 .26428 .77484 .2554 Mtetra
.662 .721 .892 r
.77484 .2554 .78032 .26428 .79252 .25872 .78718 .25095 Mtetra
.693 .759 .903 r
.13161 .46613 .13868 .4723 .14842 .46919 .14152 .46179 Mtetra
.684 .722 .878 r
.14152 .46179 .14842 .46919 .1582 .46618 .15145 .45752 Mtetra
.672 .686 .855 r
.15145 .45752 .1582 .46618 .16799 .46337 .16139 .45344 Mtetra
.657 .653 .835 r
.16139 .45344 .16799 .46337 .17779 .46083 .17133 .44965 Mtetra
.639 .622 .817 r
.17133 .44965 .17779 .46083 .18759 .45869 .18127 .44628 Mtetra
.621 .593 .801 r
.18127 .44628 .18759 .45869 .19739 .457 .19119 .44339 Mtetra
.601 .566 .786 r
.19119 .44339 .19739 .457 .20719 .45586 .20109 .44111 Mtetra
.584 .541 .773 r
.20109 .44111 .20719 .45586 .21698 .45525 .21098 .43937 Mtetra
.567 .519 .761 r
.21098 .43937 .21698 .45525 .22678 .45519 .22087 .4382 Mtetra
.556 .501 .749 r
.22087 .4382 .22678 .45519 .23661 .45556 .23078 .43744 Mtetra
.548 .485 .738 r
.23078 .43744 .23661 .45556 .24646 .45629 .24071 .43699 Mtetra
.543 .473 .726 r
.24071 .43699 .24646 .45629 .25636 .45721 .25068 .43674 Mtetra
.541 .463 .716 r
.25068 .43674 .25636 .45721 .26633 .45817 .26071 .43656 Mtetra
.544 .457 .707 r
.26071 .43656 .26633 .45817 .27638 .45886 .2708 .43624 Mtetra
.55 .454 .699 r
.2708 .43624 .27638 .45886 .28654 .45901 .28098 .43561 Mtetra
.554 .452 .694 r
.28098 .43561 .28654 .45901 .29679 .45868 .29124 .43478 Mtetra
.556 .452 .69 r
.29124 .43478 .29679 .45868 .30714 .45782 .30156 .43377 Mtetra
.56 .454 .69 r
.30156 .43377 .30714 .45782 .31759 .45632 .31196 .43254 Mtetra
.563 .458 .692 r
.31196 .43254 .31759 .45632 .32813 .45419 .32242 .43113 Mtetra
.563 .462 .697 r
.32242 .43113 .32813 .45419 .33873 .45191 .33293 .42978 Mtetra
.558 .465 .705 r
.33293 .42978 .33873 .45191 .34937 .44974 .34349 .42872 Mtetra
.547 .466 .715 r
.34349 .42872 .34937 .44974 .36007 .44758 .35407 .42827 Mtetra
.526 .467 .733 r
.35407 .42827 .36007 .44758 .37081 .44549 .36467 .42873 Mtetra
.473 .462 .765 r
.36467 .42873 .37081 .44549 .38158 .44412 .37526 .43082 Mtetra
.388 .464 .817 r
.37526 .43082 .38158 .44412 .39239 .44307 .38588 .43425 Mtetra
.392 .576 .912 r
.38588 .43425 .39239 .44307 .40338 .43906 .39666 .436 Mtetra
.375 .776 .985 r
.39666 .436 .40338 .43906 .41452 .43155 .40761 .4351 Mtetra
.014 0 0 r
.40761 .4351 .41452 .43155 .42571 .42304 .41868 .43253 Mtetra
.229 0 0 r
.41868 .43253 .42571 .42304 .4369 .41527 .42984 .4288 Mtetra
.322 0 .122 r
.42984 .4288 .4369 .41527 .448 .41157 .44105 .42509 Mtetra
.323 0 .122 r
.44105 .42509 .448 .41157 .45907 .41195 .4523 .42141 Mtetra
.166 0 0 r
.4523 .42141 .45907 .41195 .4702 .4131 .46361 .41655 Mtetra
.383 .814 .647 r
.46361 .41655 .4702 .4131 .48142 .41325 .475 .41002 Mtetra
.825 .909 .897 r
.475 .41002 .48142 .41325 .49275 .40989 .48644 .40079 Mtetra
.8 .742 .799 r
.48644 .40079 .49275 .40989 .50415 .40354 .49791 .38986 Mtetra
.737 .647 .759 r
.49791 .38986 .50415 .40354 .51558 .3975 .50936 .38025 Mtetra
.688 .584 .734 r
.50936 .38025 .51558 .3975 .52704 .39218 .52082 .37228 Mtetra
.661 .547 .716 r
.52082 .37228 .52704 .39218 .53854 .38693 .5323 .36521 Mtetra
.644 .525 .704 r
.5323 .36521 .53854 .38693 .55007 .38168 .54381 .35875 Mtetra
.635 .513 .697 r
.54381 .35875 .55007 .38168 .56165 .37653 .55536 .35257 Mtetra
.631 .505 .69 r
.55536 .35257 .56165 .37653 .57326 .37123 .56693 .34645 Mtetra
.63 .5 .685 r
.56693 .34645 .57326 .37123 .5849 .36527 .57854 .34012 Mtetra
.632 .5 .683 r
.57854 .34012 .5849 .36527 .59656 .35866 .59017 .33357 Mtetra
.634 .501 .683 r
.59017 .33357 .59656 .35866 .60823 .35149 .60182 .32682 Mtetra
.638 .506 .685 r
.60182 .32682 .60823 .35149 .61991 .3438 .6135 .31986 Mtetra
.645 .514 .689 r
.6135 .31986 .61991 .3438 .6316 .33555 .6252 .31256 Mtetra
.651 .523 .695 r
.6252 .31256 .6316 .33555 .64329 .327 .63692 .3051 Mtetra
.654 .532 .702 r
.63692 .3051 .64329 .327 .655 .31847 .64866 .29771 Mtetra
.657 .541 .711 r
.64866 .29771 .655 .31847 .66674 .31012 .66044 .2905 Mtetra
.658 .55 .721 r
.66044 .2905 .66674 .31012 .67851 .30213 .67226 .2836 Mtetra
.657 .559 .732 r
.67226 .2836 .67851 .30213 .69032 .29457 .68412 .27712 Mtetra
.653 .567 .745 r
.68412 .27712 .69032 .29457 .70219 .28757 .69606 .27121 Mtetra
.648 .576 .76 r
.69606 .27121 .70219 .28757 .71413 .2811 .70806 .26587 Mtetra
.642 .587 .777 r
.70806 .26587 .71413 .2811 .72613 .27519 .72015 .26114 Mtetra
.636 .6 .796 r
.72015 .26114 .72613 .27519 .7382 .26975 .73232 .25692 Mtetra
.631 .617 .819 r
.73232 .25692 .7382 .26975 .75035 .26471 .74458 .25312 Mtetra
.626 .639 .843 r
.74458 .25312 .75035 .26471 .76256 .25996 .75691 .24963 Mtetra
.623 .666 .871 r
.75691 .24963 .76256 .25996 .77484 .2554 .76932 .24633 Mtetra
.62 .698 .9 r
.76932 .24633 .77484 .2554 .78718 .25095 .7818 .24311 Mtetra
.725 .765 .884 r
.12449 .45992 .13161 .46613 .14152 .46179 .13455 .4545 Mtetra
.716 .733 .865 r
.13455 .4545 .14152 .46179 .15145 .45752 .14462 .44914 Mtetra
.704 .703 .847 r
.14462 .44914 .15145 .45752 .16139 .45344 .15471 .44392 Mtetra
.69 .674 .83 r
.15471 .44392 .16139 .45344 .17133 .44965 .16479 .43894 Mtetra
.674 .646 .814 r
.16479 .43894 .17133 .44965 .18127 .44628 .17487 .4343 Mtetra
.657 .617 .798 r
.17487 .4343 .18127 .44628 .19119 .44339 .18494 .43003 Mtetra
.64 .589 .781 r
.18494 .43003 .19119 .44339 .20109 .44111 .19499 .4262 Mtetra
.625 .562 .764 r
.19499 .4262 .20109 .44111 .21098 .43937 .20505 .42272 Mtetra
.612 .536 .745 r
.20505 .42272 .21098 .43937 .22087 .4382 .21511 .41953 Mtetra
.603 .513 .726 r
.21511 .41953 .22087 .4382 .23078 .43744 .22521 .41649 Mtetra
.596 .493 .706 r
.22521 .41649 .23078 .43744 .24071 .43699 .23534 .41347 Mtetra
.59 .473 .688 r
.23534 .41347 .24071 .43699 .25068 .43674 .24551 .41047 Mtetra
.585 .457 .672 r
.24551 .41047 .25068 .43674 .26071 .43656 .25573 .40744 Mtetra
.58 .443 .659 r
.25573 .40744 .26071 .43656 .2708 .43624 .26599 .40438 Mtetra
.577 .432 .647 r
.26599 .40438 .2708 .43624 .28098 .43561 .2763 .40126 Mtetra
.572 .421 .638 r
.2763 .40126 .28098 .43561 .29124 .43478 .28664 .39829 Mtetra
.566 .412 .632 r
.28664 .39829 .29124 .43478 .30156 .43377 .29701 .3956 Mtetra
.562 .406 .627 r
.29701 .3956 .30156 .43377 .31196 .43254 .3074 .39315 Mtetra
.558 .4 .623 r
.3074 .39315 .31196 .43254 .32242 .43113 .31783 .39097 Mtetra
.555 .397 .621 r
.31783 .39097 .32242 .43113 .33293 .42978 .32829 .38903 Mtetra
.551 .393 .62 r
.32829 .38903 .33293 .42978 .34349 .42872 .33879 .38742 Mtetra
.542 .386 .618 r
.33879 .38742 .34349 .42872 .35407 .42827 .34929 .38662 Mtetra
.529 .376 .617 r
.34929 .38662 .35407 .42827 .36467 .42873 .3598 .38704 Mtetra
.505 .358 .616 r
.3598 .38704 .36467 .42873 .37526 .43082 .37026 .38966 Mtetra
.478 .34 .615 r
.37026 .38966 .37526 .43082 .38588 .43425 .38072 .39447 Mtetra
.474 .342 .62 r
.38072 .39447 .38588 .43425 .39666 .436 .39127 .3994 Mtetra
.484 .357 .631 r
.39127 .3994 .39666 .436 .40761 .4351 .40196 .40331 Mtetra
.503 .385 .651 r
.40196 .40331 .40761 .4351 .41868 .43253 .41281 .40553 Mtetra
.54 .429 .677 r
.41281 .40553 .41868 .43253 .42984 .4288 .42381 .40531 Mtetra
.6 .486 .696 r
.42381 .40531 .42984 .4288 .44105 .42509 .43499 .40156 Mtetra
.648 .516 .689 r
.43499 .40156 .44105 .42509 .4523 .42141 .4463 .39427 Mtetra
.662 .509 .666 r
.4463 .39427 .4523 .42141 .46361 .41655 .45768 .38451 Mtetra
.66 .491 .645 r
.45768 .38451 .46361 .41655 .475 .41002 .4691 .37303 Mtetra
.653 .475 .63 r
.4691 .37303 .475 .41002 .48644 .40079 .48052 .3605 Mtetra
.644 .461 .621 r
.48052 .3605 .48644 .40079 .49791 .38986 .49193 .34805 Mtetra
.624 .445 .619 r
.49193 .34805 .49791 .38986 .50936 .38025 .50331 .33779 Mtetra
.606 .431 .618 r
.50331 .33779 .50936 .38025 .52082 .37228 .51468 .32974 Mtetra
.596 .423 .618 r
.51468 .32974 .52082 .37228 .5323 .36521 .52607 .32291 Mtetra
.589 .419 .619 r
.52607 .32291 .5323 .36521 .54381 .35875 .5375 .31689 Mtetra
.587 .418 .62 r
.5375 .31689 .54381 .35875 .55536 .35257 .54895 .3112 Mtetra
.585 .418 .622 r
.54895 .3112 .55536 .35257 .56693 .34645 .56044 .30575 Mtetra
.584 .419 .624 r
.56044 .30575 .56693 .34645 .57854 .34012 .57198 .30056 Mtetra
.583 .42 .627 r
.57198 .30056 .57854 .34012 .59017 .33357 .58356 .29562 Mtetra
.582 .424 .631 r
.58356 .29562 .59017 .33357 .60182 .32682 .59519 .29095 Mtetra
.584 .43 .638 r
.59519 .29095 .60182 .32682 .6135 .31986 .60686 .28644 Mtetra
.588 .439 .647 r
.60686 .28644 .6135 .31986 .6252 .31256 .61858 .28186 Mtetra
.593 .452 .658 r
.61858 .28186 .6252 .31256 .63692 .3051 .63035 .27724 Mtetra
.599 .466 .671 r
.63035 .27724 .63692 .3051 .64866 .29771 .64216 .27259 Mtetra
.606 .483 .687 r
.64216 .27259 .64866 .29771 .66044 .2905 .65401 .26796 Mtetra
.613 .503 .704 r
.65401 .26796 .66044 .2905 .67226 .2836 .66592 .26334 Mtetra
.617 .522 .723 r
.66592 .26334 .67226 .2836 .68412 .27712 .67788 .25887 Mtetra
.619 .54 .744 r
.67788 .25887 .68412 .27712 .69606 .27121 .6899 .2547 Mtetra
.618 .558 .765 r
.6899 .2547 .69606 .27121 .70806 .26587 .702 .25088 Mtetra
.613 .575 .787 r
.702 .25088 .70806 .26587 .72015 .26114 .71418 .24753 Mtetra
.607 .593 .811 r
.71418 .24753 .72015 .26114 .73232 .25692 .72645 .24456 Mtetra
.6 .611 .835 r
.72645 .24456 .73232 .25692 .74458 .25312 .73881 .24195 Mtetra
.593 .632 .86 r
.73881 .24195 .74458 .25312 .75691 .24963 .75125 .23958 Mtetra
.586 .656 .885 r
.75125 .23958 .75691 .24963 .76932 .24633 .76377 .23737 Mtetra
.58 .683 .911 r
.76377 .23737 .76932 .24633 .7818 .24311 .77637 .23521 Mtetra
.736 .766 .877 r
.11732 .45366 .12449 .45992 .13455 .4545 .12746 .44778 Mtetra
.732 .753 .869 r
.12746 .44778 .13455 .4545 .14462 .44914 .13762 .44191 Mtetra
.727 .739 .861 r
.13762 .44191 .14462 .44914 .15471 .44392 .14779 .43609 Mtetra
.72 .723 .852 r
.14779 .43609 .15471 .44392 .16479 .43894 .15798 .43035 Mtetra
.711 .703 .84 r
.15798 .43035 .16479 .43894 .17487 .4343 .16818 .42473 Mtetra
.702 .679 .825 r
.16818 .42473 .17487 .4343 .18494 .43003 .17839 .4192 Mtetra
.69 .652 .807 r
.17839 .4192 .18494 .43003 .19499 .4262 .18862 .41375 Mtetra
.679 .621 .784 r
.18862 .41375 .19499 .4262 .20505 .42272 .19888 .40832 Mtetra
.668 .591 .76 r
.19888 .40832 .20505 .42272 .21511 .41953 .20917 .40283 Mtetra
.655 .56 .736 r
.20917 .40283 .21511 .41953 .22521 .41649 .21948 .39732 Mtetra
.644 .534 .714 r
.21948 .39732 .22521 .41649 .23534 .41347 .22983 .39178 Mtetra
.631 .509 .696 r
.22983 .39178 .23534 .41347 .24551 .41047 .24018 .38645 Mtetra
.617 .488 .683 r
.24018 .38645 .24551 .41047 .25573 .40744 .25053 .38151 Mtetra
.605 .472 .673 r
.25053 .38151 .25573 .40744 .26599 .40438 .26087 .37703 Mtetra
.594 .459 .666 r
.26087 .37703 .26599 .40438 .2763 .40126 .2712 .3731 Mtetra
.585 .449 .663 r
.2712 .3731 .2763 .40126 .28664 .39829 .28152 .36975 Mtetra
.576 .442 .661 r
.28152 .36975 .28664 .39829 .29701 .3956 .29184 .36698 Mtetra
.572 .439 .661 r
.29184 .36698 .29701 .3956 .3074 .39315 .30219 .36453 Mtetra
.57 .438 .661 r
.30219 .36453 .3074 .39315 .31783 .39097 .31258 .36219 Mtetra
.572 .439 .661 r
.31258 .36219 .31783 .39097 .32829 .38903 .32302 .35964 Mtetra
.576 .439 .658 r
.32302 .35964 .32829 .38903 .33879 .38742 .33354 .35678 Mtetra
.573 .433 .653 r
.33354 .35678 .33879 .38742 .34929 .38662 .3441 .354 Mtetra
.563 .421 .645 r
.3441 .354 .34929 .38662 .3598 .38704 .35468 .35177 Mtetra
.537 .395 .635 r
.35468 .35177 .3598 .38704 .37026 .38966 .36521 .35145 Mtetra
.508 .368 .625 r
.36521 .35145 .37026 .38966 .38072 .39447 .3757 .35348 Mtetra
.492 .35 .616 r
.3757 .35348 .38072 .39447 .39127 .3994 .3862 .35702 Mtetra
.485 .343 .612 r
.3862 .35702 .39127 .3994 .40196 .40331 .39677 .36123 Mtetra
.496 .352 .615 r
.39677 .36123 .40196 .40331 .41281 .40553 .40748 .36453 Mtetra
.522 .373 .62 r
.40748 .36453 .41281 .40553 .42381 .40531 .41835 .36548 Mtetra
.572 .411 .625 r
.41835 .36548 .42381 .40531 .43499 .40156 .42944 .36167 Mtetra
.615 .441 .624 r
.42944 .36167 .43499 .40156 .4463 .39427 .44071 .35308 Mtetra
.631 .45 .62 r
.44071 .35308 .4463 .39427 .45768 .38451 .45204 .34213 Mtetra
.635 .451 .616 r
.45204 .34213 .45768 .38451 .4691 .37303 .46338 .33023 Mtetra
.629 .446 .616 r
.46338 .33023 .4691 .37303 .48052 .3605 .47471 .31899 Mtetra
.621 .442 .619 r
.47471 .31899 .48052 .3605 .49193 .34805 .48601 .30924 Mtetra
.606 .437 .626 r
.48601 .30924 .49193 .34805 .50331 .33779 .49729 .30184 Mtetra
.593 .434 .635 r
.49729 .30184 .50331 .33779 .51468 .32974 .50859 .29637 Mtetra
.592 .44 .645 r
.50859 .29637 .51468 .32974 .52607 .32291 .51992 .29144 Mtetra
.594 .448 .652 r
.51992 .29144 .52607 .32291 .5375 .31689 .53129 .2866 Mtetra
.601 .456 .657 r
.53129 .2866 .5375 .31689 .54895 .3112 .5427 .28143 Mtetra
.604 .46 .659 r
.5427 .28143 .54895 .3112 .56044 .30575 .55414 .27605 Mtetra
.603 .46 .66 r
.55414 .27605 .56044 .30575 .57198 .30056 .56563 .27078 Mtetra
.599 .457 .66 r
.56563 .27078 .57198 .30056 .58356 .29562 .57716 .26582 Mtetra
.592 .452 .661 r
.57716 .26582 .58356 .29562 .59519 .29095 .58874 .26145 Mtetra
.585 .449 .663 r
.58874 .26145 .59519 .29095 .60686 .28644 .60039 .25767 Mtetra
.579 .448 .667 r
.60039 .25767 .60686 .28644 .61858 .28186 .6121 .25445 Mtetra
.575 .452 .675 r
.6121 .25445 .61858 .28186 .63035 .27724 .62388 .25171 Mtetra
.571 .459 .687 r
.62388 .25171 .63035 .27724 .64216 .27259 .63574 .24937 Mtetra
.571 .472 .703 r
.63574 .24937 .64216 .27259 .65401 .26796 .64767 .24726 Mtetra
.575 .493 .724 r
.64767 .24726 .65401 .26796 .66592 .26334 .65967 .24512 Mtetra
.58 .517 .75 r
.65967 .24512 .66592 .26334 .67788 .25887 .67174 .24295 Mtetra
.584 .546 .778 r
.67174 .24295 .67788 .25887 .6899 .2547 .68387 .24073 Mtetra
.586 .576 .808 r
.68387 .24073 .6899 .2547 .702 .25088 .69607 .23853 Mtetra
.585 .603 .837 r
.69607 .23853 .702 .25088 .71418 .24753 .70834 .23642 Mtetra
.581 .628 .863 r
.70834 .23642 .71418 .24753 .72645 .24456 .72069 .23441 Mtetra
.574 .648 .885 r
.72069 .23441 .72645 .24456 .73881 .24195 .73313 .23252 Mtetra
.568 .664 .903 r
.73313 .23252 .73881 .24195 .75125 .23958 .74564 .23072 Mtetra
.562 .678 .917 r
.74564 .23072 .75125 .23958 .76377 .23737 .75823 .22897 Mtetra
.557 .691 .929 r
.75823 .22897 .76377 .23737 .77637 .23521 .7709 .22725 Mtetra
.733 .766 .879 r
.1101 .44736 .11732 .45366 .12746 .44778 .12025 .4416 Mtetra
.734 .77 .882 r
.12025 .4416 .12746 .44778 .13762 .44191 .13042 .43581 Mtetra
.736 .774 .883 r
.13042 .43581 .13762 .44191 .14779 .43609 .14063 .42995 Mtetra
.739 .774 .881 r
.14063 .42995 .14779 .43609 .15798 .43035 .15087 .42397 Mtetra
.741 .768 .874 r
.15087 .42397 .15798 .43035 .16818 .42473 .16115 .41783 Mtetra
.742 .754 .862 r
.16115 .41783 .16818 .42473 .17839 .4192 .17148 .41145 Mtetra
.742 .733 .843 r
.17148 .41145 .17839 .4192 .18862 .41375 .18186 .40475 Mtetra
.736 .703 .82 r
.18186 .40475 .18862 .41375 .19888 .40832 .1923 .39775 Mtetra
.729 .672 .794 r
.1923 .39775 .19888 .40832 .20917 .40283 .20278 .39041 Mtetra
.715 .638 .771 r
.20278 .39041 .20917 .40283 .21948 .39732 .21329 .383 Mtetra
.699 .608 .751 r
.21329 .383 .21948 .39732 .22983 .39178 .2238 .37569 Mtetra
.679 .579 .737 r
.2238 .37569 .22983 .39178 .24018 .38645 .23428 .36893 Mtetra
.656 .554 .728 r
.23428 .36893 .24018 .38645 .25053 .38151 .2447 .36309 Mtetra
.635 .535 .724 r
.2447 .36309 .25053 .38151 .26087 .37703 .25506 .35822 Mtetra
.615 .52 .724 r
.25506 .35822 .26087 .37703 .2712 .3731 .26536 .35443 Mtetra
.599 .512 .728 r
.26536 .35443 .2712 .3731 .28152 .36975 .27564 .35146 Mtetra
.587 .508 .734 r
.27564 .35146 .28152 .36975 .29184 .36698 .28591 .34914 Mtetra
.584 .511 .739 r
.28591 .34914 .29184 .36698 .30219 .36453 .29622 .34698 Mtetra
.59 .518 .742 r
.29622 .34698 .30219 .36453 .31258 .36219 .3066 .34457 Mtetra
.607 .528 .739 r
.3066 .34457 .31258 .36219 .32302 .35964 .31708 .34133 Mtetra
.627 .533 .729 r
.31708 .34133 .32302 .35964 .33354 .35678 .32768 .33692 Mtetra
.637 .528 .713 r
.32768 .33692 .33354 .35678 .3441 .354 .33837 .33151 Mtetra
.636 .51 .693 r
.33837 .33151 .3441 .354 .35468 .35177 .34913 .32548 Mtetra
.608 .473 .672 r
.34913 .32548 .35468 .35177 .36521 .35145 .35986 .32059 Mtetra
.572 .432 .652 r
.35986 .32059 .36521 .35145 .3757 .35348 .37052 .31774 Mtetra
.537 .394 .633 r
.37052 .31774 .3757 .35348 .3862 .35702 .38112 .31732 Mtetra
.512 .366 .62 r
.38112 .31732 .3862 .35702 .39677 .36123 .39169 .31899 Mtetra
.51 .361 .614 r
.39169 .31899 .39677 .36123 .40748 .36453 .40234 .32086 Mtetra
.526 .369 .612 r
.40234 .32086 .40748 .36453 .41835 .36548 .41312 .32134 Mtetra
.567 .399 .613 r
.41312 .32134 .41835 .36548 .42944 .36167 .42412 .31747 Mtetra
.604 .425 .613 r
.42412 .31747 .42944 .36167 .44071 .35308 .43528 .30924 Mtetra
.615 .433 .613 r
.43528 .30924 .44071 .35308 .45204 .34213 .44649 .2996 Mtetra
.616 .436 .616 r
.44649 .2996 .45204 .34213 .46338 .33023 .45771 .29014 Mtetra
.603 .431 .622 r
.45771 .29014 .46338 .33023 .47471 .31899 .46889 .28278 Mtetra
.587 .428 .634 r
.46889 .28278 .47471 .31899 .48601 .30924 .48006 .27785 Mtetra
.571 .431 .652 r
.48006 .27785 .48601 .30924 .49729 .30184 .49124 .27497 Mtetra
.56 .442 .675 r
.49124 .27497 .49729 .30184 .50859 .29637 .50247 .27325 Mtetra
.575 .472 .7 r
.50247 .27325 .50859 .29637 .51992 .29144 .51377 .27092 Mtetra
.598 .504 .719 r
.51377 .27092 .51992 .29144 .53129 .2866 .52512 .26757 Mtetra
.623 .531 .73 r
.52512 .26757 .53129 .2866 .5427 .28143 .53653 .26303 Mtetra
.64 .547 .733 r
.53653 .26303 .5427 .28143 .55414 .27605 .54797 .25764 Mtetra
.644 .55 .733 r
.54797 .25764 .55414 .27605 .56563 .27078 .55944 .25199 Mtetra
.64 .544 .73 r
.55944 .25199 .56563 .27078 .57716 .26582 .57095 .2465 Mtetra
.627 .532 .728 r
.57095 .2465 .57716 .26582 .58874 .26145 .58252 .24166 Mtetra
.61 .519 .726 r
.58252 .24166 .58874 .26145 .60039 .25767 .59414 .23766 Mtetra
.59 .505 .727 r
.59414 .23766 .60039 .25767 .6121 .25445 .60585 .23477 Mtetra
.571 .497 .733 r
.60585 .23477 .6121 .25445 .62388 .25171 .61764 .23287 Mtetra
.553 .494 .744 r
.61764 .23287 .62388 .25171 .63574 .24937 .62954 .23193 Mtetra
.539 .501 .762 r
.62954 .23193 .63574 .24937 .64767 .24726 .64153 .23156 Mtetra
.534 .52 .786 r
.64153 .23156 .64767 .24726 .65967 .24512 .65361 .2313 Mtetra
.532 .548 .816 r
.65361 .2313 .65967 .24512 .67174 .24295 .66577 .23099 Mtetra
.538 .585 .85 r
.66577 .23099 .67174 .24295 .68387 .24073 .67799 .23033 Mtetra
.541 .623 .883 r
.67799 .23033 .68387 .24073 .69607 .23853 .69028 .22936 Mtetra
.546 .659 .91 r
.69028 .22936 .69607 .23853 .70834 .23642 .70263 .22807 Mtetra
.549 .686 .93 r
.70263 .22807 .70834 .23642 .72069 .23441 .71505 .22654 Mtetra
.551 .704 .941 r
.71505 .22654 .72069 .23441 .73313 .23252 .72753 .22485 Mtetra
.554 .712 .946 r
.72753 .22485 .73313 .23252 .74564 .23072 .74007 .22303 Mtetra
.556 .714 .946 r
.74007 .22303 .74564 .23072 .75823 .22897 .75269 .22114 Mtetra
.558 .711 .943 r
.75269 .22114 .75823 .22897 .7709 .22725 .76539 .21923 Mtetra
.71 .762 .893 r
.10283 .44102 .1101 .44736 .12025 .4416 .1129 .43604 Mtetra
.716 .789 .909 r
.1129 .43604 .12025 .4416 .13042 .43581 .12301 .43097 Mtetra
.724 .814 .921 r
.12301 .43097 .13042 .43581 .14063 .42995 .13317 .42572 Mtetra
.735 .837 .928 r
.13317 .42572 .14063 .42995 .15087 .42397 .14339 .4202 Mtetra
.748 .854 .928 r
.14339 .4202 .15087 .42397 .16115 .41783 .15368 .41429 Mtetra
.762 .863 .924 r
.15368 .41429 .16115 .41783 .17148 .41145 .16404 .40795 Mtetra
.777 .865 .914 r
.16404 .40795 .17148 .41145 .18186 .40475 .17448 .40109 Mtetra
.786 .86 .905 r
.17448 .40109 .18186 .40475 .1923 .39775 .18497 .39387 Mtetra
.792 .853 .896 r
.18497 .39387 .1923 .39775 .20278 .39041 .19552 .38633 Mtetra
.789 .848 .895 r
.19552 .38633 .20278 .39041 .21329 .383 .20607 .37886 Mtetra
.78 .848 .902 r
.20607 .37886 .21329 .383 .2238 .37569 .2166 .37173 Mtetra
.763 .855 .919 r
.2166 .37173 .2238 .37569 .23428 .36893 .22709 .36527 Mtetra
.729 .866 .945 r
.22709 .36527 .23428 .36893 .2447 .36309 .23751 .35978 Mtetra
.693 .875 .967 r
.23751 .35978 .2447 .36309 .25506 .35822 .24789 .35505 Mtetra
.652 .873 .981 r
.24789 .35505 .25506 .35822 .26536 .35443 .25825 .35103 Mtetra
.629 .86 .986 r
.25825 .35103 .26536 .35443 .27564 .35146 .26861 .34744 Mtetra
.626 .837 .981 r
.26861 .34744 .27564 .35146 .28591 .34914 .27899 .34407 Mtetra
.637 .803 .962 r
.27899 .34407 .28591 .34914 .29622 .34698 .28941 .3407 Mtetra
.654 .766 .931 r
.28941 .3407 .29622 .34698 .3066 .34457 .2999 .33706 Mtetra
.685 .737 .89 r
.2999 .33706 .3066 .34457 .31708 .34133 .31049 .33249 Mtetra
.714 .712 .846 r
.31049 .33249 .31708 .34133 .32768 .33692 .32121 .32655 Mtetra
.736 .687 .804 r
.32121 .32655 .32768 .33692 .33837 .33151 .33205 .31891 Mtetra
.74 .653 .764 r
.33205 .31891 .33837 .33151 .34913 .32548 .34301 .30977 Mtetra
.71 .604 .736 r
.34301 .30977 .34913 .32548 .35986 .32059 .35394 .30097 Mtetra
.666 .547 .71 r
.35394 .30097 .35986 .32059 .37052 .31774 .36482 .29362 Mtetra
.609 .484 .685 r
.36482 .29362 .37052 .31774 .38112 .31732 .37558 .28904 Mtetra
.558 .432 .664 r
.37558 .28904 .38112 .31732 .39169 .31899 .38624 .28733 Mtetra
.539 .407 .649 r
.38624 .28733 .39169 .31899 .40234 .32086 .39692 .28676 Mtetra
.542 .401 .639 r
.39692 .28676 .40234 .32086 .41312 .32134 .40768 .28593 Mtetra
.577 .422 .635 r
.40768 .28593 .41312 .32134 .42412 .31747 .4186 .28201 Mtetra
.609 .444 .634 r
.4186 .28201 .42412 .31747 .43528 .30924 .42967 .27499 Mtetra
.614 .451 .638 r
.42967 .27499 .43528 .30924 .44649 .2996 .44076 .2677 Mtetra
.607 .453 .647 r
.44076 .2677 .44649 .2996 .45771 .29014 .45185 .26154 Mtetra
.579 .446 .664 r
.45185 .26154 .45771 .29014 .46889 .28278 .46291 .25828 Mtetra
.541 .441 .69 r
.46291 .25828 .46889 .28278 .48006 .27785 .47397 .25779 Mtetra
.508 .452 .728 r
.47397 .25779 .48006 .27785 .49124 .27497 .48509 .2588 Mtetra
.488 .481 .776 r
.48509 .2588 .49124 .27497 .50247 .27325 .49628 .26015 Mtetra
.525 .55 .823 r
.49628 .26015 .50247 .27325 .51377 .27092 .50757 .26 Mtetra
.579 .622 .859 r
.50757 .26 .51377 .27092 .52512 .26757 .51894 .25814 Mtetra
.627 .68 .881 r
.51894 .25814 .52512 .26757 .53653 .26303 .53037 .25489 Mtetra
.661 .73 .901 r
.53037 .25489 .53653 .26303 .54797 .25764 .54185 .25069 Mtetra
.672 .772 .925 r
.54185 .25069 .54797 .25764 .55944 .25199 .55337 .24622 Mtetra
.67 .812 .951 r
.55337 .24622 .55944 .25199 .57095 .2465 .56494 .24174 Mtetra
.651 .844 .975 r
.56494 .24174 .57095 .2465 .58252 .24166 .57656 .23749 Mtetra
.616 .855 .989 r
.57656 .23749 .58252 .24166 .59414 .23766 .58823 .23368 Mtetra
.567 .844 .997 r
.58823 .23368 .59414 .23766 .60585 .23477 .59998 .23058 Mtetra
.519 .817 .999 r
.59998 .23058 .60585 .23477 .61764 .23287 .6118 .22827 Mtetra
.461 .774 .997 r
.6118 .22827 .61764 .23287 .62954 .23193 .62373 .22697 Mtetra
.423 .741 .993 r
.62373 .22697 .62954 .23193 .64153 .23156 .63575 .22635 Mtetra
.405 .723 .989 r
.63575 .22635 .64153 .23156 .65361 .2313 .64787 .22611 Mtetra
.398 .72 .988 r
.64787 .22611 .65361 .2313 .66577 .23099 .66007 .22594 Mtetra
.414 .735 .991 r
.66007 .22594 .66577 .23099 .67799 .23033 .67235 .22545 Mtetra
.433 .753 .995 r
.67235 .22545 .67799 .23033 .69028 .22936 .68469 .22459 Mtetra
.465 .775 .997 r
.68469 .22459 .69028 .22936 .70263 .22807 .69708 .2232 Mtetra
.496 .788 .997 r
.69708 .2232 .70263 .22807 .71505 .22654 .70952 .22138 Mtetra
.529 .793 .994 r
.70952 .22138 .71505 .22654 .72753 .22485 .72201 .21915 Mtetra
.556 .787 .985 r
.72201 .21915 .72753 .22485 .74007 .22303 .73456 .21663 Mtetra
.577 .771 .971 r
.73456 .21663 .74007 .22303 .75269 .22114 .74716 .21393 Mtetra
.589 .749 .954 r
.74716 .21393 .75269 .22114 .76539 .21923 .75983 .21113 Mtetra
.668 .754 .915 r
.09551 .43462 .10283 .44102 .1129 .43604 .10545 .43082 Mtetra
.674 .795 .939 r
.10545 .43082 .1129 .43604 .12301 .43097 .11544 .42688 Mtetra
.681 .837 .958 r
.11544 .42688 .12301 .43097 .13317 .42572 .12551 .42267 Mtetra
.69 .876 .968 r
.12551 .42267 .13317 .42572 .14339 .4202 .13565 .41808 Mtetra
.704 .909 .967 r
.13565 .41808 .14339 .4202 .15368 .41429 .14588 .41297 Mtetra
.714 .935 .96 r
.14588 .41297 .15368 .41429 .16404 .40795 .1562 .40737 Mtetra
.725 .955 .948 r
.1562 .40737 .16404 .40795 .17448 .40109 .1666 .40122 Mtetra
.717 .969 .934 r
.1666 .40122 .17448 .40109 .18497 .39387 .17706 .39481 Mtetra
.688 .975 .911 r
.17706 .39481 .18497 .39387 .19552 .38633 .18754 .38832 Mtetra
.606 .954 .858 r
.18754 .38832 .19552 .38633 .20607 .37886 .19802 .38209 Mtetra
.443 .866 .739 r
.19802 .38209 .20607 .37886 .2166 .37173 .20847 .37646 Mtetra
0 0 0 r
.20847 .37646 .2166 .37173 .22709 .36527 .21889 .3714 Mtetra
.21889 .3714 .22709 .36527 .23751 .35978 .22927 .36701 Mtetra
.048 0 0 r
.22927 .36701 .23751 .35978 .24789 .35505 .23967 .36279 Mtetra
.064 0 0 r
.23967 .36279 .24789 .35505 .25825 .35103 .25013 .35841 Mtetra
.027 0 0 r
.25013 .35841 .25825 .35103 .26861 .34744 .26064 .35381 Mtetra
0 0 0 r
.26064 .35381 .26861 .34744 .27899 .34407 .27121 .34885 Mtetra
.27121 .34885 .27899 .34407 .28941 .3407 .28182 .34386 Mtetra
.339 .8 .684 r
.28182 .34386 .28941 .3407 .2999 .33706 .29246 .33887 Mtetra
.528 .92 .832 r
.29246 .33887 .2999 .33706 .31049 .33249 .30319 .33318 Mtetra
.689 .977 .903 r
.30319 .33318 .31049 .33249 .32121 .32655 .31402 .32632 Mtetra
.812 .976 .897 r
.31402 .32632 .32121 .32655 .33205 .31891 .325 .3174 Mtetra
.871 .931 .86 r
.325 .3174 .33205 .31891 .34301 .30977 .33613 .30628 Mtetra
.867 .874 .84 r
.33613 .30628 .34301 .30977 .35394 .30097 .34727 .29472 Mtetra
.83 .8 .823 r
.34727 .29472 .35394 .30097 .36482 .29362 .35837 .2839 Mtetra
.752 .708 .811 r
.35837 .2839 .36482 .29362 .37558 .28904 .36932 .27572 Mtetra
.661 .61 .787 r
.36932 .27572 .37558 .28904 .38624 .28733 .38015 .27069 Mtetra
.607 .54 .754 r
.38015 .27069 .38624 .28733 .39692 .28676 .39093 .26748 Mtetra
.583 .501 .728 r
.39093 .26748 .39692 .28676 .40768 .28593 .40172 .26506 Mtetra
.607 .504 .711 r
.40172 .26506 .40768 .28593 .4186 .28201 .41263 .2611 Mtetra
.632 .519 .707 r
.41263 .2611 .4186 .28201 .42967 .27499 .42363 .25559 Mtetra
.625 .526 .722 r
.42363 .25559 .42967 .27499 .44076 .2677 .43464 .25088 Mtetra
.598 .535 .755 r
.43464 .25088 .44076 .2677 .45185 .26154 .44564 .24799 Mtetra
.51 .531 .814 r
.44564 .24799 .45185 .26154 .46291 .25828 .45663 .24828 Mtetra
.338 .513 .883 r
.45663 .24828 .46291 .25828 .47397 .25779 .46764 .25123 Mtetra
.127 .499 .906 r
.46764 .25123 .47397 .25779 .48509 .2588 .47874 .25496 Mtetra
0 .483 .841 r
.47874 .25496 .48509 .2588 .49628 .26015 .48994 .25826 Mtetra
.043 .593 .831 r
.48994 .25826 .49628 .26015 .50757 .26 .50126 .25936 Mtetra
.168 .703 .83 r
.50126 .25936 .50757 .26 .51894 .25814 .51268 .25838 Mtetra
.217 .741 .797 r
.51268 .25838 .51894 .25814 .53037 .25489 .52417 .25622 Mtetra
.19 .716 .71 r
.52417 .25622 .53037 .25489 .54185 .25069 .53571 .25335 Mtetra
0 0 0 r
.53571 .25335 .54185 .25069 .55337 .24622 .54732 .2505 Mtetra
.051 0 0 r
.54732 .2505 .55337 .24622 .56494 .24174 .55898 .24759 Mtetra
.117 0 0 r
.55898 .24759 .56494 .24174 .57656 .23749 .5707 .24434 Mtetra
.151 0 0 r
.5707 .24434 .57656 .23749 .58823 .23368 .58247 .24085 Mtetra
.156 0 0 r
.58247 .24085 .58823 .23368 .59998 .23058 .59429 .2372 Mtetra
.144 0 0 r
.59429 .2372 .59998 .23058 .6118 .22827 .60618 .23372 Mtetra
.135 0 0 r
.60618 .23372 .6118 .22827 .62373 .22697 .61814 .23093 Mtetra
.098 0 0 r
.61814 .23093 .62373 .22697 .63575 .22635 .63018 .22874 Mtetra
.044 0 0 r
.63018 .22874 .63575 .22635 .64787 .22611 .64232 .22717 Mtetra
0 0 0 r
.64232 .22717 .64787 .22611 .66007 .22594 .65454 .22587 Mtetra
.139 .685 .776 r
.65454 .22587 .66007 .22594 .67235 .22545 .66683 .22449 Mtetra
.243 .753 .869 r
.66683 .22449 .67235 .22545 .68469 .22459 .67919 .22285 Mtetra
.357 .812 .937 r
.67919 .22285 .68469 .22459 .69708 .2232 .6916 .22064 Mtetra
.452 .846 .978 r
.6916 .22064 .69708 .2232 .70952 .22138 .70405 .21793 Mtetra
.534 .86 .996 r
.70405 .21793 .70952 .22138 .72201 .21915 .71653 .21466 Mtetra
.59 .849 .993 r
.71653 .21466 .72201 .21915 .73456 .21663 .72905 .211 Mtetra
.624 .822 .977 r
.72905 .211 .73456 .21663 .74716 .21393 .74161 .20707 Mtetra
.64 .786 .952 r
.74161 .20707 .74716 .21393 .75983 .21113 .75422 .20298 Mtetra
.609 .739 .937 r
.08813 .42819 .09551 .43462 .10545 .43082 .09792 .4257 Mtetra
.608 .785 .966 r
.09792 .4257 .10545 .43082 .11544 .42688 .10777 .42302 Mtetra
.607 .832 .986 r
.10777 .42302 .11544 .42688 .12551 .42267 .11771 .42006 Mtetra
.603 .875 .992 r
.11771 .42006 .12551 .42267 .13565 .41808 .12773 .41671 Mtetra
.601 .911 .981 r
.12773 .41671 .13565 .41808 .14588 .41297 .13785 .41282 Mtetra
.576 .928 .949 r
.13785 .41282 .14588 .41297 .1562 .40737 .14806 .40852 Mtetra
.528 .921 .887 r
.14806 .40852 .1562 .40737 .1666 .40122 .15835 .40382 Mtetra
.411 .856 .77 r
.15835 .40382 .1666 .40122 .17706 .39481 .16868 .39907 Mtetra
0 0 0 r
.16868 .39907 .17706 .39481 .18754 .38832 .17902 .39453 Mtetra
.17902 .39453 .18754 .38832 .19802 .38209 .18935 .3904 Mtetra
.155 0 0 r
.18935 .3904 .19802 .38209 .20847 .37646 .19964 .38696 Mtetra
.252 0 0 r
.19964 .38696 .20847 .37646 .21889 .3714 .20994 .38385 Mtetra
.304 0 .07 r
.20994 .38385 .21889 .3714 .22927 .36701 .22028 .3809 Mtetra
.307 0 .101 r
.22028 .3809 .22927 .36701 .23967 .36279 .23069 .37749 Mtetra
.281 0 .102 r
.23069 .37749 .23967 .36279 .25013 .35841 .24124 .37316 Mtetra
.254 0 .088 r
.24124 .37316 .25013 .35841 .26064 .35381 .25187 .36819 Mtetra
.223 0 .065 r
.25187 .36819 .26064 .35381 .27121 .34885 .26258 .3627 Mtetra
.221 0 .054 r
.26258 .3627 .27121 .34885 .28182 .34386 .27331 .35738 Mtetra
.24 0 .058 r
.27331 .35738 .28182 .34386 .29246 .33887 .28403 .35256 Mtetra
.228 0 .055 r
.28403 .35256 .29246 .33887 .30319 .33318 .29481 .34738 Mtetra
.195 0 .049 r
.29481 .34738 .30319 .33318 .31402 .32632 .3057 .34126 Mtetra
.1 0 .015 r
.3057 .34126 .31402 .32632 .325 .3174 .31676 .33284 Mtetra
0 0 0 r
.31676 .33284 .325 .3174 .33613 .30628 .328 .3217 Mtetra
.328 .3217 .33613 .30628 .34727 .29472 .33931 .30939 Mtetra
.33931 .30939 .34727 .29472 .35837 .2839 .3506 .29709 Mtetra
.3506 .29709 .35837 .2839 .36932 .27572 .36176 .28696 Mtetra
.055 0 0 r
.36176 .28696 .36932 .27572 .38015 .27069 .37278 .27982 Mtetra
.107 0 0 r
.37278 .27982 .38015 .27069 .39093 .26748 .38372 .27477 Mtetra
.131 0 0 r
.38372 .27477 .39093 .26748 .40172 .26506 .39464 .27117 Mtetra
.04 0 0 r
.39464 .27117 .40172 .26506 .41263 .2611 .40562 .26719 Mtetra
.009 0 0 r
.40562 .26719 .41263 .2611 .42363 .25559 .41666 .26283 Mtetra
.183 0 0 r
.41666 .26283 .42363 .25559 .43464 .25088 .4277 .25992 Mtetra
.354 0 .01 r
.4277 .25992 .43464 .25088 .44564 .24799 .43872 .25912 Mtetra
.488 .054 .141 r
.43872 .25912 .44564 .24799 .45663 .24828 .44975 .26133 Mtetra
.548 .134 .209 r
.44975 .26133 .45663 .24828 .46764 .25123 .46082 .26576 Mtetra
.548 .145 .23 r
.46082 .26576 .46764 .25123 .47874 .25496 .472 .27021 Mtetra
.523 .125 .228 r
.472 .27021 .47874 .25496 .48994 .25826 .4833 .27352 Mtetra
.458 .062 .199 r
.4833 .27352 .48994 .25826 .50126 .25936 .49473 .27409 Mtetra
.39 0 .159 r
.49473 .27409 .50126 .25936 .51268 .25838 .50626 .27234 Mtetra
.351 0 .127 r
.50626 .27234 .51268 .25838 .52417 .25622 .51785 .26963 Mtetra
.332 0 .108 r
.51785 .26963 .52417 .25622 .53571 .25335 .52951 .26657 Mtetra
.347 0 .111 r
.52951 .26657 .53571 .25335 .54732 .2505 .54122 .26401 Mtetra
.358 0 .121 r
.54122 .26401 .54732 .2505 .55898 .24759 .553 .26163 Mtetra
.347 0 .127 r
.553 .26163 .55898 .24759 .5707 .24434 .56484 .25872 Mtetra
.33 0 .127 r
.56484 .25872 .5707 .24434 .58247 .24085 .57673 .25516 Mtetra
.298 0 .113 r
.57673 .25516 .58247 .24085 .59429 .2372 .58865 .25066 Mtetra
.268 0 .083 r
.58865 .25066 .59429 .2372 .60618 .23372 .60061 .24567 Mtetra
.244 0 .038 r
.60061 .24567 .60618 .23372 .61814 .23093 .61263 .24085 Mtetra
.208 0 0 r
.61263 .24085 .61814 .23093 .63018 .22874 .6247 .23636 Mtetra
.168 0 0 r
.6247 .23636 .63018 .22874 .64232 .22717 .63685 .23257 Mtetra
.095 0 0 r
.63685 .23257 .64232 .22717 .65454 .22587 .64907 .22921 Mtetra
0 0 0 r
.64907 .22921 .65454 .22587 .66683 .22449 .66137 .22608 Mtetra
.66137 .22608 .66683 .22449 .67919 .22285 .67372 .22288 Mtetra
.334 .817 .833 r
.67372 .22288 .67919 .22285 .6916 .22064 .68612 .21928 Mtetra
.476 .886 .937 r
.68612 .21928 .6916 .22064 .70405 .21793 .69856 .21524 Mtetra
.586 .907 .98 r
.69856 .21524 .70405 .21793 .71653 .21466 .71102 .21063 Mtetra
.649 .89 .983 r
.71102 .21063 .71653 .21466 .72905 .211 .7235 .20561 Mtetra
.681 .854 .965 r
.7235 .20561 .72905 .211 .74161 .20707 .73602 .20029 Mtetra
.693 .811 .938 r
.73602 .20029 .74161 .20707 .75422 .20298 .74857 .19475 Mtetra
.538 .715 .954 r
.0807 .4217 .08813 .42819 .09792 .4257 .09034 .42041 Mtetra
.531 .757 .979 r
.09034 .42041 .09792 .4257 .10777 .42302 .10006 .41892 Mtetra
.52 .797 .996 r
.10006 .41892 .10777 .42302 .11771 .42006 .10987 .41716 Mtetra
.504 .834 .999 r
.10987 .41716 .11771 .42006 .12773 .41671 .11976 .41508 Mtetra
.485 .863 .981 r
.11976 .41508 .12773 .41671 .13785 .41282 .12976 .41253 Mtetra
.422 .859 .925 r
.12976 .41253 .13785 .41282 .14806 .40852 .13983 .40974 Mtetra
.311 .802 .809 r
.13983 .40974 .14806 .40852 .15835 .40382 .14996 .40679 Mtetra
0 0 0 r
.14996 .40679 .15835 .40382 .16868 .39907 .16012 .40402 Mtetra
.085 0 0 r
.16012 .40402 .16868 .39907 .17902 .39453 .17026 .40173 Mtetra
.235 0 0 r
.17026 .40173 .17902 .39453 .18935 .3904 .18041 .39992 Mtetra
.334 0 .009 r
.18041 .39992 .18935 .3904 .19964 .38696 .19054 .3987 Mtetra
.367 0 .088 r
.19054 .3987 .19964 .38696 .20994 .38385 .20074 .39742 Mtetra
.368 0 .126 r
.20074 .39742 .20994 .38385 .22028 .3809 .21104 .39565 Mtetra
.34 0 .131 r
.21104 .39565 .22028 .3809 .23069 .37749 .22149 .39282 Mtetra
.286 0 .11 r
.22149 .39282 .23069 .37749 .24124 .37316 .23213 .38846 Mtetra
.252 0 .091 r
.23213 .38846 .24124 .37316 .25187 .36819 .24288 .38331 Mtetra
.233 0 .078 r
.24288 .38331 .25187 .36819 .26258 .3627 .25369 .37779 Mtetra
.263 0 .095 r
.25369 .37779 .26258 .3627 .27331 .35738 .26448 .37292 Mtetra
.321 0 .133 r
.26448 .37292 .27331 .35738 .28403 .35256 .27521 .36925 Mtetra
.341 0 .162 r
.27521 .36925 .28403 .35256 .29481 .34738 .28598 .36574 Mtetra
.341 0 .184 r
.28598 .36574 .29481 .34738 .3057 .34126 .29682 .36167 Mtetra
.291 0 .184 r
.29682 .36167 .3057 .34126 .31676 .33284 .30787 .35528 Mtetra
.222 0 .174 r
.30787 .35528 .31676 .33284 .328 .3217 .31914 .34589 Mtetra
.195 0 .179 r
.31914 .34589 .328 .3217 .33931 .30939 .33053 .33475 Mtetra
.192 0 .189 r
.33053 .33475 .33931 .30939 .3506 .29709 .34195 .32286 Mtetra
.243 0 .216 r
.34195 .32286 .3506 .29709 .36176 .28696 .35328 .31245 Mtetra
.305 0 .241 r
.35328 .31245 .36176 .28696 .37278 .27982 .36449 .30445 Mtetra
.348 .016 .253 r
.36449 .30445 .37278 .27982 .38372 .27477 .37562 .29844 Mtetra
.381 .041 .259 r
.37562 .29844 .38372 .27477 .39464 .27117 .3867 .29409 Mtetra
.385 .041 .255 r
.3867 .29409 .39464 .27117 .40562 .26719 .39782 .2901 Mtetra
.394 .049 .258 r
.39782 .2901 .40562 .26719 .41666 .26283 .40896 .28648 Mtetra
.433 .088 .279 r
.40896 .28648 .41666 .26283 .4277 .25992 .4201 .28452 Mtetra
.473 .129 .301 r
.4201 .28452 .4277 .25992 .43872 .25912 .43124 .28457 Mtetra
.513 .169 .321 r
.43124 .28457 .43872 .25912 .44975 .26133 .44239 .28707 Mtetra
.534 .189 .329 r
.44239 .28707 .44975 .26133 .46082 .26576 .4536 .29107 Mtetra
.524 .177 .321 r
.4536 .29107 .46082 .26576 .472 .27021 .46493 .29434 Mtetra
.496 .146 .303 r
.46493 .29434 .472 .27021 .4833 .27352 .4764 .29587 Mtetra
.437 .084 .267 r
.4764 .29587 .4833 .27352 .49473 .27409 .48798 .29436 Mtetra
.374 .016 .223 r
.48798 .29436 .49473 .27409 .50626 .27234 .49966 .29051 Mtetra
.341 0 .185 r
.49966 .29051 .50626 .27234 .51785 .26963 .51139 .2861 Mtetra
.328 0 .155 r
.51139 .2861 .51785 .26963 .52951 .26657 .52317 .28184 Mtetra
.353 0 .146 r
.52317 .28184 .52951 .26657 .54122 .26401 .535 .2788 Mtetra
.368 0 .144 r
.535 .2788 .54122 .26401 .553 .26163 .54689 .27643 Mtetra
.357 0 .139 r
.54689 .27643 .553 .26163 .56484 .25872 .55885 .27369 Mtetra
.334 0 .133 r
.55885 .27369 .56484 .25872 .57673 .25516 .57086 .27013 Mtetra
.283 0 .113 r
.57086 .27013 .57673 .25516 .58865 .25066 .5829 .265 Mtetra
.234 0 .082 r
.5829 .265 .58865 .25066 .60061 .24567 .59495 .25878 Mtetra
.188 0 .038 r
.59495 .25878 .60061 .24567 .61263 .24085 .60704 .25203 Mtetra
.131 0 0 r
.60704 .25203 .61263 .24085 .6247 .23636 .61915 .24522 Mtetra
.077 0 0 r
.61915 .24522 .6247 .23636 .63685 .23257 .63132 .239 Mtetra
0 0 0 r
.63132 .239 .63685 .23257 .64907 .22921 .64354 .23327 Mtetra
.64354 .23327 .64907 .22921 .66137 .22608 .65583 .22803 Mtetra
.295 .776 .686 r
.65583 .22803 .66137 .22608 .67372 .22288 .66818 .22297 Mtetra
.465 .891 .856 r
.66818 .22297 .67372 .22288 .68612 .21928 .68057 .21775 Mtetra
.588 .934 .945 r
.68057 .21775 .68612 .21928 .69856 .21524 .69299 .21225 Mtetra
.671 .931 .97 r
.69299 .21225 .69856 .21524 .71102 .21063 .70543 .20627 Mtetra
.712 .9 .963 r
.70543 .20627 .71102 .21063 .7235 .20561 .71789 .19994 Mtetra
.73 .861 .943 r
.71789 .19994 .7235 .20561 .73602 .20029 .73037 .19331 Mtetra
.735 .821 .918 r
.73037 .19331 .73602 .20029 .74857 .19475 .74288 .18646 Mtetra
.483 .694 .961 r
.07322 .41517 .0807 .4217 .09034 .42041 .08277 .41464 Mtetra
.478 .72 .977 r
.08277 .41464 .09034 .42041 .10006 .41892 .0924 .41393 Mtetra
.471 .747 .989 r
.0924 .41393 .10006 .41892 .10987 .41716 .10211 .41302 Mtetra
.46 .775 .997 r
.10211 .41302 .10987 .41716 .11976 .41508 .1119 .4119 Mtetra
.445 .802 .997 r
.1119 .4119 .11976 .41508 .12976 .41253 .12178 .41048 Mtetra
.384 .807 .971 r
.12178 .41048 .12976 .41253 .13983 .40974 .13173 .409 Mtetra
.268 .766 .889 r
.13173 .409 .13983 .40974 .14996 .40679 .14171 .40762 Mtetra
.08 .639 .709 r
.14171 .40762 .14996 .40679 .16012 .40402 .15171 .40655 Mtetra
.13 0 0 r
.15171 .40655 .16012 .40402 .17026 .40173 .1617 .40605 Mtetra
.253 0 0 r
.1617 .40605 .17026 .40173 .18041 .39992 .17172 .40583 Mtetra
.322 0 0 r
.17172 .40583 .18041 .39992 .19054 .3987 .18179 .4058 Mtetra
.309 0 0 r
.18179 .4058 .19054 .3987 .20074 .39742 .19198 .40512 Mtetra
.239 0 0 r
.19198 .40512 .20074 .39742 .21104 .39565 .20236 .40317 Mtetra
.111 0 0 r
.20236 .40317 .21104 .39565 .22149 .39282 .21294 .39967 Mtetra
0 0 0 r
.21294 .39967 .22149 .39282 .23213 .38846 .22375 .39431 Mtetra
.22375 .39431 .23213 .38846 .24288 .38331 .23463 .38835 Mtetra
.23463 .38835 .24288 .38331 .25369 .37779 .24553 .38261 Mtetra
.24553 .38261 .25369 .37779 .26448 .37292 .25633 .37835 Mtetra
.145 0 0 r
.25633 .37835 .26448 .37292 .27521 .36925 .267 .37632 Mtetra
.288 0 0 r
.267 .37632 .27521 .36925 .28598 .36574 .27764 .37533 Mtetra
.356 0 .018 r
.27764 .37533 .28598 .36574 .29682 .36167 .28832 .37458 Mtetra
.325 0 .082 r
.28832 .37458 .29682 .36167 .30787 .35528 .2992 .372 Mtetra
.27 0 .121 r
.2992 .372 .30787 .35528 .31914 .34589 .31032 .36659 Mtetra
.257 0 .167 r
.31032 .36659 .31914 .34589 .33053 .33475 .3216 .35912 Mtetra
.262 0 .206 r
.3216 .35912 .33053 .33475 .34195 .32286 .333 .35024 Mtetra
.309 0 .249 r
.333 .35024 .34195 .32286 .35328 .31245 .34437 .34193 Mtetra
.357 .039 .282 r
.34437 .34193 .35328 .31245 .36449 .30445 .35568 .33508 Mtetra
.389 .071 .301 r
.35568 .33508 .36449 .30445 .37562 .29844 .36695 .32955 Mtetra
.412 .094 .313 r
.36695 .32955 .37562 .29844 .3867 .29409 .37819 .32524 Mtetra
.418 .099 .315 r
.37819 .32524 .3867 .29409 .39782 .2901 .38947 .32125 Mtetra
.424 .104 .317 r
.38947 .32125 .39782 .2901 .40896 .28648 .40078 .31759 Mtetra
.443 .121 .324 r
.40078 .31759 .40896 .28648 .4201 .28452 .4121 .31515 Mtetra
.463 .137 .328 r
.4121 .31515 .4201 .28452 .43124 .28457 .42343 .31405 Mtetra
.482 .151 .328 r
.42343 .31405 .43124 .28457 .44239 .28707 .43479 .31442 Mtetra
.489 .15 .318 r
.43479 .31442 .44239 .28707 .4536 .29107 .44622 .31539 Mtetra
.46 .112 .287 r
.44622 .31539 .4536 .29107 .46493 .29434 .45776 .31495 Mtetra
.404 .042 .233 r
.45776 .31495 .46493 .29434 .4764 .29587 .46942 .31243 Mtetra
.286 0 .132 r
.46942 .31243 .4764 .29587 .48798 .29436 .48117 .30705 Mtetra
.127 0 0 r
.48117 .30705 .48798 .29436 .49966 .29051 .49299 .2998 Mtetra
.009 0 0 r
.49299 .2998 .49966 .29051 .51139 .2861 .50483 .29277 Mtetra
0 0 0 r
.50483 .29277 .51139 .2861 .52317 .28184 .5167 .2868 Mtetra
.016 0 0 r
.5167 .2868 .52317 .28184 .535 .2788 .52861 .2831 Mtetra
.099 0 0 r
.52861 .2831 .535 .2788 .54689 .27643 .54059 .28091 Mtetra
.129 0 0 r
.54059 .28091 .54689 .27643 .55885 .27369 .55263 .27895 Mtetra
.126 0 0 r
.55263 .27895 .55885 .27369 .57086 .27013 .56474 .27639 Mtetra
.044 0 0 r
.56474 .27639 .57086 .27013 .5829 .265 .57688 .27191 Mtetra
0 0 0 r
.57688 .27191 .5829 .265 .59495 .25878 .58904 .26583 Mtetra
.58904 .26583 .59495 .25878 .60704 .25203 .6012 .25842 Mtetra
.6012 .25842 .60704 .25203 .61915 .24522 .61338 .25035 Mtetra
.61338 .25035 .61915 .24522 .63132 .239 .62559 .24244 Mtetra
.385 .805 .613 r
.62559 .24244 .63132 .239 .64354 .23327 .63783 .23481 Mtetra
.496 .897 .768 r
.63783 .23481 .64354 .23327 .65583 .22803 .65012 .22776 Mtetra
.6 .951 .888 r
.65012 .22776 .65583 .22803 .66818 .22297 .66247 .22102 Mtetra
.674 .956 .948 r
.66247 .22102 .66818 .22297 .68057 .21775 .67485 .21437 Mtetra
.714 .931 .961 r
.67485 .21437 .68057 .21775 .69299 .21225 .68727 .20764 Mtetra
.74 .899 .95 r
.68727 .20764 .69299 .21225 .70543 .20627 .6997 .2006 Mtetra
.751 .867 .933 r
.6997 .2006 .70543 .20627 .71789 .19994 .71216 .19332 Mtetra
.755 .839 .915 r
.71216 .19332 .71789 .19994 .73037 .19331 .72464 .18581 Mtetra
.755 .813 .898 r
.72464 .18581 .73037 .19331 .74288 .18646 .73713 .1781 Mtetra
.459 .684 .963 r
.06568 .40859 .07322 .41517 .08277 .41464 .0752 .40834 Mtetra
.463 .696 .968 r
.0752 .40834 .08277 .41464 .0924 .41393 .0848 .40794 Mtetra
.463 .709 .975 r
.0848 .40794 .0924 .41393 .10211 .41302 .09447 .40743 Mtetra
.459 .722 .982 r
.09447 .40743 .10211 .41302 .1119 .4119 .10421 .40684 Mtetra
.45 .739 .99 r
.10421 .40684 .1119 .4119 .12178 .41048 .11402 .40613 Mtetra
.409 .747 .994 r
.11402 .40613 .12178 .41048 .13173 .409 .12387 .40555 Mtetra
.325 .737 .978 r
.12387 .40555 .13173 .409 .14171 .40762 .13375 .40526 Mtetra
.195 .692 .916 r
.13375 .40526 .14171 .40762 .15171 .40655 .14364 .40534 Mtetra
.018 .586 .781 r
.14364 .40534 .15171 .40655 .1617 .40605 .15353 .40595 Mtetra
.076 0 0 r
.15353 .40595 .1617 .40605 .17172 .40583 .16349 .40656 Mtetra
.097 0 0 r
.16349 .40656 .17172 .40583 .18179 .4058 .17356 .40684 Mtetra
0 0 0 r
.17356 .40684 .18179 .4058 .19198 .40512 .18381 .40595 Mtetra
.307 .8 .825 r
.18381 .40595 .19198 .40512 .20236 .40317 .19433 .40313 Mtetra
.569 .929 .937 r
.19433 .40313 .20236 .40317 .21294 .39967 .20507 .39847 Mtetra
.735 .949 .949 r
.20507 .39847 .21294 .39967 .22375 .39431 .21603 .39189 Mtetra
.758 .918 .943 r
.21603 .39189 .22375 .39431 .23463 .38835 .22704 .3851 Mtetra
.726 .891 .955 r
.22704 .3851 .23463 .38835 .24553 .38261 .23799 .37926 Mtetra
.605 .864 .992 r
.23799 .37926 .24553 .38261 .25633 .37835 .24876 .37572 Mtetra
.264 .73 .947 r
.24876 .37572 .25633 .37835 .267 .37632 .25932 .37539 Mtetra
.127 0 0 r
.25932 .37539 .267 .37632 .27764 .37533 .26979 .377 Mtetra
.38 0 0 r
.26979 .377 .27764 .37533 .28832 .37458 .28026 .37969 Mtetra
.395 0 0 r
.28026 .37969 .28832 .37458 .2992 .372 .29089 .38125 Mtetra
.343 0 0 r
.29089 .38125 .2992 .372 .31032 .36659 .30178 .38043 Mtetra
.32 0 .092 r
.30178 .38043 .31032 .36659 .3216 .35912 .31287 .37748 Mtetra
.311 0 .16 r
.31287 .37748 .3216 .35912 .333 .35024 .32414 .37266 Mtetra
.342 0 .22 r
.32414 .37266 .333 .35024 .34437 .34193 .33546 .36751 Mtetra
.374 .037 .259 r
.33546 .36751 .34437 .34193 .35568 .33508 .3468 .36273 Mtetra
.395 .064 .282 r
.3468 .36273 .35568 .33508 .36695 .32955 .35816 .3584 Mtetra
.408 .08 .294 r
.35816 .3584 .36695 .32955 .37819 .32524 .36954 .35453 Mtetra
.408 .082 .297 r
.36954 .35453 .37819 .32524 .38947 .32125 .38098 .35054 Mtetra
.407 .08 .296 r
.38098 .35054 .38947 .32125 .40078 .31759 .39247 .34644 Mtetra
.413 .085 .296 r
.39247 .34644 .40078 .31759 .4121 .31515 .40398 .3428 Mtetra
.417 .084 .29 r
.40398 .3428 .4121 .31515 .42343 .31405 .41554 .33961 Mtetra
.417 .075 .276 r
.41554 .33961 .42343 .31405 .43479 .31442 .42714 .33679 Mtetra
.395 .041 .242 r
.42714 .33679 .43479 .31442 .44622 .31539 .43881 .33365 Mtetra
.313 0 .163 r
.43881 .33365 .44622 .31539 .45776 .31495 .45057 .32862 Mtetra
.148 0 .009 r
.45057 .32862 .45776 .31495 .46942 .31243 .46243 .32143 Mtetra
0 0 0 r
.46243 .32143 .46942 .31243 .48117 .30705 .47435 .31181 Mtetra
.582 .898 .632 r
.47435 .31181 .48117 .30705 .49299 .2998 .4863 .30101 Mtetra
.737 .992 .836 r
.4863 .30101 .49299 .2998 .50483 .29277 .49824 .29129 Mtetra
.742 .969 .932 r
.49824 .29129 .50483 .29277 .5167 .2868 .51018 .28354 Mtetra
.62 .893 .988 r
.51018 .28354 .5167 .2868 .52861 .2831 .52214 .27904 Mtetra
.487 .814 1 r
.52214 .27904 .52861 .2831 .54059 .28091 .53416 .2769 Mtetra
.406 .776 .994 r
.53416 .2769 .54059 .28091 .55263 .27895 .54625 .27574 Mtetra
.38 .788 .982 r
.54625 .27574 .55263 .27895 .56474 .27639 .55842 .27437 Mtetra
.475 .87 .967 r
.55842 .27437 .56474 .27639 .57688 .27191 .57064 .27103 Mtetra
.552 .925 .929 r
.57064 .27103 .57688 .27191 .58904 .26583 .58288 .26579 Mtetra
.633 .963 .886 r
.58288 .26579 .58904 .26583 .6012 .25842 .59512 .25857 Mtetra
.69 .981 .869 r
.59512 .25857 .6012 .25842 .61338 .25035 .60737 .2501 Mtetra
.722 .987 .879 r
.60737 .2501 .61338 .25035 .62559 .24244 .61962 .24129 Mtetra
.753 .985 .904 r
.61962 .24129 .62559 .24244 .63783 .23481 .6319 .23246 Mtetra
.761 .965 .93 r
.6319 .23246 .63783 .23481 .65012 .22776 .64421 .22416 Mtetra
.765 .933 .94 r
.64421 .22416 .65012 .22776 .66247 .22102 .65656 .21622 Mtetra
.761 .896 .937 r
.65656 .21622 .66247 .22102 .67485 .21437 .66896 .20859 Mtetra
.758 .864 .927 r
.66896 .20859 .67485 .21437 .68727 .20764 .68139 .20105 Mtetra
.759 .84 .913 r
.68139 .20105 .68727 .20764 .6997 .2006 .69384 .1934 Mtetra
.758 .822 .902 r
.69384 .1934 .6997 .2006 .71216 .19332 .70632 .18563 Mtetra
.759 .809 .893 r
.70632 .18563 .71216 .19332 .72464 .18581 .71882 .17774 Mtetra
.76 .799 .885 r
.71882 .17774 .72464 .18581 .73713 .1781 .73134 .16968 Mtetra
.486 .695 .961 r
.05808 .40196 .06568 .40859 .0752 .40834 .06767 .40135 Mtetra
.499 .689 .952 r
.06767 .40135 .0752 .40834 .0848 .40794 .07732 .40063 Mtetra
.507 .682 .945 r
.07732 .40063 .0848 .40794 .09447 .40743 .08703 .39987 Mtetra
.51 .676 .939 r
.08703 .39987 .09447 .40743 .10421 .40684 .0968 .39911 Mtetra
.51 .671 .936 r
.0968 .39911 .10421 .40684 .11402 .40613 .10663 .39837 Mtetra
.498 .665 .937 r
.10663 .39837 .11402 .40613 .12387 .40555 .11648 .39782 Mtetra
.472 .656 .941 r
.11648 .39782 .12387 .40555 .13375 .40526 .12635 .39765 Mtetra
.446 .649 .945 r
.12635 .39765 .13375 .40526 .14364 .40534 .13624 .39779 Mtetra
.413 .637 .948 r
.13624 .39779 .14364 .40534 .15353 .40595 .14615 .39833 Mtetra
.431 .644 .947 r
.14615 .39833 .15353 .40595 .16349 .40656 .15615 .39866 Mtetra
.48 .658 .939 r
.15615 .39866 .16349 .40656 .17356 .40684 .16629 .39838 Mtetra
.564 .676 .915 r
.16629 .39838 .17356 .40684 .18381 .40595 .17663 .39672 Mtetra
.646 .688 .875 r
.17663 .39672 .18381 .40595 .19433 .40313 .18725 .39302 Mtetra
.69 .684 .839 r
.18725 .39302 .19433 .40313 .20507 .39847 .19809 .38761 Mtetra
.718 .679 .811 r
.19809 .38761 .20507 .39847 .21603 .39189 .20911 .38061 Mtetra
.711 .669 .808 r
.20911 .38061 .21603 .39189 .22704 .3851 .22013 .37381 Mtetra
.679 .658 .822 r
.22013 .37381 .22704 .3851 .23799 .37926 .23105 .3685 Mtetra
.602 .638 .858 r
.23105 .3685 .23799 .37926 .24876 .37572 .24175 .36593 Mtetra
.426 .578 .901 r
.24175 .36593 .24876 .37572 .25932 .37539 .25219 .36697 Mtetra
.199 .495 .903 r
.25219 .36697 .25932 .37539 .26979 .377 .26252 .3704 Mtetra
0 .375 .822 r
.26252 .3704 .26979 .377 .28026 .37969 .27282 .37535 Mtetra
0 .366 .752 r
.27282 .37535 .28026 .37969 .29089 .38125 .28327 .37968 Mtetra
.165 0 0 r
.28327 .37968 .29089 .38125 .30178 .38043 .29396 .38208 Mtetra
.158 0 0 r
.29396 .38208 .30178 .38043 .31287 .37748 .30488 .38242 Mtetra
.144 0 0 r
.30488 .38242 .31287 .37748 .32414 .37266 .31602 .38069 Mtetra
.201 0 0 r
.31602 .38069 .32414 .37266 .33546 .36751 .32727 .37801 Mtetra
.247 0 0 r
.32727 .37801 .33546 .36751 .3468 .36273 .33861 .3749 Mtetra
.273 0 .025 r
.33861 .3749 .3468 .36273 .35816 .3584 .35001 .37155 Mtetra
.284 0 .054 r
.35001 .37155 .35816 .3584 .36954 .35453 .36147 .36803 Mtetra
.271 0 .055 r
.36147 .36803 .36954 .35453 .38098 .35054 .37301 .36403 Mtetra
.251 0 .045 r
.37301 .36403 .38098 .35054 .39247 .34644 .38462 .35955 Mtetra
.237 0 .029 r
.38462 .35955 .39247 .34644 .40398 .3428 .39628 .35489 Mtetra
.203 0 0 r
.39628 .35489 .40398 .3428 .41554 .33961 .408 .34999 Mtetra
.131 0 0 r
.408 .34999 .41554 .33961 .42714 .33679 .41978 .34466 Mtetra
0 0 0 r
.41978 .34466 .42714 .33679 .43881 .33365 .43162 .33837 Mtetra
.436 .828 .608 r
.43162 .33837 .43881 .33365 .45057 .32862 .44356 .32996 Mtetra
.774 .997 .834 r
.44356 .32996 .45057 .32862 .46243 .32143 .45556 .31946 Mtetra
.88 .947 .851 r
.45556 .31946 .46243 .32143 .47435 .31181 .4676 .30697 Mtetra
.876 .871 .829 r
.4676 .30697 .47435 .31181 .4863 .30101 .47964 .29382 Mtetra
.833 .811 .829 r
.47964 .29382 .4863 .30101 .49824 .29129 .49164 .28219 Mtetra
.775 .757 .836 r
.49164 .28219 .49824 .29129 .51018 .28354 .50363 .27297 Mtetra
.683 .693 .854 r
.50363 .27297 .51018 .28354 .52214 .27904 .51562 .26742 Mtetra
.598 .633 .857 r
.51562 .26742 .52214 .27904 .53416 .2769 .52765 .26467 Mtetra
.547 .596 .854 r
.52765 .26467 .53416 .2769 .54625 .27574 .53976 .26343 Mtetra
.539 .591 .855 r
.53976 .26343 .54625 .27574 .55842 .27437 .55194 .26242 Mtetra
.592 .627 .855 r
.55194 .26242 .55842 .27437 .57064 .27103 .56418 .25979 Mtetra
.646 .668 .857 r
.56418 .25979 .57064 .27103 .58288 .26579 .57647 .25539 Mtetra
.706 .712 .854 r
.57647 .25539 .58288 .26579 .59512 .25857 .58876 .24887 Mtetra
.744 .743 .851 r
.58876 .24887 .59512 .25857 .60737 .2501 .60105 .24094 Mtetra
.762 .763 .853 r
.60105 .24094 .60737 .2501 .61962 .24129 .61336 .23234 Mtetra
.769 .771 .854 r
.61336 .23234 .61962 .24129 .6319 .23246 .62567 .22352 Mtetra
.761 .77 .86 r
.62567 .22352 .6319 .23246 .64421 .22416 .63803 .21509 Mtetra
.753 .765 .863 r
.63803 .21509 .64421 .22416 .65656 .21622 .65041 .20697 Mtetra
.743 .758 .865 r
.65041 .20697 .65656 .21622 .66896 .20859 .66285 .19922 Mtetra
.737 .755 .866 r
.66285 .19922 .66896 .20859 .68139 .20105 .67532 .19167 Mtetra
.737 .755 .867 r
.67532 .19167 .68139 .20105 .69384 .1934 .68782 .18412 Mtetra
.738 .759 .87 r
.68782 .18412 .69384 .1934 .70632 .18563 .70035 .17655 Mtetra
.741 .766 .873 r
.70035 .17655 .70632 .18563 .71882 .17774 .71291 .16892 Mtetra
.746 .776 .878 r
.71291 .16892 .71882 .17774 .73134 .16968 .7255 .16118 Mtetra
.544 .717 .953 r
.05043 .39529 .05808 .40196 .06767 .40135 .06015 .39382 Mtetra
.555 .694 .933 r
.06015 .39382 .06767 .40135 .07732 .40063 .06992 .3923 Mtetra
.56 .672 .913 r
.06992 .3923 .07732 .40063 .08703 .39987 .07975 .39078 Mtetra
.56 .652 .897 r
.07975 .39078 .08703 .39987 .0968 .39911 .08962 .38932 Mtetra
.557 .633 .882 r
.08962 .38932 .0968 .39911 .10663 .39837 .09952 .38796 Mtetra
.549 .615 .871 r
.09952 .38796 .10663 .39837 .11648 .39782 .10946 .38682 Mtetra
.534 .595 .861 r
.10946 .38682 .11648 .39782 .12635 .39765 .1194 .38605 Mtetra
.525 .578 .851 r
.1194 .38605 .12635 .39765 .13624 .39779 .12937 .38552 Mtetra
.517 .561 .839 r
.12937 .38552 .13624 .39779 .14615 .39833 .13937 .38523 Mtetra
.532 .554 .823 r
.13937 .38523 .14615 .39833 .15615 .39866 .14947 .38462 Mtetra
.559 .553 .803 r
.14947 .38462 .15615 .39866 .16629 .39838 .15972 .38328 Mtetra
.595 .557 .781 r
.15972 .38328 .16629 .39838 .17663 .39672 .17017 .38062 Mtetra
.634 .566 .76 r
.17017 .38062 .17663 .39672 .18725 .39302 .18086 .37611 Mtetra
.657 .569 .745 r
.18086 .37611 .18725 .39302 .19809 .38761 .19174 .37021 Mtetra
.673 .574 .735 r
.19174 .37021 .19809 .38761 .20911 .38061 .20277 .36318 Mtetra
.664 .569 .738 r
.20277 .36318 .20911 .38061 .22013 .37381 .21376 .35666 Mtetra
.635 .556 .748 r
.21376 .35666 .22013 .37381 .23105 .3685 .22462 .35186 Mtetra
.574 .528 .766 r
.22462 .35186 .23105 .3685 .24175 .36593 .23526 .34982 Mtetra
.464 .472 .782 r
.23526 .34982 .24175 .36593 .25219 .36697 .24565 .35131 Mtetra
.359 .417 .785 r
.24565 .35131 .25219 .36697 .26252 .3704 .25591 .35521 Mtetra
.265 .368 .782 r
.25591 .35521 .26252 .3704 .27282 .37535 .26614 .36078 Mtetra
.266 .381 .794 r
.26614 .36078 .27282 .37535 .28327 .37968 .27649 .36611 Mtetra
.328 .439 .822 r
.27649 .36611 .28327 .37968 .29396 .38208 .28706 .37 Mtetra
.399 .513 .858 r
.28706 .37 .29396 .38208 .30488 .38242 .29786 .37211 Mtetra
.48 .6 .895 r
.29786 .37211 .30488 .38242 .31602 .38069 .30888 .37224 Mtetra
.524 .674 .932 r
.30888 .37224 .31602 .38069 .32727 .37801 .32005 .37114 Mtetra
.554 .738 .962 r
.32005 .37114 .32727 .37801 .33861 .3749 .33135 .36915 Mtetra
.576 .786 .978 r
.33135 .36915 .33861 .3749 .35001 .37155 .34274 .36647 Mtetra
.599 .818 .984 r
.34274 .36647 .35001 .37155 .36147 .36803 .35423 .3632 Mtetra
.635 .838 .979 r
.35423 .3632 .36147 .36803 .37301 .36403 .36581 .35917 Mtetra
.671 .848 .968 r
.36581 .35917 .37301 .36403 .38462 .35955 .37747 .35438 Mtetra
.696 .845 .954 r
.37747 .35438 .38462 .35955 .39628 .35489 .3892 .34899 Mtetra
.722 .828 .931 r
.3892 .34899 .39628 .35489 .408 .34999 .40101 .34291 Mtetra
.743 .798 .896 r
.40101 .34291 .408 .34999 .41978 .34466 .41288 .33592 Mtetra
.759 .758 .852 r
.41288 .33592 .41978 .34466 .43162 .33837 .42482 .32767 Mtetra
.775 .721 .802 r
.42482 .32767 .43162 .33837 .44356 .32996 .43683 .3174 Mtetra
.782 .693 .766 r
.43683 .3174 .44356 .32996 .45556 .31946 .4489 .30532 Mtetra
.784 .673 .741 r
.4489 .30532 .45556 .31946 .4676 .30697 .46099 .29175 Mtetra
.778 .658 .731 r
.46099 .29175 .4676 .30697 .47964 .29382 .47307 .27789 Mtetra
.754 .64 .735 r
.47307 .27789 .47964 .29382 .49164 .28219 .4851 .2657 Mtetra
.717 .617 .744 r
.4851 .2657 .49164 .28219 .50363 .27297 .4971 .25595 Mtetra
.656 .58 .757 r
.4971 .25595 .50363 .27297 .51562 .26742 .50909 .24978 Mtetra
.598 .541 .762 r
.50909 .24978 .51562 .26742 .52765 .26467 .52112 .24642 Mtetra
.557 .511 .76 r
.52112 .24642 .52765 .26467 .53976 .26343 .53321 .24482 Mtetra
.544 .501 .758 r
.53321 .24482 .53976 .26343 .55194 .26242 .54538 .24376 Mtetra
.57 .516 .755 r
.54538 .24376 .55194 .26242 .56418 .25979 .55762 .24154 Mtetra
.601 .539 .757 r
.55762 .24154 .56418 .25979 .57647 .25539 .56991 .23789 Mtetra
.641 .57 .759 r
.56991 .23789 .57647 .25539 .58876 .24887 .58222 .23233 Mtetra
.671 .597 .764 r
.58222 .23233 .58876 .24887 .60105 .24094 .59455 .22541 Mtetra
.692 .62 .772 r
.59455 .22541 .60105 .24094 .61336 .23234 .60689 .21772 Mtetra
.704 .639 .781 r
.60689 .21772 .61336 .23234 .62567 .22352 .61925 .20967 Mtetra
.706 .652 .793 r
.61925 .20967 .62567 .22352 .63803 .21509 .63165 .20187 Mtetra
.706 .663 .804 r
.63165 .20187 .63803 .21509 .65041 .20697 .64409 .1943 Mtetra
.703 .671 .816 r
.64409 .1943 .65041 .20697 .66285 .19922 .65657 .1871 Mtetra
.702 .682 .827 r
.65657 .1871 .66285 .19922 .67532 .19167 .6691 .18012 Mtetra
.704 .694 .838 r
.6691 .18012 .67532 .19167 .68782 .18412 .68167 .17323 Mtetra
.708 .711 .85 r
.68167 .17323 .68782 .18412 .70035 .17655 .69428 .16638 Mtetra
.713 .73 .864 r
.69428 .16638 .70035 .17655 .71291 .16892 .70693 .15953 Mtetra
.72 .754 .879 r
.70693 .15953 .71291 .16892 .7255 .16118 .71961 .15261 Mtetra
.614 .74 .936 r
.04273 .38856 .05043 .39529 .06015 .39382 .05264 .38582 Mtetra
.617 .703 .906 r
.05264 .38582 .06015 .39382 .06992 .3923 .0626 .38305 Mtetra
.615 .669 .879 r
.0626 .38305 .06992 .3923 .07975 .39078 .07261 .38031 Mtetra
.609 .639 .855 r
.07261 .38031 .07975 .39078 .08962 .38932 .08264 .37766 Mtetra
.601 .611 .834 r
.08264 .37766 .08962 .38932 .09952 .38796 .0927 .37515 Mtetra
.591 .586 .816 r
.0927 .37515 .09952 .38796 .10946 .38682 .10278 .37287 Mtetra
.577 .561 .8 r
.10278 .37287 .10946 .38682 .1194 .38605 .11286 .37094 Mtetra
.569 .54 .783 r
.11286 .37094 .1194 .38605 .12937 .38552 .12297 .36922 Mtetra
.561 .521 .768 r
.12297 .36922 .12937 .38552 .13937 .38523 .1331 .36771 Mtetra
.567 .511 .752 r
.1331 .36771 .13937 .38523 .14947 .38462 .14332 .36593 Mtetra
.579 .507 .738 r
.14332 .36593 .14947 .38462 .15972 .38328 .15367 .36351 Mtetra
.599 .51 .725 r
.15367 .36351 .15972 .38328 .17017 .38062 .16419 .36001 Mtetra
.624 .518 .714 r
.16419 .36001 .17017 .38062 .18086 .37611 .17493 .355 Mtetra
.639 .524 .707 r
.17493 .355 .18086 .37611 .19174 .37021 .18581 .34888 Mtetra
.652 .53 .703 r
.18581 .34888 .19174 .37021 .20277 .36318 .19682 .34186 Mtetra
.646 .527 .705 r
.19682 .34186 .20277 .36318 .21376 .35666 .20781 .33525 Mtetra
.624 .513 .708 r
.20781 .33525 .21376 .35666 .22462 .35186 .21869 .32999 Mtetra
.584 .486 .709 r
.21869 .32999 .22462 .35186 .23526 .34982 .2294 .32692 Mtetra
.525 .442 .704 r
.2294 .32692 .23526 .34982 .24565 .35131 .2399 .32664 Mtetra
.481 .402 .69 r
.2399 .32664 .24565 .35131 .25591 .35521 .2503 .32837 Mtetra
.453 .37 .673 r
.2503 .32837 .25591 .35521 .26614 .36078 .26066 .33156 Mtetra
.457 .362 .659 r
.26066 .33156 .26614 .36078 .27649 .36611 .27111 .33483 Mtetra
.477 .367 .65 r
.27111 .33483 .27649 .36611 .28706 .37 .28172 .33725 Mtetra
.498 .377 .645 r
.28172 .33725 .28706 .37 .29786 .37211 .2925 .33852 Mtetra
.52 .39 .643 r
.2925 .33852 .29786 .37211 .30888 .37224 .30346 .33839 Mtetra
.534 .399 .643 r
.30346 .33839 .30888 .37224 .32005 .37114 .31456 .33728 Mtetra
.545 .407 .643 r
.31456 .33728 .32005 .37114 .33135 .36915 .32578 .33536 Mtetra
.555 .414 .644 r
.32578 .33536 .33135 .36915 .34274 .36647 .33711 .33272 Mtetra
.563 .42 .645 r
.33711 .33272 .34274 .36647 .35423 .3632 .34853 .32942 Mtetra
.573 .427 .645 r
.34853 .32942 .35423 .3632 .36581 .35917 .36005 .32533 Mtetra
.582 .433 .644 r
.36005 .32533 .36581 .35917 .37747 .35438 .37165 .32046 Mtetra
.59 .438 .644 r
.37165 .32046 .37747 .35438 .3892 .34899 .38333 .31492 Mtetra
.597 .443 .643 r
.38333 .31492 .3892 .34899 .40101 .34291 .39508 .30866 Mtetra
.606 .448 .642 r
.39508 .30866 .40101 .34291 .41288 .33592 .40689 .30156 Mtetra
.616 .455 .641 r
.40689 .30156 .41288 .33592 .42482 .32767 .41877 .29347 Mtetra
.63 .465 .64 r
.41877 .29347 .42482 .32767 .43683 .3174 .43071 .28395 Mtetra
.644 .476 .642 r
.43071 .28395 .43683 .3174 .4489 .30532 .44269 .27324 Mtetra
.657 .489 .645 r
.44269 .27324 .4489 .30532 .46099 .29175 .4547 .26166 Mtetra
.664 .5 .653 r
.4547 .26166 .46099 .29175 .47307 .27789 .4667 .25012 Mtetra
.658 .505 .666 r
.4667 .25012 .47307 .27789 .4851 .2657 .47867 .24006 Mtetra
.643 .506 .681 r
.47867 .24006 .4851 .2657 .4971 .25595 .49063 .23201 Mtetra
.61 .495 .698 r
.49063 .23201 .4971 .25595 .50909 .24978 .50259 .2268 Mtetra
.576 .481 .71 r
.50259 .2268 .50909 .24978 .52112 .24642 .51459 .22382 Mtetra
.551 .469 .715 r
.51459 .22382 .52112 .24642 .53321 .24482 .52665 .22223 Mtetra
.542 .464 .717 r
.52665 .22223 .53321 .24482 .54538 .24376 .53879 .22106 Mtetra
.56 .474 .715 r
.53879 .22106 .54538 .24376 .55762 .24154 .551 .21897 Mtetra
.581 .489 .715 r
.551 .21897 .55762 .24154 .56991 .23789 .56327 .21575 Mtetra
.608 .509 .716 r
.56327 .21575 .56991 .23789 .58222 .23233 .57558 .21097 Mtetra
.629 .527 .72 r
.57558 .21097 .58222 .23233 .59455 .22541 .58792 .20507 Mtetra
.644 .545 .727 r
.58792 .20507 .59455 .22541 .60689 .21772 .60029 .19851 Mtetra
.654 .561 .737 r
.60029 .19851 .60689 .21772 .61925 .20967 .61269 .19165 Mtetra
.657 .575 .75 r
.61269 .19165 .61925 .20967 .63165 .20187 .62513 .18499 Mtetra
.66 .589 .765 r
.62513 .18499 .63165 .20187 .64409 .1943 .63761 .17855 Mtetra
.659 .603 .781 r
.63761 .17855 .64409 .1943 .65657 .1871 .65016 .17246 Mtetra
.661 .62 .798 r
.65016 .17246 .65657 .1871 .6691 .18012 .66275 .1666 Mtetra
.664 .641 .816 r
.66275 .1666 .6691 .18012 .68167 .17323 .67541 .16088 Mtetra
.669 .665 .837 r
.67541 .16088 .68167 .17323 .69428 .16638 .68811 .15524 Mtetra
.675 .693 .859 r
.68811 .15524 .69428 .16638 .70693 .15953 .70087 .14962 Mtetra
.682 .727 .884 r
.70087 .14962 .70693 .15953 .71961 .15261 .71368 .14397 Mtetra
.675 .756 .912 r
.03496 .38178 .04273 .38856 .05264 .38582 .04511 .37759 Mtetra
.669 .714 .882 r
.04511 .37759 .05264 .38582 .0626 .38305 .05529 .3734 Mtetra
.66 .677 .855 r
.05529 .3734 .0626 .38305 .07261 .38031 .0655 .36926 Mtetra
.65 .644 .831 r
.0655 .36926 .07261 .38031 .08264 .37766 .07574 .36522 Mtetra
.639 .615 .81 r
.07574 .36522 .08264 .37766 .0927 .37515 .08599 .36132 Mtetra
.626 .588 .791 r
.08599 .36132 .0927 .37515 .10278 .37287 .09625 .35764 Mtetra
.613 .562 .774 r
.09625 .35764 .10278 .37287 .11286 .37094 .10651 .35425 Mtetra
.602 .54 .757 r
.10651 .35425 .11286 .37094 .12297 .36922 .11679 .35107 Mtetra
.593 .519 .741 r
.11679 .35107 .12297 .36922 .1331 .36771 .12709 .34808 Mtetra
.592 .506 .726 r
.12709 .34808 .1331 .36771 .14332 .36593 .13745 .34494 Mtetra
.596 .498 .713 r
.13745 .34494 .14332 .36593 .15367 .36351 .14791 .34139 Mtetra
.605 .496 .703 r
.14791 .34139 .15367 .36351 .16419 .36001 .1585 .3371 Mtetra
.619 .5 .695 r
.1585 .3371 .16419 .36001 .17493 .355 .16924 .33177 Mtetra
.63 .505 .692 r
.16924 .33177 .17493 .355 .18581 .34888 .1801 .32565 Mtetra
.64 .511 .69 r
.1801 .32565 .18581 .34888 .19682 .34186 .19106 .31884 Mtetra
.638 .511 .692 r
.19106 .31884 .19682 .34186 .20781 .33525 .20203 .3122 Mtetra
.626 .504 .694 r
.20203 .3122 .20781 .33525 .21869 .32999 .21294 .30637 Mtetra
.602 .486 .693 r
.21294 .30637 .21869 .32999 .2294 .32692 .22375 .30191 Mtetra
.568 .456 .686 r
.22375 .30191 .2294 .32692 .2399 .32664 .23444 .29925 Mtetra
.541 .426 .671 r
.23444 .29925 .2399 .32664 .2503 .32837 .24505 .29796 Mtetra
.52 .399 .654 r
.24505 .29796 .2503 .32837 .26066 .33156 .25563 .29776 Mtetra
.516 .383 .639 r
.25563 .29776 .26066 .33156 .27111 .33483 .26626 .2978 Mtetra
.519 .376 .627 r
.26626 .2978 .27111 .33483 .28172 .33725 .27699 .29755 Mtetra
.525 .374 .619 r
.27699 .29755 .28172 .33725 .2925 .33852 .28783 .29679 Mtetra
.532 .375 .613 r
.28783 .29679 .2925 .33852 .30346 .33839 .29878 .29532 Mtetra
.537 .376 .61 r
.29878 .29532 .30346 .33839 .31456 .33728 .30984 .29332 Mtetra
.542 .378 .608 r
.30984 .29332 .31456 .33728 .32578 .33536 .32099 .29083 Mtetra
.546 .38 .608 r
.32099 .29083 .32578 .33536 .33711 .33272 .33223 .28784 Mtetra
.551 .383 .607 r
.33223 .28784 .33711 .33272 .34853 .32942 .34356 .28431 Mtetra
.557 .387 .607 r
.34356 .28431 .34853 .32942 .36005 .32533 .35497 .28016 Mtetra
.563 .391 .607 r
.35497 .28016 .36005 .32533 .37165 .32046 .36647 .27539 Mtetra
.568 .395 .608 r
.36647 .27539 .37165 .32046 .38333 .31492 .37803 .27008 Mtetra
.573 .399 .608 r
.37803 .27008 .38333 .31492 .39508 .30866 .38966 .26426 Mtetra
.578 .404 .609 r
.38966 .26426 .39508 .30866 .40689 .30156 .40134 .25793 Mtetra
.584 .409 .611 r
.40134 .25793 .40689 .30156 .41877 .29347 .41308 .25107 Mtetra
.592 .418 .615 r
.41308 .25107 .41877 .29347 .43071 .28395 .42487 .24349 Mtetra
.601 .428 .62 r
.42487 .24349 .43071 .28395 .44269 .27324 .4367 .23537 Mtetra
.609 .44 .627 r
.4367 .23537 .44269 .27324 .4547 .26166 .44856 .22694 Mtetra
.614 .452 .638 r
.44856 .22694 .4547 .26166 .4667 .25012 .46044 .21875 Mtetra
.612 .461 .652 r
.46044 .21875 .4667 .25012 .47867 .24006 .47232 .21165 Mtetra
.603 .467 .669 r
.47232 .21165 .47867 .24006 .49063 .23201 .48421 .20593 Mtetra
.583 .465 .685 r
.48421 .20593 .49063 .23201 .50259 .2268 .49612 .20204 Mtetra
.563 .461 .696 r
.49612 .20204 .50259 .2268 .51459 .22382 .50808 .19955 Mtetra
.549 .455 .701 r
.50808 .19955 .51459 .22382 .52665 .22223 .52011 .19789 Mtetra
.545 .453 .702 r
.52011 .19789 .52665 .22223 .53879 .22106 .53221 .19641 Mtetra
.557 .459 .699 r
.53221 .19641 .53879 .22106 .551 .21897 .54438 .19424 Mtetra
.571 .468 .698 r
.54438 .19424 .551 .21897 .56327 .21575 .55662 .19125 Mtetra
.589 .481 .699 r
.55662 .19125 .56327 .21575 .57558 .21097 .56891 .18719 Mtetra
.602 .494 .703 r
.56891 .18719 .57558 .21097 .58792 .20507 .58125 .18237 Mtetra
.613 .508 .711 r
.58125 .18237 .58792 .20507 .60029 .19851 .59363 .17712 Mtetra
.62 .522 .722 r
.59363 .17712 .60029 .19851 .61269 .19165 .60605 .17171 Mtetra
.622 .536 .736 r
.60605 .17171 .61269 .19165 .62513 .18499 .61853 .16649 Mtetra
.624 .552 .753 r
.61853 .16649 .62513 .18499 .63761 .17855 .63107 .16147 Mtetra
.624 .568 .771 r
.63107 .16147 .63761 .17855 .65016 .17246 .64367 .15676 Mtetra
.625 .587 .791 r
.64367 .15676 .65016 .17246 .66275 .1666 .65634 .15226 Mtetra
.627 .609 .813 r
.65634 .15226 .66275 .1666 .67541 .16088 .66908 .14791 Mtetra
.63 .635 .837 r
.66908 .14791 .67541 .16088 .68811 .15524 .68189 .14366 Mtetra
.633 .666 .864 r
.68189 .14366 .68811 .15524 .70087 .14962 .69476 .13946 Mtetra
.636 .702 .893 r
.69476 .13946 .70087 .14962 .71368 .14397 .70769 .13525 Mtetra
.719 .764 .888 r
.02714 .37496 .03496 .38178 .04511 .37759 .03752 .36936 Mtetra
.709 .725 .863 r
.03752 .36936 .04511 .37759 .05529 .3734 .04793 .3638 Mtetra
.697 .691 .841 r
.04793 .3638 .05529 .3734 .0655 .36926 .05835 .35831 Mtetra
.685 .66 .82 r
.05835 .35831 .0655 .36926 .07574 .36522 .06878 .35291 Mtetra
.673 .632 .801 r
.06878 .35291 .07574 .36522 .08599 .36132 .07923 .34764 Mtetra
.66 .607 .784 r
.07923 .34764 .08599 .36132 .09625 .35764 .08968 .34254 Mtetra
.647 .582 .768 r
.08968 .34254 .09625 .35764 .10651 .35425 .10014 .33765 Mtetra
.636 .559 .751 r
.10014 .33765 .10651 .35425 .11679 .35107 .11061 .33293 Mtetra
.625 .538 .736 r
.11061 .33293 .11679 .35107 .12709 .34808 .12109 .32838 Mtetra
.619 .521 .721 r
.12109 .32838 .12709 .34808 .13745 .34494 .13161 .32381 Mtetra
.616 .509 .709 r
.13161 .32381 .13745 .34494 .14791 .34139 .14219 .31909 Mtetra
.617 .502 .7 r
.14219 .31909 .14791 .34139 .1585 .3371 .15283 .31405 Mtetra
.621 .5 .693 r
.15283 .31405 .1585 .3371 .16924 .33177 .16357 .30851 Mtetra
.627 .502 .691 r
.16357 .30851 .16924 .33177 .1801 .32565 .17439 .30256 Mtetra
.633 .507 .692 r
.17439 .30256 .1801 .32565 .19106 .31884 .18528 .29623 Mtetra
.635 .512 .696 r
.18528 .29623 .19106 .31884 .20203 .3122 .19619 .28991 Mtetra
.631 .512 .699 r
.19619 .28991 .20203 .3122 .21294 .30637 .2071 .28388 Mtetra
.621 .504 .699 r
.2071 .28388 .21294 .30637 .22375 .30191 .21798 .27846 Mtetra
.604 .488 .694 r
.21798 .27846 .22375 .30191 .23444 .29925 .22882 .27385 Mtetra
.587 .466 .682 r
.22882 .27385 .23444 .29925 .24505 .29796 .23963 .26993 Mtetra
.572 .443 .666 r
.23963 .26993 .24505 .29796 .25563 .29776 .25043 .26661 Mtetra
.562 .424 .651 r
.25043 .26661 .25563 .29776 .26626 .2978 .26126 .26356 Mtetra
.557 .41 .637 r
.26126 .26356 .26626 .2978 .27699 .29755 .27214 .26057 Mtetra
.554 .4 .627 r
.27214 .26057 .27699 .29755 .28783 .29679 .28307 .25752 Mtetra
.552 .394 .62 r
.28307 .25752 .28783 .29679 .29878 .29532 .29406 .25434 Mtetra
.552 .39 .615 r
.29406 .25434 .29878 .29532 .30984 .29332 .30512 .25106 Mtetra
.552 .387 .612 r
.30512 .25106 .30984 .29332 .32099 .29083 .31623 .24764 Mtetra
.553 .386 .609 r
.31623 .24764 .32099 .29083 .33223 .28784 .32741 .24401 Mtetra
.555 .386 .608 r
.32741 .24401 .33223 .28784 .34356 .28431 .33866 .24012 Mtetra
.557 .388 .607 r
.33866 .24012 .34356 .28431 .35497 .28016 .34997 .23591 Mtetra
.56 .39 .608 r
.34997 .23591 .35497 .28016 .36647 .27539 .36135 .23138 Mtetra
.563 .393 .608 r
.36135 .23138 .36647 .27539 .37803 .27008 .37278 .22658 Mtetra
.566 .395 .61 r
.37278 .22658 .37803 .27008 .38966 .26426 .38427 .22158 Mtetra
.568 .399 .612 r
.38427 .22158 .38966 .26426 .40134 .25793 .39581 .21643 Mtetra
.571 .403 .616 r
.39581 .21643 .40134 .25793 .41308 .25107 .4074 .21117 Mtetra
.574 .409 .62 r
.4074 .21117 .41308 .25107 .42487 .24349 .41903 .20577 Mtetra
.578 .418 .627 r
.41903 .20577 .42487 .24349 .4367 .23537 .43071 .20032 Mtetra
.583 .428 .637 r
.43071 .20032 .4367 .23537 .44856 .22694 .44242 .19492 Mtetra
.586 .44 .65 r
.44242 .19492 .44856 .22694 .46044 .21875 .45417 .18979 Mtetra
.585 .452 .666 r
.45417 .18979 .46044 .21875 .47232 .21165 .46596 .18527 Mtetra
.58 .462 .682 r
.46596 .18527 .47232 .21165 .48421 .20593 .47778 .18144 Mtetra
.571 .467 .697 r
.47778 .18144 .48421 .20593 .49612 .20204 .48965 .17844 Mtetra
.562 .467 .705 r
.48965 .17844 .49612 .20204 .50808 .19955 .50158 .17606 Mtetra
.556 .465 .707 r
.50158 .17606 .50808 .19955 .52011 .19789 .51358 .17398 Mtetra
.555 .462 .704 r
.51358 .17398 .52011 .19789 .53221 .19641 .52564 .17192 Mtetra
.561 .462 .7 r
.52564 .17192 .53221 .19641 .54438 .19424 .53778 .16947 Mtetra
.567 .465 .697 r
.53778 .16947 .54438 .19424 .55662 .19125 .54999 .16661 Mtetra
.576 .471 .698 r
.54999 .16661 .55662 .19125 .56891 .18719 .56226 .16323 Mtetra
.583 .481 .703 r
.56226 .16323 .56891 .18719 .58125 .18237 .57458 .15952 Mtetra
.588 .492 .712 r
.57458 .15952 .58125 .18237 .59363 .17712 .58697 .15565 Mtetra
.592 .505 .725 r
.58697 .15565 .59363 .17712 .60605 .17171 .59942 .15177 Mtetra
.594 .52 .741 r
.59942 .15177 .60605 .17171 .61853 .16649 .61193 .14806 Mtetra
.594 .536 .759 r
.61193 .14806 .61853 .16649 .63107 .16147 .62452 .14452 Mtetra
.594 .553 .779 r
.62452 .14452 .63107 .16147 .64367 .15676 .63718 .1412 Mtetra
.593 .573 .8 r
.63718 .1412 .64367 .15676 .65634 .15226 .64992 .13805 Mtetra
.592 .594 .823 r
.64992 .13805 .65634 .15226 .66908 .14791 .66273 .13503 Mtetra
.591 .619 .848 r
.66273 .13503 .66908 .14791 .68189 .14366 .67563 .13212 Mtetra
.59 .647 .875 r
.67563 .13212 .68189 .14366 .69476 .13946 .6886 .12928 Mtetra
.587 .679 .905 r
.6886 .12928 .69476 .13946 .70769 .13525 .70165 .12647 Mtetra
.748 .767 .869 r
.01926 .36808 .02714 .37496 .03752 .36936 .02984 .36134 Mtetra
.736 .737 .852 r
.02984 .36134 .03752 .36936 .04793 .3638 .04043 .35468 Mtetra
.725 .71 .836 r
.04043 .35468 .04793 .3638 .05835 .35831 .05103 .34811 Mtetra
.714 .686 .821 r
.05103 .34811 .05835 .35831 .06878 .35291 .06164 .34163 Mtetra
.704 .663 .807 r
.06164 .34163 .06878 .35291 .07923 .34764 .07226 .33524 Mtetra
.693 .641 .793 r
.07226 .33524 .07923 .34764 .08968 .34254 .08288 .32894 Mtetra
.683 .619 .778 r
.08288 .32894 .08968 .34254 .10014 .33765 .09353 .32272 Mtetra
.672 .597 .763 r
.09353 .32272 .10014 .33765 .11061 .33293 .10418 .31659 Mtetra
.662 .576 .748 r
.10418 .31659 .11061 .33293 .12109 .32838 .11485 .31054 Mtetra
.652 .556 .734 r
.11485 .31054 .12109 .32838 .13161 .32381 .12554 .30459 Mtetra
.643 .54 .722 r
.12554 .30459 .13161 .32381 .14219 .31909 .13624 .29871 Mtetra
.636 .527 .713 r
.13624 .29871 .14219 .31909 .15283 .31405 .14696 .29293 Mtetra
.631 .518 .707 r
.14696 .29293 .15283 .31405 .16357 .30851 .1577 .28723 Mtetra
.629 .516 .706 r
.1577 .28723 .16357 .30851 .17439 .30256 .16846 .28161 Mtetra
.629 .519 .71 r
.16846 .28161 .17439 .30256 .18528 .29623 .17924 .27608 Mtetra
.631 .526 .717 r
.17924 .27608 .18528 .29623 .19619 .28991 .19005 .27063 Mtetra
.633 .535 .725 r
.19005 .27063 .19619 .28991 .2071 .28388 .20088 .26527 Mtetra
.634 .542 .732 r
.20088 .26527 .2071 .28388 .21798 .27846 .21173 .26 Mtetra
.633 .543 .734 r
.21173 .26 .21798 .27846 .22882 .27385 .22261 .2548 Mtetra
.629 .535 .729 r
.22261 .2548 .22882 .27385 .23963 .26993 .23352 .2497 Mtetra
.622 .522 .719 r
.23352 .2497 .23963 .26993 .25043 .26661 .24445 .24468 Mtetra
.614 .504 .705 r
.24445 .24468 .25043 .26661 .26126 .26356 .25542 .23974 Mtetra
.606 .487 .692 r
.25542 .23974 .26126 .26356 .27214 .26057 .26642 .23488 Mtetra
.598 .472 .68 r
.26642 .23488 .27214 .26057 .28307 .25752 .27745 .23012 Mtetra
.592 .46 .669 r
.27745 .23012 .28307 .25752 .29406 .25434 .28851 .22543 Mtetra
.587 .45 .662 r
.28851 .22543 .29406 .25434 .30512 .25106 .29961 .22083 Mtetra
.582 .442 .655 r
.29961 .22083 .30512 .25106 .31623 .24764 .31075 .21631 Mtetra
.579 .435 .65 r
.31075 .21631 .31623 .24764 .32741 .24401 .32192 .21188 Mtetra
.576 .431 .647 r
.32192 .21188 .32741 .24401 .33866 .24012 .33314 .20754 Mtetra
.574 .428 .645 r
.33314 .20754 .33866 .24012 .34997 .23591 .34439 .20327 Mtetra
.572 .427 .645 r
.34439 .20327 .34997 .23591 .36135 .23138 .35569 .1991 Mtetra
.572 .428 .647 r
.35569 .1991 .36135 .23138 .37278 .22658 .36703 .19501 Mtetra
.572 .431 .65 r
.36703 .19501 .37278 .22658 .38427 .22158 .37841 .191 Mtetra
.573 .435 .655 r
.37841 .191 .38427 .22158 .39581 .21643 .38984 .18708 Mtetra
.574 .441 .662 r
.38984 .18708 .39581 .21643 .4074 .21117 .40132 .18324 Mtetra
.575 .449 .67 r
.40132 .18324 .4074 .21117 .41903 .20577 .41285 .17949 Mtetra
.577 .459 .681 r
.41285 .17949 .41903 .20577 .43071 .20032 .42443 .17582 Mtetra
.58 .471 .694 r
.42443 .17582 .43071 .20032 .44242 .19492 .43606 .17224 Mtetra
.583 .485 .709 r
.43606 .17224 .44242 .19492 .45417 .18979 .44775 .16875 Mtetra
.586 .5 .724 r
.44775 .16875 .45417 .18979 .46596 .18527 .45949 .16534 Mtetra
.587 .511 .736 r
.45949 .16534 .46596 .18527 .47778 .18144 .47129 .16203 Mtetra
.586 .516 .742 r
.47129 .16203 .47778 .18144 .48965 .17844 .48315 .15879 Mtetra
.584 .512 .74 r
.48315 .15879 .48965 .17844 .50158 .17606 .49506 .15565 Mtetra
.58 .503 .733 r
.49506 .15565 .50158 .17606 .51358 .17398 .50705 .15259 Mtetra
.576 .493 .724 r
.50705 .15259 .51358 .17398 .52564 .17192 .51909 .14962 Mtetra
.572 .484 .717 r
.51909 .14962 .52564 .17192 .53778 .16947 .5312 .14674 Mtetra
.569 .479 .714 r
.5312 .14674 .53778 .16947 .54999 .16661 .54338 .14395 Mtetra
.567 .479 .715 r
.54338 .14395 .54999 .16661 .56226 .16323 .55563 .14125 Mtetra
.567 .485 .722 r
.55563 .14125 .56226 .16323 .57458 .15952 .56795 .13864 Mtetra
.567 .495 .733 r
.56795 .13864 .57458 .15952 .58697 .15565 .58035 .13612 Mtetra
.567 .508 .748 r
.58035 .13612 .58697 .15565 .59942 .15177 .59282 .13369 Mtetra
.568 .524 .767 r
.59282 .13369 .59942 .15177 .61193 .14806 .60537 .13135 Mtetra
.568 .542 .786 r
.60537 .13135 .61193 .14806 .62452 .14452 .618 .12911 Mtetra
.566 .56 .806 r
.618 .12911 .62452 .14452 .63718 .1412 .63071 .12695 Mtetra
.564 .579 .827 r
.63071 .12695 .63718 .1412 .64992 .13805 .6435 .12489 Mtetra
.561 .598 .847 r
.6435 .12489 .64992 .13805 .66273 .13503 .65638 .12293 Mtetra
.556 .618 .869 r
.65638 .12293 .66273 .13503 .67563 .13212 .66935 .12106 Mtetra
.55 .639 .892 r
.66935 .12106 .67563 .13212 .6886 .12928 .68241 .11929 Mtetra
.54 .663 .916 r
.68241 .11929 .6886 .12928 .70165 .12647 .69556 .11761 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m?ooool4o`000003oa0@4?oooooooooo06gooooo003fooooo`03o`00
0?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooo
oooo06oooooo003fooooo`03o`000?oooooooooo06oooooo003fooooo`03o`000?oooooooooo06oo
oooo003fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00
m?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003oooooo`7ooooo00Go0000oooooooooooo
ooooo`00001Sooooo`00ooooool1ooooo`05o`000?ooooooooooooooool00000Hoooool00?oooooo
0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003jooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg06?ooooo003gooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003eooooo`;o00001?ooool2o`0006_ooooo003booooo`?o00001_oo
ool00ol0003oooooo`00001Zooooo`00koooool3o`0000Wooooo00?o0000ooooool00000J_ooool0
0>gooooo0ol0000;ooooo`04o`000?ooooooooooo`0006Wooooo002gooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01co
oooo0_l0000Aooooo`05o`000?ooooooooooooooool00000J?ooool00;Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0001?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`00]oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00005_ooool01?l0003ooooooooo
ooooool3o`0006Kooooo002gooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Cooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0I?ooool00;Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05
oa0@4?nj^[[ooooookZj^_l@41004_ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Sooooo`00]oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000?ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo002gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00=Kooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0=?ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Qooooo`00dOooool2o`0002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Pooooo`00c_ooool3o`0002_ooooo00?o0000ooooooooool01Oooool3o`00067ooooo
003<ooooo`;o0000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oooooo0039
ooooo`?o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05kooooo0037ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0GOooool00<Cooooo0ol0000eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0GOooool00<7ooooo0ol0000hooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0G?ooool008[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<023ooooo0_l00002ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool3o`00
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`00R_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Kooooo`;o0000@?ooool0
0ol0003oooooooooo`0:ooooo`?o0000G?ooool008[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool3o`0004;ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol0000nooooo`00R_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o
410@olc<c00Fooooo`?o0000A?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A403kooooo002:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0E
ooooo`?o00000oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0?ooo
ool008[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo0_l0
001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0?_ooool008[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40kooooo0ol0001=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0?Oooool00:[ooooo1?l0001?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0??ooool00:So
oooo0_l00003ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@03kooooo002Uooooo`?o0000EOooool00ol0003oooooooooo`0>ooooo`?o00001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00nooooo`00Xoooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Dooooo`00X?ooool3o`00
05[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Cooooo`00W_ooool2o`0000;o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05?o
oooo002Kooooo`?o00001Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0D_ooool009Wooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0DOooool0063ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo01oooooo0ol0001Nooooo`;oS:?T1?n:ZNX00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo057ooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0Dooo
ool2ohnIf0GoSYkN1On<Xn@3ohZYjP03o`000?n:ZN[ooooo01Gooooo00?o0000ooooooooool0D?oo
ool0063ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2o`0005Oooooo0_n@
U=<5ohnIf0GoSYkN1On<Xn@2ohZYjP03o`000?nF[NOooooo01Cooooo00?o0000ooooool00000DOoo
ool0063ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001[ooooo
0ol0001Aooooo`;oTH[91?n@Slh5oi2Dd`CoSiWH1_n>W]h2ohbSi0;oUjGO0_nF[NL00ol0003oUZgW
oiJ]i`0Fooooo`03o`000?oooooooooo04oooooo001Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool0000Hooooo`;o0000D?ooool2oi66a0GoTH[91?n@Slh4oi2Dd`Go
SiWH0on>W]h2oiNNf@GoUjGO00?oUZgWo`000?nF[NL00_nF[NLFooooo`03o`000?oooooooooo04ko
oooo001Pooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Eooooo`?o
00000_ooool00ol0003oooooooooo`15ooooo`;oTGjk1?nAP[l5oi66a0CoTH[91?n@Slh5oi2Dd`;o
SiWH0_nGV=86oiNNf@CoUjGO00GoUZgWo`000?nF[NOoUZgWoj:ci00Fooooo`03o`000?oooooooooo
04kooooo001Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Coooo
o`;o0000BOooool2oi5l^0CoTGjk1OnAP[l4oi66a0CoTH[91On@Slh2oi2Dd`;oUi;<1OnGV=85oiNN
f@GoUjGO00?o0000oj:ci?nR/n@00_nR/n@Fooooo`03o`000?oooooooooo04gooooo001Pooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`?o0000B?ooool00onA
N[OoTGbhoi5l^002oi5l^0GoTGjk1?nAP[l4oi66a0GoTH[90_n@Slh2oiR=a`GoUi;<1?nGV=86oiNN
f@;oUjGO0_nRZ]d00ol0003oX[?Toj:ci003oj:ci1Kooooo00?o0000ooooooooool0C?ooool008;o
oooo0_l00017ooooo`;oTGZf1?nAN[L4oi5l^0CoTGjk1?nAP[l5oi66a0;oTH[90_nHRL85oiR=a`Co
Ui;<1OnGV=83oiNNf@;oXJ;F1?nRZ]d00ol0003oX[?Toj:ci002oj:ci003ojjjh_oooooooooo01Co
oooo00?o0000ooooooooool0C?ooool007oooooo0ol00002ooooo`03o`000?oooooooooo043ooooo
0_nBNkL4oi5j]PCoTGZg1?nAO;P4oi5n^`GoTH:o0_nAQ/@2oiR5_@GoV8W21?nHSLL4oiNBc0CoUiSB
00?oX9_@oj6Re_nQX]H00onQX]H4oj:Zg@03o`000?nRZ]goX[?T00Co[[[R5?ooool3o`0004gooooo
001looooo`?o0000A?ooool2oi=n^@CoTW^g1OnAN[H4oi5j]`?oTGbh1OnAO[/3oi62_`03oiN1^OnH
QKgoV8Fm00?oV8Fm1?nHRL84oiR=a`GoUi;<00?oUiSBoj2Kd?nPVm000_nPVm05oj6ReP?oXZ[M00?o
0000ojbafon^^^801?n^^^8Gooooo`03o`000?oooooooooo04[ooooo001jooooo`;o0000@oooool2
oiB0^`CoTgji1OnBNkL4oi5j]PCoTGZg1?nAO;P4oi5n^`04oi62_onGPKWoUh6ioiN1^@GoV8Fm1?nH
RL85oiR=a`;oUi;<0_nOU/X5oj2Kd0GoXJ;F00KoXZ[Mojbafon//M_o[;7Ko`000?n//M/3ojjjhP;o
^<7Q5_ooool00ol0003oooooooooo`1:ooooo`00Moooool3o`00047ooooo0_nEPkd5oiB0^`CoTgji
1?nBNkL4oi5j]PCoTGZg1?nAO;P2oi5n^`;oUWff1OnGPKT4oiR5_@GoV8W20onHSLL00onOTLGoWiK:
oinFbP03oinFbPGoX9_@0_nQX]H2oj^ZePCo[;7K00?o0000ojbafon^^^801Onh`N4Fooooo`03o`00
0?oooooooooo04Wooooo001eooooo`;o00000_ooool00ol0003oooooooooo`0looooo`03oiJ4_OnE
PkgoUH>m00?oUH>m1?nDP;/4oi=n^@CoTW^g1OnAN[H4oi5j]`;oTGbh00?oUG^coiIm]_nFOKH00onF
OKH4oiN1^@GoV8Fm1?nHRL800onHSLOoWi75oinAa@02oinAa@CoWiK:1?nPVm000onYY=3oZj[Foj^Z
eP03oj^ZeP?o[;7K00?o0000okJjgOnh`N401?nh`N400onna^3oooooooooo`0Eooooo`03o`000?oo
oooooooo04Sooooo001booooo`?o00001Oooool00ol0003oooooooooo`0gooooo`;oUX:l1?nFQ;d4
oiF3_@CoU82k1?nCO[T5oi9k]`CoTGZf0_nAN[L2oi=h/PCoUG^c1?nFOKH4oiN1^@GoV8Fm0_nHRL82
oin=`0GoWi751OnOU/X00onPVm3oZJC@ojVTd002ojVTd0GoZj[F00?o[;7KokJjgOl000000_nf^]d3
okS1h@?o_/KP5_ooool00ol0003oooooooooo`18ooooo`00L?ooool2o`0003kooooo0_nFOkT5oiJ2
_0?oUXBm1?nEPkd5oiB0^`CoTgji1?nBNkL2oi5j]P;oTGNb1?nCN;84oiEk/`GoUWff1?nGPKT3oiR5
_@03oin9_?nOSL3oWhg000?oWhg01?nOTLD4oinFbP03ojVNc?nYY=3oZJC@00?oZJC@1?n[Z]H01?ne
]]Wo][[MokJjgOl00003okJjg@03okS1hOnna^3o_/KP00?o_/KP5_ooool00ol0003oooooooooo`17
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008?ooool3
o`0003gooooo00?oUGbeoiIo^OnFOkT00onFOkT4oiJ2_0CoUXBm1?nEPkd4oiB0^`CoTgji0_nBNkL2
ohmf/`CoTGNb1OnCN;84oiEk/`CoUWff1?nGPKT00onHQKgoWhVloin9_002oin9_0CoWhg01OnOTLD0
0onOU/[oZIk<ojVNc002ojVNc0GoZJC@00?oZj[FokFffOne]]T00_ne]]T01Onf^]go0000okJjgOnf
^]go_LCO00Go_/KP00?o`/cRooooooooool04oooool3o`0004Sooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Nooooo`;o0000
0oooool00ol0003oooooooooo`0fooooo`;oU7Ra1?nEO;D4oiIo^@CoUX:l1?nFQ;d4oiF3_@;oU82k
0_n>Mk@4ohif]0CoSgJc1OnAMk84oi=h/PCoUG^c1OnFOKH2oiN1^@03oij5^?nORKcoWhVl00?oWhVl
1?nOSL04oinAa@03ojRJaonYW/coZIk<00?oZIk<1?nYY=000ond/MKo]KKIokFff@04okFff@03o`00
0?nma=oo_LCO00;o_LCO0onna^03ol;<hQKooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Oooool003Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01cooooo0ol0000jooooo`;o
TgF^1?nDN;44oiEl]@CoUWni1OnFP[`4oiJ4_@;oUH>m00?oSgNdohig]?n>Mk@00_n>Mk@4ohif]0Go
SgJc1?nAMk84oi=h/PCoUG^c1?nFOKH00onLP[KoWXFhoij5^002oij5^0GoWhVl1?nOSL000onOTLGo
Z9[7ojRJa`02ojRJa`GoZIk<00?oZJC@okBae_nd/MH00_nd/MH4okFff@03okc2g_l0003o_LCO00Co
_LCO00?o_/KPol;<h_o2c>800oo2c>8Fooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Zooooo`00>?ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06?ooool3o`0003[ooooo00?oTg:[oi=e
[_nCMJh00_nCMJh5oiAh/@?oUGbe1OnFOkT4oiJ2_0;oUXBm0_nBMk83ohmg]0GoSWNd1?n>M[@4ohmf
/`CoTGNb1?nCN;85oiEk/`04oiIm]_nLP[KoW8:foib2]PCoWXFh1OnORK`3oin=`003ojRF`onXV/Oo
Z9[700?oZ9[71?nYW/`00onc[]?o];7FokBaeP03okBaeP?o]KKI0_nl`]h00ol0003o_LCOokg4g`02
okg4g`;o`/oT1?o2c>82ol7@iAKooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000[ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool05Oooool3o`0003Wooooo00CoTW2Yoi=bZonCLZ_oTg:[1OnCMJh4oiAh/@CoUGbe
1?nFOkT2oiJ2_0;oU7J^1?nBMk84ohmg]0CoSWNd1?n>M[@4ohmf/`CoTGNb1OnCN;83oiEk/`03oiYn
/onLP[KoW8:f00?oW8:f1?nNQKP5oin9_004oin=`?nXU/?oZ9K3ojRF``CoZ9[70onYW/`3ok>^d`Go
];7F00Oo]KKIokc2g_nl`]ko_<;No`000?nl`]ko_LCO00Go`/oT00?o`/cRol7@iOo1d>D00oo1d>DE
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0002cooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Aooooo`?o00000oooool00ol0003oooooooooo`0dooooo`?oTW2Y1?nCLZ/4oi=e[PCoU7Ra
1?nEO;D2oiIo^@;oUG>Z1?nDMZh5oi9g/P?oSgNd1?n>Mk@4ohif]0CoSgJc1OnAMk84oi=h/P04oiEk
/onJO[?oVWjcoiYn/`GoW8:f1?nNQKP4oin9_003ojRC_onXU/?oZ9K300?oZ9K31?nXV/L00onYW/co
/jkCok>^d`02ok>^d`Co];7F00?o_<7Mokc2g_nl`]h00_nl`]h00ol0003o`];Vol;?i004ol;?i003
ol7Fj_o1d>Go`M3U00?o`M3U00?o_=;[ooooooooool05?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000/ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`;o0000>_oo
ool2oi9_Y`CoTW2Y1?nCLZ/4oi=e[PGoU7Ra0_nEO;D00onFL:KoUG>ZoiEcZP02oiEcZPGoU7J^1?nB
Mk83ohmg]0CoSWNd1?n>M[@5ohmf/`CoTGNb0_nCN;82oiIk/PGoVWjc1?nLP[H5oij5^003oin9_?nX
TkooZ9>o00;oZ9>o1?nXU/<3ojRJa`03ok>[d?nc[]?o/jkC00Co/jkC00?o];7Fokc1gOnl`Md00_nl
`Md3okc2gP03o`000?o2d^Ko`];V00?o`/oT0oo1e^X3ol7@i@?o_=;[5_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000/ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`?o
0000>Oooool00onBKZKoTVnWoi9_Y`02oi9_Y`CoTW2Y1?nCLZ/4oi=e[PGoU7Ra00?oUGbeoiI`Y_nF
L:H01OnELjX4oiAf[PCoTWNb0on?Mk@5ohig]0CoSWJd1?n?M[<2oi5g/P;oTWNb1?nFNk85oiYn/`Go
W8:f0onNQKP00onWSkcoZ9>oojRC_`03ojRC_`GoZ9K300CoZ9[7ok>[d?ncZm3o/j_@1?nc[]<7okc1
g@03okc2g_o2d^Ko000000?o`];V00?o`/oTol7Fj_o1e^X00oo1e^X00oo1d>Go_=;[okcBj`03okcB
jaCooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/
ooooo`00FOooool3o`0003Oooooo0_nBKJD3oi9^YPGoTVnW1?nBL:T3oi=bZ`GoTgF^0onDN;400onE
KJ?oUW2VoiI`YP02oiI`YPCoUG>Z1?nDMZh5oi9g/P?oSgNd1?n>Mk@4ohif]0;oSgJc0_n>MK84oi9g
/PGoUW^b1?nJO[<5oib2]P03oij5^?nWSkcoYhnl00;oYhnl1?nXTkl4ojRF``03okBYcOncZm3o/j_@
00?o/j_@00?o/jkCokc1gOnl`Md01_nl`Md2ol;Gj@04ol;Bi_l0003o`];Vol;BiP;o`=g^1?o1e^X2
ok[Ll@Co_=;[00?o/Lo`ooooooooool04Oooool01?l0003oooooooooool00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0[ooooo`00E_ooool3o`0000?ooooo00?o
0000ooooooooool0<Oooool5oi9]Y@CoTVjV1?nBKjL4oi9`Z@?oTg:[1OnCMJh01?nDN;7oUFfSoiE]
XonEKJ<4oiI`YPCoUG>Z1?nDMZh5oi9g/P?oSgNd0_n>Mk@2ohad/`CoRg>c1?n>MK85oi9g/PCoUW^b
1OnJO[<3oib2]P03ojB;^_nWSkcoYhnl00?oYhnl1OnXTkl00onXU/?o]:W=okBYc@02okBYc@Co/j_@
1onl`Md5ol;Gj@03o`000?o0gNko`=g^00?o`=g^00?o`MKZok[LlOnjg?400onjg?400onld^_o/Lo`
ok7?l002ok7?l1Kooooo00?o0000ooooooooool0@?ooool005Cooooo0_l0000hooooo`OoTVfU1?nB
KZH4oi9_Y`CoTW2Y1?nCLZ/3oi=e[P03oi=[X?nEKJ?oUFfS00?oUFfS0onFL:H4oiEcZPGoU7J^0onB
Mk801?nEMjooT7Jboi1f/_n@M[84ohad/`CoRg>c1On>MK84oi9g/PCoUW^b1OnJO[<00onLP[KoY8^j
ojB;^P02ojB;^PCoYhnl1?nXTkl00ondY/_o]:W=okBYc@03okBYc@?o/j_@0_nn`]d4okc1g@;o`]g]
1?o2enT00onmi_?o0000ol3MkP03ol3MkP?o]^Kf0_njg?42ojkJm`Go/Lo`5_ooool00ol0003ooooo
ooooo`10ooooo`00DOooool3o`0003Sooooo2OnBKJD4oi9^YPCoTVnW1?nBL:T4oi=bZ`04oi=e[_nC
Jj3oTf^Poi=[X0GoUFfS0onFL:H5oiEcZPCoU7J^00CoTWNboiEg[onEMjooUGN_0on@M[85ohad/`Co
Rg>c1?n>MK84oi9g/PGoUW^b0onJO[<00onQQ[SoY8^jojB;^P03ojB;^PGoYhnl0_nXTkl3okBVb`Go
]:W=00?o/j_@okk2gOnn`]d00_nn`]d00onl`Mgo`]g]ol;Mk@03ol;Mk@07ol;GjOnmi_?o_NKcokgV
lol0003o_NKcol3MkP04okKVmP03ojKSnon^f_Oo[][g00?o[][g0_naco03oj?9laKooooo00?o0000
ooooooooool0?oooool004kooooo1Ol0000eooooo`;oTfjU2onBKJD4oi9^YPCoTVnW1?nBL:T2oi=b
Z`;oTVRN1?nCJj05oiE]X`?oUW2V1OnELjX2oiAf[P;oVWN[1OnEMjl3oi1f/PCoS7Bc1?n;Lk<4ohie
/PCoTWNb1OnFNk801?nJO[?oXHJhoj66^?nQQ[P5ojB;^PGoYhnl00?oZ9>ookBVbondY//00_ndY//4
okBYc@03ol33g?nn`]go_/;M00;o_/;M0_o2iNl4ol;Mk@;o]^kf0onmi_<01Ol0003oZnkhoj_^n?n[
k_So]^Kf00CoY^?k0_n^f_L3oioBnPGoXlWc5_ooool00ol0003oooooooooo`0nooooo`00C?ooool2
o`0000Gooooo00?o0000ooooooooool0;oooool00onDKjKoTfjUoi=^Y@02oi=^Y@coTVfU0onBKZH5
oi9_Y`;oTW2Y00?oTVNMoi9XW_nBJ9h00_nBJ9h5oi=[X0CoUFfS1?nFL:H3oiEcZP03oiafY_nJMj_o
VWN[00;oVWN[1OnEMjl3oi1f/PCoS7Bc1?n;Lk<4ohie/PGoTWNb0onFNk800onKP[OoXHJhoj66^003
oj66^0GoY8^j0onWSk`00ondXlOo]:K;okBVb`03okBVb`?o]:W=0oo0`m`2okk2g@Co`^G_00?o`]g]
okK^m_nfk_H00onfk_H00onmi_?oZnkho`000002oj_^n0;oU^Sj0_nVho/3oiOIoPGoWm;j0_nSbO<2
oiJom1Kooooo00?o0000ooooooooool0?_ooool004Wooooo0ol0000hooooo`;oU6nV1OnCKZD;oi9]
Y@CoTVjV1?nBKjL00onBL:WoTVNMoi9WW@04oi9XWPGoTf^P1?nEKJ<4oiI`YP;oUG>Z0_nLMZH5oiYg
Z`CoUGN_0on@M[84ohad/`GoRg>c1?n>MK84oi9g/P04oiIk/_nKP[OoVh:goi^2]`GoXHJh1OnTRkX0
0onWSkco]:?7okBSa`02okBSa`Go]:K;00?o]:W=ol33g?o0`m`00_o0`m`00onn`]go`^G_ol;Uk`02
ol;Uk`?o[?Cb0_nfk_H4oiK_l@04oj_^n?l0003oU^SjoiKXnP;oR=cn1OnGfOh2oioBnP?oTlGh1?nF
_o@Dooooo`?o0000?oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o0000>?oo
ool2oiAaY`?oU6nV1OnCKZD;oi9]Y@CoTVjV0onBKjL01?nAIYcoTVNMoi9WWOnBIid5oi9XWPCoTf^P
1OnEKJ<3oiI`YP03oiEcZ_nLMZKoW7JV00;oW7JV1?nJMj/4oiEg[`CoT7Jb1?n<M;<4oh]c/`CoSWFb
0_nBMk82oiAm]`GoVh:g1?nQQ[P4ojB;^P03ok6NaOndXlOo]:?700?o]:?71?ndY//2ol;5g0?o`<?L
0oo3k_000oo2iNoo[?CbojcdlP02ojcdlP?oMnCK0_nFko42ogWRk`03og?Hn_l0003oR=cn00CoR=cn
0_nGfOh3ohk9o0GoTlGh1?nF_o@Eooooo`03o`000?oooooooooo03gooooo000Rooooo`05ogMgMonH
V9SooooooiRHV?mgMgL07Oooool3o`0000;ooooo00?o0000ooooooooool0<_ooool00onFLjWoU76W
oiAaY`02oiAaY`CoU6nV1?nCKZD;oi9]Y@CoTVjV00CoTVnWoi5VW?nAIYcoTFJL1?nBIid4oi9XWPCo
Tf^P1OnEKJ<2oiI`YP03oiecXonLMZKoW7JV00?oW7JV1?nJMj/5oiEg[`?oT7Jb1?n<M;<2oh]c/`;o
RWJg1?n?NKL4oiAm]`GoVh:g1OnQQ[P2ojB;^P?o/Ik51OndXlL00ondY/_o`/GLol;5g003ol;5g004
ol33g?o3k_3o`nk`ol?^l0?oVO?S00Co[?CbogOTfomgi=_oMnCK0_mEdMD3oe_?k`;oLmSj00Co0000
og?Hn_n8g?koR=cn0on7boh5ohk9o0;oTlGh0_n>]_85ohjflAGooooo00?o0000ooooooooool0??oo
ool002;ooooo00Go410@oooooooooooooooooa0@400Kooooo`;o0000>Oooool2oiIcZ@GoU76W0onD
KjH4oi=^Y@_oTVfU0_nBKZH2oi1UW0CoTFJL1?nBIid4oi9XWPCoTf^P1OnEKJ<00onFL:KoWG>Soiec
X`05oiafYPCoVWN[1OnEMjl2oi1f/P03oi=k]On=N;OoSGRg00;oSGRg1?n:M[L4ohmi]`GoU7fg1?nK
P[L5oj66^003ojB;^_naW/Go/Ik500;o/Ik51?ndXlL00oo4aM[o`/GLol;5g003ol;5g004ol;gk_o3
k_3o`nk`ol?^l0?oVO?S00?oBlJ_ob>_a_ln`=h00oln`=h2oe_?k`?oMlKo00?oO/Woo`000?mnbOl0
0_mnbOl4ohO;oP;oS/Wl0on=]_84ohjflPGoS[Ka5Oooool00ol0003oooooooooo`0kooooo`008_oo
ool01Ol0003ooooooooooooooooo000001Sooooo0ol0000hooooo`;oUgF[1?nFLjT4oiAaY`?oU6nV
1?nCKZD:oi9]Y@03oi1TVon@IIcoT6FL00;oT6FL1OnAIY`3oi9WW@CoTVRN1OnCJj03oiE]X`03oi]`
X?nMLj?oWG>S00;oWG>S1?nLMZH5oiYgZ`?oUGN_00?oW7jboi=k]OnCNkD00_nCNkD3oheh]`GoRWJg
1?n?NKL4oiAm]`GoVh:g0onQQ[P00on[V<?o/Ik5ok6Na@03ok6Na@?o]:?70oo4aMX3ol;5g0?o`_O^
00Co`nk`oiWchonIln?oIKSl1OmY_?d4ofk0oPCoMlKo00Co0000ogk9oon<[nkoS:o^1On=]?05ohff
lPCoS[Kb0_n>]_42ohj`kAGooooo00?o0000ooooooooool0>oooool002;ooooo00Go0000oooooooo
ooooooooo`00000Fooooo`?o0000=oooool00onIN:koUgF[oiMeZ`02oiMeZ`CoUW>Y1?nDLJL3oiA_
YPGoTfjU2?nBKJD2oi1TV`CoT6FL1OnAIY`3oi9WW@CoTVRN1OnCJj02oiE]X`;oVg2P1?nMLj<4oiaf
YPGoVWN[00CoUGN_oian/_nLO[;oW7jb1?nCNkD4oheh]`CoRWJg1?n?NKL4oiAm]`GoVh:g00?oXHJh
oj^H`on[V<<00_n[V<<5ok6Na@03okBSaoo4aM[oa<GJ00?oa<GJ00Go`/GLol;gk_o2mnko`_O^ogkU
a002ofNio@?oIKSl0_mY_?d2ohVEf@CoRYoR1?n;Z>P00ol0003oS:o^ohb_kP02ohb_kPGoSKC`0_n=
]_82oi6Yi`CoSjgZ1On>/>dEooooo`03o`000?oooooooooo03[ooooo000Rooooo`05oa0@4?oooooo
ooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0=?ooool2oiUh[PGoUgF[0onF
LjT4oiAaY`?oU6nV1OnCKZD5oi9]Y@;oSf>K0on@I9/5oi1UW0CoTFJL0onBIid4oi9XWPGoTf^P00Co
UFfSoi]`X?nKL:3oVg2P1?nMLj<5oiafYP?oVWN[00?oY86^oian/_nLO[800onLO[84oi=k]@?oSGRg
1?n:M[L4ohmi]`GoU7fg0onKP[L00onTTL;oZiS3oj^H``03oj^H``Co/Ik500?o`l?JolC5f_o4aMX0
0oo4aMX3ol3li`03ol;gk_n8QLWoR8G900;oR8G90on8S=05ohVEf@CoRYoR0on;Z>P00ol0003oRjSX
ohb_kP03ohb_kP;oSKC`0_nBYN85oi6Yi`CoSjgZ1?n>/>dFooooo`03o`000?oooooooooo03Wooooo
000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3o`0003Wooooo0_nKO;44oiUh[PCoUgF[
0onFLjT4oiAaY`CoU6nV1?nCKZD2oi9]Y@03ohiSVon?Hi_oSf>K00;oSf>K1?n@I9/4oi1UW0CoTFJL
0onBIid5oi9XWP?oTf^P00?oVFfNoi]`X?nKL:000_nKL:04oiecX`GoW7JV00CoVWN[ojB1[_nTPJko
Y86^1OnLO[84oi=k]@?oSGRg1?n:M[L5ohmi]`CoU7fg00?oVh:gojBA`_nTTL800_nTTL84oj^H``?o
/Ik50oo3`mX3olC5fP?o`?cW0on9P<<3ohR5b@CoR8c@1?n9UMT5ohZOhP;oRjSX00?o0000oiFJe_nD
X=`00onDX=`5oi:UhPGoTJWW0on?[NX2ohj`k@?oU:kY5?ooool2o`0003_ooooo000Rooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0003Wooooo00?oWH6doi]l/OnKO;400_nKO;44oiUh[PCo
UgF[0onFLjT5oiAaY`?oU6nV0onCKZD01?n>HY_oSV>KohiSVon>Hi/4ohmSV`CoT6BK1?n@II`4oi5V
W0?oTVNM1OnBJ9h2oi=[X0;oVFfN1?nKL:04oiecX`GoW7JV1OnTPJh4oian/PCoTg^e1?n=N;L4ohYf
]`CoSgVg0_nDOKL2oiV9`@GoY9721On[V<<00onaW/Go`l?Jol?3fP03ol?3fP04olC5f_o0o>Oo`?cW
ohen_PCoRH331?n8QLT4ohR<d0CoRIGI0_n:Wn82oiJCcP;oUI[F00?o0000oiFJe_nEV]H01?nDX=`5
oi:UhP;oTJWW0_nGXM`4oiJWhPGoU:kY5Oooool00ol0003oooooooooo`0hooooo`00<_ooool5o`00
03Sooooo0_nMPK@5oi]l/@?oVGR^1?nGMJ/4oiIcZ@CoU76W0onDKjH01?nCKZGoSV:KohiRVon>HY/3
ohiSV`CoSf>K1?n@I9/4oi1UW0CoTFJL1?nBIid4oi9XWP04oi=[X?nIKIkoVFfNoiU]WPGoVg2P1?nM
Lj<3oiafYP03ojR1Z_nTPJkoY86^00?oY86^1?nLO[85oi=k]@?oSGRg1?n:M[L2ohmi]`;oTHC11OnI
RL44ojBA`PCoZiS300?o_[kIol?3f_o3`mX00oo3`mX2okSlh@?oSGjn1?n9P<<4ohR5b@;oR8c@0_nD
Q;l4oiF;a`GoUY?>0_l00002oiFJePGoU:3L0_nBYN82oiVLe@GoUj7L1?nFYn82oiB^j@;oW[;V5_oo
ool00ol0003oooooooooo`0gooooo`00<?ooool2o`0003[ooooo0_nOQKP4oif1]0CoVgba0onIN:h4
oiMeZ`CoUW>Y1?nDLJL2oiA_YP03oheRVon>HY_oSV:K00;oSV:K1?n>Hi/3ohmSV`CoT6BK1?n@II`4
oi5VW0CoTVNM0onBJ9h00onGJigoVFfNoiU]WP03oiU]WPCoVg2P1?nMLj<2oiafYP?oZ86Z1?nTPJh5
oian/P?oTg^e00CoVH[3ohj2`_n>P/;oSX;21?n;P<85oi64`@CoVHW11OnTTL800on[V<?o_[kIokjn
f@02okjnf@?o`l?J0_nho>400onBOk_oSGjnohen_P02ohen_PCoRH330_n8QLT00onCO[WoU8BooiB4
_`03oiB4_`CoUH_700KoUY?>o`000?l0003o0000oiFJe_l00003oiFJeP;oU:3L0_nKUll4oiVLe@Go
Uj7L0_nFYn82oinZgPGoW[;V5Oooool00ol0003oooooooooo`0gooooo`00;Oooool3o`0003Wooooo
00?oXHRjoin5^?nOQKP00_nOQKP4oif1]0CoVgba0onIN:h5oiMeZ`?oUW>Y0_nDLJL2oheSW0?oSF:K
1?n>HY/4ohiSV`?oSf>K1?n@I9/4oi1UW0GoTFJL0onBIid01?nBJ9koUf^MoiM[WOnGJid5oiU]WPCo
Vg2P1?nMLj<00onLMZKoZ86ZojR1ZP02ojR1ZPGoY86^1?nLO[800onCNkGoVH[3oiV:``02oiV:``?o
SX;21?n;P<84oi64`@CoVHW11?nTTL800ond]][o_[kIokjnf@04okjnf@03ol?3f_nho>7o^?cQ00;o
TWnk0_n=O[h2oi9e[`CoTWRc1?nCO[T4oiB4_`;oUH_70ol00004oiJCcP04oiFJe_l0003oW9?9oibC
b@GoViO?1?nIW=D3oiNQg003oj2SeonOZ]koWj[N00?oWj[N1OnN/^HEooooo`03o`000?oooooooooo
03Kooooo000/ooooo`;o0000>_ooool2oj68^PGoWhFh0onMPK@4oi]l/@CoVGR^1?nGMJ/2oiIcZ@03
oheSWOn=HicoSF>L00;oSF>L0on=HY/4ohiRV`CoSV>K0on?Hi/4oi1TV`CoT6FL1OnAIY`2oi9WW@03
oiEXW?nGJigoUf^M00;oUf^M1OnIKIh4oi]`X0?oWG>S00?oZGnWojR1Z_nXPJX00onXPJX5ojB1[P;o
W7jb0_nWU<45oiV:``?oSX;21?n;P<84oi64`@GoVHW100?oY972okBff_nd]]X00_nd]]X4okjnf@;o
/?_N0_nBOk/2oi=c[0CoTWF_1OnBN;<3oi=n^@?oU8Bo0ol00003oiF;a`;oUY?>0_nNS/<2oibCb@03
o`000?nLTlWoW9?900CoViO?1?nIW=D00onGXMcoX:?Goj2Se`02oj2Se`GoWj[N0_nN/^H3ojVhi1Go
oooo00?o0000ooooooooool0=Oooool002cooooo0ol0000gooooo`03oj:;^onQR;[oXHRj00;oXHRj
1?nOQKP3oif1]0GoVgba0onIN:h2oiMeZ`;oSFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`CoSf>K
0on@I9/5oi1UW0CoTFJL00?oTVNMoiEXW?nEJ9`01OnGJid4oiU]WPCoVg2P0_nMLj<2ojUoY`GoZ86Z
1OnTPJh5ojND`@CoVH[30on>P/84oh^0`PGoTHC10onIRL400onUZm_o];KJokBffP04okBffP05okjn
fOn`nmko/?_NoiN1^_nDLZX01?nCLj`5oi9e[`CoTWRc0onCO[T3o`0000;oU8Bo0_nERlL2oij:_PGo
WXk30_nLTlT00ol0003oW9?9oi^Gc`04oi^Gc`;oVIcE00?oXIgAoj2SeonPXmL00onPXmL4oinZgP03
ojV`gOnY^>CoZKST00CoZKST5?ooool00ol0003oooooooooo`0eooooo`00;?ooool01?l0003ooooo
o`000?l0000dooooo`CoXX^k0onQR;X4oin5^0CoWH6d1?nKO;42oiUh[P03oheVX?n=I9koSFBN00;o
SFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`CoSf>K1?n@I9/4oi1UW0?oTFJL00CoTfNKoiEXW?nE
J9coUFRL1OnGJid4oiU]WPCoVg2P00?oWG>SojUoYonYOjL00_nYOjL4ojR1ZPCoY86^0_ngWKh4ojND
`@GoVH[30on>P/84oh^0`PCoTHC100?oVHW1ojF[fonUZm/00_nUZm/4okBffP;oX_KR00CoUG:YoiAb
Z_nDLZ[oU7:Z1OnCLj`4oi9e[`CoTWRc0ol000001OnCO[WoU8BooiB4_onDQ;ooWHFi00GoWXZn1?nN
S/<2oibCb@03o`000?nLTlWoW9?900;oViO?0_nRVL/4oj6Md@GoX:?G00?oWj[NojV`gOnY/=d00_nY
/=d4ojVhi003ok;0i?oooooooooo017ooooo00?o0000ooooool000002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool002cooooo
0_l00002ooooo`03o`000?oooooooooo02oooooo00?oXXZkoj:;^onRRk/00onRRk/3oj68^PGoWhFh
0onMPK@2oi]l/@;oSVRS0on=IZ04oheTWPCoSF>M0on=Hi`4oheRV`CoSV:K0on>Hi/4ohmSV`CoT6BK
1?n@II`01?nAIYcoTfNKoi=WVonCIi/4oiEXW0CoUf^M1?nIKIh4oi]`X0GoZGnW1OnXPJX2ojB1[P?o
]ifn1?nWU<45oiV:``?oSX;21?n;P<82oi64`@;oUj3J1OnUZm/3okBffP;oX_KR0_nELZT4oiAbZPCo
Tg>/1?nBMJl01OnBN;?o0000o`000?l0003oTWRc00?oTgji00?oU8Booif5^OnMQKT00_nMQKT4oij:
_PCoWXk30onLTlT00ol0003oY9K6oj:Ib`03oj:Ib`GoXIgA0_nPXmL2ojVZe`KoZK3M00?oZKSTok;0
i?nb`>@00_nb`>@Eooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Wooooo000[ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:oooool00onRR;WoXXZkoj::^`02oj::^`CoXX^k1?nQR;X4
oin5^0;oWH6d00?oSfbVohiXXon>J:<00_n>J:<3oheVX0CoSFBN1?n=Hid3oheSW0CoSF:K1?n>HY/3
ohiSV`CoSf>K1?n@I9/3oi1UW003oi9VVonCIi_oTfNK00;oTfNK1?nEJ9`4oiM[W@GoVFfN0onKL:05
ojUoY`GoZ86Z00?oY86^okNM__ngWKh00_ngWKh5ojND`@;oVH[30_nIX]/3ohbHfPCoRIOJ1OnGX=X5
ojF[f`03okBff_nRm^;oX_KR00CoUG:Y0onDLZX4oi=c[0?oTWF_0_l00004oi9h/`;oTgji00?oW82d
oif5^OnMQKT00onMQKT4oij:_PGoWXk300GoW9?9ojBFa_nTU/Ko0000ojBFaP04oj:Ib`?oXIgA00?o
ZZGBojVZeonYZ]L00onYZ]L4ojV`g@03ok:lhOnb`>Co//3T00?o//3T5Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wo
oooo000[ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool3oj:8^@?oXXZk
1OnRRk/3oj68^P;oWhFh0_nBLJX3ohm/YPCoSVRS1?n=IZ03oheTWPCoSF>M0on=Hi`4oheRV`CoSV:K
1?n>Hi/3ohmSV`CoT6BK00CoT6FLoi9VVonBIY_oTVJK1?nCIi/4oiEXW0CoUf^M1OnIKIh2oi]`X0;o
Z7fU1?nYOjL4ojR1ZP03ol6S_?ngWKko]ifn00Co]ifn0onWU<400on^/M[oVJ;KoiVRf`03oiVRf`?o
S9SJ1?n9UmX5oiNPfP;oYJ_K0on=k>d2oiMcZ@CoUG:Y0onDLZX4oi=c[0?o00000_nBMJl3oi9h/`03
oi]k[onLP;CoW82d00;oW82d1?nMQKT5oij:_P;oWXk30_nUTl83ojBFaP03o`000?nTU/KoXYW;00?o
XYW;00?oXIgAojZUd_nZYM800_nZYM85ojVZe`03ojV`gOnb_>7o/[cQ00;o/[cQ0onb`>@2okS8iaGo
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0Iooooo`00:oooool3o`0000Gooooo00?o0000ooooooooool09_ooool00onQ
Q[OoXXRioj:8^@02oj:8^@?oXXZk1OnRRk/2oj68^P03oiIg[_nBLJ[oTW6Z00;oTW6Z0on?K:H4ohiX
X`CoSFJP0on=I9h4oheSW@CoSF>L0on=HY/4ohiRV`CoSV>K0on?Hi/3oi1TV`03oi5UVonBIY_oTVJK
00;oTVJK1?nCIi/4oiEXW0CoUf^M1OnIKIh01?nKL:3oZ7fUojQmYOnXOJD5ojUoY`;oZ86Z0oo1Xk`5
okNM_P03ojND`On^/M[o[[7J00;o[[7J1?nIX]/3ohbHfPGoRIOJ0_nGX=X4ogWNm`03ohg/kOnGLjWo
Ug>Y00;oUg>Y1?nELZT3oiAbZP05oi=c[?l0003o0000o`000?nCLj`01?nBMJl01?nBN;?oVg^_oi]k
[onKNjl4oib0]0GoWHFi0onNR[h00onWTKkoYI?2ojFC`P03ojFC`P?oY9K600Go0000oj:IbonRVL_o
XYW;oj^RcP05ojZUdPCoZJ[G00?o/kWMok:lhOnb_>400onb_>400onb`>Co^<SWokS8i`03okS8iaGo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c00Iooooo`00:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo0onQQ[L4oj:8^@CoXXZk0onRRk/01?nJO;7oUWN^oiIg[_nFMjh4oi9aZPCoSfbV0on>J:<4
oheVX0CoSFBN0on=Hid4oheSW0?oSF:K1?n>HY/4ohiSV`?oSf>K00CoT6BKoi5UVonAII_oTFFK1OnB
IY/3oi=WV`CoUFRL1OnGJid3oiU]WP03ojAiY?nXOJGoZ7fU00;oZ7fU1OnYOjL00onXPJ[o`J>lol6S
_002ol6S_0Co]ifn00?oa/7Fojjaf_n^/MX00on^/MX5oiVRf`?oS9SJ0_n9UmX4of79n`;oNMkg0onI
M:P4oiMcZ@CoUG:Y00CoU7:Zo`000?l0003o00001?nCLj`2oi9e[`;oVGN[1OnKNjl3oib0]0GoWHFi
00?oWXZnojNA__nWTKh00_nWTKh4ojFC`PCoY9K600?o0000oj:Ibon[X/h00_n[X/h5ojZUdP03ojVZ
eonc^Mgo/kWM00;o/kWM0onb_>42okW;j0Co^<SW00?o]lcZooooooooool04oooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Kooooo`00
:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?oXHBeoj66]onQQ[L0
0_nQQ[L5oj:8^@?oXXZk00CoXX^koiYl/OnJO;7oVWba1?nFMjh3oi9aZPCoSfbV0on>J:<4oheVX0Co
SFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`;oSf>K00?oT6BKoi5UVonAII/00_nAII/5oi9VV`?o
TfNK1?nEJ9`5oiM[W@;oVFfN0_nTNJ@4ojQmY@GoZGnW1Oo1Xk`3okNM_P?oa/7F1On^/MX2oiVRf`Co
O=3o1?mWa_h2of79n`?oVWFX0onIM:P4oiMcZ@;oUG:Y0ol00003oiAbZP?oTg>/00?oUg>XoiUgZonI
Mj/00_nIMj/5oi]k[`CoW82d0onMQKT00onXSk_oYi6nojNA_P03ojNA_PGoYI?20_nTU/H2ojbObP04
o`000?n[X/koZj;>oj^RcPCoZZGB00?o];OKok>igOnc^Md01?nc^Md00onb_>7o^L_XokW;j002okW;
j003okS8iongc>[o]lcZ00;o]lcZ4oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01_ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07_ooool3oj64]@CoXHJg1?nRR;T2oj::^`03oij1/_nJO;7oVWba00?oVWba0onFMjh3
oi9aZPCoSfbV1?n>J:<3oheVX0CoSFBN0on=Hid4oheSW0CoSF:K0on>HY/4ohiSV`?oT6BK1OnAII/4
oi9VV`CoTfNK0onEJ9`5oiM[W@03oiU]W_nTNJCoY7VT00;oY7VT0onXOJD5ojUoY`03olNX^oo1Xkco
`J>l00?o`J>l00?o]ifnolK1e_o6`MH00oo6`MH2ojjafPCoW^Cl0_mld?l2oin7^P03oj><^onJMJSo
VWFX00KoVWFX0onIM:P3oiMcZ@?o00000onELZT3oiAbZP04oi=c[?nGLjSoUg>XoiMcZ0GoVGN[1?nK
Njl4oib0]003oif5^OnXSk_oZ8nk00;oZ8nk1?nWTKh4ojFC`P03ojjOb?n/Wl[o[9o:00;o[9o:00?o
0000oj^Rc_n[X/h00_n[X/h00onZYM;o];OKokBgf`02okBgf`Co/kWM00?o^/kYokW;j?nibnP00_ni
bnP2okOCkPGo]lcZ5Oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@41Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool01?ooool3o`0000[ooooo00?o0000ooooooooool06_ooool2
oj64]0CoXHBe1?nQQ[L3oj:8^@04oj63/_nNPK;oWX6boij1/PGoVWba0onFMjh4oi9aZP?oSfbV1?n>
J:<3oheVX0CoSFBN1?n=Hid3oheSW0CoSF:K0_n>HY/00on=HY_oSV>KohiSV`02ohiSV`?oT6BK1OnA
II/4oi9VV`CoTfNK1?nEJ9`3oiM[W@03oj5gXonTNJCoY7VT00?oY7VT1?nXOJD3ojUoY`;oajRk1?o1
Xk`00ooEcmCoa/7FolK1eP03olK1eP?o_OS^0_nNi?`3oiV1^0;oWhNj00?oVGBXoiYeZ?nJMJP01onJ
MJP3oiUdZ0?o00000_nGLjT4oiEbZ@;oU7:Z00?oUW2UoiMcZ?nGLjP00onGLjP4oiUgZ`GoVg^_0_nL
P;@00onXS;SoZ8nkojR?^`03ojR?^`GoYi6n00?oYI?2ojjOb?n^WlP00_n^WlP4ojbObP04o`000?n[
X/koZj;>okFffPKo];OK00?o/kWMok[>jOnjc^T00_njc^T00onibnSo]m?^okOCkP03okOCkP;o]lcZ
0_nacNhEooooo`03o`000?oooooooooo02oooooo0008ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo1Ol00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5_ooool6oj64]0?oXHBe1?nQQ[L01?nRR;WoXH>boj63/_nQPk84oij1/PCoVWba0onFMjh4oi9aZP?o
SfbV1?n>J:<4oheVX0?oSFBN1?n=Hid3oheSW0CoSF:K00?oSV:KoheRVon=HY/01?n>Hi/4oi1TV`Co
TFFK1?nBIY/4oi=WV`CoUFRL0_nGJid2oj5gX`GoY7VT1?nXOJD2ojUoY`?oajRk0oo1Xk`3omG?e0?o
a/7F0onmn>h2oi=h/`?oVH6h00CoV7:VoiUdZ?nIM:SoVGBX2OnJMJP00onIM:So0000o`000005oiMc
Z@?oUG:Y00?oUFjSoiI`YOnFL:D00_nFL:D4oiMcZ0CoVGN[1OnKNjl01?nLP;CoZ8bhojR<^?nXS;P4
ojR?^`CoYi6n00?o/J37ojjOb?n^WlP00on^WlP4ojbObP03oj^Rc_l0003o]KKJ00;o]KKJ1?nd]m/0
0onke>co^/kYok[>j@02ok[>j@;o]mcc1?ngdnh00on_eoCo/Lg^ok7=kP03ok7=kQGooooo00?o0000
ooooooooool0;_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Dooooo`OoXHBd1?nQ
Q;D2oj66]`03oj:3/_nQPk;oXH>b00?oXH>b0onNPK84oiYl/@?oUWN^1?nBLJX4ohm/YP?oSVRS1?n=
IZ03oheTWPCoSF>M0on=Hi`2oheRV`;oRf6K0on=HY/4ohiSV`CoT6BK1?nAII/4oi9VV`CoTfNK1?nE
J9`01?nGJigoXGNSoj5gXonQMj<5ojAiY0CoZ7fU00?oZGnWolNX^oo7Z;/00oo7Z;/00oo1XkcoeLoD
omG?e003omG?e004olK1e_nmn>ko_OS^ohma[0?oTgRc00CoVH6hoiQbY_nHLZKoV7:V1?nIM:P6oiYe
Z0?o00000onIM:P4oiMcZ@04oiEbZOnEKZ?oUFjSoiE^X`CoUW2U1?nGLjP4oiUgZ`CoVg^_00?oZ8Zf
ojR<^?nXS;P00_nXS;P5ojR?^`;oYi6n0onaX<L4ojjOb0?o[9o:00?o]kSJokFff_l000001?ne]]X0
0ond]m_o^mC/ok_Dk002ok_Dk003ok[>jOngg??o]mcc00?o]mcc00?o]m?^ojoGm?n_eo@00_n_eo@2
ok7=kP?oYlO`5Oooool00ol0003oooooooooo`0]ooooo`004?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo017ooooo00?oXXJfoj64]?nQQ;@01_nQQ;@4oj64]@03oj66]onRPk;oXX>b00GoXH>b0onN
PK85oiYl/@?oUWN^0onBLJX4ohm/YP?oSVRS1?n=IZ03oheTWP;oSF>M0_n9H9`3ohYPV`CoRf6K0on=
HY/4ohiSV`CoT6BK1?nAII/4oi9VV`CoTfNK0onEJ9`00onMM:CoXGNSoj5gX`03oj5gX`CoY7VT1?nX
OJD6olNX^`GoeLoD0_nloMH3ohma[0;oTgRc00?oUg2UoiQbY_nHLZH00onHLZH3oiUdZ0?oVWFX0ol0
0003oiYeZ0?oVGBX0_nGLjT2oiA/X@CoUFjS1?nFL:D4oiMcZ0GoVGN[0_nKNjl2ojR:]PCoZ8bh1OnX
Sk/00onWTKko/J37ok6Pa`02ok6Pa`Go[Yo800Ko[9o:okNhf_ng^=[o]kSJokFff_l00002okFffP;o
_=c`0onke>`3ok?Um`;o]mcc0onZhOX3ojoGm0;oY<kf1OnWao0Dooooo`03o`000?oooooooooo02go
oooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o
00003oooool2o`0000oooooo0onRQ[H9oj64]0;oXHBe00?oXX6aoj:3/_nRPk800_nRPk84oj63/PCo
WX6b1?nJO;43oiIg[P?oTW6Z1?n?K:H3ohiXX`;oSFJP0_n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`Co
SF:K0on>Hi/4oi1TV`CoTFFK1OnBIY/3oi=WV`;oUFRL0_nMM:@5oj5gX`GoY7VT0onXOJD00oo8[;go
ajRkolNX^`03olNX^`04on3Ne?oEcmCoeLoDomG?e0;o_?gF0on?LJ`01?nGKj;oUg2UoiM`YOnGL:D5
oiQbYP?oVGBX0ol00006oiYeZ0;oVGBX00?oUF^PoiA/XOnDK:400_nDK:45oiE^X`CoUW2U0onGLjP5
oiUgZ`03oi]k[onXR[KoZ8Zf00;oZ8Zf1?nXS;P3ojR?^`03okBSaonaX<Oo/J3700?o/J371?n^WlP0
0onj_=_o]kSJokNhfP03okNhfP03okFff_l0003o_=c`00?o_=c`00Co^mC/ok?UmonciOOo/nGg0_nM
j?/5oj[QnP03ojoGm?nTc_KoY<kf00;oY<kf0_nWao02oinokaGooooo00?o0000ooooooooool0;?oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03ojB:^?nRQ[KoXXJf00?oXXJf2?nQ
Q;@00onQQ;GoXX6aoj:1/@04oj:3/PGoXH>b0onNPK82oiYl/@;oTGB_0on:KJ/3ohEVY`CoQ6:S0on4
H:04ohIOWP?oR5nL1?n9H9`3ohYPV`CoRf6K1?n=HY/3ohiSV`CoT6BK1?nAII/5oi9VV`?oTfNK00Co
UFRLoiedY?nMM:CoWGBT1OnQMj<5ojAiY0;oZ7fU0oo8[;d3olNX^`?oh=kD00GoeLoDokcme_nBKZKo
TVjVohma[003oiM_XPCoUg2U1?nHLZH3o`0000WoVWFX00?oVGBXoiE[X?nEJj001?nDK:45oiE^X`Co
UW2U1?nGLjP3oiUgZ`03ojN8/onXR[KoZ8Zf00?oZ8Zf1?nXS;P00onXSk_o]:?7okBSa`02okBSa`Go
/J3700?o[Yo8okZlfonj_=/00_nj_=/3okNhfP?o^^Kd00?o0000okcLl?nYk_P00_nYk_P00onciOOo
WNSkoigXn`03oigXn`;oZ^7j0onNeO/2ojC>mP;oW<7b1OnO_nlCooooo`;o0000;_ooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`?oY8Zh1?nRQ[H7oj64]003oj20/?nRPK7oXX6a00;o
XX6a0onRPk85oj63/P;oWX6b00?oVWbaoi5d[onAM:l00_nAM:l3ohY]Z`?oQFJW1?n4HZ<3ohAPX0Co
QUnN0on8Gi`4ohUPW0CoRV2K0on;HI/4oheRV`CoSV>K0on@I9/5oi5UV`CoTVJK0_nCIi/00onKLZCo
WGBToiedY003oiedY0CoXGNS1OnTNJ@00onXOJGob:bmolR/_@02olR/_@;oajRk1?oPg]@01?nDiJ7o
TVjVoi9^Y_nKKj04oiM_XPCoUg2U00CoV7:Vo`000?l0003o00000onIM:P7oiYeZ0;oUF^O0onEJj05
oiA/X@CoUFjS1?nFL:D4oiMcZ003oiUgZonWR;?oYhRc00;oYhRc1?nXR[H4ojR<^0Go]:?71?naX<L0
0onma=oo^[cKokZlf`03okZlf`03okNhf_nji_Co^^Kd00;o^^Kd00CoT^k^o`000?nYk_SoZNkh1?n3
i_42oigXn`?oU=Wn0_nNeO/3oiW2m0CoW<7b1?nO_nlEooooo`03o`000?oooooooooo02_ooooo000Y
ooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`03ojJ>^onTR[SoY8Zh00;oY8Zh1?nRQ[H5
oj64]0?oX82`1?nRPK44oj:3/P?oXH>b00CoX86aoiYl/OnJO;7oVWba1?nAM:l4ohY]Z`?oQFJW0on4
HZ<3ohAPX0CoQUnN0on8Gi`4ohUPW0CoRV2K0on;HI/4oheRV`CoSV>K0on@I9/5oi5UV`CoTVJK00?o
TfNKoi]bY?nKLZ@01OnMM:@4oj5gX`GoY7VT1_o8[;d01_o7Z;_oh=kDon3Ne?oPg]CoU>FQoi9^YP?o
VfnP1?nGKj82oiM`Y@?o00000onHLZH4oiUdZ0?oVWFX1OnEJil4oiE[X0CoU6bQ1?nEKZ<5oiI`Y@;o
Ug>X00?oYXFaojN8/onWR;<00onWR;<5ojR:]P;oZ8bh0_nhZ<T5okBSa`03ok6Paonma=oo_LCO00;o
_LCO0onj_=/3ok;am@07ok[Vm?nBk^koT^k^oi;^k_mHd]?o0000oeSBd`02oh?Vl@?oQ=[n0_nDfOh3
oiK1m@GoVL;d1?nL`O82oinok`;oW;W]5Oooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo0onVS[/3ojB:^0GoXXJf0_nQQ;@00onN
Ok7oX82`oj20/002oj20/0CoXX6a1?nRPk801?nQPk;oX86aoj21/OnPPK44oiYl/@?oTGB_1?n:KJ/3
ohEVY`?oQ6:S1?n4H:03ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/4ohiSV`CoT6BK1?nAII/3
oi9VV`04oiQaY?nKLZCoVg:Toi]bY0GoWGBT1OnQMj<3ojAiY0;ob;741Oo8[;d2on7bf@03on3Ne?nF
KJ;oUVfR00CoVfnP1?nGKj82o`0000;oUg2U1OnHLZH3oiUdZ003oiYeZ?nEJiooUF^O00GoUF^O1?nE
Jj04oiA/X@CoUFjS1OnFL:D00onGLjSoYXFaojJ5/@05ojN8/`GoZ8Zf00CoZ8bhokRXbOnhZ<Wo^:S9
1?ndXlL00oo1d>Ko_LCOokg4g`04okg4g`06okZlfonblOGo/_7eok;amOmTfLco00001?mPc_L01?mb
e__o0000og;Fnombe_/2ohCJoP;oT[cd1OnF`OD2oiW2m0;oV[CZ1?nK]n`5oibikACooooo00?o0000
ooooooooool0:_ooool002Wooooo00?o0000ooooooooool05Oooool01?l0003ooooooooooonYTkl4
ojJ>^`CoY8Zh1?nRQ[H00onQQ;CoWWnaoiio/@04oj20/0GoXX6a0_nRPk800onSP[7oX86aoj21/@03
oj21/@?oVWba1?nAM:l3ohY]Z`?oQFJW0on4HZ<4ohAPX0?oQUnN0on8Gi`4ohUPW0CoRV2K1?n;HI/3
oheRV`CoSV>K1?n@I9/4oi5UV`04oi9VVonHLJCoV76ToiQaY0CoVg:T1?nMM:@5oj5gX`;oY7VT0oo8
/L@4olR/_@;ohO;I00CoVVjOoiI]X_nFKJ;oWW6N1OnKKj03o`000004oiM_X_nGL:GoUg2UoiM`Y@Go
V7:V0_nIM:P00onFJikoUF^OoiE[W`07oiE[W`?oUF^P1?nDK:45oiE^X`?oUW2U00?oYH>`ojJ5/OnV
QK400_nVQK45ojN8/`?oZ8Zf00?o_K3=okRXbOnhZ<T00onhZ<T00ondXlOo`M3Vol7@iP02ol7@iPCo
_LCO0_nIl^P00onblOGoF<OgoeS7m`02oeS7m`;oH<kg0_n?[>T2oi2fl003o`000?n@]_3oT[cd00Co
T[cd0_nF`OD2oiV_iPGoV[CZ1?nK]n`2oibik@?oW[OZ5?ooool00ol0003oooooooooo`0Yooooo`00
:Oooool00ol0003oooooooooo`0Fooooo`CoZI>o0onVS[/4ojB:^0;oXXJf0_nMP;<4oiio/@CoX82`
1?nRPK400onRPk;oXh:aoj>2/@05oj21/@?oVWba1?nAM:l3ohY]Z`?oQFJW1?n4HZ<3ohAPX0?oQUnN
0on8Gi`5ohUPW0?oRV2K1?n;HI/3oheRV`CoSV>K1?n@I9/3oi5UV`03oiM`Y?nHLJCoV76T00;oV76T
1?nKLZ@4oiedY0GoXGNS00?oY7VTolRaa?o8/L@00_o8/L@3olR/_@;ohO;I0_nJKYl00onFKJ;oWW6N
oiiaWP02oi]_X0?o00001?nGKj84oiM`Y@CoV7:V00?oVGBXoiI[W_nFJih02OnEJil3oiE[X0CoU6bQ
1OnEKZ<2oiI`Y@;oYH>`1?nVQK45ojN8/`03ojR:]_nm/<go_K3=00;o_K3=1?nhZ<T00oo2h^oo`M3V
ol7@iP03ol7@iP04okg4gonIl^SoVO;XoiWbj0;oTYCB1OnAX=l4ohn/j@04oi2fl?l0003oT;K`oi2f
l0;oT[cd0_nIZN45oiV_iPCoV[CZ0_nK]n`3oifai@GoW[OZ5?ooool00ol0003oooooooooo`0Xoooo
o`00:Oooool3o`0001Cooooo00?o[9S3ojVC_onYTkl00onYTkl4ojJ>^`;oY8Zh00?oWH:eoif0/onM
P;<00_nMP;<4oiio/@CoX82`0onRPK400onSP[3oXh:aoj>2/@02oj>2/@CoX86a0onJO;44oi5d[`?o
RVf[0on5IZL4ohARX`?oQ62P1?n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`CoSF:K0on>Hi/4oi1TV`04
oi5UVonGL:CoUg2ToiM`Y0CoV76T1?nKLZ@5oiedY0?oXGNS00?oa[S=olRaa?o8/L@01?o8/L@00oo8
[;gohO;Ion7bf@03oiY^W`;oWW6N0ol00003oi]_X0CoUfnR1?nGL:D3oiQbYPCoUV^N2OnEJil3oiE[
X0GoU6bQ1?nEKZ<00onFL:GoYH>`ojF3/002ojF3/0?oYXFa1?nWR;<00oo2^m?o_K3=okf`c@03okf`
c@?o^:S90oo2h^l2ol7@iP;oH=>h0onER/H4oi:DdPGoTJ3O0_n?[>T01OnKV];oVZ;JoiZRf_l0003o
VZ;J00GoVJWQ1OnI[nH2oiZdjP03oij[h?nM/NGoWK7U00CoWK7U0_nN]nX2oj>ij1?ooooo0_l0000Z
ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`?o[9S31?nYTkl4ojJ>^`03ojB:^?nMP[GoWH:e
00GoWH2c0onNOk44oj20/0;oXX6a0_nSP[04oj>2/@CoX86a1?nJO;43oi5d[`CoRVf[0on5IZL3ohAR
X`?oQ62P1?n6Gih3ohQOW0CoRF2L0on:H9/4oh]QV`CoSF:K0on>Hi/2oi1TV`;oU6jT1?nGL:@4oiQa
Y0CoVg:T1OnMM:@2oj5gX`?oa[S=1?o8/L@2olKoe@04oie_WOnJKYooVVjOoiY^W`?o00000_nNLIh4
oi]_X0CoUfnR1?nGL:D00onHLZKoUV^NoiI[WP05oiI[WPSoUF^O0onEJj05oiA/X@?oUFjS00?oXh6_
ojF3/?nUPk000onUPk04ojJ5/@;oYhRc0oo2^m<5okf`c@05okRXbOo2h^oo`^;_ol;Rkol000001?nG
P[/3oiF:aPGoTYCB0_nAX=l2oifCb@CoVi[B0_nJX]X00ol0003oVZ;JoiVYh@04oiVYh@;oVJoV0_nO
YMX4oij[h0CoWK7U00?oY;?Toj>ij?nS^NP00onS^NPDooooo`03o`000?oooooooooo02Oooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo01;ooooo00?o[Yk7ojbH`on/V<<00_n/V<<5ojVC_`;oYXjk00?oWXFhoif2]OnMP[D00_nM
P[D4oif0/`?oWWna1?nPP;000onRPK7oXh:`oj>2/002oj>2/0?oXh:a1OnPPK43oiYl/@?oTGB_1?n:
KJ/3ohEVY`?oQ6:S0on4H:04ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/2ohiSV`03oi9]YOnD
KZCoU6jT00;oU6jT1OnGL:@4oiQaY0?oVg:T1OnMM:@00onQMj?oa[S=olJhc@02olJhc@?ob;740_o6
omD2oie_W@?o000000?oXG:MoiiaW_nNLIh00_nNLIh4oi]_X0CoUfnR0onGL:D00onHK9koUV^NoiI[
WP06oiI[WPSoUF^O1?nEJj04oiA/X@04oiE^XonSPJooXh6_oj>1[`GoYH>`1?nVQK400onWR;?o`[_C
ol:kd`02ol:kd`Co_K3=0_nimO401?o2h^ooVGbboiUl/_nIO;84oiN2^`CoUH[60_nBU=82oin=`@Go
WI?90onKV]82oiZRfP03o`000?nJX][oVZ;J00;oVJWQ0_nOWm@5oinUfPCoWZ_P00?oWK7UojBci?nT
/n@00_nT/n@4oj>ij1Gooooo00?o0000ooooooooool09_ooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooo
ooooool04Oooool3ojjNa`?o[9S31?nYTkl01?nORKcoWXFhoij5^?nNQKP4oif2]@CoWH2c1?nNOk42
oj20/003oj61/OnSP[3oXh:`00?oXh:`0onSP[45oj21/@;oVWba00CoUGbeohIa]?n6LKCoQW6d1?mk
I[03og=N[0?oQ6:S1?n4H:03ohIOWP?oR5nL1?n9H9`4ohYPV`?oRf6K1?n=HY/00on>Hi_oTVfUoi9]
Y@04oiA^Y0GoUg2T1?nHLJ@4oi]bY0?oWGBT00?o`/;JolJhcOo6^<d01?o6^<d00oo8/LCoa_oEolKo
e@03o`000003oiY^WonQLYgoXG:M00;oXG:M0onNLIh5oi]_X0?oUfnR00CoUg2UoiQ/W_nHK9koV6bN
2?nFJih8oiE[W`CoUF^P0onDK:400onRP:koXh6_oj>1[`03oj>1[`CoYH>`1?nVQK46ol:kd`04okf`
cOnimO7o^OGaokWel@GoVGbb1?nGP[/3oiF:aP03oj:9^_nOSL7oWhg100?oWhg11?nMTlT4oi^JdP;o
VZ;J00?o0000oj6JcOnOWm@01?nOWm@4oinUfP;oWZ_P0onU[ml4ojBci0;oXkWX0onY_NPDooooo`03
o`000?oooooooooo02Kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool2o`00013ooooo00?o/JC;ojjNaon^W/L00_n^W/L4ojbH``04
ojVC_onORKcoWhVloin9_0CoWXFh0onMP[D5oif0/`?oWWna00?oX82`oj61/OnQPK401OnSP[04oj>2
/@?oX86a00CoWh>eoiEl]OnEO;GoUGbe0on6LK@4og]V/0?oLej/0omdG:P4ohAPX0?oQUnN0on8Gi`4
ohUPW0CoRV2K0on;HI/2oheRV`;oT6^U0onBKJD5oiA^Y0CoUg2T1?nHLJ@4oi]bY0;oWGBT0oo2`]X4
olJhc@04ofoCVonMKYco0000o`0000?oWFnM1OnQLYd3oiiaWPGoVfnP0_nGKj800onKKYkoV6bNoiQ/
WP02oiQ/WPSoUV^N2OnEJil3oiE[X004oiA/XOnRP:koXX2^oj:0[PGoXh6_1OnUPk02ojJ5/@;ob<_L
1?o2^m<3ohc]dP03okWelOnKNJcoVgV/00CoVGbb1OnGP[/01?nER/KoXXVjoj:9^_nRRKX4oin=`@Go
WI?90_nKV]801_nSULOoXI[=oj6JcOnQV/go0000oj6Jc@CoWioD0_nOYMX2ojJ[fPKoYJoO0_nT/n@2
ojZii@GoZKgX5?ooool00ol0003oooooooooo`0Uooooo`003_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0=ooooo`Co/JC;1?n^W/L2
ojbH``03oj:?`?nORKcoWhVl00?oWhVl0onNQKP3oif2]@GoWH2c0onNOk44oj61/@CoXh:`1?nSP[40
1?nPPK7oWh>eoin3]OnOPkD4oiEl]@?oQW6d0omkI[03og=N[0?oM5bX0omjGJH01?n4H:3oQUnNohIO
W_n6Gih3ohQOW0CoRF2L1?n:H9/2oh]QV`03ohiYY?n@JjGoT6^U00;oT6^U1?nBKJD4oiA^Y0CoUg2T
1?nHLJ@4oi]bY003oiedY?o2`][o`/;J00;o`/;J0oo6^<d3o`0000;oWFjL0onMKid5oj5bW@?oWW6N
1OnKKj000onGKj;oVfjNoi]^WP05oiQ/WPOoUV^N2OnEJil2oiE[X003oj5o[_nRP:koXX2^00?oXX2^
1?nSPJl5ojF3/003ojJ5/Oo8bmcob<_L00;ob<_L00Co`[_Cohc]d_n<kM;oS>gB0_nMMjL3oi]i[0Go
VGbb0onGP[/00onTQkGoXXVjoj:9^P02oj:9^PCoWhg11?nMTlT00onUT/7oXiG7oj>Ea`02oj>Ea`?o
XI[=00Go0000oj6JcOnOWmCoWioDojRWe@05ojJ[fPCoYJoO00?oZkORojZiiOnZ^ND00onZ^ND2ojVm
j0;o[L7Y5Oooool00ol0003oooooooooo`0Tooooo`003_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0;ooooo`03okBYc_naY<_o/JC;
00?o/JC;0on^W/L00onUU<CoXXo0oj:?`002oj:?`0CoWhVl0onNQKP4oif2]@?oWH2c00CoVWjcoiio
/OnNOk7oWWna1?nQPK45oj>2/0;oXh:a00?oYHJdoin3]OnOPkD00_nOPkD4oiEl]@?oQW6d0omkI[04
og=N[0;oM5bX1?mjGJH3ogmPY@?oR5nL0_n9H9`2ohQVY0CoRfRT0on>JJ@5oi1[Y@?oTVfU1?nDKZ@4
oiM`Y0CoV76T0onKLZ@00onnc>Go`/;Jol;2fP03ol;2fP?o00001OnMKY`2oie_W@03oj9cWOnQLYgo
XG:M00?oXG:M0onNLIh5oi]_X0?oVfjN1OnHK9h7oiI[WPWoUF^O00?oUF^Poj5o[_nQOjh01OnRP:h5
oj>1[`?oYH>`00?obn7XolS;g?o8bm`00_o8bm`00ol0003oWgJToiegY`04oiegY`?oVgV/1OnIO;80
0onGP[_oY8NeojB7]@02ojB7]@?oXXVj1OnOSL401?nMTlWoYI;1ojFB`OnUT/44oj>Ea`?oXI[=00?o
0000oj^UdOnXYmD00onXYmD5ojJ[fP03ojF_gon[]n;oZkOR00;oZkOR0onZ^ND00on^`NSo[L7Yojg1
j@03ojg1jA?ooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c009ooooo`003_ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool2o`0000_ooooo0ondZLh5ok6Tb`04ojjNaonUU<CoYIC4ojFD
a0?oXXo01?nORK`4oij5^0?oWH:e00CoWH2coiYn/onJO[?oVWjc1?nNOk43oj61/@GoXh:`00CoXh:a
ojF6]?nUQ[CoYHJd1?nOPkD3oiEl]@?oQW6d1?mkI[03og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8
IZ@4oh]XY0?oSVVT1On@JjD3oi9]Y@CoU6jT1OnGL:@3oiQaY003oi]bY?nnc>Go_/cU00;o_/cU00Co
`/;Jo`000?l0003o00001?nJK9`4oie^W004oie_WOnRLigoXW>Moj9cW@CoXG:M1?nNLIh3oi]_X003
oimaW_nKKYkoVfjN00;oVfjN1?nHK9h7oiI[WPSoUF^O00?oXGn_oj5o[_nQOjh00_nQOjh4oj:0[PGo
Xh6_00?oYH>`ol_Qj?o;hNP00_o;hNP00oo8bmcoVgV/oiUn/`03oimfY0CoWGNW1?nKNJ`3oiUl/P03
ojN6/OnTQkGoY8Ne00?oY8Ne1?nRRKX3oin=`@03ojRA_OnUT/7oYI;100?oYI;11?nSULL01?nQV/go
ZjGAoj^UdOl00005ojRWe@;oYZ_J0on]]]l4oj^ghP03ojZiiOn^`NSo[/7X00;o[/7X0on]`NT2ojk5
jaCooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B402Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool2o`0000[ooooo00?o]ZoBokBYc_ndZLh0
0_ndZLh4ok6Tb`03ojRKb?nUU<CoYIC400;oYIC40onRSl05oin9_0?oWXFh0_nMP[D00onHOkKoVWjc
oiYn/`02oiYn/`CoWWna1?nQPK43oj>2/003ojJ7/onUQ[CoYHJd00;oYHJd1?nOPkD4oiEl]@;oQW6d
1?mkI[03og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8IZ@4oh]XY0CoSVVT1?n@JjD3oi9]Y@CoU6jT
1OnGL:@2oiQaY0?o^=?^00Go_/cUo`000?l0003o0000ol;2fP02oi5VW0CoVVbL0onMKY`00onQLiko
XW>Moj9cW@02oj9cW@CoXG:M1?nNLIh2oi]_X0;oWg6N1?nKKYh4oiQ/WPSoUV^N1OnEJil3oj5o[`Co
XGn^1?nRP:h4oj>1[`;o`OK^0oo;hNP2oi]i[003oj5fXonOMZCoWgJT00;oWgJT1?nMMjL4oi]i[003
oiUl/_nWQ[7oYhJa00;oYhJa1?nTQkD4oj:9^P03oin=`OnXTKgoZ96m00;oZ96m1?nUT/43oj>Ea`03
ojjTc_n[YM7oZjGA00;oZjGA00Go0000ojRWeOnXYmGoZ:OEok2ggP06ojffg`;oZkOR0_n_`^P5ojk1
j003ojg1jOn^aN_o[/G[00;o[/G[5?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Wooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0
1oooool4okJ_dPCo]:W>00?o/JC;ojRKb?nXVlP00_nXVlP3ojFDa0CoXXo01?nORK`2oij5^004oiN1
^OnHOkKoV7nfoiQo]PGoVWjc0onNOk44oj61/@03oj>2/?nVQk?oYXNc00;oYXNc0onUQ[@4oin3]@Co
UGbe0on6LK@3og]V/0?oLej/0omdG:P3ogYMYPCoOf2U0on5Hj@4ohQVY0?oRfRT1?n>JJ@4oi1[Y@?o
TVfU1OnDKZ@4oiM`Y003oiQaY?nhdnko^=?^00?o00000_nnc>D4oi5VW0CoVVbL0_nMKY`2oj5cWPCo
XW>M1?nQLYd4oiiaWP03oi]_X?nOLIkoWg6N00;oWg6N0onKKYh4oiQ/WPSoUV^N0onEJil00onQPK3o
XGn_oj5o[`03oj5o[`?oXGn^1OnRP:h2oj>1[`Co`OK^00?obn7Xoi]i[?nKNJ`00_nQMZ<4oimfY0Co
WGNW1?nKNJ`5ojN6/@GoY8Ne0_nRRKX00on/T[_oZ96mojRA_@03ojRA_@CoYI;100?oXiG7ojjTc_n^
Y<h00_n^Y<h4oj^Ud@03o`000?n`]mko/;ON00;o/;ON1?n]]]l00onaaNSo[l;Xojo2j003ojo2j0;o
[/7X0_n_b>`4ojk5j`03ojc5k?oooooooooo01;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`009oooool00ol0
003oooooooooo`05ooooo`;o^KGF1Onf[m82okBYcP03ojbQcOnXVlSoZ9_800?oZ9_81?nUU<@3oj:?
`0;oWhVl0_nGQ;d4oiN1^@?oV7nf1?nJO[<4oiio/@;oXH6a00?oXhJdojJ7/onVQk<00onVQk<4ojF6
]0?oWh>e0_nEO;D2oi:7a0?oMWS80omkI[03og=N[0?oM5bX0omjGJH4ogmPY@?oQF>T1?n8IZ@3oh]X
Y0CoSVVT1?n@JjD4oi9]Y@CoU6jT0onGL:@01?nbf?Co0000o`000?l00002okSCkP?oQUjL1?nAIY`4
oiY/W004oie^W?nQLikoXG>Noj5cWPCoXW>M1OnQLYd3oiiaWPGoWg6N0onKKYh4oiQ/WPSoUV^N00Co
UF^Ooj61/?nQPK3oXH6`1OnQOjl3oj5o[PGoXX2^00CoXh6_ol7fk_o1m^ko`OK^0onMMjL01?nKNJco
XGJSoj5fXonQMZ<4oimfY0GoWGNW0_nKNJ`00on[QjooYhJaojN6/@03ojN6/@GoY8Ne00CoXXVjojbB
^on/T[_o[9:k1?nXTKd3ojFB`@03ok:Vc?n^Y<ko[ZC>00?o[ZC>0on[YM400ond^]ko0000ok2ggP04
ok2ggP03ojffgonaaNSo/LGX00;o/LGX0on_`^P00on_cNoo[lS/ojo8k003ojo8k003ojk5jon/aNco
[<G/00;o[<G/5?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Wooooo000Wooooo`;o00001Oooool4okVeeP?o]ZoB00?o
[jSAojbQcOn/XLd00_n/XLd4ojRKb0CoYIC40_nRSl000onJR/7oUhBmoiN4_@02oiN4_@CoUh6i0onH
OkH4oiYn/`CoWWna00?oXH6aoj>6]?nSQ[@01OnVQk<4ojF6]0;oWh>e00?oXXjooi:7a?nBQl@00onB
Ql@2ogIhb0?oFf[81?mcGZ`2ogALZ0CoNUfV0omoH:D3ohESY0CoR6JT1?n;J:@3ohiYY0GoT6^U0onB
KJD4oiA^Y004oiM`Y?nbf?Co0000o`0000;o/]Sd00?o^=?^oh9LWOn2G9d01?n6GY`3oi5VW0?oVVbL
00?oWG2Ooj5cW_nQLih00_nQLih4oj9cW@GoXG:M0onNLIh5oimaWP?oVfjN1?nHK9h7oiI[WP03oj:3
/_nQPK3oXH6`00?oXH6`1?nQOjl4oj5o[P?oXX2^0_nDlM43oiieY0?oWGNW1OnQMZ<3oimfY0GoWGNW
00CoVgV/oj^7[on[QjooZhN_1OnWQ[43ojB7]@03ok6F^on/T[_o[9:k00;o[9:k1OnXTKd01?nUT/7o
/ZK<ok:Vc?nbY/`5ojjTcP05oj^UdOnd^]ko];[NokBjg_l000000on`]mh00oncb^_o/LGXok75j003
ok75j003ojo2j?n_cNoo[lg_00;o[lg_0_n_b>`3ojc9k`Co[<G/5Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo
000Wooooo`03o`000?oooooooooo00;ooooo00?o_;cJokVee_ni]MH01?ni]MH01?nf[m;o[jSAojnX
dOn_Z=44ojbQc@CoZ9_80_nUU<@00onLSlKoVX[1oiZ:`@02oiZ:`@?oUhBm1?nGPKT3oiQo]PCoVWjc
0_nNOk42oin4]PCoXhJd1OnVQk<2ojF6]003ojVA_?nRS[ooXXjo00;oXXjo1?nBQl@3ogIhb0;oFf[8
0_m3G/P2og=N[0?oM5bX0omjGJH3ogmPY@?oQF>T1?n8IZ@4oh]XY0?oSVVT1On@JjD3oi9]Y@;oU6jT
00CoZmWgo`000?l0003o00000_nbf?@2oh=MWP?oPUbM1?n6GY`3oi5VW0;oVVbL0_nML9l4oj5cWPCo
XW>M1OnQLYd2oiiaWP03ojAfW_nOLIkoWg6N00?oWg6N0onKKYh5oiQ/WPGoUV^N0_nRPk85oj61/0Co
XGn_1?nQOjh00onRP:koU?7AoiCad@05oiieY0;oWGNW00?oY7RRoj5fXonQMZ<00onQMZ<4oimfY0?o
WGNW00?o[hZ_oj^7[on[Qjl00_n[Qjl5ojN6/@04ojB7]OnaU[_o/IJkok6F^`Co[9:k1?nXTKd00ong
Zlgo/ZK<ok:Vc003ok:Vc0;o[ZC>0_ni`^45okBjgP03o`000?ncb^_o/l[[00;o/l[[0_naaNP3ojoB
l`?o[lg_0_n[cO85ojc9k`;o[<G/0_nX`ndBooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000009ooooo`009oooool01?l0003ooooooooooooo
ool3okblfPCo^KGF00?o/[3GojnXdOn_Z=400_n_Z=45ojbQc@;oZ9_800?oX9K:oib?a_nLSlH00_nL
SlH3oiZ:`@CoUhBm1?nGPKT3oiQo]P;oVWjc00?oVH:ioin4]_nOQ;H00_nOQ;H4oj>6]0GoYXNc00Co
YHJdojVA_?nYTKcoZI6l1?nRS[l3oi:7a0?oMWS80omKJ/P3od=Nb0?oM5bX0omjGJH3ogmPY@?oQF>T
1?n8IZ@4oh]XY0CoSVVT1?n@JjD2oi9]Y@04oj;Fn_l0003o0000o`0000;oZmWg0_mmFId3ogaGW0?o
PUbM1?n6GY`3oi5VW004oiY/W?nML9ooWG2Ooie`W`CoXG>N1?nRLid5oj5bW@04oiiaW_nTMYkoY7JN
ojAfWPCoWg6N0onKKYh5oiQ/WP?oUV^N00?oY8Jdoj:3/_nRPk800_nRPk84oj61/0GoXGn_0_nQOjh2
o`0000;oX7BR1OnNMJ@00onMMjOoY7RRojAhXP05oj5fX`CoWgJT0_nMMjL2ojn:[`CoZhN_1?nWQ[40
0onhW[ko/IJkok6F^`03ok6F^`Co[9:k00?oZ96mokN[cOngZld00_ngZld3ok:Vc003okg?j?ni`^7o
^L;Q00?o^L;Q0_nd^]h2okCBl004o`000?ncb^_o/l[[ok?:j`;o[=_h1On_d_<00on_cNooZlgboj_=
lP02oj_=lP;o[<W_0_nWao05ojS3kACooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Wooooo000Vooooo`?o00000_noa=h4okbl
fP03okVee_nb/=Oo/[3G00;o/[3G1?n_Z=42ojbQc@;oXig?1?nPU/X3oib?aP?oVX[11?nGQ;d4oiN1
^@?oV7nf00?oVWjcoiV2^OnIP[T01OnOQ;H3oj>6]0CoYXNc00?o[9:lojVA_?nYTK`00_nYTK`4oj:>
_`CoTXO40_mfN<P4oe]Zb0;o@ek80om4HL/3ogYMYPCoOf2U0on5Hj@4ohQVY0?oRfRT1?n>JJ@3oi1[
Y@04oiWAnol0003o0000o`0000?oX]Kj00CoZmWgogeIWOmmFIgoOEVM0omlEi`3ogiJW@CoQUjL0_nA
IY`00onBJIooWG2Ooie`W`03oie`W`CoXG>N1?nRLid4oj5bW@CoY7JN1?nOLIh4oi]^WPCoV6bN00Co
UV^NojB6]?nTQ[CoY8Jd1?nRPk84oj61/0GoXGn_00?oXGn^oj5eXOnPM:801?nPM:83oiieY003ojMk
Y?nTN:;oY7RR00;oY7RR1?nQMZ<4oimfY003oiegYon_RZoo[hZ_00;o[hZ_1?n[Qjl2ojN6/@?o^9jn
1?naU[/3ojbB^`03okbedongZlgo]j_=00?o]j_=00?o/ZK<okg?j?nmcnP00_nmcnP3okW2h@;o/]kf
1?ndd_000ol0003o/l[[ojcKn003ojcKn0;o[m;c0onWd_H2oj_=lP;oYLWb1OnWao02ojS3k@;oYL3]
5Oooool00ol0003oooooooooo`0Nooooo`009_ooool00ol0003o_lCNoko4gP03oko4gP;o_;cJ0_ne
^M`5ok:`e`;o[jSA00?oYZCDoj>MconSWLl00onSWLl3oj2FbP?oW8o61?nJR/43oiN4_@;oUh6i0_nA
P/03oiB1_0CoVH:i1?nOQ;H4oj>6]0;oYXNc0on/T[`3ojVA_0GoXXjo0_nBQl@01?nJXm_oKI?VoffC
i_m]TnH3oe]Zb0?o@ek80_m4HL/2oe=`dP03ogYMY_moH:GoOf2U00;oOf2U0on5Hj@4ohQVY0?oRfRT
1?n>JJ@01?n@JjGo0000o`000?l00002oiWAn`;oX]Kj0on2GYl3ogeIW@?oO5NL0omnFYd4ohEOWP?o
TVVO1OnML9l4oj5cWPCoXW>M0onQLYd00onWNJ7oY7JNojAfWP02ojAfWPCoWg6N1?nKKYh3oiQ/WP03
ojV<]onTQ[CoY8Jd00?oY8Jd0onRPk85oj61/0?oXGn_0onQMJ45oj1dXP;oWWFT0_nWNj@4ojAhXPCo
XGJS1?nOMZ@5ojn:[`CoZhN_00?oYhJaokRN__nhW[h00_nhW[h4ok6F^`03ojbB^onl]M?o_;GC00;o
_;GC0ongZld2okgVlPGo_LoX00?o^L;Qok;Nm_nbg_H00_nbg_H2okCBl0;oXn?l00?o0000ojcKn?n/
foP01?nReoX2ojOBmP;oX/_e1?nUbO82ojO7l0?oY<7^1?nU`>dDooooo`03o`000?oooooooooo01ko
oooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooko4gP02oko4gP;o
^<?S1?ne^M`3ok:`e`03ojR]f_nVY=CoYZCD00;oYZCD1?nSWLl3oj2FbPCoW8o60_nJR/401?nAR/So
ShG4ohn5a?n?QL@5oi62`0?oU86l0onIP[T4oin4]PCoXhJd00?oYXNcojbB_?n/T[`00_n/T[`4ojVA
_0?oXXjo00?o[JSBoiZSfonJXm/00_nJXm/3offCiP;o<WkW00?oFf[8od=Nb?m3G/P00om4HL/2oe=`
dPCoOf2U0on5Hj@4ohQVY0;oRfRT0on=_?H3o`000004oi?9n_nIdO_oVM7koi1[Y@?oRFFR0on2GYl3
ogeIW@?oO5NL0omnFYd4ohEOWP?oTVVO1OnML9l4oj5cWPCoXW>M0_nQLYd2ojMiX@CoY7JN1OnOLIh3
oi]^WP04oiQ/W_nYS;OoZHbgojV<]`GoY8Jd0onRPk85oj61/003oj5o[onSMZ7oXgJQ00?oXGFQ1OnP
M:801?nNMJCoYg^TojMkY?nWNj@4ojAhXPGoXGJS0onOMZ@5ojn:[`CoZhN_1OnhW[h4ok6F^`Ko_;GC
00?o]j_=okgVl_nmi_800_nmi_82okg?j0?oXn[j0_nbg_H4ohkVnP;oXn?l00?oV=Wno`000?nHfOh0
0_nReoX2oig;m`GoX/_e0_nUbO82oj?1k`GoY<7^0_nU`>d2ojBnk1Cooooo00?o0000ooooooooool0
7Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`04o`000?oooooooooooko4gPCo
^<?S1?ne^M`01?nb/=OoZ:gJojR]f_nX[MX3ojJTe0GoXig?0onPU/X2oib?aP03oi>?c?nAR/SoTH[8
00;oTH[80on?QL@4oi62`0?oU86l0onIP[T5oin4]P;oXhJd00?oZ96nojbB_?n/T[`00on/T[`4ojVA
_003oj:>_on]Z=;o[JSB00;o[JSB1?nJXm/3offCiP?o<WkW0_l0Gm82odAQb`;oDg3B1?mVPm/3ogZI
i@GoQZc^00GoSKcfo`000?l0003o0000ohflmP02oi?9nPCoT6^U0on9IJ83oh9NW`?oOEVM1?mlEi`2
ogiJW@CoQEnN1?nBJIl4oie`W`CoXG>N1?nRLid00onQLYgoYgVQojMiX@02ojMiX@?oY7JN1OnOLIh3
oi]^WPGoZHbg1?nTQ[@4oj:3/P?oXH6`1?nSMZ43oj5eX@GoX7BR1OnWNj@3ojAhXPGoXGJS0_nOMZ@2
okB@/PGo[hZ_0_n[Qjl2ol>ab0Go^9jn0_naU[/2olC9gPCo_;GC00?oWO?ZokgVl_nmi_800_nmi_83
ogCRiP;oXn[j0omUfNP2ohkVnP?oRMOo0_nHfOh00ol0003oV<Shoig;m`04oig;m`;oX/_e0_nQ`>l5
oj?1k`;oY<7^0_nS_N/5ojBnk1?ooooo0_l0000Nooooo`006oooool01Ol@413ooooooooooooooooo
410@00Kooooo0_l00002ooooo`Go^<?S0_ne^M`00on[]^7oZ:gJojR]fP02ojR]fPCoYZCD0_nSWLl2
oiVLe@?oUiK@1?nCSl`3oi6:b0?oShG41?nAP/03oiB1_0CoVH:i1?nOQ;H01?nSQ[CoZ96nojRA__nX
TKh5ojbB_0;oZI6l00?o]Z_>ojfXd_n]Z=800on]Z=83oiZSf`CoV]gm0om3^_801?lbO^Oo05oBo`1O
d_l0GL03oe=`dPCoIX?K0omjVND2ohJ/kP?o00000_n=_?H01?nCL:SoTVjWoi9^YonBKZL4oi1[Y@?o
RFFR0on2GYl3ogeIW@CoO5NL0omnFYd4ohEOWP?oTVVO1?nML9l4oj5cWP?oXW>M00?oZ7fUojMiXOnW
NJ400onWNJ43ojAfWPGoWg6N0_nKKYh00on`UK_oZHbgojV<]`03ojV<]`GoY8Jd0onRPk800onQPK3o
YGRQoj=fX@04oj=fX@CoXGFQ0onPM:800on/PZOoYg^TojMkY003ojMkY0?oY7RR1OnQMZ<01?nOMZCo
]92bokB@/_ndT;85ojn:[`04oj^7[oo3/LSo`k78ol>ab0Go^9jn00?o/IJkolC9g_o4bMh00_o4bMh0
0onl]M?oWO?ZoigcjP02oigcjP05okgVl_mdh^KoM>;VogCRi_la^LP01?mcaol3og_Ao`;oRMOo0onD
`OH2oiS8n004o`000?nHb?SoWL_goig;m`?oWkg^1?nQ`>l2oj?1k`?oXk_Z1?nS_N/2ojBnk0;oY;g[
4_ooool00ol0003oooooo`00000Nooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool2okS3h`;o[<7Y1?n[]^44ojR]fP;oYZCD00?oVj?JoiVLeOnIW=D0
0onIW=D3oiNFd0?oTho<0onAR/P3ohn5a0GoTH;00onDPK`3oiV2^@;oWhBf0_nRT<84ojRA_PGo[9:l
00CoZI6lokJ[c_nfZlko]Z_>1On]Z=800onJXm_oV]gmoi[Mo@02oi[Mo@03oj:8^OnJN:coV7FZ00;o
V7FZ0onELZT01?l0GL3oDg3Boe=`d_mCL=83ofJ3f`?oNYWU0_l000000on6[>koTW2Yoi9`Z@04oi=`
Z0?oTVjW0on@JjD3ohUUXP?oPUjO1?mmFId3ogaGW0?oOUZM1?n5Gih3oi9YW`CoWG2O1?nQLih2oj9c
W@;oZ7fU1OnWNJ43ojAfWPGoWg6N00CoVfjNok2E^on`UK_o/9Fk1?nYS;L5ojB6]0;oXX>b1?nUN:44
oj=fX@CoXGFQ0_nPM:82ojb2Y`GoYg^T1?nTN:83oj5fX`03okZK^?ndT;;o]92b00;o]92b1?n_RZl0
0ooAemgo`k78ol>ab002ol>ab0Co^9jn0_o3jO03olC9gP?o00000_nMlnX00on7ZncoNkckog^ln`03
og^ln`;oLlOo0_nEZ^D4oiBhl0GoU<7f0_nHb?P00ol0003oW[W[oinmkP04oinmkP;oXL3_0_nR^>P5
oj>kjP;oXkg[00?oY;_YojBmjonT_N/00onT_N/Dooooo`03o`000?oooooooooo01_ooooo000Koooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`Co[<7Y1?n[]^42
ojR]fP;oWJ_Q0onKXmX4oiVLe@?oUiK@0onCSl`4oi6:b0?oShG41?nAP/03oiB1_0;oVH:i00?oV8k7
oj:@`_nRT<800onRT<83ojRA_PCo[9:l00?o]jg?okJ[c_nfZlh00onfZlh2ojfXdPCo^NCd00?oV]gm
oiel[_nJN:`00_nJN:`4oiQeZP?oUG:Y1?nCLJT2oi9`Z@?o000000?oTG2Yoi9`ZOnBL:T00_nBL:T4
oi=`Z0?oTVjW0on@JjD4ohUUXP;oPUjO1?mmFId3ogaGW0?oOUZM1?n5Gih3oi9YW`CoWG2O1?nQLih0
1?nRLigoZ7fUojQmYOnXOJD5ojMiX@CoY7JN0onOLIh00onlYL;o/9Fkok2E^`02ok2E^`GoZHbg0onT
Q[@2oi=TV003ojUlXonUN:7oYGRQ00;oYGRQ1?nSMZ44oj5eX@03oj1dX_n/PZOo[8:W00;o[8:W1?nW
Nj@4ojAhXP;oXGJS0onjVkP4okB@/P;o[hZ_0ooAemd4ol>ab003okRN__o3jO3o`nW`00?o`nW`00?o
a<WNoiFLf?nEW=P00_nEW=P4ohN[k0;oNkck0_nJW]L5oiFZi@CoU;S`0_nD`OH2oifbiP;oW[W[00?o
0000oijijonN^N/00_nO_Nh2oj:di@GoX[SX0_nS^nX2ojBij0CoY;_Y0onT_N/00onV_N[ooooooooo
o`0Cooooo`03o`000?oooooooooo01[ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`05ooooo`Co[<7Y0_n[]^400onM/nOoWJ_Qoif[h@03oif[h@?oVj?J1?nI
W=D3oiNFd0?oTho<0onAR/P2ohn5a003ohB?e_n8SM;oR8gB00;oR8gB0on?SLd4oiR>a`CoXY321?nX
TKh00on/T[co]jg?okN]c`02okN]c`Co]Z_>0oo2jo42okWTm0?oWGb^1?nJN:`3oiQeZPCoUG:Y0_nC
LJT3o`000003oi9`ZOnAL:WoTG2Y00;oTG2Y0onBL:T4oi=`Z0?oTVjW0on@JjD4ohUUXP?oPUjO0omm
FId3ogaGW0?oOUZM1?n5Gih3oi9YW`GoWG2O0onQLih5ojQmY@CoYgVQ1?nTMYh2oimaWP?o_:G20on`
UK/5ojV<]`04ojB6]?nBHYKoTfBHoi=TV0;oZGbS1?nUN:45oj=fX@?oXGFQ1On/PZL4ojMkY0CoY7RR
00?oXGJSokZK^?njVkP00_njVkP4okB@/P03ojn:[ooAemgodMOM00;odMOM0oo3/LP3ogKQa`;o`nW`
0onOTLD5oiFLf0;oQj_/00?oWiG9oiZNeonJW]L00onJW]L4oiFZi@;oU;S`0onPZml4oifbiP;oW[W[
00?o0000oj>_hOnR]>D01?nR]>D3oj:hj003ojFgiOnT^NSoY;WX00?oY;WX1?nT^nT01?nT_N_oY[gZ
ojJmj_nV_NXDooooo`03o`000?oooooooooo01[ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`0000Oooooo0_n/`NT2oifmk`?oWK?W1OnMZn43oi^SfP;oVIcE00CoSZ;QohbMg_n<
WMkoS9gN0on8V=`3ohJCf@CoQ8oF1?n8SM83ohn=c@?oV8k71?nRT<83ojRA_P03ok2_e_ng[Loo]jg?
00?o]jg?0onfZlh3ol;[l@03ojfD_?nQP[;oWGb^00?oWGb^1?nJN:`3oiQeZP?oUG:Y0ol000000onC
LJWoTW2Yoi9`Z@02oi9`Z@?oTG2Y0onBL:T2oi=`Z0;oSFBN0on:HYh3ohMPW@?oPE^M00CoRFFRoh9N
Won2GYooPUjO0ommFId3ogaGW0?oOUZM1?n5Gih3oi9YW`GoWG2O0_nQLih00onYPZ[oZ7fUojQmY@03
ojQmY@CoYgVQ1?nTMYh00onOLIko_:G2okbU`P02okbU`PCo/9Fk0onYS;L3oi9RUP03oi=TV?nYO:?o
ZGbS00;oZGbS0onUN:45oj=fX@;oXGFQ00?o/Xf_ojb2Yon/PZL00on/PZL5ojMkY0?oY7RR1OnjVkP4
okB@/P03oiga`?oAemgodMOM00?odMOM00?o`k78oiIm]_nWS;T01?nWS;T4oinAa@;oUIcH0_nUT;l4
oinEb@GoVYkG0_nEZ^D2oj>TePGoX:_O0_nM/^H01_nTZm_oXjoQoj>_hOnS[n7o0000oj>_h@CoX[CU
00?oX[SXojFgiOnU]nD00_nU]nD4ojBij0;oY;_Y0_nV^nP5ojJmjQCooooo00?o0000ooooooooool0
6Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Oooooo
1?nM_Nl3oifci`;oWJ_Q0_n?[>T3ohnVi@CoSZ;Q0on<WMh3ohRHg0?oQY?I1?n4SmH3ohR=dP?oShg=
0onHS/L5oj:@`P04ojRA__n`[mKo/:oFok2_ePGo]jg?00Go]Z_>ol;[lOo2jo7o/Y_0ojfD_002oj62
/PCoWGb^1?nJN:`3oiQeZP?o000000CoUG:Yoi=aZOnCLJWoTg6Y1?nBL:T2oi5`Z@04ohiVWon>IIko
SVFNohiUWPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid3ogeIW@?oO5NL0omnFYd4ohEOWP?oTVVO1OnM
L9l01?nQLikoZH:ZojV2Z_nYPZX4ojQmY@GoYgVQ0onTMYh5okbU`PCo/9Fk00?oZHbgoi9QU?nBHI@0
0onBHYH5ojUlX`?oYGRQ1OnSMZ401?nQMJ7o/Xf_ok:=[onbSJl4ojb2Y`GoYg^T0_nTN:82olB_aPGo
^Y^h0_ndT;83oiga`0;odMOM00?oWW^/oiIm]_nFOKH00_n_SK84ojN<^@?oWi7500?o[96iojF@_onU
T;l00_nUT;l5oinEb@;oVYkG0_nXWlh5oj>TeP;oX:_O0_nWYmH4ojB[f`?oXjoQ00?o0000oj:diOnR
]>D00onV]>84ojFgi@;oY;WX0onW^NH4ojJkj0;oY[gZ0_nX_nXDooooo`03o`000?oooooooooo01Wo
oooo000Uooooo`03o`000?oooooooooo00Sooooo0_nM_Nl2oh^gl`CoS[7^0on?[>T3ohnVi@?oSZ;Q
1?n<WMh3ohRHg0?oQY?I0on4SmH3ohR=dP?oShg=1?nHS/L2oj:@`P;oYK3O1?n`[mH4okN]c`;o_?;b
0_nbVl000onTR;KoXH:boj62/P02oj62/PCoWGb^0onJN:`3o`0000CoUG:Y0onCLJT2oi9`Z@;oSfNP
0on>IYl3ohiUWPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid2ogUGWP03ogeIWOmlEicoO5NL00;oO5NL
0_mnFYd4ohEOWPCoTVVO0onML9l00onUQ;3oZH:ZojV2ZP02ojV2ZPCoZ7fU1OnWNJ42ojAfWP;oc;g<
1OnlYL82ok2E^`CoTV6D0onBHYH5ojUlX`?oYGRQ1OnSMZ44ok:=[`Co[8:W1OnWNj@01?nTN:;oa:o6
olB_a_o4[lH5okZK^003okB@/_nVOJKoYWfV00GoWW^/00CoUWffojn=/_n_SK;o[hfb1OnWS;T01?nO
TLGo[96iojbA^On/TKT4ojF@_`?oWiG900?o[Yk7ojROc_nXWlh00onXWlh3oj>TeP03ojbUdOnWYmKo
YjOF00?oYjOF1?nTZm/2oj>_h@03o`000?nX/]ooY[CR00CoY[CR0_nU]nD2ojRhi@GoYkWV0_nV^nP2
ojRnj@CoZ;oZ4_ooool00ol0003oooooo`00000Jooooo`009Oooool00ol0003oooooooooo`0:oooo
o`?oRkOc1?n>/Nh3ohn/j@?oSjKU0on>X^42ohbMgP;oOj[_0omhYo03og:Vl@;oJJ?b00CoQ8oFohR=
d_n8SM;oR8gB0on?SLd2oiR>a`;oT:gZ1?nU/=l4ok2_eP05okN]conll_;o_?;bokcbl_nWSk`01?nT
R;H3oj62/PCoWGb^0ol00004oiQeZP?oUG:Y0_nCLJT00on@JJ7oSfNPohmWX002ohmWX0?oSVJO0on>
IIh4oheTWPCoRV:N0on7H9d3oh5KW@?oNUNM0omiEih4ogaGW0?oOUZM1?n5Gih3oi9YW`;oWG2O0_nU
Q;04ojV2ZPCoZ7fU1OnWNJ401?nTMYkoc;g<olbmc?o<_L`4okbU`P?oU6:C1?nBHI@2oi9RUP03ojb1
YOnYO:?oZGbS00?oZGbS1?nUN:43oj=fX@03ol2X`OnbSJoo/Xf_00;o/Xf_1On/PZL3ojMkY003oloK
h_o4[lKoa:o600;oa:o61?njVkP01?n_Q:KoYWfVojImY_nVOJH5oiik[0Co[hfb1?nWS;T00ondU[So
[96iojbA^@02ojbA^@CoYI2o00?oWiG9ojjNaon^W/L00_n^W/L4ojROcP03oj>Te_n/YM7o[:GA00;o
[:GA1?nWYmH2ojB[f`;oZk3L0onX/]l01?l0003oZ;;OojJdh_nV]>82ojVgh`GoZ;SU0_nW^NH2ojVm
j0GoZ;kY0_nX_nX2ojW0jQCooooo00?o0000ooooooooool05oooool002Gooooo0_l0000<ooooo`?o
RkOc0_n>/Nh01?mo/??oPJkaoh6^lOn1[_44oh:]l0?oPZ__1?moZ^l3ogRWl0?oLZKa0omYXo83ofjT
lP?oNZS`1?n@[NX4ojF`g`;o/:oF0_nAkNl00onj[<_o]j?5ojN?_002ojN?_0?oY8Rf0onQP[82oiel
[P;o00001?nJN:`3oiQeZP;oUG:Y00CoTV^Soi1YXOn@JJ7oT6VQ1?n?Ij04ohiVW`?oSVFN0on=I9h4
ohYRWP?oQf2M0on1Fid3ogYGW@?oNENN0omkFj401?mlEicoOUZMogiJWOmnFYd4ohEOWP?oTVVO00?o
WG2OojF4/?nUQ;000_nUQ;03ojV2ZPGoZ7fU0onWNJ400ooCj>Goc;g<olbmc003olbmc003okbU`_nF
HY;oU6:C00?oU6:C1?nBHI@01?nBHYKo[86Uojb1YOn/PJD4ojUlX`CoYGRQ0_nSMZ43ol2X`@?o/Xf_
1On/PZL2ojMkY0;ocm_R1Oo4[lH01?njVkSo[hBVojn4Y_n_Q:H3ojImYPCoWW^/00?o]Y6aojn=/_n_
SK800on_SK82ojN<^@?o]9Jh0on/TKT3ojF@_`03okBPa?n^W/Oo[Yk700?o[Yk70onXWlh00onaYloo
[:GAojbUd@03ojbUd@?oYjOF00?o[[7Joj^`g?n[/=`00on[/=`3ojRbg`03o`000?nY]n?oZKOS00?o
ZKOS0_nX^>D2ojZmi`GoZKgX0_nX_^T2oj[0jPGoZL3Z4oooool00ol0003oooooooooo`0Gooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`?oO;7f0omo/?<3oh6^l@CoPZg`0on2Znl4ognZk`?oN:O`
0ombY_43ofVSlP?oKZCb0omjZ?04oi2]jP;oYK3O0_m>c=<3okZ/b`03oj^G`_nWSkcoYhnl00;oYhnl
0onTR;H2oj62/P?o00000_nMO:h4oiYh[0;oV7FZ00CoTfjUoi9[XonBJj?oTV^S0on@JJ44ohmWX0Co
SVJO0on>IIh3oheTWPCoRV:N0on7H9d3oh5KW@CoNUNM0_miEih4og]KX@?oP6:V1?n5Gih2oi9YW`03
oiUl/_nUQ;3oYHB`00?oYHB`0onYPZX5ojQmY@;oYgVQ0ooCj>D3olbmc0?oUV:B1?nDHY<4oi9QU0Co
[86U1?nYO:<4ojEhX@03oj=fXOo0Z<7o`:S100;o`:S10onbSJl5ojb2Y`03ojMkY?o?fn;ocm_R00;o
cm_R0oo4[lH00on[PJOo[hBVojn4YP02ojn4YPCoYWfV0_nNNj`3okJA/@Co[hfb00?oYhbiokBF^?nd
U[P00_ndU[P4ojbA^@04ojF@_ondX<Co]:34okBPa0Go[Yk700CoZ9o>ok6WconaYloo/JO?1On/YM40
1?nWYmKo[[7Jojjaf_n^/MX4oj^`g005ojRbgon/]n7o[;OQojbghOl000000onY]n<00on/_^OoZ[gW
ojZmi`03ojZmi`;oZKgX0onZ`NX4oj[0jP;oZL3Z0_nY`N/Dooooo`03o`000?oooooooooo01Kooooo
000Tooooo`03o`000?oooooooooo00kooooo0oml/OH3ogn`l`?oPJka0_n2[O03ogFhn`CoLkgm0omX
_oh3oe>lnP;o<K7Z00?oClg?ohO[honfkoD00_nfkoD00onim?;oa]gYolKMj@02olKMj@03okfkeonl
/m7o_;?A00?o_;?A00Co^Zc;oj^G`_n[Ul;oZiO21?nWSk`2ojB8]P?o00000_nQP[83oiel[P;oVWR/
0_nDLJP3oi=^Y@?oTV^S1?n@JJ43ohmWX0CoSVJO0on>IIh4oheTWP?oRV:N0on7H9d3oh5KW@CoNUNM
0_miEih4og]KX@?oP6:V1?n:KJd3oiUl/PGoYHB`1?nYPZX4ojQmY@03ojMiXOoCj>GodnSU00?odnSU
00?oc;g<oiAPTOnFHY800_nFHY84oiART`?oTV6D00?o/HRYojb1YOn/PJD00_n/PJD5ojUlX`?oYGRQ
1Oo0Z<44ok:=[`?o[8:W0omgg[<3oloKhP04olB_a_n[PJOoZh6Woj^1Y`Co[hBV1?nVOJH00onNNjco
]Y6aokJA/@02okJA/@Co[hfb1OndU[P4ojbA^@Co]:341?n^W/L00onh[/oo/JO?ok6Wc`03ok6Wc`;o
[:GA0_nc]=T5ojjafP;oZk3L0_n_^N43ojbgh@03o`000?n/]n7oZKOS00?o[;kW0onZ_NL00on[`^[o
Z/7Zoj[1jP04oj[1jP;oZ/3Z0_nZ`^/4ojW1jaCooooo00?o0000ooooooooool05Oooool002Cooooo
0ol0000?ooooo`CoMJof0omf/_L4ogJen@?oMKSk0_mc_Od3og7=o`;oH/kh0om/fn`2oi?]lP?o]^oe
1?o3g>`01?o6gNWo_K_Gokfkeonm^mL3okbcd@03ojfNb?n[Ul;oZiO200?oZiO20_nWSk`3o`0000;o
Y8Rf0_nQP[801?nGNK3oUGB/oiEd[?nEM:`4oiAaZ0?oTfjU1?nBJj<3oi1YX@?oSfNP1?n>IYl3ohiU
WPCoSFBN0on:HYh3ohMPW@CoPE^M0omjEid3ogUGWPCoNe^Q0_n0HZH4ohY][@CoVGbb1?nUQ;04ojV2
ZP?oZ7fU0omRd:D2om?Xi@CoU62A0onFHY84oiART`;oTV6D0onaR:T3ojb1Y@GoZGbS0_nUN:42omSf
h@Go`:S10onbSJl01?n/PZOoUVVLoiIYW?nfRZL4ok24Y@CoZh6W0_noUZd3ojn4YPCoYWfV1OnfTK44
ojn=/P03ol6T_?ndU[So]9Jh00?o]9Jh0_n/TKT2okfYaPCo]:3400?o[Yk7okR^conh[/l00_nh[/l3
ok6Wc`03okNkg?nc]=Wo/kCI00?o/kCI0on^/MX00ona_N?o[kWQojnih@03ojnih@;o[;OQ00?o[KoW
o`000?n/_^L01?n/_^L01?nZ_NOoZl;Zoj_2j_n[`^X4oj[1jP03oj[3k?nZ`^_oZ/;[00?oZ/;[0_nY
`N/2ojW2ja;ooooo0_l00009ooooo`Co000000?o410@ooooooooool01oooool002Cooooo00?o0000
ooooooooool04?ooool4ogF_mP?oM[;g0_mf]OT2ogRoo@CoMLKo0_macOl3ogcLn`?oVNWk0ondj?L0
0onfkoGo`mc/ol?Lk002ol?Lk0;o_L7L1?nm^mL01?nl/m7o[Ik8ojfNb?n]W/P3oj^G`P?o00000_nW
Sk`2ojB8]P04oiQn]?nGNK3oUgV`oiMi/0?oUGB/1?nDLJP3oi=^Y@CoTV^S0on@JJ44ohmWX0?oSVJO
0on>IIh4oheTWP?oRV:N0on7H9d4oh5KW@?oNUNM0omiEih4og]KX@?oP6:V1?n:KJd3oiUl/PCoYHB`
1?nYPZX01?nXOJGoSEZ@oheJT?n=FY04oi5MT@CoU62A1?nFHY83oiART`03oi9QU?naR:Wo/HRY00;o
/HRY0on/PJD5ojUlX`04ojEhXOoHm^7of?KQomSfh@Go`:S10_nbSJl00onKJi[oUVVLoiIYW003okJ:
Y`Co/8BU0_n[PJL3oknF[@Co[hBV0onVOJH00oo1W[Go]Y6aokJA/@03okJA/@;o[hfb0_o1Y;`5okBF
^004ojbA^OnmZLKo_JW6okfYaP?o]:3400?o_kcFokR^conh[/l00onh[/l00onaYloo]k_LokNkg002
okNkg0Co/kCI00?o[[7Jok6mhona_N<00_na_N<2ojnih@?o[lCY0on]_nL00ol0003o[;kWojbni`02
ojc4j`GoZl;Z00?oZ/7Zoj[3k?nZ`n`00_nZ`n`2oj[2j`;oZL?/1OnY`^/Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool04_ooool3og^amPCoN[Sj0omh_od2
ogG6o`?oPMGo0onJgod00onIjO_o]>SgokCXm`02okCXm`?o_m[]00?o`mc/okg1g?nm`M`00onm`M`2
okfke`03ok2Vc_n]W/So[Ik800;o[Ik80ol000000on[Ul;oYhnlojN?_002oiZ3^@?oV7jd1?nGNK03
oiEd[0?oU76X0onCKZD4oi9[X`?oT6VQ1?n?Ij03ohiVW`?oSVFN1?n=I9h3ohYRWP?oQf2M1?n1Fid3
ogYGW@?oNENN1?mkFj43oh1RYPCoRVf]0onIO;85ojF4/0;oZH:Z0_n9Ei43oheJT0CoTEfA1?nDH944
oiIRTP?oU6:C1OnaR:T4ojb1Y@?oZGbS00?oaif]oj]kWon[Nil00_n[Nil01?nPL9_o`:S1ol2X`OnP
L9/4oi][VP03oiIYW?nfRZOo]XZW00;o]XZW1?n`Q:D00on[PJOo_iJ]oknF[@02oknF[@Co[hBV0_nV
OJH2ol6N]@Go]Y6a00Co[hfbol6T_?o1Y;co`JBl1?ndU[P00oo5^]3o_JW6okfYaP03okfYaP04okBP
a?no_=Ko_kcFoknleP?o^:k?00?o_<WTokNkg?ng^m`01?ng^m`2ok>df@;o]LKW0ona_N<2ojo9k@Go
[lCY0_n]_nL00ol0003o[<O]ojc4j`03ojc4j`;oZl;Z0_nZa>d4oj[3k003ojW4kOnY`ncoZL?/00?o
ZL?/0_nY`^/2ojS1jaCooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`0Cooooo`?oNk7f0_mj^?X3ohO1nPCoQLcn00CoPMGooi[O
oOnJgogoV]om1?n`h?L01?ndj?Oo_m[]okoJkOnof^d3okg4g`?o_L7L00?o/jgCok2Vc_n`Y/h00_n`
Y/h3o`000004ojfNb?n[Ul;oZiO2oib9_PCoVX>i1?nHO[@3oiMi/0?oUGB/0onDLJP4oi=^Y@?oTV^S
0on@JJ44ohmWX0?oSVJO0on>IIh4oheTWPCoRV:N0on7H9d3oh5KW@?oNUNM0omiEih4og]KX@?oP6:V
1?n:KJd4oiUl/PCoYHB`00CoZH:ZohUGTOn9Ei7oRENA0on=FY04oi5MT@CoU62A1?nFHY83oiART`Go
/HRY1?n/PJD2ojUlX`03ok>7Y_o7WJgoaif]00CoZg^O0onPL9/4oi][VPGo]XZW1?n`Q:D5oknF[@Co
[hBV00CoYWfVol6N]Oo1W[Go`Ije1?nfTK400ooBa/oo`JBlol6T_003ol6T_003okBF^?o5^]3oaK[@
00;oaK[@0onmZLH00oo7f^Oo_kcFoknleP03oknleP04okR^conlbNCo_<WTokc9i0Co]k_L00?o]=?`
okG6ionea^L00onea^L00ona_N?o[lW]ojo9k@02ojo9k@;o[lCY0_n[bo43ojc7k@04o`000?n/ango
[<C[ojc4j`;oZ/K^1?nZa>d00onZ`ncoZLC]ojW4k@02ojW4k@;oZL?/0onX`^`4ojS1ja?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`002Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Eooooo`CoRKOd0_n7
`OX3oi_8m`?oVmCl0on^e_D2ok3Pm`Co_=K]00?o_m[]okg4gonma=l00onma=l01Onm`Mco/jgCok>]
donc[M?o/:K>00;o000000Co/:K>ojfNb?n]W/SoWho31?nLRKh3oiZ3^@CoV7jd0onGNK03oiEd[0Co
U76X0onCKZD3oi9[X`?oT6VQ1?n?Ij04ohiVW`?oSVFN0on=I9h4ohYRWP?oQf2M0on1Fid3ogYGW@?o
NENN1?mkFj43oh1RYPGoRVf]0onIO;82ojF4/0;oQEJA1?n9Ei43oheJT0CoTEfA1?nDH944oiIRTP;o
U6:C0_o0V:l4ok68Z@Co[86U00?oZGbSok>7Y_o7WJd00_o7WJd4oj]kW`CoX72K0onKJiX5okJ:Y`Co
/8BU1OnoUZd4ojn4YPGo`Ije0_nfTK43om;6c`Co`JBl1Oo5^]000onmZLKoam[WolOJi`02olOJi`?o
_kcF0_nfg?<4okc9i003okNkg?nddo3o]=?`00;o]=?`0_nea^L2ojcAl`Co[lW]00?oYloeoj_;lOn[
bo400on[bo42ojc7k@03ojS8l?l0003oZ/K^00CoZ/K^0_nZa>d3ojS5kP;oZLC]0_nX`nd5ojS2k0;o
Z<7[0_nX`N`Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000Wooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0000Fooooo`;o
RKOd0onK_Nl4oi_8m`04oi_Do?n^e_Go[]KeojkFm@?o^M3[0onle^d2okg6h@Co_LCO00?o][?Gok>]
donc[M<00ol00002ok2VcP03oj>FaonOSl?oWho300;oWho30onLRKh4oiZ3^@?oV7jd0onGNK03oiEd
[0CoU76X0onCKZD4oi9[X`?oT6VQ0on?Ij04ohiVW`?oSVFN0on=I9h4ohYRWP?oQf2M0on1Fid4ogYG
W@;oNENN1OmkFj43oh1RYPCoRVf]0_nIO;82ohAETP?oQEJA1?n9Ei43oheJT0CoTEfA1?nDH944oiIR
TP04oiARToo0V:oo`9R_ol2H[`Go/HRY0on/PJD00ondQZ?o/hNVolNM[@02olNM[@CoZg^O1?nPL9/2
oi][VP;o_9F_1?nfRZL3ok24Y@;og<C21OnoUZd2ojn4YP;ocKW71?o1W[D00onfTK7od/K?om;6c`02
om;6c`?o`JBl0_o;h^T3olFjd0;oWoC[1?o7f^L00ono_=Ko]]ccokKLl`03okKLl`;o_<WT0onXh_X2
okCCl0;oX]Sk1?n/dO<00on_bNgoYloeojO?m@02ojO?m@;oZl_a0onVbo<3ojS8l003o`000?nZa^ko
Z/K^00;oYlK_1?nXaNh00onW`nkoZ<?]ojS3k@03ojS3k@;oZ<;/0_nW`N`5ojS1k17ooooo0ol00007
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Sooooo1?nK_Nl2oi_8m`?o[<_`00?o[]Ke
okW@jonid>/00onid>/00onle^go_LKQokg6h@02okg6h@03okg4gonf/mOo][?G00?o00000onc[M<0
1?n`Y/koXiK7oj>FaonSU/L3oin?``?oW8Vn1?nJPkT3oiQn]0?oUgV`0onEM:`4oiAaZ0?oTfjU1?nB
Jj<3oi1YX@?oSfNP1?n>IYl3ohiUWP;oSFBN00?oSWNdohag]on<MkL00_n<MkL3ohIg^`?oNGK31?mj
Eid3ogUGWPCoNe^Q0on0HZH2ohY][@?oQeVD0on4EI83ohEFT@CoRENA0on=FY04oi5MT@CoU62A1?nF
HY801?nDHY?o`9R_ol2H[oo0V:l5ok68Z@;o[86U0_ndQZ<4olNM[@CoZg^O1?nPL9/01?nKJi[o_9F_
okbE[onlUJl5okJ:Y`04ok24YOoLa<;og<C2omc4`PGo_iJ]00Co[hBVolfiaoo=^LOocKW71?o1W[D0
0onXm;kod/K?om;6c`03om;6c`03ol6T_?o;h^Wobn;Y00;obn;Y00?oaK[@oiodjonOm>/00_nOm>/2
olOJi`?oRnOg0_nfg?<3oggPm`;oZ>;j0_n;fOl5oj;Hn`;o[=7c0onPdoX2ojO?m@;oXL_f1OnVbo<2
ojS8l003o`000?nVao7oYlK_00?oYlK_00?oZ<G^ojO3k_nW`nh00_nW`nh2ojS3k@OoYl7/0_nX`N`2
ojO0j`kooooo1?l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Wooooo0_nK_Nl2oj_1jP?o[<_`0ongbNP3okW@j`;o_<KR0onma^401?nh^M[o0000o`000?l0
0003okJce`;o/jgC00?oZ9g<oj>FaonSU/L00_nSU/L3oin?``CoW8Vn0onJPkT4oiQn]0?oUgV`0onE
M:`3oiAaZ0?oTfjU1?nBJj<3oi1YX@;oSfNP00?oSgB`oi1e/On@MK400_n@MK43oi1f/P?oSWNd1?n<
MkL4ohIg^`;oNGK30omSM]401?mjEigoNENNogUGW_miEih4og]KX@;oP6:V0on;GIH3ohMIU0?oQ5FB
1?n5EY43ohUGT@CoSEZ@0onAGI44oiAPT@CoUV:B1?o0V:l5ok68Z@05ojb1YOndQZ?o]8JSokB6Xonj
ffh00oo7WJd4oj]kW`CoX72K00CoVf^JokbE[onlUJoo_9F_1OnfRZL01?n`Q:Gog<C2omc4`_oLa<84
oknF[@03okSkiOo=^LOocKW700;ocKW70oo1W[D3ojSd_P;od/K?0omAbkH2ol_Rj@03ofFLkonMW=?o
WIcC00CoPJCZ0_mV/o/01?l0T/7o;KGBobfed_l]]M82oggPm`CoKLom0on;fOl2oj;Hn`?oTm?m0_nP
doX2oi_:n0GoXL_f0_nVbo<2oj?7lP?oY/Oa00Co0000ojK7lOnWa^ooYlK_0_nV`nh3ojO3kP;oY/7]
1_nW`N`7ojO0j`[ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l00000
2oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool2o`0001_ooooo1?n[`NX00on/bo3o]lWXokO9j003okO9j003okW@jonla^;o_<KR00;o
_<KR0ol00003okRifP;o][?G00?o[:G@ojRMc?nXWL`00_nXWL`3oj>Fa`CoWho30onLRKh3oiZ3^@Co
V7jd0onGNK03oiEd[0?oU76X0_nCKZD00on<M;;oSG>aohec/@02ohec/@?oSW>`0on?M;04oi1e/@?o
T7Jb1?n>Mk@3ohag]`CoQWNk0omiM/<3of=fd@?oI9?Y0_mkFj42oeo6o0;oSEnH0on;GIH3ohMIU0?o
Q5FB1?n5EY43ohUGT@CoSEZ@0onAGI44oiAPT@CoUV:B1?o0V:l4ok68Z@Co]8JS0_njffh3olNM[@Go
Zg^O0onPL9/4okbE[`Go]XZW00?o0000omc4`_oLa<800_oLa<82oknF[@?o^?_U1?o=^LL00oo1W[Go
YHjmokND/`04ojJ=^`?oTHo>00?o[i_2oifLdonMW=<00onMW=<4oh6TjP?oI[?k0_mE_?/2ohBbl`Go
Ol;l1?n4c?l2oi?Co@;oU/Kh1?nKb_P2oj7;mP;oX<Gc1OnSao82ojK7l@03ojG3kol0003oY/?^00Co
Y/?^00?oYl?^ojK1kOnV`Nd00_nV`Nd2ojO1k0;oYko[1_nW`>/2ojNoj`Kooooo1?l00008ooooo`03
o`000?oooooooooo017ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool06oooool2oj_1jP?o]L?T0_ngbNP4ok_5
h@?o000000?o^[gLokRif_nh^MX00_nh^MX00on`[=Co[:G@ojbUd002ojbUd0?oZ9g<1?nSU/L3oin?
``;oW8Vn00CoTHC2ohj0_on>P;ooSX2o1?n<O;`3oh]i^@?oRWJg0on;M;@3ohad/PCoSG>a0on>Lk04
ohmd/0?oT7Fa1?n@M[83ohig]0CoS7Ng0on6Mk/3ogUf``CoHgKA1?mTTnT01?mOa_coN5ZSogQJXon=
GiP3oh]MUP?oQeVD0on4EI84ohEFT@?oRENA1?n=FY03oi5MT@CoU62A0onFHY82omFb]PCo`9R_0_na
R:T2ok:3XP;o]8JS00?oCDNYokR>Z_njffh00oo7WJd5oj]kW`;oX72K0_o6/<@3okbE[`Co]XZW00?o
/hRXoj>5]?l000000ooLa<800onoUZgo^?_UokSki@02okSki@;ocKW70onUS[d2okND/`GoYXfk00Co
THo>ojnK`_n_Vl;o[i_21?nMW=<2oh6TjP;oX9gB1OnCYn<3ohBbl`;oOl;l0onE]Nh4oi6mm@CoU/Kh
0_nKb_P2oig1lPCoX<Gc0_nSao82oj?1k`?oYL?_00Co0000ojG3konV`nkoY/?^0onV`>d2ojK1k@;o
Y[o[1OnW_n/2ojO0j`KoYko[0_ooool3o`0000cooooo00?o0000ooooooooool04Oooool002;ooooo
00?o0000ooooooooool07Oooool3okG3i0?o^lCQ00Co^lGQo`000?l0003o00001Onj_M`00onh^M[o
/:cDok2/e002ok2/e0?o[:G@1?nXWL`2oj>Fa`04oiV@bOnER/GoUH[5oiF:a@CoTHC20on>P;l3ohal
_0CoRgVi0_n:M[L3oh]d]0CoS7Bb0on=Lk44ohic/0?oSgB`1?n@MK43oi1f/P?oSWNd1?n<MkL4ohIg
^`?oNGK31?mSM]42ofBCj@;oNUZR0omhFZ<3oh]MUP?oQeVD0on4EI84ohEFT@?oRENA1?n=FY03oi5M
T@CoU62A0_nFHY83omFb]PCo`9R_00Co/HRYok:3X_nbPj;o/X>R0_ndQZ<4okR>ZP?oaif]1?n[Nil0
1?nPL9_oa[34olJ`a?o6/<@4okbE[`;o]XZW0_ncR:P4ok>7YPCoYGjY00?o`YZ^ok>@/OncT;400_nc
T;400onUS[go]iBcokND/`02okND/`?oYXfk00?o^ijlojnK`_n_Vl800on_Vl82oifLd`03ojjMaonP
WM;oX9gB00?oX9gB0onCYn<00onUYmOoVjcSoi^/h`02oi^/h`GoUKG^0_nA_OD2oibdj@CoW;c_1?nM
`O82oj35l`;oX[o^1?nS`Nl2ojG3k`03ojFok?l0003oY/3]00?oY/3]00?oY[k[ojJojonV_n/00onV
_n/2ojNoj`;oYkkZ2OnW_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo000R
ooooo`03o`000?oooooooooo01kooooo00Co]L?Tok_4hOnka>7o^lCQ0_l000001?nkaN7o^l3Nok_0
g_nk`=h3okZmg003okBcf?n`[=Co/:cD00?o/:cD1?n/YM02ojRMc003oijGcOnIT<WoVI3900;oVI39
0onER/D3oi64`P?oSX2o0on<O;`4oh]i^@?oRWJg0on;M;@3ohad/P?oSG>a1?n>Lk03ohmd/0CoT7Fa
0on@M[84ohig]0?oS7Ng1?n6Mk/2ogUf``?oPEjQ0omnG:43ogYJXP?oN5ZS0_meFjL01?n;GIKoQeVD
ohMIU?n7FI@3ohAETPCoQEJA0on9Ei44oheJT0CoTEfA0onDH942oiIRTP?oeK:f1?o0V:l4ok:3XP03
okB6XomjEY_o^8jZ00Co^8jZ00?o]XNSolNM[On[Nil00_n[Nil00onHjO[oa[34olJ`a002olJ`a0Co
_9F_00Co]XZWok>8Z?ncR:So/hRX1?ncQjH3ojEnZ@;o`YZ^1?ncT;45okND/`;oYXfk0onkW[`4ojnK
`PCo[Yg71?nPWM800onCYn?oYJOGojFWe`02ojFWe`CoVjcS0_nE]Nh2oj6^h@GoW;CY0_nL_>l00onR
]nOoXK_[oj6kj`02oj6kj`GoX[o^0_nS`Nl2ojBmj`?oYKo/00?o0000ojK0kOnV_^/00onV_^/3ojJo
j`KoYkkZ0_nW_n/2ojNojPGoYko[4?ooool00ol0003oooooooooo`0@ooooo`008_ooool2o`00023o
oooo0ol000000onka>7o_<CPokc4h004ok_0gP04okZmg?nd/mSo];?HokBcf0Go/:cD0_n/YM000onS
Wm7oWYO=oijGc@02oijGc@?oVI390onER/D3oi64`P?oSX2o1?n<O;`3oh]i^@?oRWJg0on;M;@3ohad
/PCoSG>a0on>Lk03ohmd/0CoT7Fa1?n@M[83ohig]0;oS7Ng00CoRfZXohITY?n6I:CoQVBT0on3HJ83
oh5NX@?oOUbQ0omjFZ83ogQJX`?oME^W0on7FI@4ohAETP?oQEJA0on9Ei44oheJT0CoTEfA0onDH940
0onFHY;oeK:fomFb]P03omFb]P;o`9R_00?oZgbQok:3X_nbPj800_nbPj800omjEY_o/hRXok>8Z004
okR>ZP;o]XNS00CoZg^OoiSYn_nHjO[oV>Wj1Oo6/<@2okbE[`Co/hRX00?obIj/ok>7Y_ncQjH00onc
QjH01?nUOZWo`YZ^ol:J[_o2VZh4ok>@/@03olFR]OngU;?o]iBc00;o]iBc00?oYXfkok^N_?nkW[`0
0_nkW[`3ojnK`P;o_JK21?n^WLL2oj2MdP03ok2Vc_nUYmOoYJOG00CoYJOG0_nK[><2ojN[f@CoXJkQ
0_nL]>T2ojBbhPCoX[OW1?nQ^n/2oj:okP;oY;[Y1OnT_N/2ojFok003ojJmjOl0003oY[k[00CoY[k[
00?oY[o[ojNnj_nW_^X01_nW_^X4ojNojP;oYko[0_nX_n/@ooooo`03o`000?oooooooooo013ooooo
000Rooooo`03o`000?oooooooooo01cooooo0ol000000ooooooo^lCQokc4h004okc4h0;o^l3N0_ng
^md4okBcf0;o/:cD0_nXYmD4oj>Od@?oWYO=0onIT<T3oiF:a@CoTHC20on>P;l3ohal_0CoRgVi0_n:
M[L3oh]d]0?oS7Bb1?n=Lk44ohic/0?oSgB`0on@MK44oi1f/P;oSWNd00CoPV2SogmNXomoGZ?oOejS
0on6I:@3oh=QXP?oPEjQ0omnG:43ogYJXPCoN5ZS0_meFjL2of5CZ`03ohMIU?n4EI;oQ5FB00;oQ5FB
0on5EY43ohUGT@CoSEZ@1?nAGI43oiAPT@KoeK:f00?o`9R_oj]lXOn[O:401?nbPj83ok>8Z0?o^8jZ
0_oJ];84okJ7X`03ojIhWonHjO[oa[3400?oa[3400?o_9F_okZ>Z?ncR:P00_ncR:P2olVN[0Go/hNV
00?oYGjYol:J[_o2VZh00_o2VZh2ok>@/@;oaJ:e1?ngU;<6ok^N_004ojnK`_nmY/;o_JK2okfV`P?o
[Yg700?o^Jc<ok2Vc_n`Y/h00_n`Y/h4ojFWe`03ojn[e?nWZmWoYj_I00?oYj_I0_nQ[^400onY/=go
Y;;RojBbhP03ojBbhPCoX[OW0_nQ^n/2ojFgiPCoY;[Y0_nT_N/2ojJkj0?oY[gY00Co0000ojJmjOnV
_^_oY[k[0_nW_NT4ojNnjP03ojRnjOnW_^[oYkkZ00?oYkkZ0_nW_nX2ojRojPCoZ;o[3oooool00ol0
003oooooooooo`0@ooooo`008_ooool00ol0003oooooooooo`0Iooooo`?o00001_ooool3okc4h003
okW3h_ng^mgo]k_M00?o]k_M0_nd/mP2ojb_fPCoZ:OE0onSWm44oijGc@?oVI390onER/D3oi64`P?o
SX2o0on<O;`4oh]i^@?oRWJg0on;M;@3ohad/P?oSG>a1?n>Lk03ohmd/0;oT7Fa0_n9JJL3ohETY0?o
PV2S0omoGZ<2ogaNY@03ohITY?n3HJ;oPf6R00;oPf6R0_n1GZ43ogiLX@CoNUZR0omhFZ<2ogEKY`?o
HE>[1?n4EI83ohEFT@?oRENA1?n=FY04oi5MT@?oU62A00?oiM73omFb]_oE/[H00_oE/[H4oj]lX@?o
/X>R1?ncR:P3okR>ZP;of[Bb1?nfQj<2ojIhW`;oa[341OnjSZP2ok>8Z0?obIj/1?ncQjH5ol:J[P04
ok>@/Oo5X[GoaJ:eolFR]@Co]iBc00?obJfnok^N_?nkW[`00_nkW[`00oo8]LOo_JK2okfV`P03okfV
`P04ojjMaoni[<co^Jc<okV/c0Co/:K>00?oYJOGojn[e?n_Zm@00_n_Zm@3ojN[f@03ojnaf_nY/=go
ZK3M00;oZK3M1?nT/^82oj:gi`;oYkGS1OnU]nH2ojBjj@;oYk[V1?nV^nP2ojJmj@03ojNlj?l0003o
YkgY00CoYkgY00?oYkkZojRnjOnX_^T00_nX_^T3ojNnjP03ojRnjOnX_n[oZ;oZ00?oZ;oZ0_nX_n/0
0onX`>_oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Rooooo`03o`000?oooooooooo
01Kooooo0ol0000:ooooo`04okc4h?ni`n;o^L?RokW3hP?o]k_M00?o[kSPojb_f_n/[mX00on/[mX4
ojRWe@?oXioA0_nNUld01?nFV=?oTI;Aoi6BdOnAT]43ohf>d0?oQhc@0on3Rm<3ogf<e`CoN97O0om`
VNT3oh]d]0?oS7Bb0on=Lk42ohic/0?oUg^b0on@LJ`3ohUYY`?oQFBT0on2H:<3ogmNX`?oO5jU1?n3
HJ83oh5NX@;oOUbQ1?mjFZ83ogQJX`?oME^W0_mQDj/01?lg@k;oQ5FBohAET_n4EI83ohEFT@CoRENA
0on=FY04oi5MT@;oU62A0_oUdL<3omFb]P03oj1dXOn[O:7oZgbQ00?oZgbQ0_nbPj85ok>8Z004okR>
Z_oJ];;of[BbomZd/PGo]XNS0_nVN9l2olNR/`Co^XjX00?o/hRXolVN[?o9WZ`00_o9WZ`4ok>7YP03
oln_^_o2VZko`YZ^00;o`YZ^1Oo5X[D2okND/`;obJfn0onkW[`2olRea`Co_JK200?oa[_@okV/c?ni
[<`00_ni[<`3ok2VcP03okRad_n_ZmCo[j_D00?o[j_D00?oYj_Iojnaf_n_/MX00_n_/MX4ojV`g@;o
Y;;R0_nZ/ml4ojNeh`;oYKOV0_nY^>@5ojNjiP;oY[_X0_nX^nL3ojNlj003o`000?nW_NWoYkgY00;o
Z;gX1OnX_^T00onW_^[oZ;kYojRnj@02ojRnj@CoZ;oZ1?nX`>/>ooooo`03o`000?oooooooooo013o
oooo000Rooooo`;o00005?ooool3o`0000kooooo1?ni`n801?ng^mgo[kSPojnhh?n_^>05ojb_fP;o
Z:OE00CoWZKKoiZNeonJW]OoVYkG1?nFV=<3oi6Bd@?oSHk@0on7S=03oh>;d`?oOHcG1?mhTMl3og2I
j@CoIZOf0_mC]o/01?nXUL;oWhNioin7^OnOQkT3oiMk/PCoT76/0_n9JJL3ohETY0CoPV2S0_moGZ<3
ogaNY@?oNf:Z00CoPf6Roh5NXOn1GZ7oPEjQ0omnG:43ogYJXP?oN5ZS0omeFjL3of5CZ`03ocM3/_n4
EI;oQ5FB00?oQEJA1?n9Ei43oheJT0CoTEfA00?oU62AonGA`ooUdL<00_oUdL<00ooE/[KoX7BQoj1d
X@05oj]lX@03ok:3X_nZPZWoZX:Y00Co/hRX00Co^8jZomZd/_oJ];;of[Bb1OnfQj<01?nVN9ooaj:c
olNR/oo7X[<4okZ>Z0GobIj/0oncQjH2oln_^PCo`YZ^00?ohLk5olFR]Oo5X[D00_o5X[D00ongU;?o
bJfnolV]_P02olV]_P03ok^N_?o8]LOob;G700;ob;G70_nmY/82olJkd0Go^Jc<00Co/:K>okRad_nh
/M;o^;7B0on_Zm@00ond]MWo[k7JojnafP03ojnafP;oZK3M0_n]]=h5ojZcg`;oYkGS0_n[^><4ojVh
i0;oYk[V0_nY^^D5ojRki`;oYkcX00?oZKcXo`000?nX_NP00onX_NP8ojRnj@03ojVoj_nX_n[oZ;oZ
00?oZ;oZ0_nX`>/2ojW0j`gooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000Booooo`?o
00004_ooool2okW3hP;o/L;W1?n_^>02ojb_fP;oXJkP1?nNY]/3oiZNe`?oUYSC0onAT]43ohf>d0?o
Qhc@1?n3Rm<3ogf<e`CoN97O0om`VNT2ofJWmP04ok2Sb_nXUL;oZ9G2ojRE`P?oWhNi0onGNk84oi1a
[0?oRFVW0on5I:@3oh9PX`?oOejS0_mlGZD4og]RZP?oNf^e0omnG:43ogYJXP?oN5ZS0omeFjL3of5C
Z`;o=d>b00CoQ5FBohEFTOn5EY7oQEJA1?n9Ei43oheJT0CoTEfA00?oU62AonGA`ooUdL<00_oUdL<3
oj1dX@GoZgbQ00?o/X>RojZ2ZOnZPZT01?ncR:P4omZd/PGo]XNS00CoYWROolNR/oo7X[?oaj:c1?nj
SZP00ooYglSobIj/olVN[002olVN[0;o/hNV0oo?[kX3ol:J[P;ohLk51?o5X[D5olV]_PGob;G700?o
_JK2olJkd?o6^m000_o6^m03okV/c003oknmf?nh/M;o^;7B00?o^;7B00Co[j_DokBefOnd]MWo];GI
0on_/MX00onb^=ko[KCNojfdgP03ojfdgP;oZ[?O0_n]^>85oj^hh`;oZKST0_n[^^@4ojVji@;oZ;_W
0_nY_>L3ojVlj004o`000?nY_>SoZ;gXojRmj0;oZKgX1OnX_^T4ojVojP;oZ;oZ0_nY`>X5ojW0j`co
oooo00?o0000ooooooooool04?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03oooool2o`0001Ko
oooo1?na`^L2ojnhh0;oY;KV1?nQ[^03oijVf`CoVYkG0onFV=<3oi6Bd@?oSHk@0on7S=02oh>;d`?o
M[Oj1?mS`Od01?lj_>Co]k3CokN`dong/=<3ok2SbPCoZ9G20onOQkT3oiMk/P?oT76/0on9JJL3ohET
Y0?oPV2S0omoGZ<3ogaNY@?oNf:Z0omkJkD3of]ldP?oNUZR1?mhFZ<2ogEKY`?oHE>[0olg@k83ohEF
T@CoRENA0on=FY04oi5MT@05on?`eooUdL?oiM73onGA`onDK:400onPM:45oj]lX@?oZX:Y1?ncR:P0
0onRe6cof[BbomZd/P02omZd/P?o]XNS00?od>3TolNR/oo7X[<00_o7X[<3okZ>Z0;ojMo81?o9WZ`0
0oncQjKocjnjoln_^P03oln_^P04ol:J[_oQc/GohLk5on7>a@?oaJ:e0_oEcm<4olV]_P03omOLg?o8
]LOob;G700;ob;G71Oo6^m000oni[<co_kgHoknmf002oknmf0;o^;7B0_nk`=h5okBef@04ojnaf_nb
^=ko/[SNok:hgP?o[KCN00?o[k_Sojfhh_n]^>800on]^>82oj^hh`;o[;_T1On[^^@2ojVji@;oZ[cV
1?nY_>L2ojVlj003ojVmj?l0003oZKgX00CoZKgX0_nX_^T2ojVoj@?oZKoZ1_nY`>X2ojW0j`;oZL7[
3Oooool00ol0003oooooooooo`0?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool3o`0001Wooooo
0_na`^L3ojFok0?oY;KV1?nQ[^03oijVf`;oVYkG00CoT:WVohfVi_n=Y^KoSJKV1?n9Y^P3ohFXj`Co
Ojkb1?mf]oX2of?1o@03ok^lf_ng/=?o]k3C00;o]k3C1?n`XlX3ojRE`P?oWhNi0onGNk83oi1a[0?o
RFVW0on5I:@3oh9PX`?oOejS0omlGZD3og]RZPCoNf^e1?m[O=800om_FJWoN5ZSogQJX`02ogQJX`?o
ME^W0omQDj/2ocM3/P03o`90`On5EY7oQEJA00CoRENA0on=FY03oi5MT@?oho3G00?oiM73oiA/XOnD
K:400onPM:45oj]lX@?oZX:Y0oncR:P3oj;DK0?of[Bb0_nfQj<3om3Pi0Coaj:c00Co^XjXonWOb?oY
glSojMo81?o9WZ`6oln_^P03ol:J[_oQc/GohLk500;ohLk500CoaJ:eomG?dooEcm?oeLoC0oo9[Kh2
omOLg0?ob;G70_o9en@3olJkd0;o`mSY0ono_MP00onhcnco^l3Nok_0gP03ok_0gP;o];GI0_nd`><5
ok:hgP04ojfdg_n_^n?o[k_Sojnkh`?o[KSR0_n^_ND4ojbki0;oZk[T0_n/_NH5ojZliP;oZKcW0_nZ
_^P3ojVmj003o`000?nY_NSoZKgX00OoZKoY00?oZKoZojW0j_nY`>X01?nY`>X6ojW1j`cooooo00?o
0000ooooooooool03oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Ooo
ool2o`0000[ooooo0ol0000Mooooo`GoYKo/0onT]^H2oj6^h003oiFaj_nC[NSoTjgX00;oTjgX0on@
ZNH3ohfViPCoRJKX0on5Z>/2ogn^lP;o>l3A0_njkO@00onoko;o^kcJok^lfP02ok^lfPCo]k3C0_n`
XlX01?nKRl;oTh6loi>1_?nCPK`3oh]g^0?oPfnd0ommJk<3ohUYY`?oQFBT0on2H:<3ogmNX`?oO5jU
1?mkHZX3og][]@?oJgcB0om_FJT2ofYDY`04oi5ZX_n8GicoR5nLohQOW0?oHE>[0olg@k800ol2@<7o
QEJAohUGT@03ohUGT@?oSEZ@0_nAGI43on?`e`CoU6bQ1?nPM:43oj]lX@GoZX:Y00Co/hRXoiYh[?nJ
N:coUWF/0onPLil00onQMJ7o]XNSom3Pi003om3Pi0Coaj:c00?o^XjXonWOb?oYglP00_oYglP2olVN
[0;oc_oK1?o?[kX00ol0003ohLk5on7>a@02on7>a@03oe?8Y?oEcm?oeLoC00?oeLoC00?obJfnomOL
g?oGg=`00_oGg=`00oo8]LOobMOTolWGi002olWGi003olJkd?o3f>Wo`mSY00;o`mSY00Co_kgHokS?
k?nhcnco^<o/0onk`=h2okC>k@Co]<3S0_nb^=h2ok71iPGo[k_S00?o[KSRojjmiOn^_ND00_n^_ND2
ojbki0;o[;oW1?n/_NH2ojZliP;oZkkX1OnZ_^P2ojVmj003o`000?nZ_nWoZKoY00GoZKoY1_nY`>X0
0onY`N[oZL7[ojW1j`07ojW1j`_ooooo00?o0000ooooooooool03oooool000Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool01_oo
ool3o`00027ooooo0_nU_n`3oiNkl@?oUkK]0onE/NX4oi>]j0?oT:WV0on=Y^H2ohVVj0?oK/cn0_mJ
cO<01?mli]oo^^gdok[]m?njkO@2okc4h0Go^kcJ0_ng/=<00onSU/SoVh_2oi^;`P02oi^;`P?oTh6l
0on;MkP2oh=_]0?oOF^c0omhJ;@3ohETY0CoPV2S0_moGZ<3ogaNY@CoNf:Z1?mkJkD00om[O=;oNFJ`
ogUV/002ofmIZ@?oJUBW0on8Gi`3oh5HV@?oNE>I00?o=d>bo`90`On9Ei400on9Ei43oheJT003oi5M
TOoSl=Ooho3G00;oQfBS1?nDK:44oj1dX@;oZgbQ00?oVGN/ojZ2ZOnZPZT00onZPZT00oncR:SoVWR/
oiE[W`05oj1cW`;oXGFQ0oo@h>@3olNR/`?o]iBc0ooYglP01?o9WZcoc_oKolkofoo>om/3oln_^P04
ojnA^?nmUk3oZY2kon7>a@;oZY2k0_nVW<`2omG?d`03ojJLc?m;Rn_oBh_[00;oemcL0on;jnd2olWG
i0?oTn[g0_o3f>T2oi_Po@Go^<o/00?o^l3NokC>kOndc^d00_ndc^d2okC0h`;o[LW^1?na`NH2ojnk
h`;o[L7X1?n^_ND00on/`^[o[;oWojboi`03ojboi`;o[;gV0_n[`>T4oj^nj0;oZ[kX1OnZ_nT01?l0
003oZ[oYojVojOnY_nT2oj[0jPGoZL3Z1?nY`NX9ojW1j`[ooooo00?o0000ooooooooool03oooool0
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool00oooool3o`0002Kooooo1?nG^o43oiNfk@?oUK7Z0_nC[NP2ohJmn@CoPL7l0omj
a_l2ofk<oP;oI=SW0ondj?L00onjkOCo_<CPokc4h002okc4h0;o^kcJ0_nYXLh3oj>Fb0CoVh_20onC
PK`3oh]g^0?oPfnd0_mmJk<3ogQX]0?oMF^i1?n2H:<3ogmNX`;oO5jU1?mkHZX3og][]@04ogILYomi
I[3oNFJ`ogUV/0;oKeVY0omZE:L2ofaJ[004ohQOW?n1F9WoPERIoh5HV@CoNE>I0_m[CId00ooLk]ko
06;@ohUGT@02oheJT0;oQnGh00?oM5VTohMTXon7I:<00_n7I:<3oiA/X@CoX7BQ00?oZgbQoiUg[?nI
Mj`01?nZPZT01?n8Hj7oUF^OoiE[WonEJil5oj1cW`CoXGFQ00?oWGRYom3Pi?o7X[<00_o7VjX00ong
U;?ob9n]olRO[@02olRO[@03okNC/Oo8Wjgob9n]00;ob9n]00CocjnjojnA^?nmUk3o_IN`1?nZT;/0
1?o1W[GoYYc<ojJLc?nVW<`2ok^T`PCoU:3M1?mCX_H00ol0QmSo=k[PocNjh002ocNjh0?oVn3m0_nh
cn`3oioJo0;o]<k]0_nRd_T5ojg9kP;o/L7V0_n[anh4ojg1j003ojjmiOn/`^[o[<;Z00;o[<;Z0on/
_nL00onZ`^_oZl3Yoj_0j@03oj_0j@;oZkkX0_nZ`>X6ojZoj@03oj[0j_l0003oZ/3Z00CoZ/3Z0_nY
`>X2ojW1j`?oZL7Z2_nY`N/:ooooo`03o`000?oooooooooo00oooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`04o`000?ooooooooooooooo`?o0000
:_ooool2oiNkl@;oSkWc0on<^_@4ohVkmP?oQ[gi0_n1`O`3ogoDo`;oM=Wi0_n6j?83okCXm`;o^lWU
0onla>000on_Zm?oZJ7>ojVQcP02ojVQcPCoXiK80onKRl83oi>1_0?oRgNh0on3Kk@3oge[/`?oN6Rd
0_meJkT3ogAda004oh9PXomoGZ?oOejSogmNX`?oO5jU0omkHZX01OmkJkGoMUbWogILYomfG:OoIe>X
00;oNFJ`0_m_FJT3ofYDY`?oK5Z/0on1F9T4ogUCV@04of]=WOoLk]kog>kNofEN]@;oH5:Z00Co06;@
ohOUn?mdFJCoM5VT1?n7I:<3oiA/X@CoX7BQ1?nIMj`2ojZ2Z@;oR6>Q0onEJil5oj1cW`CoXGFQ00?o
WGRYolNKZ_o7VjX00_o7VjX00ongU;?ob9n]olRO[@02olRO[@03okNC/Oo8Wjgob9n]00;ob9n]00Co
[i6hokfG/?nmUk3o_IN`0onZT;/3ol6N]@03ojJLc?nkY<;o^jC200;o^jC20_nDX=d2ok:_e@CoS;;`
1?m8Y_P00olYXngoFLWfoeW9mP02oeW9mP;oWm[l0_mmd?l4oj;Bn@;o[LW^0_nQcOL5oj_7kP;o[L7X
0_nYaNh4ojc2jP03ojboionZ`^_oZ/;[00;oZ/;[0_n[`>T2oj[2j`GoZ/3Z0_nZ_nT2oj[1j`?oZ/3Z
00?o0000oj[0j_nZ`>X01onY`N/00onY`N[oZL7[ojW1j`0:ojW1j`Wooooo00?o0000ooooooooool0
3oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo
1?l0000^ooooo`CoSkWc0on<^_@2ohVkmP;oRlGk1?n6cOh2ogoDo`?oSn?l0_n`hOP2okW;j0Co^lWU
00Co_<CPojn[don_Zm?o[j_C1?nYXLh3oj>Fb0CoVh_20onCPK`3oh]g^0;oPfnd0ommJk<3ogQX]0?o
MF^i0omdM<@3og>:f`?oO5jU0_mkHZX3oh=Y[@;oMUbW0_mWDjP01?miI[3oKeVYofmIZOm_FJT3ofYD
Y`;oK5Z/0omgK;T2ogUCV@CoXJ7D00?og>kNofEN]OmUG[D00_mPDZX2ogeLXP;oM5VT0on7I:<4oiA/
X@?oX7BQ00KoPVV]oiUg[?nIMjcoVGN/ojZ2ZOn7JJX2ohQSX@CoUF^O1?nPLil4oj5eX@Goai^Z2_o8
Wjd5okfG/003ojZ@^oo1W[Go`Ije00;o`Ije1OnkY<85ok:_e@;oS;;`0_nU^>L4ogNbm`?oCjgi0_m2
[OL4ogg@o`;oX];i0on;coh3oj7=m`;oZlO^0_nRbO@5ojW5kP;o[<;Z0onXa>h2oj[2j`;oZ<?]1?nZ
`^/2oj[0jP;oZL;[1OnZ`N/2oj[0jP03o`000?nY`N_oZL7[01CoZL7[2Oooool00ol0003ooooooooo
o`0?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01?oo
ool2o`00037ooooo0_n?^O<2oi:jlPCoSkog0on;aO/2ohK=oP;oU=[n1?n]fOL00on`hOSo^L_XokW;
j002okW;j0;o^lWU00?o/[?Iojn[don_Zm<00_n_Zm<4ojVQcP;oXiK800?oU8W5ohf1`_n=PL800_n=
PL83ohEk`@?oRgNh0on3Kk@2oge[/`?oN6Rd0omeJkT4ogAda0CoLh[K00?oJ;_moiEm]_nEOKH00on3
JJd3ogILY`;oIe>X0om_FJT3ofYDY`?oK5Z/0_mgK;T6oj6Qe003ofiIZ_mUG[GoIEje00;oH5:Z0_mS
EZd00ommG:;oM5VTohMTX`02ohMTX`CoU6bQ0_nPM:401?mLNmWoV8g6oiUg[?nIMj`3ohMYZP?oR6>Q
0onEJil4oj1cW`CoXGFQ1Oo7VjX00ooXa[Cob9n]olRO[@02olRO[@03omJd^?o8Wjgob9n]00;ob9n]
00?od:VaokfG/?nmUk000_nmUk05ol6N]@03olnZ]?nkY<;o^jC200;o^jC200Gob[;2ok:_eOnb[mGo
/ZoEol:jd`05ojFhi`;oMk;g0_n?^O<3offcnP;oEjoj00Co@ZggofO4o_mWa?koIlCn0_n;coh2ogg6
oPGoU<[j0onRbO@2ojW5kP?oXlOb0_nXa>h2ojC5l0GoZ<?]0_nZ`^/2ojS3k@CoZL;[0_nZ`N/2ojW2
k0?oZL7[00Go0000ojW1jonY`N_oZL7[ojW2j`04ojW1j`03ojW2jonY`N_oZL7[00_oZL7[2?ooool0
0ol0003oooooooooo`0?ooooo`008_ooool00ol0003oooooooooo`0_ooooo`CoT[[b0_n?_oL2oi[6
mP?oV=3k0onZd?@3ojgIm`;o]/[Y0onibnP00ond^Mgo/[?Iok:cf@02ok:cf@Co[j_C0_nYXLh00onK
TLSoU8W5oiB9a@02oiB9a@?oSH720on5Nl43ogii``?oMG[;0ommJk<3ogQX]0;oMF^i1OmdM<@2og>:
f`04ojZIa?nEOKKoUGffoiEm]P?oPfV]0omfG:L2ofMCZ003oeMF]?m_FJWoKeVY00?oJUBW0om/FZ`3
ogM/^@CoXJ7D0_m^FJX2ofEN]@;oH5:Z0omSEZd01?m^D9koQfBSohMTXon7I:<4oiA/X@04oj1dXOnX
n>;oG7_Ioeakf@;oV8g60on7JJX3ohQSX@?oUF^O1?nPLil3oj5eX@;obIn]0oo7VjX2onS6]0?ob9n]
0_oF];P3olRO[@;od:Va1?nmUk001?o8X[;o`Ijeol6N]Oo1W[D2olnZ]0?o^jC20_o://800onb[mGo
`[[Col:jd`02ol:jd`;oYKSW0onb`ND4ohnil`?oKK?j0omG[oX4ofJlo@?oOLKn0_nDb_X2oh_6n`Go
VLSg0_nSao82oik5l`CoY<G`0_nX`nd2ojG3k`GoZ<?]0_nY`^/2ojS2k0CoZL;/0_nY`N/00onY`^co
0000ojW2j`03ojW2j`03ojW1jonY`^_oZL;[00;oZL;[3?nY`N/9ooooo`03o`000?oooooooooo00ko
oooo000Sooooo`03o`000?oooooooooo02oooooo0_nB^_82oibmk`CoV/Kf00?oV=3koj[@m?nZd?@0
0onZd?@00on]fOOo]/[YokK:j@02okK:j@04okW;j?nd^Mgo];WMokBig@Co/[?I0_n_Zm<00onRV/go
Vi78oi^Ab002oi^Ab0?oU8W51?n=PL82ohEk`@CoOWW30_meN//3ofZ7g@?oN6Rd0omeJkT2ogAda0;o
UXc70on1M[h4oiEm]P;oPfV]0omfG:L3ofMCZ003oeMF]?m_FJWoJUBW00;oJUBW0om/FZ`3ogM/^@?o
XJ7D0om^FJX00omCAjKoIEjeof1BZP02of1BZP;oHeJ]0on2OLD01?m^D9koU6bQoiA/XOo7g^X3oeac
d@;oG7_I00?o8cN_oiR=a_n7JJX00_n7JJX3ohQSX@?oUF^O1OnPLil2oj5eX@;obIn]0oo7VjX2onS6
]0;ob9n]0ooF];P3olRO[@;od:Va0onmUk02olRR/P;o`Ije1?o?Z[@01?nkY<;ob[;2olZb`_o://85
ol:jd`04olc8e_nb`NGo//7Uok;1i@;o]lOV1?nJ_?03ognemPCoJk3i0om]]o`4ogVoo@?oRlKk0_nI
b?L2oiC4m`GoW/Gc0_nTaO02oj74l@CoYL?_0_nX`nd2ojK3kPGoZ<;/0_nY`^`01_nX`^coZL;/ojW2
k?nY`^co0000ojW2k0;oZL;[0onY`^`2ojW2j`;oZL;/3?nY`N/8ooooo`03o`000?oooooooooo00ko
oooo000Tooooo`03o`000?oooooooooo02oooooo1?nL_Nl2oi[6mPCoZ<O`0_nZd?@3ok?8j@;o]/[Y
0_nd_N04okBig@;o/[?I00?oYj?Boj:JcOnRV/d00_nRV/d3oi^Ab0?oU8W51?n=PL83ohEk`@?oOWW3
0omeN//4ofZ7g@03odBSmoni_]goZJGC00?oZJGC0onFS<L2oh5f_P?oLfRh00?oUGffoh=Y[On3JJd0
0omfG:L3ofMCZ0;oEeJd1?mZE:L3ofaJ[0?oMfbi00?oXJ7DohUg^Om^FJX00_m^FJX2oe=7YP03ofEN
]OmPDZ[oH5:Z00?oHeJ]1On2OLD02?o7g^[oG7?AoeacdOmLLm7o>TFboeakfOlS=jooV8g60on7JJX3
ohQSX@?oUF^O1OnPLil01?nQMJ7obIn]olVO[Oo9Wjd2olNKZPCoj<Jd00?ob9n]omJd^?oF];P00_oF
];P00oo8Wjgod:Vaom2Y/@02om2Y/@03okfG/?o8X[;ob::b00;ob::b00?o`IjeolnZ]?o?Z[@00_o?
Z[@4olZb`P04omG1a_o2^]?o`[[Col:jd`?oc<SF00?o//7UokO7i_nganH00_nganH2oiZll0;oWl3`
0on9]_@3ogVam`CoMkCi0oml^_X5ohW0n@?oU<Cg0_nNaO<2oi_3l`GoXLCa0_nU`nl2ojC2k`CoY/?^
0_nX`^`2ojO2k@CoZ<;/0_nY`^`00onX`^co0000ojS2k009ojW2k0[oZL7[0_nX`N/7ooooo`03o`00
0?oooooooooo00kooooo000Uooooo`;o0000<?ooool2oibmk`?oZ<3[0_nXao03ok75j@?o/lSY0_nd
`><4okBmh0;o];WM00?o[:_GojNSd_nWXm800_nWXm83oj:Jc@CoVi780onDRLD3ohf1`P?oQG_10omn
NL<4ogEjb`;oJXOM00Co?/2gokVngOni_]go^KkM0onYYM<3oiJ<a`?oPGJn0omcJ;P2ofIQ^003oh=Y
[OmfG:OoMUbW00?oIe>X0omGE[@2oaE[g@04ofYDYom/FZcoK5Z/ofaJ[0;oMfbi00?oM771oe1A]?n9
MkT00om^FJX3oe=7YP;oH5:Z0omSEZd4oh9ma@?oQHkE0_mLLm42ocY5/P03oeakfOlS=jooQfVZ00;o
QfVZ0on8Hj43oiE[W`GoX7>O00?oXGFQolVO[Oo9Wjd00_o9Wjd00oo7Vj[oj<JdonS6]002onS6]0Go
e[Bh00?ob9n]om2Y/Oo@ZK400_o@ZK45olRR/PGocjZd00?of[ZiolZb`_o://800ooE`LH00oo2^]?o
c<SFolc8eP02olc8ePCo]lOV00?o]lg[oio0l?nO`?000onO`?03ohVfm0?oNK7g1?mg]?T3ogbjnP;o
RL3i0_n:_?L5oi;0mP?oVl?c0_nQa?42oio2l@GoY<;_0_nV`nh00onU`^koYl;]ojO2k@03ojO2k@Oo
Z<;/00?o0000ojS2k?nY`^`01OnY`^`2ojS2k0KoZL7[1onX`N/6ooooo`03o`000?oooooooooo00ko
oooo000Wooooo`03o`000?oooooooooo02kooooo0onX`>/3ok32i`Co/LGY00?o/lSYokC0hond`><0
0_nd`><2okBmh003ojjbfon/ZmOo[:_G00;o[:_G1?nWXm83oj:Jc@;oVi7800CoTIOFohVCeon9TmOo
RI?G0on4U=/3ogfKi0CoOWW30_meN//2ofg=oP;o`m?V0oni_]d3ojVUd`?oUXc70on1M[h3og=X^0?o
IV6h0omfG:L3ofMCZ0?oEeJd00?o5F_MolcIhoo<fN<00onMXML3ogAa`@03oe1A]?n9MkWoKUVZ00;o
KUVZ0_mCAjH2oe9G^P03of1BZ_mSEZgoHeJ]00?oPWg50_oIi]l2ohF>e@03oba1]?mLLm7oG7?A00;o
>TFb00Co8cN_ocM1/?n7JJ[oQfVZ0on8Hj43oiE[W`GoX7>O1Oo9Wjd01Oo7Vj[oj<JdonS6]?oXa[Co
/oFd00Coe[Bh00?oeMKIom2Y/Oo@ZK400oo@ZK45olRR/PCocjZd0_oJ^[T00oo://;oeL76omG1aP02
omG1aP04omgAcOo<b=Koc<SFolc8eP;ocm?L00?o]lOVokO=jongcN/00_ngcN/4oio0l0CoS[Ka0on2
/O<4ognbm@CoPKKf0on:_?L2oi;0mP;oTkcc1?nJ`?84oio2l@;oY<;_0_nS`Nl4ojG2kPCoYl;]1?nX
`^`01_nW`^coZ<;/ojS2k?nX`^co0000ojS2k0;oZL;/1_nX`^`2ojW1j`[oZ<7[1_ooool00ol0003o
ooooooooo`0>ooooo`00:?ooool00ol0003oooooooooo`0^ooooo`03ojS0jon``^Oo/<;W00?o/<;W
0_naaNT2ok?1i0?o]<3S00?o/;SOojjbfon^/]/00_n^/]/4ojb[e`;oYj?B00CoWJ;IoiNLeonGW=Oo
UicG1?nAUmH3ohVCe`?oQ9CK1?mmVn@3ogZ_m@;o_ocU1?o3dnH3okVng@?oZJGC0onFS<L2oh5f_P?o
LfRh0omVHKP3ofU]``?oIe>X0_mGE[@00onAkn[oc=WSolcIh`02olcIh`;oWJ7G0omdLL42oe1A]0?o
KUVZ0omCAjH2oe9G^P?oHeJ]00CoPWg5omWVgooIi]oofNKO0on5S]D01?l/@KCoG7?AocY5/_ljAK82
ob<g[`03ocM1/?n7JJ[oQfVZ00;oR6>Q1?nEJil4oj1cW`GobIn]0ooXa[@3ok?e]0;oe[Bh0_oEe]T4
om2Y/@;od;>m0oo8X[82om6`^0;ocjZd0ooJ^[T01?oTc;ooeL76omG1a_oE`LH3omgAc@03olc8e_o?
dmcocm?L00?ocMcT0_ngcN/2ok;?k`CoWl3`1?n>]_43oh:al`;oOk;e0_n5/O83ohNdl`CoSKSc1?nC
_?<4oi[0lP;oWl;a0_nO`?04oj?1k`;oYL;^0_nU`Nh4ojO2k@03ojS2k?nW`^coYl;/00;oYl;/0_nX
`^`00ol0003oZ<;/ojS2k005ojS2k0;oZ<7/3OnX`N/5ooooo`03o`000?oooooooooo00kooooo000Y
ooooo`03o`000?oooooooooo02oooooo0_n``^L3ok;2iPCo/l7T00Co]<3Sok2hgon`^=oo/;SO1?n^
/]/2ojb[e`03oj:YfonMX]WoWJ;I00;oWJ;I0onGW=L3oi6GeP?oRI?G1?n4U=/4ogfKi003ogZ_mOn[
n>Oo`mo]00;o`mo]0_o3dnH01?nZY]?oW9C:oibDb_nLU<X3ohb3a0?oOgJo0_m^KL401?n1M[koLfRh
og=X^?mcJ;P2ofIQ^0?oJFg31OmnVN<00onn`McoVIC=oiVDc@02oiVDc@?oLFjo0_mdLL42oe1A]003
oeEH^?m^FJ[oKUVZ00?oDdNV1?mBEkX00omRaOgoi_c4omWVg`03omWVg`;oQHkE0_l/@K@3ocY5/P04
ob<g[olg@K3o=d6`ohMYZP?oR6>Q0onEJil3oj1cW`03olFU^?o9WjgobIn]00?obIn]00CobN^;onS6
]?nLOK3oW7f`0_m]G[400ooF];SoeMKIomGFf@02omGFf@;od:Va0oo@/kd2olRR/P?odK2h00?ocjZd
omZj^OoJ^[T00_oJ^[T2onC<_`04omG1a_oMdLgogM7=omgAc@;ogn3F00Gocm?LolgLi?o=g>CocMcT
olGPk005ok;?k`;oWl3`0_nK__43ohnel0CoQk7a1?n5/O83ohNdl`CoSKSc0_nC_?<2oiFjl@CoV[ga
1?nO`?02oj?1k`;oXl3^1?nU`Nh2ojO2k@?oY/7]0_nW`^`2ojO1k0;oZ<;/00Co0000ojS2k?nX`^co
Z<;/1_nX`N`;ojS1j`;oZ<3[1?ooool00ol0003oooooooooo`0>ooooo`00:_ooool2o`00037ooooo
1?nb`^H2ok?1i0;o/KgS1?n`^=l2ojjbf`;oY[3N0onRZM/4oifRf@?oUicG0onAUmH3ohVCe`;oQ9CK
0_m_c?h01?n8jn_oZoSWoj_hion[n>L3ol?Ok@03ok>ffonZY]?oZZKC00;oZZKC0onLU<X3ohb3a0?o
OgJo0_m^KL43og=X^0?oIV6h0omYKL<3ogjIh`?o_/7L0onIU<d3og5^_`;oFebj00GoM771oe1A]?m@
DKCoEERhofiIZP03oe=7YP?oDUNj00?o/_[Uok_ZS_oVo<@01?nCX=d2oe]R_`;o;46d0_m1CKP00olj
AK;o2bVZocM1/002ocM1/0?oR6>Q0onEJil2oj1cW`?oaJFh0oo9Wjd00oo9jh_o_IJ^oiam/003oiam
/0;oKEja00Go<Cf_omGFfOoEe]WoeMKIom2Y/@04om2c_@03olRR/_oA/;SodK2h00;odK2h1?oJ^[T3
onC<_`?ogM7=0ooOh=H2om[[g`04olgLi?o5h>coaN3/olGPk0;o//o_0onZc?44oi^nl@?oSkG`0_n7
/O45ohZ`k`CoRk;`1?n@]_44oiFjl@;oV[ga0_nK_>l4oinnk`;oXl3^0_nS_nd4ojG1k@;oY/7]0_nV
`N`5ojO1k0;oZ<;/00?o0000ojS1k?nX`N`01onX`N`9ojS1j`CoZ<3[0oooool00ol0003ooooooooo
o`0>ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`;o//;V0_na`^H4ok6mh`;o/;SO0_nY]^84
ojJ`gP?oXZWK0_nMX]T00onF[NKoSjcZohn/jP02ohn/jPCoRK7`0_mo^oX2ohgRo0?oXO?a0oo0iO40
1?o3gngo/kKKok>ffonc]]/3ojZVd`?oW9C:0on<Pl@3ogmf_`;oKVg10omTLld3ofIQ^0CoJFg300?o
OYWSom?Uhonn`M`00_nn`M`4oiVDc@;oLFjo0omKG;X2oe1A]0;oEERh1?mCAjH01?mBEk[o/_[Uok_Z
S_oVo<@2omKRg`?oTj3M0omKH[l2oba1]0;o@Dfh00Co2bVZob<g[olg@K3o=d6`0_mSHkd01On8Hj7o
UF^OoiE[WonEJiooX7>O00CoaJFh0_o9Wjd3okfF[PCoW7f`0om]G[42oc4m[`03ogJmoOo@/kgod;>m
00?od;>m1OoA/;P00ooI`/?of[ZiomZj^@04onC<_`03onWNb?oMdLgogn3F00;ogn3F0_oJjml2om3`
j0;oaN3/0onjgO42oj[<l@;oX/Oc0onG^o05ohnck`KoR[3_1?n;/_02oi2fl@;oTkG^0onG^>l5oi^l
k`;oWkk_00?oX;g]oj>okOnS_nd00onS_nd2ojG1k@;oYL3]1?nV`N`4ojO1k0?oZ<7/00?o0000ojS1
k?nX`N`01onX`N`7ojS1j`KoZ<3[0oooool00ol0003oooooooooo`0=ooooo`00;Oooool00ol0003o
ooooooooo`0_ooooo`Co/L;V0_na_N<2oj^li@CoZKKR0_nV/=h00onO/nKoVjoUoi^_i@02oi^_i@?o
UZgV1?n?[>X2ohVal0?oT=Cn00?oSN;loj7clOnQlo401?o0iO42okW4hP?o/kKK1?nZY]<3oibDbP;o
S8?40omoM[l3ofi]`@?oI7?=0_mAU>l2ofU]``;oc_oC0ooCiN<3okk1g0?oVIC=0_maK[l3oe]L^P04
od9G`_m@DKCoEERhoeEH^0GoKh7E00?o_Oc7onKla?oFh]l00ooFh]l3oi>Pg@;oFf:o0_l/@K@3od5=
^003o`/YZ_lg@K3o=d6`00?oHf>m0_nEJil00onRTlKoaJFholFU^003olFU^003olVO[OnmUZko_IJ^
00;o_IJ^0_nLOK02oif1/`?oOVfe0_la?Jl2o`1TeP?od;>m0_o:`=43om6`^0?ofL;300Cof[ZionC<
_ooTc;ooi<bo0_oYg/P2onO_d@03omoPe_oJjmoof^_O00;od?3X0oo5k?02ok[Ml@03ojkFm?nRao?o
X/Oc00?oX/Oc0onG^o02ohnck`;oS[7]0on<[^d4ohf_k@?oSk7^1OnC]Nh3oiNhk`;oVkc_0_nM^nd4
oj2mk@CoXko]1OnU`>d2ojK1k0KoYl7/0_nX`N`00ol0003oZ<7/ojS1k007ojS1k0GoZ<7[2?nX`>/3
ooooo`03o`000?oooooooooo00gooooo000^ooooo`03o`000?oooooooooo02oooooo0_na`^H2ojc1
j@CoZkcU0_nY]^82oj>gi`?oWk?V1?nK[nD3oiJ]iP;oSjcZ0onAaoX2oi3DoP;oVn[j1?ngi?D00oo0
iO7o^LCRokW4hP02okW4hP?o/kKK0_nZY]<01?nEUm?oRXc?ohZ<con:S<l3og^3d0?oOgJo0_m^KL44
ofAcc@04oe6Dkon?dokoc_oColkod`?odnGS00Co/KSNoi2Ge_n@UmKoT9OF0omdNl`3og5^_`?oFebj
00Co@UO2oe1A]?mEF;SoEERh0om_PMD01?nmo<Ooioc3on_fb_o[m/X2omKRg`04ojJiiom7Im3oAfO@
oi>Pg@?oFf:o00Co;46dod5=^?m1CKSo@Dfh0_mNO]X2ocM1/0;oHf>m1?nRTlH4olFU^003om>Z[onm
UZko_IJ^00;o_IJ^1?nMPK<3ogi]]@;oFUfk00Co<Cf_o`1Te_l0I=Kod;>m0oo:`=42om6`^0CofL;3
00?ogmS@onC<_ooTc;l00ooYg/P2onO_d@04omohf_oJjmood?3Xom3`j0?oaNc`00?o^NCdojkFm?n^
e_@00_n^e_@2oj;7l`;oVkoa1?nC]^l4ohjak@?oS:k]1?n=[nd3ohnakP;oTkG^0_nE]>d3oiVhk@Go
WK_]0_nP_Nd2oj6mk@CoXko]0_nU`>d2ojK0k0SoYl7/0onX`N`00ol0003oZ<7/ojS1k007ojS1k0Go
Z<7[2?nX`>/2ooooo`03o`000?oooooooooo00gooooo000_ooooo`03o`000?oooooooooo02oooooo
1?n/`NT2oj^li@;oYK_Y1?nS]nL3oinciP;oVjoU0_nG_?44oiG0m@;oTLOj0_nIgoh3ok3Om`;o]nCe
0onic>T2okW4hP;oZZoL0onQXmL4oiFGd`?oRXc?0_mkPm03ogN7eP?oN9_W0_mTLld2ohoCoP04olCn
gooFmn;oe_ORomKghPCo/KSN0on@UmH2ogAkc0;oF6S700CoLFjooe]L^_mKG;[oFebj0_m2El83oeEH
^004ofn1eOnmo<Ooioc3onOl``;ojoK:00CofnKLojJiionV^NOoY[WW0_m7Im03oe]R_`04ocA2/_l/
@KCo@Dfhod5=^0?oGWkJ00Co=d6`of=S_OmSHkgoHf>m0onRTlH3olFU^0?odjZ_0_nmUZh2okNE]0?o
WH6c1?mnKKD2oeYM^`03o`0LYol0BlWo06CF00Cob/3A00?odK2homW2`ooI`/<00_oI`/<2omoHd003
onC<_ooYg/SojMk800;oinoA0_oOn=X2om?kh@03ol[gj_o5k?3o^NCd00?o^NCd0_n^e_@3ojG;l`?o
Vkoa1?nC]^l2ohjak@03ohj^k?n=[N_oSJg[00;oSJg[0on?[^`4oi6ak0CoUKC]0onI^>d2oifkk@;o
W[_/1OnQ_Nd2oj>ok@;oY;k/1?nV`>`8ojO1k0?oZ<7/00?o0000ojS1k?nX`N`01?nX`N`5ojS1j`So
Z<3[0_nW`>/2ooooo`03o`000?oooooooooo00gooooo000`ooooo`;o0000<?ooool2ojc1j@;oY[o/
1?nU^nT2oj>gi`;oWK_^0onK^nl4oiNll@;oUL3e0onIeO`01?nIgoko/=ogok3Omon`goL2okO@k@?o
^LcY00?o[kSPojZ_g?nZ[m`00onZ[m`3oj6Se`?oUIOC0on:S<l3og^3d0?oMhOF1?mhVnL00on?doko
a?kOomKghP02omKghP;oamCT1?na^=h2oi2GeP?oM7_<0_mHJ<L3oe]L^PCo@UO200CoHJSgokglaonm
o<Ooioc30_o[m/X3om_Vg0?oY[WW00CoAfO@oceA__lmDKkoFf:o0_ld@[83od5=^0;oGWkJ00Coe=CI
of=S_OmSHkgoHf>m1?nRTlH00oo5YKSodjZ_om>Z[`02om>Z[`04okfF[_ngUKCo]iFdokNE]0CoWH6c
0omnKKD2oeYM^`;o;5;50_l0BlT2ol[0d@;o^LSV0ooI`/<2omoHd0;ogncK00?ojMk8onO_dOoWkm40
0_oOn=X2om?kh@04ol[gj_o2l?7o`_3aol;`l@;o^NCd0on`eo@2ojG;l`03oik0l?nF]nooU[O_00;o
U[O_0on@/Nd4ohj^k0CoSJg[0on?[^`4oi6ak0;oUKC]0_nH]>`4oi^hk0?oW[_/0_nQ_Nd2oj:mk0Go
Y;k/0onV`>`9ojO1k0;oZ<7/00?o0000ojS1k?nX`N`01?nX`N`3ojS1j`OoZ<3[1_nW`>/00ooooooo
0000ooooo`0>ooooo`00<_ooool00ol0003oooooooooo`0^ooooo`CoY[o/0_nU^nT2oinmkPCoWK_^
0onK^nl2oiNll@?oVLci0_nIeO`3ojWHn003ok3Omongd>go]m3]00;o]m3]00Co^LcYojnhh?n_^>3o
[kSP1?nZ[m`4oj6Se`?oUIOC0on:S<l3og^3d0?oMhOF0_mhVnL01On5jNgo[o7eolGjjOo5n^Woe_OR
00CoamCT0_na^=h01?nFVMCoMh7@ogN1d?mgPM02ogAkc0;oF6S70omRN]D00omKG;[o@UO2od9G`P02
ohbkmP04olGod_oWo<?ojoK:on_fbP?ofnKL0_nmc^L2og>Ah@06o`m1_om7Im3o?E6noceA__mKH[oo
=4:b0omfN/T00omNO][oe=CIomCDf@02onc=]@05ong6[?mSHkgoXY?6oj:Ca_oX`Jd01OoCZZl4okNE
]0CoWH6c0omnKKD3oeYM^`;o;5;500?o4V7HokW8i_nib>H00onib>H00ooI`/?ogmS@omoHd003omo/
f`;of?WO00God?gOomohf_oCnn7odo_Qol[gjP03ol;`l@;o^n?c0_n`eo@2ojW:l@CoW/3`1?nF]nl3
oi2ak@?oSZk/0_n=[N/2ohj/jPCoTJkZ0onD/N/5oiRdk0;oVkS/00?oWKS[oj2kk?nP^n`00_nP^n`4
oj:mk0;oY;k/0_nU_n`4ojK0k0WoYl7/0_nX`N`00ol0003oZ<7/ojS1k003ojS1k0CoZ<7[0_nX`>/:
ojO0j`03ooooool0003ooooo00kooooo000cooooo`03o`000?oooooooooo02kooooo0_nV_n`2oj6n
kPCoWkg^0_nM^nh2oic2l`CoVlKf0_nIc?T3ojGAm`;oZMSh0onbdO02okO@k@;o/[oT1?n_^>02ojZ_
g003oifSfOnEVmOoUI_G00;oUI_G0on:U]T4oh>Gg@CoNj7Z0_n0aOd2ojoam@;oaO[Y0oo;i>T2olOD
i003ojfbg?nFVMCoUYWD00;oUYWD0_mgPM03ofQjdP;oF6S71?mRN]D01?n<^oKoaOoBolGod_o9nNP2
omSne@03omgfg?oCj>Go_LkW00Co_LkW0_mcTN401?l?@Koo?E6noceA__lmDKh2ocA2/PCoMW[900?o
e=CIonc=]Oo/cKD00_o]aZ`3onS1[@03on>n/_oCZZoodjZ_00;odjZ_00?oc:ZgokNE]?ngUK@00_ng
UK@3oif1/`CoOVfe0_mJGK/3obaBa@03oa9Qf?nib>Ko^LSV00?oZM7e00CogmS@omo/fooOk=_ogncK
0_oHnMl01?o@oMoobOgQolWmhOo7nnL3olKfk@03ol;`lOnkho?o^n?c00;o]MC`1?nYb_42oik0l0;o
V[K[0onC/>/4ohn]jPOoSZcZ1?nA[^X3oiBaj`;oV;C/0_nJ]N/4oifhj`CoX;_/0_nR_N`2oj>mk0Co
YKo/1OnV`>`8ojO1k0;oZ<7/00?o0000ojS1k?nX`N`00onX`N`2ojS1j`koYl3[00?o0000oooooooo
ool03Oooool003Cooooo00?o0000ooooooooool0;_ooool4oj6nkP;oWkg^0_nM_o04oic2l`;oVlKf
0onSbo@2ojGAm`?o[/ka0_nbdO02ok73i`Co/[oT0_n_^>000onUZm_oWJ?IoifSf@02oifSf@CoUI_G
0on:U]T4oh>Gg@;oNj7Z0onNeO/00on_lOGoaO[YolGjj@02ol_Tj@;o^lKS1?n]/]`3oiJIe0?oMh7@
0_mXN]83oen5h0;oHW[E0_n?cOd2olWij0;of?kE00CogOKLom?XiOoCj>GodnSU0_nmc^L2oiBgk`;o
?GGN0_l?@Kl2oceA_P;oDEo20omfN/T3okFYc003onc=]Oo]aZcokLJ/00;oj<6]0_oS_[83om>Z[`;o
c:Zg1?ngUK@2oif1/`03oj28^on>OKgoSWfm00;oSWfm0omkNLH2obaBa@?oAH[[0_nYdOD3ojGNn`04
omo/fooHnMoof?WOom3mg`;obOgQ00Coao_WolKfkOo6m^goa_K]0_o5jnl00onkho?o]MC`okGDl002
okGDl0;oZL[a0_nT_N`4oiZfj`?oTk3[1?n?[NX5ohj/jP;oT:cX0onC[^T4oiJajPCoV[G[0_nM^>/2
oijij`CoXK_[1?nS_N`4ojFok0;oY/3/0_nW`>`8ojO1k0?oZ<7/00Go0000ojS1k?nX`NcoZ<7/ojO1
k00?ojO0j`03ooooool0003ooooo00kooooo000eooooo`;o0000;oooool2oj6nkP?oWkk^0onM_o02
oic2l`?oX/Kb0_nSbo@2oj[;l@?o[/ka0_n`aNT4ok73i`;o/[oT0_nY/]h3ojF[f`CoWJ?I0onEVmL3
ohZFf@;oPiOM0onA^o<2oikEn`?o]_;d00?oanW^ol?Fj?o3e^P01?nka^<4ojfbg0?oUYWD0_mgPM03
ofQjdPCoGhGP00?oSlgmolWij?o9nNP00_oHo]D01?oMm]codnSUom?XiOoCj>D2okoGk0CoU;O_0_lm
MMh00ol?@Koo:Dk4oceA_P03oe5O`P03ogIjbOneZLco]JW<00;o]JW<0_o]aZ`3onS1[@?ohkjb00Co
djZ_olbZ]oo<Z[Ooc:Zg0ongUK@00onbV;goX8Rkoj28^`02oj28^`?oSWfm0omkNLH3ofJ1f@CoAH[[
0_nUg_/2ojc[n@03okKel_nnn^_o__[[00;oaO[Y00?ob_SYolKfkOo5jnl00_o5jnl3ol3NkP;o]MC`
0_n_a^/4ojBmk0;oV[K[00?oV:kVoi>[ionCZnL00_nCZnL3ohnYi`?oSj[X1On@[>P3oi>^j@CoU[7Z
0_nJ]N/00onL]^[oW[W[oijij`03oijij`;oXK_[0_nR_>/4ojBnj`;oYKo/0_nV_n`4ojO0k0SoYl7/
0_nX`N`00ol0003oYl7/ojO1k003ojO1k0[oYl3[1_ooool00ol0003oooooooooo`0<ooooo`00=ooo
ool00ol0003oooooooooo`0^ooooo`;oWkk^0_nR_^d4oj;2l0;oX/Kb0_nXa^l4oj[;l@03ojk>lOn`
aNWo/<GY00;o/<GY0_na`nL2ojbhhPCoZK;N0onUZm/2oifSf@03oiNWhOnBYnCoTZOT00;oTZOT0on=
ZnX3oi6kl`?oY>3l00?o]_;dolOYk_o7jNh01?o3e^P2ok_6h`03ojRbgonGXMcoUj7L00;oUj7L0on6
TmT3og>:f`?oJ7[B0_mOQN02oiO9n@?o_o?a00Coe?GTomS`h_oHl>;odnSU1?noen`3oiBgk`;o?GGN
00Co02Rco`m1_olYC/Co?E6n0_mAGl85okFYc004om?0aoo]aZcoj<6]onS1[@Cohkjb1Oo<Z[L01?ng
UKCo/YRmok:H_OnbV;d3oj28^`CoSWfm0omkNLH3ofJ1f@CoN[?g00Co[>_iokKel_nfmO;o__[[0oo5
n^T00oo:n>Woc?3[olc`j`02olWUj`;o`=k^0onjcnT2ojo6j`;oZk[U0onQ]>H4oiR^iPCoTj_W0on?
ZNL3ohnZj0;oT:cX0_nBZnL4oiF_j0?oV;;Y1?nL]^X2oijij`;oX;W[1OnR_>/2ojBnj`03ojFnjonV
_ncoY[o/00?oY[o/0onW`>`;ojO1k004o`000?nW`NcoYl7/ojO1k0;oYl3/1_nW`>/9ooooo`03o`00
0?oooooooooo00cooooo000hooooo`03o`000?oooooooooo02kooooo1?nR_^d2oj;2l0;oY/?^1?nX
a^l2oj[;l@?o[/G[0_n`aNT2ojfli0Co[;SR0_nY/]h00onR/>7oWJ_Qoif[h@02oif[h@?oUjOQ1?nB
Yn@3ohf[jP04oi6klonTh?coY>3lojCPo0;o^NGd0_nog>h3ol?Fj0;o]<3S0onX/]l4oiNQg0?oQY?I
0omcR]/4ogVLj005oiO9nOnolo7o_o?aokoclOoDmN@00_oHl>83om7Ui@;o_mO/0_nZanl3og2Rl003
oaASfOlmMMko02Rc00;o:Dk40omAGl83okFYc0;odl3700?ogLW5onS1[OoX`Jd01?oS_[800ooMa;oo
c:ZgolbZ]`02olbZ]`Co/YRm0onPR;/4ohim_@CoNgW60omVPMT2ogZcm`;oX]Sk0_nkk?@2olOek004
olGjjOo:n>Woc?3[olc`j`;obNG[0_o4enP3ok[?j@;o]<;T1?n[^^D3oj6diP;oV:kV00?oVJWRoiBW
honDYn<00_nDYn<4oi6Wi0?oTJWV1?nBZnL4oiF_j0?oV;;Y0_nL]^X2oifgjPCoX;W[0_nR_>/2oj>l
j`CoYKk[1?nV_n`4ojO0k0_oYl7/00?o0000ojO0k?nW`>`00onW`>`2ojO0j`cooooo00?o0000oooo
ooooool03?ooool003Wooooo00?o0000ooooooooool0;_ooool2oj:nk@;oY[o/1?nV`nh2ojS6k`?o
[<C[0_n^aN/2ojfniPCo[KcT0_n/^>800onV]>;oX[3Qoj:`h@02oj:`h@CoWJ_Q0onGYn42oi:Wi0;o
Ukcb0onIboT3ojkJmP03okWUm?nog>ko_mc^00;o_mc^00?o`mKXokC0hond`><00_nd`><3ojRbg`?o
Uj7L0on6TmT4og>:f`;oNIcX0onKcOT01?nolo7oe?GTomS`h_oHl>83om7Ui@?oamWW0onZanl3og2R
l004oaASfOl0:;?o02RcobU>a0?oLhCF00?oDEo2okFYc?oC`<L00_oC`<L2omg9a@04onS1[OoS_[;o
hkjbon>n/P;ogLBo0oo<Z[L2ol>^a0?o/YRm1?nPR;/3ohim_@;oNgW60_nGW=L5oi>_jP03oj;Hnonk
k?Co^ncd00;oaoG/00KocOOXolocj?o?lnSoco?Xolk/jOo9iN/4olCGj003ok[?jOnd`^Co]<;T00;o
]<;T0_n[^^D00onW/MooWjcPoin/h002oin/h0?oVJWR1?nDYn<4oi6Wi0?oTJWV0onBZnL2oiF_j0;o
V:oW0onK/nT5oifgjP;oX;W[0_nR^^/4oj>lj`;oYKk[0_nV_n/4ojJok0CoYl3/2onW`N`00ol0003o
Yl3/ojO0k00@ooooo`03o`000?oooooooooo00cooooo000jooooo`;o0000;oooool4ojJok0;oY/?^
0on[`^/2ojc4j`;o[L3X1?n]_^H2ojfli0;oZKST0onV]>84oj:`h@;oWJ_Q0_nK/^P3oiNdk0CoUkcb
00CoVL_iojkJm_n^f_Ko[][f0onig?82okoLkP?o^<[X0_nd`><01?nV/MooVjKMoi^VgOnKY]d3ohbL
g@CoQY_Q1?n4Yn/2oi_=n@;o_NOc0_o=k^/3om7Xi`05om7UiOo7fNOoamWWolOIionkd>X01OnJ__42
oeFIl@04o`1Me?l07JKo4EK@obU>a0?oLhCF0ooC`<L3omg9a@03on3CbooS_[;ohkjb00CogLBo00Co
c:Zgol>^a?o3[/Co`jk41?nbV;d2oj28^`04ojBJbonMU/goWIK=oifFc@GoUicG0_nC[nX3okCDl004
ok_/m?o7mNcoaoG/olggj0?oco?X00?oc^cYol[Nj?o:g^P00oo4enP00onmb^Co]<;TokC2i002okC2
i003ok2gg_nW/MooYk7O00;oYk7O1?nO[>03oiVYhP;oU:OS00?oUZGOoiBVh_nDY^800_nDY^83oiBX
i0CoUJcV1?nH[nL3oi^cj@;oWKOZ0_nO^>T5oj:jj`;oXkc[00?oY;g[ojJojonV_n/00onV_n/2ojJo
k0KoYl3/2_nW`N`00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo000looooo`03
o`000?oooooooooo02gooooo0_nV_n`2oj[1jP?oZl;[0_n/`NT4ojg0j0;o[KkV0_nZ^nH4ojVhi0?o
Y[CR0_nR/>42oijbiPCoVk;X0onG]>`2oiNllP?oYLkf00Co[][fokWLl_nig?;o^Mcb0_nid>/3okS:
j003ojjkhonV/MooY[7O00;oY[7O0onKY]d3ohbLg@CoQY_Q0_n4Yn/3ojG9l`03okgWloo=k^_ocNk[
00?odNSW0oo>hNH01?o7fNOo^m3Zok_@j_nkd>X2oiZnl@;oT[[b0om>Vo<00ol0GMCo01fVoa5Fd004
og>4eP03om?0aooMbLGogLW500;ogLW50_oPdl/00ooS_[;ogLBoomg4_`02omg4_`Co`jk40onbV;d0
0on]Y]3oY9[;ojBJb`02ojBJb`?oWIK=0onGW=L2ok30iP?o]=C`0_o6jnh2olgej@;ocoGX00?oco?X
olk/jOo:g^P00oo:g^P01Oo4enSo_L[Tokg:i?nmb^Co]<;T00Co/;ON0onW/Ml2oin/h0;oWjOL0onJ
YMd4oiJUg`CoU:KR0onDZ>@4oiF/iP;oV:oW00?oVk3Voifdj?nM]>P00onM]>P3oinhj@;oX[[[0_nS
^nX4ojBmj`CoY[o[1_nW`>`8ojO1k0Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0<ooooo`00?Oooool00ol0003oooooooooo`0]ooooo`CoZ/7Z00?oZl;[ojc1jOn/`NT00_n/`NT2
ojg0j0;oZkgW1?nZ^nH2ojVhi0;oYKOV0onR]>D4oijbiP;oVk;X0_nN_^l4oio4lP;oYLkf0on_eo@0
0onig?;o^M3[okW@j`02okW@j`04okS:j?n^^n?o[[_Sojjkh`CoY[7O0onKY]d3ohbLg@;oQY_Q0_nC
/^`3ojG9l`?o_Moa0_o9hnX01?oAj>Ooc^7VolkQi_o>hNH2olSHi@;o^m3Z0_ncb>X4oi:jlP;oCY_c
0_l0Im@01?l07JKo4EK@og>4e_mcQ=H2oi>]j0?ogLW50ooPdl/01?oJhM_ogLBoomg4_ooMa;l2om?=
d`Co`jk400Co/YRmojfVd?n]Y]3o[JK@0onTV//4oifFc@03oiNLeon``>Ko/<3V00;o/<3V00?o]=C`
olK[k_o=mNT00_o=mNT2oloej0;oco7Y0_o<i^T2ol[Nj0;o`m7U0_nmb^@2okNmgPCo/;ON0_nW/Ml2
ojF[f`CoWjOL0onJYMd4oiJUg`;oU:KR00?oV:KOoiRYh_nHZN800_nHZN83oiV/i0CoVk3V0_nM]>P2
oj2ei`CoX[WY1?nS^nX2ojBmj`;oYKk[1?nV_n/5ojO0k0GoYl7/2Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00cooooo000nooooo`03o`000?oooooooooo02gooooo0_nZ`NX3oj_1
j@;o[<7Y0_n[_nP4oj^mi`;oZ[_V0_nW^^L4ojFgiP?oX[CU0_nN/^H2oijkk@CoW[k_0_nOa?83ojS?
m0;o[mOd0onddNl2okW@j`;o/l?V1?n^^n<2ojJag`03oif/hOnFYn;oUZOR00;oUZOR0on=Y^D4oi>b
k004ojG9lonmgo7o_MoaokgOl@;obN?Z0oo=h^L00oo>hNKob=SUolSHi@02ol;@i@Co/lSZ0_nB^_82
oi>ll`;oFJOh0_l0Im@2o`1MdPCoTjgX00CogLW5on3CbooPdl_oh=?;0ooJhM/01?oMa;oodlgCom?=
dooCcM<2ol>^a0;o]kcM1?n]Y]04ojBJb`;oWIK=0_n/]^03ok30iP;o`>7_0_o5lnl00oo=mNWocoGX
oloaj@02oloaj@;oc>KY00Coa]WXol?AiOo3dNGo`m7U0_nla>04okNmgP;o/;ON0_n/[mX4ojF[f`?o
WjOL0_nJYMd00onLXm[oVJCMoiVTg@02oiVTg@CoV:KO1?nHZN83oiV/i0;oVk3V0_nN/ND4oj2ei`Co
X[WY0_nS^nX00onU_>[oYKk[ojFnj`03ojFnj`;oY[o[0_nW_n/2ojO0k13ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0<ooooo`00?oooool2o`0002oooooo0_n[`NT2oj_1jPCoZkoX
0_n[_NL2ojRlj0CoYk[W0_nU]nH2oj:jjP?oXK[[1?nN^nd2oijnk`?oY<Wc0_nXco@3ojo?l0;o]=7_
0_nbb>X4ok?3iP;o[[_S0_nU/n83oif/h@CoUZOR0on=Y^D2oi>bk0?oY/Wb00?o_MoaolWSj_o9hnX0
0oo=h^L2olcKi003olSHiOo2d>Go`]3U00;o`]3U0_ncb>X3ojo5jP?oTkcc0omIYoP00ol3Omoo05gB
o`1MdP02oi>]j0?oW/oi00Goh=?;om[QfooJhM_of^7Kol;]l@03om?=d`;o^Mgb1?ng_=d4ojfVd0;o
Y9[;00?oYkCRojbfh?n/]^000on/]^000on``>Ko`>7_ol3Qk`02olGck`06olGgkOo5mNkoaOG^olGe
k_o?lNWoc>KY1?o6fNP00oo3dNGo_<CPokc4h002okc4h0;o]kgN00?o/[CJojb_f_n/[mX00on/[mX2
ojF[f`03ojBVeonPY=SoX:CH00;oX:CH0onLXmX4oiVTg@CoV:KO0_nHZN800onLZN3oW:gSoib]h`02
oib]h`CoW[7U0_nP]NL2oj:fi`CoY;WX0onU_>X2ojFnj`?oY[k[0_nW_n/Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02oooool0047ooooo00?o0000ooooooooool0;Oooool4oj_1
jP;oZkoX0_nY_^T4ojRlj0;oYk[W0_nT^nX4oj:jjP?oXK[[0_nN^nd3oj;3l@;oY<Wc0onZbo42ojo?
l0;o/L[]1?nbb>X2ok?3iP;oZk[T1?nU/n83oif/h@;oUZOR0_nH[nL4oiRfk@;oY/Wb0_nheo02ol;L
k@04olgRioo<fnCoc=_TolcKi0?ob=CS0_o2d>D3okg:i0;o[lGZ0_n_`nP4oiZolP?oKkKk00Co:Yk_
o`1K^OnNcoWoW/oi0on6g_d00ooJhM_o`^gaol;]l@02ol;]l@03om?=donigO;o^Mgb00;o^Mgb0ong
_=d2ojfVd0;oXK_/1?nW]>82ojbfh0?o]]Wb00Co`>7_olGckoo5lnooaOO]0oo5mNh00oo4jnoo`Mk^
ol7NkP03olKIj0;o_l[S0onla>000onf^]co/[CJok:dfP02ok:dfP;o[:oJ0_nYZMH4ojBVe`CoX:CH
0onLXmX2oiVTg@03oibTf_nKY]goVjKM00;oVjKM1?nLZN04oib]h`;oW[7U00?oXK?Toj:fionR]^L0
0onR]^L2ojBij003ojJjj?nV_>WoY[cY00?oY[cY0_nV_^/Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool004;ooooo00?o0000ooooooooool0;Oooool2oj_1jP;oZL3[1?nY
_^T2ojRlj0;oY[gZ1?nT^nX2oj:jjP;oX[o]1?nR`Nl2oj;3l@;oYlOa0onZbo42ojg:k`Co/L[]0_nb
b>X2ojfoi`CoZk[T0_nU/n800onP/>?oVZgToiZ]i002oiZ]i0CoV:oW0_nH]^d3ojS7l003okSGl?o2
g>go`]c]00?oa][X00Coc=_TolSDhoo8e>?ob=CS0_o4c^83okg:i003ok_6hon_`nSo[l?X00?o[l?X
0_nJ_o82oj?2k`?oR<7j0_mJ^O`00omoa_koQ]kmohKNo@03odW7h`;o`^ga0omlh_D2okWMlP?oL]Cl
0onGboX3oj6kk0;oYkCR0onRe?T2okKIlP;o/o3f00Ko[_Ccojgclon]lo?o[O?colGek_o4jnl4ol7N
kP03olKIj?nob^?o_l[S00;o_l[S00Co_<CPokJjg?nf^]co][[L0_nb]=X00on^[MOoZJWFojVYeP03
ojVYeP?oY:KG0_nPY=P2oj6ReP?oWZ;H1?nLY=X4oi^Vg@;oW:WP00?oWj_Ooj2_h_nP[n800_nP[n84
oj6ci0;oX[KW0_nU]nH4ojJjj0;oY[cY7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo0013ooooo`03o`000?oooooooooo02gooooo1?nY`>/2ojVnj@;oY[k[1?nV_NX2ojBk
jP;oXkk/1?nR_nd2oj;1k`;oYLG`1?nWao400onZbo7o[L[_ojg:k`02ojg:k`;o/L[]0_n^`nT4ojfo
i`;oZk[T00?oYKCToj2`honP/><00_nP/><4oiZ]i0;oV:oW0_nQ_>`2ojS7l0?o]M;_00Co`]c]olKJ
j?o6f^Soa][X0oo6e^H00oo8e>?oa<kRolC>hP02olC>hP04okg:i?nka^?o^lKSok_6h`;o[l?X0onb
`^H2oj?2k`;o[<?[1?nKaOD2ogo6oP?oV<Og0omkaOh3odninP?o7Z7U0olDXM@4oe30m`?oOlko0_nR
e?T3oh_Sn`03ok?`m_n^m??o[O?c00;o[O?c00Co/ncgokGPmOneh?Go]N3e0_o1g^h2okc?j0;o_l[S
0_ni_mh3okJjg003ok6af?n^[MOo[ZgG00;o[ZgG1?nYZMH2ojBVe`03ojBSe?nQX]KoXJ;F00?oXJ;F
0onNX]P4oibTfP;oVjKM00?oWjOKoin[gonOZml00_nOZml4oj2_hP;oXK?T0_nU]><4ojFgiP;oY[[X
8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0014ooooo`03o`000?oo
oooooooo02gooooo0_nY`>/2ojO0j`CoY[k[0_nV_NX2ojBnk0CoXkk/0_nR_nd2ojC2k`CoYLG`0_nW
ao43oj[8k`;o[L[_0_n]a>/4ojk3j@;o[KoW00?oZ;WUojFdi?nU]>@00_nU]>@2oj2`h`;oWk?V0onM
]NT3oj6lk0;oZ/O^0oned^l3okgEk004olKJj?o6e^Koa]KVolKFiP;oa=3S0oo4c^801?o1bN7o^lKS
ok_6honka^<2ok[3h@?o//;V0_ne`N<4ojc3j`;oVlGe0onXa>d2oiS7m`03ojG3k_nC`oOoTl?g00;o
Tl?g1?mf_od3odjbnP?o::;]00?o49ONo`JFcOl6U/d00om;a>l2oh_Sn`;oON;d00GoO^?doi7RoOnA
h_goTN;mok?/m`03okGPm@04okC@k_nlcnSo_<oXokc?j0;o]l;S1?ni_mh01?nf^]co/K7Hok6af?na
/MP4ojj]e`;oZJWF00?oZ:GDojBSe?nTXm@00_nTXm@4oj6ReP;oWZ;H00?oXJ;Foj2TfOnPY=T00_nP
Y=T4oinWf`CoWj_O0_nP[n800onT/>7oYKCSojFdh`03ojFdh`;oYKOV9?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo0015ooooo`;o0000;oooool3ojO0j`;oY[k[0_nU_n`4
ojBnk0;oXkk/0onT`Nh3ojC2k`;oYLG`0onXa^l2oj[8k`;o[<G/1?n]a>/2ojk3j@03ojZlionX^NGo
Z;WU00;oZ;WU0_nU]>@2oj6diPCoWk?V0onM]NT00onQ_>coZ/O^oj[7kP02oj[7kP04okGBkonmeNco
_MG/okgEk0?o`MCX00?oa]KVolC@hoo4d><00_o4d><01Oo4c^;o`LWQol79hOo1bN7o^lKS00Co^/?Q
00?o//;VokG1hone`N<00_ne`N<2ojc3j`?o//7U0_nXa>d00on``NKoYL?^ojG3kP02ojG3kP;oTl?g
0onO_>d3ohfjm0?oM;Kj0omJ/O/4odJ^n0?oCKWi0omWcO`2oi7Ro@?oW][l00Go]N3eokC@k_ndd>ko
]=3^okc?j004okO2h`;o^KoN0_nc]MX4ok6af0;o[ZgG00?oZjSDojRUe?nXYM@00_nXYM@4ojBSe0;o
XJ;F00?oXZ;Doj6Re_nQX]H00_nQX]H4oj2Tf@;oWjOK00?oXjSJojB/gOnT[=d00_nT[=d4ojB`h@;o
YKCS:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0017ooooo`03o`00
0?oooooooooo02gooooo1onU_n`2ojBnk0?oY<3]0_nT`Nh2ojK3kPCoY/C_0_nXa^l00onZa>go[<G/
ojc5k003ojc5k0;o[LC[0_n[_nP3ojZli`;oZ;WU0_nT]nH4oj6diP;oWk?V0_nQ^NX4oj>nk0;oZ/O^
0onccNd01?nmeNco`MCXol7Dj?o1e>P2ol7@iP?oa=3S0_o2bn42ol79h@?o_/GO0_nj`n43ok[1g`;o
]L7S0_nh_n03ok;1i@03okJohOn``NKo/<7V00;o/<7V0_nU`nh3ojbliP;oWkc]0_nU]^@3oiVdj`Co
RK;a0omi/_L3offdnP?oLKkm0_n3cOl2oiG3m`CoYLcd0_ndd>h3ok73i`;o]l;S0_nb^=d4ok>efP;o
/K7H00?o[JcEoj^Xe?n[Z=@00_n[Z=@4ojRUe0;oY:?D00?oY:;Coj:Re?nRX]@00_nRX]@4oj6ReP;o
X:CI00?oXjGGoj>Xf_nSZ=X00_nSZ=X4ojB/g@;oY;3Q;?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0018ooooo`03o`000?oooooooooo02gooooo1?nU_n`4ojBok@;oY<3]
0_nU`Nd4ojK3kP;oY/C_00?oZ<?]oj[4kOnZa>d00_nZa>d2ojc5k0?oZl7Z0_n[_nP2ojRli`?oY[WW
1?nT]nH2oj6diP;oXKOX1?nQ^NX2oj>nk0?oZlG]0_nccNd3okS@k003ol7Dj?o1d>Ko`M3V00;o`M3V
00?oa=3Sol;;hOo2bn400_noan03okk5g`;o_L;N0onj`Ml2ok^og@Co^;oP00Co//7UokJohOnf_n7o
][oQ0_n``NH3ok>lh0;o[;cV0_n^]ml4ojFfi0?oVKC[0_n9/_400onE[NOoS:k/ohb^k002ohb^k0?o
Q[7a1?n9^OD3oiG3m`;oYLcd0_nW`>/3ok73i`03ojjhhOnb^=go/[SM00?o/[SM0_nc]MX00on_[mOo
[JcEojf/e@02ojf/e@CoZjSD0_nXYM@00onWXm;oY:;CojBRd`02ojBRd`CoXZ;D0_nQX]H00onTXmGo
XjGGoj>Ue`02oj>Ue`CoXjSJ0_nT[=d`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool004Wooooo00?o0000ooooooooool0;Oooool4ojFok0;oY;o]0_nU`>d4ojG1k@;oY/?^
0_nW`^d3ojS3k@;oZ/C]0onZ`^/2oj_1jP;oZKkX1?nX_>L3ojJii`;oY;OV0_nR]nL4oj6gj0;oXKWZ
0_nV_n`3oj_5k@;o/L[]0onhd>`3ok_>j@;o`M3V0_o0c><00oo2bn7o_lOPoko7h002oko7h003okk5
gonm`]ko_L;N00;o_L;N00?o^/7Ook^ogOnk_md00_nk_md2okRoh0;o^KkM0_nf_n42okRlg@?o/kcP
0_nd^=`4ojjgg`;oYKKT00CoZ;3Moin^h_nO[^;oWjkR1?nE[NL4ohb^k0?oQ[7a0_n9^OD00onF/^_o
WK[]oifjk@03oifjk@?oYl3[00Co/L?WojjhhOn^^>7o[[SQ0_nb^=d2ojj`fPCo[joG0on][=D2oj^X
e0;oZJGC1?nWXm83ojBRd`;oXZ;D0_nTX]<4ojBSe@CoXjGG0_nSZ=Xdooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool004[ooooo0_l0000^ooooo`CoYKo/1?nU`>d2ojG1k@;o
Yl7]1?nW`^d01?nX`ngoZL;/ojW2k?nY`^`2oj[2j`;oZKoY1?nY_^P2ojRli`;oY[[W1?nT^>L3oj:g
i`;oXKOX0_nS_>/4ojJok003oj_5kOnab^go/L[]00;o/L[]00Go^=3/ok_>jOnkc^Wo^lkYokc<iP03
ol3<h`;o_/SR0onoan02okg3gP?o_L;N00?o_<3Mok^ogOnk_md00_nk_md01?nk_]co^KkMokVngOni
_]d2okZlf`Co^;cM00?o/kcPokBhg?nd^=`00_nd^=`2ojjgg`03ojnbf_nX/=goZ;3M00;oZ;3M0onO
[^82oiF]i`03oi^XgonFZN?oUZWS00;oUZWS0onC[>P4oiJbj`;oWK[]0_nQ/N@3ojRfh`?o[[SQ00?o
[;7Lojj`f_n^/=X00on^/=X3ojn_e`;o[JcE0_n[Z=@4ojVUd`;oYj?B00?oYZ;BojFRd_nUX]800_nU
X]84ojBRd`?oY:?E0_nSYMLiooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool004cooooo00?o0000ooooooooool0;?ooool4ojFok0;oYL3]0onV`>`3ojO1k@;oYl;]0_nX`^`2
ojW2k0;oZL3Z1?nY_nT2ojVnj0;oYkcX1?nV^^L2ojBhi`;oXk[Y1?nS^^X3oj>lj`;oY[o/0onZaNd2
ok7:k@;o]L_[00?o^lkYokc<i_nlc>H00_nlc>H00oo0c>?o_/SRokk8hP02okk8hP03oko7h?nm`mko
_L?N00;o_L?N00Go_L;Nokc0gOnl`=go_<3Mok^og@04ok^ng003okVngOnj_=_o^[cK00;o^[cK0_nh
_=d2okRifP?o];SL00?o];CHojnbf_n_/]X00_n_/]X2ojR`g@03ojV/fOnSZM_oXjWK00;oXjWK0onK
Z=l4oiJYh`?oTjcX0_nF/^/2oib]hPCoXK7T0onX]^<01?n^^>7o[;7Lojbag?n//M`4ojj`fP;o[joG
0_n/Z]H4oj^Xe0;oZJGC00?oYj?BojJRd_nVX]800_nVX]84ojFRdP?oY:;C0_nTXmDlooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004gooooo00?o0000ooooooooool0;?oo
ool2ojFok0?oY[o/0_nV`>`00onW`>coZ<7/ojS1k002ojS1k0;oZ<;/0_nX`>/4ojW0jP;oZKoY0_nX
_NT4ojNlj0;oY[[W0_nT^^T4oj>jj@;oXk[Z0_nT_N/4ojK0k0;oZ/G]0_n^an`2okG;j`?o]l_Y0_nl
c>H3ok_8i0;o_/SR0onmaN02okg3gP04okc1g_nl`=go_<3Mokc0g@Go^kkL0_nk_=/3okZlf`03okZj
fOnh^M[o^;WJ00?o^;WJ00Co];SLokBdf?nd]=So];CH0_n_/]X00on_[]OoZJcIojV/f@02ojV/f@Co
XjWK0onKZ=l2oiJYh`;oW:KL0onJZ>04oib]hP;oXK7T00?oXjcMojR_gOnX[md00_nX[md4ojbag0;o
[[3J0_n[[=L4ojbZeP;oZjSD00?oZ:GCojNSd_nWXm800_nWXm84ojJRdP;oYJ;B@oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo001>ooooo`03o`000?oooooooooo02gooooo
0_nV_n`00onW`>_oYl3/ojO0k002ojO0k0;oZ<7/1_nX`>/2ojW0jP;oZ;kY1?nX_NT2ojNlj0;oYK_Y
1?nT^^T2oj>jj@;oXkc[1?nT_N/2ojK0k004ojW3k?n^anco[/O/ojk7k0;o/LS[0ongbnT2okO8i`?o
^lST0_nja^<3okg5h003ok_2h?nl`Mko_<7N00;o_<7N00?o_<3Mok^ng?nk_]`00onk_]`4ok^lf`04
okZlfonj^]Wo^[[IokZjf@;o^;WJ0_ng]]P4okBdf004ojnbf_n_[]Oo[jkGojn^e`CoZJcI0_nSZM/0
0onUY]OoWjGIoinUf@02oinUf@CoW:KL0onJZ>02oib]hP;oX:SL0onS[=d4ojR_g@;o[;7L00?oZZcI
oj^/eon[[=L00on[[=L2ojbZeP03ojVWeOnXYM?oZ:GC00;oZ:GC1?nWXm82ojJRdTOooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`00Coooool2o`0002kooooo0onW`>/2ojO0
k0SoZ<3[0_nX_nX4ojRnj@;oZ;gY0_nV_>T4ojFkj@;oY;[Y0_nT_>X4oj>lj`;oY;g[00?oY/7/ojW3
k?nY`n`00_nY`n`00on^anco/LS[ok78j`02ok78j`03okO;jOngb>Oo]lSW00;o]lSW00?o^lSTok[6
honja^<00_nja^<01?nmaN3o^l;Pok_2h?nk`^02okc1gP?o^koM0_nk_]`2ok^mf`?o^kcK00Go^[_J
okZjfOnj^]Wo^[[IokVhf005okNff0;o];CH0_nc/MH4ojn^e`;oZJcI00?oZJSEojFVeonUY]L00_nU
Y]L4oinUf@;oW:KL00CoX:?HoinUf_nOYM[oWjGJ1OnPZ=`3oj>/g@;oZ:oM00?oYj_JojZ/fOnZ[=T0
0_nZ[=T2oj^/e`;oZJWF1?nYYmD3ojRUd`;oYj?BC?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo001Aooooo`03o`000?oooooooooo02cooooo00?oYl3[ojS0jonX`>/01_nX
`>/6ojRojP;oZ;kY0onW_NT3ojJlj@;oYK_Y0_nU_>X4ojBljP;oXkc[00?oYKk/ojK1k?nV`N`00_nV
`N`2ojW3k0?o[<G/0_nab>/3ok;7j@;o]lSW0_nga^H3ok[6h`04okS3h_nk`^3o^l;Pok_2h0;o^L3O
0onk_md2okZng@Co^kgK00Go^kcKokZkf_nj^m[o^[_JokZjf@03okVhf0?o]kKH0_nf/mL4ok>aeP;o
[jkG00?o[Z_EojVXeOnYZ=D00_nYZ=D4ojFVe`;oWjGI00?oXZ?Foj2Sf?nPXmP00_nPXmP3oinUfP;o
X:SL0_nSY]P3ojFYfPCoYj_J0_nZ[=T00onXZMSoZJWFojVYeP03ojVYeP?oZJOE0_nXYM=?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool005;ooooo00?o0000ooooooooool0
:oooool9ojS0j`;oZ;oZ0_nW_nX4ojNnjP;oYkgY0_nV_NX7ojFljP;oY;cZ0_nT_^/3ojFnk0;oY/7/
0onY`n`2ojc5k0;o[/G[0onbanT2ok?6j0Co]lKV00Go^/KSokS3h_nh`n;o^<?Rok_2h004okW0g`03
ok^ogOnj_]go^[kM00;o^[kM0_nk_M/01?nj_=_o^[_JokZkf_nj^mX2okVjfPCo^KSH00?o]kKHokJc
eonf/mL00_nf/mL2ok>aeP03ok6^eOn^ZmGo[Z_E00;o[Z_E0_nYZ=D00onYY]?oYJCDojFTe002ojFT
e0CoXZ?F0onPXmP2oinUfP03oj:TeonSY]SoXjKH00?oXjKH0onUZMX2ojN[fP03ojNYf?nXZMSoZ:WH
00;oZ:WH1?nYZMH2ojVWeE?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`00Doooool00ol0003oooooooooo`0[ooooo`OoZ<3[0_nW_n/4ojNojP;oYkkZ0_nV_^X4ojJmjP;o
YKcZ00?oYKg[ojBmjonT_N/00_nT_N/2ojBnj`;oYKo/1?nV`N`2ojW3k0;oZlC/1?n^aN/00onbanWo
/lKXok?6j002ok?6j0;o]lKV0_nfa>D2okS3hP;o]l7R0oni`=l2okRog`?o^[kM00?o^KgMokZlfonj
_=/00_nj_=/00onj^m[o^K[JokVjfP02okVjfP;o^KSH0_ng]]P3okJce`03okBae_na[]Go/JkE00;o
/JkE0_n^ZmD00on/Z=?oZJKCojVVd`02ojVVd`CoYJCD0onRXmH2oj2Sf003oj:ReOnRY=OoXZCG00;o
XZCG1?nSY]P2ojFYfP03ojJXeonWZMSoYjWH00;oYjWH1?nXZMP2ojVYeUOooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00E?ooool2o`0002gooooo0_nX`>/2ojO0j`CoYko[
0_nW_nX2ojNnj`CoY[kZ0_nV_NX00onU_^_oYKg[ojFmj`02ojFmj`;oY;g[1_nU_n`2ojK1k0;oZ<;/
1?n[a>`2ojk5j`?o[lGZ0_nca^P2ok;4i`;o]/CU0_nd`^D4okO1hP03okW0gonh_moo^;oO00;o^;oO
00Co^[kMokVmgOni_Mgo^KgM0_nj_=/2okVkg0?o^K[J0_nh^MX4okNff004okJceond/MKo];7FokBa
eP?o/JkE00Co[Z_EojbXdon/Z=?o[:SC1?nYY]<2ojFTe003ojJRd_nTX]?oY:;C00;oY:;C0onRX]D4
oj:Te`;oXjKH0_nUY]H3ojJXe`CoYjWH0_nXZMQJooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool005Kooooo00?o0000ooooooooool0:oooool4ojO0j`CoYko[1?nW_^/2ojJn
jP;oY[k[0onU_^/2ojFmj`;oYKk/1_nU_n`2ojK1k0CoZ<;/0_n[a>`3ojc4k0;o[lGZ00Co[lCYok;4
ionba>Oo//CW0_na`nL4okC2i@;o]l7R0onf`>82okRog`04okNnh?ni_Mgo^KgMokVmg@;o]kgN1?ni
^m`00oni^][o^;WJokRifP02okRifP;o]kKH00?o]KCHokBae_nd/MH00_nd/MH2ok6^e@;o[jcD1?n/
Z=<2ojVVd`03ojRTd_nVX];oYZ;B00;oYZ;B1?nTX]<3oj:Re@;oXZCG00?oY:CDojFVe_nUY]H00onU
Y]H3ojJXe`;oYjWHG_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo001G
ooooo`03o`000?oooooooooo02_ooooo1?nW`>/4ojNoj`;oYkk[1_nV_^/00onU_^_oYKk/ojFnk004
ojFnk0;oYKo/0onU`>`3ojK1k0;oZ<;/0onY`n`2ojc4k003ojc3jon_a>Wo[lCY00;o[lCY00?o//CW
ok73iona`nL00_na`nL2okC2i@;o/l7U0onf`>800ond_n?o]kkPokNnh002okNnh003okVmgOng_Mko
]kgN00;o]kgN0_ni^m`2okNkg0?o^;WJ00?o]KOJokFdf?ne]=P00_ne]=P2okBaeP;o/JoF1?n_[=@2
ojbXd`03oj^WdonXY=;oZ:CB00;oZ:CB1?nVX]82ojBRd`04ojFRd_nUX]?oYJ;CojFRd`CoY:CD0_nU
Y]IVooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool005Sooooo00?o0000
ooooooooool0;?ooool3ojO0j`;oYko[0onV_n/5ojJnj`OoYKk/0onU_n`2ojG0k0;oY/7]1?nW`^d3
ojW3k0Co[<?[0_n_a>T3ojk3j@;o/L?W0_n``^L4ok?1i@04okK0h_nd_n?o];oSokBoh`;o]kkP0_ne
_^43okNmgP;o][cO1?ng^m`01?nh^M[o]KOJokFgf_ne]mX2okFdf0;o/[;H1?na[mH2ojn/e003ojfZ
e?n[Ym?oZjOC00;oZjOC1?nXY=83ojJRdPCoYJ;B0onUX]<2ojBTe6[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`00FOooool00ol0003oooooooooo`0/ooooo`CoY[o/0_nV_n/00onV_ncoYKo/
ojFok002ojFok0;oYKk/2?nU_n`2ojG0k@CoY/7]0_nW`^d00onX`^coZL?/ojW3k002ojW3k0Go[<?[
0_n^`nT2ojk2j@Co/<;W0_nc`ND2ok70i@;o];oS0_nc_n<4okFnh@03okNmg_nf_=oo][cO00;o][cO
0_ng^m`01One^]go]KOJokFgf_ne]m[o/kKK00Go/[;H0_na[mH00on^[MOo[J[DojfZe002ojfZe0Co
ZjOC0_nXY=800onWXm;oYZ;BojJRdP02ojJRdP?oYJ;B0_nUX]=]ooooo`05o`000?oooooooooooooo
ool000002oooool005[ooooo0_l0000]ooooo`OoY[o/2_nU_n`6ojG0k@?oY/7]1?nX`^`2ojW3k0?o
ZL;/0_n/`n/2oj_2jPCo[/;Y0_n``^L2ojo1i`;o/L3U0_n``>H4ok>oh`;o]KkQ0onc_^82okJlg`03
ok>lh?ne^]go]K[M00;o]K[M00Co]KOJok>ffonc]]_o/kKK0onb/]P00on_/MWo[ZgGojj]e`02ojj]
e`Co[J[D0_n[Ym<00onXYM?oYj?BojNSdP02ojNSdP?oYZ;B0_nUX]9aooooo`04o`000?oooooooooo
o`0000_ooooo001Looooo`03o`000?oooooooooo02_ooooo1OnV_n`:ojFok0KoYL3]1OnV`Nd5ojS2
k0;oZL;/0_nY`^/4oj_2jP;o[/;Y00Co[L7Yojo1ion_`NOo[l7W0_n^`NP4ok30iP;o/koS0_na_n@3
ok>nhP03ok:nhonc_>3o/kcP00;o/kcP0_ne^]d2ok:igPCo/kKK00Co/[;HojnafOn_/MWo[k7I1?n^
[ML2ojfZe003ojZXeOnXYM?oZ:GC00;oZ:GC0onWXm82ojJRdWGooooo00?o0000ooooool000002ooo
ool005gooooo00?o0000ooooooooool0:oooool2ojJok0goYKo/1OnU`>d3ojK1k@CoYl7]1?nX`^`4
ojW2j`;oZl;Z0_n[`NX3ojg1j@03ojo1ion^`NSo[/7X00;o[/7X0_n``>H2ojo0iPCo/KoT00Co/kkR
ok:nhonb_^?o/[kS0_nc_>02ok6kh@Co/[WN0_nc]]/00on_]=co[k7Iojnaf@02ojnaf@;o[ZgG0_n[
[=P4ojZXe@?oZ:GC0_nWXm9hooooo`04o`000?ooooooooooo`0000[ooooo001Nooooo`03o`000?oo
oooooooo02_ooooo2_nU_n`6ojG0k0;oYL3]1OnV`Nd2ojO1k@;oYl7/1?nX`^`2ojW2j`;oZL7[0_n[
`NX2oj[1jPCo[<7Y0_n^`NP2ojg0j0Co[l3V0_na_n@2ok2oi@;o/[kS0_n`_N@4ok6kh@;o/[WN00?o
[kSOojndg?n_]=`00_n_]=`2ojnaf@;o[:oK1?n[[=P3ojZXe@;oZ:GCO?ooool00ol0003oooooo`00
000:ooooo`00Goooool2o`0002cooooo2?nU_n`6ojG0k003ojK0k?nV`NgoY/7]00CoY/7]0onV`N`3
ojO1k0;oZ<;/0onX`N`3ojW1j`CoZ/7Z0_n/`NT2oj_1j@Co[L3X0_n_`>H2ojk0i`;o/;oU0_n^_nH4
ok2mi0;o/K_Q00?o[[[Rojnhgon_^=l00_n_^=l2ojndg0;o[;?N1?n/[m/2oj^/f8?ooooo0_l0000:
ooooo`00HOooool00ol0003oooooooooo`0Zooooo`SoYKo/1?nU`>`3ojK0k0;oY/7]1OnV`N`6ojO1
k0?oZ<7/1?nY`N/2oj[1jP;oZL7[1?n[`NT2ojg0j0;o[<3Y0_n^`>L2ojboj0Co[[oV0_n`_N@2ojfm
i@?o[[[R0_n_^=l2ojbgh@Co[;?N0_n/[m^5ooooo`?o00002_ooool006;ooooo00?o0000oooooooo
ool0:oooool2ojFok0;oY[o/1OnU`>`6ojK0k0CoY/7/1onW`N`4ojS1k0;oZL7[0_nX`N/4ojW1j`;o
Zl7Y0_nZ`NX2ojc0j@;oZl3Y1?n/_nP2ojjoiP;o[;kW1?n]_ND00on^^^;oZkWToj^ii004ojbgh@;o
[;?NQ?ooool4o`0000gooooo001Sooooo`03o`000?oooooooooo02_ooooo1?nV_n`2ojG0k0WoY/3/
1?nV`N`7ojO1k0GoZ<7/0onX`N/4ojW1j`;oZ/7Z0_nY`N/4oj_0j@;o[;oX0_n[_nT4ojbni`;o[KgU
00?oZkcVoj^ii?n[^N@00_n[^N@2ojbghH?ooooo1?l0000Aooooo`00I?ooool2o`0002cooooo0onV
_n`<ojK0k0CoY/7/2?nW`N`2ojS1k0;oYl7/1?nX`N/00onY`N_oZ<7[ojS1j`04ojW1j`;oZl3Y0_nY
`>X4oj^oj@;o[;kW0_nZ_^P3oj^liP;oZkWTPoooool3o`0001Gooooo001Vooooo`03o`000?oooooo
oooo02_ooooo0_nV_n`=ojK0k003ojK1k?nW`>coYl3/00coYl7/0_nX`N/00onX`NcoZ<7[ojS1j`02
ojS1j`GoZL7[0onY`>X2oj^oj@;oZKoY0_nZ_^R5ooooo`Co00006?ooool006Oooooo00?o0000oooo
ooooool0:_ooool4ojJok0[oY/3/1OnW`>`<ojO1k0?oZ<7/1OnX`N/2ojW1j`GoZ<3[0_nY_nV4oooo
o`Co00007?ooool006Sooooo00?o0000ooooooooool0:_ooool2ojJok0SoY/3/2_nW`>`?ojO1k0;o
Z<7[00?oZ<7/ojS0jonX`>/01?nX`>^3ooooo`Co00008?ooool006Wooooo0_l0000/ooooo`GoY/3/
4OnW`>`;ojO1k0CoZ<7/0_nX`>^2ooooo`Co00009?ooool006_ooooo00?o0000ooooooooool0:_oo
ool4ojO0ja;oYl3/2onW`N`2ojS1k8;ooooo0ol0000Xooooo`00K?ooool00ol0003oooooooooo`0Z
ooooo`?oYl3[4onW`>`7ojO1k8?ooooo1?l0000[ooooo`00KOooool00ol0003oooooooooo`0[oooo
o`;oYl3[0_nW`>`3ojO0j`ooYl3/0_nW`Nb2ooooo`Co0000;oooool006kooooo00?o0000oooooooo
ool0:_ooool;ojO0j`;oYl3/0_nW`>/6ojO0k87ooooo1?l0000cooooo`00Koooool2o`0002_ooooo
3onW`>/2ojO0k83ooooo1?l0000gooooo`00LOooool00ol0003oooooooooo`0Zooooo`WoYl3[P_oo
ool4o`0003_ooooo001booooo`03o`000?oooooooooo02[ooooo1OnW`>^2ooooo`?o0000?oooool0
07?ooooo00?o0000ooooooooool0:_ooool00onW`>_oooooooooo`1oooooo`Co0000@_ooool007Co
oooo0_l0000Zooooo`03o`000?oooooooooo07_ooooo1?l00016ooooo`00M_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001:ooooo`00Moooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001>ooooo`00N?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo077ooooo0ol0001Booooo`00NOooool2o`0002Cooooo00?o0000oooo
ooooool0KOooool4o`0005Gooooo001kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0JOooool4o`0005Wooooo001looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
IOooool4o`0005gooooo001mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOoo
ool4o`00067ooooo001nooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000IOooool0
083ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000JOooool0087o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000K?ooool008;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000L?ooool008?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000M?ooool008Cooooo0_l0000I
ooooo`03o`000?oooooooooo04[ooooo1?l0001hooooo`00Q_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Kooooo1?l0001looooo`00Qoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04?ooooo0ol00020ooooo`00R?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03oooooo1?l00023ooooo`00ROooool2o`0001Cooooo00?o0000ooooooooool0>ooo
ool4o`0008Oooooo002;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4
o`0008_ooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`00
08oooooo002=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool3o`0009?o
oooo002>ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000U_ooool0093ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000V_ooool0097ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Tooooo`Co0000W_ooool009;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000X_ooool009?ooooo0_l00009ooooo`03
o`000?oooooooooo01gooooo1?l0002Vooooo`00UOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01[ooooo0ol0002Zooooo`00U_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Kooooo1?l0002]ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo1?l0002aooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo1?l0002eooooo`00VOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Wo
oooo002Kooooo`04o`000?ooooooooooo`0000Wooooo0ol0002mooooo`00W?ooool00ol0003ooooo
o`000005ooooo`Co0000`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002N
ooooo`;o0000b?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:kooooo00GoV9RHo`000?l0003o
A4A4okZj^P09ooooo`Go00001Oooool2o`000003oa0@4?oooooooooo00?ooooo0_lQ8B6Hooooo`00
[_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^kooooo
odA4A0Kooooo00?o0000ooooooooool01?ooool2ob4Q8ISooooo002^ooooo`03o`000?oooooooooo
00cooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`0009oooooo002^ooooo`03o`000?oooooooooo00Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo0000X?ooool00:ko
oooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmEEEGoooooo`00
0:3ooooo002/ooooo`03oa0@4?l0003o000000?o00003_ooool00ol0003oooooooooo`02ooooo`03
ogMgMoo<c<co00000:3ooooo002^ooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03onk^k_m4A4Co00000:3ooooo002^ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03ogMgMol0003ooooo09oooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0983928, 0.020481, \
0.0037547, 0.0037547}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  "The wavefronts curve toward the region of lower ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " according to Snell's law, and as they do so the amplitude and wavelength \
decrease, as expected from our WKB analysis of this equation in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  However, note the formation of a focus at a point behind the region of \
low wave speed, where the amplitude increases as wave energy is concentrated. \
This region is acting as a lens for the waves [see Exercise (13) in Sec. ",
  ButtonBox["5.2",
    ButtonData:>{"Chapter5.nb", "c:33"},
    ButtonStyle->"Hyperlink"],
  ", and the examples in Sec. ",
  ButtonBox["5.3.1",
    ButtonData:>{"Chapter5.nb", "c:35"},
    ButtonStyle->"Hyperlink"],
  " for  similar problems in which the ray trajectories for the waves are \
evaluated]. "
}], "Text",
  CellTags->"i:28"]
}, Closed]],

Cell[CellGroupData[{

Cell["Implicit Methods and Operator Splitting", "Subsubsection",
  CellTags->"i:27"],

Cell["\<\
\t Putting implicit methods in multidimensional form takes a bit \
more thought.  For example, if we try to implement the Crank-Nicolson scheme \
directly in two dimensions, we obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1\)\), "+", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \((S\_\(j\ k\)\%n + S\_\(j\ k\)\%\(n - 1\))\)}], " ", "+", 
            " ", \(\(D\_x\) T\_\(j\ k\)\%n\), 
            "+", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1\)\), 
            "+", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%n\), 
            "+", \(\(D\_\(\(y\)\(\ \)\)\) \(T\_\(j\ k\)\%\(n - 
                    1\)\)\(\ \)\)}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.30)"],

Cell["where for convenience we have introduced the notation", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], \((T\_\(j + 1\ k\)\%n - 
                2  T\_\(j\ k\)\%n + T\_\(j - 1\ k\)\%\(\(\ \)\(n\)\))\)}]}], 
        TraditionalForm]]],
  ",\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(D\_\(\(y\)\(\ \)\)\) T\_j\%n\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{"\[Chi]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]], \((T\_\(j\ k + 1\)\%n - 
                2  T\_\(j\ k\)\%n + T\_\(j\ k - 1\)\%\(\(\ \)\(n\)\))\)}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "( ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_y\)]],
  " are difference operators for second derivatives in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions respectively, multiplied by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "/", "2"}]}], TraditionalForm]]],
  ". )"
}], "Text"],

Cell[TextData[{
  "\tSolution of Eq. ",
  ButtonBox["(6.2.30)",
    ButtonData:>"(6.2.30)",
    ButtonStyle->"Hyperlink"],
  " requires some finesse, since the number of coupled equations for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%n\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\)\ \((M\_y - 1)\)\)]],
  ", which can easily exceed several hundred. The problem is even worse in \
three dimensions, where thousands of coupled equations must be solved \
simultaneously. However, the equations are sparse, and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is sufficiently adept at solving  such problems so that even in \
three dimensions, the solution can be obtained directly without too much \
difficulty.  We leave this brute-force approach to the problems at the end of \
the section.\t"
}], "Text"],

Cell[TextData[{
  "\tRather than using a direct solution of the coupled equations, it is \
often preferable to generalize the Crank-Nicolson scheme to multiple \
dimensions in a slightly different way.   The idea is to split the spatial \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " into its constituent operators ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  ", and also split the time step into two half steps, each of size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  ".  We treat  the ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  "part of the operator implicitly in the first half step, and  the ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " part implicitly in the next half step. [Note: this type of operator \
splitting is called the ",
  StyleBox["alternating-direction implicit method",
    FontSlant->"Italic"],
  ". Another type of operator splitting is discussed in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  " in relation to a nonlinear convection/diffusion equation: see Eqs. ",
  ButtonBox["(7.2.29)",
    ButtonData:>{"Chapter7.nb", "(7.2.29)"},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(7.2.31)",
    ButtonData:>{"Chapter7.nb", "(7.2.31)"},
    ButtonStyle->"Hyperlink"],
  ". For more on operator splitting, see ",
  ButtonBox["Press et al. (1992)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] The equations used for each half step are"
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%\(n - 1/2\)\), "=", " ", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1\)\), "+", " ", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], 
              " ", \(S\_\(j\ k\)\%\(n - 1\)\)}], "+", 
            " ", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            " ", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1\)\)}]}], 
        TraditionalForm]]],
  ",\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(j\ k\)\%n\), "=", 
          RowBox[{\(T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            RowBox[{\(1\/2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", \(S\_\(j\ k\)\%n\)}], 
            "+", \(\(D\_\(\(x\)\(\ \)\)\) T\_\(j\ k\)\%\(n - 1/2\)\), "+", 
            " ", \(\(D\_\(\(y\)\(\ \)\)\) T\_\(j\ k\)\%n\)}]}], 
        TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.31)"],

Cell[TextData[{
  "In the first half step, the source and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " are treated with forward time differencing as in Euler's method, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " is treated with a backward-difference; but in the next half step this is \
reversed and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]x\^2\)\)\)]],
  " is treated with a forward-difference derivative, while the source and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]y\^2\)\)\)]],
  " are treated with a backward-difference derivative. As a result of this \
time symmetry, the method is still second-order accurate in time (and in \
space as well, due to the centered-difference form for ",
  Cell[BoxData[
      \(TraditionalForm\`D\_\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D\_y\)]],
  "). Also, one can show that it is still absolutely stable. Now, however,  \
we need only solve a one-dimensional set of coupled equations in each half \
step.  In the first half step we must solve",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(M\_x - 1\)\)\)]],
  " coupled equations for each value of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and in the second half step we solve ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y - 1\)]],
  " equations for each value of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ". All in all, we still have to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\)\ \((M\_y - 1)\)\)]],
  " equations,  but they are only coupled in batches of ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x - 1\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y - 1\)]],
  " equations at a time, and this simplifies the task enormously.  The method \
is implemented below. "
}], "Text"],

Cell[BoxData[
    \(L\_x = 1; L\_y = 2; M\_x = 10; 
    M\_y\  = 10; \[CapitalDelta]t = 0.05; \[CapitalDelta]x = 
      L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y\ ; \[Chi]\  = \ 1/4;\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.78"],

Cell[TextData[{
  "\tWe now must choose initial and boundary conditions on all four sides of \
the rectangle. For simplicity, we take homogeneous Dirichlet conditions,  no \
source term, and an initial condition corresponding to the slowest-varying \
eigenmode of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ initial\ condition\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(T0[x_, y_]\  = \ Sin[Pi\ y/L\_y]\ Sin[Pi\ x/L\_x]\  // N;\), 
        "\[IndentingNewLine]", "\n", 
        StyleBox[\( (*\ boundary\ conditions\ on\ the\ four\ sides\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(T[j_, 0, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[0, k_, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[j_, M\_y, n_]\  := \ 0;\), 
        "\[IndentingNewLine]", \(T[M\_x, k_, n_]\  := \ 0;\), "\n", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ source\ term\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(S[j_, k_, n_]\  = \ 0;\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.79"],

Cell["This initial condition should decay away according to", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \(\[ExponentialE]\^\(\(-\[Chi]\)\ t\ \((\ \[Pi]\^2/\ 
                      L\_x\^2 + \ \[Pi]\^2/\ L\_y\^2)\)\)\) 
          sin\ \((\[Pi]\ x/L\_x)\) sin\ \((\[Pi]\ y/L\_y)\)\)]],
  "."
}], "NE2",
  CellTags->"(6.2.32)"],

Cell[TextData[{
  "Now we solve Eq. ",
  ButtonBox["(6.2.31)",
    ButtonData:>"(6.2.31)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(j\ k\)\%n\)]],
  ". Just as in the implementation of the 1D Crank-Nicolson method, we define \
 ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["sol",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  StyleBox[" ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as a  list of substitutions for the solution at ",
  "time step",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n\)\)\)]],
  StyleBox[". ",
    FontWeight->"Bold"],
  "The initial condition is given by the following list:"
}], "Text"],

Cell[BoxData[
    \(\(sol[0]\  = \ 
        Flatten[Table[
            T[j, k, 0] \[Rule] \ 
              T0[j\ \[CapitalDelta]x, k\ \[CapitalDelta]y], {j, 1, 
              M\_x - 1}, {k, 1, M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.80"],

Cell["\<\
Also, we define the second-derivative difference functions to \
simplify the notation:\
\>", "Text"],

Cell[BoxData[{
    \(\(Dx[j_, k_, 
          n_]\  := \(\(\[Chi]\ \[CapitalDelta]t\)\/\(2  \[CapitalDelta]x\^2\)\
\) \((\ T[j + 1, k, n]\  - 2\ T[j, k, n]\  + \ T[j - 1, k, n])\);\)\), "\n", 
    \(\(Dy[j_, k_, 
          n_]\  := \ \(\(\[Chi]\ \[CapitalDelta]t\)\/\(2  \[CapitalDelta]y\^2\
\)\) \((T[j, k + 1, n]\  - 2\ T[j, k, n]\  + \ 
              T[j, k - 1, n])\);\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.81"],

Cell["Then we have", "Text"],

Cell[BoxData[
    RowBox[{\(sol[n_]\), " ", ":=", " ", 
      RowBox[{\(sol[n]\), " ", "=", " ", "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            StyleBox[\( (*define\ the\ variables\ for\ the\ first\ half - 
                  step\ *) \),
              FontColor->RGBColor[1, 0, 0]], " ", 
            
            RowBox[{\(vars1[k_]\  := \ 
                Table[T[j, k, n - 1/2], {j, 1, M\_x - 1}]\), ";", 
              
              StyleBox[\( (*define\ the\ equations\ for\ the\ first\ half - 
                    step\ in\ Eqs . \ \((6  .2  .31)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{\(eqns1[k_]\), " ", ":=", " ", 
                RowBox[{"Flatten", "[", 
                  
                  RowBox[{\(Table[
                      T[j, k, n - 1/2] - 
                          T[j, k, 
                            n - 1]\  == \(1\/2\) \[CapitalDelta]t\ S[j, k, 
                              n - 1] + Dx[j, k, n - 1/2]\  + 
                          Dy[j, k, n - 1], {j, 1, M\_x - 1}]\), " ", 
                    StyleBox["/.",
                      FontColor->RGBColor[0, 0, 1]], 
                    StyleBox[\(sol[n - 1]\),
                      FontColor->RGBColor[0, 0, 1]]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(sol1\  = \ 
                Flatten[Table[Solve[eqns1[k], vars1[k]], {k, 1, M\_y - 1}]]\),
               ";", 
              
              StyleBox[\( (*define\ the\ variables\ for\ the\ second\ half - 
                    step\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              " ", \(vars2[j_]\  := \ Table[T[j, k, n], {k, 1, M\_y - 1}]\), 
              ";", " ", "\[IndentingNewLine]", 
              
              StyleBox[\( (*define\ the\ equations\ for\ the\ second\ half - 
                    step\ in\ Eqs . \ \((6  .2  .31)\), 
                  substituting\ for\ the\ values\ of\ T\ determined\ at\ the\ \
last\ time\ step\ \ and\ the\ first\ half - step*) \),
                FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
              RowBox[{\(eqns2[j_]\), " ", ":=", 
                RowBox[{"Flatten", "[", 
                  
                  RowBox[{\(Table[
                      T[j, k, n] - 
                          T[j, k, 
                            n - 1/2]\  == \(1\/2\) \[CapitalDelta]t\ S[j, k, 
                              n] + Dx[j, k, n - 1/2]\  + \ Dy[j, k, n], {k, 
                        1, M\_y - 1}]\), "/.", 
                    RowBox[{"Join", "[", 
                      RowBox[{
                        StyleBox[\(sol[n - 1]\),
                          FontColor->RGBColor[0, 0, 1]], ",", "sol1"}], 
                      "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              StyleBox[
                RowBox[{"(*", 
                  RowBox[{
                  "solve", " ", "the", " ", "equations", " ", Cell[""]}], 
                  "*)"}],
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(Flatten[
                Table[Solve[eqns2[j], vars2[j]], {j, 1, M\_x - 1}]]\)}]}], 
          "]"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.82"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.84",
    ButtonData:>"Cell 6.84",
    ButtonStyle->"Hyperlink"],
  " we display the result, after creating an interpolation function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Tsol", "[", 
          RowBox[{
            StyleBox["x",
              FontSlant->"Plain"], ",", 
            StyleBox["y",
              FontSlant->"Plain"], ",", 
            StyleBox["t",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tsol\  = \ 
      Interpolation[
        Flatten[Table[
            Table[{j\ \[CapitalDelta]x, k\ \ \[CapitalDelta]y, 
                  n\ \[CapitalDelta]t, T[j, k, n]}, {j, 0, M\_x}, {k, 0, 
                  M\_y}] /. sol[n], {n, 0, 20}], 2]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.83"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 2.`}, {0.`, 1.`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot3D[Tsol[x, y, t], {x, 0, L\_x}, {y, 0, L\_y}, 
          PlotRange \[Rule] {0, 1}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,y,t],t=\>" <> ToString[t] <> "\<\n\>", 
          BoxRatios \[Rule] {L\_x, L\_y, 1}], {t, 0, 1,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.84"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -38 0 ]
[.5 1.12503 38 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.24 .545 .927 r
.52593 .68772 .5561 .7194 .58394 .7109 .55408 .69725 Metetra
0 .458 .792 r
.55408 .69725 .58394 .7109 .61197 .70234 .58262 .70596 Metetra
.378 0 0 r
.58262 .70596 .61197 .70234 .64019 .69372 .61155 .713 Metetra
.457 0 0 r
.61155 .713 .64019 .69372 .66861 .68504 .64082 .7175 Metetra
.459 .002 .077 r
.64082 .7175 .66861 .68504 .69723 .6763 .67038 .71871 Metetra
.436 .015 .14 r
.67038 .71871 .69723 .6763 .72605 .6675 .70014 .7161 Metetra
.398 0 .159 r
.70014 .7161 .72605 .6675 .75507 .65863 .73004 .7093 Metetra
.341 0 .144 r
.73004 .7093 .75507 .65863 .7843 .6497 .75999 .69812 Metetra
.257 0 .091 r
.75999 .69812 .7843 .6497 .81374 .64071 .78991 .6827 Metetra
.118 0 0 r
.78991 .6827 .81374 .64071 .84339 .63166 .81976 .66337 Metetra
.81976 .66337 .84339 .63166 .87325 .62254 .84949 .64064 Metetra
.514 .856 .59 r
.84949 .64064 .87325 .62254 .90333 .61335 .87908 .61522 Metetra
.813 .999 .843 r
.87908 .61522 .90333 .61335 .93362 .6041 .90855 .58797 Metetra
.858 .901 .863 r
.90855 .58797 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
0 .052 .562 r
.49498 .6552 .52593 .68772 .55408 .69725 .5232 .68217 Metetra
.644 .091 0 r
.5232 .68217 .55408 .69725 .58262 .70596 .55205 .70784 Metetra
.684 .154 0 r
.55205 .70784 .58262 .70596 .61155 .713 .58149 .73046 Metetra
.648 .158 .075 r
.58149 .73046 .61155 .713 .64082 .7175 .61146 .74822 Metetra
.586 .129 .136 r
.61146 .74822 .64082 .7175 .67038 .71871 .64184 .75956 Metetra
.509 .077 .155 r
.64184 .75956 .67038 .71871 .70014 .7161 .67249 .76329 Metetra
.412 0 .14 r
.67249 .76329 .70014 .7161 .73004 .7093 .70326 .75861 Metetra
.28 0 .087 r
.70326 .75861 .73004 .7093 .75999 .69812 .73396 .74512 Metetra
.089 0 0 r
.73396 .74512 .75999 .69812 .78991 .6827 .76446 .72311 Metetra
.76446 .72311 .78991 .6827 .81976 .66337 .79462 .69332 Metetra
.564 .825 .463 r
.79462 .69332 .81976 .66337 .84949 .64064 .82436 .65685 Metetra
.849 .976 .673 r
.82436 .65685 .84949 .64064 .87908 .61522 .85365 .61524 Metetra
.941 .952 .752 r
.85365 .61524 .87908 .61522 .90855 .58797 .88252 .5703 Metetra
.928 .868 .759 r
.88252 .5703 .90855 .58797 .93794 .55978 .91103 .52381 Metetra
.756 .279 0 r
.4632 .62183 .49498 .6552 .5232 .68217 .49129 .66476 Metetra
.809 .322 0 r
.49129 .66476 .5232 .68217 .55205 .70784 .52021 .70617 Metetra
.796 .316 .08 r
.52021 .70617 .55205 .70784 .58149 .73046 .54996 .74345 Metetra
.746 .277 .134 r
.54996 .74345 .58149 .73046 .61146 .74822 .58043 .77384 Metetra
.67 .21 .152 r
.58043 .77384 .61146 .74822 .64184 .75956 .61149 .7949 Metetra
.563 .112 .137 r
.61149 .7949 .64184 .75956 .67249 .76329 .64294 .80476 Metetra
.409 0 .082 r
.64294 .80476 .67249 .76329 .70326 .75861 .67452 .80212 Metetra
.171 0 0 r
.67452 .80212 .70326 .75861 .73396 .74512 .706 .78636 Metetra
.706 .78636 .73396 .74512 .76446 .72311 .73714 .75796 Metetra
.574 .82 .443 r
.73714 .75796 .76446 .72311 .79462 .69332 .76775 .71806 Metetra
.851 .952 .602 r
.76775 .71806 .79462 .69332 .82436 .65685 .79769 .66846 Metetra
.957 .948 .67 r
.79769 .66846 .82436 .65685 .85365 .61524 .82691 .61157 Metetra
.971 .896 .691 r
.82691 .61157 .85365 .61524 .88252 .5703 .85544 .55014 Metetra
.95 .836 .695 r
.85544 .55014 .88252 .5703 .91103 .52381 .88337 .48685 Metetra
.858 .415 .008 r
.43058 .58756 .4632 .62183 .49129 .66476 .45834 .64407 Metetra
.867 .42 .088 r
.45834 .64407 .49129 .66476 .52021 .70617 .48713 .69906 Metetra
.847 .396 .133 r
.48713 .69906 .52021 .70617 .54996 .74345 .51695 .74913 Metetra
.804 .346 .149 r
.51695 .74913 .54996 .74345 .58043 .77384 .54773 .79065 Metetra
.73 .261 .134 r
.54773 .79065 .58043 .77384 .61149 .7949 .57929 .82035 Metetra
.605 .121 .079 r
.57929 .82035 .61149 .7949 .64294 .80476 .61139 .83567 Metetra
.376 0 0 r
.61139 .83567 .64294 .80476 .67452 .80212 .64373 .83484 Metetra
.64373 .83484 .67452 .80212 .706 .78636 .67597 .81701 Metetra
.546 .839 .51 r
.67597 .81701 .706 .78636 .73714 .75796 .70781 .78282 Metetra
.852 .962 .627 r
.70781 .78282 .73714 .75796 .76775 .71806 .73899 .73386 Metetra
.958 .945 .654 r
.73899 .73386 .76775 .71806 .79769 .66846 .76932 .6726 Metetra
.981 .899 .657 r
.76932 .6726 .79769 .66846 .82691 .61157 .79872 .60227 Metetra
.975 .853 .656 r
.79872 .60227 .82691 .61157 .85544 .55014 .82722 .52653 Metetra
.957 .812 .658 r
.82722 .52653 .85544 .55014 .88337 .48685 .85493 .44884 Metetra
.894 .475 .099 r
.39706 .55236 .43058 .58756 .45834 .64407 .42436 .6193 Metetra
.892 .467 .136 r
.42436 .6193 .45834 .64407 .48713 .69906 .45285 .68481 Metetra
.874 .439 .148 r
.45285 .68481 .48713 .69906 .51695 .74913 .48257 .7449 Metetra
.839 .385 .133 r
.48257 .7449 .51695 .74913 .54773 .79065 .51345 .79522 Metetra
.771 .287 .081 r
.51345 .79522 .54773 .79065 .57929 .82035 .54533 .83178 Metetra
.627 .098 0 r
.54533 .83178 .57929 .82035 .61139 .83567 .57793 .85145 Metetra
.272 0 0 r
.57793 .85145 .61139 .83567 .64373 .83484 .6109 .85202 Metetra
.408 .829 .658 r
.6109 .85202 .64373 .83484 .67597 .81701 .64386 .83244 Metetra
.837 .993 .742 r
.64386 .83244 .67597 .81701 .70781 .78282 .67643 .79352 Metetra
.953 .952 .704 r
.67643 .79352 .70781 .78282 .73899 .73386 .70829 .73723 Metetra
.978 .898 .669 r
.70829 .73723 .73899 .73386 .76932 .6726 .7392 .66661 Metetra
.979 .855 .648 r
.7392 .66661 .76932 .6726 .79872 .60227 .76904 .58561 Metetra
.971 .822 .639 r
.76904 .58561 .79872 .60227 .82722 .52653 .79783 .49861 Metetra
.958 .794 .637 r
.79783 .49861 .82722 .52653 .85493 .44884 .82567 .40974 Metetra
.908 .501 .141 r
.36263 .5162 .39706 .55236 .42436 .6193 .38941 .58978 Metetra
.903 .489 .15 r
.38941 .58978 .42436 .6193 .45285 .68481 .41749 .66208 Metetra
.887 .459 .136 r
.41749 .66208 .45285 .68481 .48257 .7449 .44696 .72868 Metetra
.855 .401 .089 r
.44696 .72868 .48257 .7449 .51345 .79522 .47778 .78474 Metetra
.785 .285 0 r
.47778 .78474 .51345 .79522 .54533 .83178 .50979 .82579 Metetra
.594 .02 0 r
.50979 .82579 .54533 .83178 .57793 .85145 .54273 .84826 Metetra
.003 .578 .746 r
.54273 .84826 .57793 .85145 .6109 .85202 .57621 .84967 Metetra
.718 .974 .926 r
.57621 .84967 .6109 .85202 .64386 .83244 .60981 .82881 Metetra
.914 .946 .807 r
.60981 .82881 .64386 .83244 .67643 .79352 .6431 .78661 Metetra
.957 .889 .722 r
.6431 .78661 .67643 .79352 .70829 .73723 .67571 .72531 Metetra
.966 .847 .673 r
.67571 .72531 .70829 .73723 .7392 .66661 .70735 .64835 Metetra
.966 .819 .645 r
.70735 .64835 .7392 .66661 .76904 .58561 .73786 .5602 Metetra
.962 .798 .631 r
.73786 .5602 .76904 .58561 .79783 .49861 .76723 .46573 Metetra
.956 .781 .626 r
.76723 .46573 .79783 .49861 .82567 .40974 .79557 .36951 Metetra
.912 .509 .154 r
.32723 .47902 .36263 .5162 .38941 .58978 .35353 .55506 Metetra
.905 .495 .14 r
.35353 .55506 .38941 .58978 .41749 .66208 .3812 .62989 Metetra
.888 .461 .098 r
.3812 .62989 .41749 .66208 .44696 .72868 .41034 .69892 Metetra
.848 .391 .009 r
.41034 .69892 .44696 .72868 .47778 .78474 .44099 .75712 Metetra
.744 .238 0 r
.44099 .75712 .47778 .78474 .50979 .82579 .473 .79982 Metetra
.41 0 0 r
.473 .79982 .50979 .82579 .54273 .84826 .50611 .82326 Metetra
.34 .705 .983 r
.50611 .82326 .54273 .84826 .57621 .84967 .53995 .82482 Metetra
.773 .862 .916 r
.53995 .82482 .57621 .84967 .60981 .82881 .57409 .80325 Metetra
.89 .847 .795 r
.57409 .80325 .60981 .82881 .6431 .78661 .60805 .7595 Metetra
.928 .821 .72 r
.60805 .7595 .6431 .78661 .67571 .72531 .64142 .69597 Metetra
.943 .801 .675 r
.64142 .69597 .67571 .72531 .70735 .64835 .67389 .61625 Metetra
.949 .788 .647 r
.67389 .61625 .70735 .64835 .73786 .5602 .70525 .52503 Metetra
.951 .778 .632 r
.70525 .52503 .73786 .5602 .76723 .46573 .73545 .4274 Metetra
.951 .771 .624 r
.73545 .4274 .76723 .46573 .79557 .36951 .76458 .32809 Metetra
.908 .501 .141 r
.29083 .44079 .32723 .47902 .35353 .55506 .31679 .51483 Metetra
.898 .483 .102 r
.31679 .51483 .35353 .55506 .3812 .62989 .34412 .58763 Metetra
.869 .439 .025 r
.34412 .58763 .3812 .62989 .41034 .69892 .37298 .65472 Metetra
.796 .342 0 r
.37298 .65472 .41034 .69892 .44099 .75712 .40341 .71117 Metetra
.587 .12 0 r
.40341 .71117 .44099 .75712 .473 .79982 .43533 .75242 Metetra
0 .303 .795 r
.43533 .75242 .473 .79982 .50611 .82326 .46849 .7748 Metetra
.486 .639 .923 r
.46849 .7748 .50611 .82326 .53995 .82482 .50255 .77577 Metetra
.743 .739 .848 r
.50255 .77577 .53995 .82482 .57409 .80325 .53707 .7541 Metetra
.843 .758 .769 r
.53707 .7541 .57409 .80325 .60805 .7595 .57159 .71073 Metetra
.889 .761 .714 r
.57159 .71073 .60805 .7595 .64142 .69597 .60569 .64799 Metetra
.914 .76 .677 r
.60569 .64799 .64142 .69597 .67389 .61625 .639 .56939 Metetra
.928 .76 .653 r
.639 .56939 .67389 .61625 .70525 .52503 .6713 .4795 Metetra
.937 .761 .638 r
.6713 .4795 .70525 .52503 .73545 .4274 .70251 .3833 Metetra
.943 .764 .63 r
.70251 .3833 .73545 .4274 .76458 .32809 .73265 .28543 Metetra
.894 .475 .099 r
.25338 .40146 .29083 .44079 .31679 .51483 .27925 .46913 Metetra
.872 .447 .027 r
.27925 .46913 .31679 .51483 .34412 .58763 .30644 .53546 Metetra
.812 .379 0 r
.30644 .53546 .34412 .58763 .37298 .65472 .33514 .59633 Metetra
.654 .227 0 r
.33514 .59633 .37298 .65472 .40341 .71117 .36541 .64723 Metetra
0 .061 .622 r
.36541 .64723 .40341 .71117 .43533 .75242 .39721 .68401 Metetra
.194 .386 .825 r
.39721 .68401 .43533 .75242 .46849 .7748 .43033 .70337 Metetra
.534 .574 .841 r
.43033 .70337 .46849 .7748 .50255 .77577 .46446 .70302 Metetra
.708 .654 .794 r
.46446 .70302 .50255 .77577 .53707 .7541 .49922 .68186 Metetra
.797 .689 .746 r
.49922 .68186 .53707 .7541 .57159 .71073 .53415 .64073 Metetra
.848 .709 .709 r
.53415 .64073 .57159 .71073 .60569 .64799 .56883 .58172 Metetra
.881 .723 .682 r
.56883 .58172 .60569 .64799 .639 .56939 .60293 .50802 Metetra
.904 .734 .662 r
.60293 .50802 .639 .56939 .6713 .4795 .63618 .42375 Metetra
.92 .745 .649 r
.63618 .42375 .6713 .4795 .70251 .3833 .66845 .33349 Metetra
.933 .757 .642 r
.66845 .33349 .70251 .3833 .73265 .28543 .69976 .24147 Metetra
.858 .415 .008 r
.21484 .36098 .25338 .40146 .27925 .46913 .24095 .4182 Metetra
.803 .363 0 r
.24095 .4182 .27925 .46913 .30644 .53546 .2683 .47396 Metetra
.663 .245 0 r
.2683 .47396 .30644 .53546 .33514 .59633 .29705 .52471 Metetra
0 0 .549 r
.29705 .52471 .33514 .59633 .36541 .64723 .32731 .56665 Metetra
.025 .232 .737 r
.32731 .56665 .36541 .64723 .39721 .68401 .35903 .59628 Metetra
.352 .424 .796 r
.35903 .59628 .39721 .68401 .43033 .70337 .39207 .61089 Metetra
.556 .533 .785 r
.39207 .61089 .43033 .70337 .46446 .70302 .42616 .60859 Metetra
.678 .596 .756 r
.42616 .60859 .46446 .70302 .49922 .68186 .46098 .58846 Metetra
.754 .635 .729 r
.46098 .58846 .49922 .68186 .53415 .64073 .49612 .55121 Metetra
.806 .664 .706 r
.49612 .55121 .53415 .64073 .56883 .58172 .53123 .49856 Metetra
.844 .687 .688 r
.53123 .49856 .56883 .58172 .60293 .50802 .56595 .43313 Metetra
.874 .709 .674 r
.56595 .43313 .60293 .50802 .63618 .42375 .60004 .35839 Metetra
.897 .729 .665 r
.60004 .35839 .63618 .42375 .66845 .33349 .63336 .27818 Metetra
.917 .751 .661 r
.63336 .27818 .66845 .33349 .69976 .24147 .66586 .19616 Metetra
.756 .279 0 r
.17516 .3193 .21484 .36098 .24095 .4182 .20195 .36248 Metetra
.611 .172 0 r
.20195 .36248 .24095 .4182 .2683 .47396 .22981 .40416 Metetra
0 .006 .579 r
.22981 .40416 .2683 .47396 .29705 .52471 .25892 .44156 Metetra
0 .202 .718 r
.25892 .44156 .29705 .52471 .32731 .56665 .28936 .47175 Metetra
.266 .351 .765 r
.28936 .47175 .32731 .56665 .35903 .59628 .32111 .49212 Metetra
.448 .446 .764 r
.32111 .49212 .35903 .59628 .39207 .61089 .35407 .50062 Metetra
.569 .509 .748 r
.35407 .50062 .39207 .61089 .42616 .60859 .38804 .49586 Metetra
.653 .555 .731 r
.38804 .49586 .42616 .60859 .46098 .58846 .42276 .47718 Metetra
.714 .591 .716 r
.42276 .47718 .46098 .58846 .49612 .55121 .45792 .4451 Metetra
.762 .622 .704 r
.45792 .4451 .49612 .55121 .53123 .49856 .4932 .40087 Metetra
.802 .651 .695 r
.4932 .40087 .53123 .49856 .56595 .43313 .52832 .34647 Metetra
.836 .681 .69 r
.52832 .34647 .56595 .43313 .60004 .35839 .56306 .28447 Metetra
.866 .711 .688 r
.56306 .28447 .60004 .35839 .63336 .27818 .59727 .21784 Metetra
.893 .744 .689 r
.59727 .21784 .63336 .27818 .66586 .19616 .63089 .14942 Metetra
0 .052 .562 r
.13429 .27638 .17516 .3193 .20195 .36248 .16223 .30264 Metetra
0 .191 .722 r
.16223 .30264 .20195 .36248 .22981 .40416 .19105 .32756 Metetra
.108 .303 .778 r
.19105 .32756 .22981 .40416 .25892 .44156 .22085 .34925 Metetra
.298 .377 .776 r
.22085 .34925 .25892 .44156 .28936 .47175 .25173 .36579 Metetra
.426 .427 .758 r
.25173 .36579 .28936 .47175 .32111 .49212 .28366 .37545 Metetra
.514 .465 .739 r
.28366 .37545 .32111 .49212 .35407 .50062 .3166 .37696 Metetra
.58 .496 .724 r
.3166 .37696 .35407 .50062 .38804 .49586 .35039 .36945 Metetra
.633 .525 .714 r
.35039 .36945 .38804 .49586 .42276 .47718 .38487 .35248 Metetra
.677 .553 .708 r
.38487 .35248 .42276 .47718 .45792 .4451 .41982 .32639 Metetra
.716 .582 .705 r
.41982 .32639 .45792 .4451 .4932 .40087 .45502 .29197 Metetra
.752 .614 .705 r
.45502 .29197 .4932 .40087 .52832 .34647 .49027 .25046 Metetra
.787 .648 .709 r
.49027 .25046 .52832 .34647 .56306 .28447 .52539 .20354 Metetra
.82 .687 .717 r
.52539 .20354 .56306 .28447 .59727 .21784 .56026 .15315 Metetra
.854 .733 .729 r
.56026 .15315 .59727 .21784 .63089 .14942 .59481 .1012 Metetra
.24 .545 .927 r
.09217 .23214 .13429 .27638 .16223 .30264 .12177 .23951 Metetra
.371 .521 .876 r
.12177 .23951 .16223 .30264 .19105 .32756 .15198 .24598 Metetra
.447 .497 .818 r
.15198 .24598 .19105 .32756 .22085 .34925 .18285 .25062 Metetra
.497 .484 .773 r
.18285 .25062 .22085 .34925 .25173 .36579 .21444 .25249 Metetra
.534 .481 .743 r
.21444 .25249 .25173 .36579 .28366 .37545 .24674 .2508 Metetra
.564 .483 .722 r
.24674 .2508 .28366 .37545 .3166 .37696 .27972 .24496 Metetra
.59 .491 .71 r
.27972 .24496 .3166 .37696 .35039 .36945 .31332 .23455 Metetra
.615 .504 .704 r
.31332 .23455 .35039 .36945 .38487 .35248 .34745 .2194 Metetra
.64 .521 .703 r
.34745 .2194 .38487 .35248 .41982 .32639 .38201 .19965 Metetra
.664 .544 .707 r
.38201 .19965 .41982 .32639 .45502 .29197 .41688 .17566 Metetra
.69 .571 .716 r
.41688 .17566 .45502 .29197 .49027 .25046 .45195 .148 Metetra
.719 .607 .731 r
.45195 .148 .49027 .25046 .52539 .20354 .48713 .11745 Metetra
.75 .652 .752 r
.48713 .11745 .52539 .20354 .56026 .15315 .52235 .08494 Metetra
.784 .709 .781 r
.52235 .08494 .56026 .15315 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12177 .23951 .08051 .17394 Metetra
.651 .653 .839 r
.08051 .17394 .12177 .23951 .15198 .24598 .11254 .16124 Metetra
.635 .592 .788 r
.11254 .16124 .15198 .24598 .18285 .25062 .14483 .14843 Metetra
.622 .55 .752 r
.14483 .14843 .18285 .25062 .21444 .25249 .1774 .13551 Metetra
.612 .521 .728 r
.1774 .13551 .21444 .25249 .24674 .2508 .21025 .12249 Metetra
.605 .503 .712 r
.21025 .12249 .24674 .2508 .27972 .24496 .24339 .10934 Metetra
.602 .493 .703 r
.24339 .10934 .27972 .24496 .31332 .23455 .27681 .09609 Metetra
.6 .49 .7 r
.27681 .09609 .31332 .23455 .34745 .2194 .31052 .08272 Metetra
.602 .493 .703 r
.31052 .08272 .34745 .2194 .38201 .19965 .34452 .06923 Metetra
.605 .503 .712 r
.34452 .06923 .38201 .19965 .41688 .17566 .37882 .05563 Metetra
.612 .521 .728 r
.37882 .05563 .41688 .17566 .45195 .148 .41342 .04191 Metetra
.622 .55 .752 r
.41342 .04191 .45195 .148 .48713 .11745 .44833 .02806 Metetra
.635 .592 .788 r
.44833 .02806 .48713 .11745 .52235 .08494 .48355 .01409 Metetra
.651 .653 .839 r
.48355 .01409 .52235 .08494 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onVYmKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojJW
eP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nVYmH00ol0003oYZOFo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nVYmH00ol0003oYZOFojJWeP03ojJWeP04o`000?nVYmKoYZOFo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojJWeP04o`000?nVYmKoYZOFo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onRUlWo0000ojJWeP09
ojJWeP05o`000?nVYmKoYZOFojJWe_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003oj:GbOl0003oXYO900;oXYO9
00?o0000ojJWe_nVYmH01onVYmH00ol0003oYZOFojJWeP02ojJWeP03o`000?oooooooooo09Sooooo
002/ooooo`Co00001onRUlT00ol0003oYZOFojJWeP07ojJWeP03o`000?nVYmKoYZOF00?oYZOF00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;oj:Gb@03o`000?nVYmKoYZOF00KoYZOF00?o0000
ojJWe_nVYmH00onVYmH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coXYO900?o0000ojJW
e_nVYmH01OnVYmH00ol0003oYZOFojJWeP04ojJWeP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnOS<000ol0003oXYO9oj:Gb@09oj:Gb@03o`000?nVYmKoYZOF00GoYZOF00?o0000ojJWe_nV
YmH01OnVYmH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000SoWhc000?o0000oj:G
bOnRUlT02_nRUlT00ol0003oYZOFojJWeP04ojJWeP03o`000?nVYmKoYZOF00KoYZOF00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onOS<3o0000oin<`009oin<`003o`000?nRUlWo
XYO900WoXYO900?o0000ojJWe_nVYmH01?nVYmH00ol0003oYZOFojJWeP06ojJWeP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnLQK[o0000oin<`?nOS<3o000000WoWhc000?o0000oj:GbOnRUlT0
2_nRUlT00ol0003oYZOFojJWeP03ojJWeP03o`000?nVYmKoYZOF00OoYZOF00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoW8Fj00?o0000oin<`?nOS<002OnOS<000ol0003oXYO9oj:Gb@0:oj:Gb@03
o`000?nVYmKoYZOF00?oYZOF00?o0000ojJWe_nVYmH02?nVYmH00ol0003oooooooooo`2Booooo`00
KOooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eoooo
o`Co000000?oW8Fjo`000?nLQKX01?nLQKX00ol0003oWhc0oin<`00:oin<`003o`000?nRUlWoXYO9
00[oXYO900?o0000ojJWe_nVYmH00_nVYmH00ol0003oYZOFojJWeP08ojJWeP;o0000Toooool006go
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000:oib5
^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnRUlT02onRUlT01Ol0003oYZOFojJWe_nVYmKo
000000WoYZOF00?o0000olReaol00000Toooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01?ooooo1?l0000<oib5^P03o`000?nOS<3oWhc000[oWhc000?o0000
oj:GbOnRUlT02_nRUlT01Ol0003oYZOFojJWe_nVYmKo000000SoYZOF00Go0000olReaoo8]LOob;G7
o`00002Booooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@3oooool2o`0000;oVX2f0_l0000<oib5^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnR
UlT02onRUlT01?l0003oYZOFojJWe_l00007ojJWeP03o`000?o8]LOob;G700?ob;G700?o0000oooo
ooooool0Soooool008kooooo0ol00006oiZ0]P03o`000?nLQK[oW8Fj00WoW8Fj00?o0000oin<`?nO
S<002onOS<000ol0003oXYO9oj:Gb@0:oj:Gb@04o`000?nVYmKoYZOFo`0000KoYZOF00?o0000olRe
aoo8]LL01Oo8]LL00ol0003oooooooooo`2>ooooo`00S?ooool3o`0000SoVX2f00?o0000oib5^_nL
QKX02_nLQKX00ol0003oWhc0oin<`00:oin<`003o`000?nRUlWoXYO900_oXYO900?o0000ojJWe_l0
00001OnVYmH00ol0003ob;G7olRea`06olRea`;o0000Soooool008Wooooo1?l000000onJP;Ko0000
oiZ0]P07oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9
oj:Gb@0:oj:Gb@03o`000?nVYmKo000000CoYZOF00?o0000olReaoo8]LL02?o8]LL00ol0003ooooo
ooooo`2=ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool08?ooool4o`000003oiYn/ol0003oVX2f00[oVX2f00?o0000oib5^_nLQKX0
2OnLQKX00ol0003oWhc0oin<`00;oin<`003o`000?nRUlWoXYO900_oXYO90_l00003ojJWeP03o`00
0?o8]LOob;G700[ob;G700?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001?nJO[<00ol0003oVX2f
oiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002_nOS<000ol0003oXYO9
oj:Gb@0<oj:Gb@04o`000?nVYmKoYZOFo`0000kob;G700?o0000ooooooooool0Roooool0053ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003oiYn/ol0003oVWjc00Go
VWjc00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3oWhc000_o
Whc000?o0000oj:GbOnRUlT02onRUlT00ol0003oYZOFo`00000?olRea`;o0000S?ooool0053ooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001_ooooo0ol00005oiYn
/`03o`000?nJO[?oVWjc00?oVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:oib5
^P03o`000?nOS<3oWhc000[oWhc000?o0000oj:GbOnRUlT02onRUlT2o`00017ob;G70_l0002;oooo
o`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00006Oooool3
o`000003oiUm/ol0003oVWjc00[oVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:
oib5^P03o`000?nOS<3oWhc000_oWhc000?o0000oj:GbOnRUlT02_nRUlT2o`0001;ob;G700?o0000
ooooooooool0ROooool0053ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000001Kooooo0ol00002oiUm/`03o`000?nIOK?o000000coVWjc00?o0000oiZ0]_nJP;H02?nJP;H0
0ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3oWhc000_oWhc000?o0000oj:GbOnRUlT02OnRUlT2
o`000003oknV`?l0003ob;G7017ob;G700?o0000ooooooooool0R?ooool0053ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo0ol00007oiUm/`03o`000?nJO[?o
VWjc00WoVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0:oib5^P03o`000?nOS<3o
Whc000_oWhc000?o0000oj:GbOnRUlT01onRUlT01Ol0003o_jK0o`000?noY/3o000001;ob;G70_l0
0029ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool04?oo
ool3o`0000[oVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nL
QK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9oj:Gb@06oj:Gb@04o`000?no
Y/3o_jK0o`0000;o_jK000?o0000olReaoo8]LL04?o8]LL2o`0008Sooooo001cooooo`?o000000?o
VWjco`000?l000002OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00WoVX2f00?o
0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00<oin<`003o`000?nRUlWoXYO900CoXYO900Go
0000oknV`?noY/3o_jK0o`000003oknV`003o`000?o8]LOob;G7013ob;G70_l00027ooooo`00L?oo
ool3o`0000CoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJ
P;KoVX2f00WoVX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00;oin<`003o`000?nR
UlWoXYO900?oXYO900?o0000oknV`?noY/000_noY/001Ol0003o_jK0oknV`?noY/3o000001?ob;G7
00?o0000ooooooooool0QOooool006kooooo0ol00007oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o
0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o
0000oin<`?nOS<002onOS<000ol0003oXYO9oj:Gb@02oj:Gb@03o`000?noY/3o_jK000?o_jK000?o
0000oknV`?noY/000_noY/000ol0003ob;G7olRea`0?olRea`?o0000Q_ooool003?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0002?ooooo0ol00002oiYn/`03o`000?nJ
O[?oVWjc00GoVWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJ
P;KoVX2f00WoVX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0oin<`00<oin<`004o`000?nR
UlWoXYO9o`0000Ko_jK000?o0000oknV`?noY/000_noY/000ol0003ob;G7olRea`0>olRea`03o`00
0?oJ^k[of[^j00;o0000QOooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol000000onJP;Ko0000oiYn/`09oiYn/`03
o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03
o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<002onOS<000ol0003oXYO9o`000007oknV`003
o`000?noY/3o_jK000?o_jK000?o0000olReaoo8]LL03Oo8]LL01?l0003of[^jomZk^_oJ^kX2o`00
08Cooooo000cooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Ooooo
o`Co00000onJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn
/onJO[<02OnJO[<00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<
`?nOS<002onOS<02o`0000So_jK000?o0000oknV`?noY/000onoY/000ol0003ob;G7olRea`0<olRe
a`03o`000?oJ^k[of[^j00?of[^j00?o0000ooooooooool0P_ooool003?ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01_ooooo0ol00004oiZ0]P05o`000?nJP;KoVX2f
oiZ0]_l000002_nJO[<00ol0003oVGfcoiUm/`08oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000
oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5^P0;oib5^P03o`000?nOS<3oWhc000WoWhc000?o0000
okRK^ol000002?noY/000ol0003o_jK0oknV`004oknV`003o`000?o8]LOob;G700[ob;G700?o0000
omZk^_oJ^kX01?oJ^kX2o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Hooooo`?o00002_nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?o
VGfc00SoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[o
W8Fj00[oW8Fj00?o0000oin<`?nOS<002?nOS<001Ol0003o^9^kokRK^onhVk_o000000Oo_jK000?o
0000oknV`?noY/001OnoY/000ol0003ob;G7olRea`09olRea`03o`000?oJ^k[of[^j00Gof[^j0_l0
0022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool05?oo
ool3o`000003oib5^_l0003oVX2f00[oVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm
/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oW8Fjoib5
^P0:oib5^P03o`000?nOS<3oWhc000OoWhc000?o0000okRK^onhVk/00_nhVk/00ol0003o_jK0oknV
`005oknV`003o`000?noY/3o_jK000Go_jK000?o0000olReaoo8]LL02?o8]LL00ol0003of[^jomZk
^P07omZk^P;o0000POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41005?ooool3o`0000?oW8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjc
oiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2f
oiZ0]P09oiZ0]P03o`000?nLQK[oW8Fj00_oW8Fj00?o0000oin<`?nOS<001OnOS<000ol0003o^9^k
okRK^`03okRK^`03o`000?noY/3o_jK000Go_jK000?o0000oknV`?noY/001_noY/000ol0003ob;G7
olRea`06olRea`03o`000?oJ^k[of[^j00Wof[^j00?o0000ooooooooool0Ooooool003?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`0000Oo
W8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00So
VGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[oW8Fj00[o
W8Fj00?o0000oin<`?nOS<001?nOS<000ol0003o^9^kokRK^`05okRK^`03o`000?noY/3o_jK000Co
_jK000?o0000oknV`?noY/001_noY/000ol0003ob;G7olRea`05olRea`03o`000?oJ^k[of[^j00[o
f[^j0_l00020ooooo`00Eoooool3o`000003oib5^_l0003oW8Fj00KoW8Fj00?o0000oiZ0]_nJP;H0
2OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn/onJO[<0
2OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nLQK[oW8Fj00[oW8Fj00?o0000oin<`?nOS<00
0onOS<000ol0003o^9^kokRK^`06okRK^`03o`000?noY/3o_jK000Co_jK000?o0000oknV`?noY/00
1onoY/000ol0003ob;G7olRea`04olRea`03o`000?oJ^k[of[^j00_of[^j0_l0001oooooo`00E?oo
ool3o`000003oin<`?l0003oW8Fj00WoW8Fj00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn
/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0
]P09oiZ0]P03o`000?nLQK[oW8Fj00_oW8Fj00Go0000oin<`?nOS<3oWhc0o`00000:okRK^`03o`00
0?noY/3o_jK000?o_jK000?o0000oknV`?noY/001onoY/000ol0003ob;G7olRea`03olRea`03o`00
0?oJ^k[of[^j00gof[^j00?o0000ooooooooool0OOooool005;ooooo0ol00004oin<`003o`000?nL
QK[oW8Fj00SoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nI
OK?oVGfc00WoVGfc00?o0000oiYn/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P03o`000?nL
QK[oW8Fj00[oW8Fj00Co0000oin<`?nOS<3o00002onhVk/00ol0003o_jK0oknV`003oknV`003o`00
0?noY/3o_jK000So_jK000Go0000olReaoo8]LOob;G7o`00000AomZk^P03o`000?oooooooooo07co
oooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003oin<`?l0003oWhc000?o
Whc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nJO[?oVWjc00So
VWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00[o
VX2f00?o0000oib5^_nLQKX02_nLQKX00ol0003oWhc0o`00000<okRK^`03o`000?noY/3o_jK000?o
_jK000?o0000oknV`?noY/002OnoY/001?l0003ob;G7olReaol0000AomZk^P;o0000OOooool002Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`?o00002OnOS<000ol0003oW8Fjoib5^P08oib5
^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm/`09oiUm
/`03o`000?nJO[?oVWjc00SoVWjc00?o0000oiZ0]_nJP;H02_nJP;H00ol0003oW8Fjoib5^P0:oib5
^P;o00003_nhVk/00ol0003o_jK0oknV`002oknV`003o`000?noY/3o_jK000Wo_jK000?o0000olRe
aol000004ooJ^kX2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`00
00_oWhc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc
00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f
00[oVX2f00?o0000oib5^_nLQKX02?nLQKX00ol0003o/9:go`00000>okRK^`03o`000?noY/3o_jK0
00;o_jK000?o0000oknV`?noY/002_noY/000ol0003of[^jomZk^P0ComZk^P03o`000?oooooooooo
07[ooooo000Wooooo`05o`000?ooooooooooooooool000007?ooool3o`0000;oXYO900?o0000oj:G
bOl000002_nOS<000ol0003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn
/onJO[<01onJO[<00ol0003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0
]_nJP;H02_nJP;H00ol0003oW8Fjoib5^P07oib5^P05o`000?n`T[Oo/9:gok2B]ol000003_nhVk/0
1Ol0003o_jK0oknV`?noY/3o000000co_jK000?o0000omZk^_oJ^kX04_oJ^kX00ol0003oi;j`o`00
001kooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005oj:Gb@;o00002_nO
S<000ol0003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJO[<02?nJ
O[<00ol0003oVGfcoiUm/`08oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02_nJ
P;H00ol0003oW8Fjoib5^P05oib5^P;o00001?n`T[L00ol0003o^9^kokRK^`0<okRK^`05o`000?no
Y/3o_jK0oknV`?l000002onoY/000ol0003odJngo`00000ComZk^P04o`000?oT_[3o0000o`0007[o
oooo000Wooooo`05oa0@4?ooooooooooooooool@41005oooool3o`0000WoXYO900?o0000oin<`?nO
S<002OnOS<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00WoVX2f00?o0000oiYn/onJ
O[<02?nJO[<00ol0003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJ
P;H02_nJP;H00ol0003oW8Fjoib5^P03oib5^P03o`000?n`T[Oo/9:g00Co/9:g00?o0000okRK^onh
Vk/03OnhVk/01?l0003o_jK0oknV`?l0000:oknV`005o`000?oA[kOodJngom6_]ol000004OoJ^kX0
1?l0003oi;j`onBn/?oT_[02o`0007Wooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?oo
ool5o`000003oj:GbOl0003oXYO900SoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5
^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm
/`09oiUm/`03o`000?nJO[?oVWjc00WoVWjc00?o0000oiZ0]_nJP;H02_nJP;H01?l0003oW8Fjoib5
^_nLQKX2o`0000So/9:g00?o0000okRK^onhVk/03?nhVk/01?l0003o_jK0oknV`?l0000:oknV`005
o`000?oA[kOodJngom6_]ol000004OoJ^kX00ol0003oi;j`onBn/002onBn/003o`000?oooooooooo
07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool3o`0000CoYZOF00?o0000oj:G
bOnRUlT02?nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00SoW8Fj00?o0000oiZ0
]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00SoVGfc00?o0000oiYn
/onJO[<02OnJO[<00ol0003oVX2foiZ0]P0:oiZ0]P04o`000?nLQK[oW8Fjo`0000[o/9:g00?o0000
okRK^onhVk/03?nhVk/01?l0003o_jK0oknV`?l00009oknV`003o`000?oA[kOodJng00?odJng00?o
0000omZk^_oJ^kX03OoJ^kX00ol0003oi;j`onBn/004onBn/003o`000?oooooooooo07Kooooo000k
ooooo`Go00001OnVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000WoWhc000?o0000
oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P09oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000
oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn/`08oiYn/`03o`000?nJP;KoVX2f00_oVX2f0_l0000<
ok2B]`03o`000?nhVk_o^9^k00co^9^k00?o0000oknV`?l000002?noY/000ol0003odJngom6_]`04
om6_]`03o`000?oJ^k[of[^j00gof[^j00?o0000onBn/?oT_[001?oT_[02o`0007Oooooo000ioooo
o`?o00002_nVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5
^_nLQKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm
/onIOK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00WoVX2f0_l0000=ok2B
]`03o`000?nhVk_o^9^k00co^9^k00?o0000oknV`?l000002?noY/000ol0003odJngom6_]`05om6_
]`03o`000?oJ^k[of[^j00_of[^j00?o0000onBn/?oT_[001_oT_[02o`0007Kooooo000gooooo`Co
00002onVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onI
OK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`03o`000?nJP;KoVX2f00SoVX2f00?o0000ojV;]?l0
00003On`T[L00ol0003o^9^kokRK^`0=okRK^`;o00001onoY/000ol0003odJngom6_]`07om6_]`03
o`000?oJ^k[of[^j00[of[^j00?o0000onBn/?oT_[001ooT_[000ol0003oooooooooo`1dooooo`00
=?ooool3o`000005ojZliol0003oZ[cWojZliol000002onVYmH00ol0003oXYO9oj:Gb@08oj:Gb@03
o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P09oiZ0]P03
o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02?nIOK<00ol0003oVWjcoiYn/`09oiYn/`03
o`000?nJP;KoVX2f00OoVX2f00Go0000ojV;]?nYRkCoZH^do`00000=ok2B]`03o`000?nhVk_o^9^k
00co^9^k0_l00006oknV`003o`000?oA[kOodJng00SodJng00?o0000omZk^_oJ^kX02OoJ^kX00ol0
003oi;j`onBn/009onBn/003o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L00ol0003o
YZOFojJWeP08ojJWeP03o`000?nRUlWoXYO900SoXYO900?o0000oin<`?nOS<002?nOS<000ol0003o
W8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003o
VGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00SoVWjc00?o0000oiZ0]_nJP;H01OnJP;H2o`0000Co
ZH^d00?o0000ok2B]on`T[L02on`T[L00ol0003o^9^kokRK^`0<okRK^`;o00001OnoY/000ol0003o
dJngom6_]`0:om6_]`03o`000?oJ^k[of[^j00Sof[^j00?o0000onBn/?oT_[002OoT_[02o`0007Co
oooo000aooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojJWe_nVYmH02?nVYmH00ol0003oXYO9
oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX02?nLQKX00ol0003oVX2f
oiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjc
oiYn/`09oiYn/`03o`000?nJP;KoVX2f00?oVX2f00?o0000ojV;]?nYRk@01?nYRk@00ol0003o/9:g
ok2B]`0;ok2B]`03o`000?nhVk_o^9^k00go^9^k00?o0000oknV`?noY/000onoY/000ol0003odJng
om6_]`0:om6_]`03o`000?oJ^k[of[^j00Sof[^j00?o0000onBn/?oT_[002_oT_[000ol0003ooooo
ooooo`1booooo`00<Oooool2o`0000[oZ[cW00?o0000ojJWe_nVYmH02?nVYmH00ol0003oXYO9oj:G
b@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0
]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0003oVWjcoiYn
/`09oiYn/`04o`000?nJP;KoVX2foiZ0]P;o00002?nYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`00
0?nhVk_o^9^k00co^9^k00?o0000oknV`?noY/000_noY/000ol0003odJngom6_]`0<om6_]`03o`00
0?oJ^k[of[^j00Kof[^j00?o0000onBn/?oT_[003?oT_[000ol0003oooooooooo`1aooooo`009Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo0_l0000;ojZli`03o`000?nVYmKoYZOF00OoYZOF
00?o0000oj:GbOnRUlT02?nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj
00?o0000oiZ0]_nJP;H02OnJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc
00?o0000oiYn/onJO[<02?nJO[<01?l0003oVX2foiZ0]_l0000:ojV;]003o`000?n`T[Oo/9:g00_o
/9:g00?o0000okRK^onhVk/03?nhVk/2o`0000;o_jK000?o0000om6_]ooA[kL03_oA[kL00ol0003o
f[^jomZk^P05omZk^P03o`000?oT_[3oi;j`00goi;j`00?o0000ooooooooool0L?ooool002Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000[oZ[cW00?o0000ojJWe_nV
YmH02?nVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onI
OK<02OnIOK<00ol0003oVWjcoiYn/`09oiYn/`;o00002onYRk@00ol0003o/9:gok2B]`0<ok2B]`03
o`000?nhVk_o^9^k00_o^9^k0_l00002oknV`003o`000?oA[kOodJng00kodJng00?o0000omZk^_oJ
^kX01?oJ^kX00ol0003oi;j`onBn/00>onBn/0;o0000LOooool002Gooooo00Go410@oooooooooooo
oooooa0@4007ooooo`04o`000?ooooooooooo`0000[oZ[cW00?o0000ojJWe_nVYmH01onVYmH00ol0
003oXYO9oj:Gb@08oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0
003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0
003oVWjcoiYn/`08oiYn/`;o00003OnYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`000?nhVk_o^9^k
00_o^9^k0_l000000onoY/3o0000om6_]`0Aom6_]`03o`000?oJ^k[of[^j00?of[^j00?o0000onBn
/?oT_[003ooT_[000ol0003oooooooooo`1_ooooo`009Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojJWe_nVYmH01onVYmH00ol0
003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000SoWhc000?o0000oib5^_nLQKX01onLQKX00ol0
003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<02OnIOK<00ol0
003oVWjcoiYn/`06oiYn/`;o000000?oXhFco`000?nYRk@03?nYRk@00ol0003o/9:gok2B]`0;ok2B
]`03o`000?nhVk_o^9^k00_o^9^k00?o0000okRK^ol000004ooA[kL00ol0003of[^jomZk^P02omZk
^P03o`000?oT_[3oi;j`00ooi;j`00?o0000on[0ZOl00000L?ooool002Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZlionZ_>L01onZ_>L00ol0
003oYZOFojJWeP07ojJWeP03o`000?nRUlWoXYO900SoXYO900?o0000oin<`?nOS<001onOS<000ol0
003oW8Fjoib5^P08oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0
003oVGfcoiUm/`09oiUm/`03o`000?nJO[?oVWjc00CoVWjc00Go0000oj>5/onSQK?oXhFco`00000=
ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000okRK^onhVk/02_nhVk/00ol0003o^9^ko`00000D
om6_]`05o`000?oJ^k[of[^jomZk^_l000004OoT_[001?l0003oj/2Yon[0ZOl0001_ooooo`009Ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooool00ol0003oZ[cW
ojZli`07ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT01onRUlT00ol0003oWhc0
oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjc
oiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<00_nJO[<2o`0000GoXhFc
00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B]`0;ok2B]`03o`000?nhVk_o^9^k00[o^9^k
0_l000000oo9YKGo0000om6_]`0Com6_]`03o`000?oJ^k[o000001;oi;j`00?o0000on[0ZOoZ`:T0
0_l0001^ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oZ[cWojZli`06ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT0
1onRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H0
2?nJP;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00WoVGfc00?o0000oiYn/onJO[<0
0_l00007oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^k
okRK^`09okRK^`04o`000?o9YKGobJFeo`0001CodJng00?o0000omZk^_l000004OoT_[000ol0003o
j/2Yon[0Z@02on[0Z@03o`000?oooooooooo06cooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojJWe_nV
YmH01onVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000OoWhc000?o0000oib5^_nL
QKX02?nLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00OoVWjc00?o0000oiUm/onI
OK<02_nIOK<2o`0000WoXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B]`0<ok2B]`03
o`000?nhVk_o^9^k00So^9^k0_l00003olVU]@03o`000?oA[kOodJng01;odJng00?o0000onBn/?oT
_[004?oT_[000ol0003oj/2Yon[0Z@03on[0Z@03o`000?oooooooooo06_ooooo000`ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ojZlionZ_>L01_nZ_>L00ol0003oYZOFojJWeP06ojJWeP03o`00
0?nRUlWoXYO900OoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5^P07oib5^P03o`00
0?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<02?nJO[<00ol0003oVGfcoiUm/`08oiUm/`;o0000
2onSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00_o/9:g00?o0000okRK^onhVk/0
2?nhVk/2o`0000?obJFe00?o0000om6_]ooA[kL04_oA[kL00ol0003oi;j`onBn/00?onBn/003o`00
0?oZ`:Woj/2Y00Goj/2Y00?o0000ooooooooool0J_ooool0033ooooo00?o0000ooooooooool02?oo
ool00ol0003oZ[cWojZli`05ojZli`03o`000?nVYmKoYZOF00OoYZOF00?o0000oj:GbOnRUlT01_nR
UlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJ
P;H00ol0003oVWjcoiYn/`08oiYn/`03o`000?nIOK?oVGfc00KoVGfc0_l000000onMPKCo0000oj>5
/`0:oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^kokRK
^`06okRK^`03o`000?o9YKGo000000CobJFe00?o0000om6_]ooA[kL04?oA[kL00ol0003ogKJ`o`00
000@onBn/003o`000?oZ`:Woj/2Y00Goj/2Y00?o0000ooooooooool0J_ooool002oooooo0_l0000;
ooooo`03o`000?nZ_>OoZ[cW00GoZ[cW00?o0000ojJWe_nVYmH01_nVYmH00ol0003oXYO9oj:Gb@07
oj:Gb@03o`000?nOS<3oWhc000OoWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P08
oiZ0]P03o`000?nJO[?oVWjc00SoVWjc00?o0000oiUm/onIOK<00onIOK<3o`0000?oWH6d00?o0000
oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000
okRK^onhVk/01OnhVk/01?l0003obJFeolVU]Ol00004olVU]@03o`000?oA[kOodJng013odJng00?o
0000omff/?l000004?oT_[000ol0003oj/2Yon[0Z@06on[0Z@03o`000?oooooooooo06Wooooo000`
ooooo`03o`000?oooooooooo00[ooooo00?o0000ojZlionZ_>L01OnZ_>L00ol0003oYZOFojJWeP05
ojJWeP03o`000?nRUlWoXYO900OoXYO900?o0000oin<`?nOS<002?nOS<000ol0003oW8Fjoib5^P07
oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/onJO[<01onJO[<01?l0003oVGfcoiUm/onI
OK<2o`0000OoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00;ojV;]003o`000?n`
T[Oo/9:g00_o/9:g00?o0000okRK^onhVk/01OnhVk/01?l0003obJFeolVU]Ol00005olVU]@03o`00
0?oA[kOodJng00kodJng00Go0000omff/?oM][3ogKJ`o`00000>onBn/003o`000?oZ`:Woj/2Y00So
j/2Y00?o0000ooooooooool0J?ooool002oooooo00?o0000ooooooooool03?ooool3o`0000CoZ[cW
00?o0000ojJWe_nVYmH01_nVYmH00ol0003oXYO9oj:Gb@07oj:Gb@03o`000?nOS<3oWhc000OoWhc0
00?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P08oiZ0]P03o`000?nJO[?oVWjc00SoVWjc
0ol00009oif1]003o`000?nSQK?oXhFc00WoXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:g
ok2B]`0<ok2B]`03o`000?nhVk_o^9^k00?o^9^k00Go0000olVU]Oo9YKGobJFeo`000005olVU]@03
o`000?oA[kOodJng00kodJng00?o0000omff/?oM][000_oM][000ol0003oi;j`onBn/00;onBn/003
o`000?oZ`:Woj/2Y00Woj/2Y00?o0000ooooooooool0Ioooool002oooooo00?o0000ooooooooool0
3Oooool00ol0003o?H_]o`000005o`0000OoYZOF00?o0000oj:GbOnRUlT01onRUlT00ol0003oWhc0
oin<`007oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o0000oiZ0]_nJP;H02?nJP;H00ol0003oVWjc
oiYn/`06oiYn/`?o00002onMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d
00?o0000ok2B]on`T[L03?n`T[L00ol0003o^9^kokRK^`02okRK^`03o`000?o9YKGobJFe00;obJFe
00?o0000olVU]Oo9YKD01?o9YKD00ol0003odJngom6_]`0<om6_]`03o`000?oM][3ogKJ`00?ogKJ`
00?o0000onBn/?oT_[002_oT_[000ol0003oj/2Yon[0Z@0:on[0Z@03o`000?oooooooooo06Oooooo
000_ooooo`03o`000?oooooooooo00kooooo00?o0000ocf;kOlmRnd00olmRnd4o`0000GoYZOF00?o
0000oj:GbOnRUlT01_nRUlT00ol0003oWhc0oin<`008oin<`003o`000?nLQK[oW8Fj00OoW8Fj00?o
0000oiZ0]_nJP;H01onJP;H00ol0003oVWjcoiYn/`03oiYn/`?o00000_nGOKD00ol0003oWH6doif1
]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:gok2B
]`0<ok2B]`04o`000?nhVk_o^9^ko`0000GobJFe00?o0000olVU]Oo9YKD01?o9YKD00ol0003odJng
om6_]`0<om6_]`03o`000?oM][3ogKJ`00CogKJ`00?o0000onBn/?oT_[002OoT_[000ol0003oj/2Y
on[0Z@0;on[0Z@03o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o
0000ocf;kOlmRnd00olmRnd00ol0003oGXGPoej5h006o`0000WoXYO900?o0000oin<`?nOS<001onO
S<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00SoVX2f00?o0000oiYn/ol000000_l0
0005oiMm]@03o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;
]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00Co0000okRK^onhVk_o00001Oo9YKD00ol0003obJFe
olVU]@05olVU]@03o`000?oA[kOodJng00[odJng00?o0000omff/?oM][001OoM][000ol0003oi;j`
onBn/009onBn/003o`000?oZ`:Woj/2Y00coj/2Y00?o0000ooooooooool0IOooool002kooooo0ol0
000Aooooo`03o`000?lmRngo?H_]00?o?H_]00?o0000oej5h?mNQN001?mNQN05o`0000GoXYO900?o
0000oin<`?nOS<001onOS<000ol0003oW8Fjoib5^P07oib5^P03o`000?nJP;KoVX2f00KoVX2f1?l0
0009oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;
]00;ojV;]003o`000?n`T[Oo/9:g00co/9:g00?o0000okRK^ol000001_o9YKD00ol0003obJFeolVU
]@05olVU]@03o`000?oA[kOodJng00[odJng00?o0000omff/?oM][001_oM][000ol0003oi;j`onBn
/007onBn/003o`000?oZ`:Woj/2Y00goj/2Y0_l0001Vooooo`00;oooool00ol0003oooooooooo`0A
ooooo`03o`000?lmRngo?H_]00?o?H_]00?o0000oej5h?mNQN001?mNQN001?l0003oLWoAog9odOmb
Om46o`0000[oWhc000?o0000oib5^_nLQKX01onLQKX00ol0003oVX2foiZ0]P05o`0000;oT7^h00?o
0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009oif1]003o`000?nSQK?oXhFc00WoXhFc00?o
0000ojV;]?nYRk@03?nYRk@00ol0003o/9:gok2B]`0<ok2B]`03o`000?o9YKGobJFe00GobJFe00?o
0000olVU]Oo9YKD01Oo9YKD00ol0003odJngom6_]`09om6_]`03o`000?oM][3ogKJ`00SogKJ`00?o
0000onBn/?oT_[001_oT_[000ol0003oj/2Yon[0Z@0<on[0Z@03o`000?o^`JCo000006Kooooo000_
ooooo`03o`000?oooooooooo01;ooooo00?o0000ocf;kOlmRnd00_lmRnd00ol0003oGXGPoej5h005
oej5h003o`000?mbOm7oLWoA00GoLWoA6?l00007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000
oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000
ok2B]on`T[L03?n`T[L00ol0003obJFeolVU]@05olVU]@03o`000?o9YKGobJFe00KobJFe00?o0000
om6_]ooA[kL01ooA[kL00ol0003ogKJ`omff/009omff/003o`000?oT_[3oi;j`00Goi;j`00?o0000
on[0ZOoZ`:T03OoZ`:T01?l0003ok/6Tonk1Y?l0001Uooooo`00;oooool00ol0003oooooooooo`0C
ooooo`03o`000?lmRngo?H_]00;o?H_]00?o0000oej5h?mNQN001?mNQN000ol0003oLWoAog9od@06
og9od@03o`000?moNlGoOg_500OoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008
oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09
oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000ok2B]on`T[L02on`T[L00ol0003o`9fdo`000006
olVU]@03o`000?o9YKGobJFe00KobJFe00?o0000om6_]ooA[kL01ooA[kL00ol0003ogKJ`omff/00:
omff/003o`000?oT_[3oi;j`00Coi;j`00?o0000on[0ZOoZ`:T03OoZ`:T01Ol0003ok/6Tonk1Y?o^
`JCo000006Cooooo000_ooooo`03o`000?oooooooooo01?ooooo0_l00004ocf;k@03o`000?mNQN3o
GXGP00CoGXGP00?o0000og9odOmbOm401_mbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8Nkko
R7^n00OoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCo
WH6d00WoWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]003o`000?n`T[Oo
/9:g00Wo/9:g00Co0000ol2M]?o0WKCo00001_o9YKD00ol0003obJFeolVU]@07olVU]@03o`000?oA
[kOodJng00GodJng00?o0000omff/?oM][002ooM][000ol0003oi;j`onBn/004onBn/003o`000?oZ
`:Woj/2Y00coj/2Y00?o0000onk1Y?o^`J@00_o^`J@2o`0006?ooooo000^ooooo`03o`000?oooooo
oooo01Gooooo0_l00003ocf;k@03o`000?mNQN3oGXGP00CoGXGP00?o0000og9odOmbOm401_mbOm40
0ol0003oOg_5ogmka@07ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP0
0ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<0
0ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00So/9:g00Go0000ol2M]?o0WKCo`9fdo`00
0006olVU]@03o`000?o9YKGobJFe00OobJFe00?o0000om6_]ooA[kL01OoA[kL00ol0003ogKJ`omff
/00<omff/003o`000?oT_[3oi;j`00;oi;j`00?o0000on[0ZOoZ`:T03OoZ`:T00ol0003ok/6Tonk1
Y003onk1Y003o`000?oooooooooo067ooooo000^ooooo`?o00005_ooool2o`0000?o?H_]00?o0000
oej5h?mNQN001?mNQN000ol0003oLWoAog9od@05og9od@03o`000?moNlGoOg_500OoOg_500?o0000
ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000
oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00_oZH^d00?o0000
ok2B]on`T[L01on`T[L00ol0003o`9fdol2M]003ol2M]003o`000?o9YKGobJFe00?obJFe00?o0000
olVU]Oo9YKD02?o9YKD00ol0003odJngom6_]`03om6_]`03o`000?oM][3ogKJ`00gogKJ`00?o0000
onBn/?oT_[000_oT_[000ol0003oj/2Yon[0Z@0=on[0Z@03o`000?o^`JCok/6T00Cok/6T00?o0000
ooooooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000?o?H_]00?o0000oej5
h?mNQN000omNQN000ol0003oLWoAog9od@06og9od@03o`000?moNlGoOg_500KoOg_500?o0000ohQk
__n8Nkh01on8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1
]?nMPK@02OnMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00coZH^d00?o0000ok2B
]on`T[L01On`T[L00ol0003o`9fdol2M]004ol2M]003o`000?o9YKGobJFe00?obJFe00?o0000olVU
]Oo9YKD02?o9YKD00ol0003odJngom6_]`03om6_]`03o`000?oM][3ogKJ`00kogKJ`00Co0000onBn
/?oT_[3o00003ooZ`:T00ol0003ok/6Tonk1Y006onk1Y003o`000?oooooooooo05oooooo000Boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooo
oooo01Sooooo0_l00002ocf;k@03o`000?mNQN3oGXGP00CoGXGP00?o0000og9odOmbOm401OmbOm40
0ol0003oOg_5ogmka@07ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP0
0ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<0
0ol0003oZH^dojV;]00;ojV;]003o`000?n`T[Oo/9:g00Co/9:g00?o0000ol2M]?o0WK@01Oo0WK@0
0ol0003obJFeolVU]@03olVU]@03o`000?o9YKGobJFe00WobJFe00Go0000om6_]ooA[kOodJngo`00
000Bomff/003o`000?oT_[3o000000ooj/2Y00?o0000onk1Y?o^`J@01oo^`J@00ol0003ooooooooo
o`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`0Iooooo`;o00000_lmRnd00ol0003oGXGP
oej5h003oej5h003o`000?mbOm7oLWoA00KoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02onYRk@00ol0003o/9:g
ok2B]`04ok2B]`03o`000?o0WKCo`9fd00Ko`9fd00?o0000olVU]Oo9YKD00_o9YKD00ol0003obJFe
olVU]@09olVU]@05o`000?oA[kOodJngom6_]ol000004_oM][000ol0003oi;j`o`00000?on[0Z@03
o`000?o^`JCok/6T00Ook/6T00?o0000ooooooooool0G_ooool001;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_ooool2o`000003
ocf;kOl0003oGXGP00GoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03
o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@07oiMm]@03
o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]003
o`000?n`T[Oo/9:g00;o/9:g00?o0000ol2M]?o0WK@01oo0WK@00ol0003obJFeolVU]@02olVU]@03
o`000?o9YKGobJFe00[obJFe00?o0000om6_]ol000005?oM][000ol0003oj/2Yon[0Z@0=on[0Z@03
o`000?o^`JCok/6T00Wok/6T00?o0000ooooooooool0GOooool001;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool2o`000003
ocf;kOl0003oGXGP00CoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@07ogmka@03
o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@08oiMm]@03
o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]00;ojV;]005
o`000?n`T[Oo/9:gok2B]ol000002_o0WK@00ol0003obJFeolVU]@02olVU]@03o`000?o9YKGobJFe
00[obJFe00?o0000om6_]ol000005?oM][000ol0003oj/2Yon[0Z@0=on[0Z@03o`000?o^`JCok/6T
00[ok/6T00?o0000ooooooooool0G?ooool001;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool07?ooool2o`000003ocf;kOl0003oGXGP
00CoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8NkkoR7^n
00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d
00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]00;ojV;]004o`000?n`T[Oo/9:g
o`0000co`9fd00Go0000olVU]Oo9YKGobJFeo`00000=olVU]@03o`000?oM][3ogKJ`01;ogKJ`00?o
0000onFjZ_l000003_oZ`:T00ol0003ok/6Tonk1Y00;onk1Y003o`000?oooooooooo05_ooooo000B
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o00007ooo
ool3o`0000GoGXGP00?o0000og9odOmbOm401OmbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8
NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nM
PKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnSQK<00ol0003oZH^dojV;]00<ojV;]0;o00003Oo0
WK@01Ol0003obJFeolVU]Oo9YKGo000000gobJFe00?o0000omff/?oM][004_oM][000ol0003oiKZZ
o`00000=on[0Z@03o`000?o^`JCok/6T00cok/6T00?o0000ooooooooool0Foooool001;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`0Oooooo`?o00001?mNQN000ol0003oLWoAog9od@06og9od@03o`000?moNlGoOg_500Ko
Og_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^008oi1k^003o`000?nGOKGoUgfe00Oo
Ugfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`09oj>5/`03o`000?nYRkCoZH^d00co
ZH^d00?o0000ol2M]?o0WK@03Oo0WK@01?l0003obJFeolVU]Ol0000<olVU]@03o`000?oF[[3o0000
01;ogKJ`00Go0000onFjZ_oU^Z[oiKZZo`00000<on[0Z@03o`000?o^`JCok/6T00cok/6T0_l0001L
ooooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo023ooooo0ol00004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o
0000ogmkaOmoNlD01_moNlD00ol0003oR7^nohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o
0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o
0000ojV;]?nYRk@02_nYRk@2o`0000oo`9fd00Co0000olVU]Oo9YKGo00003?o9YKD00ol0003oeZj`
o`00000Bomff/003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on[0ZOoZ`:T02?oZ`:T00ol0003ok/6T
onk1Y00<onk1Y004o`000?oa`j7olL>Qo`0005_ooooo000]ooooo`03o`000?oooooooooo027ooooo
0_l00004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00[oXhFc00?o0000ojV;]?nYRk@02OnYRk@00ol0003o]iBd
o`00000?ol2M]004o`000?o9YKGobJFeo`0000_obJFe00Go0000omJ^/?oF[[3oeZj`o`00000Aomff
/003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on[0ZOoZ`:T02?oZ`:T00ol0003ok/6Tonk1Y00<onk1
Y005o`000?oa`j7olL>Qoo73XOl00000F_ooool002gooooo00?o0000ooooooooool08Oooool00ol0
003o00f?o`000004oej5h003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01_moNlD00ol0
003oR7^nohQk_P06ohQk_P03o`000?n@NkSoT7^h00SoT7^h00?o0000oiMm]OnGOKD01onGOKD00ol0
003oWH6doif1]00:oif1]003o`000?nSQK?oXhFc00WoXhFc00?o0000ojV;]?nYRk@02?nYRk@01Ol0
003o]iBdokND]?ngU;Co000000oo`9fd00?o0000olVU]Ol000002_o9YKD00ol0003oeZj`omJ^/002
omJ^/003o`000?oM][3ogKJ`00kogKJ`00?o0000onFjZ_oU^ZX01?oU^ZX00ol0003oj/2Yon[0Z@07
on[0Z@03o`000?o^`JCok/6T00cok/6T00Go0000oo73XOoa`j7olL>Qo`00001Jooooo`00;Oooool0
0ol0003oooooooooo`0Rooooo`04o`000?l03Hoo0000o`0000;oGXGP00?o0000og9odOmbOm401Omb
Om400ol0003oOg_5ogmka@06ogmka@03o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@
NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nS
QK<00ol0003oZH^dojV;]006ojV;]003o`000?ngU;Co]iBd00;o]iBd00?o0000ol2M]?o0WK@03Oo0
WK@00ol0003obJFeo`00000:olVU]@03o`000?oF[[3oeZj`00?oeZj`00?o0000omff/?oM][003OoM
][000ol0003oiKZZonFjZP04onFjZP03o`000?oZ`:Woj/2Y00Koj/2Y00?o0000onk1Y?o^`J@03?o^
`J@00ol0003olL>Qoo73X@03oo73X@03o`000?oooooooooo05Oooooo000/ooooo`?o00009?ooool2
o`000005o`0`^?l0003oGXGPoej5h?l000001ombOm400ol0003oOg_5ogmka@05ogmka@03o`000?n8
NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nM
PKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]005ojV;]003o`000?ng
U;Co]iBd00?o]iBd00?o0000ol2M]?o0WK@03Oo0WK@00ol0003obJFeo`000009olVU]@03o`000?oF
[[3oeZj`00CoeZj`00?o0000omff/?oM][003?oM][000ol0003oiKZZonFjZP06onFjZP03o`000?oZ
`:Woj/2Y00Goj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73X@04oo73X@03o`000?oo
oooooooo05Kooooo000]ooooo`03o`000?oooooooooo02Cooooo0_l000001?l0<;So0000oej5h?l0
0007og9od@03o`000?moNlGoOg_500KoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k
^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02OnMPK@00ol0003oXhFcoj>5
/`0:oj>5/`03o`000?nYRkCoZH^d00CoZH^d00?o0000okND]?ngU;@01OngU;@00ol0003o`9fdol2M
]00=ol2M]0;o00002Oo9YKD00ol0003oeZj`omJ^/005omJ^/003o`000?oM][3ogKJ`00_ogKJ`00?o
0000onFjZ_oU^ZX01ooU^ZX00ol0003oj/2Yon[0Z@04on[0Z@03o`000?o^`JCok/6T00cok/6T00?o
0000oo73XOoa`j401Ooa`j400ol0003oooooooooo`1Eooooo`00;Oooool00ol0003oooooooooo`0U
ooooo`;o000000Co032ho`000?mNQN3o00001_mbOm400ol0003oOg_5ogmka@06ogmka@03o`000?n8
NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP02?n@NkP00ol0003oUgfeoiMm]@07oiMm]@03o`000?nM
PKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02_nSQK<00ol0003oZH^dojV;]002ojV;]003o`000?ng
U;Co]iBd00Ko]iBd00?o0000ol2M]?o0WK@03Oo0WK@2o`0000SobJFe00?o0000omJ^/?oF[[001_oF
[[000ol0003ogKJ`omff/00:omff/003o`000?oU^Z[oiKZZ00SoiKZZ00?o0000on[0ZOoZ`:T00ooZ
`:T00ol0003ok/6Tonk1Y00<onk1Y003o`000?oa`j7olL>Q00KolL>Q0_l0001Fooooo`00;Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?l0<;So032h00;o00001ombOm400ol0003oOg_5ogmka@05
ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08
oiMm]@03o`000?nMPKCoWH6d00WoWH6d00?o0000oj>5/onSQK<02_nSQK<01Ol0003oZH^dojV;]?nY
RkCo000000Wo]iBd00?o0000ol2M]?o0WK@03_o0WK@00ol0003obJFeolVU]@05olVU]@03o`000?oF
[[3oeZj`00SoeZj`00?o0000omff/?oM][002OoM][000ol0003oiKZZonFjZP09onFjZP03o`000?oZ
`:Woj/2Y00;oj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73X@07oo73X@03o`000?oo
oooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo00?o0000o`0`^?l0<;P00_l00006
og9od@03o`000?moNlGoOg_500GoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k^007
oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02OnMPK@00ol0003oXhFcoj>5/`0:
oj>5/`04o`000?nYRkCoZH^do`0000_o]iBd00?o0000ol2M]?o0WK@03Oo0WK@00ol0003obJFeolVU
]@05olVU]@03o`000?oF[[3oeZj`00SoeZj`00?o0000omff/?oM][002?oM][000ol0003oiKZZonFj
ZP0:onFjZP03o`000?oZ`:Woj/2Y00;oj/2Y00?o0000onk1Y?o^`J@03?o^`J@00ol0003olL>Qoo73
X@08oo73X@03o`000?oooooooooo05?ooooo000/ooooo`03o`000?oooooooooo02Sooooo0_l00002
o`0`^003o`000?mbOm7oLWoA00GoLWoA00?o0000ogmkaOmoNlD01OmoNlD00ol0003oR7^nohQk_P06
ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6doif1]009
oif1]003o`000?nSQK?oXhFc00_oXhFc0_l0000<okND]003o`000?o0WKCo`9fd00go`9fd00?o0000
olVU]Oo9YKD01?o9YKD00ol0003oeZj`omJ^/00:omJ^/003o`000?oM][3ogKJ`00OogKJ`00?o0000
onFjZ_oU^ZX02ooU^ZX01?l0003oj/2Yon[0ZOl0000?onk1Y003o`000?oa`j7olL>Q00WolL>Q00?o
0000ooooooooool0D_ooool002cooooo0_l0000Zooooo`04o`000?l0<;So032ho`0`^0;o00001Omb
Om400ol0003oOg_5ogmka@05ogmka@03o`000?n8NkkoR7^n00OoR7^n00?o0000oi1k^?n@NkP01on@
NkP00ol0003oUgfeoiMm]@07oiMm]@03o`000?nMPKCoWH6d00[oWH6d00?o0000oj>5/onSQK<02OnS
QK<2o`0000go]iBd00?o0000ol2M]?o0WK@03Oo0WK@2o`0000GobJFe00?o0000omJ^/?oF[[002_oF
[[000ol0003ogKJ`omff/007omff/003o`000?oU^Z[oiKZZ00coiKZZ00?o0000on[0ZOl000003_o^
`J@00ol0003olL>Qoo73X@0:oo73X@;o0000Doooool002cooooo00?o0000ooooooooool0:_ooool0
1_l0003o032ho`0`^?l0003o6dg7o`0000CoLWoA00?o0000ogmkaOmoNlD01OmoNlD00ol0003oR7^n
ohQk_P07ohQk_P03o`000?n@NkSoT7^h00OoT7^h00?o0000oiMm]OnGOKD02?nGOKD00ol0003oWH6d
oif1]009oif1]003o`000?nSQK?oXhFc00SoXhFc00?o0000ojf=]Ol000003_ngU;@00ol0003o`9fd
ol2M]00<ol2M]0;o00001?o9YKD00ol0003oeZj`omJ^/00;omJ^/003o`000?oM][3ogKJ`00KogKJ`
00?o0000onFjZ_oU^ZX03OoU^ZX00ol0003oj/2Yo`00000>onk1Y003o`000?oa`j7olL>Q00_olL>Q
00?o0000ooooooooool0DOooool002cooooo00?o0000ooooooooool0:_ooool2o`0000;o032h00Co
0000oa]=aol0003o00000ombOm400ol0003oOg_5ogmka@05ogmka@03o`000?n8NkkoR7^n00KoR7^n
00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d
00?o0000oj>5/onSQK<01onSQK<01Ol0003o[Hfeojf=]On]SKGo000000go]iBd00?o0000ol2M]?o0
WK@03?o0WK@2o`0000CobJFe00?o0000omJ^/?oF[[003?oF[[000ol0003ogKJ`omff/005omff/003
o`000?oU^Z[oiKZZ00koiKZZ00?o0000onk1Y?o^`J@03Oo^`J@00ol0003olL>Qoo73X@0;oo73X@;o
0000D_ooool002cooooo00?o0000ooooooooool0:oooool01?l0003o032ho`0`^?l00003oa]=a`04
o`000?mbOm7oLWoAo`0000OoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^008oi1k
^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5/`04oj>5
/`;o00001?n]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd00co`9fd00?o0000ol2M
]?l000000_o9YKD00ol0003oeZj`omJ^/00=omJ^/003o`000?oM][3ogKJ`00CogKJ`00?o0000onFj
Z_oU^ZX03ooU^ZX00ol0003ok/6Tonk1Y00<onk1Y003o`000?oa`j7olL>Q00_olL>Q00Co0000oo?5
WoocaIoo0000DOooool002cooooo00?o0000ooooooooool0;?ooool01?l0003o032ho`0`^?l00003
oa]=a`04o`000?mbOm7oLWoAo`0000KoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003oT7^hoi1k
^007oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@00ol0003oXhFcoj>5
/`03oj>5/`03o`000?n]SKGo[Hfe00Co[Hfe00?o0000okND]?ngU;@03?ngU;@00ol0003o`9fdol2M
]00;ol2M]005o`000?o0WKCo0000olVU]Ol000004OoF[[000ol0003ogKJ`omff/003omff/003o`00
0?oU^Z[oiKZZ00ooiKZZ0_l0000=onk1Y003o`000?oa`j7olL>Q00_olL>Q00?o0000oo?5WoocaIl0
0_l0001@ooooo`00;?ooool00ol0003oooooooooo`0]ooooo`03o`000?l0<;So000000Co6dg70ol0
0007ogmka@03o`000?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm
]@08oiMm]@03o`000?nMPKCoWH6d00WoWH6d00Co0000oj>5/onSQK?oXhFc0_l00008ojf=]@03o`00
0?ngU;Co]iBd00_o]iBd00?o0000ol2M]?o0WK@02oo0WK@01Ol0003o`9fdo`000?o9YKGo0000017o
eZj`00?o0000omff/?oM][000_oM][000ol0003oiKZZonFjZP0?onFjZP04o`000?o[_ZKojkjVo`00
00cok/6T00?o0000oo73XOoa`j402ooa`j401Ol0003ollFOoo?5WoocaIoo0000053ooooo000/oooo
o`;o0000;_ooool01?l0003o032ho`0`^?l00005oa]=a`03o`000?moNlGoOg_500GoOg_500?o0000
ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000
oif1]?nMPK@02OnMPK@01?l0003oXhFcoj>5/ol0000:ojf=]@03o`000?ngU;Co]iBd00_o]iBd00?o
0000ol2M]?o0WK@02oo0WK@01?l0003o`9fdol2M]?l0000ComJ^/005o`000?oM][3ogKJ`omff/?l0
00004OoU^ZX01Ol0003ojkjVon^nY_o[_ZKo000000[ok/6T00?o0000oo73XOoa`j402ooa`j400ol0
003ollFOoo?5W`03oo?5W`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo02oo
oooo00?o0000o`0`^?l000001_lKCLL2o`0000GoOg_500?o0000ohQk__n8Nkh01on8Nkh00ol0003o
T7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00OoUgfe00?o0000oif1]?nMPK@02_nMPK@2o`0000_o
[Hfe00?o0000okND]?ngU;@03?ngU;@00ol0003o`9fdol2M]00:ol2M]004o`000?o0WKCo`9fdo`00
01?oeZj`00Go0000omff/?oM][3ogKJ`o`00000AonFjZP05o`000?o[_ZKojkjVon^nY_l000002_o^
`J@00ol0003olL>Qoo73X@0;oo73X@03o`000?ocaIoollFO00CollFO00?o0000ooooooooool0C?oo
ool002_ooooo00?o0000ooooooooool0<?ooool00ol0003o032ho`000005oa]=a`04o`000?m<H<Ko
0000o`0000CoOg_500?o0000ohQk__n8Nkh01_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nG
OKGoUgfe00SoUgfe00?o0000oif1]?nMPK@02?nMPK@2o`0000go[Hfe00?o0000okND]?ngU;@02ong
U;@00ol0003o`9fdol2M]00:ol2M]005o`000?o0WKCo0000olfV/Ol000004ooF[[000ol0003ogKJ`
o`00000AonFjZP03o`000?o[_ZKojkjV00?ojkjV00?o0000onk1Y?o^`J@01oo^`J@00ol0003olL>Q
oo73X@0;oo73X@03o`000?ocaIoollFO00CollFO0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?l0<;So000000Ko6dg700?o0000odaPa_m<H<H00_l00002ogmka@03o`00
0?n8NkkoR7^n00KoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfeoiMm]@08oiMm]@03o`00
0?nMPKCoWH6d00KoWH6d0_l000000onRQ[Ko0000ojf=]@0<ojf=]@03o`000?ngU;Co]iBd00_o]iBd
00?o0000ol2M]?o0WK@02_o0WK@2o`0000;ocJJa00?o0000omJ^/?oF[[004OoF[[000ol0003ogKJ`
o`00000AonFjZP03o`000?o[_ZKojkjV00CojkjV00?o0000onk1Y?o^`J@01_o^`J@00ol0003olL>Q
oo73X@0;oo73X@03o`000?ocaIoollFO00GollFO0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<Oooool00ol0003o032ho`000005oa]=a`03o`000?m<H<KoC63600;oC63600?o0000ogmkaOl00000
2?n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe00SoUgfe00?o0000oif1]?nMPK@0
0onMPK@3o`0000?oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00<okND]003o`00
0?o0WKCo`9fd00Wo`9fd0_l00003olfV/@03o`000?oF[[3oeZj`017oeZj`00?o0000onFjZ_oU^ZX0
4?oU^ZX00ol0003ojkjVon^nYP05on^nYP03o`000?o^`JCok/6T00Cok/6T00?o0000oo73XOoa`j40
2ooa`j400ol0003ollFOoo?5W`07oo?5W`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0<_ooool2o`0000Go6dg7
00?o0000odaPa_m<H<H00om<H<H3o`0000SoR7^n00?o0000oi1k^?n@NkP01on@NkP00ol0003oUgfe
oiMm]@07oiMm]@04o`000?nMPKCoWH6doif1]0;o00001onRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03
o`000?ngU;Co]iBd00_o]iBd00?o0000ol2M]?o0WK@02Oo0WK@00ol0003ocJJaolfV/@02olfV/@03
o`000?oF[[3oeZj`017oeZj`00?o0000onFjZ_oU^ZX03ooU^ZX00ol0003ojkjVon^nYP06on^nYP03
o`000?o^`JCok/6T00Cok/6T00?o0000oo73XOoa`j402ooa`j400ol0003ollFOoo?5W`08oo?5W`03
o`000?oooooooooo04Wooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo03;ooooo00?o0000o`0`^?l000001OlKCLL00ol0
003oC636odaPaP04odaPaP?o00001_n8Nkh00ol0003oT7^hoi1k^007oi1k^003o`000?nGOKGoUgfe
00SoUgfe0ol00009oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@00ol0
003o`9fdol2M]008ol2M]0;o00001?o=Y[400ol0003oeZj`omJ^/00@omJ^/003o`000?oO]Jco0000
013oiKZZ00?o0000on^nY_o[_ZH01oo[_ZH00ol0003ok/6Tonk1Y003onk1Y003o`000?oa`j7olL>Q
00_olL>Q00?o0000oo?5WoocaIl02?ocaIl2o`0004[ooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03?ooooo0_l00005
oa]=a`03o`000?m<H<KoC63600CoC63600?o0000ofe]`_m]KL800ol00003ohQk_P03o`000?n@NkSo
T7^h00OoT7^h00?o0000oiMm]OnGOKD01_nGOKD3o`0000_oXXJf00?o0000ojf=]On]SKD02on]SKD0
0ol0003o]iBdokND]00<okND]003o`000?o0WKCo`9fd00Oo`9fd0_l00005olfV/@03o`000?oF[[3o
eZj`00ooeZj`00Co0000omne[?oO]Jco00003ooU^ZX00ol0003ojkjVon^nYP08on^nYP05o`000?o^
`JCok/6Tonk1Y?l000003Ooa`j400ol0003ollFOoo?5W`0:oo?5W`;o0000BOooool0013ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000fooooo`;o0000
1OlKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200;oKFg20ol000000on8Nkko0000
oi1k^008oi1k^003o`000?nGOKGoUgfe00Go00000_nDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`00
0?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@00ol0003o`9fdol2M]006ol2M]003o`00
0?o=Y[7o000000GocJJa00?o0000omJ^/?oF[[003_oF[[001Ol0003ogkF/omne[?oO]Jco000000ko
iKZZ00?o0000on^nY_o[_ZH02Oo[_ZH01Ol0003ok/6Tonk1Y?o^`JCo000000golL>Q00?o0000oo?5
WoocaIl02oocaIl00ol0003oooooooooo`17ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0dooooo`;o00001OlKCLL00ol0
003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200GoKFg23_l00007oiAn^@03o`000?nRQ[KoXXJf
00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd
00Go`9fd00Co0000olfV/Oo=Y[7o00001_o=Y[400ol0003oeZj`omJ^/00=omJ^/003o`000?oO]Jco
gkF/00;ogkF/00?o0000onFjZ_oU^ZX02ooU^ZX00ol0003ojkjVon^nYP0:on^nYP04o`000?o^`JCo
k/6To`0000golL>Q00?o0000oo?5WoocaIl02oocaIl2o`0004Sooooo000@ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo03Kooooo0_l0
0004oa]=a`03o`000?m<H<KoC63600CoC63600?o0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g
_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=
]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd00?o0000ol2M]?o0WK@01?o0WK@01?l0003ocJJaolfV
/Ol00006olfV/@03o`000?oF[[3oeZj`00goeZj`00?o0000omne[?oO]J`00_oO]J`00ol0003oiKZZ
onFjZP0;onFjZP03o`000?o[_ZKojkjV00_ojkjV0_l0000=oo73X@03o`000?ocaIoollFO00_ollFO
00Co0000ooC7X?l0003o0000Aoooool002[ooooo00?o0000ooooooooool0=_ooool2o`0000Go6dg7
00?o0000odaPa_m<H<H01?m<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm
00?o0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe
00?o0000okND]?ngU;@02ongU;@00ol0003o`9fdol2M]003ol2M]005o`000?o=Y[7ocJJaolfV/Ol0
00001oo=Y[400ol0003oeZj`omJ^/00;omJ^/003o`000?oO]JcogkF/00CogkF/00?o0000onFjZ_oU
^ZX02OoU^ZX00ol0003ojkjVon^nYP0=on^nYP03o`000?oa`j7olL>Q00_olL>Q00?o0000oo?5Wooc
aIl02oocaIl01?l0003om<NPooC7X?l00017ooooo`00:_ooool00ol0003oooooooooo`0gooooo`;o
00001?lKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200KoKFg200?o0000oh=g_On3
Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]
SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o0WKCo`9fd00?o`9fd00Go0000olfV/Oo=
Y[7ocJJao`000007olfV/@03o`000?oF[[3oeZj`00_oeZj`00?o0000omne[?oO]J`01OoO]J`00ol0
003oiKZZonFjZP08onFjZP03o`000?o[_ZKojkjV00gojkjV00?o0000oo73XOoa`j402ooa`j400ol0
003ollFOoo?5W`0;oo?5W`05o`000?odaj3om<NPooC7X?l00000A_ooool002[ooooo00?o0000oooo
ooooool0>?ooool00ol0003o6dg7oa]=a`03oa]=a`03o`000?m<H<KoC63600?oC63600?o0000ofe]
`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6
]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd00Go0000ol2M
]?o0WKCo`9fdo`000004olfV/@03o`000?o=Y[7ocJJa00KocJJa00?o0000omJ^/?oF[[002OoF[[00
0ol0003ogkF/omne[006omne[003o`000?oU^Z[oiKZZ00SoiKZZ00?o0000on^nY_o[_ZH03?o[_ZH0
0ol0003okl:So`00000<oo73X@03o`000?ocaIoollFO00[ollFO00?o0000ooC7X?odaj000oodaj00
0ol0003oooooooooo`13ooooo`00:Oooool3o`0003Wooooo0_l00004oa]=a`03o`000?m<H<KoC636
00CoC63600?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji
00SoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd
00_o]iBd00Co0000ol2M]?o0WKCo00001Oo=Y[400ol0003ocJJaolfV/@06olfV/@03o`000?oF[[3o
eZj`00WoeZj`00?o0000omne[?oO]J`01ooO]J`00ol0003oiKZZonFjZP06onFjZP03o`000?o[_ZKo
jkjV00gojkjV00Co0000ono2Xoo_`Z?o00002_oa`j400ol0003ollFOoo?5W`0;oo?5W`03o`000?od
aj3om<NP00?om<NP0_l00014ooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?lKCLOo
6dg700;o6dg700?o0000odaPa_m<H<H01?m<H<H00ol0003oKFg2ofe]`P06ofe]`P03o`000?n3Mkgo
PgNm00OoPgNm00?o0000oiAn^OnDO[T01onDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo
[Hfe00_o[Hfe00?o0000okND]?ngU;@02ongU;@01?l0003o`9fdol2M]?l00005olfV/@03o`000?o=
Y[7ocJJa00KocJJa00?o0000omJ^/?oF[[002?oF[[000ol0003ogkF/omne[008omne[003o`000?oU
^Z[oiKZZ00KoiKZZ00?o0000on^nY_o[_ZH03Oo[_ZH01Ol0003okl:Sono2Xoo_`Z?o000000WolL>Q
00?o0000oo?5WoocaIl02oocaIl00ol0003om<NPooC7X004ooC7X003o`000?oooooooooo04;ooooo
000Zooooo`03o`000?oooooooooo03Wooooo0_l00004oa]=a`03o`000?m<H<KoC63600?oC63600?o
0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o
0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00co]iBd0_l0
0006olfV/@03o`000?o=Y[7ocJJa00OocJJa00?o0000omJ^/?oF[[001ooF[[000ol0003ogkF/omne
[009omne[003o`000?oU^Z[oiKZZ00GoiKZZ00?o0000on^nY_o[_ZH03?o[_ZH00ol0003okl:Sono2
X`02ono2X`03o`000?oa`j7olL>Q00OolL>Q00?o0000oo?5WoocaIl02_ocaIl00ol0003om<NPooC7
X006ooC7X003o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000
oa]=aolKCLL00_lKCLL00ol0003oC636odaPaP04odaPaP03o`000?m]KL;oKFg200GoKFg200?o0000
oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000
ojf=]On]SKD02on]SKD00ol0003o]iBdokND]00;okND]003o`000?o=Y[7ocJJa00GocJJa00?o0000
olfV/Oo=Y[401oo=Y[400ol0003oeZj`omJ^/007omJ^/003o`000?oO]JcogkF/00[ogkF/00?o0000
onFjZ_oU^ZX00ooU^ZX00ol0003ojkjVon^nYP0=on^nYP03o`000?o_`Z?okl:S00?okl:S00?o0000
oo73XOoa`j401Ooa`j400ol0003ollFOoo?5W`0;oo?5W`03o`000?odaj3om<NP00Oom<NP00?o0000
ooooooooool0@?ooool002Wooooo00?o0000ooooooooool0??ooool01Ol0003o6dg7oa]=aolKCLOo
000000KoC63600?o0000ofe]`_m]KL801_m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[Wo
U7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co
]iBd00_o]iBd00?o0000olfV/Oo=Y[401Oo=Y[400ol0003ocJJaolfV/@08olfV/@03o`000?oF[[3o
eZj`00GoeZj`00?o0000omne[?oO]J`02ooO]J`00ol0003oiKZZonFjZP03onFjZP03o`000?o[_ZKo
jkjV00gojkjV00?o0000ono2Xoo_`Z<01?o_`Z<00ol0003olL>Qoo73X@04oo73X@03o`000?ocaIoo
llFO00_ollFO00?o0000ooC7X?odaj001oodaj000ol0003oooooooooo`10ooooo`00:Oooool00ol0
003oooooooooo`0looooo`03o`000?lKCLOo6dg700;o6dg700?o0000odaPa_m<H<H01?m<H<H00ol0
003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0
003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo[Hfe00_o[Hfe00?o0000okND]?ngU;@02_ngU;@00ol0
003o`indo`000006olfV/@03o`000?o=Y[7ocJJa00SocJJa00?o0000omJ^/?oF[[001OoF[[000ol0
003ogkF/omne[00<omne[003o`000?oU^Z[oiKZZ00;oiKZZ00?o0000on^nY_o[_ZH03?o[_ZH00ol0
003okl:Sono2X`05ono2X`03o`000?oa`j7olL>Q00ColL>Q00?o0000oo?5WoocaIl02oocaIl00ol0
003om<NPooC7X008ooC7X003o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo03go
oooo00Go0000oa]=aolKCLOo6dg7o`000006odaPaP03o`000?m]KL;oKFg200GoKFg200?o0000oh=g
_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=
]On]SKD02on]SKD00ol0003o]iBdokND]008okND]004o`000?o3WkCo`indo`0000KocJJa00?o0000
olfV/Oo=Y[402Oo=Y[400ol0003oeZj`omJ^/003omJ^/003o`000?oO]JcogkF/00gogkF/00Go0000
onFjZ_oU^Z[oiKZZo`00000?on^nYP03o`000?o_`Z?okl:S00Kokl:S00?o0000oo73XOoa`j400ooa
`j400ol0003ollFOoo?5W`0:oo?5W`03o`000?odaj3om<NP00[om<NP00?o0000ooooooooool0?_oo
ool002Wooooo0_l0000nooooo`;o00000olKCLL00ol0003oC636odaPaP03odaPaP03o`000?m]KL;o
KFg200KoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`000?nRQ[Ko
XXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]007okND]005o`000?o3WkCo
`indol>O]?l000001_o=Y[400ol0003ocJJaolfV/@09olfV/@03o`000?oF[[3oeZj`00?oeZj`00?o
0000omne[?oO]J`03_oO]J`01?l0003oiKZZonFjZ_l0000?on^nYP03o`000?o_`Z?okl:S00Ookl:S
00Go0000oo73XOoa`j7olL>Qo`00000=oo?5W`03o`000?odaj3om<NP00[om<NP0_l0000oooooo`00
:Oooool00ol0003oooooooooo`0nooooo`;o00000_lKCLL00ol0003oC636odaPaP04odaPaP03o`00
0?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`00
0?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]007okND]003o`00
0?o3WkCo`ind00;o`ind00?o0000olfV/Oo=Y[400oo=Y[400ol0003ocJJaolfV/@0:olfV/@05o`00
0?oF[[3oeZj`omJ^/?l000004_oO]J`00ol0003oiKZZo`00000>on^nYP03o`000?o_`Z?okl:S00Wo
kl:S00Co0000oo73XOoa`j7o00003OocaIl00ol0003om<NPooC7X009ooC7X003o`000?oebj?o0000
03oooooo000Yooooo`03o`000?oooooooooo03oooooo0_l000000olKCLOo0000odaPaP05odaPaP03
o`000?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03
o`000?nRQ[KoXXJf00WoXXJf00?o0000ojf=]On]SKD03?n]SKD00ol0003o]iBdokND]005okND]003
o`000?o3WkCo`ind00?o`ind00?o0000olfV/Oo=Y[400oo=Y[400ol0003ocJJaolfV/@0:olfV/@05
o`000?oF[[3oeZj`omJ^/?l000004_oO]J`2o`0000oojkjV00?o0000ono2Xoo_`Z<02Oo_`Z<01?l0
003olL>Qoo73XOl0000<oo?5W`03o`000?odaj3om<NP00[om<NP00Co0000ooG;Xooebj?o0000?_oo
ool002Wooooo00?o0000ooooooooool0?oooool01Ol0003o006Do`000?lKCLOo000000GoC63600?o
0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o
0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@03o`000?ngU;Co]iBd00Co]iBd00?o
0000ol>O]?o3Wk@01Oo3Wk@00ol0003ocJJaolfV/@02olfV/@03o`000?o=Y[7ocJJa00[ocJJa00Go
0000omJ^/?oF[[3oeZj`o`00000Comne[003o`000?o[_ZKojkjV00gojkjV00?o0000ono2Xoo_`Z<0
2_o_`Z<2o`0000gollFO00?o0000ooC7X?odaj002_odaj001Ol0003omL^SooG;Xooebj?o000003go
oooo000Yooooo`03o`000?oooooooooo043ooooo0_l000000olKCLOo0000odaPaP05odaPaP03o`00
0?m]KL;oKFg200GoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@07oiAn^@03o`00
0?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02on]SKD00ol0003o]iBdokND]003okND]003o`00
0?o3WkCo`ind00Ko`ind00?o0000olfV/Oo=Y[400_o=Y[400ol0003ocJJaolfV/@0;olfV/@03o`00
0?oF[[3o000001CogkF/00?o0000on^nY_o[_ZH03?o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`00
0?ocaIoollFO00_ollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`02ooG;X`;o0000
??ooool002Wooooo00?o0000ooooooooool0@?ooool01Ol0003o006Do`000?lKCLOo000000GoC636
00?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji
00?o0000oj:6]_nRQ[H02OnRQ[H00ol0003o[Hfeojf=]@0<ojf=]@05o`000?ngU;Co]iBdokND]?l0
00002Oo3Wk@00ol0003ocJJaolfV/@02olfV/@03o`000?o=Y[7ocJJa00_ocJJa00?o0000omJ^/?l0
00004ooO]J`00ol0003oik^Yo`00000=on^nYP03o`000?o_`Z?okl:S00cokl:S00?o0000oo?5Wooc
aIl02_ocaIl00ol0003om<NPooC7X00:ooC7X003o`000?oebj?omL^S00?omL^S00?o0000oooooooo
ool0>_ooool002Sooooo0ol00012ooooo`04o`000?l00ICo0000o`0000GoC63600?o0000ofe]`_m]
KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00SoU7ji00?o0000oj:6]_nR
Q[H02_nRQ[H00ol0003o[Hfeojf=]@0;ojf=]@05o`000?ngU;Co]iBdokND]?l000002_o3Wk@01Ol0
003ocJJaolfV/Oo=Y[7o000000kocJJa00?o0000omne[?oO]J`04_oO]J`00ol0003oik^Yo`00000=
on^nYP03o`000?o_`Z?okl:S00cokl:S0_l0000;oo?5W`03o`000?odaj3om<NP00[om<NP00?o0000
ooG;Xooebj<01?oebj<00ol0003oooooooooo`0iooooo`00:?ooool00ol0003oooooooooo`12oooo
o`04o`000?l00ICo006Do`0000KoC63600?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07
oh=g_@03o`000?nDO[WoU7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@0;
ojf=]@04o`000?ngU;Co]iBdo`0000_o`ind00Go0000olfV/Oo=Y[7ocJJao`00000>olfV/@03o`00
0?oO]JcogkF/01;ogkF/00Co0000onNkZOoW^jWo00002oo[_ZH00ol0003okl:Sono2X`0<ono2X`04
o`000?ocaj7ollNQo`0000[ollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`06ooG;
X`03o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03o`000?oooooooooo04?ooooo00Co0000
o`01U?l00ICo00001Om<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o
0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo[Hfe00co[Hfe0_l0
000=ol>O]004o`000?o=Y[7ocJJao`0000gocJJa00?o0000omR_/?l000004_oO]J`00ol0003oik^Y
onNkZ@02onNkZ@03o`000?o[_ZKojkjV00SojkjV00?o0000ono2Xoo_`Z<03?o_`Z<01Ol0003ollNQ
oo?7XOocaj7o000000WollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`06ooG;X`;o
0000>Oooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0A?ooool01?l0003o006Do`000?l00005
odaPaP03o`000?m]KL;oKFg200CoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08
oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD02_n]SKD2o`0000ko`ind00Co0000
olfV/Ol0003o00003Oo=Y[400ol0003of:n`o`00000Bomne[003o`000?oW^jWoik^Y00;oik^Y00?o
0000on^nY_o[_ZH02?o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00;ollNQ00?o
0000oo?5WoocaIl01OocaIl00ol0003om<NPooC7X00:ooC7X003o`000?oebj?omL^S00OomL^S00?o
0000ooooooooool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`14ooooo`03o`000?l00ICo006D00;o0000
1?m<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T0
1onDO[T00ol0003oXXJfoj:6]P0:oj:6]P03o`000?n]SKGo[Hfe00Wo[Hfe00?o0000okJG]ol00000
3Oo3Wk@3o`000003olfV/Ol0003ocJJa00_ocJJa00Go0000omR_/?oH[k3of:n`o`00000@omne[003
o`000?oW^jWoik^Y00Coik^Y00?o0000on^nY_o[_ZH01_o[_ZH00ol0003okl:Sono2X`0<ono2X`03
o`000?ocaj7ollNQ00CollNQ00?o0000oo?5WoocaIl01?ocaIl00ol0003om<NPooC7X009ooC7X003
o`000?oebj?omL^S00WomL^S00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15oooo
o`05o`000?l00ICo0000o`0c]ol000000om<H<H00ol0003oKFg2ofe]`P05ofe]`P03o`000?n3Mkgo
PgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0003oXXJfoj:6]P09oj:6]P03o`000?n]SKGo
[Hfe00So[Hfe00Go0000okJG]onfUkOo]YNgo`000009ol>O]0?o00000_o3Wk@01?l0003ocJJaolfV
/Ol0000;olfV/@05o`000?oH[k3of:n`omR_/?l000004?oO]J`00ol0003oik^YonNkZ@04onNkZ@03
o`000?o[_ZKojkjV00KojkjV00?o0000ono2Xoo_`Z<03?o_`Z<00ol0003ollNQoo?7X@04oo?7X@03
o`000?ocaIoollFO00CollFO00?o0000ooC7X?odaj002Oodaj000ol0003omL^SooG;X`0:ooG;X`03
o`000?oooooooooo03Gooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0AOooool01_l0003o006Do`01U?l0003o
03>go`0000?oC63600?o0000ofe]`_m]KL801?m]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nD
O[WoU7ji00SoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfeojf=]@06ojf=]@03o`000?nf
UkOo]YNg00;o]YNg00?o0000ol>O]?o3Wk@01?o3Wk@3o`0000Go`ind00Go0000olfV/Oo=Y[7ocJJa
o`000009olfV/@03o`000?oH[k3of:n`00?of:n`00?o0000omne[?oO]J`03?oO]J`00ol0003oik^Y
onNkZ@06onNkZ@03o`000?o[_ZKojkjV00GojkjV00?o0000ono2Xoo_`Z<03?o_`Z<00ol0003ollNQ
oo?7X@05oo?7X@03o`000?ocaIoollFO00;ollFO00?o0000ooC7X?odaj002_odaj000ol0003omL^S
ooG;X`0:ooG;X`;o0000=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003o006Do`000002o`0c]`04o`00
0?m<H<KoC636o`0000KoKFg200?o0000oh=g_On3Mkd02?n3Mkd00ol0003oU7jioiAn^@07oiAn^@03
o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD01On]SKD00ol0003o]YNgokJG]`03okJG]`04
o`000?o3WkCo`indol>O]0?o00002Oo3Wk@01Ol0003ocJJaolfV/Oo=Y[7o000000OocJJa00?o0000
omR_/?oH[k001?oH[k000ol0003ogkF/omne[00<omne[003o`000?oW^jWoik^Y00Ooik^Y00?o0000
on^nY_o[_ZH00oo[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00OollNQ00Go0000
oo?5WoocaIoollFOo`00000;ooC7X003o`000?oebj?omL^S00[omL^S00?o0000ooC?Z?l00000=_oo
ool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo0_l0
0018ooooo`04o`000?l00ICo006Do`0000;o03>g00?o0000odaPa_l000001om]KL800ol0003oPgNm
oh=g_@07oh=g_@03o`000?nDO[WoU7ji00OoU7ji00?o0000oj:6]_nRQ[H02_nRQ[H00ol0003o[Hfe
ojf=]@04ojf=]@03o`000?nfUkOo]YNg00Go]YNg0ol0000<ol>O]003o`000?o=Y[7ocJJa00;ocJJa
00?o0000olfV/Oo=Y[401?o=Y[400ol0003of:n`omR_/005omR_/003o`000?oO]JcogkF/00_ogkF/
00?o0000onNkZOoW^jT01ooW^jT00ol0003ojkjVon^nYP03on^nYP03o`000?o_`Z?okl:S00cokl:S
00?o0000oo?7XOocaj402?ocaj401?l0003ollFOoo?5Wol0000;ooC7X003o`000?oebj?omL^S00[o
mL^S00Co0000ooC?Z?odcjSo0000=Oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0B?ooool00ol0003o006Do`000003
o`0c]`03o`000?m<H<Ko000000KoKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08
oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00?o0000ojf=]On]SKD00_n]SKD00ol0003o]YNgokJG]`03
okJG]`Co00003_o3Wk@00ol0003ocJJaolfV/@03olfV/@03o`000?o=Y[7ocJJa00;ocJJa00?o0000
omR_/?oH[k001_oH[k000ol0003ogkF/omne[00:omne[003o`000?oW^jWoik^Y00Woik^Y00?o0000
on^nY_o[_ZH00_o[_ZH00ol0003okl:Sono2X`0<ono2X`03o`000?ocaj7ollNQ00WollNQ0_l0000<
ooC7X003o`000?oebj?omL^S00[omL^S00Go0000ooC?Z?odcjSom<nXo`00000dooooo`009oooool0
0ol0003oooooooooo`19ooooo`;o00001?l0<kL2o`0000KoKFg200?o0000oh=g_On3Mkd01on3Mkd0
0ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00[oXXJf00Go0000ojf=]On]SKGo[Hfeo`00
0003okJG]`?o00000onfUkL00ol0003o`indol>O]00=ol>O]003o`000?o=Y[7ocJJa00?ocJJa00Go
0000olfV/Oo=Y[7ocJJao`000009omR_/003o`000?oO]JcogkF/00WogkF/00?o0000onNkZOoW^jT0
2OoW^jT01Ol0003ojkjVon^nY_o[_ZKo000000ookl:S00?o0000oo?7XOocaj402_ocaj400ol0003o
m<NPooC7X009ooC7X003o`000?oebj?omL^S00[omL^S00?o0000ooC?Z?odcjP00oodcjP00ol0003o
ooooooooo`0aooooo`009oooool00ol0003oooooooooo`19ooooo`03o`000?l00ICo000000Co03>g
00?o0000ofe]`_m]KL801Om]KL800ol0003oPgNmoh=g_@07oh=g_@03o`000?nDO[WoU7ji00OoU7ji
00?o0000oj:6]_nRQ[H02_nRQ[H01Ol0003o[Hfeojf=]Ol0003o]YNg00?o00001onfUkL00ol0003o
`indol>O]00<ol>O]003o`000?o=Y[7ocJJa00CocJJa00?o0000olfV/Ol000002_oH[k000ol0003o
gkF/omne[008omne[003o`000?oW^jWoik^Y00_oik^Y00Co0000on^nY_o[_ZKo00003_o_`Z<00ol0
003ollNQoo?7X@0;oo?7X@03o`000?odaj3om<NP00Wom<NP00?o0000ooG;Xooebj<02_oebj<00ol0
003om<nXooC?Z003ooC?Z0;o0000<_ooool002Oooooo00?o0000ooooooooool0B_ooool2o`0000Go
03>g0_l00005ofe]`P03o`000?n3MkgoPgNm00OoPgNm00?o0000oiAn^OnDO[T02?nDO[T00ol0003o
XXJfoj:6]P0:oj:6]PCo00002_nfUkL00ol0003o`indol>O]00=ol>O]003o`000?o=Y[7ocJJa00?o
cJJa00?o0000olfV/Ol000002ooH[k000ol0003ogkF/omne[007omne[003o`000?oW^jWoik^Y00co
ik^Y00?o0000on^nY_l000003_o_`Z<00ol0003ollNQoo?7X@0;oo?7X@;o00002_odaj000ol0003o
mL^SooG;X`09ooG;X`03o`000?odcjSom<nX00Gom<nX00?o0000ooooooooool0<?ooool002Oooooo
00?o0000ooooooooool0B_ooool00ol0003o006Do`000004o`0c]`03o`000?m4FL?o000000CoKFg2
00?o0000oh=g_On3Mkd01on3Mkd00ol0003oU7jioiAn^@08oiAn^@03o`000?nRQ[KoXXJf00SoXXJf
0ol0000=okJG]`03o`000?o3WkCo`ind00go`ind00?o0000olfV/Oo=Y[401?o=Y[400ol0003of:n`
omR_/00:omR_/003o`000?oO]JcogkF/00KogkF/00?o0000onNkZOoW^jT03OoW^jT2o`0000ookl:S
00?o0000oo?7XOocaj402_ocaj401?l0003om/bQooK<XOl00008ooC7X003o`000?oebj?omL^S00[o
mL^S00?o0000ooC?Z?odcjP01_odcjP00ol0003oooooooooo`0_ooooo`009oooool2o`0004cooooo
0_l00005o`0c]`04o`000?m4FL?o0000o`0000?oKFg200?o0000oh=g_On3Mkd01on3Mkd00ol0003o
U7jioiAn^@07oiAn^@03o`000?nRQ[KoXXJf00GoXXJf1?l000000onWS[_o0000okJG]`0=okJG]`03
o`000?o3WkCo`ind00co`ind00?o0000olfV/Oo=Y[401?o=Y[42o`0000_of:n`00?o0000omne[?oO
]J`01_oO]J`00ol0003oik^YonNkZ@0>onNkZ@03o`000?o_`Z?okl:S00cokl:S00?o0000oo?7XOoc
aj402oocaj401Ol0003om/bQooK<XOofc:7o000000Oom<NP00?o0000ooG;Xooebj<02_oebj<00ol0
003om<nXooC?Z007ooC?Z003o`000?oooooooooo02kooooo000Vooooo`;o0000COooool00ol0003o
006Do`000004o`0c]`05o`000?m4FL?oA5W3odAI`ol000000_m]KL800ol0003oPgNmoh=g_@07oh=g
_@03o`000?nDO[WoU7ji00SoU7ji00Co0000oj:6]_nRQ[KoXXJf1Ol00004ojN>^`03o`000?nfUkOo
]YNg00_o]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@00ol0003ocJJaolfV/@02olfV/@04o`000?oH[k3o
f:n`o`0000_of:n`00?o0000omne[?oO]J`01OoO]J`00ol0003oik^YonNkZ@0>onNkZ@03o`000?o_
`Z?okl:S00cokl:S00?o0000oo?7XOocaj402oocaj400ol0003om/bQooK<X@02ooK<X@03o`000?od
aj3om<NP00Com<NP00?o0000ooG;Xooebj<02Ooebj<00ol0003om<nXooC?Z008ooC?Z0;o0000;ooo
ool002Oooooo00?o0000ooooooooool0C?ooool2o`0000Co03>g00?o0000odAI`om4FL<00_m4FL<3
o`0000WoPgNm00?o0000oiAn^OnDO[T02?nDO[T4o`0000;oXXJf00?o0000ojN>^onWS[/01?nWS[/0
0ol0003o]YNgokJG]`0;okJG]`03o`000?o3WkCo`ind00go`ind00Go0000olfV/Oo=Y[7ocJJao`00
0004omR_/003o`000?oH[k3of:n`00Sof:n`00?o0000omne[?oO]J`01?oO]J`00ol0003oik^YonNk
Z@0>onNkZ@03o`000?o]`ZOo000000gokl:S00?o0000oo?7XOocaj402_ocaj400ol0003om/bQooK<
X@04ooK<X@03o`000?odaj3om<NP00;om<NP00?o0000ooG;Xooebj<02_oebj<00ol0003om<nXooC?
Z009ooC?Z0;o0000;_ooool002Oooooo00?o0000ooooooooool0COooool2o`0000Co03>g00?o0000
odAI`om4FL<00om4FL<2o`0000WoPgNm00?o0000oiAn^OnDO[T01OnDO[T3o`0000?oXXJf0_l00007
ojN>^`03o`000?nfUkOo]YNg00co]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@01?l0003ocJJaolfV/Ol0
0005omR_/003o`000?oH[k3of:n`00Sof:n`00?o0000omne[?oO]J`00ooO]J`00ol0003oik^YonNk
Z@0>onNkZ@04o`000?o]`ZOokL:Wo`0000_okl:S00?o0000oo?7XOocaj402oocaj400ol0003om/bQ
ooK<X@05ooK<X@05o`000?odaj3om<NPooC7X?l000002ooebj<00ol0003om<nXooC?Z00;ooC?Z003
o`000?oooooooooo02cooooo000Vooooo`03o`000?oooooooooo04kooooo0_l00004o`0c]`03o`00
0?m4FL?oA5W300CoA5W30ol00007oh=g_@03o`000?nDO[WoU7ji00;oU7ji0ol00003oiAn^@?o0000
2_nWS[/00ol0003o]YNgokJG]`0;okJG]`03o`000?o3WkCo`ind00go`ind00?o0000olfV/Ol00000
1ooH[k000ol0003of:n`omR_/007omR_/003o`000?oO]JcogkF/00;ogkF/00?o0000onNkZOoW^jT0
3ooW^jT01Ol0003okL:Wong2Yoo]`ZOo000000[okl:S00?o0000oo?7XOocaj402oocaj400ol0003o
m/bQooK<X@06ooK<X@04o`000?odaj3om<NPo`0000_omL^S00?o0000ooC?Z?odcjP02_odcjP00ol0
003olmJao`00000]ooooo`009_ooool00ol0003oooooooooo`1?ooooo`;o00000ol0<kL00ol0003o
A5W3odAI``04odAI``03o`000?mbL/?oLW;300Co00000on3Mkd00ol0003oU7jio`000002o`0000Co
U7ji0ol0000<ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@03Oo3Wk@00ol0003o
cJJao`000008omR_/003o`000?oH[k3of:n`00Oof:n`00Go0000omne[?oO]JcogkF/o`00000@onNk
Z@03o`000?o]`ZOokL:W00?okL:W00?o0000ono2Xoo_`Z<01oo_`Z<00ol0003ollNQoo?7X@0:oo?7
X@03o`000?ofc:7om/bQ00Som/bQ0_l0000<ooG;X`03o`000?odcjSom<nX00[om<nX00Co0000oo?F
/Ol0003o0000;?ooool002Kooooo00?o0000ooooooooool0Coooool2o`0000Co03>g00?o0000odAI
`om4FL<01?m4FL<00ol0003oLW;3og9b``03og9b``Go00000_nDO[T5o`0000;oTH:o00?o0000ojN>
^onWS[/02_nWS[/00ol0003o]YNgokJG]`0<okJG]`03o`000?o3WkCo`ind00go`ind00?o0000omR_
/?oH[k001ooH[k000ol0003of:n`omR_/007omR_/004o`000?oO]JcogkF/o`00017oik^Y00?o0000
ong2Yoo]`ZL00oo]`ZL00ol0003okl:Sono2X`07ono2X`03o`000?ocaj7ollNQ00[ollNQ00?o0000
ooK<XOofc:402Oofc:42o`0000[omL^S00?o0000ooC?Z?odcjP02_odcjP01Ol0003olmJaoo?F/Ooc
e[7o000002cooooo000Vooooo`;o0000DOooool2o`0000?o03>g00?o0000odAI`om4FL<01?m4FL<0
0ol0003oLW;3og9b``03og9b``;o000000?oLW;3o`000?l000000_l00008oi62_`03o`000?nWS[_o
Yhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0003o`indol>O]00=ol>O]003o`000?oH[k3o
f:n`00Sof:n`00?o0000omR_/?oH[k001ooH[k000ol0003ogkF/o`00000AonNkZ@03o`000?o]`ZOo
kL:W00CokL:W00?o0000ono2Xoo_`Z<01Oo_`Z<00ol0003ollNQoo?7X@0;oo?7X@03o`000?ofc:7o
m/bQ00Wom/bQ00?o0000ooSBXol000002Ooebj<00ol0003om<nXooC?Z00:ooC?Z003o`000?oce[7o
lmJa00;olmJa00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0D?ooool2o`00
00Co03>g00?o0000odAI`om4FL<00om4FL<00ol0003oLW;3og9b``03o`0000CoLW;300?o0000oi62
_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O
]?o3Wk@03?o3Wk@00ol0003ocZVdo`00000:omR_/003o`000?oH[k3of:n`00Kof:n`00?o0000omne
[?l000004?oW^jT00ol0003okL:Wong2Y`06ong2Y`03o`000?o_`Z?okl:S00Cokl:S00?o0000oo?7
XOocaj402_ocaj400ol0003om/bQooK<X@09ooK<X@05o`000?ohdZ?on=:SooSBXol000002?oebj<0
0ol0003om<nXooC?Z00:ooC?Z003o`000?oce[7olmJa00?olmJa00?o0000ooooooooool0:?ooool0
02Kooooo00?o0000ooooooooool0DOooool00ol0003o03>go`0c]`02o`0c]`03o`000?m4FL?oA5W3
00?oA5W30ol00008og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0
003o]YNgokJG]`0<okJG]`03o`000?o3WkCo`ind00[o`ind00Co0000oljY]?o>ZKCo00002ooH[k00
0ol0003of:n`omR_/006omR_/003o`000?oW^jWoik^Y00ooik^Y00?o0000ong2Yoo]`ZL01oo]`ZL0
0ol0003okl:Sono2X`03ono2X`03o`000?ocaj7ollNQ00[ollNQ00?o0000ooK<XOofc:402Oofc:40
0ol0003on=:SooSBX`02ooSBX`03o`000?oebj?omL^S00ComL^S00?o0000ooC?Z?odcjP02_odcjP0
0ol0003olmJaoo?F/@04oo?F/@03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oooooooooo
057ooooo0_l00003o`0c]`03o`000?m4FL?oA5W300?o000000?oA5W3o`000?mbL/<02?mbL/<00ol0
003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0
003o`indol>O]00:ol>O]005o`000?o>ZKCocZVdoljY]?l000002ooH[k000ol0003of:n`omR_/005
omR_/003o`000?oW^jWoik^Y00ooik^Y00?o0000ong2Yoo]`ZL01oo]`ZL00ol0003okl:Sono2X`02
ono2X`03o`000?ocaj7ollNQ00_ollNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:SooSBX`03
ooSBX`03o`000?oebj?omL^S00?omL^S00?o0000ooC?Z?odcjP02_odcjP00ol0003olmJaoo?F/@05
oo?F/@03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo05;ooooo00Co0000o`0c
]ol0<kOo03>g0ol00004odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62_onAP[l02?nAP[l0
0ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@02Oo3Wk@0
0ol0003ocZVdoljY]002oljY]003o`000?oH[k3of:n`00[of:n`00?o0000omR_/?oH[k000ooH[k00
0ol0003ohKV^o`00000?onNkZ@03o`000?o]`ZOokL:W00WokL:W00Go0000ono2Xoo_`Z?okl:So`00
000<oo?7X@03o`000?ofc:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<01OohdZ<01Ol0003omL^SooG;
Xooebj?o000000com<nX00?o0000oo?F/Ooce[401ooce[400ol0003oooooooooo`0Vooooo`009_oo
ool00ol0003oooooooooo`1Cooooo`?o000000?o03>go`000?m4FL<01Om4FL<00ol0003oLW;3og9b
``07og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0003o]YNgokJG
]`0<okJG]`03o`000?o3WkCo`ind00Oo`ind00?o0000oljY]?o>ZK@01?o>ZK@00ol0003of:n`omR_
/00:omR_/003o`000?oH[k3of:n`00;of:n`00?o0000on6i[_l000003ooW^jT00ol0003okL:Wong2
Y`0:ong2Y`04o`000?o_`Z?okl:So`0000collNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:S
ooSBX`06ooSBX`04o`000?oebj?omL^So`0000com<nX00?o0000oo?F/Ooce[401ooce[42o`0002Oo
oooo000Uooooo`03o`000?oooooooooo057ooooo1?l00004o`0c]`03o`000?m4FL?oA5W300?oA5W3
00?o0000og9b`ombL/<01ombL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk
00?o0000okJG]onfUkL02onfUkL00ol0003o`indol>O]007ol>O]003o`000?o>ZKCocZVd00CocZVd
00?o0000omR_/?oH[k002_oH[k001Ol0003of:n`omR_/?oH[k3o000000?ohKV^00?o0000onNkZOoW
^jT03?oW^jT00ol0003okL:Wong2Y`0;ong2Y`;o00003Oocaj400ol0003om/bQooK<X@09ooK<X@03
o`000?ohdZ?on=:S00Oon=:S00?o0000ooG;Xol000002oodcjP00ol0003olmJaoo?F/@09oo?F/@03
o`000?oooooooooo02Gooooo000Uooooo`?o0000C_ooool3o`0000Cooooo00Go0000o`0c]ol0<kOo
03>go`000006odAI``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003o
YhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@01_o3Wk@00ol0003o
cZVdoljY]005oljY]003o`000?oH[k3of:n`00_of:n`00Co0000omR_/?oH[k3o00001?oQ^Jh00ol0
003oik^YonNkZ@0:onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo?7XOocaj402oocaj400ol0
003om/bQooK<X@08ooK<X@03o`000?ohdZ?on=:S00Won=:S0_l0000;ooC?Z003o`000?oce[7olmJa
00[olmJa00?o0000ooooooooool09?ooool002Gooooo00?o0000ooooooooool0Boooool3o`0000Oo
oooo00Go0000o`0c]ol0<kOo03>go`000006odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62
_onAP[l01onAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00co]YNg00?o0000ol>O
]?o3Wk@01?o3Wk@00ol0003ocZVdoljY]007oljY]003o`000?oH[k3of:n`00_of:n`00?o0000omR_
/?l000001?oQ^Jh00ol0003oik^YonNkZ@0:onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo?7
XOocaj402_ocaj400ol0003om/bQooK<X@09ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o0000ooWJ
Yol000002OodcjP00ol0003olmJaoo?F/@0;oo?F/@;o00009Oooool000Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o0000
ooooooooool0B?ooool3o`0000_ooooo00Go0000o`0c]ol0<kOo03>go`000005odAI``03o`000?mb
L/?oLW;300OoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nf
UkOo]YNg00_o]YNg00?o0000ol>O]?o3Wk@00oo3Wk@00ol0003ocZVdoljY]008oljY]003o`000?oH
[k3of:n`00cof:n`00?o0000on6i[_oQ^Jh01?oQ^Jh00ol0003oik^YonNkZ@08onNkZ@03o`000?o]
`ZOokL:W00gokL:W00?o0000oo;9YOl000002oocaj400ol0003om/bQooK<X@09ooK<X@03o`000?oh
dZ?on=:S00Son=:S00Go0000ooWJYooifZOonMZWo`000008ooC?Z003o`000?oce[7olmJa00[olmJa
00Co0000ongN`_l0003o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`00
00kooooo0_l00002o`0c]`03o`000?m4FL?oA5W300CoA5W300?o0000og9b`ombL/<01_mbL/<00ol0
003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL00ol0
003o`indol>O]003ol>O]003o`000?o>ZKCocZVd00WocZVd00?o0000omR_/?oH[k002ooH[k02o`00
00GohKV^00?o0000onNkZOoW^jT02?oW^jT00ol0003okL:Wong2Y`0=ong2Y`04o`000?obbJGol/VU
o`0000[ollNQ00?o0000ooK<XOofc:402?ofc:400ol0003on=:SooSBX`09ooSBX`03o`000?oifZOo
nMZW00;onMZW00?o0000ooC?Z?odcjP01?odcjP00ol0003olmJaoo?F/@0:oo?F/@05o`000?o]g/;o
kMk2ongN`_l000009?ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o00004_ooool01?l0003o03>g
o`0c]ol00006odAI``03o`000?mbL/?oLW;300OoLW;300?o0000oi62_onAP[l01onAP[l00ol0003o
YhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00co]YNg00Go0000ol>O]?o3WkCo`indo`00000<oljY
]003o`000?oH[k3of:n`00[of:n`00Co0000on6i[_oQ^Jko00001OoQ^Jh00ol0003oik^YonNkZ@07
onNkZ@03o`000?o]`ZOokL:W00gokL:W00Go0000oo;9YOobbJGol/VUo`000008oo?7X@03o`000?of
c:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`03ooWJY`03o`000?od
cjSom<nX00?om<nX00?o0000oo?F/Ooce[402_oce[400ol0003okMk2ongN`P02ongN`P03o`000?oo
oooooooo027ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Oooooo00?o0000ooooooooool0?oooool3o`0001Gooooo0_l00002o`0c]`03o`00
0?m4FL?oA5W300?oA5W300?o0000og9b`ombL/<01ombL/<00ol0003oTH:ooi62_`08oi62_`03o`00
0?nWS[_oYhjk00[oYhjk00?o0000okJG]onfUkL02onfUkL01?l0003o`indol>O]?l0000>oljY]003
o`000?oH[k3of:n`00Wof:n`00Go0000on6i[_oQ^JkohKV^o`000005on6i[P03o`000?oW^jWoik^Y
00Goik^Y00?o0000ong2Yoo]`ZL03Oo]`ZL00ol0003ol/VUoo;9Y@03oo;9Y@03o`000?ocaj7ollNQ
00GollNQ00?o0000ooK<XOofc:402Oofc:400ol0003on=:SooSBX`08ooSBX`03o`000?oifZOonMZW
00GonMZW00?o0000ooC?Z?odcjP00_odcjP00ol0003olmJaoo?F/@09oo?F/@03o`000?o]g/;okMk2
00?okMk20_l0000Rooooo`002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c007ooooo`03o`000?oooooooooo03cooooo0ol0000Iooooo`;o000000?o03>g
o`000?m4FL<01Om4FL<00ol0003oLW;3og9b``06og9b``03o`000?nAP[ooTH:o00SoTH:o00?o0000
ojN>^onWS[/02_nWS[/00ol0003o]YNgokJG]`0;okJG]`04o`000?o3WkCo`indo`0000kocZVd00?o
0000omR_/?oH[k002?oH[k000ol0003ohKV^on6i[P03on6i[P03o`000?oQ^JkohKV^00;ohKV^00?o
0000onNkZOoW^jT01OoW^jT00ol0003okL:Wong2Y`0=ong2Y`03o`000?obbJGol/VU00Col/VU00?o
0000oo?7XOocaj401?ocaj400ol0003om/bQooK<X@08ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o
0000ooWJYooifZL01_oifZL01?l0003om<nXooC?Z?l0000;oo?F/@03o`000?o]g/;okMk200GokMk2
0_l0000Qooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4007ooooo`03o`000?oooooooooo03Wooooo0ol0000Mooooo`;o000000?o03>go`000?m4
FL<01?m4FL<00ol0003oLW;3og9b``07og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onW
S[/02_nWS[/00ol0003o]YNgokJG]`0<okJG]`;o00004?o>ZK@00ol0003of:n`omR_/007omR_/003
o`000?oQ^JkohKV^00?ohKV^00?o0000on6i[_oQ^Jh00ooQ^Jh00ol0003oik^YonNkZ@04onNkZ@03
o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOobbJD01OobbJD00ol0003ollNQoo?7X@02oo?7X@03
o`000?ofc:7om/bQ00Wom/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`07ooWJY`03
o`000?odcjSo000000_olmJa00?o0000ongN`_o]g/801_o]g/800ol0003oooooooooo`0Oooooo`00
2Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo03Oooooo0ol0000Pooooo`;o000000?o03>go`000?m4FL<01Om4FL<00ol0
003oLW;3og9b``06og9b``03o`000?nAP[ooTH:o00SoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0
003o]YNgokJG]`0;okJG]`03o`000?o>ZKCocZVd00oocZVd00?o0000omR_/?oH[k001ooH[k000ol0
003ohKV^on6i[P04on6i[P03o`000?oQ^JkohKV^00;ohKV^00?o0000onNkZOoW^jT00ooW^jT00ol0
003okL:Wong2Y`0=ong2Y`03o`000?obbJGol/VU00Ool/VU00Go0000oo?7XOocaj7ollNQo`00000;
ooK<X@03o`000?ohdZ?on=:S00Son=:S00?o0000ooWJYooifZL02OoifZL2o`0000[olmJa00?o0000
ongN`_o]g/801oo]g/82o`00023ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0=?ooool3o`0002Cooooo0ol0
0006odAI``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>
^`0:ojN>^`03o`000?nfUkOo]YNg00_o]YNg00?o0000oljY]?o>ZK@04?o>ZK@00ol0003of:n`omR_
/005omR_/003o`000?oQ^JkohKV^00KohKV^00?o0000on6i[_oQ^Jh00_oQ^Jh00ol0003oik^YonNk
Z@02onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOobbJD02?obbJD01?l0003ollNQoo?7
XOl0000:ooK<X@03o`000?ohdZ?on=:S00Won=:S00?o0000ooWJYooifZL02OoifZL00ol0003on>F`
o`000009oo?F/@03o`000?o]g/;okMk200SokMk20_l0000Oooooo`009?ooool00ol0003ooooooooo
o`0aooooo`?o00009oooool01?l0003o002<o`000?l00005odAI``03o`000?mbL/?oLW;300OoLW;3
00?o0000oi62_onAP[l01onAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00[o]YNg
00?o0000ol6R^_l000004Oo>ZK@00ol0003of:n`omR_/005omR_/003o`000?oQ^JkohKV^00OohKV^
00Go0000on6i[_oQ^JkohKV^o`000004onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000oo;9YOob
bJD02OobbJD2o`0000_om/bQ00?o0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`05
o`000?ohiK3on>F`ooSU/?l000001ooce[400ol0003okMk2ongN`P0:ongN`P;o00007_ooool002Co
oooo00?o0000ooooooooool0;oooool2o`0002_ooooo0ol00006odAI``03o`000?mbL/?oLW;300Ko
LW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00So
]YNg00Co0000ol6R^_o1X[[o00004_o>ZK@00ol0003of:n`omR_/003omR_/003o`000?oQ^JkohKV^
00WohKV^00Go0000on6i[_oQ^JkohKV^o`000002onNkZ@03o`000?o]`ZOokL:W00gokL:W00?o0000
oo;9YOobbJD02oobbJD2o`0000[om/bQ00?o0000ooSBXoohdZ<02?ohdZ<00ol0003onMZWooWJY`09
ooWJY`03o`000?ohiK3on>F`00;on>F`0_l00004oo?F/@03o`000?o]g/;okMk200_okMk20_l0000N
ooooo`009?ooool00ol0003oooooooooo`0/ooooo`?o0000;Oooool00ol0003o002<o`000006odAI
``03o`000?mbL/?oLW;300KoLW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>
^`03o`000?nfUkOo]YNg00Oo]YNg00?o0000ol6R^_o1X[X00_o1X[X00ol0003ocZVdoljY]00?oljY
]003o`000?oH[k3of:n`00?of:n`00?o0000on6i[_oQ^Jh02_oQ^Jh01ol0003ohKV^on6i[_oQ^Jko
0000onNkZOl000003oo]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?ogdJGo000000Som/bQ00?o
0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Gon>F`00Go
0000oo?F/Ooce[7olmJao`00000<ongN`P04o`000?oKi]co0000o`0001gooooo000Tooooo`03o`00
0?oooooooooo02Wooooo0ol0000aooooo`04o`000?l008co0000o`0000CoA5W300?o0000og9b`omb
L/<01ombL/<00ol0003oTH:ooi62_`07oi62_`03o`000?nWS[_oYhjk00[oYhjk00?o0000okJG]onf
UkL01_nfUkL00ol0003o`J:jol6R^P03ol6R^P03o`000?o>ZKCocZVd00oocZVd00?o0000omR_/?oH
[k000_oH[k000ol0003ohKV^on6i[P0<on6i[P06o`000?oQ^JkohKV^o`000?oW^jWo00003oo]`ZL0
0ol0003ol/VUoo;9Y@0:oo;9Y@05o`000?ogdJGomm6UooOAYOl000001oofc:400ol0003on=:SooSB
X`09ooSBX`03o`000?oifZOonMZW00SonMZW00?o0000ooSU/?ohiK001_ohiK000ol0003olmJao`00
000<ongN`P04o`000?oKi]cofnKLom_Vg0;o00007?ooool002Cooooo00?o0000ooooooooool09_oo
ool3o`0003Cooooo00Go0000o`00S?l0003o1S^lo`000004odAI``03o`000?mbL/?oLW;300KoLW;3
00?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`03o`000?nfUkOo]YNg00Co]YNg
00?o0000ol6R^_o1X[X01?o1X[X00ol0003ocZVdoljY]00@oljY]005o`000?oH[k3of:n`omR_/?l0
00003ooQ^Jh01?l0003ohKV^on6i[_l0000?ong2Y`03o`000?obbJGol/VU00_ol/VU00?o0000ooOA
YOogdJD00_ogdJD00ol0003om/bQooK<X@04ooK<X@03o`000?ohdZ?on=:S00Son=:S00?o0000ooWJ
YooifZL02?oifZL00ol0003on>F`ooSU/008ooSU/0;o00002oo]g/800ol0003ofnKLom_Vg003om_V
g0;o00006oooool002?ooooo0_l0000Uooooo`?o0000>?ooool01Ol0003o002<o`000?l6>kco0000
00?oA5W300?o0000og9b`ombL/<01_mbL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk
00[oYhjk00?o0000okJG]onfUkL01?nfUkL00ol0003o`J:jol6R^P05ol6R^P03o`000?o>ZKCocZVd
00oocZVd00Go0000omR_/?oH[k3of:n`o`00000?on6i[P04o`000?oQ^JkohKV^o`0000ookL:W00?o
0000oo;9YOobbJD02oobbJD00ol0003omm6UooOAY@03ooOAY@03o`000?ofc:7om/bQ00;om/bQ00?o
0000ooSBXoohdZ<02OohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Son>F`00?o
0000oo3c`?l000002Oo]g/800ol0003ofnKLom_Vg005om_Vg003o`000?oooooooooo01Wooooo000T
ooooo`03o`000?oooooooooo023ooooo0ol0000kooooo`03o`000?l008co000000;o1S^l00Go0000
odAI`om4FL?oA5W3o`000008og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nW
S[/00ol0003o]YNgokJG]`03okJG]`03o`000?o1X[[o`J:j00Ko`J:j00?o0000oljY]?o>ZK@04?o>
ZK@00ol0003of:n`o`00000Aon6i[P;o000000?ojL:]o`000?o]`ZL03?o]`ZL00ol0003ol/VUoo;9
Y@0;oo;9Y@03o`000?ogdJGomm6U00Gomm6U00Go0000ooK<XOofc:7om/bQo`00000;ooSBX`03o`00
0?oifZOonMZW00OonMZW00?o0000ooSU/?ohiK002?ohiK001?l0003ol??0oo3c`?o`ll02o`0000Ko
kMk200?o0000om_Vg?oKi]`01ooKi]`00ol0003oooooooooo`0Hooooo`008oooool00ol0003ooooo
ooooo`0Nooooo`?o0000?oooool00ol0003o002<o`000002o`Hk_004o`000?m4FL?oA5W3o`0000So
LW;300?o0000oi62_onAP[l02?nAP[l00ol0003oYhjkojN>^`0:ojN>^`05o`000?nfUkOo]YNgokJG
]ol000002_o1X[X00ol0003ocZVdoljY]00?oljY]003o`000?oH[k3o000001;ohKV^00Co0000onW2
[OoY`Zgo00003?o]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?ogdJGomm6U00Komm6U00Co0000
ooK<XOofc:7o00002_ohdZ<00ol0003onMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Oon>F`00?o
0000oo3c`?o`ll001?o`ll02o`0000?okMk200?o0000om_Vg?oKi]`02OoKi]`00ol0003ooooooooo
o`0Gooooo`008oooool00ol0003oooooooooo`0Kooooo`?o0000@oooool2o`0000?o1S^l00?o0000
odAI`ol000002?mbL/<00ol0003oTH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00[oYhjk00Co0000
okJG]onfUkOo00002oo1X[X00ol0003ocZVdoljY]00@oljY]003o`000?oQ^JkohKV^017ohKV^0_l0
0002onW2[@03o`000?o]`ZOokL:W00WokL:W00?o0000oo;9YOobbJD02oobbJD00ol0003omm6UooOA
Y@07ooOAY@;o00002oohdZ<00ol0003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Son>F`00?o
0000oo3c`?o`ll001_o`ll000ol0003okMk2o`00000<om_Vg0;o00006?ooool002?ooooo00?o0000
ooooooooool06?ooool3o`0004Kooooo00?o0000o`00S?l000000ol6>k`00ol0003oA5W3o`000008
og9b``03o`000?nAP[ooTH:o00OoTH:o00?o0000ojN>^onWS[/02_nWS[/00ol0003o]YNgo`00000=
ol6R^P03o`000?o>ZKCocZVd00oocZVd00?o0000on6i[_oQ^Jh04?oQ^Jh01?l0003ojL:]onW2[Ol0
0002onW2[@03o`000?o]`ZOokL:W00OokL:W00?o0000oo;9YOobbJD02oobbJD00ol0003omm6UooOA
Y@09ooOAY@;o00002_ohdZ<00ol0003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Oon>F`00?o
0000oo3c`?o`ll002?o`ll02o`0000gofnKL00?o0000ooooooooool05_ooool002?ooooo00?o0000
ooooooooool05Oooool3o`0004[ooooo0_l00004o`Hk_0;o00002?mbL/<00ol0003oTH:ooi62_`08
oi62_`03o`000?nWS[_oYhjk00WoYhjk0_l0000>ol6R^P03o`000?o>ZKCocZVd00kocZVd00?o0000
omVe]Ol000004OoQ^Jh01ol0003ojL:]onW2[OoY`Zgo0000onW2[Ol000002Oo]`ZL00ol0003ol/VU
oo;9Y@0;oo;9Y@03o`000?ogdJGomm6U00Womm6U00Co0000oo[JYOl0003o00001oohdZ<00ol0003o
nMZWooWJY`08ooWJY`03o`000?ohiK3on>F`00Kon>F`00?o0000oo3c`?o`ll002?o`ll001?l0003o
d?oGom3oeol0000=om_Vg003o`000?oooooooooo01Gooooo000Sooooo`03o`000?oooooooooo01;o
oooo0ol0001=ooooo`03o`000?l008co000000Co1S^l00?o0000og9b`ombL/<01_mbL/<00ol0003o
TH:ooi62_`08oi62_`03o`000?nWS[_oYhjk00OoYhjk0_l000000on]V<7o0000ol6R^P0=ol6R^P03
o`000?o>ZKCocZVd00gocZVd00Co0000omVe]OoI]KGo00004?oQ^Jh00ol0003ojL:]onW2[@03onW2
[@03o`000?oY`Zgo000000SokL:W00?o0000oo;9YOobbJD02_obbJD00ol0003omm6UooOAY@09ooOA
Y@03o`000?ojfZGon]ZU00;on]ZU0_l00005ooSBX`03o`000?oifZOonMZW00OonMZW00?o0000ooSU
/?ohiK001oohiK000ol0003ol??0oo3c`007oo3c`003o`000?o@omOod?oG00;od?oG0_l0000<om_V
g003o`000?oooooooooo01Cooooo000Rooooo`?o00004?ooool3o`00057ooooo0_l00005o`Hk_0;o
00001ombL/<00ol0003oTH:ooi62_`07oi62_`03o`000?nWS[_oYhjk00GoYhjk0_l00004ojfH`@03
o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?o>ZK@03?o>ZK@01Ol0003ofKFeomVe]OoI]KGo0000
00oohKV^00?o0000onW2[OoY`Zd01?oY`Zd00ol0003ojL:]o`000006ong2Y`03o`000?obbJGol/VU
00_ol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@04oo[JY@;o00000oohdZ<00ol0
003onMZWooWJY`07ooWJY`03o`000?ohiK3on>F`00Kon>F`00?o0000oo3c`?o`ll001oo`ll000ol0
003od?oGom3oe`05om3oe`;o00002OoKi]`3o`0001Gooooo000Sooooo`03o`000?oooooooooo00co
oooo0ol0001Dooooo`03o`000?l008co000000Co1S^l00?o0000oeY/bol000000_l00004og9b``03
o`000?nAP[ooTH:o00SoTH:o00?o0000ojN>^onWS[/00onWS[/00ol0003o[IS1ojfH`@04ojfH`@03
o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?o>ZK@02oo>ZK@00ol0003ofKFeomVe]@02omVe]@03
o`000?oQ^JkohKV^00cohKV^00?o0000onW2[OoY`Zd01OoY`Zd01?l0003ojL:]onW2[Ol00005ong2
Y`03o`000?obbJGol/VU00_ol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@06oo[J
Y@?o00002OoifZL00ol0003on>F`ooSU/007ooSU/003o`000?o`ll3ol??000Kol??000?o0000om3o
eoo@omL02?o@omL01?l0003ofnKLom_Vg?oKi]`5o`0000;ooooo00?o0000ooooooooool04oooool0
02?ooooo00?o0000ooooooooool02Oooool3o`0005Sooooo0_l00005o`Hk_004o`000?mJK<_oFVc;
oeY/b`;o00000_mbL/<00ol0003oTH:ooi62_`08oi62_`04o`000?nWS[_oYhjkojN>^`;o00001on]
V<400ol0003o`J:jol6R^P0=ol6R^P03o`000?o>ZKCocZVd00[ocZVd00?o0000omVe]OoI]KD00ooI
]KD00ol0003ohKV^on6i[P0;on6i[P03o`000?oY`ZgojL:]00KojL:]00?o0000onW2[Ol000001Oo]
`ZL00ol0003ol/VUoo;9Y@0:oo;9Y@03o`000?ogdJGomm6U00Womm6U00?o0000oo[JYOojfZD02Ooj
fZD2o`0000SonMZW00?o0000ooSU/?ohiK001_ohiK000ol0003ol??0oo3c`006oo3c`003o`000?o@
omOod?oG00Wod?oG1_l00005ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooo
oooo00Kooooo0ol0001Kooooo`03o`000?l008co000000Co1S^l00?o0000oeY/bomJK</00omJK</4
o`0000WoTH:o00Co0000ojN>^ol0003o00002_n]V<400ol0003o`J:jol6R^P0<ol6R^P03o`000?o>
ZKCocZVd00WocZVd00?o0000omVe]OoI]KD01OoI]KD00ol0003ohKV^on6i[P0:on6i[P03o`000?oY
`ZgojL:]00OojL:]00?o0000onW2[Ol000000oo]`ZL00ol0003ol/VUoo;9Y@0;oo;9Y@03o`000?og
dJGomm6U00Womm6U00?o0000oo[JYOojfZD02OojfZD00ol0003onnJXo`000002o`0000ConMZW00?o
0000ooSU/?ohiK001_ohiK000ol0003ol??0oo3c`006oo3c`003o`000?o@omOod?oG00Ood?oG1_l0
0008ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol0001O
ooooo`;o00001Ol6>k`00ol0003oFVc;oeY/b`05oeY/b`co00003?n]V<400ol0003o`J:jol6R^P0=
ol6R^P03o`000?o>ZKCocZVd00OocZVd00?o0000omVe]OoI]KD01_oI]KD00ol0003ohKV^on6i[P09
on6i[P03o`000?oY`ZgojL:]00WojL:]00?o0000onW2[Ol000000_o]`ZL00ol0003ol/VUoo;9Y@0;
oo;9Y@03o`000?ogdJGomm6U00Womm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_VZ003
oo_VZ0?o000000?onMZWo`000?ohiK001oohiK000ol0003ol??0oo3c`005oo3c`003o`000?o@omOo
d?oG00God?oG1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?oooooooooo
ooooo`?o0000Hoooool00ol0003o1S^lo`Hk_003o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000
ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0;ojfH`@03o`000?o1X[[o`J:j00co`J:j00?o0000
oljY]?o>ZK@01oo>ZK@00ol0003ofKFeomVe]@07omVe]@03o`000?oQ^JkohKV^00SohKV^00?o0000
onW2[OoY`Zd02_oY`Zd01Ol0003ojL:]o`000?o]`ZOo000000col/VU00?o0000ooOAYOogdJD02Oog
dJD00ol0003on]ZUoo[JY@09oo[JY@03o`000?okiZSonnJX00KonnJX1Ol00004ooSU/003o`000?o`
ll3ol??000Gol??000?o0000om3oeoo@omL02?l0000?ooooo`03o`000?oooooooooo01?ooooo000R
ooooo`Co0000I_ooool2o`0000Co1S^l00?o0000oeY/bomJK</01_mJK</00ol0003oSXS8ohj8b008
ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03?o1X[X00ol0003ocZVdoljY]006
oljY]003o`000?oI]KGofKFe00SofKFe00?o0000on6i[_oQ^Jh01ooQ^Jh00ol0003ojL:]onW2[@0<
onW2[@03o`000?oY`Zgo000000gol/VU00?o0000ooOAYOogdJD02OogdJD00ol0003on]ZUoo[JY@08
oo[JY@03o`000?okiZSonnJX00OonnJX00?o0000ooCbZoodlZ/00_odlZ/Do`0001;ooooo00?o0000
ooooooooool04oooool002;ooooo0ol0001Xooooo`03o`000?l6>kco1S^l00?o1S^l00?o0000oeY/
bomJK</01OmJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R
^_o1X[X03Oo1X[X00ol0003ocZVdoljY]005oljY]003o`000?oI]KGofKFe00WofKFe00?o0000on6i
[_oQ^Jh01_oQ^Jh00ol0003ojL:]onW2[@0=onW2[@?o00003?obbJD00ol0003omm6UooOAY@09ooOA
Y@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[ooCbZ`06ooCb
Z`03o`000?oInJcofOV/00?ofOV/00?o0000oh?KUon3fiL01?l0000Gooooo`03o`000?oooooooooo
01;ooooo000Tooooo`03o`000?oooooooooo06Kooooo0_l00004o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0;ojfH`@03o`000?o1X[[o`J:j00co
`J:j00?o0000oljY]?o>ZK@01?o>ZK@00ol0003ofKFeomVe]@0:omVe]@03o`000?oQ^JkohKV^00Ko
hKV^00?o0000onW2[OoY`Zd03OoY`Zd01?l0003olLf/oo7=[?l0000:oo;9Y@03o`000?ogdJGomm6U
00Womm6U00?o0000oo[JYOojfZD02OojfZD00ol0003onnJXoo_VZ006oo_VZ003o`000?odlZ_om?:[
00Gom?:[00?o0000omWi[?oInJ`00ooInJ`5o`0001[ooooo00?o0000ooooooooool04_ooool001Ko
oooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo06Ko
oooo00?o0000o`Hk_?l6>k`00ol6>k`00ol0003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800So
SXS800?o0000ojfH`On]V<402_n]V<400ol0003o`J:jol6R^P0=ol6R^P03o`000?o>ZKCocZVd00;o
cZVd00?o0000omVe]OoI]KD03?oI]KD00ol0003ohKV^on6i[P04on6i[P03o`000?oY`ZgojL:]00ko
jL:]0_l00002oo7=[003o`000?obbJGol/VU00Ool/VU00?o0000ooOAYOogdJD02OogdJD00ol0003o
n]ZUoo[JY@08oo[JY@03o`000?okiZSonnJX00KonnJX00?o0000ooCbZoodlZ/01OodlZ/00ol0003o
fOV/omWi[003omWi[0?o00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RH
ooooool0003oMgMg00_ooooo00?o0000ooooooooool0IOooool2o`0000Co1S^l00?o0000oeY/bomJ
K</01OmJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100_o[IS100?o0000ol6R^_o1
X[X03?o1X[X00ol0003ocZVdoljY]002oljY]003o`000?oI]KGofKFe00cofKFe00?o0000on6i[_oQ
^Jh01?oQ^Jh00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJco000000;olLf/00?o0000oo;9YOob
bJD01OobbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU00Won]ZU00?o0000oo_VZ?ok
iZP01_okiZP00ol0003om?:[ooCbZ`05ooCbZ`03o`000?oInJcofOV/00;ofOV/0_l0000Oooooo`03
o`000?oooooooooo01;ooooo000Fooooo`05oa0@4?ooooooooooo`000?l@41003?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?l6>kco1S^l00?o1S^l00?o0000oeY/bomJK</01OmJK</00ol0003o
SXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03Oo1X[X01?l0003o
cZVdoljY]?l0000@omVe]@03o`000?oQ^JkohKV^00;ohKV^00?o0000onW2[OoY`Zd03_oY`Zd01Ol0
003olLf/oo7=[?oacJco000000;olLf/00?o0000oo;9YOobbJD01?obbJD00ol0003omm6UooOAY@09
ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[ooCbZ`05
ooCbZ`03o`000?oInJcofOV/00;ofOV/0_l0000Pooooo`03o`000?oooooooooo01;ooooo000Foooo
o`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`1Tooooo`;o00001?l6>k`00ol0
003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<402_n]V<400ol0
003o`J:jol6R^P0=ol6R^P04o`000?o>ZKCocZVdo`00017ofKFe00Go0000on6i[_oQ^JkohKV^o`00
000@onW2[@03o`000?oacJcolLf/00;olLf/00Co0000oo7=[?oacJco00001OobbJD00ol0003omm6U
ooOAY@09ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01_okiZP00ol0003om?:[
ooCbZ`04ooCbZ`03o`000?oInJcofOV/00;ofOV/00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Booooo`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0I?oo
ool00ol0003o1S^lo`Hk_003o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000ohj8b?n>R<P02?n>
R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00co`J:j00?o0000oljY]?l000004_oI
]KD01?l0003ohKV^on6i[_l0000@onW2[@03o`000?oacJcolLf/00ColLf/00Co0000oo7=[?oacJco
00000oobbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?ok
iZP01_okiZP00ol0003om?:[ooCbZ`04ooCbZ`03o`000?oInJcofOV/00;ofOV/00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oo
oooo00?o0000ooooooooool0I?ooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00go
`J:j00?o0000omVe]OoI]KD04_oI]KD00ol0003ohKV^o`00000@onW2[@03o`000?oacJcolLf/00Go
lLf/00Co0000oo7=[?oacJco00000_obbJD00ol0003omm6UooOAY@09ooOAY@03o`000?ojfZGon]ZU
00Son]ZU00?o0000oo_VZ?okiZP01OokiZP00ol0003om?:[ooCbZ`05ooCbZ`03o`000?oInJcofOV/
00;o00009?ooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003oMgMg
013ooooo0_l0001Tooooo`03o`000?l6>kco1S^l00;o1S^l00?o0000oeY/bomJK</01OmJK</00ol0
003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1X[X03Oo1X[X00ol0
003ofKFeomVe]@0BomVe]@03o`000?oQ^Jko0000013ojL:]00?o0000oo7=[?oacJ`01_oacJ`01_l0
003olLf/oo7=[?l0003ol/VUo`0000_omm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_V
Z005oo_VZ003o`000?odlZ_om?:[00Com?:[00Co0000omWi[?oInJco00009_ooool00ol0003ooooo
ooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0
H_ooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00GoFVc;00?o0000ohj8b?n>R<P0
2?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00_o`J:j00?o0000olb`__l00000
5?oI]KD00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJcolLf/00OolLf/00Co0000oo7=[?oacJco
lLf/0_l0000:ooOAY@03o`000?ojfZGon]ZU00Son]ZU00?o0000oo_VZ?okiZP01OokiZP00ol0003o
m?:[ooCbZ`04ooCbZ`04o`000?oInJco0000o`0002Oooooo00?o0000ooooooooool04_ooool002co
oooo00?o0000ooooool00000Hoooool00ol0003o1S^lo`Hk_002o`Hk_003o`000?mJK<_oFVc;00Go
FVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00[o
`J:j00Co0000olb`__o</;ko00005?oI]KD00ol0003ojL:]onW2[@0>onW2[@03o`000?oacJcolLf/
00SolLf/00Go0000oo7=[?oacJco0000ooOH[002o`0000Somm6U00?o0000oo[JYOojfZD02?ojfZD0
0ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[00Com?:[0ol0000Xooooo`03o`000?oooooo
oooo01;ooooo000_ooooo`03o`000?oooooooooo067ooooo00?o0000o`Hk_?l6>k`00_l6>k`00ol0
003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<402_n]V<400ol0
003o`J:jol6R^P08ol6R^P03o`000?o</;koc;2n00;oc;2n00?o0000omVe]OoI]KD04?oI]KD00ol0
003ohl:fo`00000>onW2[@03o`000?oacJcolLf/00[olLf/0_l00004ooOH[003o`000?ogdJGomm6U
00Gomm6U00?o0000oo[JYOojfZD01oojfZD00ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[
00Com?:[0_l0000[ooooo`03o`000?oooooooooo017ooooo000`ooooo`03o`000?oooooooooo067o
oooo00Go0000o`Hk_?l6>kco1S^lo`000007oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH
`On]V<402_n]V<400ol0003o`J:jol6R^P07ol6R^P03o`000?o</;koc;2n00Coc;2n00?o0000omVe
]OoI]KD03ooI]KD01?l0003ohl:fon?2]_l0000=onW2[@03o`000?oacJcolLf/00_olLf/00?o0000
ooOH[?ogf:`00oogf:`2o`0000Comm6U00?o0000oo[JYOojfZD02?ojfZD00ol0003onnJXoo_VZ005
oo_VZ003o`000?odlZ_om?:[00;om?:[0ol0000/ooooo`03o`000?oooooooooo017ooooo000aoooo
o`03o`000?oooooooooo063ooooo0_l00003o`Hk_003o`000?mJK<_oFVc;00CoFVc;00?o0000ohj8
b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o`J:j00Ko`J:j00?o0000olb`
__o</;h01Oo</;h00ol0003ofKFeomVe]@0>omVe]@03o`000?oS`[Kohl:f00;ohl:f00?o0000onW2
[OoY`Zd02_oY`Zd00ol0003olLf/oo7=[00;oo7=[0;o00001_ogf:`2o`0000;omm6U00?o0000oo[J
YOojfZD01oojfZD00ol0003onnJXoo_VZ005oo_VZ003o`000?odlZ_om?:[00?o000000?ofO>Jo`00
0?ooool0;?ooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0003oooooooooo`1Pooooo`;o
00000_l6>k`00ol0003oFVc;oeY/b`05oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]
V<402_n]V<400ol0003o`J:jol6R^P04ol6R^P03o`000?o</;koc;2n00Ooc;2n00?o0000omVe]OoI
]KD03OoI]KD00ol0003ohl:fon?2]P02on?2]P03o`000?oY`ZgojL:]00WojL:]00?o0000oo7=[?oa
cJ`02ooacJ`01?l0003ommR/ooOH[?l00007ooOH[003o`000?ogdJGo000000Won]ZU00?o0000oo_V
Z?okiZP01OokiZP3o`0000?ofO>J00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Aoooo
o`00<oooool00ol0003oooooooooo`1Oooooo`03o`000?l03ioo000000;o1S^l00?o0000oeY/bomJ
K</01?mJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100[o[IS100?o0000ol6R^_o1
X[X00oo1X[X00ol0003oc;2nolb`_P08olb`_P03o`000?oI]KGofKFe00cofKFe00?o0000on?2]_oS
`[H01?oS`[H00ol0003ojL:]onW2[@08onW2[@03o`000?oacJcolLf/00_olLf/00Go0000ooOH[?og
f:commR/o`000007ooOH[0Ko00001OojfZD00ol0003onnJXoo_VZ005o`0000GofO>J0_l0000^oooo
o`03o`000?oooooooooo017ooooo000dooooo`;o0000H?ooool01Ol0003o00nOo`000?l6>kco0000
00OoFVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:ojfH`@05o`000?o1X[[o`J:j
ol6R^_l000003?o</;h00ol0003ofKFeomVe]@0;omVe]@03o`000?oS`[Kohl:f00Gohl:f00?o0000
onW2[OoY`Zd01_oY`Zd00ol0003olLf/oo7=[00<oo7=[003o`000?ogf:commR/00;ommR/00?o0000
ooOH[?ogf:`01?ogf:`00ol0003on^F[oo[UZ`03oo[UZ`So00001?oelJL00ol0003ofO>JomWcVP02
omWcVP;o0000;oooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooooooo`1Noooo
o`04o`000?l03ioo0000o`0000OoFVc;00?o0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@0:
ojfH`@04o`000?o1X[[o`J:jo`0000goc;2n00?o0000omVe]OoI]KD02_oI]KD00ol0003ohl:fon?2
]P07on?2]P03o`000?oY`ZgojL:]00GojL:]00?o0000oo7=[?oacJ`02ooacJ`00ol0003ommR/ooOH
[003ooOH[003o`000?ogf:commR/00?ommR/00?o0000oo[UZoojiJ/02?ojiJ/00ol0003omO6WooGa
Y`04ooGaY`03o`000?oIli[ofO>J00;ofO>J0_l0000`ooooo`03o`000?oooooooooo017ooooo000g
ooooo`;o0000G_ooool00ol0003o00nOo`0?W`02o`0000KoFVc;00?o0000ohj8b?n>R<P02?n>R<P0
0ol0003o[IS1ojfH`@0:ojfH`@03o`000?o1X[[o000000ooc;2n00?o0000omVe]OoI]KD02OoI]KD0
0ol0003ohl:fon?2]P07on?2]P03o`000?oY`ZgojL:]00GojL:]00?o0000oo7=[?oacJ`02ooacJ`0
0ol0003ommR/ooOH[004ooOH[003o`000?ogf:commR/00;ommR/00?o0000oo[UZoojiJ/01oojiJ/0
0ol0003omO6WooGaY`05ooGaY`04o`000?oIli[ofO>JomWcVP;o0000<Oooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooo`00001Oooooo`04o`000?l03ioo00nOo`0000OoFVc;00?o
0000ohj8b?n>R<P02?n>R<P00ol0003o[IS1ojfH`@09ojfH`@;o00004Oo</;h00ol0003ofKFeomVe
]@07omVe]@03o`000?oS`[Kohl:f00Wohl:f00?o0000onW2[OoY`Zd00ooY`Zd00ol0003olLf/oo7=
[00;oo7=[003o`000?ogf:commR/00KommR/00Co0000ooOH[?ogf:co00002_ojiJ/00ol0003omO6W
ooGaY`04ooGaY`03o`000?oIli[ofO>J00;ofO>J00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Aooooo`00>Oooool00ol0003oooooooooo`1Mooooo`03o`000?l03ioo00nO00;o00001OmJ
K</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100So[IS100?o0000okFWbol000004Oo<
/;h00ol0003ofKFeomVe]@06omVe]@03o`000?oS`[Kohl:f00_ohl:f00?o0000onW2[OoY`Zd00_oY
`Zd00ol0003olLf/oo7=[00;oo7=[003o`000?ogf:commR/00OommR/00?o0000ooOH[?l000002Ooj
iJ/00ol0003omO6WooGaY`04ooGaY`03o`000?oIli[ofO>J00;ofO>J00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`1Looooo`05o`000?l03ioo
00nOo`000?laH]<00_l00004oeY/b`03o`000?n>R<SoSXS800SoSXS800?o0000ojfH`On]V<401On]
V<42o`0000?o]JO;00?o0000olb`__o</;h03oo</;h00ol0003ofKFeomVe]@05omVe]@03o`000?oS
`[Kohl:f00_ohl:f00Go0000onW2[OoY`ZgojL:]o`00000>oo7=[003o`000?ogf:commR/00SommR/
0_l00009oo[UZ`03o`000?oelJOomO6W00ComO6W00Go0000omWcV_oIli[ofO>Jo`00000dooooo`03
o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo05cooooo00Co0000o`0?Wol03ioo
00000_laH]<01Ol0003oFVc;oeY/bomJK<_o000000[oSXS800?o0000ojfH`On]V<401?n]V<400ol0
003o]JO;okFWb`03okFWb`03o`000?o</;koc;2n00ooc;2n00?o0000omVe]OoI]KD01?oI]KD00ol0
003ohl:fon?2]P0=on?2]P04o`000?oY`ZgojL:]o`0000golLf/00?o0000ooOH[?ogf:`02Oogf:`2
o`0000Son^F[00?o0000ooGaYooelJL01?oelJL01Ol0003ofO>JomWcV_oIli[o000003Kooooo00?o
0000ooooooooool04?ooool003cooooo00?o0000ooooooooool0G?ooool00ol0003o00nOo`000003
oc5Rd`;o00000_mJK</00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o[IS100;o[IS100?o0000
okFWboneYl/01OneYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oI]KGofKFe00?ofKFe00?o0000
on?2]_oS`[H03_oS`[H00ol0003ojL:]o`00000=oo7=[003o`000?ogf:commR/00WommR/00?o0000
oo[UZol000001oojiJ/00ol0003omO6WooGaY`04ooGaY`04o`000?oIli[ofO>Jo`0003Oooooo00?o
0000ooooooooool04?ooool003gooooo0_l0001Looooo`04o`000?l03ioo00nOo`0000Co<F;C0ol0
000:ohj8b003o`000?n]V<7o[IS100;o00002?neYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oI
]KGofKFe00;ofKFe00?o0000on?2]_oS`[H04?oS`[H2o`0000golLf/00?o0000ooOH[?ogf:`02?og
f:`01Ol0003on^F[oo[UZoojiJ_o000000Gon^F[00?o0000ooGaYooelJL01?oelJL01?l0003ofO>J
omWcV_l0000hooooo`03o`000?oooooooooo013ooooo000oooooo`03o`000?oooooooooo05[ooooo
00Co0000o`0?Wol03ioo00001OlaH]<00ol0003oSXS8ohj8b008ohj8b003o`000?n]V<7o000000_o
]JO;00?o0000olb`__o</;h03oo</;h01Ol0003ofKFeomVe]OoI]KGo000001;ohl:f00?o0000ongB
^?l000002ooacJ`00ol0003ommR/ooOH[009ooOH[005o`000?ojiJ_on^F[oo[UZol000001OojiJ/0
0ol0003omO6WooGaY`04ooGaY`03o`000?oIli[o000003Wooooo00?o0000ooooooooool04?ooool0
043ooooo00?o0000ooooooooool0FOooool01?l0003o00nOo`0?Wol00006oc5Rd`co00003?neYl/0
0ol0003oc;2nolb`_P0@olb`_P03o`000?oI]KGo000001;ohl:f00Go0000ongB^?o]d[SokM:ho`00
000:oo7=[003o`000?ogf:commR/00SommR/00?o0000oo[UZoojiJ/00oojiJ/01Ol0003on^F[oo[U
ZoojiJ_o000000KomO6W00?o0000omWcV_l00000>_ooool00ol0003oooooooooo`0@ooooo`00@Ooo
ool2o`0005[ooooo00Co0000o`0?Wol03ioo00001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`00
0?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h03oo</;h00ol0003ofKFeo`00000Bon?2]P03o`00
0?o]d[SokM:h00;okM:h00?o0000oo7=[?oacJ`01_oacJ`00ol0003ommR/ooOH[009ooOH[003o`00
0?ojiJ_on^F[00Con^F[00?o0000oo[UZol000001ooelJL2o`0003_ooooo00?o0000ooooooooool0
4?ooool0043ooooo00?o0000ooooool00000Foooool00ol0003o00nOo`000006oc5Rd`03o`000?n8
T]OoR9;G00SoR9;G00?o0000okFWboneYl/02_neYl/00ol0003oc;2nolb`_P0@olb`_P03o`000?oS
`[Kohl:f013ohl:f00?o0000ongB^?o]d[P01?o]d[P2o`0000KolLf/00?o0000ooOH[?ogf:`02Oog
f:`00ol0003on^F[oo[UZ`05oo[UZ`;o00001_oelJL2o`0003cooooo00?o0000ooooooooool04?oo
ool004?ooooo00?o0000ooooooooool0F?ooool01?l0003o00nOo`0?Wol00005oc5Rd`03o`000?n8
T]OoR9;G00SoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`_P0?olb`_P03o`000?oS
`[Kohl:f013ohl:f00?o0000ongB^?o]d[P01_o]d[P00ol0003olLf/oo7=[003oo7=[003o`000?og
f:commR/00SommR/00?o0000oo[UZoojiJ/01_ojiJ/2o`0000GomO6W0_l0000mooooo`03o`000?oo
oooooooo013ooooo0014ooooo`03o`000?oooooooooo05Sooooo00?o0000o`0?Wol000001_laH]<0
0ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00[o]JO;00?o0000olb`__o</;h03_o</;h0
0ol0003oel;4o`00000@on?2]P03o`000?o]d[SokM:h00SokM:h00Go0000oo7=[?oacJcolLf/o`00
000;ooOH[003o`000?ojiJ_on^F[00Kon^F[00?o0000ooGaYol000001?oelJL00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo013ooooo0015ooooo`03o`000?oooooooooo05Sooooo00?o0000
o`0?Wol000001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000
olb`__o</;h03?o</;h01Ol0003oel;4omO2a?oG`/Co000000oohl:f00?o0000ongB^?o]d[P02Oo]
d[P01?l0003olLf/oo7=[?l0000:ooOH[003o`000?ojiJ_on^F[00Kon^F[00Ko0000ooGaYooelJOo
mO6Wo`000?oelJL2o`0003oooooo00?o0000ooooooooool04?ooool004Kooooo0_l0001Iooooo`03
o`000?l03ioo000000Go<F;C00?o0000ohRBeon8T]L02?n8T]L00ol0003o]JO;okFWb`0;okFWb`03
o`000?o</;koc;2n00[oc;2n00?o0000omO2a?oG`/@00ooG`/@00ol0003ohl:fon?2]P0;on?2]P03
o`000?o]d[SokM:h00_okM:h00?o0000oo7=[?l000002_ogf:`00ol0003on^F[oo[UZ`06oo[UZ`04
o`000?oelJOomO6WooGaY`;o000000?of_JPo`000?ooool0?_ooool00ol0003oooooooooo`0@oooo
o`00B?ooool00ol0003oooooooooo`1Fooooo`03o`000?l03ioo000000Ko<F;C00?o0000ohRBeon8
T]L01on8T]L00ol0003o]JO;okFWb`0;okFWb`03o`000?o</;koc;2n00Woc;2n00?o0000omO2a?oG
`/@01?oG`/@00ol0003ohl:fon?2]P0;on?2]P03o`000?o]d[SokM:h00cokM:h0ol00008ooOH[003
o`000?ojiJ_on^F[00Kon^F[00?o0000ooGaYol000000_l000000ooJmZ3o0000o`000011ooooo`03
o`000?oooooooooo00oooooo0019ooooo`03o`000?oooooooooo05Kooooo00?o0000o`0?Wol00000
1OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h0
2?o</;h00ol0003oel;4omO2a005omO2a003o`000?oS`[Kohl:f00Wohl:f00?o0000ongB^?o]d[P0
3Oo]d[P00ol0003om>>hooCS^003o`0000GommR/00?o0000oo[UZoojiJ/01_ojiJ/2o`0000Cof_JP
0_l00011ooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo05Kooooo0_l0
0006oc5Rd`03o`000?n8T]OoR9;G00OoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`
_P07olb`_P03o`000?oG`/Coel;400Ooel;400?o0000on?2]_oS`[H01ooS`[H00ol0003okM:hongB
^00=ongB^003o`000?odhkSom>>h00Com>>h0ol00002ooOH[004o`000?ojiJ_on^F[oo[UZ`Go0000
1OoJmZ001?l0003oooooooooool00010ooooo`03o`000?oooooooooo00oooooo001:ooooo`;o0000
F?ooool2o`0000Go<F;C00?o0000ohRBeon8T]L02?n8T]L00ol0003o]JO;okFWb`0;okFWb`03o`00
0?o</;koc;2n00Goc;2n00?o0000omO2a?oG`/@02OoG`/@00ol0003ohl:fon?2]P06on?2]P03o`00
0?o]d[SokM:h00gokM:h00?o0000ooCS^?odhkP01oodhkP6o`0000Colo>d00?o0000om[fX?oJmZ00
0ooJmZ001Ol0003ooooooooooooooooo000003oooooo00?o0000ooooooooool03oooool004cooooo
00?o0000ooooooooool0EOooool2o`0000Ko<F;C00?o0000ohRBeon8T]L01on8T]L00ol0003o]JO;
okFWb`0;okFWb`03o`000?o</;koc;2n00Coc;2n00?o0000omO2a?oG`/@02_oG`/@00ol0003ohl:f
on?2]P05on?2]P03o`000?o]d[SokM:h00gokM:h00?o0000ooCS^?odhkP02OodhkP00ol0003olo>d
oo?c]005oo?c]003o`000?oJmZ3of_JP00?of_JP00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo05Gooooo0_l0
0005oc5Rd`03o`000?n8T]OoR9;G00SoR9;G00?o0000okFWboneYl/02oneYl/00ol0003oc;2nolb`
_P03olb`_P03o`000?oG`/Coel;400_oel;400?o0000on?2]_oS`[H01?oS`[H00ol0003okM:hongB
^00=ongB^003o`000?odhkSom>>h00Som>>h00?o0000oo?c]?oclk@01Ooclk@00ol0003of_JPom[f
X003om[fX003o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0?ooooo`00C_ooool00ol0003oooooooooo`1Eooooo`;o00001OlaH]<00ol0003oR9;GohRBe`07
ohRBe`03o`000?neYl_o]JO;00_o]JO;00?o0000olb`__o</;h00_o</;h00ol0003oel;4omO2a00=
omO2a003o`000?oS`[Kohl:f00;ohl:f00?o0000ongB^?o]d[P03Oo]d[P00ol0003om>>hooCS^009
ooCS^003o`000?oclkColo>d00Golo>d00?o0000om[fX?oJmZ000_oJmZ000ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool004oooooo0_l0001Eoooo
o`;o00001OlaH]<00ol0003oR9;GohRBe`08ohRBe`03o`000?neYl_o]JO;00_o]JO;00Co0000olb`
__o</;ko00004?oG`/@00ol0003ohl:fon?2]P02on?2]P03o`000?o]d[SokM:h00gokM:h00?o0000
ooCS^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]003o`000?oJmZ3of_JP00?of_JP00?o0000
ooooooooool01oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aoooo
o`03o`000?oooooooooo05?ooooo0ol00004oc5Rd`03o`000?n8T]OoR9;G00OoR9;G00?o0000okFW
boneYl/02oneYl/00ol0003oc;2no`00000BomO2a004o`000?oS`[Kohl:fo`0000ookM:h00?o0000
ooCS^?odhkP02?odhkP00ol0003olo>doo?c]006oo?c]003o`000?oJmZ3of_JP00;of_JP00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo001Boooo
o`03o`000?oooooooooo05?ooooo00?o0000o`1=bol000000olaH]<00ol0003oR9;GohRBe`08ohRB
e`03o`000?neYl_o]JO;00[o]JO;0_l0000DomO2a003o`000?oS`[Ko000000ookM:h00?o0000ooCS
^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]003o`000?oJmZ3of_JP00;of_JP00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00oooooo001Cooooo`03
o`000?oooooooooo05?ooooo00Co0000o`1=bol0003o00000_laH]<00ol0003oR9;GohRBe`07ohRB
e`03o`000?neYl_o]JO;00So]JO;0_l000000onn_MWo0000omO2a00DomO2a0;o00003_o]d[P00ol0
003om>>hooCS^008ooCS^003o`000?oclkColo>d00Golo>d00Co0000om[fX?oJmZ3of_JP0_l0000?
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool005Cooooo0ol0001Boooo
o`;o00000_l0CL/01?l0003o<F;Coc5Rdol00009ohRBe`03o`000?neYl_o]JO;00Go]JO;0_l00004
okjmf@03o`000?oG`/Coel;401;oel;400?o0000on?Hbol000003?o]d[P00ol0003om>>hooCS^009
ooCS^003o`000?oclkColo>d00Golo>d00Co0000om[fX?oJmZ3o00004_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000E?ooool2o`0000;o04g;00?o0000
oc5Rdol000002On8T]L00ol0003o]JO;okFWb`04okFWb`03o`000?nn_MWo_[gI00Go_[gI00?o0000
omO2a?oG`/@04?oG`/@01Ol0003ohmS;on?HbooSf<_o000000_okM:h00?o0000ooCS^?odhkP02?od
hkP00ol0003olo>doo?c]005oo?c]004o`000?oJmZ3of_JPo`0001Cooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1Booooo`04
o`000?l0CL_o04g;o`1=b`?o00002On8T]L01?l0003o]JO;okFWboneYl/2o`0000Wo_[gI00?o0000
omO2a?oG`/@03_oG`/@00ol0003ohmS;on?Hb`03on?Hb`03o`000?o]d[SokM:h00OokM:h00?o0000
ooCS^?odhkP02OodhkP00ol0003olo>doo?c]005oo?c]0?o00005_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool02?ooool00ol0003oooooooooo`1Booooo`03o`000?l0CL_o
04g;00;o04g;00?o0000ohRBeon8T]L01on8T]L01?l0003o]JO;o`000?l0000;okjmf@03o`000?oG
`/Coel;400goel;400?o0000on?HbooSf</01OoSf</2o`0000OokM:h00?o0000ooCS^?odhkP02?od
hkP00ol0003olo>doo?c]005oo?c]0?o00006?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`08ooooo`;o0000D_ooool2o`0000Co04g;2ol0000>okjmf@03o`000?oG`/Coel;400_oel;400?o
0000on?HbooSf</02?oSf</00ol0003okM:hongB^003ongB^003o`000?odhkSom>>h00Wom>>h00?o
0000oo?c]?oclk@01?oclk@3o`0001Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool02ooo
ool00ol0003oooooooooo`1@ooooo`;o00000ol0CL/00ol0003oO:?/ogbSk007ogbSk003o`000?nn
_MWo_[gI00go_[gI00?o0000omO2a?oG`/@02_oG`/@00ol0003ohmS;on?Hb`09on?Hb`03o`000?o]
d[SokM:h00;okM:h00?o0000ooCS^?odhkP02?odhkP00ol0003olo>doo?c]005oo?c]0;o00006ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000ooooooooool0
D?ooool00ol0003o04g;o`1=b`02o`1=b`03o`000?mlXncoO:?/00OoO:?/00?o0000okjmfOnn_MT0
3Onn_MT00ol0003oel;4omO2a008omO2a003o`000?oSf<_ohmS;00_ohmS;00Co0000ongB^?o]d[So
00002_odhkP00ol0003olo>doo?c]004oo?c]0?o00007Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo053ooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003o
O:?/ogbSk007ogbSk003o`000?nn_MWo_[gI00co_[gI00?o0000omO2a?oG`/@01ooG`/@00ol0003o
hmS;on?Hb`0=on?Hb`03o`000?o]d[So000000[om>>h00Co0000oo?c]?oclkColo>d0ol000000ooF
o[go0000ooooo`0Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool003So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0D?ooool00ol0003o04g;o`1=b`02o`1=b`03o`000?mlXncoO:?/00OoO:?/00?o0000okjm
fOnn_MT03?nn_MT00ol0003oel;4omO2a005omO2a003o`000?oSf<_ohmS;00oohmS;1?l00007ooCS
^003o`000?oclkColo>d00;o00000ooFo[d00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool2o`00057ooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003oO:?/ogbSk008ogbS
k003o`000?nn_MWo_[gI00co_[gI00?o0000omO2a?oG`/@01?oG`/@00ol0003ohmS;on?Hb`0?on?H
b`04o`000?oYl/kojO;>onWbcPGo00000_odhkP3o`0000Coe_jm00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo
04oooooo00?o0000o`1=bol0CL/00_l0CL/00ol0003oO:?/ogbSk007ogbSk003o`000?nn_MWo_[gI
00co_[gI00?o0000omO2a?oG`/@00ooG`/@00ol0003ohmS;on?Hb`0?on?Hb`03o`000?oYl/kojO;>
00OojO;>0_l00006omKn_@03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0>ooooo`00H?ooool00ol0003oooooooooo`1?ooooo`03o`000?l0CL_o04g;00;o
04g;00?o0000ogbSk?mlXn`01omlXn`00ol0003o_[gIokjmf@0<okjmf@05o`000?oG`/Coel;4omO2
a?l000004OoSf</00ol0003ojO;>onWbcP09onWbcP03o`000?oFo[goe_jm00?oe_jm00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o
0000D?ooool2o`0000?o04g;00?o0000ogbSk?mlXn`01omlXn`00ol0003o_[gIokjmf@0<okjmf@03
o`000?oG`/Co0000017ohmS;00?o0000onWbc_oYl/h02OoYl/h00ol0003oe_jmomKn_@03omKn_@03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`00
Hoooool00ol0003oooooooooo`1?ooooo`04o`000?l0CL_o04g;o`0000[oO:?/00?o0000okjmfOnn
_MT02onn_MT3o`00013ohmS;00?o0000onWbc_oYl/h02OoYl/h00ol0003oe_jmomKn_@03omKn_@03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00
I?ooool00ol0003oooooooooo`1?ooooo`;o000000?o04g;o`000?mlXn`02OmlXn`00ol0003o_[gI
okjmf@08okjmf@;o00000oo5g>X00ol0003ohmS;on?Hb`0<on?Hb`03o`000?oYl/kojO;>00WojO;>
00?o0000omKn_OoFo[d00ooFo[d00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03Oooool006Gooooo00?o0000ooooooooool0D?ooool00ol0003o04g;o`00
0009ogbSk003o`000?nn_MWo_[gI00Oo_[gI00?o0000olGLj_o5g>X01?o5g>X00ol0003ohmS;on?H
b`0:on?Hb`03o`000?oYl/kojO;>00WojO;>00?o0000omKn_OoFo[d00ooFo[d00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool006Kooooo00?o0000
ooooooooool0D?ooool2o`0000[oO:?/00?o0000okjmfOnn_MT01?nn_MT2o`0000SoaMcZ0_l0000:
on?Hb`03o`000?oYl/kojO;>00SojO;>00?o0000omKn_OoFo[d00ooFo[d00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0001Aoooo
o`;o00002_mlXn`01?l0003o_[gIokjmfOnn_MT2o`0000coaMcZ00?o0000on?HbooSf</01_oSf</0
0ol0003ojO;>onWbcP09onWbcP04o`000?oFo[goe_jmomKn_@;o0000<_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo057ooooo00?o0000
ogbSk?mlXn`02?mlXn`00ol0003o_[gIo`00000?olGLjP;o00001OoSf</00ol0003ojO;>onWbcP09
onWbcP03o`000?oFo[goe_jm00;o0000=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00gooooo001Yooooo`03o`000?oooooooooo057ooooo3Ol0000AolGLjP05o`000?oSf<_ohmS;
on?Hbol000002ooYl/h01?l0003oe_jmo`000?l0000hooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03Oooool006[ooooo0_l0001Cooooo`03o`000?mG]?_oEkCk00SoEkCk00?o0000
olGLj_o5g>X03oo5g>X00ol0003ohmS;o`00000;onWbcP?o0000>_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00gooooo001/ooooo`03o`000?oooooooooo057ooooo0_l00009oeNd
n`03o`000?o5g>[oaMcZ00koaMcZ2?l00005onWbcP;o0000?Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05;ooooo00?o0000oeNdnomG
]?/01omG]?/2o`0000coaMcZ0_l00008okOik@Go0000@?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo001^ooooo`03o`000?oooooooooo05;ooooo0_l00009oeNdn`03o`00
0?o5g>[oaMcZ00SoaMcZ00?o0000okOikOngnNd02OngnNd2o`0004?ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Cooooo`03o`000?mG
]?_oEkCk00OoEkCk0_l00006olGLjP;o00002ongnNd00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03?ooool006oooooo0ol0001Dooooo`;o00002OmG]?/0
1?l0003oaMcZolGLj_o5g>X2o`0000_o]oW]0_l00018ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool03?ooool0077ooooo00?o0000ooooooooool0E?ooool00ol0003oEkCkoeNdn`07
oeNdn`03o`000?o5g>[o000000_o]oW]0_l0001;ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool03?ooool007;ooooo00?o0000ooooooooool0E?oooolAo`0000Go]oW]00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001cooooo`;o
0000F?ooool00ol0003oooooooooo`0?o`0004oooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo001hooooo`;o
0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02ooo
ool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Ooooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`0004Wooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo001f
ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2o`0004Kooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo
001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`000?oooooooooo
00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmVIVKo0000013o
oooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo
001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00GOoo
ool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005cooooo00?o
k^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo002A
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool009Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo002L
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Nooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Pooooo`;o0000:ooo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?ooooo00Co0000
oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`24
ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000ooooooooool0
O?ooool4o`00017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1hooooo`Co0000
5Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Iooooo`00T?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0KOooool3o`00
027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo002@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/ooooo`00S_oo
ool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000ooooooooool0GOoo
ool4o`00033ooooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co0000=?ooool0
0;Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000>?ooool00;Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??ooool00;Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool00;Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;Sooooo0_l0000C
ooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000ooooooooool0
>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_oo
ool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool4
o`0005_ooooo002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000Goooool00;oo
oooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo00?o0000oooo
ooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003oooooooooo`0Fooooo`Co
0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001kooooo`00b?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001nooooo`00bOooool0
1Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003oooooooooool0
0009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[ooooo003<oooo
o`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onHV9So8B4Qonk^
kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003oooooooooo`2Hoooo
o`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:gooooo0ol00000
0ol@413oooooooooo`2^ooooo`00V_ooool2o`0000_ooooo00?o0000okZj^_ooool01Oooool00ol@
413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo
097ooooo002Jooooo`03o`000?oooooooooo00[ooooo0_lb<S86ooooo`03oiRHV?lb<S;ooooo00Co
oooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:Booooo`00T?ooool01Ol@413o0000
o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03
ohN7Qol0003o^[Zj00Gooooo00?ogMgMo`000?nj^[X01?ooool00on7QhOo0000okZj^P05ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0N_oo
ool009;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`03oeEEEOmgMgOoA4A400Cooooo
00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000oooooooo
ool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`00
0006oooooomgMgOoV9RHoooooonHV9SoMgMgN_ooool009;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4Q
omgMg@0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`05oa0@4?ooooooooooooooool@4100N_ooool009;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7Qooo
ooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1hoooo
o`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00001jooooo`00Soooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Cooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@401jooooo`00Soooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg07[ooooo002?ooooo`Oo0000
1?ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool0
2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07[ooooo003oooooof;ooooo003oooooof;ooooo003o
ooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.397 .629 .947 r
.52593 .68772 .5561 .7194 .58394 .7109 .55406 .69242 Metetra
.245 .656 .962 r
.55406 .69242 .58394 .7109 .61197 .70234 .58254 .69648 Metetra
.01 .576 .791 r
.58254 .69648 .61197 .70234 .64019 .69372 .61135 .69927 Metetra
.174 0 0 r
.61135 .69927 .64019 .69372 .66861 .68504 .64047 .70017 Metetra
.25 0 0 r
.64047 .70017 .66861 .68504 .69723 .6763 .66984 .69864 Metetra
.259 0 0 r
.66984 .69864 .69723 .6763 .72605 .6675 .69943 .6943 Metetra
.228 0 0 r
.69943 .6943 .72605 .6675 .75507 .65863 .72917 .68687 Metetra
.158 0 0 r
.72917 .68687 .75507 .65863 .7843 .6497 .759 .67624 Metetra
.04 0 0 r
.759 .67624 .7843 .6497 .81374 .64071 .78887 .66249 Metetra
.78887 .66249 .81374 .64071 .84339 .63166 .81875 .64586 Metetra
.421 .83 .637 r
.81875 .64586 .84339 .63166 .87325 .62254 .84859 .62672 Metetra
.684 .98 .847 r
.84859 .62672 .87325 .62254 .90333 .61335 .8784 .60557 Metetra
.805 .961 .912 r
.8784 .60557 .90333 .61335 .93362 .6041 .90817 .58305 Metetra
.816 .867 .885 r
.90817 .58305 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
0 .339 .811 r
.49498 .6552 .52593 .68772 .55406 .69242 .52323 .67264 Metetra
0 .248 .664 r
.52323 .67264 .55406 .69242 .58254 .69648 .552 .68902 Metetra
.439 0 0 r
.552 .68902 .58254 .69648 .61135 .69927 .58126 .70306 Metetra
.467 0 0 r
.58126 .70306 .61135 .69927 .64047 .70017 .61096 .71347 Metetra
.429 0 0 r
.61096 .71347 .64047 .70017 .66984 .69864 .64101 .71916 Metetra
.35 0 0 r
.64101 .71916 .66984 .69864 .69943 .6943 .67131 .71929 Metetra
.233 0 0 r
.67131 .71929 .69943 .6943 .72917 .68687 .70176 .71332 Metetra
.062 0 0 r
.70176 .71332 .72917 .68687 .759 .67624 .73222 .70095 Metetra
.73222 .70095 .759 .67624 .78887 .66249 .76259 .68241 Metetra
.469 .833 .578 r
.76259 .68241 .78887 .66249 .81875 .64586 .79278 .65818 Metetra
.732 .977 .741 r
.79278 .65818 .81875 .64586 .84859 .62672 .82273 .62904 Metetra
.871 .992 .815 r
.82273 .62904 .84859 .62672 .8784 .60557 .8524 .59609 Metetra
.903 .931 .822 r
.8524 .59609 .8784 .60557 .90817 .58305 .88182 .56058 Metetra
.887 .855 .804 r
.88182 .56058 .90817 .58305 .93794 .55978 .91103 .52381 Metetra
0 0 .503 r
.4632 .62183 .49498 .6552 .52323 .67264 .49143 .6509 Metetra
.617 .075 0 r
.49143 .6509 .52323 .67264 .552 .68902 .52032 .67863 Metetra
.65 .093 0 r
.52032 .67863 .552 .68902 .58126 .70306 .54987 .70314 Metetra
.619 .061 0 r
.54987 .70314 .58126 .70306 .61096 .71347 .58001 .7225 Metetra
.538 0 0 r
.58001 .7225 .61096 .71347 .64101 .71916 .61063 .73501 Metetra
.403 0 0 r
.61063 .73501 .64101 .71916 .67131 .71929 .64159 .73939 Metetra
.197 0 0 r
.64159 .73939 .67131 .71929 .70176 .71332 .6727 .73478 Metetra
.6727 .73478 .70176 .71332 .73222 .70095 .70381 .72074 Metetra
.456 .834 .599 r
.70381 .72074 .73222 .70095 .76259 .68241 .73473 .6976 Metetra
.739 .974 .721 r
.73473 .6976 .76259 .68241 .79278 .65818 .76533 .66613 Metetra
.887 .991 .765 r
.76533 .66613 .79278 .65818 .82273 .62904 .79551 .62756 Metetra
.936 .948 .768 r
.79551 .62756 .82273 .62904 .8524 .59609 .82523 .58354 Metetra
.937 .891 .758 r
.82523 .58354 .8524 .59609 .88182 .56058 .85449 .536 Metetra
.919 .836 .747 r
.85449 .536 .88182 .56058 .91103 .52381 .88337 .48685 Metetra
.703 .217 0 r
.43058 .58756 .4632 .62183 .49143 .6509 .45863 .6265 Metetra
.747 .24 0 r
.45863 .6265 .49143 .6509 .52032 .67863 .48751 .66396 Metetra
.743 .221 0 r
.48751 .66396 .52032 .67863 .54987 .70314 .51719 .69752 Metetra
.697 .158 0 r
.51719 .69752 .54987 .70314 .58001 .7225 .54763 .72466 Metetra
.6 .039 0 r
.54763 .72466 .58001 .7225 .61063 .73501 .57869 .74313 Metetra
.418 0 0 r
.57869 .74313 .61063 .73501 .64159 .73939 .61019 .75122 Metetra
.095 0 0 r
.61019 .75122 .64159 .73939 .6727 .73478 .64193 .74778 Metetra
.358 .81 .685 r
.64193 .74778 .6727 .73478 .70381 .72074 .67366 .73222 Metetra
.715 .982 .784 r
.67366 .73222 .70381 .72074 .73473 .6976 .70518 .70497 Metetra
.883 .992 .783 r
.70518 .70497 .73473 .6976 .76533 .66613 .73629 .6671 Metetra
.941 .949 .757 r
.73629 .6671 .76533 .66613 .79551 .62756 .76684 .62022 Metetra
.954 .9 .733 r
.76684 .62022 .79551 .62756 .82523 .58354 .79679 .56654 Metetra
.947 .856 .718 r
.79679 .56654 .82523 .58354 .85449 .536 .82613 .50859 Metetra
.932 .817 .71 r
.82613 .50859 .85449 .536 .88337 .48685 .85493 .44884 Metetra
.791 .322 0 r
.39706 .55236 .43058 .58756 .45863 .6265 .42486 .59885 Metetra
.802 .32 0 r
.42486 .59885 .45863 .6265 .48751 .66396 .45359 .6438 Metetra
.784 .285 0 r
.45359 .6438 .48751 .66396 .51719 .69752 .48327 .68438 Metetra
.733 .205 0 r
.48327 .68438 .51719 .69752 .54763 .72466 .51386 .71758 Metetra
.62 .053 0 r
.51386 .71758 .54763 .72466 .57869 .74313 .54523 .74071 Metetra
.375 0 0 r
.54523 .74071 .57869 .74313 .61019 .75122 .57717 .7517 Metetra
.102 .658 .759 r
.57717 .7517 .61019 .75122 .64193 .74778 .60945 .74912 Metetra
.61 .953 .905 r
.60945 .74912 .64193 .74778 .67366 .73222 .64179 .73227 Metetra
.846 .986 .86 r
.64179 .73227 .67366 .73222 .70518 .70497 .67392 .70169 Metetra
.925 .943 .791 r
.67392 .70169 .70518 .70497 .73629 .6671 .7056 .65866 Metetra
.948 .897 .742 r
.7056 .65866 .73629 .6671 .76684 .62022 .73667 .60516 Metetra
.952 .859 .712 r
.73667 .60516 .76684 .62022 .79679 .56654 .76703 .54385 Metetra
.947 .829 .695 r
.76703 .54385 .79679 .56654 .82613 .50859 .79668 .47774 Metetra
.936 .803 .687 r
.79668 .47774 .82613 .50859 .85493 .44884 .82567 .40974 Metetra
.827 .371 0 r
.36263 .5162 .39706 .55236 .42486 .59885 .39011 .56746 Metetra
.823 .356 0 r
.39011 .56746 .42486 .59885 .45359 .6438 .41863 .61719 Metetra
.796 .31 0 r
.41863 .61719 .45359 .6438 .48327 .68438 .44821 .66227 Metetra
.732 .213 0 r
.44821 .66227 .48327 .68438 .51386 .71758 .47884 .69936 Metetra
.583 .021 0 r
.47884 .69936 .51386 .71758 .54523 .74071 .51039 .72547 Metetra
0 .341 .686 r
.51039 .72547 .54523 .74071 .57717 .7517 .54266 .73827 Metetra
.338 .77 .97 r
.54266 .73827 .57717 .7517 .60945 .74912 .57539 .73616 Metetra
.728 .925 .957 r
.57539 .73616 .60945 .74912 .64179 .73227 .60827 .71836 Metetra
.87 .914 .857 r
.60827 .71836 .64179 .73227 .67392 .70169 .64101 .68545 Metetra
.919 .879 .78 r
.64101 .68545 .67392 .70169 .7056 .65866 .67332 .6389 Metetra
.937 .849 .731 r
.67332 .6389 .7056 .65866 .73667 .60516 .70501 .58092 Metetra
.942 .825 .7 r
.70501 .58092 .73667 .60516 .76703 .54385 .73595 .51449 Metetra
.941 .806 .683 r
.73595 .51449 .76703 .54385 .79668 .47774 .76612 .44295 Metetra
.936 .791 .675 r
.76612 .44295 .79668 .47774 .82567 .40974 .79557 .36951 Metetra
.837 .385 0 r
.32723 .47902 .36263 .5162 .39011 .56746 .35444 .53199 Metetra
.822 .36 0 r
.35444 .53199 .39011 .56746 .41863 .61719 .38273 .58345 Metetra
.781 .301 0 r
.38273 .58345 .41863 .61719 .44821 .66227 .41217 .63014 Metetra
.686 .179 0 r
.41217 .63014 .44821 .66227 .47884 .69936 .44276 .66862 Metetra
.463 0 0 r
.44276 .66862 .47884 .69936 .51039 .72547 .47439 .69575 Metetra
0 .444 .859 r
.47439 .69575 .51039 .72547 .54266 .73827 .50688 .7091 Metetra
.483 .743 .985 r
.50688 .7091 .54266 .73827 .57539 .73616 .53995 .70699 Metetra
.744 .829 .917 r
.53995 .70699 .57539 .73616 .60827 .71836 .5733 .6886 Metetra
.849 .832 .83 r
.5733 .6886 .60827 .71836 .64101 .68545 .6066 .65456 Metetra
.894 .819 .766 r
.6066 .65456 .64101 .68545 .67332 .6389 .63956 .60639 Metetra
.916 .806 .723 r
.63956 .60639 .67332 .6389 .70501 .58092 .67194 .54642 Metetra
.927 .795 .696 r
.67194 .54642 .70501 .58092 .73595 .51449 .70359 .47775 Metetra
.931 .787 .679 r
.70359 .47775 .73595 .51449 .76612 .44295 .73445 .40386 Metetra
.932 .781 .671 r
.73445 .40386 .76612 .44295 .79557 .36951 .76458 .32809 Metetra
.827 .371 0 r
.29083 .44079 .32723 .47902 .35444 .53199 .31786 .49222 Metetra
.797 .334 0 r
.31786 .49222 .35444 .53199 .38273 .58345 .34599 .54214 Metetra
.727 .254 0 r
.34599 .54214 .38273 .58345 .41217 .63014 .37531 .58737 Metetra
.57 .094 0 r
.37531 .58737 .41217 .63014 .44276 .66862 .40583 .62452 Metetra
0 .182 .698 r
.40583 .62452 .44276 .66862 .47439 .69575 .43749 .65055 Metetra
.199 .491 .901 r
.43749 .65055 .47439 .69575 .50688 .7091 .4701 .66308 Metetra
.544 .673 .922 r
.4701 .66308 .50688 .7091 .53995 .70699 .50342 .66046 Metetra
.726 .74 .863 r
.50342 .66046 .53995 .70699 .5733 .6886 .53714 .64191 Metetra
.815 .76 .802 r
.53714 .64191 .5733 .6886 .6066 .65456 .57093 .60803 Metetra
.863 .766 .754 r
.57093 .60803 .6066 .65456 .63956 .60639 .60449 .5603 Metetra
.89 .768 .72 r
.60449 .5603 .63956 .60639 .67194 .54642 .63757 .50102 Metetra
.908 .769 .697 r
.63757 .50102 .67194 .54642 .70359 .47775 .67 .4332 Metetra
.918 .771 .682 r
.67 .4332 .70359 .47775 .73445 .40386 .70169 .36025 Metetra
.925 .774 .675 r
.70169 .36025 .73445 .40386 .76458 .32809 .73265 .28543 Metetra
.791 .322 0 r
.25338 .40146 .29083 .44079 .31786 .49222 .28042 .44816 Metetra
.733 .266 0 r
.28042 .44816 .31786 .49222 .34599 .54214 .30852 .49335 Metetra
.608 .152 0 r
.30852 .49335 .34599 .54214 .37531 .58737 .3378 .53409 Metetra
0 .047 .597 r
.3378 .53409 .37531 .58737 .40583 .62452 .3683 .56729 Metetra
0 .3 .795 r
.3683 .56729 .40583 .62452 .43749 .65055 .39996 .59016 Metetra
.341 .503 .874 r
.39996 .59016 .43749 .65055 .4701 .66308 .43264 .60052 Metetra
.569 .617 .861 r
.43264 .60052 .4701 .66308 .50342 .66046 .4661 .59691 Metetra
.702 .673 .819 r
.4661 .59691 .50342 .66046 .53714 .64191 .50008 .57859 Metetra
.78 .702 .778 r
.50008 .57859 .53714 .64191 .57093 .60803 .53426 .54613 Metetra
.829 .72 .745 r
.53426 .54613 .57093 .60803 .60449 .5603 .56834 .50086 Metetra
.861 .733 .72 r
.56834 .50086 .60449 .5603 .63757 .50102 .60208 .44487 Metetra
.884 .745 .702 r
.60208 .44487 .63757 .50102 .67 .4332 .63528 .38091 Metetra
.901 .755 .691 r
.63528 .38091 .67 .4332 .70169 .36025 .66785 .31211 Metetra
.913 .767 .685 r
.66785 .31211 .70169 .36025 .73265 .28543 .69976 .24147 Metetra
.703 .217 0 r
.21484 .36098 .25338 .40146 .28042 .44816 .24214 .39996 Metetra
.59 .128 0 r
.24214 .39996 .28042 .44816 .30852 .49335 .27043 .43746 Metetra
0 .023 .579 r
.27043 .43746 .30852 .49335 .3378 .53409 .29983 .47096 Metetra
0 .217 .74 r
.29983 .47096 .3378 .53409 .3683 .56729 .33039 .4978 Metetra
.21 .39 .823 r
.33039 .4978 .3683 .56729 .39996 .59016 .36208 .51563 Metetra
.433 .506 .834 r
.36208 .51563 .39996 .59016 .43264 .60052 .39479 .52263 Metetra
.581 .578 .814 r
.39479 .52263 .43264 .60052 .4661 .59691 .42832 .51758 Metetra
.679 .624 .786 r
.42832 .51758 .4661 .59691 .50008 .57859 .46244 .49986 Metetra
.745 .655 .761 r
.46244 .49986 .50008 .57859 .53426 .54613 .49688 .46994 Metetra
.793 .68 .74 r
.49688 .46994 .53426 .54613 .56834 .50086 .53136 .42895 Metetra
.828 .701 .723 r
.53136 .42895 .56834 .50086 .60208 .44487 .56564 .37863 Metetra
.856 .72 .712 r
.56564 .37863 .60208 .44487 .63528 .38091 .59955 .32129 Metetra
.878 .74 .705 r
.59955 .32129 .63528 .38091 .66785 .31211 .63297 .25961 Metetra
.896 .76 .703 r
.63297 .25961 .66785 .31211 .69976 .24147 .66586 .19616 Metetra
0 0 .503 r
.17516 .3193 .21484 .36098 .24214 .39996 .20303 .34793 Metetra
0 .112 .65 r
.20303 .34793 .24214 .39996 .27043 .43746 .23177 .37518 Metetra
0 .248 .761 r
.23177 .37518 .27043 .43746 .29983 .47096 .2615 .39908 Metetra
.184 .366 .811 r
.2615 .39908 .29983 .47096 .33039 .4978 .29227 .41756 Metetra
.367 .452 .815 r
.29227 .41756 .33039 .4978 .36208 .51563 .32407 .42882 Metetra
.497 .51 .801 r
.32407 .42882 .36208 .51563 .39479 .52263 .35682 .43149 Metetra
.59 .553 .781 r
.35682 .43149 .39479 .52263 .42832 .51758 .39035 .42463 Metetra
.659 .587 .763 r
.39035 .42463 .42832 .51758 .46244 .49986 .42451 .4078 Metetra
.712 .616 .748 r
.42451 .4078 .46244 .49986 .49688 .46994 .45905 .38135 Metetra
.755 .643 .737 r
.45905 .38135 .49688 .46994 .53136 .42895 .49376 .34612 Metetra
.79 .669 .729 r
.49376 .34612 .53136 .42895 .56564 .37863 .52843 .30343 Metetra
.821 .695 .725 r
.52843 .30343 .56564 .37863 .59955 .32129 .56291 .25504 Metetra
.847 .722 .725 r
.56291 .25504 .59955 .32129 .63297 .25961 .59708 .20304 Metetra
.871 .752 .729 r
.59708 .20304 .63297 .25961 .66586 .19616 .63089 .14942 Metetra
0 .339 .811 r
.13429 .27638 .17516 .3193 .20303 .34793 .16308 .29252 Metetra
.115 .399 .851 r
.16308 .29252 .20303 .34793 .23177 .37518 .19259 .30754 Metetra
.273 .441 .846 r
.19259 .30754 .23177 .37518 .2615 .39908 .22291 .32006 Metetra
.392 .471 .822 r
.22291 .32006 .2615 .39908 .29227 .41756 .25407 .32872 Metetra
.48 .496 .797 r
.25407 .32872 .29227 .41756 .32407 .42882 .28609 .33232 Metetra
.546 .518 .775 r
.28609 .33232 .32407 .42882 .35682 .43149 .3189 .32998 Metetra
.598 .539 .759 r
.3189 .32998 .35682 .43149 .39035 .42463 .3524 .32108 Metetra
.642 .561 .747 r
.3524 .32108 .39035 .42463 .42451 .4078 .38648 .30534 Metetra
.68 .583 .74 r
.38648 .30534 .42451 .4078 .45905 .38135 .42098 .28298 Metetra
.714 .608 .737 r
.42098 .28298 .45905 .38135 .49376 .34612 .45573 .25456 Metetra
.745 .635 .738 r
.45573 .25456 .49376 .34612 .52843 .30343 .4906 .22092 Metetra
.775 .666 .742 r
.4906 .22092 .52843 .30343 .56291 .25504 .52546 .18323 Metetra
.804 .701 .751 r
.52546 .18323 .56291 .25504 .59708 .20304 .56021 .14286 Metetra
.831 .74 .765 r
.56021 .14286 .59708 .20304 .63089 .14942 .59481 .1012 Metetra
.397 .629 .947 r
.09217 .23214 .13429 .27638 .16308 .29252 .12226 .23433 Metetra
.46 .589 .895 r
.12226 .23433 .16308 .29252 .19259 .30754 .15287 .23579 Metetra
.503 .559 .846 r
.15287 .23579 .19259 .30754 .22291 .32006 .18404 .23586 Metetra
.535 .54 .806 r
.18404 .23586 .22291 .32006 .25407 .32872 .2158 .23386 Metetra
.562 .53 .777 r
.2158 .23386 .25407 .32872 .28609 .33232 .24817 .22921 Metetra
.585 .528 .758 r
.24817 .22921 .28609 .33232 .3189 .32998 .2811 .2215 Metetra
.607 .532 .745 r
.2811 .2215 .3189 .32998 .3524 .32108 .31456 .21043 Metetra
.627 .542 .738 r
.31456 .21043 .3524 .32108 .38648 .30534 .34848 .19587 Metetra
.648 .556 .737 r
.34848 .19587 .38648 .30534 .42098 .28298 .38279 .17794 Metetra
.669 .575 .74 r
.38279 .17794 .42098 .28298 .45573 .25456 .41741 .15687 Metetra
.692 .6 .749 r
.41741 .15687 .45573 .25456 .4906 .22092 .45225 .13308 Metetra
.715 .631 .762 r
.45225 .13308 .4906 .22092 .52546 .18323 .48726 .10713 Metetra
.74 .67 .782 r
.48726 .10713 .52546 .18323 .56021 .14286 .52237 .07968 Metetra
.765 .718 .808 r
.52237 .07968 .56021 .14286 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12226 .23433 .08051 .17394 Metetra
.655 .673 .855 r
.08051 .17394 .12226 .23433 .15287 .23579 .11254 .16124 Metetra
.644 .623 .814 r
.11254 .16124 .15287 .23579 .18404 .23586 .14483 .14843 Metetra
.633 .586 .783 r
.14483 .14843 .18404 .23586 .2158 .23386 .1774 .13551 Metetra
.625 .559 .761 r
.1774 .13551 .2158 .23386 .24817 .22921 .21025 .12249 Metetra
.619 .542 .746 r
.21025 .12249 .24817 .22921 .2811 .2215 .24339 .10934 Metetra
.616 .532 .737 r
.24339 .10934 .2811 .2215 .31456 .21043 .27681 .09609 Metetra
.615 .529 .734 r
.27681 .09609 .31456 .21043 .34848 .19587 .31052 .08272 Metetra
.616 .532 .737 r
.31052 .08272 .34848 .19587 .38279 .17794 .34452 .06923 Metetra
.619 .542 .746 r
.34452 .06923 .38279 .17794 .41741 .15687 .37882 .05563 Metetra
.625 .559 .761 r
.37882 .05563 .41741 .15687 .45225 .13308 .41342 .04191 Metetra
.633 .586 .783 r
.41342 .04191 .45225 .13308 .48726 .10713 .44833 .02806 Metetra
.644 .623 .814 r
.44833 .02806 .48726 .10713 .52237 .07968 .48355 .01409 Metetra
.655 .673 .855 r
.48355 .01409 .52237 .07968 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onW[=[o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojN/
fP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nW[=X00ol0003oYjcJo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nW[=X00ol0003oYjcJojN/fP03ojN/fP04o`000?nW[=[oYjcJo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojN/fP04o`000?nW[=[oYjcJo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onTWm3o0000ojN/fP09
ojN/fP05o`000?nW[=[oYjcJojN/f_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojBOd?l0003oY9o@00;oY9o@
00?o0000ojN/f_nW[=X01onW[=X00ol0003oYjcJojN/fP02ojN/fP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nTWm000ol0003oYjcJojN/fP06ojN/fP03o`000?nW[=[oYjcJ00?oYjcJ00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojBOd003o`000?nW[=[oYjcJ00KoYjcJ00?o0000
ojN/f_nW[=X00onW[=X00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coY9o@00?o0000ojN/
f_nW[=X01OnW[=X00ol0003oYjcJojN/fP04ojN/fP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnRU/P00ol0003oY9o@ojBOd009ojBOd003o`000?nW[=[oYjcJ00GoYjcJ00?o0000ojN/f_nW
[=X01OnW[=X00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000SoXYK800?o0000ojBO
d?nTWm002_nTWm000ol0003oYjcJojN/fP04ojN/fP03o`000?nW[=[oYjcJ00KoYjcJ00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onRU/So0000oj:Fb009oj:Fb003o`000?nTWm3o
Y9o@00[oY9o@00?o0000ojN/f_nW[=X00onW[=X00ol0003oYjcJojN/fP06ojN/fP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnOSl;o0000oj:Fb?nRU/So000000WoXYK800?o0000ojBOd?nTWm00
2_nTWm000ol0003oYjcJojN/fP03ojN/fP03o`000?nW[=[oYjcJ00OoYjcJ00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoWho200?o0000oj:Fb?nRU/P02_nRU/P00ol0003oY9o@ojBOd00:ojBOd003
o`000?nW[=[oYjcJ00;oYjcJ00?o0000ojN/f_nW[=X02?nW[=X00ol0003oooooooooo`2Booooo`00
KOooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eoooo
o`Co000000?oWho2o`000?nOSl801?nOSl800ol0003oXYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@
00[oY9o@00?o0000ojN/f_nW[=X00_nW[=X00ol0003oYjcJojN/fP08ojN/fP;o0000Toooool006go
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;oin?
`P03o`000?nRU/SoXYK800[oXYK800?o0000ojBOd?nTWm002_nTWm001Ol0003oYjcJojN/f_nW[=[o
000000WoYjcJ00?o0000ol>gc_l00000Toooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03omgMgOl@413oV9RH01?ooooo1?l0000<oin?`P03o`000?nRU/SoXYK800[oXYK800?o0000
ojBOd?nTWm002onTWm001?l0003oYjcJojN/f_l00008ojN/fP05o`000?o3]lko`kO>ol>gc_l00000
T_ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40oo
oooo0_l00002oij:_P03o`000?nNR[ko000000_oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003o
Y9o@ojBOd00:ojBOd004o`000?nW[=[oYjcJo`0000OoYjcJ00?o0000ol>gc_o3]lh00oo3]lh00ol0
003oooooooooo`2?ooooo`00S_ooool3o`0000KoWXZn00?o0000oin?`_nOSl802_nOSl800ol0003o
XYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@00_oY9o@00?o0000ojN/f_l000001OnW[=X2o`0000Oo
`kO>00?o0000ooooooooool0S_ooool008cooooo0ol00008oij:_P03o`000?nOSl;oWho200[oWho2
00?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd00:ojBOd003o`000?nW[=[o000000CoYjcJ
00?o0000ol>gc_o3]lh01oo3]lh2o`0008oooooo0029ooooo`Co000000?oWXZno`000?nNR[h02?nN
R[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800[oXYK800?o0000ojBOd?nTWm002onT
Wm02o`0000?oYjcJ00?o0000ol>gc_o3]lh02Oo3]lh00ol0003oooooooooo`2=ooooo`00D?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08?oo
ool4o`000003oif8_?l0003oWXZn00[oWXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:F
b00;oj:Fb003o`000?nTWm3oY9o@00_oY9o@00Co0000ojN/f_nW[=[o00003Oo3]lh00ol0003ooooo
ooooo`2<ooooo`00D?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo01kooooo1?l00005oif8_003o`000?nNR[koWXZn00SoWXZn00?o0000oin?`_nOSl80
2onOSl800ol0003oXYK8oj:Fb00:oj:Fb003o`000?nTWm3oY9o@00_oY9o@00?o0000ojN/f_l00000
3oo3]lh00ol0003oooooooooo`2;ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00_ooooo
1Ol0000Mooooo`?o000000?oWHRlo`000?nMR;`01OnMR;`00ol0003oWXZnoij:_P09oij:_P03o`00
0?nOSl;oWho200[oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd00:ojBOd0;o0000
4?o3]lh2o`0008cooooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgM
ooooool0000Kooooo`?o00001OnMR;`00ol0003oWHRloif8_003oif8_003o`000?nNR[koWXZn00Wo
WXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00Wo
Y9o@0ol0000Aol>gcP;o0000Roooool0053ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0001Wooooo0ol000000onMQk_o0000oif8_00;oif8_003o`000?nNR[koWXZn
00WoWXZn00?o0000oin?`_nOSl802_nOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@
00OoY9o@00Go0000okf[b?l0003o_J_8o`00000Aol>gcP03o`000?oooooooooo08Wooooo001@oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Fooooo`?o00000_nMQk/0
1?l0003oWHNkoif7^ol0000;oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802_nO
Sl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00KoY9o@00Co0000okf[b?nmZlSo0000
0_nmZlP00ol0003o`kO>ol>gcP0?ol>gcP03o`000?oooooooooo08Sooooo001@ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000Dooooo`?o00001onMQk/00ol0003oWHRl
oif8_009oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802onOSl800ol0003oXYK8
oj:Fb00;oj:Fb003o`000?nTWm3oY9o@00?oY9o@0_l00003okf[b004o`000?nmZlSo_J_8o`00017o
`kO>0_l00029ooooo`00D?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?oo
ool04?ooool3o`0000[oWHNk00?o0000oif8_?nMR;`02_nMR;`00ol0003oWXZnoij:_P09oij:_P03
o`000?nOSl;oWho200[oWho200?o0000oj:Fb?nRU/P02onRU/P00ol0003oY9o@ojBOd002ojBOd003
o`000?nmZlSo_J_800?o_J_800Go0000okf[b?nmZlSo_J_8o`00000Aol>gcP;o0000R?ooool007?o
oooo0ol000000onMR;co0000o`00000:oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nN
R[h02OnNR[h00ol0003oWho2oin?`P0;oin?`P03o`000?nRU/SoXYK800_oXYK800Co0000ojBOd?nT
Wm3o00001_nmZlP01Ol0003o_J_8okf[b?nmZlSo000001;o`kO>0_l00027ooooo`00L?ooool3o`00
00CoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn
00WoWXZn00?o0000oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb00;oj:Fb003o`000?nTWm3o0000
00Oo_J_800?o0000okf[b?nmZlP00_nmZlP00ol0003o`kO>ol>gcP0@ol>gcP03o`000?oooooooooo
08Gooooo001^ooooo`?o00001onMR;`00ol0003oWHNkoif7^`08oif7^`03o`000?nMR;coWHRl00[o
WHRl00?o0000oij:__nNR[h02OnNR[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800_o
XYK80_l00008okf[b003o`000?nmZlSo_J_800?o_J_800?o0000ol>gc_o3]lh03_o3]lh3o`0008Ko
oooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Sooooo`?o
00000_nMR;`00ol0003oWHRloif8_005oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8_?nM
R;`02OnMR;`00ol0003oWXZnoij:_P09oij:_P03o`000?nOSl;oWho200_oWho200?o0000oj:Fb?nR
U/P02OnRU/P00ol0003o]j73o`000008okf[b003o`000?nmZlSo_J_800?o_J_800?o0000ol>gc_o3
]lh03Oo3]lh00ol0003oe;g3omBm``02o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oWXZno`00
0?nMR;`02OnMR;`00ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:
__nNR[h02_nNR[h00ol0003oWho2oin?`P0:oin?`P03o`000?nRU/SoXYK800SoXYK800Go0000okNQ
`ongXL?o]j73o`000007okf[b003o`000?nmZlSo_J_800Co_J_800?o0000ol>gc_o3]lh02oo3]lh0
0ol0003oe;g3omBm``02omBm``;o0000Q?ooool003?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00003oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000
oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000
oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb005oj:Fb0;o00001?ngXL<00ol0003o_J_8okf[b005
okf[b003o`000?nmZlSo_J_800Go_J_800?o0000ol>gc_o3]lh02Oo3]lh00ol0003oe;g3omBm``04
omBm``03o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP0Kooooo`?o00001?nNR[h01Ol0003oWXZnoij:__nNR[ko000000[oWHRl00?o
0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00WoWXZn00?o
0000oin?`_nOSl802onOSl800ol0003oXYK8oj:Fb004oj:Fb003o`000?ngXL?o]j7300Go]j7300?o
0000okf[b?nmZlP01?nmZlP00ol0003o_J_8okf[b005okf[b003o`000?o3]lko`kO>00So`kO>00?o
0000omBm`ooD_L<01OoD_L<2o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Hooooo`?o00002_nNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P03o`000?nO
Sl;oWho200_oWho200Co0000oj:Fb?nRU/SoXYK80_l00008okNQ``03o`000?nmZlSo_J_800Co_J_8
00?o0000okf[b?nmZlP01_nmZlP00ol0003o`kO>ol>gcP06ol>gcP03o`000?oD_L?oe;g300Ooe;g3
0_l00022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
5?ooool3o`000003oin?`_l0003oWXZn00[oWXZn00?o0000oif8_?nMR;`02OnMR;`00ol0003oWHNk
oif7^`08oif7^`03o`000?nMR;coWHRl00[oWHRl00?o0000oij:__nNR[h02OnNR[h00ol0003oWho2
oin?`P0;oin?`P04o`000?nRU/SoXYK8o`0000_o]j7300?o0000okf[b?nmZlP00onmZlP00ol0003o
_J_8okf[b007okf[b003o`000?o3]lko`kO>00Go`kO>00?o0000omBm`ooD_L<02?oD_L<2o`00087o
oooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
01Cooooo0ol00004oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0
003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nNR[h02OnNR[h00ol0
003oWho2oin?`P0;oin?`P03o`000?nRU/So000000co]j7300?o0000okf[b?nmZlP00onmZlP00ol0
003o_J_8okf[b007okf[b003o`000?o3]lko`kO>00Co`kO>00?o0000omBm`ooD_L<02_oD_L<00ol0
003oooooooooo`1oooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`?o00001onOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;co
WHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[ko
WXZn00[oWXZn00?o0000oin?`_nOSl802_nOSl82o`0000go]j7300?o0000okf[b?nmZlP00onmZlP0
0ol0003o_J_8okf[b008okf[b003o`000?o3]lko`kO>00;o`kO>00?o0000omBm`ooD_L<02ooD_L<2
o`00083ooooo001Gooooo`?o000000?oWho2o`000?nOSl801_nOSl800ol0003oWXZnoij:_P09oij:
_P03o`000?nMR;coWHRl00WoWHRl00?o0000oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8
_003o`000?nNR[koWXZn00WoWXZn00?o0000oin?`_nOSl802OnOSl800ol0003o/IVoo`00000>okNQ
``03o`000?nmZlSo_J_800;o_J_800?o0000okf[b?nmZlP02?nmZlP01Ol0003o`kO>ol>gc_o3]lko
000000ooe;g30_l0001oooooo`00E?ooool3o`000003oj:Fb?l0003oWho200[oWho200?o0000oij:
__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8
_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P03o`000?nOSl;oWho200OoWho200Go0000ok6I
_onaVKoo/IVoo`00000=okNQ``03o`000?nmZlSo_J_800;o_J_800?o0000okf[b?nmZlP02OnmZlP0
0ol0003o`kO>o`00000AomBm``03o`000?oooooooooo07gooooo001Booooo`?o00001?nRU/P00ol0
003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0
003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00WoWHRl00?o0000oij:__nNR[h02_nNR[h00ol0
003oWho2oin?`P05oin?`P;o00001?naVKl00ol0003o]j73okNQ``0<okNQ``05o`000?nmZlSo_J_8
okf[b?l000003?nmZlP00ol0003oe;g3omBm``0AomBm``03o`000?oooooooooo07cooooo000Woooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003oj:Fb?l0003oXYK800?oXYK800?o0000
oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000
oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o0000
oin?`_nOSl801?nOSl800ol0003o/IVook6I_`05ok6I_`03o`000?ngXL?o]j7300_o]j7300Go0000
okf[b?nmZlSo_J_8o`00000<okf[b003o`000?oD_L?oe;g3017oe;g30_l0001mooooo`009oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg027ooooo0ol00009oj:Fb003o`000?nOSl;oWho200WoWho200?o
0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o
0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P0:oij:_P04o`000?nOSl;oWho2oin?`P;o0000
2?naVKl00ol0003o]j73okNQ``0<okNQ``04o`000?nmZlSo_J_8o`0000_o_J_800?o0000olfc`?l0
00004ooD_L<2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`0000_o
XYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00So
WHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00[o
WXZn00Co0000oin?`_nOSl;o00002_naVKl00ol0003o]j73okNQ``0<okNQ``04o`000?nmZlSo_J_8
o`0000[o_J_800Co0000olfc`?o=/l3o00005?oD_L<00ol0003oooooooooo`1jooooo`009oooool0
1Ol0003ooooooooooooooooo000001cooooo0ol00002ojBOd003o`000?nTWm3o000000[oXYK800?o
0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00WoWHRl00?o
0000oif7^onMQk/02?nMQk/00ol0003oWHRloif8_00:oif8_003o`000?nNR[koWXZn00WoWXZn00?o
0000oin?`_l000003?naVKl00ol0003o]j73okNQ``0<okNQ``03o`000?nmZlSo000000Wo_J_800?o
0000olfc`?o=/l000_o=/l000ol0003oe;g3omBm``0@omBm``03o`000?oN`;[o000007_ooooo000W
ooooo`05o`000?ooooooooooooooool000006Oooool4o`0000GoY9o@0_l0000;oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P09oij:_P;o00003Ona
VKl00ol0003o]j73okNQ``0<okNQ``03o`000?nmZlSo000000So_J_800?o0000olfc`?o=/l001?o=
/l000ol0003oe;g3omBm``0>omBm``03o`000?oN`;[og/2j00;o0000N_ooool002Oooooo00Go410@
oooooooooooooooooa0@400Gooooo`?o00002_nTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02OnNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00WoWHNk00?o0000oif8_?nMR;`02OnMR;`00ol0003oWXZnoij:_P07oij:_P;o000000?o
Zi>mo`000?naVKl03OnaVKl00ol0003o]j73okNQ``0<okNQ``;o00001onmZlP00ol0003ocK?0olfc
`005olfc`003o`000?oD_L?oe;g300koe;g300Co0000omk0^_oN`;[og/2j0_l0001iooooo`009ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onTWm3o0000ojBOd008ojBOd003o`00
0?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802OnOSl800ol0003oWXZnoij:_P08oij:_P03o`00
0?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_00:oif8_003o`00
0?nNR[koWXZn00CoWXZn0_l00004oj^C_@03o`000?naVKoo/IVo00_o/IVo00?o0000okNQ`ongXL<0
3?ngXL<2o`0000Ko_J_800?o0000olfc`?o=/l001oo=/l000ol0003oe;g3omBm``0<omBm``03o`00
0?oN`;[og/2j00?og/2j00?o0000ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`?o00001?nW[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800WoXYK8
00?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P09oij:_P03o`000?nMR;coWHRl00SoWHRl
00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_009oif8_003o`000?nNR[koWXZn00?oWXZn
00?o0000oj^C_On[Tkd01?n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o]j7300_o]j73
0_l00006okf[b003o`000?o=/l3ocK?000OocK?000?o0000omBm`ooD_L<02ooD_L<00ol0003og/2j
omk0^P05omk0^P03o`000?oooooooooo07Kooooo000kooooo`Go00001OnW[=X00ol0003oY9o@ojBO
d009ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:
_P09oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8
_009oif8_004o`000?nNR[koWXZnoij:_P;o00001on[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`00
0?ngXL?o]j7300co]j7300?o0000okf[b?nmZlP00onmZlP00ol0003ocK?0olfc`009olfc`003o`00
0?oD_L?oe;g300[oe;g300?o0000omk0^_oN`;X01OoN`;X2o`0007Oooooo000iooooo`?o00002_nW
[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800WoXYK800?o0000oin?`_nOSl802?nO
Sl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnM
Qk/00ol0003oWHRloif8_00:oif8_0?o00002_n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ng
XL?o]j7300_o]j7300?o0000okf[b?nmZlP00_nmZlP00ol0003ocK?0olfc`00;olfc`003o`000?oD
_L?oe;g300Soe;g300?o0000omk0^_oN`;X01ooN`;X2o`0007Kooooo000gooooo`Co00003?nW[=X0
0ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl80
0ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00WoWHRl00?o0000oif7^onMQk/02OnMQk/0
0ol0003oWHRloif8_008oif8_0;o00003?n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o
]j7300_o]j730_l00002okf[b003o`000?o=/l3ocK?000cocK?000?o0000omBm`ooD_L<01ooD_L<0
0ol0003og/2jomk0^P09omk0^P03o`000?oooooooooo07Cooooo000dooooo`?o000000GoZ[cWo`00
0?nZ_>OoZ[cWo`00000;ojN/fP03o`000?nTWm3oY9o@00SoY9o@00?o0000oj:Fb?nRU/P02?nRU/P0
0ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00WoWXZn00?o0000oif8_?nMR;`02?nMR;`0
0ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl00KoWHRl0_l000000onUS[co0000oj^C_@0<
oj^C_@03o`000?naVKoo/IVo00_o/IVo00?o0000okNQ`ongXL<02ongXL<2o`000003okf[b?l0003o
cK?000oocK?000?o0000omBm`ooD_L<01_oD_L<00ol0003og/2jomk0^P0:omk0^P03o`000?oooooo
oooo07?ooooo000booooo`?o00001onZ_>L00ol0003oYjcJojN/fP09ojN/fP03o`000?nTWm3oY9o@
00SoY9o@00?o0000oj:Fb?nRU/P02?nRU/P00ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn
00SoWXZn00?o0000oif8_?nMR;`02?nMR;`00ol0003oWHNkoif7^`09oif7^`03o`000?nMR;coWHRl
00GoWHRl00?o0000ojF>_?nUS[`00_nUS[`00ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo
00co/IVo00?o0000okNQ`ongXL<02_ngXL<00ol0003o]j73o`00000Aolfc`003o`000?oD_L?oe;g3
00Goe;g300?o0000omk0^_oN`;X02ooN`;X2o`0007Cooooo000aooooo`03o`000?nZ_>OoZ[cW00Wo
Z[cW00?o0000ojN/f_nW[=X02?nW[=X00ol0003oY9o@ojBOd008ojBOd003o`000?nRU/SoXYK800So
XYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00Wo
WHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRloif8_002oif8_0;o00001OnUS[`00ol0003o
Zi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<02_ngXL<00ol0003o
]j73o`00000Bolfc`003o`000?oD_L?oe;g300Coe;g300?o0000omk0^_oN`;X03?oN`;X00ol0003o
ooooooooo`1booooo`00<Oooool2o`0000[oZ[cW00?o0000ojN/f_nW[=X02OnW[=X00ol0003oY9o@
ojBOd008ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onOSl800ol0003oWXZn
oij:_P09oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/02OnMQk/00ol0003oWHRl
oif8_002o`0000OoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`00
0?ngXL?o]j7300Wo]j730_l000000oo6Z[go0000olfc`00@olfc`003o`000?oD_L?oe;g300?oe;g3
00?o0000omk0^_oN`;X03_oN`;X00ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo0_l0000;ojZli`03o`000?nW[=[oYjcJ00SoYjcJ00?o0000ojBOd?nTWm00
2?nTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nOSl;oWho200SoWho200?o0000oij:__nNR[h0
2?nNR[h00ol0003oWHRloif8_008oif8_003o`000?nMQk_oWHNk00WoWHNk00?o0000oif8_?l00000
2_nUS[`00ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<0
2OngXL<01?l0003oaZZmolJZ_Ol0000Bolfc`005o`000?oD_L?oe;g3omBm`ol000004_oN`;X00ol0
003oooooooooo`1`ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000oooo
ool000002onZ_>L00ol0003oYjcJojN/fP08ojN/fP03o`000?nTWm3oY9o@00OoY9o@00?o0000oj:F
b?nRU/P02?nRU/P00ol0003oWho2oin?`P08oin?`P03o`000?nNR[koWXZn00SoWXZn00?o0000oif8
_?nMR;`02OnMR;`00ol0003oWHNkoif7^`08oif7^`;o00002onUS[`00ol0003oZi>moj^C_@0;oj^C
_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<01ongXL<2o`0000?oaZZm00?o0000olfc
`?o=/l004?o=/l001?l0003oe;g3omBm`ol0000Bomk0^P;o0000LOooool002Gooooo00Go410@oooo
oooooooooooooa0@4007ooooo`04o`000?ooooooooooo`0000[oZ[cW00?o0000ojN/f_nW[=X02OnW
[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nO
Sl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00SoWHRl00?o0000oif7^onMQk/01OnM
Qk/3o`000003oj2:_?l0003oYHjl00[oYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I
_`0<ok6I_`03o`000?ngXL?o]j7300Ko]j7300?o0000olJZ_Ol000000oo6Z[d00ol0003ocK?0olfc
`00@olfc`003o`000?oD_L?o000001Cog/2j00?o0000ooooooooool0Koooool002Gooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00000oooool00ol0003oZ[cWojZli`08ojZli`03o`000?nW
[=[oYjcJ00SoYjcJ00?o0000ojBOd?nTWm001onTWm000ol0003oXYK8oj:Fb008oj:Fb003o`000?nO
Sl;oWho200SoWho200?o0000oij:__nNR[h02?nNR[h00ol0003oWHRloif8_008oif8_003o`000?nM
Qk_oWHNk00;oWHNk0ol00005oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02_n[
Tkd00ol0003o/IVook6I_`0=ok6I_`03o`000?ngXL?o]j7300Co]j7300Co0000olJZ_Oo6Z[go0000
1?o6Z[d00ol0003ocK?0olfc`00@olfc`003o`000?oN`;[og/2j01;og/2j00?o0000onG2/ol00000
L?ooool002Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ojZlionZ_>L02?nZ_>L00ol0003oYjcJojN/fP08ojN/fP03o`000?nTWm3oY9o@00OoY9o@
00?o0000oj:Fb?nRU/P02?nRU/P00ol0003oWho2oin?`P07oin?`P03o`000?nNR[koWXZn00SoWXZn
00?o0000oif8_?nMR;`02OnMR;`4o`0000SoX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>m
oj^C_@0;oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ongXL<00ongXL<01Ol0003oaZZm
olJZ_Oo6Z[go000000GoaZZm00?o0000olfc`?o=/l003oo=/l000ol0003og/2jomk0^P0Bomk0^P04
o`000?oU`[?oiL:co`0006oooooo000Uooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`04ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojN/f_nW[=X01onW[=X00ol0
003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl802?nOSl800ol0
003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00OoWHRl0_l0000;oj2:_003o`000?nUS[coYHjl
00[oYHjl00?o0000oj^C_On[Tkd02_n[Tkd00ol0003o/IVook6I_`0<ok6I_`03o`000?ngXL?o]j73
00;o]j7300?o0000olJZ_Oo6Z[d00_o6Z[d00ol0003oaZZmolJZ_@03olJZ_@03o`000?o=/l3ocK?0
00kocK?000?o0000omRh^Ol000004_oN`;X01?l0003oiL:conG2/ooU`[<2o`0006kooooo000Uoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?nZ_>Oo
Z[cW00OoZ[cW00?o0000ojN/f_nW[=X02?nW[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/So
XYK800OoXYK800?o0000oin?`_nOSl802?nOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;co
WHRl00CoWHRl0ol000000onKR;ko0000oj2:_00;oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000
oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0<ok6I_`04o`000?ngXL?o]j73o`0000GoaZZm00?o
0000olJZ_Oo6Z[d01?o6Z[d00ol0003ocK?0olfc`00<olfc`005o`000?oH^;Wof;RiomRh^Ol00000
4OoN`;X00ol0003oiL:conG2/`02onG2/`03o`000?oooooooooo06cooooo000Uooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?nZ_>OoZ[cW00OoZ[cW
00?o0000ojN/f_nW[=X01onW[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK8
00?o0000oin?`_nOSl801onOSl800ol0003oWXZnoij:_P08oij:_P03o`000?nMR;coWHRl00;oWHRl
0_l00005oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>m
oj^C_@0;oj^C_@03o`000?naVKoo/IVo00co/IVo00?o0000okNQ`ol000001_o6Z[d00ol0003oaZZm
olJZ_@04olJZ_@03o`000?o=/l3ocK?000cocK?000Go0000omRh^OoH^;Wof;Rio`00000@omk0^P03
o`000?oU`[?oiL:c00CoiL:c00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool0
1oooool00ol0003oZ[cWojZli`07ojZli`03o`000?nW[=[oYjcJ00OoYjcJ00?o0000ojBOd?nTWm00
1onTWm000ol0003oXYK8oj:Fb007oj:Fb003o`000?nOSl;oWho200SoWho200?o0000oij:__nNR[h0
2?nNR[h4o`0000OoVhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_00:ojF>_003o`00
0?n[TkgoZi>m00[oZi>m00?o0000ok6I_onaVKl03OnaVKl00ol0003oaZZmolJZ_@05olJZ_@03o`00
0?o6Z[goaZZm00GoaZZm00?o0000olfc`?o=/l002_o=/l000ol0003of;RiomRh^@03omRh^@03o`00
0?oN`;[og/2j00gog/2j00?o0000onG2/ooU`[<01OoU`[<00ol0003oooooooooo`1Zooooo`00<?oo
ool00ol0003oooooooooo`08ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojN/f_nW[=X01onW
[=X00ol0003oY9o@ojBOd007ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onO
Sl800ol0003oWXZnoij:_P06oij:_P?o00002_nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I_`0;ok6I_`;o00001oo6
Z[d00ol0003oaZZmolJZ_@05olJZ_@03o`000?o=/l3ocK?000[ocK?000?o0000omRh^OoH^;T01?oH
^;T00ol0003og/2jomk0^P0;omk0^P03o`000?oU`[?oiL:c00KoiL:c00?o0000ooooooooool0J_oo
ool002oooooo0_l0000;ooooo`03o`000?nZ_>OoZ[cW00KoZ[cW00?o0000ojN/f_nW[=X01onW[=X0
0ol0003oY9o@ojBOd006ojBOd003o`000?nRU/SoXYK800SoXYK800?o0000oin?`_nOSl801onOSl80
1?l0003oWXZnoij:__nNR[h5o`0000;oUHO200?o0000oi^8__nKR;h02OnKR;h00ol0003oX8Zloj2:
_009oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVook6I
_`0:ok6I_`04o`000?nnX[co_Z:lo`0000KoaZZm00?o0000olJZ_Oo6Z[d01_o6Z[d00ol0003ocK?0
olfc`008olfc`003o`000?oH^;Wof;Ri00Kof;Ri00?o0000omk0^_oN`;X02_oN`;X00ol0003oiL:c
onG2/`07onG2/`03o`000?oooooooooo06Wooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ojZlionZ_>L01_nZ_>L00ol0003oYjcJojN/fP07ojN/fP03o`000?nTWm3oY9o@00KoY9o@00?o
0000oj:Fb?nRU/P01onRU/P00ol0003oWho2oin?`P03oin?`PSo00002?nEQl800ol0003oVhRnoi^8
_P08oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`00ol0003oZi>moj^C
_@0;oj^C_@03o`000?naVKoo/IVo00So/IVo00Go0000okjR_?nnX[co_Z:lo`000006olJZ_@03o`00
0?o6Z[goaZZm00KoaZZm00?o0000olfc`?o=/l001oo=/l000ol0003of;RiomRh^@07omRh^@03o`00
0?oN`;[og/2j00Wog/2j00?o0000onG2/ooU`[<02OoU`[<00ol0003oooooooooo`1Xooooo`00;ooo
ool00ol0003oooooooooo`0<ooooo`oo00000onW[=X00ol0003oY9o@ojBOd006ojBOd003o`000?nR
U/SoXYK800?oXYK82_l00005ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nK
R;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[
Tkd00ol0003o/IVook6I_`07ok6I_`03o`000?nnX[co_Z:l00;o_Z:l00?o0000olJZ_Oo6Z[d01?o6
Z[d00ol0003oaZZmolJZ_@07olJZ_@03o`000?o=/l3ocK?000KocK?000?o0000omRh^OoH^;T02?oH
^;T00ol0003og/2jomk0^P07omk0^P03o`000?oU`[?oiL:c00_oiL:c00?o0000ooooooooool0Iooo
ool002oooooo00?o0000ooooooooool03Oooool00ol0003oIJ7bofFQlP05ofFQlP03o`000?meU^Go
MIKU00?oMIKU4_l00005ohR:cP03o`000?n?QlKoShO600SoShO600?o0000oiF7`_nEQl801onEQl80
0ol0003oVhRnoi^8_P09oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`0
0ol0003oZi>moj^C_@0:oj^C_@03o`000?naVKoo/IVo00Ko/IVo00?o0000okjR_?nnX[`01?nnX[`0
0ol0003oaZZmolJZ_@03olJZ_@03o`000?o6Z[goaZZm00OoaZZm00?o0000olfc`?o=/l001Oo=/l00
0ol0003of;RiomRh^@0:omRh^@03o`000?oN`;[og/2j00Kog/2j00?o0000onG2/ooU`[<02ooU`[<0
0ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0>ooooo`03o`000?mUXO;oIJ7b
00GoIJ7b00?o0000ogFFiOmeU^D01_meU^D00ol0003oP8oHoh2?f006oh2?f003o`000?n8R/koR8[>
00SoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn
00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_009ojF>_003o`000?n[TkgoZi>m
00_oZi>m00?o0000ok6I_onaVKl01?naVKl00ol0003o_Z:lokjR_005okjR_003o`000?o6Z[goaZZm
00?oaZZm00?o0000olJZ_Oo6Z[d02?o6Z[d00ol0003ocK?0olfc`003olfc`003o`000?oH^;Wof;Ri
00_of;Ri00?o0000omk0^_oN`;X01OoN`;X00ol0003oiL:conG2/`0=onG2/`03o`000?oooooooooo
06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ofFQl_mUXO801OmUXO800ol0003o
MIKUogFFi@06ogFFi@03o`000?n0SmSoP8oH00KoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003o
ShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003o
X8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o
/IVook6I_`03ok6I_`03o`000?nnX[co_Z:l00Oo_Z:l00?o0000olJZ_Oo6Z[d00_o6Z[d00ol0003o
aZZmolJZ_@09olJZ_@03o`000?o=/l3ocK?000;ocK?000?o0000omRh^OoH^;T03?oH^;T00ol0003o
g/2jomk0^P04omk0^P03o`000?oU`[?oiL:c00koiL:c00?o0000ooooooooool0IOooool002kooooo
0ol0000Aooooo`03o`000?mUXO;oIJ7b00GoIJ7b00?o0000ogFFiOmeU^D01OmeU^D00ol0003oP8oH
oh2?f006oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?QlH02?n?QlH00ol0003oUHO2
oiF7`P07oiF7`P03o`000?nKR;koVhRn00WoVhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjl
ojF>_00:ojF>_003o`000?n[TkgoZi>m00_oZi>m00Go0000ok6I_onaVKoo/IVoo`00000:okjR_003
o`000?o6Z[goaZZm00;oaZZm00?o0000olJZ_Oo6Z[d02Oo6Z[d01Ol0003ocK?0olfc`?o=/l3o0000
013of;Ri00?o0000omk0^_oN`;X00_oN`;X00ol0003oiL:conG2/`0?onG2/`;o0000I_ooool002oo
oooo00?o0000ooooooooool04Oooool00ol0003oIJ7bofFQlP04ofFQlP03o`000?meU^GoMIKU00Ko
MIKU00?o0000oh2?f?n0SmP01_n0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?QlKoShO600Oo
ShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nPR[coX8Zl00[o
X8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>moj^C_@0;oj^C_@04o`000?naVKoo/IVoo`00
00co_Z:l00Go0000olJZ_Oo6Z[goaZZmo`00000<olJZ_@04o`000?o=/l3ocK?0o`00017of;Ri00Go
0000omk0^_oN`;[og/2jo`00000@onG2/`03o`000?oYa:oo000006Kooooo000_ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ofFQl_mUXO801?mUXO800ol0003oMIKUogFFi@05ogFFi@03o`000?n0
SmSoP8oH00KoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nE
Ql;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00WoYHjl00?o0000oj^C_On[Tkd02on[Tkd00ol0003o/IVoo`00000=okjR_005o`000?o6
Z[goaZZmolJZ_Ol000003?o6Z[d00ol0003ocK?0o`00000BomRh^@04o`000?oN`;[og/2jo`00017o
iL:c00Co0000onW4[ooYa:oo0000IOooool002oooooo00?o0000ooooooooool04oooool00ol0003o
IJ7bofFQlP04ofFQlP03o`000?meU^GoMIKU00GoMIKU00?o0000oh2?f?n0SmP01_n0SmP00ol0003o
R8[>ohR:cP07ohR:cP03o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003o
VhRnoi^8_P09oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02_nUS[`00ol0003o
Zi>moj^C_@0:oj^C_@;o00003_nnX[`01Ol0003oaZZmolJZ_Oo6Z[go000000goaZZm00?o0000omRh
^OoH^;T04_oH^;T00ol0003og/2jo`00000@onG2/`03o`000?oYa:oojLB_00;ojLB_00?o0000oooo
ooooool0H_ooool002oooooo00?o0000ooooooooool04oooool2o`0000GoIJ7b00?o0000ogFFiOme
U^D01_meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?
QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o0000oj2:_?nP
R[`02_nPR[`00ol0003oYHjlojF>_009ojF>_003o`000?n[TkgoZi>m00WoZi>m00?o0000okJK_?l0
00003onnX[`01?l0003oaZZmolJZ_Ol0000=olJZ_@03o`000?oH^;Wof;Ri01?of;Ri00?o0000onG2
/ooU`[<03ooU`[<00ol0003ojLB_onW4[`02onW4[`;o0000Hoooool002kooooo00?o0000oooooooo
ool05Oooool2o`0000GoIJ7b00?o0000ogFFiOmeU^D01OmeU^D00ol0003oP8oHoh2?f005oh2?f003
o`000?n8R/koR8[>00OoR8[>00?o0000ohn7a_n?QlH02?n?QlH00ol0003oUHO2oiF7`P07oiF7`P03
o`000?nKR;koVhRn00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_00:ojF>_003
o`000?n[TkgoZi>m00OoZi>m00Go0000okJK_?nfVkco]Y^lo`00000>okjR_004o`000?o6Z[goaZZm
o`0000coaZZm00?o0000om:a^Ol000005?oH^;T00ol0003oiL:conG2/`0>onG2/`03o`000?oYa:oo
jLB_00CojLB_00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00001OmUXO800ol0
003oMIKUogFFi@05ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0
003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0
003oX8Zloj2:_009oj2:_003o`000?nUS[coYHjl00[oYHjl00?o0000oj^C_On[Tkd01On[Tkd2o`00
00Co]Y^l00?o0000okjR_?nnX[`03OnnX[`00ol0003oaZZmo`00000;olJZ_@04o`000?oB/KWod[6i
o`0001?of;Ri00?o0000on2m]?l000003ooU`[<00ol0003ojLB_onW4[`05onW4[`03o`000?oooooo
oooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo0_l00005ofFQlP03o`000?meU^GoMIKU
00CoMIKU00?o0000oh2?f?n0SmP01On0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?QlKoShO6
00OoShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nPR[coX8Zl
00[oX8Zl00?o0000ojF>_?nUS[`02OnUS[`00ol0003oZi>moj^C_@04oj^C_@03o`000?nfVkco]Y^l
00Go]Y^l00?o0000okjR_?nnX[`03?nnX[`00ol0003oaZZmo`00000:olJZ_@03o`000?oB/KWod[6i
00;od[6i00?o0000omRh^OoH^;T04?oH^;T01?l0003oh;fdon2m]?l0000=onG2/`03o`000?oYa:oo
jLB_00OojLB_00?o0000ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000CoIJ7b00?o0000
ogFFiOmeU^D01OmeU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00OoR8[>00?o0000
ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00WoVhRn00?o0000
oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_00:ojF>_004o`000?n[TkgoZi>moj^C_@;o00002?nf
Vk`00ol0003o_Z:lokjR_00=okjR_0;o00002_o6Z[d00ol0003od[6iom:a^@02om:a^@03o`000?oH
^;Wof;Ri00oof;Ri00Go0000on2m]?oP_KCoh;fdo`00000=onG2/`03o`000?oYa:oojLB_00SojLB_
00?o0000ooooooooool0G_ooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool06Oooool3o`0000?o
IJ7b00?o0000ogFFiOmeU^D01?meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00Oo
R8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00So
VhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_009ojF>_004o`000?n[TkgoZi>mo`00
00[o]Y^l00?o0000okjR_?nnX[`03OnnX[`2o`0000WoaZZm00?o0000om:a^OoB/KT01?oB/KT00ol0
003of;RiomRh^@0=omRh^@03o`000?oP_KCoh;fd00?oh;fd00?o0000onG2/ooU`[<02OoU`[<00ol0
003ojLB_onW4[`09onW4[`03o`000?oooooooooo05kooooo000Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo01[ooooo00Co0000o`1F
col0003o00000_mUXO800ol0003oMIKUogFFi@04ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000
ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200SoUHO200?o0000
oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nUS[coYHjl00WoYHjl00?o0000
oj^C_Ol000003?nfVk`00ol0003o_Z:lokjR_00<okjR_0;o00002?o6Z[d00ol0003od[6iom:a^@06
om:a^@03o`000?oH^;Wof;Ri00cof;Ri00?o0000on2m]?oP_K@00ooP_K@00ol0003oiL:conG2/`09
onG2/`03o`000?oYa:oojLB_00[ojLB_00?o0000ooooooooool0GOooool001;ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool0
0ol0003o05K?o`1Fc`03o`0000KoMIKU00?o0000oh2?f?n0SmP01On0SmP00ol0003oR8[>ohR:cP07
ohR:cP03o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRnoi^8_P09
oi^8_P03o`000?nPR[coX8Zl00WoX8Zl00?o0000ojF>_?nUS[`02OnUS[`2o`0000go]Y^l00?o0000
okjR_?nnX[`03OnnX[`00ol0003oaZZmolJZ_@05olJZ_@03o`000?oB/KWod[6i00Ood[6i00?o0000
omRh^OoH^;T02ooH^;T00ol0003oh;fdon2m]005on2m]003o`000?oU`[?oiL:c00SoiL:c00?o0000
onW4[ooYa:l02ooYa:l00ol0003oooooooooo`1Looooo`004_ooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01_ooool00ol0003oooooooooo`0Looooo`04o`000?l0E/oo
05K?o`1Fc`;o00001_meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00KoR8[>00?o
0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o
0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_007ojF>_003o`000?n^UKgo000000ko]Y^l00?o
0000okjR_?nnX[`03?nnX[`00ol0003oaZZmolJZ_@05olJZ_@03o`000?oB/KWod[6i00Sod[6i00?o
0000omRh^OoH^;T02_oH^;T00ol0003oh;fdon2m]006on2m]003o`000?oU`[?oiL:c00KoiL:c00?o
0000onW4[ooYa:l03OoYa:l00ol0003oooooooooo`1Kooooo`004_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00Co0000o`1Fcol0E/oo05K?
0_l00005ogFFi@03o`000?n0SmSoP8oH00GoP8oH00?o0000ohR:c_n8R/h01on8R/h00ol0003oShO6
ohn7aP07ohn7aP03o`000?nEQl;oUHO200OoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zl
oj2:_00:oj2:_003o`000?nUS[coYHjl00GoYHjl0_l00003ojjE_@03o`000?nfVkco]Y^l00_o]Y^l
00?o0000okjR_?nnX[`03?nnX[`2o`0000GoaZZm00?o0000om:a^OoB/KT02OoB/KT00ol0003of;Ri
omRh^@09omRh^@03o`000?oP_KCoh;fd00Ooh;fd00?o0000onG2/ooU`[<01_oU`[<00ol0003ojLB_
onW4[`0=onW4[`03o`000?oooooooooo05_ooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool07oooool00ol0003o
05K?o`1Fc`02o`1Fc`;o00001?meU^D00ol0003oP8oHoh2?f005oh2?f003o`000?n8R/koR8[>00Ko
R8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00Wo
VhRn00?o0000oj2:_?nPR[`02OnPR[`00ol0003oYHjlojF>_004ojF>_003o`000?n^UKgo[YFm00?o
[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_00;okjR_0;o00001?o6Z[d00ol0003o
d[6iom:a^@0;om:a^@03o`000?oH^;Wof;Ri00Oof;Ri00?o0000on2m]?oP_K@02OoP_K@00ol0003o
iL:conG2/`04onG2/`03o`000?oYa:oojLB_00gojLB_00?o0000onc6[?l00000G?ooool001;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`0Pooooo`06o`000?l0E/oo05K?o`1Fcol0003o7FKI0_l00003ogFFi@03o`000?n0
SmSoP8oH00CoP8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nE
Ql;oUHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_00:oj2:_003o`000?nU
S[coYHjl00;oYHjl00?o0000ojjE_On^UKd01?n^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nn
X[co_Z:l00_o_Z:l00?o0000okjR_?l000000oo6Z[d00ol0003od[6iom:a^@0;om:a^@03o`000?oH
^;Wof;Ri00Oof;Ri00?o0000on2m]?oP_K@02_oP_K@00ol0003oiL:conG2/`03onG2/`03o`000?oY
a:oojLB_00gojLB_00Co0000onc6[?o/aZco0000Foooool002gooooo00?o0000ooooooooool08Ooo
ool01Ol0003o05K?o`1Fcol0E/oo000000;o7FKI0_l000000omeU^Go0000oh2?f006oh2?f003o`00
0?n8R/koR8[>00KoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2oiF7`P07oiF7`P03o`00
0?nKR;koVhRn00SoVhRn00?o0000oj2:_?nPR[`02_nPR[`00ol0003oYHjlojF>_002o`0000So[YFm
00?o0000okJK_?nfVk`02onfVk`00ol0003o_Z:lokjR_00;okjR_003o`000?nnX[co000000;oaZZm
00?o0000om:a^OoB/KT03OoB/KT00ol0003of;RiomRh^@05omRh^@03o`000?oP_KCoh;fd00_oh;fd
00?o0000onG2/ooU`[<00_oU`[<00ol0003ojLB_onW4[`0>onW4[`05o`000?o/aZcok<J/onc6[?l0
0000F_ooool002gooooo00?o0000ooooooooool08Oooool00ol0003o05K?o`1Fc`02o`1Fc`07o`00
0?lMI]Wo7FKIoaeVfOl0003oMIKUo`000006oh2?f003o`000?n8R/koR8[>00KoR8[>00?o0000ohn7
a_n?QlH01on?QlH00ol0003oUHO2oiF7`P08oiF7`P03o`000?nKR;koVhRn00SoVhRn00?o0000oj2:
_?nPR[`02OnPR[`00ol0003oYHjlo`00000:ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR
_?nnX[`02_nnX[`01Ol0003o_Z:lo`000?o6Z[go0000013od[6i00?o0000omRh^OoH^;T01OoH^;T0
0ol0003oh;fdon2m]00<on2m]005o`000?oU`[?oiL:conG2/ol000003ooYa:l00ol0003ok<J/onc6
[002onc6[003o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo00Go0000
o`1Fcol0E/oo05K?o`000004oaeVf@;o00001_n0SmP00ol0003oR8[>ohR:cP07ohR:cP03o`000?n?
QlKoShO600KoShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P08oi^8_P03o`000?nP
R[coX8Zl00WoX8Zl0_l0000<ojjE_@03o`000?nfVkco]Y^l00_o]Y^l00?o0000okjR_?nnX[`02_nn
X[`01?l0003o_Z:lokjR_?l0000Bom:a^@03o`000?oH^;Wof;Ri00?of;Ri00?o0000on2m]?oP_K@0
3OoP_K@01?l0003oiL:conG2/ol0000@onW4[`03o`000?o/aZcok<J/00?ok<J/00?o0000oooooooo
ool0Eoooool002cooooo0ol0000Tooooo`05o`000?l0E/oo05K?o`1Fcol000001OlMI]T2o`0000Go
P8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;oUHO200Oo
UHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_007oj2:_0;o000000?oY8noo`000?n^
UKd02on^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nnX[co_Z:l00Wo_Z:l00Co0000okjR_?nn
X[co00004ooB/KT00ol0003of;RiomRh^@02omRh^@03o`000?oP_KCoh;fd00koh;fd00?o0000onG2
/ol000003ooYa:l00ol0003ok<J/onc6[005onc6[003o`000?oooooooooo05Kooooo000]ooooo`03
o`000?oooooooooo02Cooooo00Go0000o`1Fcol0E/oo05K?o`000004oaeVf@04o`000?m5L=So0000
o`0000?oP8oH00?o0000ohR:c_n8R/h01_n8R/h00ol0003oShO6ohn7aP07ohn7aP03o`000?nEQl;o
UHO200SoUHO200?o0000oi^8__nKR;h02?nKR;h00ol0003oX8Zloj2:_003oj2:_0?o00001?nTSkl0
0ol0003o[YFmojjE_@09ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`02OnnX[`0
1Ol0003o_Z:lo`000?o:Zk[o000001;od[6i00Go0000omRh^OoH^;Wof;Rio`00000Bon2m]003o`00
0?oYa:oojLB_00kojLB_00?o0000onc6[?o/aZ`01_o/aZ`00ol0003oooooooooo`1Eooooo`00;Ooo
ool00ol0003oooooooooo`0Uooooo`05o`000?l0E/oo05K?o`1Fcol000001?lMI]T00ol0003oAG3H
odE`f003o`000003oh2?f?l0003oR8[>00OoR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003oUHO2
oiF7`P07oiF7`P03o`000?nKR;koVhRn00SoVhRn00Co0000oj2:_?nPR[coX8Zl0_l00007ojB?_`03
o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_008okjR_0;o
00000_o:ZkX00ol0003od[6iom:a^@0Aom:a^@03o`000?oH^;Wo000001?oh;fd00?o0000onW4[ooY
a:l03_oYa:l00ol0003ok<J/onc6[006onc6[0;o0000E_ooool002gooooo00?o0000ooooooooool0
9_ooool01?l0003o05K?o`1Fcol00004oaeVf@03o`000?m5L=SoAG3H00?oAG3H0_l00008ohR:cP03
o`000?n?QlKoShO600OoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRnoi^8_P08oi^8_P04
o`000?nPR[co0000o`0000WoY8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lokJK_00<okJK
_003o`000?nnX[co_Z:l00So_Z:l00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003od[6iom:a^@0@om:a
^@03o`000?oH^;Wo000001;oh;fd00?o0000onK1/?l000003_oYa:l00ol0003ok<J/onc6[008onc6
[003o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo0_l000000ol0E/oo
0000oaeVf@03oaeVf@03o`000?m5L=SoAG3H00CoAG3H0ol00006ohR:cP03o`000?n?QlKoShO600Ko
ShO600?o0000oiF7`_nEQl802?nEQl800ol0003oVhRnoi^8_P06oi^8_P?o00003?nTSkl00ol0003o
[YFmojjE_@09ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`02?nnX[`00ol0003o
bZ^jolZ[^P02olZ[^P03o`000?oB/KWod[6i017od[6i00?o0000on2m]?oP_K@04OoP_K@01?l0003o
i/6`onK1/?l0000=onW4[`03o`000?o/aZcok<J/00Wok<J/00?o0000ooooooooool0Doooool002co
oooo00?o0000ooooooooool0:Oooool2o`000003o`1Fcol0003o7FKI00?o7FKI00?o0000odE`f?m5
L=P00om5L=P00ol0003oI7SBofAhdP03o`0000?oR8[>00?o0000ohn7a_n?QlH01on?QlH00ol0003o
UHO2oiF7`P07oiF7`P03o`000?nKR;koVhRn00?oVhRn0ol00002oiV9`P03o`000?nTSkooY8no00[o
Y8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lokJK_00<okJK_003o`000?nnX[co_Z:l00Ko
_Z:l0_l00005olZ[^P03o`000?oB/KWod[6i013od[6i00?o0000on2m]?oP_K@04?oP_K@00ol0003o
i/6`onK1/002onK1/003o`000?oYa:oojLB_00WojLB_00?o0000onc6[?o/aZ`02oo/aZ`00ol0003o
ooooooooo`1Booooo`00;?ooool2o`0002_ooooo0ol00004oaeVf@03o`000?m5L=SoAG3H00CoAG3H
00?o0000ofAhd_mTN=800_mTN=84o`0000WoShO600?o0000oiF7`_nEQl801onEQl800ol0003oVhRn
oi^8_P03o`0000KoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`00
0?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`01OnnX[`00ol0003obZ^jo`000005olZ[^P03o`00
0?oB/KWod[6i00ood[6i00?o0000om^h]_l000004OoP_K@00ol0003oi/6`onK1/002onK1/003o`00
0?oYa:oojLB_00WojLB_00?o0000onc6[?o/aZ`02oo/aZ`2o`0005?ooooo000/ooooo`03o`000?oo
oooooooo02_ooooo0ol00004oaeVf@03o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=801OmT
N=87o`0000?oShO600?o0000oiF7`_nEQl800onEQl87o`0000WoVHW200?o0000ojB?_onTSkl02_nT
Skl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00co]Y^l00?o0000okjR_?nnX[`00onn
X[`01?l0003obZ^jolZ[^_l00006olZ[^P03o`000?oB/KWod[6i00kod[6i00?o0000om^h]_l00000
4?oP_K@00ol0003oi/6`onK1/004onK1/003o`000?oYa:oojLB_00SojLB_00?o0000onc6[?o/aZ`0
3?o/aZ`00ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0/ooooo`?o00000olM
I]T00ol0003oAG3HodE`f004odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`00omj
O/`9o`0000GoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?_`0:ojB?_`03o`000?n^
UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lokjR_002okjR_005o`000?o:
Zk[obZ^jolZ[^_l000001_o:ZkX00ol0003od[6iom:a^@0=om:a^@05o`000?oK^;KofkRfom^h]_l0
00003ooP_K@00ol0003oi/6`onK1/005onK1/003o`000?oYa:oojLB_00KojLB_00?o0000onc6[?o/
aZ`03?o/aZ`00ol0003ok/N[o`00001Booooo`00;?ooool00ol0003oooooooooo`0]ooooo`?o0000
0olMI]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00KoI7SB00?o0000ogYnc?mjO/`0
1_mjO/`00ol0003oRhC6oh^4aP08oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl0
2OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00go]Y^l00Go0000okjR_?nnX[co
_Z:lo`000003olZ[^P03o`000?o:Zk[obZ^j00GobZ^j00?o0000om:a^OoB/KT02ooB/KT00ol0003o
fkRfom^h]P03om^h]P03o`000?oP_KCoh;fd00coh;fd00?o0000onK1/?oV`K001_oV`K000ol0003o
jLB_onW4[`05onW4[`03o`000?o/aZcok<J/00cok<J/00Co0000onk7Zoo^aj_o0000DOooool002co
oooo00?o0000ooooooooool0;_ooool2o`0000?o7FKI00?o0000odE`f?m5L=P01?m5L=P00ol0003o
I7SBofAhdP05ofAhdP03o`000?mjO/coNWk<00OoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003o
VHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00[oY8no00?o0000ojjE_On^UKd02_n^UKd00ol0003o
]Y^lokJK_00<okJK_004o`000?nnX[co_Z:lo`0000CobZ^j00?o0000olZ[^_o:ZkX01Oo:ZkX00ol0
003od[6iom:a^@0;om:a^@03o`000?oK^;KofkRf00?ofkRf00?o0000on2m]?oP_K@02ooP_K@00ol0
003oi/6`onK1/007onK1/003o`000?oYa:oojLB_00GojLB_00?o0000onc6[?o/aZ`03?o/aZ`00ol0
003ok/N[onk7Z`02o`00053ooooo000/ooooo`03o`000?oooooooooo02oooooo0_l00003oaeVf@03
o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=801_mTN=800ol0003oNWk<ogYnc006ogYnc003
o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?_`0:ojB?_`03
o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`03?nfVk`00ol0003o_Z:lo`000005olZ[^P03
o`000?o:Zk[obZ^j00KobZ^j00?o0000om:a^OoB/KT02OoB/KT00ol0003ofkRfom^h]P05om^h]P03
o`000?oP_KCoh;fd00[oh;fd00?o0000onK1/?oV`K002?oV`K000ol0003ojLB_onW4[`03onW4[`03
o`000?o/aZcok<J/00cok<J/00?o0000onk7Zoo^aj/00_o^aj/00ol0003oooooooooo`1>ooooo`00
;?ooool2o`00037ooooo0_l00003oaeVf@03o`000?m5L=SoAG3H00?oAG3H00?o0000ofAhd_mTN=80
1OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600SoRhC600?o0000oiV9`_nIRL80
2?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00?o0000okJK_?nfVk`0
3?nfVk`00ol0003obZ^jolZ[^P04olZ[^P03o`000?o:Zk[obZ^j00OobZ^j00?o0000om:a^OoB/KT0
2?oB/KT00ol0003ofkRfom^h]P05om^h]P03o`000?oP_KCoh;fd00Woh;fd00?o0000onK1/?oV`K00
2_oV`K000ol0003ojLB_onW4[`02onW4[`03o`000?o/aZcok<J/00cok<J/00?o0000onk7Zoo^aj/0
0oo^aj/00ol0003oooooooooo`1=ooooo`00:oooool00ol0003oooooooooo`0booooo`;o00000_lM
I]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01omj
O/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl02_nT
Skl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00_o]Y^l0_l00006olZ[^P03o`000?o:
Zk[obZ^j00OobZ^j00?o0000om:a^OoB/KT01ooB/KT00ol0003ofkRfom^h]P07om^h]P03o`000?oP
_KCoh;fd00Soh;fd00?o0000onK1/?oV`K002_oV`K001Ol0003ojLB_onW4[ooYa:oo000000ook<J/
00?o0000onk7Zoo^aj/01?o^aj/00ol0003oooooooooo`1<ooooo`00:oooool00ol0003ooooooooo
o`0cooooo`;o00000_lMI]T00ol0003oAG3HodE`f003odE`f003o`000?mTN=;oI7SB00GoI7SB00?o
0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200WoVHW200?o
0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE_@03o`000?nfVkco]Y^l00[o]Y^l00Co
0000ol6T_?o1Y;co00001Oo:ZkX00ol0003obZ^jolZ[^P08olZ[^P03o`000?oB/KWod[6i00Kod[6i
00?o0000om^h]_oK^;H02?oK^;H00ol0003oh;fdon2m]006on2m]003o`000?oV`K3oi/6`00coi/6`
00Co0000onW4[ooYa:oo00003_o/aZ`00ol0003ok/N[onk7Z`05onk7Z`;o0000COooool0013ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Co
oooo00?o0000ooooooooool0=?ooool2o`000003oaeVfOl0003oAG3H00CoAG3H00?o0000ofAhd_mT
N=801OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600SoRhC600?o0000oiV9`_nI
RL802?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00?o0000okJK_?nf
Vk`02?nfVk`01Ol0003o`JBlol6T_?o1Y;co000000GobZ^j00?o0000olZ[^_o:ZkX02?o:ZkX00ol0
003od[6iom:a^@05om:a^@03o`000?oK^;KofkRf00WofkRf00?o0000on2m]?oP_K@01_oP_K@00ol0
003oi/6`onK1/00=onK1/003o`000?oYa:oo000000kok<J/00?o0000onk7Zoo^aj/01_o^aj/2o`00
04cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0dooooo`05o`000?l07:Ko0000oaeVfOl000001Om5L=P0
0ol0003oI7SBofAhdP05ofAhdP03o`000?mjO/coNWk<00KoNWk<00?o0000oh^4a_n;Q<H01on;Q<H0
0ol0003oVHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00[oY8no00?o0000ojjE_On^UKd02_n^UKd0
0ol0003o]Y^lokJK_007okJK_003o`000?o1Y;co`JBl00?o`JBl00?o0000olZ[^_o:ZkX00_o:ZkX0
0ol0003obZ^jolZ[^P09olZ[^P03o`000?oB/KWod[6i00Cod[6i00?o0000om^h]_oK^;H02_oK^;H0
0ol0003oh;fdon2m]004on2m]003o`000?oV`K3oi/6`00ooi/6`00?o0000onc6[?o/aZ`03?o/aZ`0
0ol0003ok/N[onk7Z`08onk7Z`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0=Oooool01?l0003o01bVo`000?l0
0005odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4
aP07oh^4aP03o`000?nIRL;oVHW200WoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE
_@0:ojjE_@03o`000?nfVkco]Y^l00Ko]Y^l00?o0000ol6T_?o1Y;`01?o1Y;`00ol0003obZ^jolZ[
^P02olZ[^P03o`000?o:Zk[obZ^j00WobZ^j00?o0000om:a^OoB/KT00ooB/KT00ol0003ofkRfom^h
]P0;om^h]P03o`000?oP_KCoh;fd00Coh;fd00?o0000onK1/?oV`K003ooV`K000ol0003ok<J/onc6
[00<onc6[003o`000?o^aj_ok/N[00Wok/N[00?o0000ooooooooool0BOooool0013ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0
=_ooool01?l0003o01bVo`000?l00005odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mj
O/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onT
Skl02OnTSkl00ol0003o[YFmojjE_@0;ojjE_@03o`000?nfVkco]Y^l00Co]Y^l00?o0000ol6T_?o1
Y;`01Oo1Y;`00ol0003obZ^jolZ[^P02olZ[^P03o`000?o:Zk[obZ^j00[obZ^j00Go0000om:a^OoB
/KWod[6io`00000?om^h]P03o`000?oP_KCoh;fd00;oh;fd00?o0000onK1/?oV`K003ooV`K000ol0
003ojlF^o`00000=onc6[003o`000?o^aj_ok/N[00Wok/N[0_l0001:ooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0g
ooooo`04o`000?l07:Ko0000o`0000CoAG3H00?o0000ofAhd_mTN=801OmTN=800ol0003oNWk<ogYn
c006ogYnc003o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nIRL802?nIRL800ol0003oY8noojB?
_`0:ojB?_`03o`000?n^UKgo[YFm00[o[YFm00?o0000okJK_?nfVk`00onfVk`00ol0003o`JBlol6T
_007ol6T_005o`000?o:Zk[obZ^jolZ[^_l000003?o:ZkX01Ol0003od[6iom:a^OoB/KWo000000oo
fkRf00?o0000on2m]?oP_K@00_oP_K@00ol0003oi/6`onK1/00?onK1/004o`000?o[aJkojlF^o`00
00_ok<J/00?o0000onk7Zoo^aj/02oo^aj/2o`0004Wooooo000@ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o0000>Oooool01?l0003o01bVo`0LY_l00005
odE`f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01OmjO/`00ol0003oRhC6oh^4aP07
oh^4aP03o`000?nIRL;oVHW200WoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0;
ojjE_@05o`000?nfVkco]Y^lokJK_?l000002_o1Y;`01Ol0003obZ^jolZ[^_o:Zk[o000000gobZ^j
00?o0000om:a^Ol000004OoK^;H01Ol0003oh;fdon2m]?oP_KCo0000013oi/6`00?o0000on_5[_o[
aJh00_o[aJh00ol0003ok<J/onc6[008onc6[003o`000?o^aj_ok/N[00cok/N[00?o0000oooooooo
ool0Aoooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0>?ooool00ol0003o01bVo`0LYP02o`0000?oAG3H00?o0000ofAhd_mT
N=801OmTN=800ol0003oNWk<ogYnc006ogYnc003o`000?n;Q<KoRhC600OoRhC600?o0000oiV9`_nI
RL802?nIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm00_o[YFm00Co0000okJK_?nf
Vkco00003?o1Y;`01?l0003obZ^jolZ[^_l0000=olZ[^P03o`000?oB/KWo000001;ofkRf00?o0000
on2m]?l000004OoV`K000ol0003ojlF^on_5[P02on_5[P03o`000?o/aZcok<J/00Sok<J/00?o0000
onk7Zoo^aj/02oo^aj/00ol0003oklZ/o`000018ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`0jooooo`05o`000?l07:Ko
0000o`0o`_l000000om5L=P00ol0003oI7SBofAhdP04ofAhdP03o`000?mjO/coNWk<00KoNWk<00?o
0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`000?nTSkooY8no00WoY8no00?o
0000ojjE_On^UKd02_n^UKd00ol0003o]Y^lo`00000=ol6T_004o`000?o:Zk[obZ^jo`0000kobZ^j
00?o0000om^h]_oK^;H04OoK^;H00ol0003oh;fdo`00000AonK1/003o`000?o[aJkojlF^00?ojlF^
00?o0000onc6[?o/aZ`01_o/aZ`00ol0003ok/N[onk7Z`0<onk7Z`04o`000?o_bZco0000o`0004Oo
oooo000Zooooo`03o`000?oooooooooo03[ooooo00Ko0000o`0LY_l07:Ko0000o`0o`_l00002odE`
f003o`000?mTN=;oI7SB00GoI7SB00?o0000ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4
aP03o`000?nIRL;oVHW200SoVHW200?o0000ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@0:ojjE
_@;o00003oo1Y;`00ol0003obZ^jo`00000>olZ[^P03o`000?oK^;KofkRf01;ofkRf00?o0000onK1
/?oV`K003ooV`K000ol0003ojlF^on_5[P05on_5[P03o`000?o/aZcok<J/00Gok<J/00?o0000onk7
Zoo^aj/03?o^aj/01?l0003oklZ/ono:[?l00017ooooo`00:_ooool00ol0003oooooooooo`0koooo
o`05o`000?l07:Ko01bVo`000?l0?l800_l000000om5L=So0000ofAhdP05ofAhdP03o`000?mjO/co
NWk<00KoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P08oiV9`P03o`000?nTSkoo
Y8no00WoY8no00?o0000ojjE_On^UKd02On^UKd00ol0003o]Yfoo`00000?ol6T_003o`000?o:Zk[o
000000gobZ^j00?o0000om>c^Ol000004ooK^;H00ol0003oi/6`onK1/00?onK1/003o`000?o[aJko
jlF^00GojlF^00?o0000onc6[?o/aZ`01?o/aZ`00ol0003ok/N[onk7Z`0<onk7Z`03o`000?o_bZco
klZ/00;oklZ/00?o0000ooooooooool0A?ooool002[ooooo00?o0000ooooooooool0??ooool00ol0
003o01bVo`000003o`0o`P;o00001omTN=800ol0003oNWk<ogYnc005ogYnc003o`000?n;Q<KoRhC6
00OoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`09ojB?_`03o`000?n^UKgo[YFm
00Oo[YFm00Go0000okJM_onfWKoo]Yfoo`00000?ol6T_0;o00003?o:ZkX01?l0003odk>iom>c^Ol0
000Bom^h]P03o`000?oR_[?o000000ooi/6`00?o0000on_5[_o[aJh01oo[aJh00ol0003ok<J/onc6
[003onc6[003o`000?o^aj_ok/N[00cok/N[00?o0000ono:[?o_bZ`00oo_bZ`00ol0003ooooooooo
o`13ooooo`00:Oooool3o`0003kooooo00?o0000o`0LY_l000000ol0?l82o`0000KoI7SB00?o0000
ogYnc?mjO/`01_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000
ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@05ojjE_@;o00001?nfWKl00ol0003o`JBlol6T_00=
ol6T_0;o00002oo:ZkX00ol0003odk>iom>c^@02om>c^@03o`000?oK^;KofkRf00oofkRf00Co0000
on:n/ooR_[?o00003_oV`K000ol0003ojlF^on_5[P08on_5[P03o`000?o/aZcok<J/00;ok<J/00?o
0000onk7Zoo^aj/02oo^aj/00ol0003oklZ/ono:[004ono:[0;o0000A?ooool002[ooooo00?o0000
ooooooooool0?Oooool00ol0003o01bVo`000004o`0o`P03o`000?mTN=;oI7SB00GoI7SB00?o0000
ogYnc?mjO/`01OmjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200SoVHW200?o0000
ojB?_onTSkl02OnTSkl00ol0003o[YFmojjE_@04ojjE_@03o`000?nfWKoo]Yfo00Go]Yfo00?o0000
ol6T_?o1Y;`03?o1Y;`2o`0000_obZ^j00?o0000om>c^OoC/kT00_oC/kT00ol0003ofkRfom^h]P0>
om^h]P05o`000?oR_[?oh[jcon:n/ol000003OoV`K000ol0003ojlF^on_5[P0:on_5[P04o`000?o/
aZcok<J/o`0000kok/N[00?o0000ono:[?o_bZ`01Oo_bZ`00ol0003oooooooooo`12ooooo`00:_oo
ool00ol0003oooooooooo`0nooooo`03o`000?l07:Ko000000Co03o20_l00005ofAhdP03o`000?mj
O/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`000?nT
SkooY8no00WoY8no00Co0000ojjE_On^UKgo[YFm0_l00008okJM_`03o`000?o1Y;co`JBl00go`JBl
00?o0000olZ[^_o:ZkX02?o:ZkX00ol0003odk>iom>c^@04om>c^@03o`000?oK^;KofkRf00gofkRf
00?o0000on:n/ooR_[<00_oR_[<00ol0003oi/6`onK1/00:onK1/003o`000?o[aJkojlF^00[ojlF^
00Co0000onc6[?o/aZco00003_o^aj/00ol0003oklZ/ono:[006ono:[003o`000?oooooooooo047o
oooo000Zooooo`03o`000?oooooooooo03oooooo00?o0000o`0LY_l000000ol0?l801?l0003o;eg?
o`000?l00004ofAhdP03o`000?mjO/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003o
VHW2oiV9`P08oiV9`P03o`000?nTSkooY8no00WoY8no00Co0000ojjE_On^UKgo00002_nfWKl00ol0
003o`JBlol6T_00=ol6T_003o`000?o:Zk[obZ^j00OobZ^j00?o0000om>c^OoC/kT01_oC/kT00ol0
003ofkRfom^h]P0;om^h]P03o`000?oR_[?oh[jc00Coh[jc00?o0000onK1/?oV`K002OoV`K000ol0
003ojlF^on_5[P0;on_5[P03o`000?o/aZco000000gok/N[00?o0000ono:[?o_bZ`02?o_bZ`00ol0
003oooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`10ooooo`03o`000?l07:Ko000000Co
03o200Co0000obmMcol_GLoo00000omTN=800ol0003oNWk<ogYnc005ogYnc003o`000?n;Q<KoRhC6
00OoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`08ojB?_`03o`000?n^UKgo0000
00co]Yfo00?o0000ol6T_?o1Y;`03?o1Y;`2o`0000OobZ^j00?o0000om>c^OoC/kT01ooC/kT00ol0
003ofkRfom^h]P0;om^h]P03o`000?oR_[?oh[jc00Coh[jc00?o0000onK1/?oV`K002?oV`K000ol0
003ojlF^on_5[P0=on_5[P03o`000?o^aj_ok/N[00cok/N[00?o0000ono:[?o_bZ`02?o_bZ`00ol0
003oooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`11ooooo`03o`000?l07:Ko000000?o
03o200Co0000obmMcol_GLoo;eg?0_l000000omTN=;o0000ogYnc007ogYnc003o`000?n;Q<KoRhC6
00KoRhC600?o0000oiV9`_nIRL802OnIRL800ol0003oY8noojB?_`08ojB?_`;o00003OnfWKl00ol0
003o`JBlol6T_00<ol6T_0;o00001oo:ZkX00ol0003odk>iom>c^@08om>c^@03o`000?oK^;KofkRf
00WofkRf00?o0000on:n/ooR_[<01_oR_[<00ol0003oi/6`onK1/007onK1/003o`000?o[aJkojlF^
00gojlF^00?o0000onk7Zoo^aj/02oo^aj/00ol0003oklZ/ono:[00:ono:[003o`000?oooooooooo
03oooooo000Yooooo`03o`000?oooooooooo04;ooooo00?o0000o`0LY_l000000ol0?l800ol0003o
;eg?obmMc`02obmMc`?o00001omjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`000?nIRL;oVHW200So
VHW200?o0000ojB?_onTSkl01_nTSkl2o`000003ojRF`ol0003o]Yfo00go]Yfo00?o0000ol6T_?o1
Y;`02oo1Y;`00ol0003o`JBlo`000005olZ[^P03o`000?oC/kWodk>i00Wodk>i00?o0000om^h]_oK
^;H02OoK^;H00ol0003oh[jcon:n/`07on:n/`03o`000?oV`K3oi/6`00Goi/6`00?o0000on_5[_o[
aJh03Oo[aJh00ol0003ok/V]o`00000<onk7Z`03o`000?o_bZcoklZ/00_oklZ/00?o0000oooooooo
ool0?_ooool002Wooooo0_l00014ooooo`;o00000ol0?l800ol0003o;eg?obmMc`04obmMc`03o`00
0?mjO/coNWk<00GoNWk<00?o0000oh^4a_n;Q<H01on;Q<H00ol0003oVHW2oiV9`P09oiV9`P03o`00
0?nTSkooY8no00?oY8no0_l00004ojRF``03o`000?nfWKoo]Yfo00_o]Yfo00?o0000ol6T_?o1Y;`0
2oo1Y;`00ol0003o`JBlo`000004olZ[^P03o`000?oC/kWodk>i00_odk>i00?o0000om^h]_oK^;H0
1ooK^;H00ol0003oh[jcon:n/`09on:n/`03o`000?oV`K3oi/6`00Coi/6`00?o0000on_5[_o[aJh0
3Oo[aJh01?l0003ok/V]onk9[Ol0000;onk7Z`03o`000?o_bZcoklZ/00_oklZ/0_l0000oooooo`00
:Oooool00ol0003oooooooooo`14ooooo`;o00000ol0?l800ol0003o;eg?obmMc`04obmMc`?o0000
1OmjO/`00ol0003oRhC6oh^4aP06oh^4aP03o`000?nIRL;oVHW200WoVHW200Co0000ojB?_onTSkoo
Y8no0_l00006ojRF``03o`000?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02_o1Y;`00ol0003o
`JBlo`000004olZ[^P03o`000?oC/kWodk>i00_odk>i00?o0000om^h]_oK^;H01_oK^;H00ol0003o
h[jcon:n/`0:on:n/`03o`000?oV`K3oi/6`00?oi/6`00?o0000on_5[_o[aJh03Oo[aJh00ol0003o
k/V]onk9[@02onk9[@03o`000?o^aj_ok/N[00Ook/N[00?o0000ono:[?o_bZ`02oo_bZ`00ol0003o
klf_o`00000oooooo`00:Oooool00ol0003oooooooooo`15ooooo`;o00000ol0?l800ol0003o;eg?
obmMc`03obmMc`03o`000?mMLm3oGG?@00?o00000_mjO/`00ol0003oRhC6oh^4aP07oh^4aP03o`00
0?nIRL;oVHW200SoVHW200Co0000ojB?_ol0003o00002OnXU/<00ol0003o]YfookJM_`0;okJM_`03
o`000?o1Y;co`JBl00[o`JBl00Co0000ol6T_?o1Y;co00000_o:ZkX00ol0003odk>iom>c^@0=om>c
^@03o`000?oK^;KofkRf00GofkRf00?o0000on:n/ooR_[<02ooR_[<00ol0003oi/6`onK1/002onK1
/003o`000?o[aJkojlF^00gojlF^00?o0000onk9[Oo^bJd00oo^bJd00ol0003ok/N[onk7Z`06onk7
Z`03o`000?o_bZcoklZ/00_oklZ/00Co0000ono=[oo_cJoo0000?_ooool002Wooooo00?o0000oooo
ooooool0AOooool2o`0000?o03o200?o0000obmMcol_GLl01?l_GLl00ol0003oGG?@oeecd002oeec
d0?o00002On;Q<H00ol0003oVHW2oiV9`P06oiV9`PCo00002onXU/<00ol0003o]YfookJM_`0<okJM
_`03o`000?o1Y;co`JBl00Wo`JBl00Ko0000ol6T_?o1Y;co0000olZ[^_l0000@om>c^@03o`000?oK
^;KofkRf00CofkRf00?o0000on:n/ooR_[<03OoR_[<01Ol0003oi/6`onK1/?oV`K3o000000kojlF^
00?o0000onk9[Oo^bJd01Oo^bJd00ol0003ok/N[onk7Z`05onk7Z`03o`000?o_bZcoklZ/00[oklZ/
00?o0000ono=[oo_cJl00_o_cJl00ol0003oooooooooo`0kooooo`00:Oooool00ol0003ooooooooo
o`16ooooo`;o00000ol0?l800ol0003o;eg?obmMc`03obmMc`03o`000?mMLm3oGG?@00GoGG?@1_l0
0003oh^4aP04o`000?nIRL;oVHW2oiV9`PGo00000onGSLL00ol0003oZ9K3ojRF``09ojRF``03o`00
0?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02Oo1Y;`01Ol0003o`JBlol6T_?o1Y;co000001;o
dk>i00?o0000om^h]_oK^;H00ooK^;H00ol0003oh[jcon:n/`0=on:n/`04o`000?oV`K3oi/6`o`00
00oojlF^00?o0000onk9[Oo^bJd01Oo^bJd00ol0003ok/N[onk7Z`04onk7Z`03o`000?o_bZcoklZ/
00_oklZ/00?o0000ono=[oo_cJl00_o_cJl2o`0003cooooo000Yooooo`03o`000?oooooooooo04Oo
oooo00Go0000o`0o`_l0?l;o03o2o`000006obmMc`03o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2
cOmoP/d00omoP/d7o`0000WoUhg700?o0000ojRF`onXU/<02OnXU/<00ol0003o]YfookJM_`0;okJM
_`03o`000?o1Y;co`JBl00Wo`JBl00Go0000ol6T_?o1Y;co`JBlo`00000Com>c^@05o`000?oK^;Ko
fkRfom^h]_l000004OoR_[<00ol0003oi/6`o`00000?on_5[P03o`000?o^bJgok/V]00Kok/V]00?o
0000onk7Zoo^aj/00oo^aj/00ol0003oklZ/ono:[00;ono:[003o`000?o_cJooklf_00?oklf_00?o
0000ooooooooool0>_ooool002Sooooo0ol00019ooooo`05o`000?l0?l;o03o2o`0o`_l000001Ol_
GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00KoOh;=00?o0000oiN=aonGSLL02OnG
SLL00ol0003oZ9K3ojRF``09ojRF``03o`000?nfWKoo]Yfo00co]Yfo00?o0000ol6T_?o1Y;`02?o1
Y;`01_l0003o`JBlol6T_?l0003objjmo`0001;odk>i00Go0000om^h]_oK^;KofkRfo`00000Bon:n
/`03o`000?o[aJkojlF^00gojlF^00?o0000onk9[Oo^bJd02?o^bJd01Ol0003ok/N[onk7Zoo^aj_o
000000goklZ/00?o0000ono=[oo_cJl01Oo_cJl00ol0003oooooooooo`0iooooo`00:?ooool00ol0
003oooooooooo`1:ooooo`04o`000?l0?l;o03o2o`0000Go;eg?00?o0000oeecd?mMLm001OmMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<0
0ol0003o]YfookJM_`0;okJM_`03o`000?o1Y;co`JBl00So`JBl00?o0000ol6T_?l000000_o;[[d0
0ol0003odk>iom>c^@0Aom>c^@03o`000?oK^;Ko000001?oh[jc00?o0000on_5[_o[aJh03Oo[aJh0
0ol0003ok/V]onk9[@09onk9[@04o`000?o^aj_ok/N[o`0000goklZ/00?o0000ono=[oo_cJl01_o_
cJl00ol0003oooooooooo`0hooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01oooool00ol0003oooooooooo`1:ooooo`05o`00
0?l0?l;o03o2o`0o`_l000001Ol_GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00Ko
Oh;=00?o0000oiN=aonGSLL02OnGSLL00ol0003oZ9K3ojRF``09ojRF``03o`000?nfWKoo]Yfo00co
]Yfo00?o0000ol6T_?o1Y;`01oo1Y;`2o`0000Cobjjm00?o0000om>c^OoC/kT04?oC/kT00ol0003o
fkRfo`00000Bon:n/`03o`000?oXa;;o000000gojlF^00?o0000onk9[Oo^bJd02oo^bJd00ol0003o
k/N[o`00000<ono:[003o`000?o_cJooklf_00Ooklf_0_l0000iooooo`003?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0
003oooooooooo`1;ooooo`04o`000?l0?l;o03o2o`0000Go;eg?00?o0000oeecd?mMLm001OmMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<0
0ol0003o]YfookJM_`0;okJM_`03o`000?o1Y;co`JBl00Ko`JBl0ol00004ol^^_@03o`000?oC/kWo
dk>i017odk>i00?o0000on:n/ooR_[<04OoR_[<01?l0003oj<BbonS4/_l0000<on_5[P03o`000?o^
bJgok/V]00cok/V]00?o0000ono:[?o_bZ`02oo_bZ`00ol0003oklf_ono=[`08ono=[`03o`000?oo
oooooooo03Oooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool0C?ooool01?l0003o03o2o`0o`_l00005obmMc`03
o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2cOmoP/d01omoP/d00ol0003oUhg7oiN=a`08oiN=a`03
o`000?nXU/?oZ9K300[oZ9K300?o0000okJM_onfWKl03?nfWKl00ol0003o`JBlol6T_002ol6T_0?o
000000?o`JBlo`000?o;[[d01Oo;[[d00ol0003odk>iom>c^@0@om>c^@03o`000?oR_[?oh[jc013o
h[jc00?o0000onS4/_oXa;800_oXa;800ol0003ojlF^on_5[P08on_5[P03o`000?o^bJgok/V]00go
k/V]00?o0000ono:[?o_bZ`02_o_bZ`00ol0003oklf_ono=[`0:ono=[`03o`000?oooooooooo03Ko
oooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Oooooo00?o0000ooooooooool0C?ooool2o`000003o`0o`_l0003o;eg?00Co;eg?00?o0000oeec
d?mMLm001OmMLm000ol0003oOh;=ogn2c@06ogn2c@03o`000?nGSLOoUhg700WoUhg700?o0000ojRF
`onXU/<02OnXU/<00ol0003o]YfookJM_`0<okJM_`03o`000?o1Y;co000000;o00000oo1Y;`00ol0
003objjmo`000005ol^^_@03o`000?oC/kWodk>i00oodk>i00?o0000ombk^?l000004OoR_[<00ol0
003oj<BbonS4/P02onS4/P03o`000?o[aJkojlF^00SojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0
003ol<j^o`00000;ono:[003o`000?o_cJooklf_00_oklf_00?o0000ooooooooool0=Oooool000co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool0
0ol0003oooooooooo`1=ooooo`;o000000?o03o2o`000?l_GLl01?l_GLl00ol0003oGG?@oeecd004
oeecd003o`000?moP/goOh;=00OoOh;=00?o0000oiN=aonGSLL02?nGSLL00ol0003oZ9K3ojRF``0:
ojRF``03o`000?nfWKoo]Yfo00[o]Yfo0ol00005ol6T_005o`000?o;[[gobjjmol^^_Ol000001Oo;
[[d00ol0003odk>iom>c^@0>om>c^@04o`000?oL^kSog;^ho`0000ooh[jc00?o0000onS4/_oXa;80
1?oXa;800ol0003ojlF^on_5[P06on_5[P03o`000?o^bJgok/V]00gok/V]00Co0000oo3>[_o`cZko
00002Oo_bZ`00ol0003oklf_ono=[`0<ono=[`;o0000=_ooool000cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0C_ooool2o`000003
o`0o`_l0003o;eg?00?o;eg?00?o0000oeecd?mMLm001OmMLm000ol0003oOh;=ogn2c@06ogn2c@03
o`000?nGSLOoUhg700WoUhg700?o0000ojRF`onXU/<02OnXU/<00ol0003o]YfookJM_`07okJM_`?o
00000_nfWKl00ol0003o`JBlol6T_002ol6T_003o`000?o;[[gobjjm00?objjm00?o0000ol^^_Oo;
[[d00_o;[[d00ol0003odk>iom>c^@0=om>c^@05o`000?oL^kSog;^hombk^?l000003ooR_[<00ol0
003oj<BbonS4/P05onS4/P03o`000?o[aJkojlF^00GojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0
003ol<j^oo3>[P02oo3>[P03o`000?o_bZcoklZ/00KoklZ/00?o0000ono=[oo_cJl02oo_cJl00ol0
003ok]6eo`00000fooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P02?ooool2o`00057ooooo0ol00005obmMc`03o`000?mMLm3oGG?@00CoGG?@00?o0000ogn2
cOmoP/d01omoP/d00ol0003oUhg7oiN=a`08oiN=a`03o`000?nXU/?oZ9K300[oZ9K300?o0000okJM
_onfWKl00onfWKl3o`0000Go]Yfo00?o0000ol6T_?o1Y;`00_o1Y;`00ol0003objjmol^^_@04ol^^
_@03o`000?o;[[gobjjm00;objjm00?o0000om>c^OoC/kT02ooC/kT00ol0003og;^hombk^003ombk
^003o`000?oR_[?oh[jc00_oh[jc00?o0000onS4/_oXa;801ooXa;800ol0003ojlF^on_5[P03on_5
[P03o`000?o^bJgok/V]00gok/V]00?o0000oo3>[_o`cZh00oo`cZh00ol0003oklZ/ono:[004ono:
[003o`000?o_cJooklf_00coklf_00Co0000onkA]Oo^dKGo0000=Oooool000cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0D?oo
ool01?l0003o00FDo`000?l00004obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOmoP/d0
1_moP/d00ol0003oUhg7oiN=a`08oiN=a`03o`000?nXU/?oZ9K300[oZ9K300?o0000okJM_onfWKl0
0ol00009okJM_`04o`000?o1Y;co`JBlo`0000Sobjjm00Go0000ol^^_Oo;[[gobjjmo`00000=om>c
^@03o`000?oL^kSog;^h00?og;^h00?o0000on:n/ooR_[<02ooR_[<00ol0003oj<BbonS4/P08onS4
/P03o`000?o[aJkojlF^00;ojlF^00?o0000onk9[Oo^bJd03?o^bJd00ol0003ol<j^oo3>[P05oo3>
[P03o`000?o_bZcoklZ/00?oklZ/00?o0000ono=[oo_cJl02oo_cJl00ol0003ok]6eonkA]@02onkA
]@03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooooooo057ooooo00?o0000o`05U?l0
00001?l_GLl00ol0003oGG?@oeecd005oeecd003o`000?moP/goOh;=00OoOh;=00?o0000oiN=aonG
SLL02?nGSLL00ol0003oZ9K3ojRF``09ojRF``?o00003?nfWKl00ol0003o`JBlo`00000:ol^^_@05
o`000?o;[[gobjjmol^^_Ol000002ooC/kT00ol0003og;^hombk^005ombk^003o`000?oR_[?oh[jc
00Woh[jc00?o0000onS4/_oXa;802OoXa;800ol0003ojlF^on_5[P02on_5[P03o`000?o^bJgok/V]
00cok/V]00?o0000oo3>[_o`cZh01_o`cZh00ol0003oklZ/ono:[002ono:[003o`000?o_cJooklf_
00_oklf_00?o0000onkA]Oo^dKD00oo^dKD00ol0003oooooooooo`0aooooo`009oooool00ol0003o
ooooooooo`1Booooo`03o`000?l01ICo000000Co;eg?00?o0000oeecd?mMLm001OmMLm000ol0003o
Oh;=ogn2c@06ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<01_nXU/<3o`000003
ojRF`ol0003o]Yfo00co]Yfo0_l0000<ol^^_@05o`000?o;[[gobjjmol^^_Ol000002_oC/kT00ol0
003og;^hombk^006ombk^003o`000?oR_[?oh[jc00Soh[jc00?o0000onS4/_oXa;802_oXa;801?l0
003ojlF^on_5[_l0000?onk9[@03o`000?o`cZkol<j^00Ool<j^00Co0000ono:[?o_bZco00003Oo_
cJl00ol0003ok]6eonkA]@04onkA]@;o0000<_ooool002Oooooo00?o0000ooooooooool0D_ooool0
1?l0003o00FDo`000?l00003obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOmoP/d01_mo
P/d00ol0003oUhg7oiN=a`09oiN=a`03o`000?nXU/?oZ9K300;oZ9K30ol00004ojRF``03o`000?nf
WKoo]Yfo00[o]Yfo00?o0000okjW`_l000003?o;[[d01Ol0003objjmol^^_Oo;[[go000000Wodk>i
00?o0000ombk^?oL^kP01ooL^kP00ol0003oh[jcon:n/`08on:n/`03o`000?oXa;;oj<Bb00_oj<Bb
00?o0000on_5[_l000003_o^bJd00ol0003ol<j^oo3>[P09oo3>[P03o`000?o_bZco000000goklf_
00?o0000onkA]Oo^dKD01Oo^dKD00ol0003oooooooooo`0`ooooo`009oooool00ol0003ooooooooo
o`1Cooooo`04o`000?l01ICo0000o`0000?o;eg?00?o0000oeecd?mMLm001?mMLm000ol0003oOh;=
ogn2c@07ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`ol000000_l00008ojRF``03o`00
0?nfWKoo]Yfo00So]Yfo00Go0000okjW`_nnYl;o_ZO2o`00000<ol^^_@05o`000?o;[[gobjjmol^^
_Ol000002?oC/kT00ol0003og;^hombk^008ombk^003o`000?oR_[?oh[jc00Koh[jc00?o0000onS4
/_oXa;803OoXa;800ol0003ok/V]onk9[@0=onk9[@03o`000?o`cZkol<j^00[ol<j^00?o0000ono=
[oo_cJl02oo_cJl00ol0003ok]6eonkA]@07onkA]@03o`000?oooooooooo02oooooo000Wooooo`;o
0000EOooool01?l0003o00FDo`000?l00002obmMc`03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2
cOmoP/d01_moP/d00ol0003oUhg7oiN=a`07oiN=a`?o00002onXU/<00ol0003o]YfookJM_`07okJM
_`03o`000?nnYl;o_ZO200;o_ZO200?o0000ol^^_Oo;[[d02oo;[[d01?l0003objjmol^^_Ol00007
om>c^@03o`000?oL^kSog;^h00Wog;^h00?o0000on:n/ooR_[<01_oR_[<00ol0003oj<BbonS4/P0=
onS4/P03o`000?o^bJgok/V]00cok/V]00?o0000oo3>[_o`cZh02oo`cZh00ol0003oklf_ono=[`0;
ono=[`03o`000?o^dKGok]6e00Sok]6e00?o0000ooooooooool0;_ooool002Kooooo0_l0001Goooo
o`;o000000Go03Nmo`000?l_GLoo;eg?o`000006oeecd003o`000?moP/goOh;=00OoOh;=00?o0000
oiN=aonGSLL00onGSLL3o`0000;oUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]YfookJM_`04
okJM_`;o00001_nnYl800ol0003objjmol^^_@0;ol^^_@04o`000?o;[[gobjjmo`0000Kodk>i00?o
0000ombk^?oL^kP02_oL^kP00ol0003oh[jcon:n/`04on:n/`03o`000?oXa;;oj<Bb00goj<Bb00?o
0000ong;/_l000003Oo^bJd00ol0003ol<j^oo3>[P0:oo3>[P03o`000?obe;7o000000_oklf_00?o
0000onkA]Oo^dKD02Oo^dKD2o`0002oooooo000Wooooo`03o`000?oooooooooo05Gooooo00Oo0000
o`05U?l0003o03Nmo`000?l_GLoo000000OoGG?@00?o0000ogn2cOmoP/d01_moP/d00ol0003oUhg7
oiN=a`03o`0000GoUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]YfookJM_`03okJM_`03o`00
0?nnYl;o_ZO200Ko_ZO200?o0000ol^^_Oo;[[d03?o;[[d00ol0003objjmo`000005om>c^@03o`00
0?oL^kSog;^h00cog;^h00?o0000on:n/ooR_[<00ooR_[<00ol0003oj<BbonS4/P0=onS4/P04o`00
0?o]bk;okL^bo`0000_ok/V]00?o0000oo3>[_o`cZh02oo`cZh01?l0003ol]Baoo;D/Ol0000:ono=
[`03o`000?o^dKGok]6e00[ok]6e0_l0000^ooooo`009oooool00ol0003oooooooooo`1Fooooo`;o
00000_l0=kd2o`0000OoGG?@00?o0000ogn2cOmoP/d01_moP/d3o`0000SoUhg700?o0000ojRF`onX
U/<02onXU/<01Ol0003o]YfookJM_onfWKoo000000[o_ZO200?o0000ol^^_Oo;[[d03?o;[[d00ol0
003objjmo`000003om>c^@03o`000?oL^kSog;^h00gog;^h00?o0000on:n/ooR_[<00_oR_[<00ol0
003oj<BbonS4/P0>onS4/P05o`000?o]bk;okL^bong;/_l000002_o^bJd00ol0003ol<j^oo3>[P0:
oo3>[P03o`000?obe;7ol]Ba00;ol]Ba00?o0000ono=[oo_cJl01_o_cJl00ol0003ok]6eonkA]@0<
onkA]@03o`000?oooooooooo02cooooo000Vooooo`03o`000?oooooooooo05Sooooo0_l00002o`0g
_@;o00001omMLm000ol0003oOh;=ogn2c@02ogn2c@?o000000?oOh;=o`000?nGSLL02OnGSLL00ol0
003oZ9K3ojRF``0:ojRF``04o`000?nfWKoo]Yfoo`0000_o_ZO200?o0000ol^^_Oo;[[d03Oo;[[d2
o`0000?odk>i00?o0000ombk^?oL^kP03_oL^kP01Ol0003oh[jcon:n/ooR_[?o000000ooj<Bb00?o
0000ong;/_o]bk800oo]bk800ol0003ok/V]onk9[@06onk9[@03o`000?o`cZkol<j^00_ol<j^00?o
0000oo;D/Oobe;400oobe;400ol0003oklf_ono=[`05ono=[`03o`000?o^dKGok]6e00_ok]6e00?o
0000on_F_ol00000;Oooool002Kooooo00?o0000ooooooooool0F?ooool00ol0003o00FDo`000002
o`0g_@03o`000?mMLm3oGG?@00GoGG?@00?o0000ogn2cOl000000_l00004ogn2c@03o`000?nGSLOo
Uhg700SoUhg700?o0000ojRF`onXU/<02_nXU/<00ol0003o]Yfoo`00000<okjW`P03o`000?o;[[go
bjjm00kobjjm0_l000000ooC/kWo0000ombk^00@ombk^004o`000?oR_[?oh[jco`00013oj<Bb00?o
0000ong;/_o]bk801?o]bk800ol0003ok/V]onk9[@05onk9[@03o`000?o`cZkol<j^00_ol<j^00?o
0000oo;D/Oobe;401?obe;400ol0003oklf_ono=[`03ono=[`03o`000?o^dKGok]6e00_ok]6e00?o
0000on_F_oo[e[l00_l0000/ooooo`009_ooool00ol0003oooooooooo`1Iooooo`;o00000ol0=kd2
o`0000CoGG?@0ol00008ogn2c@03o`000?nGSLOoUhg700SoUhg700?o0000ojRF`onXU/<02OnXU/<2
o`0000ko_ZO200?o0000ol^^_Oo;[[d03Oo;[[d2o`000003om>c^Ol0003og;^h017og;^h00?o0000
on:n/ol000003ooXa;800ol0003okL^bong;/P05ong;/P03o`000?o^bJgok/V]00Cok/V]00?o0000
oo3>[_o`cZh02oo`cZh00ol0003ol]Baoo;D/@06oo;D/@03o`000?o_cJooklf_00;oklf_00?o0000
onkA]Oo^dKD02oo^dKD01Ol0003ojmJoon_F_oo[e[oo000002cooooo000Vooooo`;o0000Foooool2
o`0000;o03Nm00?o0000ocESd_l000000ol00002oeecd003o`000?moP/goOh;=00KoOh;=00?o0000
oiN=aonGSLL02?nGSLL00ol0003oZ9K3ojRF``07ojRF``;o000000?o[Io9o`000?nnYl803OnnYl80
0ol0003objjmol^^_@0>ol^^_@;o00005?oL^kP00ol0003oj<BbonS4/P0>onS4/P03o`000?o]bk;o
kL^b00KokL^b00?o0000onk9[Oo^bJd00oo^bJd00ol0003ol<j^oo3>[P0;oo3>[P03o`000?obe;7o
l]Ba00Ool]Ba00Co0000ono=[oo_cJoo00003Oo^dKD00ol0003ojmJoon_F_`03on_F_`03o`000?oo
oooooooo02Wooooo000Vooooo`03o`000?oooooooooo05[ooooo0_l00003o`0g_@Go00000_mMLm00
0ol0003oOh;=ogn2c@07ogn2c@03o`000?nGSLOoUhg700OoUhg700?o0000ojRF`onXU/<01OnXU/<2
o`0000Co[Io900?o0000okjW`_nnYl803?nnYl800ol0003objjmol^^_@0>ol^^_@03o`000?oL^kSo
g;^h01;og;^h00?o0000onS4/_oXa;803_oXa;800ol0003okL^bong;/P07ong;/P03o`000?o^bJgo
k/V]00;ok/V]00?o0000oo3>[_o`cZh02_o`cZh00ol0003ol]Baoo;D/@09oo;D/@03o`000?o_cJoo
000000gok]6e00?o0000on_F_oo[e[l01?o[e[l00ol0003oooooooooo`0Xooooo`009_ooool00ol0
003oooooooooo`1Kooooo`Go00001?leHm82o`000003oeecd?l0003oOh;=00OoOh;=00?o0000oiN=
aonGSLL02?nGSLL00ol0003oZ9K3ojRF``03ojRF``03o`000?n]WlWo[Io900Co[Io900?o0000okjW
`_nnYl803?nnYl800ol0003objjmol^^_@0=ol^^_@03o`000?oD^;ko000001;og;^h00?o0000on?4
^?l000003_oXa;800ol0003okL^bong;/P09ong;/P04o`000?o^bJgok/V]o`0000gol<j^00?o0000
oo;D/Oobe;402_obe;42o`0000cok]6e00?o0000on_F_oo[e[l01Oo[e[l00ol0003oooooooooo`0X
ooooo`009_ooool00ol0003oooooooooo`1Iooooo`Go00000_l0=kd00ol0003o=F?BocESdP03ocES
dP;o00002OmoP/d00ol0003oUhg7oiN=a`07oiN=a`04o`000?nXU/?oZ9K3ojRF``;o00002?n]WlT0
0ol0003o_ZO2okjW`P0<okjW`P03o`000?o;[[gobjjm00_objjm00Go0000omBh__oD^;koe;Rno`00
000Aombk^004o`000?oSa;SohlBho`0000goj<Bb00?o0000ong;/_o]bk802_o]bk800ol0003ok/V]
o`00000<oo3>[P03o`000?obe;7ol]Ba00_ol]Ba00?o0000oo;K]ol000002_o^dKD00ol0003ojmJo
on_F_`07on_F_`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo05Kooooo0ol0
0004ooooo`05o`000?l0=kgo03Nmo`0g_Ol000001_leHm84o`0000GoOh;=00?o0000oiN=aonGSLL0
1onGSLL01?l0003oZ9K3o`000?l0000:ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;
[[d02_o;[[d00ol0003oe;RnomBh_P02omBh_P;o00003ooL^kP00ol0003ohlBhon?4^002on?4^003
o`000?oXa;;oj<Bb00Woj<Bb00?o0000ong;/_o]bk803?o]bk82o`0000col<j^00?o0000oo;D/Oob
e;402_obe;401Ol0003ol]^goo;K]oobfkOo000000Wok]6e00?o0000on_F_oo[e[l02?o[e[l00ol0
003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`1Cooooo`?o00001oooool2o`0000;o
03Nm00?o0000ocESd_leHm801?leHm801?l0003oKX7Eofj1eOm^PMD6o`0000GoUhg71_l0000=ojfO
b@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d02?o;[[d00ol0003oe;RnomBh_P04omBh
_P;o00003OoL^kP00ol0003ohlBhon?4^004on?4^003o`000?oXa;;oj<Bb00Soj<Bb00?o0000ong;
/_o]bk803?o]bk800ol0003olM>co`00000;oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000oo;K
]oobfkL00_obfkL00ol0003ok]6eonkA]@05onkA]@03o`000?o[e[oojmJo00WojmJo0_l0000Woooo
o`009Oooool00ol0003oooooooooo`1Aooooo`?o00002oooool01Ol0003o03Nmo`0g_Ol0=kgo0000
00Ko=F?B00?o0000ofj1eOm^PMD01Om^PMD6o`0000GoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0
003o_ZO2okjW`P0<okjW`P03o`000?o;[[gobjjm00Sobjjm00?o0000omBh__oD^;h01?oD^;h2o`00
00gog;^h00?o0000on?4^?oSa;P01?oSa;P00ol0003oj<BbonS4/P07onS4/P03o`000?o]bk;okL^b
00cokL^b00Go0000oo7C/ooadk?olM>co`000009oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000
oo;K]oobfkL01?obfkL00ol0003ok]6eonkA]@04onkA]@03o`000?o[e[oojmJo00[ojmJo00?o0000
ooooooooool09Oooool002Gooooo0ol0001>ooooo`?o00003oooool01?l0003o03Nmo`0g_Ol00006
ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm002?nDTm000ol0003o[Io9ojfOb@0;
ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d01_o;[[d00ol0003oe;RnomBh_P06
omBh_P;o00002ooL^kP00ol0003ohlBhon?4^006on?4^003o`000?oXa;;oj<Bb00Koj<Bb00?o0000
ong;/_o]bk803?o]bk800ol0003olM>coo7C/`02oo7C/`03o`000?o`cZkol<j^00Kol<j^00?o0000
oo;D/Oobe;402_obe;400ol0003ol]^goo;K]`05oo;K]`03o`000?o^dKGok]6e00;ok]6e00?o0000
on_F_oo[e[l03?o[e[l00ol0003oooooooooo`0Tooooo`009Oooool00ol0003oooooooooo`1;oooo
o`?o00004_ooool2o`0000;o03Nm00?o0000ocESd_leHm801?leHm800ol0003oKX7Eofj1e@06ofj1
e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2okjW`P0<okjW
`P03o`000?o;[[gobjjm00Gobjjm00?o0000omBh__oD^;h02?oD^;h2o`0000[og;^h00?o0000on?4
^?oSa;P01ooSa;P00ol0003oj<BbonS4/P05onS4/P03o`000?o]bk;okL^b00_okL^b00?o0000oo7C
/ooadk<01?oadk<00ol0003ol<j^oo3>[P04oo3>[P03o`000?obe;7ol]Ba00[ol]Ba00?o0000oo;K
]oobfkL01oobfkL01?l0003ok]6eonkA]Ol0000?on_F_`;o00009Oooool000Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o
0000ooooooooool0B?ooool3o`0001Kooooo00Co0000o`0g_Ol0=kgo00001_leHm800ol0003oKX7E
ofj1e@06ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2
okjW`P0;okjW`P03o`000?o;[[gobjjm00Cobjjm00?o0000omBh__oD^;h02OoD^;h00ol0003og;^h
o`000008ombk^003o`000?oSa;SohlBh00WohlBh00?o0000onS4/_oXa;800ooXa;800ol0003okL^b
ong;/P0<ong;/P03o`000?oadk?olM>c00GolM>c00?o0000oo3>[_o`cZh00oo`cZh00ol0003ol]Ba
oo;D/@0:oo;D/@03o`000?obfkOol]^g00Sol]^g00?o0000onkA]Ol000003_o[e[l01?l0003ohm[=
o`000?l0000Tooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15ooooo`?o00006_ooool01?l0
003o03Nmo`0g_Ol00006ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm001onDTm00
0ol0003o[Io9ojfOb@0;ojfOb@03o`000?nnYl;o_ZO200co_ZO200?o0000ol^^_Oo;[[d00oo;[[d0
0ol0003oe;RnomBh_P0:omBh_P03o`000?oL^kSo000000Oog;^h00?o0000on?4^?oSa;P02OoSa;P0
0ol0003oj<BbonS4/P03onS4/P03o`000?o]bk;okL^b00cokL^b00?o0000oo7C/ooadk<01_oadk<0
1Ol0003ol<j^oo3>[_o`cZko000000col]Ba00?o0000oo;K]oobfkL02_obfkL00ol0003ojmJoon_F
_`0<on_F_`05o`000?oSf/gohm[=on?JcOl000009?ooool000Wooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o
00007Oooool01Ol0003o03Nmo`0g_Ol0=kgo000000Go=F?B00?o0000ofj1eOm^PMD01_m^PMD00ol0
003oU9?@oiBCd008oiBCd003o`000?n]WlWo[Io900_o[Io900?o0000okjW`_nnYl802onnYl800ol0
003objjmol^^_@02ol^^_@03o`000?oD^;koe;Rn00_oe;Rn00Co0000ombk^?oL^kSo00001OoL^kP0
0ol0003ohlBhon?4^00;on?4^005o`000?oXa;;oj<BbonS4/_l000003_o]bk800ol0003olM>coo7C
/`08oo7C/`04o`000?o`cZkol<j^o`0000col]Ba00?o0000oo;K]oobfkL02_obfkL2o`0000cojmJo
00?o0000on?JcOoSf/d00ooSf/d00ol0003oooooooooo`0Qooooo`002Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07ooooo`03o`000?oooooooooo03oo
oooo0ol0000Qooooo`04o`000?l0=kgo03Nmo`0000Ko=F?B00?o0000ofj1eOm^PMD01_m^PMD00ol0
003oU9?@oiBCd007oiBCd003o`000?n]WlWo[Io900_o[Io900?o0000okjW`_nnYl803?nnYl801?l0
003objjmol^^_Ol0000?omBh_P04o`000?oL^kSog;^ho`0000Cog;^h00?o0000on?4^?oSa;P03?oS
a;P01?l0003oj<BbonS4/_l0000>ong;/P03o`000?oadk?olM>c00WolM>c00?o0000oo3>[_l00000
2oobe;400ol0003ol]^goo;K]`0:oo;K]`04o`000?o_i<;oknC2o`0000[ojmJo00?o0000on?JcOoS
f/d01?oSf/d2o`0002;ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0??ooool3o`0002Gooooo00Co0000o`0g
_Ol0=kgo00001OleHm800ol0003oKX7Eofj1e@06ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000
ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P0<okjW`P03o`000?o;[[go0000017oe;Rn00Co0000
ombk^?oL^kSo00000_oL^kP00ol0003ohlBhon?4^00>on?4^003o`000?oXa;;o000000gokL^b00?o
0000oo7C/ooadk<02ooadk<2o`0000_ol]Ba00?o0000oo;K]oobfkL02OobfkL00ol0003oknC2onoT
`P02onoT`P03o`000?o[e[oojmJo00KojmJo00?o0000on?JcOoSf/d01_oSf/d2o`00027ooooo0009
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Oooooo
00?o0000ooooooooool0>Oooool3o`0002Sooooo0_l000000ol0=kgo0000ocESdP05ocESdP03o`00
0?m^PMGoKX7E00KoKX7E00?o0000oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@0;ojfOb@03o`00
0?nnYl;o_ZO200co_ZO200?o0000omBh__oD^;h04?oD^;h01_l0003og;^hombk^?l0003og;^ho`00
01;ohlBh00?o0000ong;/_o]bk803?o]bk800ol0003olM>coo7C/`0;oo7C/`03o`000?ocfkKo0000
00Wol]Ba00?o0000oo;K]oobfkL02_obfkL00ol0003oknC2onoT`P03onoT`P03o`000?o[e[oojmJo
00GojmJo00?o0000on?JcOoSf/d01ooSf/d00ol0003oooooooooo`0Oooooo`002Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo03Oooooo0ol0000/ooooo`;o000000?o03Nmo`000?leHm801?leHm800ol0003oKX7Eofj1e@06
ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P0;
okjW`P;o00004ooD^;h00ol0003og;^hombk^002o`0001;ohlBh0_l0000<ong;/P03o`000?oadk?o
lM>c00_olM>c00Go0000oo?K]_ocfkKolm^fo`000008oo;D/@03o`000?obfkOol]^g00Wol]^g00?o
0000onoT`_o_i<801Oo_i<800ol0003ojmJoon_F_`03on_F_`03o`000?oSf/gohm[=00Sohm[=0_l0
000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000`ooooo`?o00001_leHm800ol0003oKX7E
ofj1e@06ofj1e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2
okjW`P09okjW`P04o`000?o7/lOoak?7o`0001;oe;Rn00?o0000ombk^?oL^kP00_l0000Aon?4^004
o`000?oZc[Woj/jio`0000_okL^b00?o0000oo7C/ooadk<02ooadk<00ol0003olm^foo?K]P02oo?K
]P;o00001Oobe;400ol0003ol]^goo;K]`0:oo;K]`03o`000?o_i<;oknC200KoknC200Go0000on_F
_oo[e[oojmJoo`00000<on?Jc@;o00007oooool002Cooooo00?o0000ooooooooool0<Oooool3o`00
03?ooooo00Co0000o`0<V?l0003o00001_leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3o
U9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2okjW`P08okjW`P05o`000?o7/lOo
ak?7olNcaol000004ooD^;h01Ol0003og;^ho`000?oSa;So0000013ohlBh00Go0000on[>^OoZc[Wo
j/jio`000009ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K]_ocfkH01OocfkH00ol0003o
l]Baoo;D/@02oo;D/@03o`000?obfkOol]^g00Wol]^g00?o0000onoT`_o_i<802?o_i<800ol0003o
jmJoo`00000>on?Jc@;o00007_ooool002Cooooo00?o0000ooooooooool0;oooool2o`0003Oooooo
00Co0000o`0<V?l0003o00001OleHm800ol0003oKX7Eofj1e@06ofj1e@03o`000?nDTm3oU9?@00Oo
U9?@00?o0000ojfObOn]WlT02on]WlT00ol0003o_ZO2okjW`P06okjW`P03o`000?o7/lOoak?700?o
ak?700?o0000omBh__oD^;h04OoD^;h01Ol0003ohlBhon?4^?oSa;So000000kohlBh00?o0000on[>
^OoZc[T00ooZc[T00ol0003okL^bong;/P06ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K
]_ocfkH01_ocfkH01?l0003ol]Baoo;D/Ol0000;oo;K]`03o`000?o_i<;oknC200[oknC20_l0000>
on?Jc@;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`0003[ooooo00?o0000o`0<
V?l000001_leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfO
bOn]WlT02_n]WlT00ol0003o_ZO2okjW`P05okjW`P03o`000?o7/lOoak?700Goak?700?o0000omBh
__oD^;h04?oD^;h00ol0003ohlBhon?4^002on?4^003o`000?oSa;SohlBh00[ohlBh00?o0000on[>
^OoZc[T01OoZc[T00ol0003okL^bong;/P04ong;/P03o`000?oadk?olM>c00_olM>c00?o0000oo?K
]_ocfkH02?ocfkH00ol0003ol]Bao`00000;oo;K]`03o`000?o_i<;oknC200[oknC200?o0000onO^
d_l000003?oSf/d01?l0003od=gRo`000?l0000Mooooo`009?ooool00ol0003oooooooooo`0Yoooo
o`?o0000?_ooool01?l0003o00bHo`000?l00004ocESdP03o`000?m^PMGoKX7E00KoKX7E00?o0000
oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@0;ojfOb@03o`000?nnYl;o_ZO200?o_ZO200?o0000
olNcaoo7/lL01_o7/lL00ol0003oe;RnomBh_P0?omBh_P03o`000?oLa<7o000000CohlBh00?o0000
on?4^?oSa;P02OoSa;P00ol0003oj/jion[>^@06on[>^@03o`000?o]bk;okL^b00?okL^b00?o0000
oo7C/ooadk<02ooadk<00ol0003olm^foo?K]P09oo?K]P;o00002_obfkL00ol0003oknC2onoT`P0:
onoT`P05o`000?oWk];oinkBonO^d_l000002_oSf/d01?l0003od=gRom3Mh_o@gN82o`0001cooooo
000Tooooo`03o`000?oooooooooo02Kooooo0ol00011ooooo`05o`000?l039So0000o`1<bol00000
1?leHm800ol0003oKX7Eofj1e@05ofj1e@03o`000?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT0
2_n]WlT00ol0003o_ZO2okjW`P02okjW`P03o`000?o7/lOoak?700Soak?700?o0000omBh__oD^;h0
3OoD^;h01Ol0003og<C1omc4`OoLa<7o000000CohlBh00?o0000on?4^?oSa;P01ooSa;P00ol0003o
j/jion[>^@08on[>^@03o`000?o]bk;okL^b00;okL^b00?o0000oo7C/ooadk<02_oadk<00ol0003o
lm^foo?K]P0:oo?K]P04o`000?odi[_o0000o`0000Sol]^g00?o0000onoT`_o_i<802Oo_i<800ol0
003oinkBonO^dP03onO^dP03o`000?oSf/gohm[=00Gohm[=0_l00005om3MhP;o00006oooool002?o
oooo0_l0000Uooooo`?o0000AOooool01?l0003o00bHo`000?l0C</2o`0000;o=F?B00?o0000ofj1
eOm^PMD01_m^PMD00ol0003oU9?@oiBCd007oiBCd003o`000?n]WlWo[Io900_o[Io900Co0000okjW
`_nnYl;o00002oo7/lL00ol0003oe;RnomBh_P0<omBh_P03o`000?oLa<7og<C100?og<C100Go0000
on?4^?oSa;SohlBho`000009on?4^003o`000?oZc[Woj/ji00Woj/ji00Co0000ong;/_o]bk;o0000
3Ooadk<00ol0003olm^foo?K]P09oo?K]P03o`000?odi[_om>Jk00;om>Jk0_l00005oo;K]`03o`00
0?o_i<;oknC200WoknC200?o0000onO^d_oWk]801OoWk]800ol0003ohm[=on?Jc@03on?Jc@03o`00
0?o@gN;od=gR00Kod=gR00?o0000ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?oo
ool3o`0004Wooooo00?o0000o`0<V?l000000_l0C</01?l0003o=F?BocESd_l00007ofj1e@03o`00
0?nDTm3oU9?@00SoU9?@00?o0000ojfObOn]WlT02_n]WlT00ol0003o_ZO2o`00000=olNca`03o`00
0?oD^;koe;Rn00_oe;Rn00?o0000omc4`OoLa<401?oLa<401Ol0003ohlBhon?4^?oSa;So000000Oo
hlBh00?o0000on[>^OoZc[T02ooZc[T00ol0003okL^bo`00000<oo7C/`03o`000?ocfkKolm^f00[o
lm^f00?o0000ooCV^oodi[/01?odi[/01Ol0003ol]^goo;K]oobfkOo000000_oknC200?o0000onO^
d_oWk]801ooWk]801Ol0003ohm[=on?JcOoSf/go000000[od=gR00?o0000ooooooooool06?ooool0
02?ooooo00?o0000ooooooooool07_ooool3o`0004cooooo00?o0000o`0<V?l000000ol0C</00ol0
003o=F?Bo`000008ofj1e@03o`000?nDTm3oU9?@00OoU9?@00?o0000ojfObOn]WlT02_n]WlT2o`00
00ooak?700?o0000omBh__oD^;h02OoD^;h00ol0003og<C1omc4`@05omc4`@03o`000?oSa;SohlBh
00;ohlBh00?o0000on?4^?oSa;P01?oSa;P00ol0003oj/jion[>^@0<on[>^@;o00002ooadk<00ol0
003olm^foo?K]P0:oo?K]P03o`000?odi[_om>Jk00Kom>Jk0_l000000oobfkOo0000onoT`P09onoT
`P03o`000?oWk];oinkB00WoinkB00?o0000on?JcOl000003?o@gN800ol0003oooooooooo`0Goooo
o`008oooool00ol0003oooooooooo`0Kooooo`?o0000D?ooool00ol0003o00bHo`000003o`1<b`?o
00001om^PMD00ol0003oU9?@oiBCd008oiBCd003o`000?n]WlWo[Io900Oo[Io90_l000000onc[=7o
0000olNca`0>olNca`03o`000?oD^;koe;Rn00Soe;Rn00?o0000omc4`OoLa<401ooLa<400ol0003o
hlBhon?4^002on?4^003o`000?oSa;SohlBh00;ohlBh00?o0000on[>^OoZc[T03OoZc[T00ol0003o
kmVko`00000:oo7C/`03o`000?ocfkKolm^f00Wolm^f00?o0000ooCV^oodi[/02Oodi[/2o`0000[o
knC200?o0000onO^d_oWk]802OoWk]83o`0000cod=gR0_l0000Hooooo`008oooool00ol0003ooooo
ooooo`0Hooooo`?o0000E?ooool00ol0003o00bHo`000004o`1<b`03o`000?m^PMGoKX7E00KoKX7E
00?o0000oiBCd?nDTm001onDTm000ol0003o[Io9ojfOb@04ojfOb@?o00001?nc[=400ol0003oak?7
olNca`0=olNca`03o`000?oD^;koe;Rn00Koe;Rn00?o0000omc4`OoLa<402OoLa<400ol0003ohlBh
on?4^002on?4^005o`000?oSa;SohlBhon?4^?l000003_oZc[T01Ol0003okmVkonoI^oo_fK_o0000
00SolM>c00?o0000oo?K]_ocfkH02_ocfkH00ol0003om>JkooCV^`09ooCV^`04o`000?o_l/Co0000
o`0000OoknC200?o0000onO^d_oWk]802OoWk]801Ol0003oc_KYolkfjOo>m^Wo000000cod=gR00?o
0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool05Oooool3o`0005Oooooo00?o0000
o`0<V?l000001Ol0C</3o`0000GoKX7E00?o0000oiBCd?nDTm002?nDTm001?l0003o[Io9ojfObOn]
WlT2o`0000Oo/jcA00?o0000olNcaoo7/lL03Oo7/lL00ol0003oe;RnomBh_P06omBh_P03o`000?oL
a<7og<C100[og<C100?o0000on?4^?oSa;P00_oSa;P00ol0003ohlBho`00000?on[>^@03o`000?o_
fK_okmVk00;okmVk00?o0000oo7C/ooadk<01Ooadk<00ol0003olm^foo?K]P09oo?K]P03o`000?od
i[_om>Jk00Wom>Jk00?o0000onoba?o_l/@00_o_l/@2o`0000CoknC200?o0000onO^d_oWk]802OoW
k]800ol0003oc_KYolkfj@03olkfj@03o`000?o@gN;od=gR00[od=gR00?o0000ooooooooool05Ooo
ool002?ooooo00?o0000ooooooooool04_ooool3o`0005_ooooo00?o0000o`0<V?l000001?l0C</0
0ol0003oEh3OoeN0g`03o`0000?oKX7E00?o0000oiBCd?nDTm001onDTm001?l0003o[Io9o`000?l0
000:ok>/d@03o`000?o7/lOoak?700goak?700?o0000omBh__oD^;h01?oD^;h00ol0003og<C1omc4
`@0;omc4`@03o`000?oSa;SohlBh00?ohlBh00?o0000on[>^OoZc[T03OoZc[T00ol0003okmVkonoI
^`04onoI^`03o`000?oadk?olM>c00?olM>c00?o0000oo?K]_ocfkH02_ocfkH00ol0003om>JkooCV
^`08ooCV^`03o`000?o_l/Coko;400Goko;40_l000000oo_i<;o0000onO^dP09onO^dP;o00001oo>
m^T2o`0000_od=gR00?o0000ooooooooool05?ooool002;ooooo0ol0000@ooooo`?o0000Goooool0
0ol0003o00bHo`000004o`1<b`03o`000?mGP=ooEh3O00;oEh3O1?l00005oiBCd0Ko00003Onc[=40
0ol0003oak?7olNca`0<olNca`03o`000?oD^;koe;Rn00?oe;Rn00?o0000omc4`OoLa<403OoLa<40
0ol0003ohlBhon?4^002on?4^0;o00003OoZc[T00ol0003okmVkonoI^`06onoI^`03o`000?oadk?o
lM>c00;olM>c00?o0000oo?K]_ocfkH02OocfkH00ol0003om>JkooCV^`09ooCV^`03o`000?o_l/Co
ko;400Ooko;40_l00009onO^dP03o`000?o>m^Woc_KY00Woc_KY00?o0000om3Mh_o@gN801oo@gN83
o`0001Gooooo000Sooooo`03o`000?oooooooooo00cooooo0ol0001Sooooo`;o00001?l0C</00ol0
003oEh3OoeN0g`05oeN0g`Ko00001OnAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?7
00goak?700?o0000omBh__oD^;h00_oD^;h00ol0003og<C1omc4`@0>omc4`@06o`000?oSa;SohlBh
o`000?oZc[Wo00003OoZc[T00ol0003okmVkonoI^`07onoI^`04o`000?oadk?olM>co`0000colm^f
00?o0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba008onoba003o`000?oNoM3o000000;o0000
1OoWk]800ol0003oc_KYolkfj@0;olkfj@04o`000?o@gN;od=gRom3MhPGo00000_ooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09ooooo`?o0000Ioooool2o`0000Co04c;
00?o0000oeN0gomGP=l01OmGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00_o/jcA
00?o0000olNcaoo7/lL03Oo7/lL01?l0003oe;RnomBh__l0000Bomc4`@03o`000?oSa;So000000;o
j/ji00?o0000on[>^OoZc[T02OoZc[T00ol0003okmVkonoI^`09onoI^`03o`000?oadk?o000000_o
lm^f00?o0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba008onoba003o`000?oNoM3og_g@00?o
g_g@0ol000000ooWk];o0000olkfj@0=olkfj@Ko00001Oooool00ol0003oooooooooo`0Cooooo`00
8oooool00ol0003oooooooooo`06ooooo`?o0000Joooool2o`0000Co04c;00?o0000oeN0gomGP=l0
1OmGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00[o/jcA00?o0000olNcaoo7/lL0
3Oo7/lL00ol0003oe;Rno`00000Domc4`@03o`000?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T0
2?oZc[T00ol0003okmVkonoI^`0:onoI^`;o00002oocfkH00ol0003om>JkooCV^`08ooCV^`03o`00
0?o_l/Coko;400Ooko;400?o0000omkmd?oNoM001_oNoM04o`0000[oc_KY1_l00008ooooo`03o`00
0?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol0001^ooooo`;o00001?l0
C</00ol0003oEh3OoeN0g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402onc
[=400ol0003oak?7olNca`0=olNca`03o`000?oLa<7og<C101?og<C10_l00004on[>^@03o`000?oZ
c[Woj/ji00Koj/ji00?o0000onoI^oo_fK/02oo_fK/00ol0003ol^Fmo`000002o`0000Oolm^f00?o
0000ooCV^oodi[/02?odi[/00ol0003oko;4onoba007onoba003o`000?oNoM3og_g@00Kog_g@00?o
0000ojojf?n_n]P00_n_n]P4o`0000?oc_KY1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000R
ooooo`04o`000?ooooooooooooooo`?o0000L_ooool2o`0000Co04c;00?o0000oeN0gomGP=l01OmG
P=l00ol0003oTIgLoi6Mg008oi6Mg003o`000?nc[=7o/jcA00_o/jcA00?o0000olNcaoo7/lL02oo7
/lL2o`0001Cog<C100Co0000onCAa?oTdLCo00001?oZc[T00ol0003oj/jion[>^@05on[>^@03o`00
0?o_fK_okmVk00[okmVk00?o0000oo;U_OobiKd00oobiKd2o`0000Colm^f00?o0000ooCV^oodi[/0
2Oodi[/00ol0003oko;4onoba006onoba003o`000?oNoM3og_g@00Gog_g@0_l00009ojojf0Go0000
3oooool00ol0003oooooooooo`0Cooooo`008_ooool4o`0007Kooooo0_l00003o`1<b`03o`000?mG
P=ooEh3O00GoEh3O00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7
/lOoak?700[oak?700Co0000om32cOo@`/go00004_oLa<400ol0003oi=74onCAa002onCAa003o`00
0?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T00ooZc[T00ol0003okmVkonoI^`0;onoI^`03o`00
0?obiKgol^Fm00Gol^Fm0ol000000oocfkKo0000ooCV^`09ooCV^`03o`000?o_l/Coko;400Koko;4
00?o0000omkmd?oNoM001OoNoM000ol0003o[o[Hojojf006ojojf0Go00004_ooool00ol0003ooooo
ooooo`0Cooooo`008_ooool3o`0007Sooooo00?o0000o`1<bol0C</00_l0C</00ol0003oEh3OoeN0
g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402onc[=400ol0003oak?7olNc
a`08olNca`03o`000?o@`/god<;=00;od<;=00?o0000omc4`OoLa<403_oLa<400ol0003oi=74onCA
a004onCAa003o`000?oZc[Woj/ji00;oj/ji00?o0000on[>^OoZc[T00_oZc[T00ol0003okmVkonoI
^`0:onoI^`03o`000?obiKgol^Fm00Wol^Fm0ol00008ooCV^`03o`000?o_l/Coko;400Koko;400?o
0000omkmd?oNoM001?oNoM02o`0000Ko[o[H1?l0000Gooooo`03o`000?oooooooooo01;ooooo000T
ooooo`03o`000?oooooooooo07Oooooo00?o0000o`1<bol0C</00_l0C</00ol0003oEh3OoeN0g`05
oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402_nc[=400ol0003oak?7olNca`07
olNca`03o`000?o@`/god<;=00Cod<;=00?o0000omc4`OoLa<403OoLa<400ol0003oi=74onCAa005
onCAa005o`000?oZc[Woj/jion[>^Ol000000ooZc[T00ol0003okmVkonoI^`0:onoI^`03o`000?ob
iKgol^Fm00[ol^Fm00?o0000oo3b`Oo`l/400ol00005ooCV^`03o`000?o_l/Coko;400Goko;400?o
0000omkmd?oNoM001?oNoM000ol0003o[o[Hojojf007o`0001[ooooo00?o0000ooooooooool04_oo
ool001Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooo
oooo07Oooooo0_l00002o`1<b`03o`000?mGP=ooEh3O00GoEh3O00?o0000oi6Mg?nAWM`02?nAWM`0
0ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?700Goak?700?o0000om32cOo@`/d01_o@`/d0
0ol0003og<C1omc4`@0;omc4`@03o`000?oTdLCoi=7400Ooi=7400Oo0000on[>^OoZc[Woj/jio`00
0?oZc[Wo000000gokmVk00?o0000oo;U_OobiKd02OobiKd00ol0003ol?;1oo3b`@04oo3b`@?o0000
00?om>Jko`000?o_l/@01_o_l/@00ol0003og_g@omkmd00<o`0001gooooo00?o0000ooooooooool0
4_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo07Kooooo
00?o0000o`0^/_l000000_l0C</00ol0003oEh3OoeN0g`05oeN0g`03o`000?nAWMcoTIgL00SoTIgL
00?o0000ok>/dOnc[=402_nc[=400ol0003oak?7olNca`04olNca`03o`000?o@`/god<;=00Ood<;=
00?o0000omc4`OoLa<402_oLa<400ol0003oi=74onCAa009onCAa004o`000?oZc[Woj/jion[>^@;o
00003?o_fK/00ol0003ol^Fmoo;U_@09oo;U_@03o`000?o`l/7ol?;100Sol?;13?l00002ok_j_@03
o`000?m[e:?o000000?o00008Oooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413ooooo
ooooool0003o410@00cooooo00?o0000ooooooooool0M_ooool01Ol0003o02jbo`000?l0C<_o0000
00OoEh3O00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAok>/d@0;ok>/d@03o`000?o7/lOoak?7
00;oak?700?o0000om32cOo@`/d02Oo@`/d00ol0003og<C1omc4`@08omc4`@03o`000?oTdLCoi=74
00_oi=7400?o0000on[>^OoZc[T00_l0000<onoI^`03o`000?obiKgol^Fm00Wol^Fm00?o0000oo3b
`Oo`l/402?o`l/400ol0003ohog3on?m``04on?m``03o`000?nkn[go^oZm00;o^oZm1Ol0000Toooo
o`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo00;o00003Oooool00ol0003o
ooooooooo`1fooooo`05o`000?l0;[;o0000o`1<bol000001omGP=l00ol0003oTIgLoi6Mg008oi6M
g003o`000?nc[=7o/jcA00_o/jcA00Co0000olNcaoo7/lOo00003Oo@`/d00ol0003og<C1omc4`@07
omc4`@03o`000?oTdLCoi=7400coi=7400Go0000on[>^Ol0003okmVko`00000:onoI^`03o`000?ob
iKgol^Fm00Wol^Fm00?o0000oo3b`Oo`l/402?o`l/400ol0003ohog3on?m``04on?m``03o`000?nk
n[go^oZm00;o^oZm0ol0000Wooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooo
oooo00;o00003_ooool00ol0003oooooooooo`1fooooo`04o`000?l0;[;o0000o`0000OoEh3O00?o
0000oi6Mg?nAWM`02OnAWM`00ol0003o/jcAok>/d@0:ok>/d@03o`000?o7/lOo000000ood<;=00?o
0000omc4`OoLa<401OoLa<400ol0003oi=74onCAa00>onCAa0;o00000_o_fK/00ol0003okmVkonoI
^`07onoI^`03o`000?obiKgol^Fm00Sol^Fm00?o0000oo3b`Oo`l/402?o`l/400ol0003ohog3on?m
``04on?m``04o`000?nkn[go^oZmok_j_@;o0000:_ooool00ol0003oooooooooo`0Booooo`005_oo
ool01Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0M_ooool01?l0003o02jb
o`000?l00007oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc[=402_nc[=42o`00013o
d<;=00?o0000omc4`OoLa<401?oLa<400ol0003oi=74onCAa00?onCAa006o`000?o[hLOo0000o`00
0?o_fK_o00001oo_fK/00ol0003ol^Fmoo;U_@09oo;U_@03o`000?o`l/7ol?;100Ool?;100?o0000
on?m`ooSoL<01?oSoL<01?l0003o^oZmok_j_Onkn[d2o`0002_ooooo00?o0000ooooooooool04_oo
ool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o0000Moooool01?l0003o02jbo`00
0?l00006oeN0g`03o`000?nAWMcoTIgL00WoTIgL00?o0000ok>/dOnc[=401onc[=42o`000003okVm
g?l0003od<;=013od<;=00?o0000omc4`OoLa<400ooLa<400ol0003oi=74onCAa00>onCAa003o`00
0?o[hLOojn7700;ojn7700?o0000onoI^ol000001_o_fK/00ol0003ol^Fmoo;U_@08oo;U_@03o`00
0?o`l/7ol?;100Ool?;100?o0000on?m`ooSoL<01?oSoL<00ol0003o^oZmok_j_@02o`0002gooooo
00?o0000ooooooooool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03o`00
0?oooooooooo07Gooooo00?o0000o`0^/_l000001omGP=l00ol0003oTIgLoi6Mg008oi6Mg003o`00
0?nc[=7o/jcA00Ko/jcA00?o0000okVmg?ni_M`00_ni_M`00ol0003od<;=om32c@0?om32c@05o`00
0?oLa<7og<C1omc4`Ol000004?oTdL@00ol0003ojn77on_Qa`04on_Qa`;o00001Oo_fK/00ol0003o
l^Fmoo;U_@08oo;U_@03o`000?o`l/7ol?;100Ool?;100?o0000on?m`ooSoL<01?oSoL<01?l0003o
^oZmo`000?l0000_ooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000007Ko
oooo00?o0000o`0^/_l0;[800_l00006oeN0g`03o`000?nAWMcoTIgL00SoTIgL00?o0000ok>/dOnc
[=400onc[=42o`0000Ko^KgL00?o0000om32cOo@`/d03oo@`/d00ol0003og<C1o`00000@onCAa003
o`000?o[hLOojn7700Oojn770_l00002onoI^`03o`000?obiKgol^Fm00Wol^Fm00?o0000oo3b`Oo`
l/401oo`l/400ol0003ohog3on?m``03on?m``?o0000<Oooool00ol0003oooooooooo`0Booooo`00
;oooool00ol0003oooooooooo`1dooooo`04o`000?l0;[;o0000oc9miP?o00000omGP=l00ol0003o
TIgLoi6Mg009oi6Mg003o`000?nc[=7o/jcA00;o00002Oni_M`00ol0003od<;=om32c@0?om32c@;o
00004?oTdL@00ol0003ojn77on_Qa`08on_Qa`;o000000?okmVko`000?obiKd02OobiKd00ol0003o
l?;1oo3b`@07oo3b`@03o`000?oSoL?ohog300?ohog30_l0000dooooo`03o`000?oooooooooo017o
oooo000`ooooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000000olbONH2o`0000;oEh3O
00?o0000oi6Mg?nAWM`02?nAWM`00ol0003o/jcAo`00000<okVmg003o`000?o@`/god<;=00god<;=
00Co0000omWDe?oIe=Co00003_oTdL@00ol0003ojn77on_Qa`0:on_Qa`Co00002?obiKd00ol0003o
l?;1oo3b`@07oo3b`@03o`000?oSoL?ohog300;ohog30ol0000eooooo`03o`000?oooooooooo017o
oooo000aooooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000001?lbONH3o`0000KoTIgL
1_l0000=okVmg003o`000?o@`/god<;=00cod<;=00?o0000omWDe?oIe=@00_oIe=@00ol0003oi=74
onCAa00:onCAa003o`000?o[hLOojn7700cojn7700?o0000oncab_o/lLX00ol00005oo;U_@03o`00
0?o`l/7ol?;100Kol?;100?o0000on?m`ooSoL<01?l0000gooooo`03o`000?oooooooooo017ooooo
000booooo`03o`000?oooooooooo07Cooooo00?o0000o`0^/_l000001_lbONH6o`0000GoRjc/00?o
0000okVmg?ni_M`03?ni_M`00ol0003od<;=om32c@0:om32c@03o`000?oIe=CofMCD00CofMCD00?o
0000onCAa?oTdL@02OoTdL@00ol0003ojn77on_Qa`0;on_Qa`03o`000?o/lL[o000000Cok?7:0ol0
00000oobiKgo0000oo3b`@07oo3b`@Co000000?o_OVho`000?ooool0>?ooool00ol0003ooooooooo
o`0Aooooo`00<oooool00ol0003oooooooooo`1dooooo`?o00001OlbONH00ol0003oRjc/oh^/k009
oh^/k003o`000?ni_Mco^KgL00co^KgL00?o0000om32cOo@`/d02?o@`/d00ol0003ofMCDomWDe006
omWDe0;o00002?oTdL@00ol0003ojn77on_Qa`0;on_Qa`05o`000?o/lL[ok?7:oncab_l000001_o/
lLX;o`0000?o_OVh00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`00=?ooool2
o`0007Kooooo0_l00005oc9miP03o`000?n;[>coRjc/00WoRjc/00?o0000okVmg?ni_M`03?ni_M`0
0ol0003od<;=om32c@06om32c@03o`000?oIe=CofMCD00WofMCD00?o0000onCAa?oTdL@01?oTdL@0
0ol0003ojn77on_Qa`0;on_Qa`03o`000?o/lL[ok?7:00?ok?7:00?o0000oncab_o/lLX00oo/lLX0
0ol0003oh_g8on;mb005on;mb004o`000?nmnKSo_OVhokgi^0;o0000>oooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooooooo`1dooooo`;o00001OlbONH00ol0003oRjc/oh^/k009
oh^/k003o`000?ni_Mco^KgL00_o^KgL00?o0000om32cOo@`/d01Oo@`/d00ol0003ofMCDomWDe00;
omWDe003o`000?oTdLCoi=7400;oi=7400?o0000on_Qaoo[hLL03?o[hLL00ol0003ok?7:oncabP03
oncabP03o`000?o/lL[ok?7:00;ok?7:00?o0000on;mb?oRoLP01OoRoLP01Ol0003o_OVhokgi^?nm
nKSo000003gooooo00?o0000ooooooooool04Oooool003Oooooo0_l0001eooooo`03o`000?lbONKo
<WgV00Co<WgV00?o0000oh^/k?n;[>`02On;[>`00ol0003o^KgLokVmg00;okVmg003o`000?o@`/go
d<;=00?od<;=00?o0000omWDe?oIe=@03OoIe=@01Ol0003oi=74onCAa?oTdLCo000000gojn7700?o
0000oncab_o/lLX01Oo/lLX01?l0003ok?7:oncab_l00007on;mb005o`000?nmnKSo_OVhokgi^?l0
0000?_ooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooo`00001fooooo`03o`00
0?lbONKo<WgV00Co<WgV00?o0000oh^/k?n;[>`02?n;[>`00ol0003o^KgLokVmg00<okVmg005o`00
0?o@`/god<;=om32cOl000004OoIe=@00ol0003oi=74o`00000=on_Qa`03o`000?o/lL[ok?7:00Oo
k?7:0_l00007on;mb005o`000?nmnKSo_OVhokgi^?l00000?oooool00ol0003oooooooooo`0Aoooo
o`00>Oooool00ol0003oooooooooo`1dooooo`03o`000?lbONKo<WgV00Co<WgV00?o0000oh^/k?n;
[>`02?n;[>`00ol0003o^KgLokVmg00<okVmg003o`000?o@`/go000001?ofMCD0_l0000<on_Qa`03
o`000?o/lL[ok?7:00Sok?7:0_l00006on;mb003o`000?nmnKSo_OVh00;o0000@?ooool00ol0003o
ooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`1dooooo`03o`000?lbONKo<WgV00Co<WgV
00?o0000oh^/k?n;[>`02?n;[>`00ol0003o^KgLokVmg00;okVmg0?o00004ooIe=@01?l0003og^WK
o`000?l00009on_Qa`03o`000?o/lL[ok?7:00Sok?7:00Co0000on;mb?oRoLSo00001?oRoLP01?l0
003o_OVho`000?l00012ooooo`03o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo
07Cooooo00?o0000oc9mi_lbONH00olbONH00ol0003oRjc/oh^/k009oh^/k003o`000?ni_Mco^KgL
00So^KgL0_l00003okkDjP03o`000?oIe=CofMCD00oofMCD00?o0000omkYfooNjM/00_oNjM/2o`00
00Oojn7700?o0000oncab_o/lLX02?o/lLX01Ol0003oh_g8on;mb?oRoLSo000000;oh_g80ol00015
ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooooooo07Cooooo00?o0000oc9m
i_lbONH00olbONH00ol0003oRjc/oh^/k008oh^/k003o`000?ni_Mco^KgL00Oo^KgL00?o0000okkD
j_nne>X01?nne>X00ol0003ofMCDomWDe00=omWDe003o`000?oNjM_og^WK00Gog^WK0_l00004on_Q
a`03o`000?o/lL[ok?7:00Sok?7:00?o0000on;mb?oRoLP00ooRoLP3o`0004Oooooo00?o0000oooo
ooooool04?ooool003gooooo0_l0001eooooo`;o00001?lbONH00ol0003oRjc/oh^/k008oh^/k003
o`000?ni_Mco^KgL00Co^KgL0_l00008okkDjP03o`000?oIe=CofMCD00_ofMCD00?o0000omkYfooN
jM/02?oNjM/2o`000003on_Qaol0003ok?7:00Wok?7:00?o0000on;mb?oRoLP00_oRoLP4o`0004So
oooo00?o0000ooooooooool04?ooool003oooooo00?o0000ooooooooool0Loooool4o`0000;o<WgV
00?o0000oh^/k?n;[>`02?n;[>`01?l0003o^KgLokVmg?ni_M`2o`0000_o_]CZ00?o0000omWDe?oI
e=@02OoIe=@00ol0003og^WKomkYf`0;omkYf`Ko00001Oo/lLX8o`000003ooooool0003ooooo04Oo
oooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0M?ooool01_l0003o077K
o`000?l0003o<WgVo`0000[oRjc/00?o0000okVmg?l000003_nne>X00ol0003ofMCDomWDe007omWD
e003o`000?oNjM_og^WK00_og^WK00?o0000omSlg?oHo=`01?oHo=`6o`0000?o]o_80_l00004oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool0047ooooo0_l0001eooooo`03
o`000?l0LM_o077K00?o00001On;[>`7o`0000oo_]CZ00?o0000omWDe?oIe=@01OoIe=@00ol0003o
g^WKomkYf`0;omkYf`03o`000?oHo=cof?cL00Oof?cL00?o0000okOkb?ngnlP00ongnlP2o`0000Ko
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003ooooo
o`00001fooooo`;o00000ol0LM/5o`0000OoNkkl00?o0000okkDj_nne>X03Onne>X00ol0003ofMCD
omWDe003omWDe003o`000?oNjM_og^WK00_og^WK00?o0000omSlg?oHo=`01ooHo=`00ol0003o]o_8
okOkb003okOkb003o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0@ooooo`00@oooool00ol0003oooooooooo`1dooooo`;o00001?l0LM/00ol0003oNkklog^n
o008og^no003o`000?nne>[o_]CZ00go_]CZ00Go0000omWDe?oIe=CofMCDo`00000=omkYf`03o`00
0?oHo=cof?cL00Oof?cL00?o0000okOkb?ngnlP00_ngnlP2o`0000_ooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`1eooooo`03o`000?l0
LM_o077K00;o077K00?o0000og^no?mk__`02?mk__`00ol0003o_]CZokkDjP0=okkDjP03o`000?oI
e=Co000000gog^WK00?o0000omSlg?oHo=`01ooHo=`00ol0003o]o_8okOkb002okOkb003o`000?oo
oooooooo00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool0
0ol0003oooooooooo`1eooooo`03o`000?l0LM_o077K00;o077K00?o0000og^no?mk__`02?mk__`2
o`0000go_]CZ0ol0000<omkYf`03o`000?oHo=cof?cL00Oof?cL00Co0000okOkb?ngnlSo]o_80_l0
000@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?ooool004Kooooo0_l0001f
ooooo`03o`000?l0LM_o077K00;o077K0_l0000:og^no003o`000?nne>[o_]CZ00So_]CZ0_l00003
ok[/m0?o00002?oNjM/00ol0003of?cLomSlg007omSlg003o`000?ngnlSo]o_800;o00004oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo013ooooo0018ooooo`03o`000?oooooooooo
07Cooooo0_l00004o`1af`03o`000?mk__coNkkl00SoNkkl00?o0000okkDj_nne>X01Onne>X2o`00
00So^^cd0_l00005omkYf`03o`000?oHo=cof?cL00Oof?cL1?l0000Eooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000ooooooooool0MOooool3o`0000;o
077K00?o0000og^no?mk__`02?mk__`00ol0003o_]CZokkDjP02okkDjP;o00003?njk?@3o`000003
omkYfol0003of?cL00Sof?cL0ol0000Hooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool004[ooooo00?o0000ooooooooool0Moooool2o`000003o`1afol0003oNkkl00WoNkkl
00Co0000okkDj_l0003o00004?njk?@>o`0001[ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0?ooooo`00B_ooool2o`0007[ooooo0ol00005og^no0Oo00003onjk?@2o`0000SoW??W
1?l0000Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool004cooooo00?o
0000ooooooooool0N_ooool5o`0000OoE/Gh0ol0000:ok[/m0;o00002?nLlnL4o`00023ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1k
ooooo`?o00002_mFaOP2o`0000Ko^^cd0_l00008oicci`?o00009?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oooooooooo07cooooo0ol0000:oeK5
n0?o000000?o^^cdo`000?l000002?nLlnL3o`0002Oooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool00ol00005oeK5n13o
0000:_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool00oooool?o`00037ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`00Doooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Kooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000Moooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`08ooooo`;o0000Loooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool003So
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000oooo
ooooool0L?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0>
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000K_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_ooool0
05oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool03_ooool0063ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0067ooooo
0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00I?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0=
ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0=ooooo`00I_ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`00
I_ooool3o`0006Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo001Yooooo`03o`000?oooooo
oooo067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo001Zooooo`;o0000HOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03Oooool006cooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool006gooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03Oooool006kooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool006oooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool03?ooool006oooooo0ol0001Kooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`00LOooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`00
L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`00Loooool2o`0005Sooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo001eooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00cooooo001fooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo001gooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00co
oooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`00N_ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<
ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0;ooooo`00O?ooool2o`0004oooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo001nooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00_ooooo001oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0020ooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00_ooooo0021ooooo`?o0000BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool02oooool007Kooooo1?l000000ol@413oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2oooool007Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool0
0ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02oooool005cooooo0ol000000ol@413oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool005kooooo00?o410@okZj^_oo
ool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oiRH
V?lb<S;ooooo01Oooooo00?o0000ooooooooool03_ooool2o`0004;ooooo00?o0000ooooooooool0
Koooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo001Nooooo`03omgMgOl0
003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2o`0004;ooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oeEEEOmgMgOo
A4A402[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool005gooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Z
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05ofIVI_n7QhOooooooiRHV?mEEED0:oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
02[ooooo0_l0000mooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`00G?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
02_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool0097ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0097ooooo
0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`00Toooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00U?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`00UOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`00U_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`00
Uoooool2o`0003Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo002Iooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo002Iooooo`?o0000<Oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
09_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool009cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool009gooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool009kooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`00XOooool2o`0002[ooooo00?o0000oooooooo
ool0P_ooool01Ol0003ooooooooooooooooo000000[ooooo002Sooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Poooool01?l0003oooooooooool0000:ooooo`00Y?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo00?o0000ooooool000002_ooool00:Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`25ooooo`;o00002_ooool00:Kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`24ooooo`?o00002_ooool00:Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`20ooooo`Co00003Oooool00:Sooooo00Co0000oooo
ool0003o00008Oooool00ol0003oooooooooo`1looooo`Co00004Oooool008kooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo0_l0000R
ooooo`03o`000?oooooooooo07Sooooo1?l0000Eooooo`00T?ooool00ol0003oooooooooo`04oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0M?ooool4o`0001Wooooo002@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo073ooooo1?l0000Mooooo`00
T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1]ooooo`?o00008Oooool0093ooooo00?o0000ooooooooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IOooool4o`0002Sooooo002@
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool3o`0001[ooooo00?o0000
ooooooooool0HOooool4o`0002cooooo002>ooooo`03oeEEEOmVIVKo000000gooooo1?l0000>oooo
o`;o00006oooool00ol0003oooooooooo`1Mooooo`Co0000<?ooool00;;ooooo0_l0000Iooooo`03
o`000?oooooooooo05Wooooo1?l0000dooooo`00]?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo05Gooooo1?l0000hooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo057ooooo1?l0000looooo`00]_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04gooooo1?l00010ooooo`00]oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo00?o0000ooooooooool0AOooool4o`0004So
oooo002iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool4o`0004cooooo
002jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool3o`00053ooooo002k
ooooo`;o00004?ooool00ol0003oooooooooo`0jooooo`Co0000Doooool00;gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0fooooo`Co0000Eoooool00;kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0booooo`Co0000Foooool00;oooooo0_l0000<ooooo`03o`00
0?oooooooooo02kooooo1?l0001Oooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0:_oo
ool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool4
o`0006Oooooo0032ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool4o`00
06_ooooo0033ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool4o`0006oo
oooo0034ooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`Co0000Loooool00<Kooooo0ol0
0004ooooo`03o`000?oooooooooo01Kooooo1?l0001gooooo`00a_ooool2o`0000Gooooo00?o0000
ooooooooool04oooool3o`0007_ooooo0038ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool4o`0007kooooo0039ooooo`05o`000?ooooooooooooooool000003Oooool4o`00
08;ooooo003:ooooo`04o`000?ooooooooooo`0000Wooooo1?l00026ooooo`00boooool00ol0003o
ooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0002>ooooo`00`_ooool5o`0000Kooooo0_l0
002Booooo`00`_ooool01OnHV9So8B4Qonk^k_ooooooA4A409[ooooo0033ooooo`03oiRHV?lQ8B7o
k^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[ooooo0035ooooo`03ogMgMomVIVKooooo09Wo
oooo0036ooooo`03o`000?oooooooooo09Sooooo0032ooooo`05o`000?nj^[[ooooooiRHV?l@4100
V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Jooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomR
ooooo`00oooooomRooooo`00YOooool3o`000003oa0@4?oooooooooo0;Kooooo002Cooooo`;o0000
2oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOooool009?ooooo00?o0000ooooooooool02_oo
ool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool00ooo
ool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`000?nj^[X0
1Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003o
ooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`1^
ooooo`00R_ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo073ooooo
002:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@
4?o<c<`:ooooo`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00kooooo00?o0000ooooooooool0L?ooool008[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0L?oo
ool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`1`ooooo`00Qoooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`00
0?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1`ooooo`00Qoooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0L?ooool008Oooooo1ol00005
ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00001booooo`00oooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.49 .673 .946 r
.52593 .68772 .5561 .7194 .58394 .7109 .55405 .68887 Metetra
.428 .723 .987 r
.55405 .68887 .58394 .7109 .61197 .70234 .58248 .68952 Metetra
.329 .749 .976 r
.58248 .68952 .61197 .70234 .64019 .69372 .6112 .68922 Metetra
.207 .723 .877 r
.6112 .68922 .64019 .69372 .66861 .68504 .6402 .68749 Metetra
.11 .663 .732 r
.6402 .68749 .66861 .68504 .69723 .6763 .66945 .68397 Metetra
.66945 .68397 .69723 .6763 .72605 .6675 .69891 .67837 Metetra
.69891 .67837 .72605 .6675 .75507 .65863 .72853 .67049 Metetra
.72853 .67049 .75507 .65863 .7843 .6497 .75828 .66025 Metetra
.284 .764 .663 r
.75828 .66025 .7843 .6497 .81374 .64071 .78812 .64772 Metetra
.452 .878 .782 r
.78812 .64772 .81374 .64071 .84339 .63166 .81801 .63305 Metetra
.62 .958 .89 r
.81801 .63305 .84339 .63166 .87325 .62254 .84794 .61652 Metetra
.733 .963 .939 r
.84794 .61652 .87325 .62254 .90333 .61335 .8779 .5985 Metetra
.778 .909 .931 r
.8779 .5985 .90333 .61335 .93362 .6041 .90789 .57943 Metetra
.78 .837 .896 r
.90789 .57943 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.203 .523 .918 r
.49498 .6552 .52593 .68772 .55405 .68887 .52326 .66565 Metetra
.078 .518 .901 r
.52326 .66565 .55405 .68887 .58248 .68952 .55197 .67525 Metetra
0 .501 .828 r
.55197 .67525 .58248 .68952 .6112 .68922 .58109 .68307 Metetra
0 .487 .722 r
.58109 .68307 .6112 .68922 .6402 .68749 .61059 .6882 Metetra
.094 0 0 r
.61059 .6882 .6402 .68749 .66945 .68397 .6404 .68983 Metetra
.028 0 0 r
.6404 .68983 .66945 .68397 .69891 .67837 .67046 .6874 Metetra
.67046 .6874 .69891 .67837 .72853 .67049 .70068 .6805 Metetra
.268 .758 .678 r
.70068 .6805 .72853 .67049 .75828 .66025 .73096 .66894 Metetra
.47 .885 .77 r
.73096 .66894 .75828 .66025 .78812 .64772 .76124 .65287 Metetra
.658 .972 .848 r
.76124 .65287 .78812 .64772 .81801 .63305 .79145 .63263 Metetra
.786 .991 .885 r
.79145 .63263 .81801 .63305 .84794 .61652 .82154 .60878 Metetra
.845 .957 .883 r
.82154 .60878 .84794 .61652 .8779 .5985 .85149 .58208 Metetra
.858 .899 .863 r
.85149 .58208 .8779 .5985 .90789 .57943 .88131 .55345 Metetra
.847 .838 .837 r
.88131 .55345 .90789 .57943 .93794 .55978 .91103 .52381 Metetra
0 .293 .776 r
.4632 .62183 .49498 .6552 .52326 .66565 .49153 .64075 Metetra
0 .255 .705 r
.49153 .64075 .52326 .66565 .55197 .67525 .52041 .65856 Metetra
0 .248 .632 r
.52041 .65856 .55197 .67525 .58109 .68307 .54981 .67389 Metetra
.31 0 0 r
.54981 .67389 .58109 .68307 .61059 .6882 .57971 .68538 Metetra
.226 0 0 r
.57971 .68538 .61059 .6882 .6404 .68983 .61001 .69182 Metetra
.069 0 0 r
.61001 .69182 .6404 .68983 .67046 .6874 .64062 .69235 Metetra
.156 .694 .719 r
.64062 .69235 .67046 .6874 .70068 .6805 .6714 .68635 Metetra
.419 .864 .809 r
.6714 .68635 .70068 .6805 .73096 .66894 .70223 .67352 Metetra
.647 .968 .863 r
.70223 .67352 .73096 .66894 .76124 .65287 .733 .65409 Metetra
.795 .994 .873 r
.733 .65409 .76124 .65287 .79145 .63263 .76359 .6286 Metetra
.869 .969 .855 r
.76359 .6286 .79145 .63263 .82154 .60878 .79394 .59789 Metetra
.896 .924 .831 r
.79394 .59789 .82154 .60878 .85149 .58208 .82401 .56311 Metetra
.896 .876 .808 r
.82401 .56311 .85149 .58208 .88131 .55345 .8538 .52564 Metetra
.882 .829 .79 r
.8538 .52564 .88131 .55345 .91103 .52381 .88337 .48685 Metetra
0 .076 .586 r
.43058 .58756 .4632 .62183 .49153 .64075 .45885 .61365 Metetra
.475 0 0 r
.45885 .61365 .49153 .64075 .52041 .65856 .48778 .63844 Metetra
.483 0 0 r
.48778 .63844 .52041 .65856 .54981 .67389 .51737 .66022 Metetra
.425 0 0 r
.51737 .66022 .54981 .67389 .57971 .68538 .54755 .67718 Metetra
.287 0 0 r
.54755 .67718 .57971 .68538 .61001 .69182 .57825 .68778 Metetra
0 .533 .727 r
.57825 .68778 .61001 .69182 .64062 .69235 .60933 .69085 Metetra
.27 .774 .861 r
.60933 .69085 .64062 .69235 .6714 .68635 .64064 .68559 Metetra
.574 .935 .924 r
.64064 .68559 .6714 .68635 .70223 .67352 .67202 .67161 Metetra
.766 .982 .909 r
.67202 .67161 .70223 .67352 .733 .65409 .7033 .6492 Metetra
.862 .965 .865 r
.7033 .6492 .733 .65409 .76359 .6286 .73434 .61908 Metetra
.902 .928 .824 r
.73434 .61908 .76359 .6286 .79394 .59789 .76506 .58237 Metetra
.914 .888 .792 r
.76506 .58237 .79394 .59789 .82401 .56311 .79538 .54057 Metetra
.911 .851 .77 r
.79538 .54057 .82401 .56311 .8538 .52564 .82533 .49547 Metetra
.9 .817 .756 r
.82533 .49547 .8538 .52564 .88337 .48685 .85493 .44884 Metetra
.561 .067 0 r
.39706 .55236 .43058 .58756 .45885 .61365 .42522 .5839 Metetra
.584 .066 0 r
.42522 .5839 .45885 .61365 .48778 .63844 .45412 .61405 Metetra
.558 .015 0 r
.45412 .61405 .48778 .63844 .51737 .66022 .48378 .64076 Metetra
.467 0 0 r
.48378 .64076 .51737 .66022 .54755 .67718 .51416 .66194 Metetra
0 .297 .654 r
.51416 .66194 .54755 .67718 .57825 .68778 .54516 .67574 Metetra
.03 .571 .844 r
.54516 .67574 .57825 .68778 .60933 .69085 .57664 .68075 Metetra
.4 .819 .971 r
.57664 .68075 .60933 .69085 .64064 .68559 .60842 .676 Metetra
.677 .931 .969 r
.60842 .676 .64064 .68559 .67202 .67161 .64031 .66104 Metetra
.818 .941 .907 r
.64031 .66104 .67202 .67161 .7033 .6492 .67212 .63622 Metetra
.881 .915 .845 r
.67212 .63622 .7033 .6492 .73434 .61908 .70368 .6024 Metetra
.908 .884 .798 r
.70368 .6024 .73434 .61908 .76506 .58237 .73485 .56091 Metetra
.917 .854 .765 r
.73485 .56091 .76506 .58237 .79538 .54057 .76558 .51357 Metetra
.916 .829 .745 r
.76558 .51357 .79538 .54057 .82533 .49547 .79584 .46249 Metetra
.909 .806 .734 r
.79584 .46249 .82533 .49547 .85493 .44884 .82567 .40974 Metetra
.635 .142 0 r
.36263 .5162 .39706 .55236 .42522 .5839 .39063 .55115 Metetra
.628 .121 0 r
.39063 .55115 .42522 .5839 .45412 .61405 .41945 .58467 Metetra
.574 .05 0 r
.41945 .58467 .45412 .61405 .48378 .64076 .44912 .61452 Metetra
.449 0 0 r
.44912 .61452 .48378 .64076 .51416 .66194 .47961 .63836 Metetra
0 .32 .737 r
.47961 .63836 .51416 .66194 .54516 .67574 .51082 .65415 Metetra
.148 .601 .93 r
.51082 .65415 .54516 .67574 .57664 .68075 .54262 .66032 Metetra
.499 .802 .999 r
.54262 .66032 .57664 .68075 .60842 .676 .57481 .65581 Metetra
.718 .875 .954 r
.57481 .65581 .60842 .676 .64031 .66104 .60718 .6401 Metetra
.825 .878 .883 r
.60718 .6401 .64031 .66104 .67212 .63622 .63951 .61357 Metetra
.876 .862 .823 r
.63951 .61357 .67212 .63622 .70368 .6024 .67162 .5772 Metetra
.9 .843 .779 r
.67162 .5772 .70368 .6024 .73485 .56091 .70333 .53247 Metetra
.911 .825 .749 r
.70333 .53247 .73485 .56091 .76558 .51357 .73457 .4814 Metetra
.913 .81 .731 r
.73457 .4814 .76558 .51357 .79584 .46249 .76531 .42632 Metetra
.911 .796 .721 r
.76531 .42632 .79584 .46249 .82567 .40974 .79557 .36951 Metetra
.657 .165 0 r
.32723 .47902 .36263 .5162 .39063 .55115 .3551 .51515 Metetra
.624 .126 0 r
.3551 .51515 .39063 .55115 .41945 .58467 .38384 .54983 Metetra
.54 .035 0 r
.38384 .54983 .41945 .58467 .44912 .61452 .41348 .58073 Metetra
0 .129 .619 r
.41348 .58073 .44912 .61452 .47961 .63836 .44402 .60546 Metetra
0 .367 .818 r
.44402 .60546 .47961 .63836 .51082 .65415 .47539 .62186 Metetra
.27 .606 .954 r
.47539 .62186 .51082 .65415 .54262 .66032 .50743 .62832 Metetra
.554 .75 .968 r
.50743 .62832 .54262 .66032 .57481 .65581 .53995 .62372 Metetra
.723 .804 .915 r
.53995 .62372 .57481 .65581 .60718 .6401 .57275 .6075 Metetra
.811 .816 .854 r
.57275 .6075 .60718 .6401 .63951 .61357 .60558 .5801 Metetra
.858 .813 .804 r
.60558 .5801 .63951 .61357 .67162 .5772 .63823 .54251 Metetra
.884 .806 .766 r
.63823 .54251 .67162 .5772 .70333 .53247 .67054 .49629 Metetra
.899 .799 .741 r
.67054 .49629 .70333 .53247 .73457 .4814 .70239 .44355 Metetra
.906 .793 .725 r
.70239 .44355 .73457 .4814 .76531 .42632 .73372 .38669 Metetra
.908 .788 .716 r
.73372 .38669 .76531 .42632 .79557 .36951 .76458 .32809 Metetra
.635 .142 0 r
.29083 .44079 .32723 .47902 .3551 .51515 .31865 .47571 Metetra
.574 .085 0 r
.31865 .47571 .3551 .51515 .38384 .54983 .34734 .50919 Metetra
0 .028 .547 r
.34734 .50919 .38384 .54983 .41348 .58073 .37698 .53896 Metetra
0 .207 .715 r
.37698 .53896 .41348 .58073 .44402 .60546 .40756 .56266 Metetra
.074 .421 .867 r
.40756 .56266 .44402 .60546 .47539 .62186 .43902 .5782 Metetra
.369 .594 .933 r
.43902 .5782 .47539 .62186 .50743 .62832 .47124 .58399 Metetra
.581 .694 .919 r
.47124 .58399 .50743 .62832 .53995 .62372 .50403 .57894 Metetra
.712 .74 .874 r
.50403 .57894 .53995 .62372 .57275 .6075 .53718 .56251 Metetra
.788 .76 .827 r
.53718 .56251 .57275 .6075 .60558 .5801 .57046 .53513 Metetra
.834 .768 .789 r
.57046 .53513 .60558 .5801 .63823 .54251 .60364 .49776 Metetra
.863 .772 .759 r
.60364 .49776 .63823 .54251 .67054 .49629 .63655 .45193 Metetra
.882 .775 .738 r
.63655 .45193 .67054 .49629 .70239 .44355 .66905 .39969 Metetra
.894 .777 .725 r
.66905 .39969 .70239 .44355 .73372 .38669 .70109 .34342 Metetra
.901 .78 .719 r
.70109 .34342 .73372 .38669 .76458 .32809 .73265 .28543 Metetra
.561 .067 0 r
.25338 .40146 .29083 .44079 .31865 .47571 .28128 .43284 Metetra
0 .011 .534 r
.28128 .43284 .31865 .47571 .34734 .50919 .31003 .46282 Metetra
0 .14 .667 r
.31003 .46282 .34734 .50919 .37698 .53896 .33972 .4893 Metetra
0 .307 .799 r
.33972 .4893 .37698 .53896 .40756 .56266 .37037 .51011 Metetra
.223 .466 .88 r
.37037 .51011 .40756 .56266 .43902 .5782 .40192 .52334 Metetra
.441 .58 .896 r
.40192 .52334 .43902 .5782 .47124 .58399 .43427 .52753 Metetra
.594 .649 .874 r
.43427 .52753 .47124 .58399 .50403 .57894 .46726 .52168 Metetra
.696 .689 .839 r
.46726 .52168 .50403 .57894 .53718 .56251 .50069 .50532 Metetra
.762 .713 .806 r
.50069 .50532 .53718 .56251 .57046 .53513 .53434 .47882 Metetra
.807 .729 .778 r
.53434 .47882 .57046 .53513 .60364 .49776 .56799 .44307 Metetra
.839 .741 .757 r
.56799 .44307 .60364 .49776 .63655 .45193 .60147 .39946 Metetra
.861 .752 .741 r
.60147 .39946 .63655 .45193 .66905 .39969 .63463 .34988 Metetra
.878 .763 .731 r
.63463 .34988 .66905 .39969 .70109 .34342 .6674 .2965 Metetra
.889 .773 .728 r
.6674 .2965 .70109 .34342 .73265 .28543 .69976 .24147 Metetra
0 .076 .586 r
.21484 .36098 .25338 .40146 .28128 .43284 .243 .38663 Metetra
0 .166 .687 r
.243 .38663 .28128 .43284 .31003 .46282 .27197 .41096 Metetra
0 .284 .785 r
.27197 .41096 .31003 .46282 .33972 .4893 .30183 .43216 Metetra
.154 .404 .849 r
.30183 .43216 .33972 .4893 .37037 .51011 .3326 .44837 Metetra
.348 .501 .869 r
.3326 .44837 .37037 .51011 .40192 .52334 .36426 .45796 Metetra
.495 .569 .86 r
.36426 .45796 .40192 .52334 .43427 .52753 .39673 .4597 Metetra
.602 .615 .837 r
.39673 .4597 .43427 .52753 .46726 .52168 .42986 .45275 Metetra
.679 .648 .812 r
.42986 .45275 .46726 .52168 .50069 .50532 .46349 .4367 Metetra
.735 .673 .79 r
.46349 .4367 .50069 .50532 .53434 .47882 .49741 .41187 Metetra
.777 .694 .772 r
.49741 .41187 .53434 .47882 .56799 .44307 .53145 .37902 Metetra
.81 .712 .758 r
.53145 .37902 .56799 .44307 .60147 .39946 .56542 .33931 Metetra
.835 .73 .748 r
.56542 .33931 .60147 .39946 .63463 .34988 .59919 .29436 Metetra
.856 .748 .743 r
.59919 .29436 .63463 .34988 .6674 .2965 .63268 .24603 Metetra
.872 .766 .743 r
.63268 .24603 .6674 .2965 .69976 .24147 .66586 .19616 Metetra
0 .293 .776 r
.17516 .3193 .21484 .36098 .243 .38663 .20382 .33728 Metetra
.017 .36 .832 r
.20382 .33728 .243 .38663 .27197 .41096 .2332 .35408 Metetra
.181 .427 .86 r
.2332 .35408 .27197 .41096 .30183 .43216 .26337 .3683 Metetra
.328 .484 .863 r
.26337 .3683 .30183 .43216 .3326 .44837 .29438 .37845 Metetra
.447 .529 .849 r
.29438 .37845 .3326 .44837 .36426 .45796 .3262 .3833 Metetra
.538 .564 .829 r
.3262 .3833 .36426 .45796 .39673 .4597 .35878 .38188 Metetra
.608 .592 .809 r
.35878 .38188 .39673 .4597 .42986 .45275 .39201 .37356 Metetra
.664 .617 .792 r
.39201 .37356 .42986 .45275 .46349 .4367 .42576 .35803 Metetra
.708 .64 .778 r
.42576 .35803 .46349 .4367 .49741 .41187 .45986 .33553 Metetra
.745 .662 .768 r
.45986 .33553 .49741 .41187 .53145 .37902 .49416 .30664 Metetra
.776 .684 .762 r
.49416 .30664 .53145 .37902 .56542 .33931 .52851 .27226 Metetra
.803 .707 .759 r
.52851 .27226 .56542 .33931 .59919 .29436 .5628 .23362 Metetra
.826 .731 .76 r
.5628 .23362 .59919 .29436 .63268 .24603 .59694 .1922 Metetra
.845 .758 .766 r
.59694 .1922 .63268 .24603 .66586 .19616 .63089 .14942 Metetra
.203 .523 .918 r
.13429 .27638 .17516 .3193 .20382 .33728 .16371 .28511 Metetra
.304 .529 .906 r
.16371 .28511 .20382 .33728 .2332 .35408 .19372 .29291 Metetra
.392 .535 .88 r
.19372 .29291 .2332 .35408 .26337 .3683 .2244 .29881 Metetra
.465 .543 .852 r
.2244 .29881 .26337 .3683 .29438 .37845 .25578 .30182 Metetra
.524 .553 .827 r
.25578 .30182 .29438 .37845 .3262 .3833 .28784 .30109 Metetra
.573 .564 .806 r
.28784 .30109 .3262 .3833 .35878 .38188 .32056 .296 Metetra
.614 .578 .79 r
.32056 .296 .35878 .38188 .39201 .37356 .35386 .28612 Metetra
.65 .594 .778 r
.35386 .28612 .39201 .37356 .42576 .35803 .38765 .27126 Metetra
.682 .612 .771 r
.38765 .27126 .42576 .35803 .45986 .33553 .42181 .25156 Metetra
.711 .632 .768 r
.42181 .25156 .45986 .33553 .49416 .30664 .45625 .22742 Metetra
.737 .656 .769 r
.45625 .22742 .49416 .30664 .52851 .27226 .49084 .19942 Metetra
.762 .682 .774 r
.49084 .19942 .52851 .27226 .5628 .23362 .52551 .16839 Metetra
.785 .712 .783 r
.52551 .16839 .5628 .23362 .59694 .1922 .56017 .13532 Metetra
.806 .745 .796 r
.56017 .13532 .59694 .1922 .63089 .14942 .59481 .1012 Metetra
.49 .673 .946 r
.09217 .23214 .13429 .27638 .16371 .28511 .12262 .23052 Metetra
.521 .635 .904 r
.12262 .23052 .16371 .28511 .19372 .29291 .15352 .22833 Metetra
.545 .606 .865 r
.15352 .22833 .19372 .29291 .2244 .29881 .18491 .22507 Metetra
.567 .586 .832 r
.18491 .22507 .2244 .29881 .25578 .30182 .2168 .22024 Metetra
.586 .574 .807 r
.2168 .22024 .25578 .30182 .28784 .30109 .24921 .21345 Metetra
.603 .569 .789 r
.24921 .21345 .28784 .30109 .32056 .296 .2821 .20438 Metetra
.621 .571 .777 r
.2821 .20438 .32056 .296 .35386 .28612 .31546 .19284 Metetra
.638 .577 .77 r
.31546 .19284 .35386 .28612 .38765 .27126 .34923 .17871 Metetra
.655 .589 .768 r
.34923 .17871 .38765 .27126 .42181 .25156 .38336 .16209 Metetra
.673 .605 .771 r
.38336 .16209 .42181 .25156 .45625 .22742 .4178 .14314 Metetra
.691 .626 .779 r
.4178 .14314 .45625 .22742 .49084 .19942 .45247 .12217 Metetra
.71 .653 .791 r
.45247 .12217 .49084 .19942 .52551 .16839 .48735 .09956 Metetra
.729 .686 .808 r
.48735 .09956 .52551 .16839 .56017 .13532 .52239 .07581 Metetra
.747 .725 .831 r
.52239 .07581 .56017 .13532 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12262 .23052 .08051 .17394 Metetra
.659 .689 .867 r
.08051 .17394 .12262 .23052 .15352 .22833 .11254 .16124 Metetra
.65 .649 .835 r
.11254 .16124 .15352 .22833 .18491 .22507 .14483 .14843 Metetra
.642 .617 .81 r
.14483 .14843 .18491 .22507 .2168 .22024 .1774 .13551 Metetra
.636 .594 .791 r
.1774 .13551 .2168 .22024 .24921 .21345 .21025 .12249 Metetra
.631 .579 .777 r
.21025 .12249 .24921 .21345 .2821 .20438 .24339 .10934 Metetra
.628 .57 .769 r
.24339 .10934 .2821 .20438 .31546 .19284 .27681 .09609 Metetra
.627 .567 .767 r
.27681 .09609 .31546 .19284 .34923 .17871 .31052 .08272 Metetra
.628 .57 .769 r
.31052 .08272 .34923 .17871 .38336 .16209 .34452 .06923 Metetra
.631 .579 .777 r
.34452 .06923 .38336 .16209 .4178 .14314 .37882 .05563 Metetra
.636 .594 .791 r
.37882 .05563 .4178 .14314 .45247 .12217 .41342 .04191 Metetra
.642 .617 .81 r
.41342 .04191 .45247 .12217 .48735 .09956 .44833 .02806 Metetra
.65 .649 .835 r
.44833 .02806 .48735 .09956 .52239 .07581 .48355 .01409 Metetra
.659 .689 .867 r
.48355 .01409 .52239 .07581 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.547 .697 .938 r
.52593 .68772 .5561 .7194 .58394 .7109 .55404 .68626 Metetra
.522 .741 .975 r
.55404 .68626 .58394 .7109 .61197 .70234 .58243 .68442 Metetra
.487 .784 .997 r
.58243 .68442 .61197 .70234 .64019 .69372 .6111 .68184 Metetra
.445 .816 .993 r
.6111 .68184 .64019 .69372 .66861 .68504 .64001 .6782 Metetra
.407 .832 .962 r
.64001 .6782 .66861 .68504 .69723 .6763 .66917 .67323 Metetra
.39 .84 .923 r
.66917 .67323 .69723 .6763 .72605 .6675 .69853 .6667 Metetra
.404 .854 .898 r
.69853 .6667 .72605 .6675 .75507 .65863 .72807 .6585 Metetra
.454 .882 .899 r
.72807 .6585 .75507 .65863 .7843 .6497 .75775 .64855 Metetra
.529 .916 .922 r
.75775 .64855 .7843 .6497 .81374 .64071 .78756 .6369 Metetra
.614 .941 .95 r
.78756 .6369 .81374 .64071 .84339 .63166 .81747 .62366 Metetra
.686 .94 .964 r
.81747 .62366 .84339 .63166 .87325 .62254 .84746 .60904 Metetra
.731 .911 .956 r
.84746 .60904 .87325 .62254 .90333 .61335 .87753 .5933 Metetra
.75 .865 .932 r
.87753 .5933 .90333 .61335 .93362 .6041 .90768 .57676 Metetra
.751 .813 .901 r
.90768 .57676 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.375 .618 .946 r
.49498 .6552 .52593 .68772 .55404 .68626 .52328 .66052 Metetra
.323 .645 .967 r
.52328 .66052 .55404 .68626 .58243 .68442 .55194 .66517 Metetra
.279 .675 .971 r
.55194 .66517 .58243 .68442 .6111 .68184 .58097 .66847 Metetra
.257 .708 .956 r
.58097 .66847 .6111 .68184 .64001 .6782 .61032 .66976 Metetra
.269 .747 .934 r
.61032 .66976 .64001 .6782 .66917 .67323 .63996 .66846 Metetra
.321 .795 .919 r
.63996 .66846 .66917 .67323 .69853 .6667 .66984 .66418 Metetra
.407 .852 .919 r
.66984 .66418 .69853 .6667 .72807 .6585 .69989 .65662 Metetra
.517 .908 .931 r
.69989 .65662 .72807 .6585 .75775 .64855 .73005 .64564 Metetra
.627 .948 .943 r
.73005 .64564 .75775 .64855 .78756 .6369 .76026 .63135 Metetra
.718 .96 .944 r
.76026 .63135 .78756 .6369 .81747 .62366 .79048 .61399 Metetra
.778 .945 .932 r
.79048 .61399 .81747 .62366 .84746 .60904 .82067 .59397 Metetra
.808 .91 .91 r
.82067 .59397 .84746 .60904 .87753 .5933 .85082 .57182 Metetra
.816 .866 .884 r
.85082 .57182 .87753 .5933 .90768 .57676 .88093 .54821 Metetra
.809 .82 .859 r
.88093 .54821 .90768 .57676 .93794 .55978 .91103 .52381 Metetra
.16 .497 .907 r
.4632 .62183 .49498 .6552 .52328 .66052 .49161 .6333 Metetra
.098 .505 .904 r
.49161 .6333 .52328 .66052 .55194 .66517 .52046 .64388 Metetra
.069 .532 .898 r
.52046 .64388 .55194 .66517 .58097 .66847 .54977 .65258 Metetra
.09 .586 .898 r
.54977 .65258 .58097 .66847 .61032 .66976 .57949 .6584 Metetra
.166 .666 .911 r
.57949 .6584 .61032 .66976 .63996 .66846 .60956 .66051 Metetra
.289 .763 .934 r
.60956 .66051 .63996 .66846 .66984 .66418 .63991 .65828 Metetra
.44 .857 .956 r
.63991 .65828 .66984 .66418 .69989 .65662 .67045 .65129 Metetra
.589 .925 .963 r
.67045 .65129 .69989 .65662 .73005 .64564 .70109 .63933 Metetra
.708 .954 .951 r
.70109 .63933 .73005 .64564 .76026 .63135 .73174 .62255 Metetra
.787 .95 .926 r
.73174 .62255 .76026 .63135 .79048 .61399 .76232 .60134 Metetra
.831 .926 .896 r
.76232 .60134 .79048 .61399 .82067 .59397 .79279 .57627 Metetra
.85 .892 .867 r
.79279 .57627 .82067 .59397 .85082 .57182 .82311 .54818 Metetra
.853 .855 .843 r
.82311 .54818 .85082 .57182 .88093 .54821 .8533 .51804 Metetra
.845 .818 .823 r
.8533 .51804 .88093 .54821 .91103 .52381 .88337 .48685 Metetra
0 .357 .824 r
.43058 .58756 .4632 .62183 .49161 .6333 .45901 .60423 Metetra
0 .36 .81 r
.45901 .60423 .49161 .6333 .52046 .64388 .48798 .61983 Metetra
0 .4 .816 r
.48798 .61983 .52046 .64388 .54977 .65258 .51749 .63311 Metetra
0 .484 .85 r
.51749 .63311 .54977 .65258 .57949 .6584 .5475 .64281 Metetra
.112 .606 .905 r
.5475 .64281 .57949 .6584 .60956 .66051 .57794 .64782 Metetra
.295 .742 .961 r
.57794 .64782 .60956 .66051 .63991 .65828 .60871 .64733 Metetra
.489 .854 .989 r
.60871 .64733 .63991 .65828 .67045 .65129 .63972 .64079 Metetra
.651 .917 .978 r
.63972 .64079 .67045 .65129 .70109 .63933 .67083 .62793 Metetra
.76 .932 .943 r
.67083 .62793 .70109 .63933 .73174 .62255 .70194 .60895 Metetra
.824 .92 .901 r
.70194 .60895 .73174 .62255 .76232 .60134 .73294 .58434 Metetra
.857 .896 .863 r
.73294 .58434 .76232 .60134 .79279 .57627 .76376 .55488 Metetra
.871 .868 .832 r
.76376 .55488 .79279 .57627 .82311 .54818 .79436 .52163 Metetra
.872 .839 .81 r
.79436 .52163 .82311 .54818 .8533 .51804 .82474 .48586 Metetra
.865 .812 .795 r
.82474 .48586 .8533 .51804 .88337 .48685 .85493 .44884 Metetra
0 .238 .732 r
.39706 .55236 .43058 .58756 .45901 .60423 .42548 .57295 Metetra
0 .251 .728 r
.42548 .57295 .45901 .60423 .48798 .61983 .45451 .59237 Metetra
0 .31 .759 r
.45451 .59237 .48798 .61983 .51749 .63311 .48415 .60915 Metetra
0 .421 .827 r
.48415 .60915 .51749 .63311 .5475 .64281 .51437 .62179 Metetra
.108 .571 .914 r
.51437 .62179 .5475 .64281 .57794 .64782 .54511 .62899 Metetra
.329 .723 .982 r
.54511 .62899 .57794 .64782 .60871 .64733 .57625 .6298 Metetra
.537 .832 .999 r
.57625 .6298 .60871 .64733 .63972 .64079 .60768 .62355 Metetra
.69 .883 .97 r
.60768 .62355 .63972 .64079 .67083 .62793 .63925 .60991 Metetra
.784 .893 .922 r
.63925 .60991 .67083 .62793 .70194 .60895 .67083 .58913 Metetra
.837 .881 .875 r
.67083 .58913 .70194 .60895 .73294 .58434 .70229 .5618 Metetra
.865 .863 .836 r
.70229 .5618 .73294 .58434 .76376 .55488 .73354 .52884 Metetra
.877 .843 .807 r
.73354 .52884 .76376 .55488 .79436 .52163 .76452 .49152 Metetra
.88 .823 .788 r
.76452 .49152 .79436 .52163 .82474 .48586 .79522 .45132 Metetra
.876 .805 .775 r
.79522 .45132 .82474 .48586 .85493 .44884 .82567 .40974 Metetra
0 .162 .667 r
.36263 .5162 .39706 .55236 .42548 .57295 .39101 .53922 Metetra
0 .191 .682 r
.39101 .53922 .42548 .57295 .45451 .59237 .42005 .56101 Metetra
0 .269 .739 r
.42005 .56101 .45451 .59237 .48415 .60915 .44977 .57995 Metetra
0 .397 .83 r
.44977 .57995 .48415 .60915 .51437 .62179 .48016 .59441 Metetra
.146 .556 .927 r
.48016 .59441 .51437 .62179 .54511 .62899 .51113 .60295 Metetra
.377 .701 .984 r
.51113 .60295 .54511 .62899 .57625 .6298 .54259 .60449 Metetra
.572 .794 .983 r
.54259 .60449 .57625 .6298 .60768 .62355 .5744 .59832 Metetra
.706 .836 .945 r
.5744 .59832 .60768 .62355 .63925 .60991 .6064 .58406 Metetra
.787 .846 .896 r
.6064 .58406 .63925 .60991 .67083 .58913 .63844 .56199 Metetra
.834 .841 .851 r
.63844 .56199 .67083 .58913 .70229 .5618 .67039 .53277 Metetra
.861 .831 .816 r
.67039 .53277 .70229 .5618 .73354 .52884 .70212 .49742 Metetra
.875 .819 .79 r
.70212 .49742 .73354 .52884 .76452 .49152 .73357 .45733 Metetra
.881 .808 .773 r
.73357 .45733 .76452 .49152 .79522 .45132 .76471 .41415 Metetra
.88 .797 .763 r
.76471 .41415 .79522 .45132 .82567 .40974 .79557 .36951 Metetra
0 .137 .644 r
.32723 .47902 .36263 .5162 .39101 .53922 .35559 .50282 Metetra
0 .181 .681 r
.35559 .50282 .39101 .53922 .42005 .56101 .38464 .52537 Metetra
0 .273 .755 r
.38464 .52537 .42005 .56101 .44977 .57995 .41443 .545 Metetra
0 .407 .852 r
.41443 .545 .44977 .57995 .48016 .59441 .44493 .55999 Metetra
.213 .554 .933 r
.44493 .55999 .48016 .59441 .51113 .60295 .4761 .56888 Metetra
.426 .675 .966 r
.4761 .56888 .51113 .60295 .54259 .60449 .50782 .57053 Metetra
.593 .75 .952 r
.50782 .57053 .54259 .60449 .5744 .59832 .53995 .5642 Metetra
.707 .787 .913 r
.53995 .5642 .5744 .59832 .6064 .58406 .57235 .5495 Metetra
.779 .8 .87 r
.57235 .5495 .6064 .58406 .63844 .56199 .60484 .52673 Metetra
.823 .803 .832 r
.60484 .52673 .63844 .56199 .67039 .53277 .63728 .49656 Metetra
.851 .801 .802 r
.63728 .49656 .67039 .53277 .70212 .49742 .66953 .46006 Metetra
.867 .797 .78 r
.66953 .46006 .70212 .49742 .73357 .45733 .70151 .41868 Metetra
.876 .794 .766 r
.70151 .41868 .73357 .45733 .76471 .41415 .73319 .37413 Metetra
.879 .79 .758 r
.73319 .37413 .76471 .41415 .79557 .36951 .76458 .32809 Metetra
0 .162 .667 r
.29083 .44079 .32723 .47902 .35559 .50282 .31922 .46363 Metetra
0 .219 .719 r
.31922 .46363 .35559 .50282 .38464 .52537 .34832 .48523 Metetra
0 .316 .797 r
.34832 .48523 .38464 .52537 .41443 .545 .37818 .50395 Metetra
.091 .439 .877 r
.37818 .50395 .41443 .545 .44493 .55999 .4088 .51813 Metetra
.293 .559 .928 r
.4088 .51813 .44493 .55999 .4761 .56888 .44012 .52631 Metetra
.471 .65 .937 r
.44012 .52631 .4761 .56888 .50782 .57053 .47206 .52739 Metetra
.606 .708 .916 r
.47206 .52739 .50782 .57053 .53995 .5642 .50447 .52065 Metetra
.701 .74 .882 r
.50447 .52065 .53995 .5642 .57235 .5495 .53722 .50571 Metetra
.763 .758 .847 r
.53722 .50571 .57235 .5495 .60484 .52673 .57012 .48286 Metetra
.806 .767 .817 r
.57012 .48286 .60484 .52673 .63728 .49656 .60303 .45275 Metetra
.834 .773 .793 r
.60303 .45275 .63728 .49656 .66953 .46006 .63581 .41644 Metetra
.854 .777 .776 r
.63581 .41644 .66953 .46006 .70151 .41868 .66837 .37533 Metetra
.866 .78 .764 r
.66837 .37533 .70151 .41868 .73319 .37413 .70065 .33111 Metetra
.873 .783 .759 r
.70065 .33111 .73319 .37413 .76458 .32809 .73265 .28543 Metetra
0 .238 .732 r
.25338 .40146 .29083 .44079 .31922 .46363 .28191 .42162 Metetra
0 .298 .786 r
.28191 .42162 .31922 .46363 .34832 .48523 .31113 .4406 Metetra
.035 .386 .847 r
.31113 .4406 .34832 .48523 .37818 .50395 .34111 .45686 Metetra
.206 .482 .894 r
.34111 .45686 .37818 .50395 .4088 .51813 .37185 .46889 Metetra
.372 .567 .913 r
.37185 .46889 .4088 .51813 .44012 .52631 .40333 .47533 Metetra
.509 .63 .905 r
.40333 .47533 .44012 .52631 .47206 .52739 .43545 .47519 Metetra
.613 .672 .883 r
.43545 .47519 .47206 .52739 .50447 .52065 .4681 .46779 Metetra
.69 .701 .855 r
.4681 .46779 .50447 .52065 .53722 .50571 .50113 .4528 Metetra
.745 .721 .829 r
.50113 .4528 .53722 .50571 .57012 .48286 .5344 .43047 Metetra
.785 .735 .807 r
.5344 .43047 .57012 .48286 .60303 .45275 .56774 .40142 Metetra
.814 .746 .789 r
.56774 .40142 .60303 .45275 .63581 .41644 .60103 .36659 Metetra
.836 .757 .776 r
.60103 .36659 .63581 .41644 .66837 .37533 .63416 .3273 Metetra
.851 .767 .769 r
.63416 .3273 .66837 .37533 .70065 .33111 .66708 .28508 Metetra
.861 .776 .766 r
.66708 .28508 .70065 .33111 .73265 .28543 .69976 .24147 Metetra
0 .357 .824 r
.21484 .36098 .25338 .40146 .28191 .42162 .24364 .37686 Metetra
.057 .406 .859 r
.24364 .37686 .28191 .42162 .31113 .4406 .2731 .39164 Metetra
.189 .466 .886 r
.2731 .39164 .31113 .4406 .34111 .45686 .30328 .40401 Metetra
.323 .526 .898 r
.30328 .40401 .34111 .45686 .37185 .46889 .3342 .41264 Metetra
.444 .576 .892 r
.3342 .41264 .37185 .46889 .40333 .47533 .36584 .41641 Metetra
.541 .615 .876 r
.36584 .41641 .40333 .47533 .43545 .47519 .39812 .41443 Metetra
.618 .645 .855 r
.39812 .41443 .43545 .47519 .4681 .46779 .43097 .40615 Metetra
.678 .669 .834 r
.43097 .40615 .4681 .46779 .50113 .4528 .46424 .39128 Metetra
.725 .688 .815 r
.46424 .39128 .50113 .4528 .5344 .43047 .4978 .37004 Metetra
.761 .706 .8 r
.4978 .37004 .5344 .43047 .56774 .40142 .53152 .34294 Metetra
.79 .722 .788 r
.53152 .34294 .56774 .40142 .60103 .36659 .56526 .3108 Metetra
.813 .737 .781 r
.56526 .3108 .60103 .36659 .63416 .3273 .59893 .27474 Metetra
.83 .753 .778 r
.59893 .27474 .63416 .3273 .66708 .28508 .63247 .23609 Metetra
.844 .769 .779 r
.63247 .23609 .66708 .28508 .69976 .24147 .66586 .19616 Metetra
.16 .497 .907 r
.17516 .3193 .21484 .36098 .24364 .37686 .2044 .32946 Metetra
.249 .517 .909 r
.2044 .32946 .24364 .37686 .2731 .39164 .23424 .33867 Metetra
.342 .54 .903 r
.23424 .33867 .2731 .39164 .30328 .40401 .26473 .3459 Metetra
.43 .564 .888 r
.26473 .3459 .30328 .40401 .3342 .41264 .29591 .35009 Metetra
.506 .587 .87 r
.29591 .35009 .3342 .41264 .36584 .41641 .32775 .35035 Metetra
.57 .607 .85 r
.32775 .35035 .36584 .41641 .39812 .41443 .36021 .34603 Metetra
.623 .625 .832 r
.36021 .34603 .39812 .41443 .43097 .40615 .39321 .33668 Metetra
.667 .643 .817 r
.39321 .33668 .43097 .40615 .46424 .39128 .42666 .32207 Metetra
.704 .661 .805 r
.42666 .32207 .46424 .39128 .4978 .37004 .46045 .30238 Metetra
.735 .679 .796 r
.46045 .30238 .4978 .37004 .53152 .34294 .49445 .27801 Metetra
.761 .697 .791 r
.49445 .27801 .53152 .34294 .56526 .3108 .52857 .24958 Metetra
.784 .717 .789 r
.52857 .24958 .56526 .3108 .59893 .27474 .56272 .21799 Metetra
.803 .738 .792 r
.56272 .21799 .59893 .27474 .63247 .23609 .59683 .18425 Metetra
.818 .76 .798 r
.59683 .18425 .63247 .23609 .66586 .19616 .63089 .14942 Metetra
.375 .618 .946 r
.13429 .27638 .17516 .3193 .2044 .32946 .16417 .27966 Metetra
.425 .606 .923 r
.16417 .27966 .2044 .32946 .23424 .33867 .19455 .2822 Metetra
.474 .599 .897 r
.19455 .2822 .23424 .33867 .26473 .3459 .2255 .28329 Metetra
.519 .596 .871 r
.2255 .28329 .26473 .3459 .29591 .35009 .25702 .28222 Metetra
.559 .598 .849 r
.25702 .28222 .29591 .35009 .32775 .35035 .28912 .27837 Metetra
.595 .604 .83 r
.28912 .27837 .32775 .35035 .36021 .34603 .32177 .27131 Metetra
.627 .612 .816 r
.32177 .27131 .36021 .34603 .39321 .33668 .35491 .26073 Metetra
.656 .624 .805 r
.35491 .26073 .39321 .33668 .42666 .32207 .38849 .24649 Metetra
.682 .638 .799 r
.38849 .24649 .42666 .32207 .46045 .30238 .42242 .22871 Metetra
.706 .654 .796 r
.42242 .22871 .46045 .30238 .49445 .27801 .45662 .20764 Metetra
.728 .674 .797 r
.45662 .20764 .49445 .27801 .52857 .24958 .49102 .18372 Metetra
.748 .696 .801 r
.49102 .18372 .52857 .24958 .56272 .21799 .52554 .15753 Metetra
.766 .72 .81 r
.52554 .15753 .56272 .21799 .59683 .18425 .56015 .12979 Metetra
.782 .748 .822 r
.56015 .12979 .59683 .18425 .63089 .14942 .59481 .1012 Metetra
.547 .697 .938 r
.09217 .23214 .13429 .27638 .16417 .27966 .12289 .22772 Metetra
.563 .666 .907 r
.12289 .22772 .16417 .27966 .19455 .2822 .154 .22284 Metetra
.577 .641 .877 r
.154 .22284 .19455 .2822 .2255 .28329 .18555 .21715 Metetra
.591 .623 .852 r
.18555 .21715 .2255 .28329 .25702 .28222 .21753 .21027 Metetra
.605 .611 .831 r
.21753 .21027 .25702 .28222 .28912 .27837 .24997 .20192 Metetra
.619 .605 .815 r
.24997 .20192 .28912 .27837 .32177 .27131 .28284 .19187 Metetra
.632 .605 .805 r
.28284 .19187 .32177 .27131 .35491 .26073 .31612 .17998 Metetra
.646 .61 .799 r
.31612 .17998 .35491 .26073 .38849 .24649 .34978 .16616 Metetra
.66 .619 .797 r
.34978 .16616 .38849 .24649 .42242 .22871 .38378 .15049 Metetra
.675 .632 .799 r
.38378 .15049 .42242 .22871 .45662 .20764 .41808 .13309 Metetra
.689 .65 .805 r
.41808 .13309 .45662 .20764 .49102 .18372 .45264 .11417 Metetra
.704 .672 .816 r
.45264 .11417 .49102 .18372 .52554 .15753 .48742 .09401 Metetra
.718 .698 .83 r
.48742 .09401 .52554 .15753 .56015 .12979 .5224 .07297 Metetra
.731 .729 .849 r
.5224 .07297 .56015 .12979 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12289 .22772 .08051 .17394 Metetra
.661 .701 .877 r
.08051 .17394 .12289 .22772 .154 .22284 .11254 .16124 Metetra
.655 .67 .852 r
.11254 .16124 .154 .22284 .18555 .21715 .14483 .14843 Metetra
.649 .644 .832 r
.14483 .14843 .18555 .21715 .21753 .21027 .1774 .13551 Metetra
.644 .625 .816 r
.1774 .13551 .21753 .21027 .24997 .20192 .21025 .12249 Metetra
.64 .611 .805 r
.21025 .12249 .24997 .20192 .28284 .19187 .24339 .10934 Metetra
.638 .603 .798 r
.24339 .10934 .28284 .19187 .31612 .17998 .27681 .09609 Metetra
.637 .601 .796 r
.27681 .09609 .31612 .17998 .34978 .16616 .31052 .08272 Metetra
.638 .603 .798 r
.31052 .08272 .34978 .16616 .38378 .15049 .34452 .06923 Metetra
.64 .611 .805 r
.34452 .06923 .38378 .15049 .41808 .13309 .37882 .05563 Metetra
.644 .625 .816 r
.37882 .05563 .41808 .13309 .45264 .11417 .41342 .04191 Metetra
.649 .644 .832 r
.41342 .04191 .45264 .11417 .48742 .09401 .44833 .02806 Metetra
.655 .67 .852 r
.44833 .02806 .48742 .09401 .5224 .07297 .48355 .01409 Metetra
.661 .701 .877 r
.48355 .01409 .5224 .07297 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.584 .711 .931 r
.52593 .68772 .5561 .7194 .58394 .7109 .55404 .68434 Metetra
.573 .746 .958 r
.55404 .68434 .58394 .7109 .61197 .70234 .5824 .68066 Metetra
.561 .782 .981 r
.5824 .68066 .61197 .70234 .64019 .69372 .61102 .67642 Metetra
.55 .816 .995 r
.61102 .67642 .64019 .69372 .66861 .68504 .63987 .67139 Metetra
.544 .845 .999 r
.63987 .67139 .66861 .68504 .69723 .6763 .66896 .66535 Metetra
.546 .868 .995 r
.66896 .66535 .69723 .6763 .72605 .6675 .69825 .65816 Metetra
.561 .886 .989 r
.69825 .65816 .72605 .6675 .75507 .65863 .72772 .64971 Metetra
.589 .901 .985 r
.72772 .64971 .75507 .65863 .7843 .6497 .75737 .63997 Metetra
.626 .909 .983 r
.75737 .63997 .7843 .6497 .81374 .64071 .78715 .62896 Metetra
.665 .906 .979 r
.78715 .62896 .81374 .64071 .84339 .63166 .81707 .61678 Metetra
.697 .891 .968 r
.81707 .61678 .84339 .63166 .87325 .62254 .84711 .60355 Metetra
.719 .865 .951 r
.84711 .60355 .87325 .62254 .90333 .61335 .87726 .58948 Metetra
.729 .831 .928 r
.87726 .58948 .90333 .61335 .93362 .6041 .90753 .57481 Metetra
.729 .794 .904 r
.90753 .57481 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.476 .667 .947 r
.49498 .6552 .52593 .68772 .55404 .68434 .52329 .65675 Metetra
.457 .696 .97 r
.52329 .65675 .55404 .68434 .5824 .68066 .55193 .65777 Metetra
.446 .73 .987 r
.55193 .65777 .5824 .68066 .61102 .67642 .58088 .65777 Metetra
.448 .767 .997 r
.58088 .65777 .61102 .67642 .63987 .67139 .61013 .65627 Metetra
.468 .806 .999 r
.61013 .65627 .63987 .67139 .66896 .66535 .63964 .65285 Metetra
.505 .843 .997 r
.63964 .65285 .66896 .66535 .69825 .65816 .66938 .64722 Metetra
.557 .876 .993 r
.66938 .64722 .69825 .65816 .72772 .64971 .69931 .63918 Metetra
.617 .901 .986 r
.69931 .63918 .72772 .64971 .75737 .63997 .72938 .62862 Metetra
.674 .913 .975 r
.72938 .62862 .75737 .63997 .78715 .62896 .75954 .61563 Metetra
.722 .91 .96 r
.75954 .61563 .78715 .62896 .81707 .61678 .78977 .60037 Metetra
.755 .893 .94 r
.78977 .60037 .81707 .61678 .84711 .60355 .82003 .58312 Metetra
.774 .868 .918 r
.82003 .58312 .84711 .60355 .87726 .58948 .85032 .56429 Metetra
.78 .836 .895 r
.85032 .56429 .87726 .58948 .90753 .57481 .88065 .54436 Metetra
.777 .803 .874 r
.88065 .54436 .90753 .57481 .93794 .55978 .91103 .52381 Metetra
.349 .605 .944 r
.4632 .62183 .49498 .6552 .52329 .65675 .49166 .62784 Metetra
.326 .627 .96 r
.49166 .62784 .52329 .65675 .55193 .65777 .52051 .63313 Metetra
.325 .661 .973 r
.52051 .63313 .55193 .65777 .58088 .65777 .54974 .637 Metetra
.351 .707 .985 r
.54974 .637 .58088 .65777 .61013 .65627 .57933 .63873 Metetra
.405 .761 .994 r
.57933 .63873 .61013 .65627 .63964 .65285 .60923 .63772 Metetra
.48 .816 .999 r
.60923 .63772 .63964 .65285 .66938 .64722 .6394 .63351 Metetra
.565 .862 .996 r
.6394 .63351 .66938 .64722 .69931 .63918 .66976 .62581 Metetra
.647 .892 .984 r
.66976 .62581 .69931 .63918 .72938 .62862 .70026 .61447 Metetra
.714 .904 .963 r
.70026 .61447 .72938 .62862 .75954 .61563 .73082 .5996 Metetra
.762 .899 .937 r
.73082 .5996 .75954 .61563 .78977 .60037 .7614 .58146 Metetra
.793 .882 .911 r
.7614 .58146 .78977 .60037 .82003 .58312 .79195 .56048 Metetra
.809 .859 .886 r
.79195 .56048 .82003 .58312 .85032 .56429 .82246 .53725 Metetra
.813 .833 .865 r
.82246 .53725 .85032 .56429 .88065 .54436 .85292 .51246 Metetra
.809 .805 .847 r
.85292 .51246 .88065 .54436 .91103 .52381 .88337 .48685 Metetra
.219 .532 .922 r
.43058 .58756 .4632 .62183 .49166 .62784 .45913 .59731 Metetra
.203 .551 .932 r
.45913 .59731 .49166 .62784 .52051 .63313 .48813 .60621 Metetra
.22 .59 .947 r
.48813 .60621 .52051 .63313 .54974 .637 .51758 .61335 Metetra
.276 .649 .967 r
.51758 .61335 .54974 .637 .57933 .63873 .54746 .61781 Metetra
.365 .72 .988 r
.54746 .61781 .57933 .63873 .60923 .63772 .57771 .61881 Metetra
.473 .788 .999 r
.57771 .61881 .60923 .63772 .6394 .63351 .60826 .61579 Metetra
.58 .841 .994 r
.60826 .61579 .6394 .63351 .66976 .62581 .63905 .60834 Metetra
.672 .872 .974 r
.63905 .60834 .66976 .62581 .70026 .61447 .66997 .59627 Metetra
.74 .882 .945 r
.66997 .59627 .70026 .61447 .73082 .5996 .70095 .57974 Metetra
.786 .877 .913 r
.70095 .57974 .73082 .5996 .7614 .58146 .73191 .55908 Metetra
.815 .863 .884 r
.73191 .55908 .7614 .58146 .79195 .56048 .76281 .53484 Metetra
.829 .845 .859 r
.76281 .53484 .79195 .56048 .82246 .53725 .79361 .50778 Metetra
.833 .824 .84 r
.79361 .50778 .82246 .53725 .85292 .51246 .82431 .47881 Metetra
.83 .803 .825 r
.82431 .47881 .85292 .51246 .88337 .48685 .85493 .44884 Metetra
.109 .465 .89 r
.39706 .55236 .43058 .58756 .45913 .59731 .42567 .56493 Metetra
.108 .485 .899 r
.42567 .56493 .45913 .59731 .48813 .60621 .45479 .57654 Metetra
.15 .533 .921 r
.45479 .57654 .48813 .60621 .51758 .61335 .48441 .58613 Metetra
.235 .604 .952 r
.48441 .58613 .51758 .61335 .54746 .61781 .51453 .59264 Metetra
.352 .686 .98 r
.51453 .59264 .54746 .61781 .57771 .61881 .54507 .59515 Metetra
.479 .76 .992 r
.54507 .59515 .57771 .61881 .60826 .61579 .57598 .59297 Metetra
.595 .814 .983 r
.57598 .59297 .60826 .61579 .63905 .60834 .60715 .58564 Metetra
.689 .843 .957 r
.60715 .58564 .63905 .60834 .66997 .59627 .63849 .57294 Metetra
.754 .853 .924 r
.63849 .57294 .66997 .59627 .70095 .57974 .66989 .55504 Metetra
.797 .85 .89 r
.66989 .55504 .70095 .57974 .73191 .55908 .70128 .53235 Metetra
.824 .841 .861 r
.70128 .53235 .73191 .55908 .76281 .53484 .73258 .50551 Metetra
.838 .828 .838 r
.73258 .50551 .76281 .53484 .79361 .50778 .76375 .47542 Metetra
.844 .814 .82 r
.76375 .47542 .79361 .50778 .82431 .47881 .79477 .44314 Metetra
.843 .799 .809 r
.79477 .44314 .82431 .47881 .85493 .44884 .82567 .40974 Metetra
.037 .417 .863 r
.36263 .5162 .39706 .55236 .42567 .56493 .39128 .53047 Metetra
.057 .444 .877 r
.39128 .53047 .42567 .56493 .45479 .57654 .42048 .54374 Metetra
.122 .499 .906 r
.42048 .54374 .45479 .57654 .48441 .58613 .45025 .55483 Metetra
.229 .576 .942 r
.45025 .55483 .48441 .58613 .51453 .59264 .48056 .56256 Metetra
.361 .66 .97 r
.48056 .56256 .51453 .59264 .54507 .59515 .51135 .56594 Metetra
.494 .732 .978 r
.51135 .56594 .54507 .59515 .57598 .59297 .54257 .5642 Metetra
.608 .781 .964 r
.54257 .5642 .57598 .59297 .60715 .58564 .5741 .55685 Metetra
.696 .809 .935 r
.5741 .55685 .60715 .58564 .63849 .57294 .60584 .54362 Metetra
.757 .82 .902 r
.60584 .54362 .63849 .57294 .66989 .55504 .63767 .52472 Metetra
.798 .821 .87 r
.63767 .52472 .66989 .55504 .70128 .53235 .6695 .50059 Metetra
.824 .817 .843 r
.6695 .50059 .70128 .53235 .73258 .50551 .70124 .47194 Metetra
.839 .81 .822 r
.70124 .47194 .73258 .50551 .76375 .47542 .73284 .43977 Metetra
.847 .802 .807 r
.73284 .43977 .76375 .47542 .79477 .44314 .76428 .40523 Metetra
.848 .794 .798 r
.76428 .40523 .79477 .44314 .82567 .40974 .79557 .36951 Metetra
.011 .4 .852 r
.32723 .47902 .36263 .5162 .39128 .53047 .35594 .49379 Metetra
.052 .432 .871 r
.35594 .49379 .39128 .53047 .42048 .54374 .38523 .50753 Metetra
.136 .491 .904 r
.38523 .50753 .42048 .54374 .45025 .55483 .41512 .51903 Metetra
.255 .567 .937 r
.41512 .51903 .45025 .55483 .48056 .56256 .44559 .52707 Metetra
.388 .643 .958 r
.44559 .52707 .48056 .56256 .51135 .56594 .47661 .53061 Metetra
.513 .705 .957 r
.47661 .53061 .51135 .56594 .54257 .5642 .5081 .52887 Metetra
.617 .748 .939 r
.5081 .52887 .54257 .5642 .5741 .55685 .53995 .52131 Metetra
.696 .774 .911 r
.53995 .52131 .5741 .55685 .60584 .54362 .57206 .50769 Metetra
.752 .787 .881 r
.57206 .50769 .60584 .54362 .63767 .52472 .60431 .48819 Metetra
.791 .792 .853 r
.60431 .48819 .63767 .52472 .6695 .50059 .63659 .4633 Metetra
.817 .794 .83 r
.63659 .4633 .6695 .50059 .70124 .47194 .6688 .43374 Metetra
.834 .793 .812 r
.6688 .43374 .70124 .47194 .73284 .43977 .70088 .40055 Metetra
.844 .791 .8 r
.70088 .40055 .73284 .43977 .76428 .40523 .7328 .36492 Metetra
.848 .788 .793 r
.7328 .36492 .76428 .40523 .79557 .36951 .76458 .32809 Metetra
.037 .417 .863 r
.29083 .44079 .32723 .47902 .35594 .49379 .31964 .45478 Metetra
.094 .451 .883 r
.31964 .45478 .35594 .49379 .38523 .50753 .34904 .46774 Metetra
.187 .506 .91 r
.34904 .46774 .38523 .50753 .41512 .51903 .37906 .47851 Metetra
.304 .571 .933 r
.37906 .47851 .41512 .51903 .44559 .52707 .4097 .48587 Metetra
.426 .632 .941 r
.4097 .48587 .44559 .52707 .47661 .53061 .44092 .48881 Metetra
.534 .682 .933 r
.44092 .48881 .47661 .53061 .5081 .52887 .47264 .48657 Metetra
.623 .717 .913 r
.47264 .48657 .5081 .52887 .53995 .52131 .50479 .47864 Metetra
.692 .74 .888 r
.50479 .47864 .53995 .52131 .57206 .50769 .53724 .46475 Metetra
.742 .755 .863 r
.53724 .46475 .57206 .50769 .60431 .48819 .56988 .44511 Metetra
.779 .764 .84 r
.56988 .44511 .60431 .48819 .63659 .4633 .60259 .42016 Metetra
.805 .771 .821 r
.60259 .42016 .63659 .4633 .6688 .43374 .63527 .39065 Metetra
.824 .775 .807 r
.63527 .39065 .6688 .43374 .70088 .40055 .66787 .35756 Metetra
.836 .779 .798 r
.66787 .35756 .70088 .40055 .7328 .36492 .70033 .32209 Metetra
.842 .782 .794 r
.70033 .32209 .7328 .36492 .76458 .32809 .73265 .28543 Metetra
.109 .465 .89 r
.25338 .40146 .29083 .44079 .31964 .45478 .28237 .4134 Metetra
.174 .493 .904 r
.28237 .4134 .31964 .45478 .34904 .46774 .31194 .42437 Metetra
.264 .536 .919 r
.31194 .42437 .34904 .46774 .37906 .47851 .34212 .43327 Metetra
.367 .583 .926 r
.34212 .43327 .37906 .47851 .4097 .48587 .37293 .43899 Metetra
.467 .627 .922 r
.37293 .43899 .4097 .48587 .44092 .48881 .40435 .4406 Metetra
.555 .663 .908 r
.40435 .4406 .44092 .48881 .47264 .48657 .43629 .4374 Metetra
.627 .69 .889 r
.43629 .4374 .47264 .48657 .50479 .47864 .4687 .4289 Metetra
.685 .711 .868 r
.4687 .4289 .50479 .47864 .53724 .46475 .50145 .41488 Metetra
.729 .726 .848 r
.50145 .41488 .53724 .46475 .56988 .44511 .53444 .39551 Metetra
.763 .739 .83 r
.53444 .39551 .56988 .44511 .60259 .42016 .56756 .37123 Metetra
.789 .749 .816 r
.56756 .37123 .60259 .42016 .63527 .39065 .60071 .34269 Metetra
.809 .759 .806 r
.60071 .34269 .63527 .39065 .66787 .35756 .63382 .31082 Metetra
.823 .767 .8 r
.63382 .31082 .66787 .35756 .70033 .32209 .66684 .27671 Metetra
.832 .776 .799 r
.66684 .27671 .70033 .32209 .73265 .28543 .69976 .24147 Metetra
.219 .532 .922 r
.21484 .36098 .25338 .40146 .28237 .4134 .2441 .36969 Metetra
.28 .549 .924 r
.2441 .36969 .28237 .4134 .31194 .42437 .27392 .37752 Metetra
.355 .573 .922 r
.27392 .37752 .31194 .42437 .34212 .43327 .30434 .3835 Metetra
.434 .6 .915 r
.30434 .3835 .34212 .43327 .37293 .43899 .33536 .38669 Metetra
.509 .626 .902 r
.33536 .38669 .37293 .43899 .40435 .4406 .36698 .38628 Metetra
.575 .649 .886 r
.36698 .38628 .40435 .4406 .43629 .4374 .39913 .38167 Metetra
.631 .668 .868 r
.39913 .38167 .43629 .4374 .4687 .4289 .43177 .37244 Metetra
.677 .686 .851 r
.43177 .37244 .4687 .4289 .50145 .41488 .46478 .35841 Metetra
.714 .701 .836 r
.46478 .35841 .50145 .41488 .53444 .39551 .49808 .33972 Metetra
.745 .715 .824 r
.49808 .33972 .53444 .39551 .56756 .37123 .53157 .31674 Metetra
.77 .728 .815 r
.53157 .31674 .56756 .37123 .60071 .34269 .56514 .29003 Metetra
.789 .742 .809 r
.56514 .29003 .60071 .34269 .63382 .31082 .59874 .26041 Metetra
.804 .755 .807 r
.59874 .26041 .63382 .31082 .66684 .27671 .63232 .22879 Metetra
.815 .769 .809 r
.63232 .22879 .66684 .27671 .69976 .24147 .66586 .19616 Metetra
.349 .605 .944 r
.17516 .3193 .21484 .36098 .2441 .36969 .20483 .32373 Metetra
.395 .605 .932 r
.20483 .32373 .2441 .36969 .27392 .37752 .235 .3274 Metetra
.447 .61 .917 r
.235 .3274 .27392 .37752 .30434 .3835 .26573 .32955 Metetra
.5 .618 .9 r
.26573 .32955 .30434 .3835 .33536 .38669 .29702 .32943 Metetra
.55 .629 .883 r
.29702 .32943 .33536 .38669 .36698 .38628 .32887 .3264 Metetra
.594 .64 .866 r
.32887 .3264 .36698 .38628 .39913 .38167 .36124 .32 Metetra
.634 .652 .85 r
.36124 .32 .39913 .38167 .43177 .37244 .39408 .3099 Metetra
.668 .665 .838 r
.39408 .3099 .43177 .37244 .46478 .35841 .42732 .29595 Metetra
.698 .679 .827 r
.42732 .29595 .46478 .35841 .49808 .33972 .46087 .27828 Metetra
.724 .693 .82 r
.46087 .27828 .49808 .33972 .53157 .31674 .49466 .25716 Metetra
.746 .708 .816 r
.49466 .25716 .53157 .31674 .56514 .29003 .52861 .23304 Metetra
.765 .724 .815 r
.52861 .23304 .56514 .29003 .59874 .26041 .56266 .20654 Metetra
.78 .742 .818 r
.56266 .20654 .59874 .26041 .63232 .22879 .59676 .17842 Metetra
.792 .76 .824 r
.59676 .17842 .63232 .22879 .66586 .19616 .63089 .14942 Metetra
.476 .667 .947 r
.13429 .27638 .17516 .3193 .20483 .32373 .1645 .27566 Metetra
.502 .652 .926 r
.1645 .27566 .20483 .32373 .235 .3274 .19516 .27435 Metetra
.53 .641 .904 r
.19516 .27435 .235 .3274 .26573 .32955 .22629 .27194 Metetra
.559 .635 .883 r
.22629 .27194 .26573 .32955 .29702 .32943 .25793 .26789 Metetra
.587 .634 .865 r
.25793 .26789 .29702 .32943 .32887 .3264 .29005 .26179 Metetra
.613 .636 .849 r
.29005 .26179 .32887 .3264 .36124 .32 .32265 .2533 Metetra
.637 .641 .837 r
.32265 .2533 .36124 .32 .39408 .3099 .35569 .24222 Metetra
.66 .649 .828 r
.35569 .24222 .39408 .3099 .42732 .29595 .38911 .22843 Metetra
.681 .66 .822 r
.38911 .22843 .42732 .29595 .46087 .27828 .42287 .21203 Metetra
.7 .673 .82 r
.42287 .21203 .46087 .27828 .49466 .25716 .4569 .1932 Metetra
.718 .689 .821 r
.4569 .1932 .49466 .25716 .52861 .23304 .49115 .17224 Metetra
.734 .707 .825 r
.49115 .17224 .52861 .23304 .56266 .20654 .52557 .14957 Metetra
.748 .726 .832 r
.52557 .14957 .56266 .20654 .59676 .17842 .56013 .12572 Metetra
.76 .748 .842 r
.56013 .12572 .59676 .17842 .63089 .14942 .59481 .1012 Metetra
.584 .711 .931 r
.09217 .23214 .13429 .27638 .1645 .27566 .12308 .22566 Metetra
.592 .687 .908 r
.12308 .22566 .1645 .27566 .19516 .27435 .15436 .21882 Metetra
.601 .667 .886 r
.15436 .21882 .19516 .27435 .22629 .27194 .18601 .21134 Metetra
.61 .651 .866 r
.18601 .21134 .22629 .27194 .25793 .26789 .21807 .20296 Metetra
.62 .641 .85 r
.21807 .20296 .25793 .26789 .29005 .26179 .25053 .19347 Metetra
.631 .636 .837 r
.25053 .19347 .29005 .26179 .32265 .2533 .28338 .1827 Metetra
.641 .634 .828 r
.28338 .1827 .32265 .2533 .35569 .24222 .3166 .17055 Metetra
.652 .638 .823 r
.3166 .17055 .35569 .24222 .38911 .22843 .35018 .15697 Metetra
.664 .645 .821 r
.35018 .15697 .38911 .22843 .42287 .21203 .38409 .142 Metetra
.675 .655 .823 r
.38409 .142 .42287 .21203 .4569 .1932 .41829 .12572 Metetra
.687 .67 .828 r
.41829 .12572 .4569 .1932 .49115 .17224 .45276 .10829 Metetra
.698 .687 .836 r
.45276 .10829 .49115 .17224 .52557 .14957 .48747 .08993 Metetra
.708 .708 .848 r
.48747 .08993 .52557 .14957 .56013 .12572 .52241 .07088 Metetra
.717 .732 .863 r
.52241 .07088 .56013 .12572 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12308 .22566 .08051 .17394 Metetra
.662 .711 .884 r
.08051 .17394 .12308 .22566 .15436 .21882 .11254 .16124 Metetra
.658 .687 .865 r
.11254 .16124 .15436 .21882 .18601 .21134 .14483 .14843 Metetra
.654 .666 .85 r
.14483 .14843 .18601 .21134 .21807 .20296 .1774 .13551 Metetra
.65 .651 .837 r
.1774 .13551 .21807 .20296 .25053 .19347 .21025 .12249 Metetra
.648 .639 .828 r
.21025 .12249 .25053 .19347 .28338 .1827 .24339 .10934 Metetra
.646 .633 .822 r
.24339 .10934 .28338 .1827 .3166 .17055 .27681 .09609 Metetra
.645 .63 .821 r
.27681 .09609 .3166 .17055 .35018 .15697 .31052 .08272 Metetra
.646 .633 .822 r
.31052 .08272 .35018 .15697 .38409 .142 .34452 .06923 Metetra
.648 .639 .828 r
.34452 .06923 .38409 .142 .41829 .12572 .37882 .05563 Metetra
.65 .651 .837 r
.37882 .05563 .41829 .12572 .45276 .10829 .41342 .04191 Metetra
.654 .666 .85 r
.41342 .04191 .45276 .10829 .48747 .08993 .44833 .02806 Metetra
.658 .687 .865 r
.44833 .02806 .48747 .08993 .52241 .07088 .48355 .01409 Metetra
.662 .711 .884 r
.48355 .01409 .52241 .07088 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY]^;o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVf
hP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY]^800ol0003oZKKRo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY]^800ol0003oZKKRojVfhP03ojVfhP04o`000?nY]^;oZKKRo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVfhP04o`000?nY]^;oZKKRo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onX[mgo0000ojVfhP09
ojVfhP05o`000?nY]^;oZKKRojVfh_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojR_gOl0003oZ:oM00;oZ:oM
00?o0000ojVfh_nY]^801onY]^800ol0003oZKKRojVfhP02ojVfhP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nX[md00ol0003oZKKRojVfhP06ojVfhP03o`000?nY]^;oZKKR00?oZKKR00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojR_g@03o`000?nY]^;oZKKR00KoZKKR00?o0000
ojVfh_nY]^800onY]^800ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ:oM00?o0000ojVf
h_nY]^801OnY]^800ol0003oZKKRojVfhP04ojVfhP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnWZ]T00ol0003oZ:oMojR_g@0:ojR_g@03o`000?nY]^;oZKKR00CoZKKR00?o0000ojVfh_nY
]^801OnY]^800ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoYj[I00?o0000ojR_
gOnX[md02_nX[md00ol0003oZKKRojVfhP03ojVfhP03o`000?nY]^;oZKKR00KoZKKR00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onWZ]Wo0000ojNZf@09ojNZf@03o`000?nX[mgo
Z:oM00[oZ:oM00?o0000ojVfh_nY]^800onY]^800ol0003oZKKRojVfhP06ojVfhP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnVY]Ko0000ojNZfOnWZ]Wo000000[oYj[I00?o0000ojR_gOnX[md0
2_nX[md00ol0003oZKKRojVfhP02ojVfhP03o`000?nY]^;oZKKR00OoZKKR00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoYZKF00?o0000ojNZfOnWZ]T02_nWZ]T00ol0003oZ:oMojR_g@0;ojR_g@05
o`000?nY]^;oZKKRojVfh_l000002_nY]^800ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oYZKF
o`000?nVY]H01?nVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00[oZ:oM00Go0000
ojVfh_nY]^;oZKKRo`00000:ojVfhP;o0000Toooool006gooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;ojJVeP03o`000?nWZ]WoYj[I00_oYj[I00?o
0000ojR_gOnX[md02_nX[md01?l0003oZKKRojVfh_l00008ojVfhP;o000000?o]k_Lo`000?ooool0
T_ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo
1?l0000=ojJVeP03o`000?nWZ]WoYj[I00[oYj[I00?o0000ojR_gOnX[md02onX[md00ol0003oZKKR
o`000006ojVfhP;o00001?ng^m`00ol0003oooooooooo`2@ooooo`00KOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool2o`0000;oYJ?C00?o0000ojFSdol0
00003?nVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00_oZ:oM0_l00005ojVfhP03
o`000?ng^mco]k_L00Go]k_L00?o0000ooooooooool0Soooool008kooooo0ol00006ojFSd`03o`00
0?nVY]KoYZKF00_oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_g@0:ojR_g@;o0000
0onY]^82o`0000Wo]k_L00?o0000ooooooooool0S_ooool008cooooo0ol00009ojFSd`03o`000?nV
Y]KoYZKF00[oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_g@0;ojR_g@04o`000?nY
]^;o0000o`0000_o]k_L0_l0002?ooooo`00ROooool4o`000003ojFSdol0003oYJ?C00SoYJ?C00?o
0000ojJVe_nVY]H02onVY]H00ol0003oYj[IojNZf@0;ojNZf@03o`000?nX[mgoZ:oM00[oZ:oM0_l0
000>okNkg003o`000?oooooooooo08gooooo001@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Pooooo`Co000000?oYJ;Bo`000?nUXm<02onU
Xm<00ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00coYj[I00?o0000ojR_gOnX[md01onX
[md4o`0000oo]k_L00?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001OnUX]800ol0003oYJ?CojFS
d`0:ojFSd`03o`000?nVY]KoYZKF00[oYZKF00?o0000ojNZfOnWZ]T02onWZ]T00ol0003oZ:oMojR_
g@06ojR_g@06o`000?ne]MWo]KGIo`000?ne]MWo00003ong^m`00ol0003oooooooooo`2;ooooo`00
D?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oYJ;Bo`000?nU
X]801OnUX]800ol0003oYJ?CojFSd`0:ojFSd`03o`000?nVY]KoYZKF00_oYZKF00?o0000ojNZfOnW
Z]T02onWZ]T00ol0003oZ:oMojR_g@03ojR_g@;o00000one]MT01?l0003o]KGIokFefOl0000>okNk
g0;o0000S?ooool0053ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0001_ooooo0ol00005ojFRdP03o`000?nUX];oYJ;B00CoYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00_oYj[I00Co0000ojR_gOnX[mgoZ:oM0_l0
0005okFef@04o`000?ne]MWo]KGIo`0000oo]k_L0_l0002;ooooo`00D?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojFQd_l0003oYJ;B00_o
YJ;B00?o0000ojFSdonUXm<02_nUXm<00ol0003oYZKFojJVeP0;ojJVeP03o`000?nWZ]WoYj[I00_o
Yj[I00?o0000ojR_gOl000001one]MT01Ol0003o]KGIokFefOne]MWo000000oo]k_L00?o0000oooo
ooooool0ROooool0053ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co0000
01Kooooo0ol00002ojFQdP04o`000?nUXM;oYJ7Bo`0000coYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00_oYj[I0_l00008okFef@03o`000?ne]MWo
]KGI00;o]KGI00?o0000okNkg?ng^m`03Ong^m`00ol0003oooooooooo`28ooooo`00D?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000005?ooool3o`0000OoYJ7B00?o0000
ojFRd_nUX]802onUX]800ol0003oYJ?CojFSd`09ojFSd`03o`000?nVY]KoYZKF00_oYZKF00?o0000
ojNZfOnWZ]T02?nWZ]T2o`000003ok:_e_l0003o]KGI00Oo]KGI00?o0000okFefOne]MT00one]MT0
0ol0003o]k_LokNkg00<okNkg0;o0000ROooool0053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000
ojFSdonUXm<02_nUXm<00ol0003oYZKFojJVeP0:ojJVeP03o`000?nWZ]WoYj[I00KoYj[I0_l00004
ok:_eP03o`000?ne]MWo]KGI00Go]KGI00?o0000okFefOne]MT00one]MT00ol0003o]k_LokNkg00=
okNkg0;o0000R?ooool007?ooooo0ol000000onUX];o0000o`00000:ojFQdP03o`000?nUX];oYJ;B
00_oYJ;B00?o0000ojFSdonUXm<02OnUXm<00ol0003oYZKFojJVeP0;ojJVeP03o`000?nWZ]WoYj[I
00CoYj[I00?o0000ok:_e_nb[mH01Onb[mH00ol0003o]KGIokFef@04okFef@03o`000?ne]MWo]KGI
00Co]KGI00?o0000okNkg?ng^m`03Ong^m`2o`0008Oooooo001`ooooo`?o00001OnUX]800ol0003o
YJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<00ol0003o
YZKFojJVeP0;ojJVeP04o`000?nWZ]WoYj[IojNZf@;o00002?nb[mH00ol0003o]KGIokFef@04okFe
f@03o`000?ne]MWo]KGI00Go]KGI00?o0000okNkg?ng^m`02ong^m`00ol0003o`[oGo`000027oooo
o`00K_ooool3o`0000OoYJ;B00?o0000ojFQd_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFRdP03
o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojJVe_nVY]H02onVY]H01?l0003oYj[Io`000?l0000;ok:_
eP03o`000?ne]MWo]KGI00?o]KGI00?o0000okFefOne]MT01One]MT00ol0003o]k_LokNkg00:okNk
g003o`000?o2_mOo`[oG00;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0002?ooooo0ol00002ojFRdP03o`000?nUX];oYJ;B00KoYJ;B00?o0000ojFQ
d_nUXM802OnUXM800ol0003oYJ;BojFRdP0:ojFRdP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojJV
e_nVY]H02_nVY]H2o`0000go/ZoF00?o0000okFefOne]MT00one]MT00ol0003o]KGIokFef@06okFe
f@03o`000?ng^mco]k_L00Oo]k_L0_l00004ol:oe`;o0000QOooool003?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol00000
0onUXm?o0000ojFRdP0:ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]802onUX]80
0ol0003oYJ?CojFSd`0:ojFSd`03o`000?nVY]KoYZKF00OoYZKF0_l000000on_Zm?o0000ok:_eP0=
ok:_eP03o`000?ne]MWo]KGI00;o]KGI00?o0000okFefOne]MT01one]MT00ol0003o]k_LokNkg005
okNkg003o`000?o2_mOo`[oG00Go`[oG0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYZKFojJVeP04ojJVeP?o00001?n_Zm<00ol0003o/ZoFok:_eP0<ok:_eP05o`000?ne]MWo
]KGIokFefOl000002_ne]MT00ol0003o]k_LokNkg002okNkg0;o00002Oo2_mL00ol0003ooooooooo
o`22ooooo`00<oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06ooo
ool3o`0000CoYJ?C00Go0000ojFSdonUXm?oYJ?Co`00000;ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B
00?o0000ojFRd_nUX]802onUX]800ol0003oYJ?CojFSd`0:ojFSd`04o`000?nVY]KoYZKFojJVeP;o
00002?n_Zm<00ol0003o/ZoFok:_eP0;ok:_eP05o`000?ne]MWo]KGIokFefOl000002_ne]MT01Ol0
003o]k_LokNkg?ng^mco000000_o`[oG0_l00023ooooo`00<oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool06?ooool3o`0000_oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP09ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<02_nUXm<0
1?l0003oYZKFo`000?l0000:ojn[d`03o`000?nb[mKo/ZoF00co/ZoF00Co0000okFefOne]MWo0000
2one]MT00ol0003o]k_Lo`00000=ol:oe`;o0000P_ooool003?ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo01Cooooo0ol000000onVY]Ko0000ojFSd`0;ojFSd`03o`00
0?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802_nUXM800ol0003oYJ;BojFRdP0:ojFRdP03o`00
0?nUXm?oYJ?C00WoYJ?C0_l0000=ojn[d`03o`000?nb[mKo/ZoF00_o/ZoF00Co0000okFefOne]MWo
00002one]MT2o`0000oo`[oG0_l00021ooooo`00<oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00001?nVY]H00ol0003oYJ?CojFSd`0:ojFS
d`03o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFR
dP03o`000?nUXm?oYJ?C00KoYJ?C0_l000000on/Ym;o0000ojn[d`0<ojn[d`03o`000?nb[mKo/ZoF
00co/ZoF00?o0000okFefOl000002_ne]MT00ol0003o_kWDo`00000@ol:oe`03o`000?oooooooooo
07oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<017ooooo0ol00007ojJVeP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP0:ojFQdP03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFSdonUXm<01?nUXm<2
o`0000Co[:OB00?o0000ojn[don_Zm<02on_Zm<00ol0003o/ZoFok:_eP0<ok:_eP;o00002?ne]MT2
o`0000?o_kWD00?o0000ol:oeoo2_mL03Oo2_mL2o`00083ooooo001Gooooo`?o000000?oYZKFo`00
0?nVY]H01onVY]H00ol0003oYJ?CojFSd`0:ojFSd`03o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQ
d_nUXM802OnUXM800ol0003oYJ;BojFRdP0;ojFRdP04o`000?nUXm?oYJ?CojFSd`;o00001_n/Ym80
0ol0003o[j_Cojn[d`0<ojn[d`03o`000?nb[mKo/ZoF00_o/ZoF0_l00006okFef@;o00001_no^M@0
0ol0003o`[oGol:oe`0=ol:oe`;o0000Ooooool005Cooooo0ol000000onWZ]Wo0000ojJVeP0;ojJV
eP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]802_nUX]800ol0003oYJ7BojFQdP09ojFQ
dP03o`000?nUX];oYJ;B00[oYJ;B00Co0000ojFSdol0003o00002On/Ym800ol0003o[j_Cojn[d`0;
ojn[d`03o`000?nb[mKo/ZoF00co/ZoF00?o0000okFefOne]MT00one]MT00ol0003o_kWDoknie006
oknie003o`000?o2_mOo`[oG00ko`[oG00?o0000ooooooooool0OOooool005;ooooo0ol00004ojNZ
f@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<00ol0003oYJ;BojFRdP09ojFR
dP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]802_nUX]82o`0000co[:OB00?o0000ojn[
don_Zm<02on_Zm<00ol0003o/ZoFok:_eP0;ok:_eP04o`000?ne]MWo]KGIokFef@;o00002_no^M@0
0ol0003o`[oGol:oe`0>ol:oe`03o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h08oooool4o`000003ojNZfOl0003oYj[I00CoYj[I00?o0000ojJVe_nVY]H02OnVY]H0
0ol0003oYJ?CojFSd`09ojFSd`03o`000?nUX];oYJ;B00[oYJ;B00?o0000ojFQd_nUXM802OnUXM80
0ol0003oYJ;BojFRdP07ojFRdP;o000000?oZJGBo`000?n/Ym802on/Ym800ol0003o[j_Cojn[d`0<
ojn[d`03o`000?nb[mKo/ZoF00[o/ZoF0_l000000one]MWo0000oknie00<oknie003o`000?o2_mOo
`[oG00go`[oG0_l0001mooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg027ooooo0ol0000:
ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<00ol0003oYJ;BojFRdP09
ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00?o0000ojFRd_nUX]801?nUX]83o`0000CoZJGB00?o0000
ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`0;ojn[d`03o`000?nb[mKo/ZoF00[o/ZoF0ol0000>
oknie003o`000?o2_mOo`[oG00ko`[oG0_l0001looooo`009oooool01Ol@413ooooooooooooooooo
410@01kooooo1Ol0000<ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonUXm<02_nUXm<0
0ol0003oYJ;BojFRdP09ojFRdP03o`000?nUXM;oYJ7B00WoYJ7B00Co0000ojFRd_nUX];oYJ;B0_l0
0007ojVUdP03o`000?n/Ym;o[:OB00[o[:OB00?o0000ojn[don_Zm<03?n_Zm<00ol0003o/ZoFok:_
eP09ok:_eP03o`000?nk]=?o000000oo_kWD00?o0000ol:oeoo2_mL03?o2_mL00ol0003ob/;Bo`00
001looooo`009oooool01Ol0003ooooooooooooooooo000001cooooo0ol00002ojR_g@03o`000?nX
[mgo000000_oYj[I00?o0000ojJVe_nVY]H02_nVY]H00ol0003oYJ?CojFSd`09ojFSd`03o`000?nU
X];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802OnUXM801?l0003oYJ;Bo`000?l0000:ojVUdP03o`00
0?n/Ym;o[:OB00[o[:OB00?o0000ojn[don_Zm<03?n_Zm<00ol0003o/ZoFok:_eP06ok:_eP?o0000
0_nk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00[o`[oG00Go0000ol[2d_o:`];o
b/;Bo`00001kooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005ojR_g@03
o`000?nX[mgo000000_oYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`0:ojFSd`03
o`000?nUX];oYJ;B00WoYJ;B00?o0000ojFQd_nUXM802?nUXM82o`0000coZJGB00?o0000ojbWd_n/
Ym802_n/Ym800ol0003o[j_Cojn[d`0<ojn[d`03o`000?nb[mKo/ZoF00Go/ZoF00Co0000ok^ddonk
]=?o00000onk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00So`[oG00?o0000ol[2
d_o:`]800_o:`]82o`0007[ooooo000Wooooo`05oa0@4?ooooooooooooooool@41005oooool3o`00
00[oZ:oM00?o0000ojNZfOnWZ]T02_nWZ]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C
00WoYJ?C00?o0000ojFRd_nUX]802OnUX]800ol0003oYJ7BojFQdP05ojFQdP?o000000?oYZ?Bo`00
0?nYYM803?nYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o[j_C00co[j_C00?o0000ok:_
e_nb[mH00onb[mH01Ol0003o^kCCok^ddonk]=?o000000?o^kCC00?o0000oknie?no^M@03Ono^M@0
0ol0003o`[oGol:oe`06ol:oe`;o00001_o:`]82o`0007Wooooo000Wooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool5o`000003ojR_gOl0003oZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T0
0ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00[oYJ?C00?o0000ojFRd_nUX]802OnUX]80
0ol0003oYJ7BojFQdP02ojFQdP;o00001OnVXm800ol0003oZJGBojVUdP0;ojVUdP03o`000?n/Ym;o
[:OB00[o[:OB00?o0000ojn[don_Zm<02on_Zm<01?l0003o/ZoFok:_e_nb[mH2o`0000Co^kCC00?o
0000ok^ddonk]=<00_nk]=<00ol0003o_kWDoknie00=oknie003o`000?o2_mOo`[oG00Co`[oG00?o
0000ol[2d_o:`]801oo:`]800ol0003oooooooooo`1gooooo`009oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01;ooooo0ol00004ojVfhP03o`000?nX[mgoZ:oM00[oZ:oM00?o0000ojNZfOnWZ]T02OnW
Z]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]802OnU
X]800ol0003oYJ7Bo`000002o`0000OoYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbW
dP0:ojbWdP03o`000?n_Zm?o[j_C00co[j_C00?o0000ok:_e_l000001_nk]=<00ol0003o^kCCok^d
d`03ok^dd`03o`000?no^MCo_kWD00go_kWD00?o0000ol:oeoo2_mL00_o2_mL00ol0003ob/;Bol[2
dP09ol[2dP03o`000?oooooooooo07Kooooo000kooooo`Go00001_nY]^800ol0003oZ:oMojR_g@09
ojR_g@03o`000?nWZ]WoYj[I00[oYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09
ojFSd`03o`000?nUX];oYJ;B00SoYJ;B0_l0000;ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000
ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`0;ojn[d`;o00001onk]=<00ol0003o^kCCok^dd`03
ok^dd`03o`000?no^MCo_kWD00go_kWD00Go0000ol:oeoo2_mOo`[oGo`00000<ol[2dP;o0000Mooo
ool003Wooooo0ol0000;ojVfhP03o`000?nX[mgoZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T0
0ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00WoYJ?C00?o0000ojFRd_nUX]801OnUX]83
o`000003ojBRdol0003oYZ?B00[oYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:
ojbWdP03o`000?n_Zm?o[j_C00[o[j_C00?o0000okN`d_l000001onk]=<00ol0003o^kCCok^dd`04
ok^dd`03o`000?no^MCo_kWD00go_kWD00?o0000ol:oeol000003_o:`]82o`0007Kooooo000goooo
o`Co00003?nY]^800ol0003oZ:oMojR_g@0:ojR_g@03o`000?nWZ]WoYj[I00WoYj[I00?o0000ojJV
e_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09ojFSd`03o`000?nUX];oYJ;B00;oYJ;B0_l00005ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:ojbW
dP03o`000?n_Zm?o[j_C00Oo[j_C0_l00003okN`dP03o`000?nk]=?o^kCC00Co^kCC00?o0000ok^d
donk]=<01Onk]=<00ol0003o_kWDoknie00<oknie0;o00004?o:`]800ol0003oooooooooo`1doooo
o`00=?ooool3o`000005ojZliol0003oZ[cWojZliol000003?nY]^800ol0003oZ:oMojR_g@0:ojR_
g@03o`000?nWZ]WoYj[I00SoYj[I00?o0000ojJVe_nVY]H02OnVY]H00ol0003oYJ?CojFSd`09ojFS
d`03o`000?nUX];o000000;o00001onTX]<00ol0003oYZ?BojJSdP0:ojJSdP03o`000?nYYM;oZJGB
00[oZJGB00?o0000ojbWd_n/Ym802_n/Ym800ol0003o[j_Cojn[d`05ojn[d`;o00001Ong/=800ol0
003o^kCCok^dd`04ok^dd`03o`000?nk]=?o^kCC00Go^kCC00?o0000oknie?no^M@02ono^M@00ol0
003oakgAo`00000Aol[2dP03o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L00ol0003o
ZKKRojVfhP0:ojVfhP03o`000?nX[mgoZ:oM00WoZ:oM00?o0000ojNZfOnWZ]T02OnWZ]T00ol0003o
YZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00OoYJ?C0ol0000;ojBRd`03o`000?nVXm;oYZ?B00Wo
YZ?B00?o0000ojVUd_nYYM802onYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o[j_C00?o
[j_C00?o0000okN`d_ng/=801_ng/=800ol0003o^kCCok^dd`03ok^dd`03o`000?nk]=?o^kCC00Ko
^kCC00?o0000oknie?no^M@02Ono^M@01Ol0003oakgAolNmdOo7_M7o0000013ob/;B0_l0001doooo
o`00<Oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]^;oZKKR00WoZKKR00?o0000ojR_gOnX
[md02_nX[md00ol0003oYj[IojNZf@09ojNZf@03o`000?nVY]KoYZKF00WoYZKF00?o0000ojFSdonU
Xm<00onUXm<3o`0000;oXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP0:ojJSdP03
o`000?nYYM;oZJGB00[oZJGB00?o0000ojbWd_n/Ym802on/Ym800ol0003o[j_Cojn[d`02o`0000[o
]k3B00?o0000ok^ddonk]=<00_nk]=<00ol0003o^kCCok^dd`07ok^dd`03o`000?no^MCo_kWD00Oo
_kWD00?o0000olNmdOo7_M400oo7_M400ol0003ob/;Bol[2dP0>ol[2dP03o`000?oooooooooo07;o
oooo000aooooo`;o00002onZ_>L00ol0003oZKKRojVfhP09ojVfhP03o`000?nX[mgoZ:oM00[oZ:oM
00?o0000ojNZfOnWZ]T02?nWZ]T00ol0003oYZKFojJVeP09ojJVeP03o`000?nUXm?oYJ?C00?o0000
1_nQX]H00ol0003oY:;CojBRd`09ojBRd`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM80
2onYYM800ol0003o[:OBojbWdP0:ojbWdP03o`000?n_Zm?o000000co]k3B00?o0000ok^ddonk]=<0
0_nk]=<00ol0003o^kCCok^dd`07ok^dd`03o`000?no^MCo_kWD00Ko_kWD00?o0000olNmdOo7_M40
1?o7_M400ol0003ob/;Bol[2dP0?ol[2dP03o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01oooool2o`0000_oZ[cW00?o0000ojVfh_nY]^802_nY]^800ol0003oZ:oM
ojR_g@09ojR_g@03o`000?nWZ]WoYj[I00WoYj[I00?o0000ojJVe_nVY]H01onVY]H4o`0000WoXJ;F
00?o0000ojBRdonTX]<02_nTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00[oZJGB
00?o0000ojbWd_n/Ym802_n/Ym82o`0000ko]k3B00Go0000ok^ddonk]=?o^kCCo`00000:ok^dd`03
o`000?no^MCo_kWD00Co_kWD00?o0000olNmdOo7_M401_o7_M400ol0003ob/;Bol[2dP0?ol[2dP03
o`000?oooooooooo073ooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00ol0003o
ooooo`00000;ojZli`03o`000?nY]^;oZKKR00[oZKKR00?o0000ojR_gOnX[md02OnX[md00ol0003o
Yj[IojNZf@08ojNZf@03o`000?nVY]KoYZKF00CoYZKF0ol00002oijTf@03o`000?nQX]KoXJ;F00Wo
XJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_o
ZJGB00?o0000ojbWd_n/Ym801on/Ym82o`000003ok>/dOl0003o]k3B00go]k3B00Go0000ok^ddonk
]=?o^kCCo`00000;ok^dd`03o`000?no^MCo_kWD00;o_kWD00?o0000olNmdOo7_M402?o7_M400ol0
003ob/;Bol[2dP0>ol[2dP;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007oooo
o`04o`000?ooooooooooo`0000_oZ[cW00?o0000ojVfh_nY]^802OnY]^800ol0003oZ:oMojR_g@0:
ojR_g@03o`000?nWZ]WoYj[I00SoYj[I00?o0000ojJVe_nVY]H00ol00006oijTf@03o`000?nQX]Ko
XJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`000?nYYM;o
ZJGB00_oZJGB00?o0000ojbWd_n/Ym801On/Ym800ol0003o/jcAok>/d@02ok>/d@03o`000?ng/=;o
]k3B00co]k3B00Co0000ok^ddonk]=?o00002onk]=<01Ol0003o_kWDoknie?no^MCo000000_oakgA
00?o0000ol[2d_o:`]803Oo:`]800ol0003od<C?o`00001aooooo`009Oooool01Ol0003ooooooooo
oooooooo000000Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojVfh_nY]^80
2OnY]^800ol0003oZ:oMojR_g@09ojR_g@03o`000?nWZ]WoYj[I00OoYj[I1?l00009oijTf@03o`00
0?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP09ojJSdP03o`00
0?nYYM;oZJGB00_oZJGB00?o0000ojbWd_n/Ym800on/Ym82o`0000Ko/jcA00?o0000okN`d_ng/=80
3?ng/=800ol0003o^kCCo`00000<ok^dd`03o`000?no^MCo000000goakgA00?o0000ol[2d_o:`]80
2oo:`]801Ol0003od<C?om34coo@a<oo0000073ooooo000Uooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`03ooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojVfh_nY
]^802OnY]^800ol0003oZ:oMojR_g@09ojR_g@04o`000?nWZ]WoYj[IojNZf@Go00000_nLY]d00ol0
003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0
003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000ojbWd_n/Ym800_l00008ok>/
d@03o`000?ng/=;o]k3B00co]k3B00?o0000ok^ddol000003?nk]=<2o`0000ooakgA00?o0000ol[2
d_o:`]802Oo:`]800ol0003od<C?om34c`03om34c`03o`000?oooooooooo06gooooo000Uooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooo`03o`000?nZ_>OoZ[cW
00WoZ[cW00?o0000ojVfh_nY]^802?nY]^800ol0003oZ:oMojR_g@08ojR_g@Go00002?nLY]d00ol0
003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00SoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0
003oYZ?BojJSdP09ojJSdP03o`000?nYYM;oZJGB00_oZJGB00?o0000ojbWd_l000002onc[=400ol0
003o]k3BokN`dP0<okN`dP;o00002onk]=<00ol0003o`kW@o`00000@olNmd@03o`000?o:`];ob/;B
00Oob/;B00?o0000om34coo@a<l01?o@a<l2o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW00?o0000ojVf
h_nY]^802OnY]^800ol0003oZ:oMojR_g@04ojR_g@?o00000_nIZ^800ol0003oW:KMoibVg@09oibV
g@03o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM802_nYYM82o`0000co/jcA00?o0000okN`
d_ng/=803?ng/=82o`0000[o^kCC00Go0000ol>id?o3^M3o`kW@o`00000?olNmd@03o`000?o:`];o
b/;B00Kob/;B00?o0000om34coo@a<l01_o@a<l00ol0003oooooooooo`1/ooooo`009Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003oZ[cWojZli`08
ojZli`03o`000?nY]^;oZKKR00WoZKKR00?o0000ojR_gOnX[md00ol00006oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02OnNY=T00ol0003oXJ;Foj6ReP08oj6ReP03o`000?nTX]?o
Y:;C00WoY:;C00?o0000ojJSd_nVXm802_nVXm800ol0003oZJGBojVUdP07ojVUdP;o000000?o[ZSB
o`000?nc[=403?nc[=400ol0003o]k3BokN`dP0<okN`dP03o`000?nk]=?o^kCC00Ko^kCC0_l00005
ol>id003o`000?o7_M7oakgA00goakgA00?o0000ol[2d_o:`]801?o:`]800ol0003od<C?om34c`08
om34c`03o`000?oooooooooo06_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZl
ionZ_>L02?nZ_>L00ol0003oZKKRojVfhP07ojVfhPCo00002_nIZ^800ol0003oW:KMoibVg@08oibV
g@03o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBR
d`03o`000?nVXm;oYZ?B00WoYZ?B00?o0000ojVUd_nYYM801?nYYM83o`0000Co[ZSB00?o0000ok>/
dOnc[=402onc[=400ol0003o]k3BokN`dP0;okN`dP03o`000?nk]=?o^kCC00Go^kCC00?o0000ol>i
d?o3^M001Oo3^M000ol0003oakgAolNmd@0>olNmd@03o`000?o:`];ob/;B00;ob/;B00?o0000om34
coo@a<l02_o@a<l00ol0003oooooooooo`1Zooooo`00<?ooool00ol0003oooooooooo`08ooooo`03
o`000?nZ_>OoZ[cW00SoZ[cW00Co0000ojVfh_nY]^;oZKKR1Ol00002oiN_j003o`000?nIZ^;oVJ[R
00WoVJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F
00WoXJ;F00?o0000ojBRdonTX]<02?nTX]<00ol0003oYZ?BojJSdP0:ojJSdP04o`000?nYYM;oZJGB
ojVUdP;o00001on^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00_o]k3B0_l00004
ok^dd`;o00002Oo3^M000ol0003oakgAolNmd@0=olNmd@05o`000?o:`];ob/;Bol[2d_l000003Oo@
a<l00ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000ojZlionZ_>L01_nZ_>L5
o`0000SoUjoX00?o0000oiVZh_nIZ^802OnIZ^800ol0003oW:KMoibVg@08oibVg@03o`000?nNY=Wo
WZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`09ojBRd`03o`000?nVXm;o
YZ?B00WoYZ?B00Co0000ojVUd_l0003o00002_n^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng
/=;o]k3B00[o]k3B00?o0000okN`d_l000000_nk]=<00ol0003o`kW@ol>id00:ol>id003o`000?o7
_M7oakgA00goakgA00?o0000ol[2d_l000003oo@a<l00ol0003oooooooooo`1Yooooo`00<?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?nZ_>OoZ[cW00Go00000_nE]^h00ol0003oUjoXoiN_j009
oiN_j003o`000?nIZ^;oVJ[R00SoVJ[R00?o0000oibVgOnLY]d02OnLY]d00ol0003oWZCIoijTf@08
oijTf@03o`000?nQX]KoXJ;F00WoXJ;F00?o0000ojBRdonTX]<02OnTX]<00ol0003oYZ?BojJSdP08
ojJSdP;o00003?n^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00[o]k3B00Go0000
okN`d_l0003o^kCCo`00000=ol>id003o`000?o7_M7oakgA00koakgA00?o0000om34coo@a<l03oo@
a<l00ol0003oooooooooo`1Xooooo`00;oooool00ol0003oooooooooo`0<ooooo`;o00002?nE]^h0
0ol0003oUjoXoiN_j009oiN_j003o`000?nIZ^;oVJ[R00SoVJ[R00?o0000oibVgOnLY]d02?nLY]d0
0ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F00SoXJ;F00?o0000ojBRdonTX]<02OnTX]<0
0ol0003oYZ?BojJSdP05ojJSdP?o000000?oZ:KCo`000?n^Z=803?n^Z=800ol0003o/jcAok>/d@0;
ok>/d@03o`000?ng/=;o]k3B00Wo]k3B00Co0000okN`d_l0003o00003oo3^M000ol0003oakgAolNm
d@0<olNmd@;o00004_o@a<l00ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0=
ooooo`03o`000?nE]^koUKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP09
oiVZhP03o`000?nLY]goW:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP09
oj6ReP03o`000?nTX]?oY:;C00WoY:;C00?o0000ojJSd_nVXm800_nVXm82o`0000GoZ:KC00?o0000
ojjXd_n^Z=802on^Z=800ol0003o/jcAok>/d@0;ok>/d@03o`000?ng/=;o]k3B00So]k3B0_l00000
0onn]M3o0000ol>id00?ol>id003o`000?o7_M7oakgA00[oakgA00Co0000olg1c_o=`Lko00004Oo@
a<l00ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0>ooooo`03o`000?nE]^ko
UKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP08oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02OnNY=T00ol0003oXJ;Foj6ReP08oj6ReP03o`000?nTX]?o
Y:;C00WoY:;C00?o0000ojJSd_l000000_l00008ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000
ok>/dOnc[=402onc[=400ol0003o]k3BokN`dP08okN`dP05o`000?nn]M3o_[G@okjed?l000003oo3
^M000ol0003oakgAolNmd@09olNmd@03o`000?o=`LkocL7>00;ocL7>00?o0000om34coo@a<l03oo@
a<l00ol0003oooooooooo`1Vooooo`00;oooool00ol0003oooooooooo`0?ooooo`03o`000?nE]^ko
UKK^00OoUKK^00?o0000oiN_j?nG[nP02?nG[nP00ol0003oVJ[RoiVZhP08oiVZhP03o`000?nLY]go
W:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP09oj6ReP03o`000?nTX]?o
Y:;C00OoY:;C0ol0000;ojRVd`03o`000?n^Z=;o[ZSB00_o[ZSB00?o0000ok>/dOnc[=402onc[=40
0ol0003o]k3BokN`dP06okN`dP;o00001?nn]M000ol0003o`kW@ol>id00=ol>id003o`000?o7_M7o
akgA00OoakgA00?o0000olg1c_o=`Lh01?o=`Lh00ol0003od<C?om34c`0?om34c`03o`000?oooooo
oooo06Gooooo000^ooooo`?o00004Oooool00ol0003oUKK^oiFfkP07oiFfkP03o`000?nG[nSoUjoX
00SoUjoX00?o0000oiVZh_nIZ^802?nIZ^800ol0003oW:KMoibVg@08oibVg@03o`000?nNY=WoWZCI
00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`03ojBRd`?o00000_nSY=H00ol0
003oZ:KCojRVd`0:ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000ok>/dOnc[=402onc[=400ol0
003o]k3BokN`dP04okN`dP;o000000?o_[G@o`000?nn]M000onn]M000ol0003o`kW@ol>id00=ol>i
d003o`000?o7_M7oakgA00KoakgA00?o0000olg1c_o=`Lh01Oo=`Lh00ol0003od<C?om34c`0?om34
c`;o0000I_ooool002oooooo00?o0000ooooooooool04Oooool00ol0003oUKK^oiFfkP07oiFfkP03
o`000?nG[nSoUjoX00SoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KMoibVg@08oibVg@03
o`000?nNY=WoWZCI00SoWZCI00?o0000oj6Re_nQX]H02OnQX]H00ol0003oY:;CojBRd`03o`0000Ko
XjCF00?o0000ojRVdonXY]<02OnXY]<00ol0003o[ZSBojjXdP0;ojjXdP03o`000?nc[=7o/jcA00_o
/jcA00?o0000okN`d_ng/=800_ng/=801Ol0003o_[G@okjed?nn]M3o000000Go_[G@00?o0000ol>i
d?o3^M003Oo3^M000ol0003oakgAolNmd@04olNmd@03o`000?o=`LkocL7>00OocL7>00?o0000om34
coo@a<l03Oo@a<l00ol0003oe<K<o`00001Vooooo`00;oooool00ol0003oooooooooo`0Booooo`03
o`000?nE]^koUKK^00OoUKK^00?o0000oiN_j?nG[nP01onG[nP00ol0003oVJ[RoiVZhP08oiVZhP03
o`000?nLY]goW:KM00SoW:KM00?o0000oijTfOnNY=T02?nNY=T00ol0003oXJ;Foj6ReP07oj6RePCo
00002OnSY=H00ol0003oZ:KCojRVd`0:ojRVd`03o`000?n^Z=;o[ZSB00[o[ZSB00?o0000ok>/dOnc
[=403?nc[=401?l0003o]k3BokN`d_l00004okjed003o`000?nn]M3o_[G@00Co_[G@00?o0000ol>i
d?o3^M003Oo3^M000ol0003oakgAolNmd@02olNmd@03o`000?o=`LkocL7>00WocL7>00?o0000om34
coo@a<l02oo@a<l01Ol0003oe<K<omC6c?oDa/co000006Gooooo000_ooooo`03o`000?oooooooooo
01?ooooo00?o0000oiFfk_nE]^h01_nE]^h00ol0003oUjoXoiN_j008oiN_j003o`000?nIZ^;oVJ[R
00SoVJ[R00?o0000oibVgOnLY]d01onLY]d00ol0003oWZCIoijTf@09oijTf@03o`000?nQX]KoXJ;F
00?oXJ;F0ol00002oibRf@03o`000?nSY=KoXjCF00WoXjCF00?o0000ojRVdonXY]<02_nXY]<00ol0
003o[ZSBojjXdP0:ojjXdP03o`000?nc[=7o/jcA00_o/jcA00?o0000okN`d_l000001Onn]M000ol0
003o_[G@okjed004okjed003o`000?o3^M3o`kW@00go`kW@00Go0000olNmdOo7_M7oakgAo`00000=
olg1cP03o`000?o@a<ood<C?00Wod<C?00?o0000omC6c?oDa/`00ooDa/`00ol0003oooooooooo`1R
ooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o00002?nE]^h00ol0003oUjoXoiN_j008oiN_
j003o`000?nIZ^;oVJ[R00OoVJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@08oijT
f@03o`000?nQX]KoXJ;F00?o00001_nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC
00WoZ:KC00?o0000ojjXd_n^Z=802_n^Z=800ol0003o/jcAok>/d@0;ok>/d@;o00001_nn]M000ol0
003o_[G@okjed005okjed003o`000?o3^M3o`kW@00go`kW@00?o0000olNmdOl000003_o=`Lh00ol0
003od<C?om34c`08om34c`03o`000?oDa/coe<K<00Coe<K<0_l0001Sooooo`00;_ooool00ol0003o
ooooooooo`0Eooooo`;o00002?nE]^h00ol0003oUjoXoiN_j008oiN_j003o`000?nIZ^;oVJ[R00Oo
VJ[R00?o0000oibVgOnLY]d02?nLY]d00ol0003oWZCIoijTf@06oijTf@Co00002OnLX]T00ol0003o
XjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000ojjXd_n^Z=802_n^Z=800ol0003o
/jcAok>/d@08ok>/d@;o000000?o^K7Ao`000?nn]M001Onn]M000ol0003o_[G@okjed006okjed003
o`000?o3^M3o`kW@00co`kW@0_l0000@olg1cP03o`000?o@a<ood<C?00Kod<C?00?o0000omC6c?oD
a/`01_oDa/`00ol0003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l00008oiFfkP03o`00
0?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KMoibVg@08oibVg@04o`00
0?nNY=WoWZCIoijTf@Go00000_nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00Wo
XjCF00?o0000ojRVdonXY]<02OnXY]<00ol0003o[ZSBojjXdP0;ojjXdP03o`000?nc[=7o/jcA00Go
/jcA0_l00004okVad@03o`000?nn]M3o_[G@00?o_[G@00?o0000okjed?nn]M001_nn]M000ol0003o
`kW@ol>id00;ol>id003o`000?o9_Loo0000017ocL7>00?o0000om34coo@a<l01?o@a<l00ol0003o
e<K<omC6c008omC6c003o`000?oooooooooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo
0_l00008oiFfkP03o`000?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^801onIZ^800ol0003oW:KM
oibVg@03oibVg@So00002?nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF
00?o0000ojRVdonXY]<02_nXY]<00ol0003o[ZSBojjXdP0:ojjXdP03o`000?nc[=7o/jcA00Co/jcA
00?o0000okVadOni/M401Oni/M400ol0003o_[G@okjed002okjed003o`000?nn]M3o_[G@00Oo_[G@
00?o0000ol>id?o3^M002Oo3^M001Ol0003obKg?olVmcoo9_Loo0000013ocL7>00?o0000om34coo@
a<l00oo@a<l00ol0003oe<K<omC6c00:omC6c003o`000?oooooooooo05oooooo000Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo01So
oooo0_l00008oiFfkP03o`000?nG[nSoUjoX00OoUjoX00?o0000oiVZh_nIZ^800onIZ^89o`0000Go
Sj;R00?o0000oiJRgOnFX]d02OnFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nSY=KoXjCF00Wo
XjCF00?o0000ojRVdonXY]<02_nXY]<00ol0003o[ZSBojjXdP0:ojjXdP04o`000?nc[=7o/jcAok>/
d@;o00002?ni/M400ol0003o_[G@okjed002okjed003o`000?nn]M3o_[G@00So_[G@00?o0000ol>i
d?o3^M001oo3^M000ol0003obKg?olVmc`03olVmc`03o`000?o=`LkocL7>00kocL7>00Go0000om34
coo@a<ood<C?o`00000>omC6c003o`000?oooooooooo05kooooo000Booooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oo
oooooooo01Wooooo6Ol00004ohNTi`03o`000?n?X^;oSj;R00SoSj;R00?o0000oiJRgOnFX]d02?nF
X]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF00?o0000ojRVdonXY]<02_nX
Y]<00ol0003o[ZSBojjXdP0:ojjXdP04o`000?nc[=7o0000o`0000_o^K7A00Go0000okjed?nn]M3o
_[G@o`00000:okjed003o`000?o3^M3o`kW@00Ko`kW@00?o0000olVmcoo9_Ll01Oo9_Ll00ol0003o
cL7>olg1cP0>olg1cP03o`000?o@a<oo000000ooe<K<00?o0000ooooooooool0G_ooool001;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000oooooooo
ool06_ooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0Y^goP:K]00OoP:K]00?o0000ohNTion7
Y>L01on7Y>L00ol0003oSj;RohnRhP08ohnRhP03o`000?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnL
X]T02?nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000ojjXd_n^
Z=802On^Z=82o`0000go^K7A00Go0000okjed?nn]M3o_[G@o`00000;okjed003o`000?o3^M3o`kW@
00Co`kW@00?o0000olVmcoo9_Ll01_o9_Ll00ol0003ocL7>olg1cP0?olg1cP03o`000?oDa/coe<K<
00ooe<K<00?o0000ooooooooool0GOooool001;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003oNJ[bogVZlP06ogVZ
lP03o`000?n0Y^goP:K]00OoP:K]00?o0000ohNTion7Y>L01on7Y>L00ol0003oSj;RohnRhP07ohnR
hP03o`000?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T02OnLX]T00ol0003oXjCFoj>TeP09oj>T
eP03o`000?nXY]?oZ:KC00WoZ:KC00?o0000ojjXd_n^Z=801on^Z=82o`000003ok:]dol0003o^K7A
00go^K7A00Co0000okjed?nn]M3o00003?nn]M000ol0003o`kW@ol>id002ol>id003o`000?o9_Loo
bKg?00SobKg?00?o0000olg1c_o=`Lh03Oo=`Lh2o`0001;oe<K<00?o0000ooooooooool0G?ooool0
01;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000
ooooooooool07?ooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0Y^goP:K]00OoP:K]00?o0000
ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP08ohnRhP03o`000?nFX]goUZ;M00SoUZ;M00?o0000
oibRfOnLX]T02?nLX]T00ol0003oXjCFoj>TeP09oj>TeP03o`000?nXY]?oZ:KC00[oZ:KC00?o0000
ojjXd_n^Z=801?n^Z=82o`0000Co/ZgC00?o0000okVadOni/M403?ni/M400ol0003o_[G@o`00000<
okjed005o`000?o3^M3o`kW@ol>id?l000003?o9_Ll00ol0003ocL7>olg1cP0;olg1cP04o`000?oB
a<cod/C<o`0001;oe<K<00?o0000ooooooooool0Foooool001;ooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03o`000?miZ_;oNJ[b00KoNJ[b
00?o0000oh2VkOn0Y^d01on0Y^d00ol0003oQjCWohNTi`06ohNTi`03o`000?n?X^;oSj;R00OoSj;R
00?o0000oiJRgOnFX]d02OnFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nSY=KoXjCF00WoXjCF
00?o0000ojRVdonXY]<02_nXY]<01?l0003o[ZSBojjXd_n^Z=82o`0000Oo/ZgC00?o0000okVadOni
/M402oni/M400ol0003o_[G@o`00000=okjed003o`000?o3^M3o000000kobKg?00?o0000olg1c_o=
`Lh02Oo=`Lh00ol0003od/C<om;4c002om;4c003o`000?oDa/coe<K<00ooe<K<00?o0000oooooooo
ool0Foooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Oooooo`03o`000?miZ_;oNJ[b00KoNJ[b00?o0000oh2V
kOn0Y^d01_n0Y^d00ol0003oQjCWohNTi`07ohNTi`03o`000?n?X^;oSj;R00OoSj;R00?o0000oiJR
gOnFX]d02?nFX]d00ol0003oW:;IoibRf@09oibRf@03o`000?nSY=KoXjCF00SoXjCF00?o0000ojRV
donXY]<02_nXY]<01?l0003o[ZSBo`000?l00009ok:]d`03o`000?ni/M7o^K7A00co^K7A0_l0000=
okjed0;o00003oo9_Ll00ol0003ocL7>olg1cP08olg1cP03o`000?oBa<cod/C<00Cod/C<00?o0000
omC6c?oDa/`03OoDa/`00ol0003oelS;o`00001Looooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023ooooo00?o
0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>OoQjCW00KoQjCW00?o
0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]WoW:;I00SoW:;I00?o
0000oj>Te_nSY=H02OnSY=H00ol0003oZ:KCojRVd`09ojRVd`;o00003?nb[M<00ol0003o^K7AokVa
d@0;okVad@;o00003?nn]M000ol0003oaK[@o`00000@olVmc`03o`000?o=`LkocL7>00KocL7>00?o
0000om;4c?oBa<`01OoBa<`00ol0003oe<K<omC6c00<omC6c005o`000?oGb<_oelS;omO8bol00000
Foooool002gooooo00?o0000ooooooooool08Oooool00ol0003oNJ[bogVZlP06ogVZlP03o`000?n0
Y^goP:K]00KoP:K]00?o0000ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP07ohnRhP03o`000?nF
X]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T02OnLX]T00ol0003oXjCFoj>TeP08oj>TeP03o`000?nX
Y]?oZ:KC00OoZ:KC0_l000000on[Z]Ko0000ok:]d`0;ok:]d`03o`000?ni/M7o^K7A00co^K7A00?o
0000okjed?nn]M002Onn]M001Ol0003oaK[@olFjd?o5^]3o0000013obKg?00?o0000olg1c_o=`Lh0
1?o=`Lh00ol0003od/C<om;4c007om;4c003o`000?oDa/coe<K<00[oe<K<00?o0000omO8booGb</0
0ooGb</00ol0003oooooooooo`1Hooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?mi
Z_;oNJ[b00OoNJ[b00?o0000oh2VkOn0Y^d01_n0Y^d00ol0003oQjCWohNTi`06ohNTi`03o`000?n?
X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d02?nFX]d00ol0003oW:;IoibRf@08oibRf@03o`000?nS
Y=KoXjCF00WoXjCF00?o0000ojRVdonXY]<01?nXY]<2o`0000CoZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@0;okVad@;o00002?nn]M02o`0000GoaK[@00?o0000olVmcoo9_Ll03Oo9
_Ll00ol0003ocL7>olg1cP03olg1cP03o`000?oBa<cod/C<00Wod/C<00?o0000omC6c?oDa/`02?oD
a/`00ol0003oelS;omO8b`04omO8b`03o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>Oo
QjCW00KoQjCW00?o0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]Wo
W:;I00SoW:;I00?o0000oj>Te_nSY=H02OnSY=H01?l0003oZ:KCojRVdonXY]<2o`0000OoZj[F00?o
0000ok:]donb[M<02_nb[M<00ol0003o^K7AokVad@0:okVad@;o00001onn]M000ol0003oaK[@olFj
d005olFjd003o`000?o9_LoobKg?00kobKg?00Go0000olg1c_o=`LkocL7>o`00000<om;4c003o`00
0?oDa/coe<K<00Ooe<K<00?o0000omO8booGb</01_oGb</00ol0003oooooooooo`1Gooooo`00;?oo
ool3o`0002Cooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7
Y>OoQjCW00KoQjCW00?o0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nL
X]WoW:;I00SoW:;I00?o0000oj>Te_nSY=H02OnSY=H01?l0003oZ:KCo`000?l00009oj^ZeP03o`00
0?nb[M?o/ZgC00[o/ZgC00?o0000okVadOni/M402_ni/M400ol0003o^K7Ao`000004okjed0;o0000
2Oo5^]000ol0003obKg?olVmc`0>olVmc`03o`000?o=`Lko000000kod/C<00?o0000omC6c?oDa/`0
1_oDa/`00ol0003oelS;omO8b`07omO8b`03o`000?oooooooooo05Kooooo000]ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7
Y>OoQjCW00KoQjCW00?o0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nL
X]WoW:;I00SoW:;I00?o0000oj>Te_nSY=H01onSY=H3o`0000coZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@09okVad@03o`000?ni/M7o000000?o_[G@00?o0000olFjd?o5^]002_o5
^]000ol0003obKg?olVmc`0>olVmc`03o`000?oBa<cod/C<00kod/C<00?o0000omC6c?oDa/`01?oD
a/`00ol0003oelS;omO8b`09omO8b`03o`000?oooooooooo05Gooooo000]ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@06oh2Vk@03o`000?n7Y>Oo
QjCW00GoQjCW00?o0000ohnRh_n?X^802?n?X^800ol0003oUZ;MoiJRg@07oiJRg@03o`000?nLX]Wo
W:;I00WoW:;I00?o0000oj>Te_nSY=H00onSY=H3o`0000;oXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H0
0ol0003o/ZgCok:]d`0;ok:]d`03o`000?ni/M7o^K7A00So^K7A00Ko0000okVadOni/M7o0000okje
d?l0000=olFjd003o`000?o9_LoobKg?00gobKg?0_l0000Aom;4c003o`000?oDa/coe<K<00;oe<K<
00?o0000omO8booGb</02_oGb</2o`0005Kooooo000]ooooo`03o`000?oooooooooo02Kooooo00?o
0000ogVZl_miZ_801_miZ_800ol0003oP:K]oh2Vk@05oh2Vk@03o`000?n7Y>OoQjCW00KoQjCW00?o
0000ohnRh_n?X^801on?X^800ol0003oUZ;MoiJRg@08oiJRg@03o`000?nLX]WoW:;I00SoW:;I00?o
0000oj>Te_nSY=H00ol00006oj:Vf@03o`000?n[Z]KoZj[F00[oZj[F00?o0000ok:]donb[M<02_nb
[M<00ol0003o^K7AokVad@08okVad@03o`000?ni/M7o^K7A00;o00003oo5^]000ol0003obKg?olVm
c`0;olVmc`04o`000?o?`/kocl;>o`00013od/C<00Go0000omC6c?oDa/coe<K<o`00000>omO8b`03
o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo1_l00003ogVZlP03o`00
0?n0Y^goP:K]00GoP:K]00?o0000ohNTion7Y>L01_n7Y>L00ol0003oSj;RohnRhP07ohnRhP03o`00
0?nFX]goUZ;M00SoUZ;M00?o0000oibRfOnLX]T01_nLX]T4o`0000[oXZKI00?o0000oj^Ze_n[Z]H0
2_n[Z]H00ol0003o/ZgCok:]d`0:ok:]d`03o`000?ni/M7o^K7A00Oo^K7A00Go0000okVadOl0003o
_[OBo`00000@olFjd003o`000?o9_LoobKg?00WobKg?00?o0000olo2c_o?`/h00_o?`/h00ol0003o
d/C<om;4c00>om;4c003o`000?oDa/co0000013oelS;00?o0000ooooooooool0Doooool002cooooo
00?o0000ooooooooool0:Oooool00ol0003oFI[aoeVJl@02oeVJl@[o00000_n0Y^d00ol0003oQjCW
ohNTi`05ohNTi`03o`000?n?X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d02?nFX]d01?l0003oW:;I
oibRfOnLX]T5o`0000;oV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03
o`000?nb[M?o/ZgC00_o/ZgC00?o0000okVadOni/M401_ni/M42o`0000?o_[OB00?o0000olFjd?o5
^]003_o5^]000ol0003obKg?olVmc`07olVmc`03o`000?o?`/kocl;>00Cocl;>00?o0000om;4c?oB
a<`03_oBa<`00ol0003oelS;omO8b`0@omO8b`03o`000?oooooooooo05;ooooo000/ooooo`;o0000
:oooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mUV^koII[^00?oII[^2Ol00002ohNTi`03o`00
0?n?X^;oSj;R00OoSj;R00?o0000oiJRgOnFX]d00onFX]d8o`0000SoV:?M00?o0000oj:VfOnRY]T0
2OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC00[o/ZgC00?o0000okVadOni/M40
1Oni/M42o`0000Go_[OB00?o0000olFjd?o5^]003Oo5^]000ol0003obKg?olVmc`06olVmc`03o`00
0?o?`/kocl;>00Gocl;>00?o0000om;4c?oBa<`03OoBa<`2o`0001;oelS;0_l0001Cooooo`00;?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01OmU
V^h00ol0003oLYcZog:LjP03og:LjQ;o00001On<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nR
Y]WoXZKI00WoXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]d`0;ok:]d`03o`000?ni
/M7o^K7A00?o^K7A00?o0000okjgd_l000001Onn]m800ol0003oaK[@olFjd00>olFjd003o`000?o9
_LoobKg?00CobKg?00?o0000olo2c_o?`/h01oo?`/h00ol0003od/C<om;4c00;om;4c004o`000?oF
alcoe/O<o`0001;oelS;00?o0000ooooooooool0DOooool002cooooo00?o0000ooooooooool0;?oo
ool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mUV^koII[^00GoII[^00?o0000og:Lj_mbW>X01Omb
W>X00ol0003oOikVognNiP07ognNiP03o`000?n<XN;oS:7R00SoS:7R00?o0000oiRSgOnHXmd02?nH
Xmd00ol0003oXZKIoj:Vf@09oj:Vf@03o`000?n[Z]KoZj[F00[oZj[F00?o0000ok:]donb[M<02_nb
[M<01?l0003o^K7AokVadOni/M42o`0000;o_[OB00?o0000okjgd_nn]m801?nn]m800ol0003oaK[@
olFjd00>olFjd003o`000?o9_LoobKg?00;obKg?00?o0000olo2c_o?`/h02Oo?`/h00ol0003od/C<
om;4c009om;4c003o`000?oFalcoe/O<00;oe/O<00?o0000omO8booGb</03_oGb</00ol0003ofLW;
o`00001Booooo`00;?ooool00ol0003oooooooooo`0]ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o
0000ofFJk_mUV^h01OmUV^h00ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o
0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o
0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]d`0:ok:]d`03o`000?ni/M7o000000Co_[OB00?o
0000okjgd_nn]m801Onn]m800ol0003oaK[@olFjd00=olFjd005o`000?o9_LoobKg?olVmcol00000
3?o?`/h00ol0003od/C<om;4c008om;4c003o`000?oFalcoe/O<00Coe/O<00?o0000omO8booGb</0
3?oGb</01Ol0003ofLW;omW9booIbL_o0000057ooooo000/ooooo`03o`000?oooooooooo02kooooo
00?o0000oeVJlOmIV_401OmIV_400ol0003oII[^ofFJkP05ofFJkP03o`000?mbW>[oLYcZ00GoLYcZ
00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M00SoV:?M
00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC00[o/ZgC
0_l00005okjgdP03o`000?nn]m;o_[OB00Go_[OB00?o0000olFjd?o5^]003_o5^]000ol0003obKg?
o`00000>olo2cP03o`000?oBa<cod/C<00Kod/C<00?o0000omK7c?oFal`01OoFal`00ol0003oelS;
omO8b`0;omO8b`03o`000?oIbL_ofLW;00;ofLW;0_l0001@ooooo`00;?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01?mUV^h00ol0003oLYcZog:L
jP06og:LjP03o`000?moW^KoOikV00KoOikV00?o0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRS
g@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o0000oj^Ze_n[Z]H02_n[Z]H00ol0003o/ZgCok:]
d`07ok:]d`;o000000?o][?Fo`000?nn]m801?nn]m800ol0003o_[OBokjgdP06okjgdP03o`000?o5
^]3oaK[@00goaK[@0_l0000@olo2cP03o`000?oBa<cod/C<00Cod/C<00?o0000omK7c?oFal`01ooF
al`00ol0003oelS;omO8b`09omO8b`03o`000?oIbL_ofLW;00CofLW;00?o0000ooooooooool0C_oo
ool002cooooo0_l0000aooooo`03o`000?mIV_7oFI[a00GoFI[a00?o0000ofFJk_mUV^h01?mUV^h0
0ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o0000ohbQh_n<XN802?n<XN80
0ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00[oXZKI00?o0000oj^Ze_n[Z]H02On[Z]H0
0ol0003o/ZgCok:]d`06ok:]d`03o`000?nf/mKo][?F00;o][?F00?o0000okjgd_nn]m800_nn]m80
0ol0003o_[OBokjgdP07okjgdP03o`000?o5^]3oaK[@00_oaK[@00?o0000olVod?l000004Oo?`/h0
0ol0003od/C<om;4c002om;4c003o`000?oFalcoe/O<00Woe/O<00?o0000omO8booGb</01ooGb</0
0ol0003ofLW;omW9b`06omW9b`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo
03;ooooo00?o0000oeVJlOmIV_401?mIV_400ol0003oII[^ofFJkP05ofFJkP03o`000?mbW>[oLYcZ
00GoLYcZ00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M
00SoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP0:oj^ZeP03o`000?nb[M?o/ZgC
00?o/ZgC0_l00006okJceP05o`000?nn]m;o_[OBokjgd_l000002Onn]m800ol0003oaK[@olFjd00:
olFjd005o`000?o9_m3obKo@olVod?l000004?o?`/h01Ol0003od/C<om;4c?oBa<co000000goe/O<
00?o0000omO8booGb</01_oGb</00ol0003ofLW;omW9b`07omW9b`03o`000?oooooooooo04cooooo
000[ooooo`03o`000?oooooooooo03?ooooo00?o0000oeVJlOmIV_401?mIV_400ol0003oII[^ofFJ
kP05ofFJkP03o`000?mbW>[oLYcZ00GoLYcZ00?o0000ognNi_moW^H01omoW^H00ol0003oS:7RohbQ
hP07ohbQhP03o`000?nHXmgoV:?M00SoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^Z
eP0:oj^ZeP03o`000?nb[M?o/ZgC00;o00002?nf/mH01Ol0003o_[OBokjgd_nn]m;o000000[o_[OB
00?o0000olFjd?o5^]002?o5^]000ol0003obKo@olVod003olVod003o`000?o?`/kocl;>00kocl;>
00?o0000om;4c?l000003ooFal`00ol0003oelS;omO8b`04omO8b`03o`000?oIbL_ofLW;00SofLW;
0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?mIV_7oFI[a00CoFI[a
00?o0000ofFJk_mUV^h01?mUV^h00ol0003oLYcZog:LjP06og:LjP03o`000?moW^KoOikV00KoOikV
00?o0000ohbQh_n<XN802?n<XN800ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00[oXZKI
00?o0000oj^Ze_n[Z]H02On[Z]H00ol0003o/ZgCo`00000;okJceP04o`000?nn]m;o_[OBo`0000[o
_[OB00?o0000olFjd?o5^]001_o5^]02o`0000KobKo@00?o0000olo2c_o?`/h03oo?`/h00ol0003o
e/O<omK7c00>omK7c003o`000?oGb<_oelS;00?oelS;00?o0000omW9booIbL/02_oIbL/2o`0004co
oooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0eooooo`03o`000?mIV_7oFI[a00CoFI[a00?o0000ofFJk_mU
V^h01?mUV^h00ol0003oLYcZog:LjP05og:LjP03o`000?moW^KoOikV00OoOikV00?o0000ohbQh_n<
XN801on<XN800ol0003oV:?MoiRSg@08oiRSg@03o`000?nRY]WoXZKI00WoXZKI00?o0000oj^Ze_n[
Z]H02On[Z]H2o`0000go][?F00?o0000okjgd_l000002onn]m800ol0003oaK[@olFjd004olFjd003
o`000?o9_m3obKo@00OobKo@00?o0000olo2c_o?`/h03_o?`/h00ol0003oe/O<omK7c00?omK7c005
o`000?oGb<_oelS;omO8bol000003_oIbL/00ol0003oooooooooo`1:ooooo`004?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo0ol00004oeVJ
l@03o`000?mUV^koII[^00CoII[^00?o0000og:Lj_mbW>X01OmbW>X00ol0003oOikVognNiP07ognN
iP03o`000?n<XN;oS:7R00OoS:7R00?o0000oiRSgOnHXmd01onHXmd00ol0003oXZKIoj:Vf@0:oj:V
f@03o`000?n[Z]KoZj[F00GoZj[F0ol000000on][mWo0000okJceP0<okJceP03o`000?nn]m;o0000
00co_[OB00?o0000olFjd?o5^]000_o5^]000ol0003obKo@olVod009olVod003o`000?o?`/kocl;>
00cocl;>00?o0000om;6c_l000004OoFal`00ol0003oelS;o`00000@omW9b`03o`000?oooooooooo
04Wooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007
ooooo`03o`000?oooooooooo03Oooooo00?o0000ocR8k?l000001Ol00006ofFJkP03o`000?mbW>[o
LYcZ00GoLYcZ00?o0000ognNi_moW^H01_moW^H00ol0003oS:7RohbQhP08ohbQhP03o`000?nHXmgo
V:?M00OoV:?M00?o0000oj:VfOnRY]T02OnRY]T00ol0003oZj[Foj^ZeP03oj^ZeP;o00001On][mT0
0ol0003o][?FokJceP0;okJceP;o00003?nn]m801Ol0003oaK[@olFjd?o5^]3o000000cobKo@00?o
0000olo2c_o?`/h02oo?`/h01Ol0003od/K>om;6c_oBa/ko0000017oe/O<00?o0000omW9booIbL/0
3ooIbL/2o`0004[ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo03Sooooo00?o0000ocR8k?lhR>`00olhR>`4o`0000?o
II[^00?o0000og:Lj_mbW>X01_mbW>X00ol0003oOikVognNiP06ognNiP03o`000?n<XN;oS:7R00Oo
S:7R00?o0000oiRSgOnHXmd01onHXmd00ol0003oXZKIoj:Vf@0:oj:Vf@03o`000?n[Z]Ko000000;o
00002?n][mT00ol0003o][?FokJceP0;okJceP03o`000?nn]m;o_[OB00_o_[OB00?o0000olFjd?l0
00003_o9_m000ol0003ocl;>olo2cP09olo2cP03o`000?oBa/kod/K>00?od/K>00?o0000omK7c?oF
al`03_oFal`00ol0003ofLW;omW9b`0@omW9b`;o0000BOooool0013ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000kooooo`03o`000?lhR>co>8S/00?o
>8S/00?o0000odN<k?m7S>`00ol000000omUV^ko0000og:LjP06og:LjP03o`000?moW^KoOikV00Oo
OikV00?o0000ohbQh_n<XN801on<XN800ol0003oV:?MoiRSg@07oiRSg@03o`000?nRY]WoXZKI00So
XZKI0ol0000;ojf_f@03o`000?nf/mKo][?F00_o][?F00?o0000okjgd_nn]m802onn]m82o`00013o
bKo@00?o0000olo2c_o?`/h01oo?`/h00ol0003od/K>om;6cP04om;6cP03o`000?oFalcoe/O<00go
e/O<00?o0000omS:c?l000004_oIbL/00ol0003oooooooooo`17ooooo`004?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0jooooo`03
o`000?lhR>co>8S/00?o>8S/00?o0000odN<k?m7S>`00_m7S>`3o`0000OoLYcZ00?o0000ognNi_mo
W^H01omoW^H00ol0003oS:7RohbQhP07ohbQhP03o`000?nHXmgoV:?M00OoV:?M00?o0000oj:VfOnR
Y]T00onRY]T4o`0000;oXJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o][?FokJceP0:okJceP;o
00002onn]m800ol0003o`kgDo`00000@olVod003o`000?o?`/kocl;>00Kocl;>00?o0000om;6c_oB
a/h01_oBa/h00ol0003oe/O<omK7c00;omK7c005o`000?oHb/cof<[<omS:c?l000004?oIbL/00ol0
003ofL_<o`000018ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`00
0?ooool01Oooool00ol0003oooooooooo`0looooo`03o`000?lhR>co>8S/00?o>8S/00?o0000odN<
k?m7S>`01?m7S>`6o`0000;oLYcZ00?o0000ognNi_moW^H01_moW^H00ol0003oS:7RohbQhP07ohbQ
hP03o`000?nHXmgoV:?M00OoV:?M00?o0000oj:VfOnRY]T00ol00007oj6[gP03o`000?n][mWo[JoI
00[o[JoI00?o0000okJce_nf/mH02Onf/mH2o`0000Wo_[OB0_l00003ol>me003o`000?o9_m3obKo@
00kobKo@00?o0000olo2c_o?`/h01?o?`/h00ol0003od/K>om;6cP08om;6cP03o`000?oFalcoe/O<
00Woe/O<00?o0000omS:c?oHb/`00ooHb/`00ol0003ofLW;omW9b`0<omW9b`03o`000?oIblcofL_<
00;o0000Aoooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003o>8S/ocR8k003ocR8k003
o`000?m7S>coAhc/00?oAhc/00?o0000oeZBk?mJT^`00omJT^`9o`0000?oOikV00?o0000ohbQh_n<
XN801on<XN800ol0003oV:?MoiRSg@03oiRSg@Ko00002onQZmh00ol0003o[JoIojf_f@09ojf_f@03
o`000?nf/mKo][?F00Wo][?F00?o0000okJce_l000001onn]m800ol0003o`kgDol>me004ol>me003
o`000?o9_m3obKo@00kobKo@00?o0000olo2c_o?`/h00_o?`/h00ol0003od/K>om;6cP09om;6cP03
o`000?oFalcoe/O<00Soe/O<00?o0000omS:c?oHb/`01OoHb/`00ol0003ofLW;omW9b`0:omW9b`03
o`000?oIblcofL_<00;ofL_<00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0
?_ooool00ol0003o>8S/ocR8k003ocR8k003o`000?m7S>coAhc/00?oAhc/00?o0000oeZBk?mJT^`0
1OmJT^`00ol0003oKiWZofnIjP03ofnIjQ?o00001?nCY^800ol0003oXJ_Noj6[gP0:oj6[gP03o`00
0?n][mWo[JoI00[o[JoI00?o0000okJce_nf/mH02?nf/mH01?l0003o][?FokJce_l00005okjgdP03
o`000?o3_MCo`kgD00Ko`kgD00?o0000olVod?o9_m003Oo9_m001Ol0003ocl;>olo2c_o?`/ko0000
00god/K>00?o0000omK7c?oFal`01_oFal`00ol0003of<[<omS:c007omS:c003o`000?oIbL_ofLW;
00SofLW;00?o0000omW;c?oIbl`01?oIbl`00ol0003oooooooooo`14ooooo`00:_ooool00ol0003o
ooooooooo`0oooooo`03o`000?lhR>co>8S/00?o>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003o
FY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o
][?FokJceP07okJceP04o`000?nf/mKo][?Fo`0000?o_[OB0_l00009ol>me003o`000?o9_m3obKo@
00kobKo@00?o0000olo2c_l000003ooBa/h00ol0003oe/O<omK7c004omK7c003o`000?oHb/cof<[<
00Sof<[<00?o0000omW9booIbL/01ooIbL/00ol0003ofL_<omW;c006omW;c003o`000?oooooooooo
04?ooooo000Yooooo`?o0000@?ooool2o`0000Go>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003o
FY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT02On][mT00ol0003o
][?FokJceP07okJceP07o`000?nf/mKo][?FokJce_l0003o_[OBo`00000<ol>me003o`000?o9_m3o
bKo@00gobKo@0_l0000Aom;6cP03o`000?oFalcoe/O<00;oe/O<00?o0000omS:c?oHb/`02_oHb/`0
0ol0003ofLW;omW9b`05omW9b`03o`000?oIblcofL_<00OofL_<0_l00014ooooo`00:_ooool00ol0
003oooooooooo`10ooooo`;o00001?lhR>`00ol0003oAhc/odN<k004odN<k003o`000?mJT^coFY;/
00GoFY;/00?o0000ofnIj_m_VNX01_m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR
00KoTjKR00?o0000oj6[g_nQZmh02_nQZmh00ol0003o[JoIojf_f@0:ojf_f@03o`000?nf/mKo][?F
00Ko][?F00Co0000okJce_nf/mKo][?F0_l0000>ol>me003o`000?o9_m3obKo@00_obKo@00?o0000
olk5d_l000004OoBa/h01Ol0003oe/O<omK7c?oFalco000000kof<[<00?o0000omW9booIbL/00ooI
bL/00ol0003ofL_<omW;c009omW;c003o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooo
oooo047ooooo0_l00004ocR8k003o`000?m7S>coAhc/00CoAhc/00?o0000oeZBk?mJT^`01?mJT^`0
0ol0003oKiWZofnIjP06ofnIjP03o`000?n2X>KoPZ3V00OoPZ3V00?o0000oi>Vh_nCY^801onCY^80
0ol0003oXJ_Noj6[gP0:oj6[gP03o`000?n][mWo[JoI00Wo[JoI00?o0000okJce_nf/mH01_nf/mH0
1_l0003o][?Fo`000?l0003o^[WIo`0000oo`kgD00?o0000olVod?o9_m002Oo9_m001Ol0003oc/GB
olk5d_o>aM;o0000017od/K>00?o0000omK7c?l000004?oHb/`01Ol0003ofLW;omW9booIbL_o0000
00gofL_<00?o0000ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0@_ooool3o`0000?o
>8S/00?o0000odN<k?m7S>`01?m7S>`00ol0003oFY;/oeZBk004oeZBk003o`000?m_VN[oKiWZ00Ko
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[o
XJ_N00?o0000ojf_fOn][mT02On][mT00ol0003o][?FokJceP05okJceP;o00001?nj^MT00ol0003o
`kgDol>me00<ol>me003o`000?o9_m3obKo@00SobKo@00?o0000olk5d_o>aM800oo>aM800ol0003o
d/K>om;6cP0?om;6cP03o`000?oHb/cof<[<013of<[<00?o0000omW9bol000003ooIbl`00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`14ooooo`04o`000?lKMn?o0000o`0000;o
>8S/00?o0000odN<k?m7S>`00om7S>`00ol0003oFY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00Ko
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00Wo
XJ_N00?o0000ojf_fOn][mT02_n][mT00ol0003o][?FokJceP03okJceP;o00001_nj^MT00ol0003o
`kgDol>me00<ol>me003o`000?o9_m3obKo@00KobKo@00?o0000olk5d_o>aM801Oo>aM800ol0003o
d/K>om;6cP0>om;6cP03o`000?oHb/cof<[<017of<[<00?o0000omW;c?oIbl`03_oIbl`00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`15ooooo`03o`000?lKMn?o6gOS00Co0000
1Om7S>`00ol0003oFY;/oeZBk005oeZBk003o`000?m_VN[oKiWZ00GoKiWZ00?o0000oh:Pi_n2X>H0
1on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00[oXJ_N00?o0000ojf_fOn][mT0
2On][mT01?l0003o][?FokJce_nf/mH2o`000003okZifOl0003o^[WI00Ko^[WI00?o0000ol>me?o3
_M@03?o3_M@00ol0003obKo@olVod004olVod003o`000?o>aM;oc/GB00Ooc/GB00?o0000om;6c_oB
a/h03?oBa/h00ol0003oeL_?o`00000BomS:c003o`000?oIblcofL_<00oofL_<00?o0000oooooooo
ool0?oooool002Wooooo00?o0000ooooooooool0A_ooool00ol0003o6gOSoa]gh`02oa]gh`;o0000
1Om7S>`00ol0003oFY;/oeZBk004oeZBk003o`000?m_VN[oKiWZ00KoKiWZ00?o0000oh:Pi_n2X>H0
1on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00WoXJ_N00?o0000ojf_fOn][mT0
2_n][mT00ol0003o][?Fo`000003okZif@03o`000?nj^MWo^[WI00Go^[WI00?o0000ol>me?o3_M@0
3?o3_M@00ol0003obKo@olVod003olVod003o`000?o>aM;oc/GB00Woc/GB00?o0000om;6c_oBa/h0
2_oBa/h01Ol0003oeL_?omG;cooEbloo0000013of<[<00?o0000omS=c_l000004OoIbl`00ol0003o
ooooooooo`0nooooo`00:Oooool2o`0004Sooooo00?o0000oa]gholKMn<00olKMn<3o`0000?oAhc/
00?o0000oeZBk?mJT^`01?mJT^`00ol0003oKiWZofnIjP06ofnIjP03o`000?n2X>KoPZ3V00OoPZ3V
00?o0000oi>Vh_nCY^801onCY^800ol0003oXJ_Noj6[gP09oj6[gP03o`000?n][mWo[JoI00Wo[JoI
0_l00004okZif@03o`000?nj^MWo^[WI00Ko^[WI00?o0000ol>me?o3_M@03?o3_M@01Ol0003obKo@
olVod?o9_m3o000000goc/GB00?o0000om;6c_oBa/h02?oBa/h00ol0003oeL_?omG;c`03omG;c`03
o`000?oHb/cof<[<00cof<[<00Go0000omS=c_oHcLkof<g>o`00000?omW;c0?o0000?oooool002Wo
oooo00?o0000ooooooooool0B?ooool00ol0003o6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00?o
000000?oAhc/o`000?mJT^`01OmJT^`00ol0003oKiWZofnIjP05ofnIjP03o`000?n2X>KoPZ3V00Oo
PZ3V00?o0000oi>Vh_nCY^801onCY^800ol0003oXJ_Noj6[gP0:oj6[gP03o`000?n][mWo[JoI00Go
[JoI0ol000000on_]]ko0000okZif@03okZif@03o`000?nj^MWo^[WI00Oo^[WI00?o0000ol>me?o3
_M@03?o3_M@00ol0003obKo@o`00000>olk5dP03o`000?oBa/kod/K>00Ood/K>00?o0000omG;cooE
bll01OoEbll00ol0003of<[<omS:c00:omS:c003o`000?oHcLkof<g>00?of<g>00?o0000omW;c?oI
bl`02ooIbl`01?l0003oelc?omO<col0000oooooo`00:Oooool00ol0003oooooooooo`19ooooo`03
o`000?lKMn?o6gOS00;o6gOS00?o0000obaniol/O^L00_l/O^L3o`0000KoFY;/00?o0000ofnIj_m_
VNX01Om_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00OoTjKR00?o0000oj6[g_nQ
Zmh02OnQZmh00ol0003o[JoIojf_f@03ojf_f@;o00001On_]]h01Ol0003o^[WIokZifOnj^MWo0000
00[o^[WI00?o0000ol>me?o3_M@02oo3_M@2o`00013oc/GB00?o0000om;6c_oBa/h01OoBa/h00ol0
003oeL_?omG;c`07omG;c`03o`000?oHb/cof<[<00Sof<[<00?o0000omS=c_oHcLh01?oHcLh00ol0
003ofL_<omW;c00:omW;c003o`000?oGc<ooelc?00;oelc?00?o0000ooooooooool0??ooool002Wo
oooo00?o0000ooooooooool0B_ooool00ol0003o6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00Co
;7kW0ol00003oeZBk003o`000?m_VN[oKiWZ00GoKiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003o
TjKRoi>VhP08oi>VhP03o`000?nQZmkoXJ_N00WoXJ_N00?o0000ojf_fOl000000_l00008ojnfgP04
o`000?nj^MWo^[WIo`0000[o^[WI00?o0000ol>me?o3_M@02_o3_M@00ol0003oal?Go`00000Aolk5
dP03o`000?oBa/kod/K>00?od/K>00?o0000omG;cooEbll02?oEbll00ol0003of<[<omS:c007omS:
c003o`000?oHcLkof<g>00Kof<g>00?o0000omW;c?oIbl`02?oIbl`00ol0003oelc?omO<c`04omO<
c`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oa]gholK
Mn<00_lKMn<00ol0003o;7kWobani`03obani`03o`000?m3RN_o@hW[00?o000000?oFY;/o`000?m_
VNX01_m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00SoTjKR00?o0000oj6[g_nQ
Zmh01onQZmh3o`0000co[kKN00?o0000okZifOl000002onj^MT00ol0003o`kgDol>me007ol>me0;o
00000oo7`mL00ol0003oc/GBolk5dP0?olk5dP05o`000?oBa/kod/K>om;6c_l000003?oEbll00ol0
003of<[<omS:c005omS:c003o`000?oHcLkof<g>00Sof<g>00?o0000omW;c?oIbl`01_oIbl`00ol0
003oelc?omO<c`05omO<c`;o0000??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003o
6gOSoa]gh`02oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000od>9jom3RN/00_m3RN/3o`0000Oo
KiWZ00?o0000oh:Pi_n2X>H01on2X>H00ol0003oTjKRoi>VhP07oi>VhP03o`000?nQZmkoXJ_N00Co
XJ_N0ol00002oj2`h`03o`000?n_]]ko[kKN00[o[kKN00?o0000okZifOl000003?nj^MT00ol0003o
`kgDol>me005ol>me003o`000?o7`mOoal?G00Coal?G00?o0000olk5d_o>aM803oo>aM800ol0003o
d/K>o`00000>omG;c`03o`000?oHb/cof<[<00?of<[<00?o0000omS=c_oHcLh02_oHcLh00ol0003o
fL_<omW;c004omW;c003o`000?oGc<ooelc?00Ooelc?00?o0000ooooooooool0>_ooool002Sooooo
0ol0001>ooooo`03o`000?lKMn?o6gOS00;o6gOS00?o0000obaniol/O^L00ol/O^L00ol0003o@hW[
od>9j`04od>9j`?o00001?m_VNX00ol0003oPZ3Voh:PiP07oh:PiP03o`000?nCY^;oTjKR00SoTjKR
00?o0000oj6[g_nQZmh00ol00006oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000<okZif@03o`00
0?o3_MCo`kgD00Co`kgD00?o0000olO3eoo7`mL01_o7`mL00ol0003oc/GBolk5dP0>olk5dP;o0000
4?oEbll01Ol0003of<[<omS:c?oHb/co000000gof<g>00?o0000omW;c?oIbl`00ooIbl`00ol0003o
elc?omO<c`09omO<c`03o`000?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo04oooooo
00?o0000oa]gholKMn<00_lKMn<00ol0003o;7kWobani`03obani`03o`000?m3RN_o@hW[00?o@hW[
00?o0000oefEkOmMUNd01_l00009oh:PiP03o`000?nCY^;oTjKR00?oTjKR1ol0000:oj2`h`03o`00
0?n_]]ko[kKN00[o[kKN00?o0000okZifOnj^MT02onj^MT01?l0003o`kgDol>me?o3_M@2o`0000[o
al?G00?o0000olk5d_o>aM803?o>aM800ol0003odL_Do`00000AomG;c`03o`000?oHb/co000000oo
f<g>00Go0000omW;c?oIblcofL_<o`00000=omO<c`03o`000?oooooooooo03Sooooo000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007
ooooo`03o`000?oooooooooo053ooooo0_l00003oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000
od>9jom3RN/00om3RN/00ol0003oGIG]oefEk@04oefEkA3o00001On>ZNP00ol0003oX;3Soj2`h`09
oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000=okZif@03o`000?o3_MCo000000goal?G00?o0000
olk5d_o>aM802_o>aM801Ol0003odL_Dom7;e?oAbmCo0000017oeL_?00?o0000omS=c_oHcLh03ooH
cLh00ol0003ofL_<o`00000>omO<c`;o0000>Oooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0
D?ooool01?l0003o2F[Lo`000?l00002oa]gh`03o`000?l/O^Oo;7kW00?o;7kW00?o0000od>9jom3
RN/00om3RN/00ol0003oGIG]oefEk@04oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>
ZNP02?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`03o`000?n_]]ko[kKN00So[kKN0ol0000=okZif@;o
00003oo7`mL00ol0003oc/GBolk5dP08olk5dP03o`000?oAbmCodL_D00?odL_D00?o0000omG;cooE
bll03_oEbll00ol0003of<g>omS=cP0@omS=cP03o`000?oGc<ooelc?00koelc?00?o0000oooooooo
ool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`1Aooooo`03o`000?l9J]co2F[L00Co00001Ol/O^L00ol0
003o@hW[od>9j`03od>9j`03o`000?mMUNgoGIG]00CoGIG]00?o0000ogNPk?mgX>`01omgX>`00ol0
003oSZWXohjYj008ohjYj003o`000?nP/>?oX;3S00WoX;3S00?o0000ojnfg_n_]]h01?n_]]h3o`00
0004ojnfg_l0003o[kKNo`0000[o^[WI0_l000000onm`Mco0000olO3e`0>olO3e`03o`000?o>aM;o
c/GB00Ooc/GB00?o0000om7;e?oAbm@01OoAbm@00ol0003oeL_?omG;c`0<omG;c`03o`000?oFcm;o
0000017of<g>00?o0000omO<cooGc<l03ooGc<l00ol0003oooooooooo`0fooooo`003?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03o`000?oo
oooooooo05;ooooo00?o0000o`UZg?l9J]`00_l9J]`2o`0000Co;7kW00?o0000od>9jom3RN/01?m3
RN/00ol0003oGIG]oefEk@04oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>ZNP02?n>
ZNP00ol0003oX;3Soj2`h`08oj2`h`04o`000?n_]]ko[kKNojnfgP?o00001On_]]h00ol0003o[kKN
o`000008okZif@03o`000?nm`Mco_L7L00;o_L7L00?o0000olO3eoo7`mL03Oo7`mL00ol0003oc/GB
olk5dP05olk5dP03o`000?oAbmCodL_D00OodL_D00?o0000omG;cooEbll02_oEbll01Ol0003oe/oB
omK?d_oFcm;o000000oof<g>00?o0000omS@dOl000004?oGc<l2o`0003Oooooo000<ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo00?o0000oooo
ooooool0Doooool00ol0003o2F[Lo`UZg003o`UZg0;o00000ol/O^L00ol0003o@hW[od>9j`03od>9
j`03o`000?mMUNgoGIG]00GoGIG]00?o0000ogNPk?mgX>`01omgX>`00ol0003oSZWXohjYj007ohjY
j003o`000?nP/>?oX;3S00WoX;3S0ol00009ojnfgP;o00001_nj^MT2o`0000Ko_L7L00?o0000olO3
eoo7`mL03Oo7`mL00ol0003oc/GBolk5dP03olk5dP03o`000?oAbmCodL_D00WodL_D00?o0000omG;
cooEbll02?oEbll00ol0003oe/oBomK?dP03omK?dP03o`000?oHcLkof<g>00_of<g>00Go0000omS@
dOoHd=7of=3Ao`00000>omO<c`04o`000?oDcM?o0000o`0003Kooooo000<ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000o`UZg?l9J]`00_l9J]`01?l0003o67?Ro`000?l00002obani`03o`000?m3RN_o@hW[00?o@hW[
00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>ZNSoSZWX00SoSZWX
00?o0000oj2`honP/><01OnP/><3o`000003oj2`hol0003o[kKN00[o[kKN0_l00003okZif@;o0000
2Onm`M`00ol0003oal?GolO3e`0=olO3e`05o`000?o>aM;oc/GBolk5d_l000003?oAbm@00ol0003o
eL_?omG;c`07omG;c`03o`000?oFcm;oe/oB00Goe/oB00?o0000omS=c_oHcLh02OoHcLh00ol0003o
f=3AomS@d@03omS@d@03o`000?oGc<ooelc?00[oelc?00Go0000omC=dooDcM?oe<gCo`00000foooo
o`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool2o`00
05Oooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP04o`0000Go@hW[00?o0000oefE
kOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>ZNSoSZWX00SoSZWX00Co0000oj2`
honP/>?oX;3S0ol00005oj2`h`03o`000?n_]]ko[kKN00Wo[kKN0_l000000onj^MWo0000okg1g00;
okg1g003o`000?o7`mOoal?G00goal?G00?o0000olk5d_l000003_oAbm@00ol0003oeL_?omG;c`05
omG;c`03o`000?oFcm;oe/oB00Ooe/oB00?o0000omS=c_oHcLh01ooHcLh00ol0003of=3AomS@d@05
omS@d@03o`000?oGc<ooelc?00Soelc?00?o0000omC=dooDcM<00ooDcM<00ol0003oooooooooo`0c
ooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?l9J]co2F[L00;o2F[L00?o0000oaQch_lHLn800_lH
Ln82o`0000Go@hW[00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk003o`000?n>
ZNSoSZWX00SoSZWX0ol00008oj2`h`03o`000?n_]]ko[kKN00[o[kKN0_l0000=okg1g003o`000?o7
`mOoal?G00goal?G0_l0000@om7;e003o`000?oEblooeL_?00?oeL_?00?o0000omK?d_oFcm802OoF
cm800ol0003of<g>omS=cP05omS=cP03o`000?oHd=7of=3A00Oof=3A00?o0000omO<cooGc<l01_oG
c<l00ol0003oe<gComC=d`05omC=d`03o`000?oooooooooo03;ooooo000Wooooo`03o`000?oooooo
oooo05Sooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP03oaQchP;o00000om3RN/0
0ol0003oGIG]oefEk@05oefEk@03o`000?mgX>coMj3/00OoMj3/00?o0000ohjYj?n>ZNP01?n>ZNP4
o`0000_oX;3S00?o0000ojnfg_n_]]h01on_]]h2o`000003ok6mhol0003o_L7L00go_L7L00?o0000
olO3eoo7`mL02oo7`mL00ol0003ob/[Jo`00000Aom7;e005o`000?oEblooeL_?omG;col000003OoF
cm800ol0003of<g>omS=cP03omS=cP03o`000?oHd=7of=3A00Sof=3A00?o0000omO<cooGc<l01OoG
c<l00ol0003oe<gComC=d`07omC=d`03o`000?oooooooooo037ooooo000Wooooo`03o`000?oooooo
oooo05Wooooo00?o0000o`UZg?l9J]`00_l9J]`00ol0003o67?RoaQchP02oaQchP04o`000?l_PNSo
0000o`0000;o@hW[00?o0000oefEkOmMUNd01OmMUNd00ol0003oMj3/ogNPk006ogNPk004o`000?n>
ZNSoSZWXohjYj0?o00001?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`03o`000?n_]]ko[kKN00Co[kKN
0_l00004ok6mh`03o`000?nm`Mco_L7L00co_L7L00?o0000olO3eoo7`mL02Oo7`mL01Ol0003ob/[J
ol[:f_o:b][o0000017odL_D00?o0000omG;col000003ooFcm801Ol0003of<g>omS=c_oHcLko0000
00cof=3A00?o0000omO<cooGc<l00ooGc<l00ol0003oe<gComC=d`08omC=d`;o0000<_ooool002Oo
oooo00?o0000ooooooooool0F_ooool00ol0003o2F[Lo`UZg002o`UZg003o`000?lHLn;o67?R00;o
67?R00?o0000obn1j?l_PNP01?l00007oefEk@03o`000?mgX>coMj3/00KoMj3/0ol00008ohjYj003
o`000?nP/>?oX;3S00SoX;3S00?o0000ojnfg_n_]]h00_n_]]h2o`0000Ko/KgS0_l0000>okg1g003
o`000?o7`mOoal?G00Ooal?G00?o0000ol[:f_o:b]X00oo:b]X00ol0003odL_Dom7;e00>om7;e0;o
00004OoFcm800ol0003of<g>o`00000>omS@d@05o`000?oGc<ooelc?omO<col000003?oDcM<00ol0
003oooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Kooooo`03o`000?l9J]co2F[L00;o
2F[L00?o0000oaQch_lHLn800_lHLn800ol0003o;h7Xobn1j002obn1j0;o00001omMUNd00ol0003o
Mj3/ogNPk002ogNPk0?o000000?oMj3/o`000?n>ZNP02?n>ZNP00ol0003oX;3Soj2`h`09oj2`h`04
o`000?n_]]ko0000o`0000Wo/KgS0_l0000=okg1g003o`000?o7`mOoal?G00Goal?G0_l00007ol[:
fP03o`000?oAbmCodL_D00codL_D00?o0000om;Aeol000004OoFcm82o`00013of=3A00?o0000omO<
col000003_oDcM<00ol0003oooooooooo`0_ooooo`009oooool2o`0005gooooo0_l00003o`UZg003
o`000?lHLn;o67?R00;o67?R00?o0000obn1j?l_PNP00ol_PNP4o`0000CoGIG]1?l00004ogNPk003
o`000?n>ZNSoSZWX00SoSZWX00?o0000oj2`honP/><01onP/><3o`0000co/KgS0_l0000=okg1g003
o`000?o7`mOoal?G00?oal?G00?o0000ol[:f_o:b]X02?o:b]X00ol0003odL_Dom7;e00:om7;e005
o`000?oBdMOod]7Gom;Aeol000003ooFcm800ol0003oe]?Fo`00000AomS@d@03o`000?oDcM?oe<gC
00koe<gC00?o0000ooooooooool0;_ooool002Kooooo0_l0001Oooooo`?o00000_l9J]`00ol0003o
67?RoaQchP02oaQchP03o`000?l_PNSo;h7X00;o;h7X00Co0000odfBk_m=T^koCI;^1_l00007ogNP
k003o`000?n>ZNSoSZWX00SoSZWX00Co0000oj2`honP/>?oX;3S1Ol00002oingj@03o`000?na_N?o
/KgS00_o/KgS00?o0000okg1g?nm`M`03?nm`M`01Ol0003oal?GolO3eoo7`mOo000000cob/[J00?o
0000om7;e?oAbm@02?oAbm@00ol0003od]7Gom;Ae`03om;Ae`03o`000?oFcm;oe/oB00_oe/oB00Go
0000omKCe_oFdmKoe]?Fo`00000?omS@d@;o00004?oDcM<2o`0002oooooo000Wooooo`03o`000?oo
oooooooo05kooooo00?o0000o`9Vf_l000000ol00004oaQchP03o`000?l_PNSo;h7X00;o;h7X00?o
0000odfBk_l000000_l00003odfBkPOo00000_mgX>`00ol0003oSZWXohjYj003ohjYj0So00002?nO
]nT00ol0003o/KgSok6mh`0;ok6mh`03o`000?nm`Mco_L7L00co_L7L00?o0000olO3eol000003Oo:
b]X00ol0003odL_Dom7;e007om7;e003o`000?oBdMOod]7G00God]7G00?o0000omK?d_oFcm802OoF
cm800ol0003oe]?FomKCeP03omKCeP03o`000?oHd=7of=3A00_of=3A00Co0000omGBeooEd]Oo0000
4?oDcM<2o`0002kooooo000Wooooo`03o`000?oooooooooo05oooooo00Co0000o`9Vf_l2I][o0VKJ
0_l00004oaQchP03o`000?l_PNSo;h7X00?o00001om=T^h00ol0003oKJ7`offQl003offQl0So0000
1On8[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?nm`M`0
2onm`M`2o`0000oob/[J00?o0000om7;e?oAbm@01OoAbm@00ol0003od]7Gom;Ae`07om;Ae`03o`00
0?oFcm;oe/oB00Ooe/oB00?o0000omKCe_oFdmH01OoFdmH00ol0003of=3AomS@d@09omS@d@03o`00
0?oEd]OoeM;G00;oeM;G00?o0000omC=dooDcM<03?oDcM<00ol0003oclkHo`00000^ooooo`009_oo
ool00ol0003oooooooooo`1Qooooo`03o`000?l2I][o0VKJ00;o0VKJ0_l00002oaQchP?o00000ol_
PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8
[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?nm`M`02?nm
`M`2o`000003ol39hOl0003ob/[J00oob/[J00?o0000om7;e?oAbm@00ooAbm@00ol0003od]7Gom;A
e`09om;Ae`03o`000?oFcm;oe/oB00Goe/oB00?o0000omKCe_oFdmH01ooFdmH00ol0003of=3AomS@
d@07omS@d@03o`000?oEd]OoeM;G00CoeM;G00?o0000omC=dooDcM<02_oDcM<01Ol0003oclkHolo>
f?o?c]So000002gooooo000Vooooo`03o`000?oooooooooo06;ooooo00Co0000o`9Vf_l2I][o0VKJ
1?l000000olHLn;o0000obn1j004obn1j003o`000?m=T^koCI;^00GoCI;^00?o0000offQl?m]XO00
1Om]XO000ol0003oR:k^ohR^kP08ohR^kP03o`000?nO]nWoWkOY00WoWkOY00?o0000ok6mhona_N<0
2_na_N<2o`0000So_L7L00?o0000ol39hOo0bN400_o0bN400ol0003ob/[Jol[:fP0>ol[:fP05o`00
0?oAbmCodL_Dom7;e?l000003OoBdML00ol0003oe/oBomK?dP03omK?dP03o`000?oFdmKoe]?F00Wo
e]?F00?o0000omS@dOoHd=401OoHd=400ol0003oeM;GomGBe`06omGBe`03o`000?oDcM?oe<gC00So
e<gC00?o0000olo>f?o?c]P00_o?c]P2o`0002cooooo000Vooooo`03o`000?oooooooooo06?ooooo
1Ol00002o`e^gP?o00001Ol_PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`
00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@09oingj@03o`000?na_N?o/KgS00[o/KgS
00?o0000okg1g?nm`M`01?nm`M`2o`0000Ko`<WQ00?o0000ol[:f_o:b]X03_o:b]X00ol0003odL_D
o`00000?om;Ae`05o`000?oFcm;oe/oBomK?d_l000003OoFdmH00ol0003of=3AomS@d@03omS@d@03
o`000?oEd]OoeM;G00SoeM;G00?o0000omC=dooDcM<01OoDcM<2o`0000KoclkH00?o0000oooooooo
ool0:_ooool002Kooooo0_l0001Sooooo`?o00000ol2I]X01?l0003o3FkNo`e^g_l=K]h2o`0000Go
;h7X00?o0000odfBk_m=T^h01Om=T^h00ol0003oKJ7`offQl005offQl003o`000?n8[^koR:k^00So
R:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o/KgSok6mh`0:ok6mh`04o`000?nm`Mco_L7Lokg1
g0;o00002Oo0bN400ol0003ob/[Jol[:fP0=ol[:fP?o00004?oBdML00ol0003oe/oBo`00000?omKC
eP05o`000?oHd=7of=3AomS@dOl000003?oEd]L00ol0003oe<gComC=d`03omC=d`03o`000?o?c]So
clkH00OoclkH00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`00
00?ooooo00Go0000o`9Vf_l2I][o0VKJo`000003o`e^gP;o00001Ol_PNP00ol0003oCI;^odfBkP05
odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@08
oingj@03o`000?na_N?o/KgS00_o/KgS00?o0000okg1g?l000003?o0bN400ol0003ob/[Jol[:fP0;
ol[:fP05o`000?o<d]koc=;NolcBg_l000003ooBdML3o`00013oe]?F00?o0000omS@dOl000003_oE
d]L01Ol0003oe<gComC=dooDcM?o000000_oclkH00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0G?ooool3o`0000Oooooo00Go0000o`9Vf_l2I][o0VKJo`000004o`e^gP?o0000
0ol_PNP00ol0003oCI;^odfBkP05odfBkP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h0
2?n8[^h00ol0003oWkOYoingj@08oingj@03o`000?na_N?o/KgS00[o/KgS0_l0000>ol39h@03o`00
0?o:b][ob/[J00Sob/[J0_l00005olcBgP03o`000?oBdMOod]7G00_od]7G00Go0000om;Gg?oBemco
d]OLo`00000?omKCeP;o00004?oEd]L00ol0003oe<gCo`00000<olo>f003o`000?oooooooooo02So
oooo000Vooooo`03o`000?oooooooooo05Wooooo0ol0000;ooooo`05o`000?l2I][o0VKJo`9Vf_l0
00001?l=K]h00ol0003o8WgWo`000002o`000003obn1j?l0003oCI;^00GoCI;^00?o0000offQl?m]
XO001_m]XO000ol0003oR:k^ohR^kP07ohR^kP03o`000?nO]nWoWkOY00WoWkOY00?o0000ok6mhona
_N<01_na_N<3o`000003ok;6jOl0003o000000ko`<WQ00?o0000ol[:f_o:b]X01_o:b]X00ol0003o
c=;NolcBgP06olcBgP03o`000?oBdMOod]7G00Wod]7G00?o0000om;Gg?oBem`00ooBem`00ol0003o
e]?FomKCeP0;omKCeP04o`000?oDf=_oe=SKo`0000ooeM;G0_l0000>olo>f003o`000?oooooooooo
02Oooooo000Vooooo`03o`000?oooooooooo05Kooooo0ol0000?ooooo`;o00000_l2I]X00ol0003o
3FkNo`e^gP02o`e^gP04o`000?lRONOo8WgWob9mi`?o00001_m=T^h00ol0003oKJ7`offQl005offQ
l003o`000?n8[^koR:k^00SoR:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o/KgSok6mh`03ok6m
h`;o00001Onba^T2o`0000ko`<WQ00?o0000ol[:f_o:b]X01?o:b]X00ol0003oc=;NolcBgP08olcB
gP03o`000?oBdMOod]7G00Ood]7G00?o0000om;Gg?oBem`01OoBem`00ol0003oe]?FomKCeP09omKC
eP03o`000?oDf=_oe=SK00;oe=SK00?o0000omGBeooEd]L02ooEd]L00ol0003od=GMo`00000?olo>
f003o`000?oooooooooo02Kooooo000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`?o
000000?o0VKJo`000?l=K]h00ol=K]h00ol0003o8WgWob9mi`03ob9mi`?o00001?m=T^h00ol0003o
KJ7`offQl005offQl003o`000?n8[^koR:k^00SoR:k^00?o0000oingjOnO]nT02OnO]nT00ol0003o
/KgSo`000002o`0000So//KY0_l0000>ol39h@04o`000?o:b][ob/[Jol[:fP;o00003?o<d]h00ol0
003od]7Gom;Ae`05om;Ae`03o`000?oBemcod]OL00Ood]OL00?o0000omKCe_oFdmH01ooFdmH00ol0
003oe=SKomCHf`04omCHf`03o`000?oEd]OoeM;G00WoeM;G00Go0000om3EgOo@eMgod=GMo`00000>
olo>f0;o00009oooool002Gooooo00?o0000ooooooooool0DOooool3o`0001Oooooo00?o0000o`UZ
g?l000000_l00004o`e^gP03o`000?lRONOo8WgW00?o8WgW00?o0000od6Akol000000_l00002odfB
kP03o`000?m]XO3oKJ7`00GoKJ7`00?o0000ohR^k_n8[^h02?n8[^h00ol0003oWkOYoingj@07oing
j@?o00003?nba^T00ol0003o`<WQol39h@0=ol39h@03o`000?o:b][o000000ooc=;N00?o0000om;A
eooBdML00ooBdML00ol0003od]OLom;Gg009om;Gg003o`000?oFdmKoe]?F00Goe]?F00?o0000omCH
fooDf=/01_oDf=/00ol0003oeM;GomGBe`07omGBe`03o`000?o@eMgod=GM00?od=GM00?o0000olo>
f?o?c]P03?o?c]P00ol0003oooooooooo`0Uooooo`009Oooool3o`0004kooooo0ol0000Jooooo`;o
00000_l9J]`2o`0000Co3FkN00?o0000ob9miolRONL00olRONL01?l0003o@I7_od6Akom1TNl4o`00
00OoKJ7`00?o0000ohR^k_n8[^h02?n8[^h01?l0003oWkOYoingjOnO]nT5o`0000;oWKo`00?o0000
ok;6jOnba^T02onba^T00ol0003o`<WQol39h@0<ol39h@?o00004?o<d]h01Ol0003od]7Gom;AeooB
dMOo000000god]OL00?o0000omKCe_oFdmH00ooFdmH00ol0003oe=SKomCHf`08omCHf`03o`000?oE
d]OoeM;G00GoeM;G00?o0000om3EgOo@eMd01Oo@eMd00ol0003oclkHolo>f00;olo>f0;o00009_oo
ool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00002o`UZg0;o00001?l=K]h0
0ol0003o8WgWob9mi`03ob9mi`03o`000?m1TNoo@I7_00?o@I7_1ol00002offQl003o`000?n8[^ko
R:k^00?oR:k^2?l00008oifol003o`000?nba^Wo//KY00_o//KY00?o0000ol39hOo0bN402Oo0bN42
o`0000?o`M7V00?o0000olcBg_o<d]h03_o<d]h00ol0003od]7Go`00000?om;Gg005o`000?oFdmKo
e]?FomKCe_l000003?oDf=/00ol0003oeM;GomGBe`03omGBe`03o`000?o@eMgod=GM00Ood=GM00?o
0000olo>f?o?c]P02Oo?c]P01?l0003oa/gOo`000?l0000Uooooo`002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003o
ooooooooo`18ooooo`?o00008_ooool2o`0000?o2F[L0_l00003o`e^gP03o`000?lRONOo8WgW00?o
8WgW00?o0000od6Akom1TNl01?m1TNl00ol0003oHjCeof>Tm@02of>Tm@So00001_n3]?@00ol0003o
WKo`oifol008oifol003o`000?nba^Wo//KY00_o//KY00?o0000ol39hOo0bN401oo0bN400ol0003o
`M7Vol7AiP04ol7AiP03o`000?o<d]koc=;N00goc=;N0_l0000Aom;Gg003o`000?oFdmKo000000ko
e=SK00Go0000omGBeooEd]OoeM;Go`00000;om3Eg@03o`000?o?c]SoclkH00KoclkH0_l00003olK=
g`;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Kooooo0_l00004
o`UZg0;o00000_l=K]h00ol0003o8WgWob9mi`03ob9mi`03o`000?m1TNoo@I7_00Co@I7_00?o0000
of>TmOmSY?D01OmSY?D00ol0003oPkCdoh>dm008oh>dm003o`000?nM_o3oWKo`00SoWKo`00?o0000
ok;6jOnba^T02onba^T00ol0003o`<WQol39h@04ol39h@;o00002?o1dNH00ol0003oc=;NolcBgP0;
olcBgP04o`000?o<fN?oc=WSo`00013od]OL0_l0000@omCHf`03o`000?oEd]Oo000000god=GM00?o
0000olo>f?o?c]P01?o?c]P00ol0003oa/gOolK=g`04olK=g`03o`000?oooooooooo02;ooooo0009
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0@_ooool3o`0002[ooooo0_l00004o`UZg0Go00001OlRONL00ol0003o@I7_
od6Ak`04od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`
oifol008oifol003o`000?nba^Wo//KY00_o//KY00Co0000ol39hOo0bN7o`<WQ0_l0000;ol7AiP03
o`000?o<d]koc=;N00Soc=;N0_l00004olcIh`03o`000?oBemcod]OL00cod]OL00Co0000om3Lh_o@
g>;o00003ooDf=/2o`0000ood=GM00Co0000olo>f?o?c]SoclkH0_l00008olK=g`03o`000?oooooo
oooo027ooooo0009ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Oooooo00?o0000ooooooooool0?oooool3o`0002kooooo0_l00004o`UZg003o`000?l>
LN3o3W7P00;o00001OlRONL00ol0003o@I7_od6Ak`04od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o
0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol008oifol003o`000?nba^Wo//KY00_o//KY00?o
0000ol39hOl000003_o1dNH00ol0003oc=;NolcBgP06olcBgP03o`000?o<fN?oc=WS00Goc=WS00?o
0000om;Gg?oBem`02_oBem`00ol0003od=cRom3LhP02om3LhP03o`000?oDf=_oe=SK00_oe=SK00Co
0000oloKh_o?fn;o00003oo@eMd00ol0003oclkHo`00000:olK=g`;o00008_ooool000Wooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01oooool00ol0003o
ooooooooo`0looooo`?o0000<_ooool2o`0000Co2F[L00Co0000o`iah?l>LN3o3W7P0ol00003ob9m
i`03o`000?m1TNoo@I7_00Co@I7_00?o0000of>TmOmSY?D01OmSY?D00ol0003oPkCdoh>dm008oh>d
m003o`000?nM_o3oWKo`00SoWKo`00?o0000ok;6jOnba^T02_nba^T3o`0000oo`M7V00?o0000olcB
g_o<d]h01?o<d]h00ol0003oc=WSolcIh`07olcIh`03o`000?oBemcod]OL00Sod]OL00?o0000om3L
h_o@g>801?o@g>800ol0003oe=SKomCHf`08omCHf`;o00001?o?fn800ol0003od=GMom3Eg@0<om3E
g@;o00003?o6cMl2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00004
o`UZg003o`000?l>LN3o3W7P00;o3W7P1?l000000olRONOo0000od6Ak`05od6Ak`03o`000?mSY?Go
HjCe00GoHjCe00?o0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol008oifol003o`000?nba^Wo
//KY00Ko//KY0ol000001?nbcnoo0000ok;?kol0000?ol7AiP04o`000?o<d]koc=;NolcBgP;o0000
2oo<fN<00ol0003od]OLom;Gg005om;Gg0;o00002?o@g>800ol0003oe=SKomCHf`06omCHf`03o`00
0?o?fn;ocm_R00Gocm_R00?o0000om3EgOo@eMd02Oo@eMd2o`000003olOFiOl0003oa/gO00coa/gO
00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0gooooo`?o0000>_ooool3o`0000?o
2F[L00?o0000o`iah?l>LN000_l>LN000ol0003o7goWoamoi`03o`0000Ko@I7_00?o0000of>TmOmS
Y?D01OmSY?D00ol0003oPkCdoh>dm008oh>dm003o`000?nM_o3oWKo`00SoWKo`00?o0000ok;6jOnb
a^T00onba^T2o`0000Go//o_00?o0000ok;?kol000003oo1dNH00ol0003oc=;No`00000>olcIh`03
o`000?oBemcod]OL00?od]OL00?o0000om3Lh_o@g>802Oo@g>800ol0003oe=SKomCHf`04omCHf`03
o`000?o?fn;ocm_R00Oocm_R00?o0000om3EgOo@eMd01oo@eMd00ol0003oamKUolOFi@02olOFi@03
o`000?o6cMooa/gO00[oa/gO0_l0000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000noooo
o`04o`000?lKMn?o0000o`0000;o2F[L00?o0000o`iah?l>LN000_l>LN000ol0003o7goWoamoi`02
oamoi`?o00001?m1TNl00ol0003oHjCeof>Tm@05of>Tm@03o`000?n3]?CoPkCd00SoPkCd00?o0000
oifol?nM_o002?nM_o000ol0003o//KYo`000002o`0000So//o_00?o0000ok;?kol000003_o1dNH3
o`0000ooc=WS00Go0000om;Gg?oBemcod]OLo`00000=om3LhP04o`000?oDf=_oe=SKomCHf`;o0000
2oo?fn800ol0003od=GMom3Eg@04om3Eg@;o00001_o7e^D00ol0003oa/gOolK=g`0:olK=g`;o0000
7oooool002Cooooo00?o0000ooooooooool0<Oooool3o`0004;ooooo00?o0000oa]gholKMn<01?l0
0004o`iah003o`000?lOOnOo7goW00?o7goW1?l00002od6Ak`03o`000?mSY?GoHjCe00GoHjCe00?o
0000oh>dm?n3]?@02?n3]?@00ol0003oWKo`oifol006oifol0Co00002onbcnl00ol0003o//o_o`00
000;ol7AiP;o00000oo1f^`00ol0003oc=WSolcIh`0=olcIh`03o`000?oBemco000000ood=cR00?o
0000omCHfol000003_o?fn801?l0003od=GMom3EgOo@eMd2o`0000WoamKU00?o0000olK=goo6cMl0
2_o6cMl2o`0001kooooo000Tooooo`03o`000?oooooooooo02oooooo0_l00016ooooo`03o`000?lK
Mn?o6gOS00;o6gOS0_l00004o`iah003o`000?lOOnOo7goW00?o7goW00?o0000ocZClOljTo401?l0
0007of>Tm@03o`000?n3]?CoPkCd00SoPkCd00?o0000oifol?nM_o001Ol00004oi_7mP03o`000?nb
cnoo//o_00Wo//o_00?o0000ok;?kol000002Oo1dNH00ol0003o`M[/ol7Jk004ol7Jk003o`000?o<
fN?oc=WS00coc=WS0ol0000?om3LhP?o00003oo?fn800ol0003od=GMo`00000<olOFi@03o`000?o6
cMooa/gO00Woa/gO0_l0000Nooooo`009?ooool00ol0003oooooooooo`0/ooooo`?o0000BOooool0
0ol0003o6gOSoa]gh`03oa]gh`;o00000ol>LN000ol0003o7goWoamoi`03oamoi`03o`000?ljTo7o
>Y?a00;o>Y?a1ol00002of>Tm@03o`000?n3]?CoPkCd00?oPkCd1ol0000:oi_7mP03o`000?nbcnoo
//o_00Wo//o_00?o0000ok;?kol000001_o1dNH2o`0000So`M[/00?o0000olcIhoo<fN<02Oo<fN<2
o`0000?obN3Y00?o0000om3Lh_o@g>802oo@g>801Ol0003obn7Yol_QjOo;hNWo000000kocm_R0ol0
000=olOFi@03o`000?o6cMooa/gO00Koa/gO0_l000000onjbnOo0000o`00000Mooooo`009?ooool0
0ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003o6gOSoa]gh`03oa]gh`?o00000_l>LN00
0ol0003o7goWoamoi`03oamoi`03o`000?ljTo7o>Y?a00Co>Y?a00Co0000oebXn?mLZ?SoG:Sh2?l0
0007ogjknP03o`000?nKaoKoVlOf00SoVlOf00?o0000ok;?konbcnl02Onbcnl00ol0003o//o_o`00
0003ol7AiP;o00002oo1f^`00ol0003oc=WSolcIh`07olcIh`03o`000?o9h>WobN3Y00CobN3Y0_l0
0009om3LhP;o00001Oo;hNT00ol0003ocm_RoloKhP0:oloKhP05o`000?o6g^_oa]k[olKNjol00000
3Oo7e^D00ol0003oa/gOolK=g`02olK=g`?o00001?njbnL2o`0001cooooo000Tooooo`03o`000?oo
oooooooo02Kooooo0ol0001Aooooo`03o`000?lKMn?o6gOS00?o6gOS00?o0000oa]li_l000000ol0
0005oamoi`03o`000?ljTo7o>Y?a00Co>Y?a00?o0000oebXn?mLZ?P01OmLZ?P00ol0003oO[_jogjk
nP08ogjknP03o`000?nKaoKoVlOf00SoVlOf0_l0000:ok;?k`05o`000?nbcnoo0000ol7Ai_l00000
3_o1f^`00ol0003oc=WSolcIh`04olcIh`;o00002Oo9h>T00ol0003od=cRom3LhP05om3LhP03o`00
0?o;hNWobn7Y00Kobn7Y0_l00008oloKhP;o00001Oo6g^/00ol0003oamKUolOFi@0;olOFi@04o`00
0?o6cMoo0000o`0000So^/_W0_l0000Kooooo`008oooool2o`0002Gooooo0ol0001Eooooo`03o`00
0?lKMn?o6gOS00?o6gOS00Co0000oa]li_lKO>Ko6gcV0_l00005oamoi`03o`000?ljTo7o>Y?a00Co
>Y?a00?o0000oebXn?mLZ?P01OmLZ?P00ol0003oO[_jogjknP08ogjknP03o`000?nKaoKoVlOf00Wo
VlOf00?o0000ok;?konbcnl01onbcnl00ol0003o//o_o`000002o`0000oo`M[/00Co0000olcIhoo<
fN?oc=WS0_l0000<olWPj@;o00000oo@g>82o`0000_obn7Y00?o0000oloKh_o?fn801?o?fn800ol0
003oa]k[olKNj`06olKNj`03o`000?o7e^GoamKU00[oamKU0_l0000;ok[;i`03o`000?oooooooooo
01Wooooo000Tooooo`03o`000?oooooooooo023ooooo0ol0001Iooooo`03o`000?lKMn?o6gOS00?o
6gOS00?o0000oa]li_lKO>H00_lKO>H3o`0000?o7goW00?o0000ocZClOljTo401?ljTo400ol0003o
G:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH02OnKaoH00ol0003o
//o_ok;?k`06ok;?k`;o00000on`eo@00ol0003o`M[/ol7Jk00=ol7Jk003o`000?o<fN?o0000013o
bN3Y00?o0000om3Lh_l000003_o;hNT01?l0003ocm_RoloKh_o?fn82o`0000[oa]k[00?o0000olOF
iOo7e^D01oo7e^D2o`000003ok[DkOl0003o^/_W00_o^/_W00?o0000ooooooooool06?ooool002?o
oooo00?o0000ooooooooool07_ooool3o`0005gooooo00?o0000oa]gholKMn<00olKMn<00ol0003o
6gcVoa]liP03oa]liPCo000000?o7goWo`000?ljTo401OljTo400ol0003oG:ShoebXn005oebXn003
o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH02OnKaoH00ol0003o//o_ok;?k`02ok;?k`?o
00000_n`eo@01?l0003o/=Odok3Gm?n`eo@2o`0000go`M[/0ol0000@olWPj@?o00003oo;hNT00ol0
003ocm_Ro`00000=olKNj`03o`000?o7e^GoamKU00CoamKU0_l00004ok[Dk@03o`000?njbnOo^/_W
00[o^/_W00?o0000ooooooooool05oooool002?ooooo00?o0000ooooooooool06oooool3o`00067o
oooo00?o0000oa]gholKMn<00olKMn<00ol0003o6gcVoa]liP03oa]liP03o`000?lVR>_o9XS[00?o
00001_ljTo400ol0003oG:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nK
aoH02OnKaoH01?l0003o//o_o`000?l00006ok3Gm003o`000?n`eoCo/=Od00;o/=Od00?o0000ol7J
k?o1f^`02?o1f^`2o`0000?o_N7a0_l0000=olWPj@05o`000?o3i^oo`nK_ol?Vkol000003_o;hNT3
o`0000koa]k[00?o0000olOFiOo7e^D00_o7e^D00ol0003o^]C]ok[Dk@05ok[Dk@03o`000?njbnOo
^/_W00Wo^/_W0_l0000Hooooo`008oooool00ol0003oooooooooo`0Hooooo`?o0000IOooool3o`00
00?o6gOS00?o0000oa]li_lKO>H00olKO>H00ol0003o9XS[obJ8j`02obJ8j`?o00001?ljTo400ol0
003oG:ShoebXn005oebXn003o`000?mn^o[oO[_j00SoO[_j00?o0000oi_7m_nKaoH01onKaoH4o`00
00So/=Od00?o0000ok3Gm?n`eo@00_n`eo@00ol0003o`M[/ol7Jk005ol7Jk0;o00001onmhO400ol0
003obN3YolWPj@08olWPj@;o00001Oo3i^l2o`0000[obn7Y0_l00003ol7Tl003o`000?o6g^_oa]k[
00coa]k[00Co0000olOFiOl0003o00002Onje>d00ol0003o^/_Wok[;i`09ok[;i`03o`000?oooooo
oooo01Kooooo000Sooooo`03o`000?oooooooooo01Gooooo0ol0001Xooooo`03o`000?lhR>co>8S/
00?o000000?o6gOSo`000?lKO>H01?lKO>H00ol0003o9XS[obJ8j`03obJ8j`Oo00001omLZ?P00ol0
003oO[_jogjknP08ogjknP04o`000?nKaoKoVlOfoi_7mPGo00001?nHd?/00ol0003o/=Odok3Gm006
ok3Gm003o`000?n`eoCo/=Od00;o/=Od0_l00004ol7Jk003o`000?nmhO7o_N7a00So_N7a0_l00007
olWPj@03o`000?o3i^oo`nK_00Oo`nK_00?o0000ol_QjOo;hNT01Oo;hNT2o`0000Ko`NC`00?o0000
olKNjoo6g^/02oo6g^/3o`0000_o^]C]00?o0000ok[;ionjbnL02OnjbnL00ol0003oooooooooo`0E
ooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003o>8S/ocR8k002ocR8
k0?o00001OlKO>H00ol0003o9XS[obJ8j`03obJ8j`03o`000?llV_?o?9[c00;o?9[c1ol00002oebX
n003o`000?mn^o[oO[_j00?oO[_j2?l0000:oiS@n`03o`000?n`eoCo/=Od00Ko/=Od00?o0000ok3G
m?n`eo@00on`eo@01?l0003o`M[/o`000?l0000=okgQl@;o00000oo9h>T2o`0000_o`nK_0_l00004
ol_Qj@03o`000?o1i?3o`NC`00Oo`NC`0_l00008olKNj`?o00000onhgO<00ol0003o^]C]ok[Dk@09
ok[Dk@03o`000?njbnOo^/_W00Wo^/_W00?o0000ooooooooool05?ooool002;ooooo0ol0000@oooo
o`?o0000L?ooool00ol0003o>8S/ocR8k004ocR8k0?o00000olKO>H00ol0003o9XS[obJ8j`03obJ8
j`03o`000?llV_?o?9[c00Co?9[c00Co0000oeZ_n_mJ[o[oFZoj2?l00007og[2o@03o`000?nHd?_o
V=3k00WoV=3k0_l00007ok3Gm003o`000?n`eoCo/=Od00;o/=Od0ol0000@okgQl@03o`000?o9h>Wo
000000oo`nK_00Co0000ol_QjOl0003o00003?o1i?000ol0003oa]k[olKNj`03olKNj`;o00001onh
gO<00ol0003o^]C]ok[Dk@09ok[Dk@03o`000?njbnOo^/_W00Oo^/_W0ol0000Eooooo`008oooool0
0ol0003oooooooooo`0<ooooo`?o0000M?ooool00ol0003o>8S/ocR8k004ocR8k003o`000?lcSNko
000000;o000000?o6gcVo`000?lVR>/01?lVR>/2o`0000Go?9[c00?o0000oeZ_n_mJ[oX01OmJ[oX0
0ol0003oN/;mog[2o@08og[2o@;o00002onHd?/00ol0003o/=Odok3Gm004ok3Gm003o`000?n`eoCo
000000;o00000on/goT00ol0003o_N7aokgQl@0=okgQl@?o00003oo3i^l3o`0000ko`NC`00?o0000
olKNjol000000_l0000:okSMl`03o`000?nje>go^]C]00Wo^]C]00Co0000ok[;ionjbnOo^/_W1Ol0
0002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Wooooo0ol0001h
ooooo`03o`000?lhR>co>8S/00Co>8S/00Co0000oc>=k_lcSNko<hg^0ol00006obJ8j`03o`000?ll
V_?o?9[c00?o?9[c00?o0000oeZ_n_mJ[oX01OmJ[oX2o`0000[oN/;m00?o0000oiS@nonHd?/02OnH
d?/00ol0003o/=Odok3Gm003ok3Gm0;o00001on/goT2o`0000_o_N7a0_l00003okKWmP;o00002oo3
i^l2o`0000?o^>Se00?o0000ol7Tl?o1i?002oo1i?03o`0000go^=gc00?o0000ok[DkOnje>d02?nj
e>d6o`0000Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool01_ooool3
o`0007cooooo00?o0000ocR8k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP03oc>=kP?o00001?lVR>/0
0ol0003o?9[cocbJl`03ocbJl`;o00001omJ[oX00ol0003oN/;mog[2o@08og[2o@03o`000?nHd?_o
V=3k00WoV=3k00?o0000ok3Gm?l000000_l00002ojcOn@03o`000?n/goWo[=oi00Ko[=oi00?o0000
okgQlOnmhO401_nmhO42o`0000Oo]^Of0_l00007ol?Vk`;o00001_nhj?D2o`0000Wo`NC`0_l00003
ok;Tm`03o`000?nhgO?o^=gc00_o^=gc00?o0000ok[DkOnje>d01?nje>d6o`0000Sooooo00?o0000
ooooooooool04oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo00?o0000ocR8
k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=kPOo00001_llV_<00ol0003oFZojoeZ_nP05oeZ_
nP03o`000?mj`_goN/;m00SoN/;m0_l00008oiS@n`Co00001On/goT00ol0003o[=oiojcOn@06ojcO
n@;o00001?nmhO42o`0000_o]^Of00?o0000ol?Vkoo3i^l00oo3i^l00ol0003o^>SeokSXm@08okSX
m@;o00001?o1i?03o`0000Ko/^Cg0_l0000<okSMl`03o`000?nje>go^]C]00Go00003?ooool00ol0
003oooooooooo`0Cooooo`008_ooool01?l0003oooooooooooooool3o`0008Cooooo00?o0000ocR8
k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=kP03o`000?lhUo;o>9Ob00;o>9Ob1?l00004ocbJ
l`03o`000?mJ[o[oFZoj00GoFZoj0_l0000:og[2o@03o`000?nHd?_oV=3k00Go00001?nDeoh2o`00
00Co[=oi00?o0000ojcOnOn/goT01on/goT01?l0003o_N7ao`000?l0000>okKWmP;o000000?o`nK_
o`000?l000003Onhj?D01?l0003o`NC`o`000?l0000;ok;Tm`03o`000?nhgO?o^=gc00Wo^=gc1Ol0
000?ooooo`03o`000?oooooooooo01?ooooo000Rooooo`Co0000R?ooool00ol0003o>8S/ocR8k004
ocR8k003o`000?lcSNko<hg^00Co<hg^00?o0000ocRGl_lhUo801?lhUo87o`0000SoFZoj00?o0000
og[2oOmj`_d00omj`_d7o`0000_oU=On0_l00003ojcOn@03o`000?n/goWo[=oi00Ko[=oi0ol0000@
okKWmP?o00003_nhj?D3o`0000go/^Cg0_l00006okSMl`Go00004_ooool00ol0003oooooooooo`0C
ooooo`008_ooool3o`0008[ooooo00?o0000ocR8k?lhR>`01?lhR>`00ol0003o<hg^oc>=kP04oc>=
kP;o00001OlhUo800ol0003oAZKgodJVm`02odJVm`oo00001omibOl2o`0000_oU=On0_l00002ojcO
n@03o`000?n/goWo[=oi00;o[=oi0ol00003ojGTn`;o00002onfioH3o`0000?o[>Wi0_l0000:okSX
m@;o00000onZioX00ol0003o/^Cgok;Tm`0<ok;Tm`03o`000?nhgO?o^=gc00Co00005oooool00ol0
003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`29ooooo`?o00001?lhR>`00ol0003o
<hg^oc>=kP05oc>=kP03o`000?lhUo;o>9Ob00?o>9Ob00?o0000odJVmom6Y_L01?m6Y_L2o`0000Oo
GKSl0_l0000:ogW9o`;o00002onDeoh3o`000004ojcOnOl0003o0000o`0000SoYNCk0ol00006okKW
mP;o00002?n/jOT2o`0000Go^>Se0ol00006oj[WnP;o00002onbi?L5o`0001[ooooo00?o0000oooo
ooooool04_ooool001Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03
o`000?oooooooooo08Wooooo00?o0000oeVJlOl000001Ol00007oc>=kP03o`000?lhUo;o>9Ob00?o
>9Ob0_l00006odJVm`03o`000?mM^?coGKSl00KoGKSl00?o0000ogW9oomibOl02OmibOl00ol0003o
U=OnoiCGoP08oiCGoPCo00003_nUi?/2o`000004okKWm_l0003o0000o`0000co[>Wi0_l000000onh
j?Go0000o`00000;oj[WnP;o00001_nbi?L5o`0001gooooo00?o0000ooooooooool04_ooool001Ko
oooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo08Wooooo00?o0000oeVJ
lOmIV_400omIV_47o`0000;o<hg^00?o0000ocRGl_lhUo801?lhUo800ol0003oAZKgodJVm`04odJV
m`;o00001omM^?`2o`0000[oNLWo0_l00003oiCGoPGo00001?n@g?h2o`0000goYNCk1?l0000>ojcY
n@?o00003_nZioX00ol0003o/^Cgok;Tm`04o`00027ooooo00?o0000ooooooooool04_ooool001Ko
oooo00Go410@oooooooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000oeVJ
lOmIV_401OmIV_401?l0003oDj3eoe>PmOmCX?D6o`0000Co>9Ob00?o0000odJVmom6Y_L01Om6Y_L2
o`0000OoGKSl0_l00008ogW9o`Go00002_n@g?h4o`0000OoYNCk0ol00004oigVo0?o00002?n/jOT3
o`0000?oX>Sk0_l0000<oj[WnPCo00009?ooool00ol0003oooooooooo`0Booooo`005_ooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool0ROooool00ol0003oFI[aoeVJl@05oeVJ
l@03o`000?mCX?GoDj3e00GoDj3e1ol00008odJVm`03o`000?mM^?coGKSl00KoGKSl00?o0000ogW9
oomibOl01Ol00004og[@o`;o00002_n@g?h00ol0003oT=cnoi3LoP02o`0000;oYNCk0ol0000:oigV
o0?o00000_n/jOT3o`0000SoX>Sk0_l00007oj[WnPCo00009oooool00ol0003oooooooooo`0Boooo
o`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0ROooool00ol0003o
FI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00GoDj3e00?o0000oe>YnOmCZOT00_mCZOTEo`0000_o
N]3o0_l00009oi3LoP03o`000?n@g?koT=cn00Co00003_nMi_`3o`0000goX>Sk0_l00002oj[WnPCo
0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oo
oooo00?o0000ooooooooool0ROooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00Go
Dj3e00?o0000oe>YnOmCZOT01?mCZOT00ol0003oFKCloeVdo006oeVdo0;o00001omW`_h3o`0000[o
N]3o0_l00007oi3LoP?o00001?n>h?h3o`0000SoWNKl0ol00003oiKVo0?o00002_nPj?/4o`0002ko
oooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o
0000R_ooool00ol0003oFI[aoeVJl@05oeVJl@03o`000?mCX?GoDj3e00GoDj3e0_l00005oe>Yn@;o
00002?mI]?`2o`0000SoIl;n0_l0000:og[@o`;o00000_n@g?h3o`0000;oS^3n00?o0000ohkPo_n>
h?h01On>h?h3o`0000;oWNKl0ol00009oiKVo0?o00000_nPj?/6o`00037ooooo00?o0000oooooooo
ool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03o`000?oooooooooo08So
oooo00?o0000oeVJlOmIV_401OmIV_400ol0003oDj3eoe>Pm@06oe>Pm@03o`000?mCZOWoDjWi00Co
DjWi00?o0000oeVdo?mI]?`01omI]?`00ol0003oIl;nofO2oP07ofO2oP?o00001Omjd?l7o`0000Co
S^3n00?o0000ohkPo_n>h?h01on>h?h3o`0000koU^Kl1_l0000dooooo`03o`000?oooooooooo01;o
oooo000/ooooo`03o`000?oooooo000008[ooooo00?o0000oeVJlOmIV_401OmIV_400ol0003oDj3e
oe>Pm@06oe>Pm@03o`000?mCZOWoDjWi00CoDjWi0_l00008oeVdo0;o00001OmW`_h:o`0000OoPMOo
0ol00002ohkPoP03o`000?n>h?koS^3n00?oS^3n0ol00003ohoRo@?o00002?nFi_`5o`0003Sooooo
00?o0000ooooooooool04_ooool002oooooo00?o0000ooooooooool0R?ooool6o`0000;oFI[a00?o
0000oe>PmOmCX?D01_mCX?D00ol0003oDjWioe>Yn@05oe>Yn@03o`000?mI]?coFKCl00?oFKCl2Ol0
0007ogO>o`;o00002on1eol4o`000004ohkPo_l0003o0000o`0000WoSn;m0ol00002oiKVo0Go0000
??ooool00ol0003oooooooooo`0Aooooo`00<?ooool00ol0003oooooooooo`27ooooo`;o00001?mi
Z_8Io`0000KoL/Co0_l0000:ogO>o`?o00002On1eol4o`0000koSn;m1Ol0000oooooo`03o`000?oo
oooooooo017ooooo000aooooo`03o`000?oooooooooo08Oooooo0_l00008ogVZlP03o`000?md/_So
M;;h00KoM;;h00?o0000og:jo?mb^_`01Omb^_`2o`0000WoL/Co0_l0000;ogO>o`;o00000_n1eol5
o`0000CoRmkn0ol00008ohoRo@Co0000@oooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0
003oooooooooo`27ooooo`;o00002?miZ_800ol0003oM;;hogBbn006ogBbn003o`000?mb^_coL[[l
00KoL[[l00?o0000og;4oomba?l02?mba?l2o`0000WoMlko1?l0000:oh_NoP03o`000?n;g_ko0000
00;o00000_n?h_d4o`0004Kooooo00?o0000ooooooooool04Oooool003?ooooo00?o0000oooooooo
ool0Qoooool2o`0000SoNJ[b00?o0000ogBbn?md/_P01_md/_P2o`0000OoL[[l0_l0000:og;4o`;o
00000_mgc_l5o`0000CoRmSo0_l00009oh_NoP03o`000?n;g_koRmkn00Co0000BOooool00ol0003o
ooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00008ogVZlP03o`000?md/_SoM;;h00OoM;;h
00?o0000og:jo?mb^_`01_mb^_`2o`0000SoL/Co1?l0000;oh_Ho`;o00001on;g_h3o`0004gooooo
00?o0000ooooooooool04Oooool003Kooooo00?o0000ooooooooool0Q_ooool2o`0000SoNJ[b00?o
0000ogBbn?md/_P01omd/_P00ol0003oL[[log:jo007og:jo003o`000?mba?ooL/Co00Go00001?n<
d?h2o`0000_oRmSo0_l00002oh_NoP?o000000?oooooo`000?ooool0COooool00ol0003ooooooooo
o`0Aooooo`00=oooool2o`0008Oooooo0_l00008ogVZlP03o`000?md/_SoM;;h00OoM;;h00?o0000
og:jo?mb^_`00omb^_`6o`0000_oS=3n0_l00009oh_Ho`Co00001Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00008ogVZ
lP03o`000?md/_SoM;;h00?oM;;h2Ol00006oho8n`;o00002on<d?h2o`0000;oRmSo1Ol0000:oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04Oooool003Wooooo00?o0000oooooooo
ool0Q_ooool2o`0000CoNJ[b2Ol00006oi:nm@03o`000?n?b?_oSlSk00SoSlSk0_l0000:ohc@oPGo
00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`00
0?oooooooooo08Kooooo1Ol00006oiFfkP03o`000?nB__GoT[ke00OoT[ke00?o0000oho8non?b?/0
2On?b?/00ol0003oS=3nohc@oP04ohc@oPGo00004_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000oiFfk_nE]^h02?nE
]^h00ol0003oT[keoi:nm@07oi:nm@;o00002_n?b?/2o`000003ohc@o_l0003o000000;o00005ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooo
oooo08Kooooo00?o0000oiFfk_nE]^h02?nE]^h00ol0003oT[keoi:nm@08oi:nm@03o`000?n?b?_o
SlSk00SoSlSk0ol0000Kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04?ooool0
03gooooo0_l00027ooooo`03o`000?nE]^koUKK^00SoUKK^00?o0000oi:nmOnB__D02?nB__D00ol0
003oSlSkoho8n`04oho8n`?o00007oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
013ooooo000oooooo`03o`000?oooooooooo08Gooooo00?o0000oiFfk_nE]^h02?nE]^h00ol0003o
T[keoi:nm@08oi:nm@03o`000?n?b?_oSlSk00?o00008_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo013ooooo0010ooooo`03o`000?oooooooooo08Gooooo00?o0000oiFfk_nE]^h0
2?nE]^h00ol0003oT[keoi:nm@06oi:nm@Co00009_ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo013ooooo0011ooooo`;o0000Q_ooool00ol0003oUKK^oiFfkP08oiFfkP03o`000?nB
__GoT[ke00Go0000:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo0010
ooooo`03o`000?oooooo000008Oooooo00?o0000oiFfk_nE]^h01onE]^h5o`0002oooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`25oooo
o`03o`000?nE]^koUKK^00?oUKK^1?l0000dooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool04?ooool004Cooooo00?o0000ooooooooool0QOooool00ol0003oUKK^o`000003o`0003So
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool00ol0003ooooo
ooooo`25ooooo`;o0000??ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo
0016ooooo`;o0000QOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool04?ooool004Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool03oooool004[ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool03oooool004[ooooo0_l00021ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`00C?oo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`00C_ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`000?oooooooooo07Wooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo
001Booooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00oooooo001Cooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo001Doooo
o`?o0000M_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool03oooool005Cooooo0_l0001gooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>oooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Sooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00Sooooo0_l0001cooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool02oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`00013ooooo0_l0001^ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`00Goooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>oooo
o`00H?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0>ooooo`00HOooool2o`0006[ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00gooooo001Sooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00gooooo001Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo001Uooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00gooooo001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00gooooo001Vooooo`?o0000I?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool006Sooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool03Oooool006Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1G
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006[ooooo0_l0001Qoooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=oooo
o`00K?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0=ooooo`00KOooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00K_oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`00Koooool3o`00
05_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00cooooo001aooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001booooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo
001cooooo`;o0000F?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03?ooool007Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool007Kooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool007Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`00N?oo
ool2o`0005?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00cooooo001jooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo001kooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00_ooooo001looooo`;o0000Coooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool007kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool007oooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02oooool0083ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0087ooooo0ol00019oooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;oooo
o`00M_ooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool007Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00[ooooo0_l00016
ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;
ooooo`00G?ooool3o`000003oa0@4?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`00G_ooool00ol@413o^[Zjooooo`0Gooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool005kooooo00?oV9RHoc8b<_ooool05oooool00ol0003ooooo
ooooo`0>ooooo`;o0000@_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool005kooooo00?ogMgMo`000?nj^[X05Oooool00omEEEGoIVIVo`00
000@ooooo`;o0000@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02_ooool005kooooo00?oEEEEogMgMom4A4@0:_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:
ooooo`00GOooool01OoMgMgo410@oooooolQ8B7ogMgM02[ooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool0
05gooooo00GoIVIVohN7QoooooooV9RHoeEEE@0[ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Loooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0:_ooool2o`0003gooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo001Looooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0:oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`00TOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0:ooooo`00TOooool2o`0003[ooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo002Cooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo002Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo002Eooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo002Fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0NOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo002Gooooo`;o0000=?ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool009Wooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool009Wooooo0ol0000aooooo`03o`000?oooooooooo07cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00Voooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`00W?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`00WOooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00W_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`00Woooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00X?ooool2o`00
02_ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo002Qooooo`;o0000:_ooool00ol0003oooooooooo`22ooooo`05o`000?oooooooooooooo
ool000002_ooool00:?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`23ooooo`04
o`000?ooooooooooo`0000[ooooo002Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooo`00000:ooooo`00YOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo08Gooooo0_l0000:ooooo`00Y_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo08Cooooo0ol0000:ooooo`00Yoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo083ooooo1?l0000=ooooo`00Z?ooool01?l0003oooooo`000?l0000Qooooo`03o`000?oooooo
oooo07cooooo1?l0000Aooooo`00S_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01_ooool2o`0002;ooooo00?o0000ooooooooool0N?ooool4
o`0001Gooooo002@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`Co00006Oooool0093o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0L?ooool4o`0001gooooo002@ooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06gooooo
0ol0000Qooooo`00T?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06Wooooo1?l0000Tooooo`00T?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Uooooo`Co0000:?ooool0093ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0?ooooo`?o00006_ooool00ol0003oooooooooo`1Qooooo`Co0000;?ooool0
08kooooo00?oEEEEofIVI_l000003Oooool4o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo
05gooooo1?l0000`ooooo`00/_ooool2o`0001Wooooo00?o0000ooooooooool0FOooool4o`0003Co
oooo002dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0EOooool4o`0003Sooooo
002eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool4o`0003cooooo002f
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0COooool4o`00043ooooo002goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool4o`0004Cooooo002hooooo`;o
00004oooool00ol0003oooooooooo`15ooooo`Co0000B?ooool00;Wooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`11ooooo`Co0000C?ooool00;[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0nooooo`?o0000D?ooool00;_ooooo0_l0000@ooooo`03o`000?oooooo
oooo03[ooooo1?l0001Cooooo`00_Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03Kooooo1?l0001Gooooo`00__ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;o
oooo1?l0001Kooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0;_ooool4o`0005oooooo
002oooooo`;o00003?ooool00ol0003oooooooooo`0Zooooo`Co0000Hoooool00<7ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`Co0000Ioooool00<;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`Co0000Joooool00<?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`Co0000Koooool00<Cooooo0_l00007ooooo`03o`00
0?oooooooooo01[ooooo1?l0001cooooo`00a_ooool3o`0000Cooooo00?o0000ooooooooool05_oo
ool4o`0007Oooooo0036ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`?o0000Noooool0
0<Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`Co0000O_ooool00<Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`Co0000P_ooool00<[ooooo00Co0000oooooooo
oooo00002Oooool4o`0008Kooooo003;ooooo`03o`000?oooooo000000Gooooo1?l0002:ooooo`00
c?ooool7o`0008kooooo0032ooooo`Go00001_ooool2o`0009;ooooo0032ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@0V_ooool00<?ooooo00?oV9RHob4Q8Oo^k^h0Voooool00<Cooooo00?oV9RHob4Q
8Oo^k^h0V_ooool00<Gooooo00?oMgMgofIVI_ooool0VOooool00<Kooooo00?o0000ooooooooool0
V?ooool00<;ooooo00Go0000okZj^_ooooooV9RHoa0@402Jooooo`00`_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<09[ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;o
oooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;o
oooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo002Uooooo`?o
000000?o410@ooooooooool0]_ooool009?ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00Cooooo
00?o410@okZj^_ooool01Oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2Iooooo`00Toooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8boooo
o`05ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8bV_ooool008Sooooo00Go410@
o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj
^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo06oooooo002:ooooo`03o`000?oooooooooo
00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co
0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005oooo
o`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0L?ooool008[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo
8B4QomgMg@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00077ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:oooo
o`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0007;ooooo002:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo
00?o0000omgMgOooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoo
oooo0000L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l00000L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000007;ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool0
1Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00go
oooo00?oMgMgo`000?ooool0LOooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.608 .72 .924 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68293 Metetra
.604 .746 .945 r
.55403 .68293 .58394 .7109 .61197 .70234 .58238 .6779 Metetra
.6 .773 .962 r
.58238 .6779 .61197 .70234 .64019 .69372 .61096 .67244 Metetra
.599 .799 .976 r
.61096 .67244 .64019 .69372 .66861 .68504 .63977 .66638 Metetra
.601 .823 .985 r
.63977 .66638 .66861 .68504 .69723 .6763 .6688 .65956 Metetra
.608 .843 .988 r
.6688 .65956 .69723 .6763 .72605 .6675 .69804 .65188 Metetra
.62 .857 .988 r
.69804 .65188 .72605 .6675 .75507 .65863 .72747 .64326 Metetra
.637 .866 .985 r
.72747 .64326 .75507 .65863 .7843 .6497 .75708 .63367 Metetra
.657 .868 .979 r
.75708 .63367 .7843 .6497 .81374 .64071 .78685 .62314 Metetra
.677 .862 .97 r
.78685 .62314 .81374 .64071 .84339 .63166 .81678 .61172 Metetra
.694 .849 .957 r
.81678 .61172 .84339 .63166 .87325 .62254 .84685 .59951 Metetra
.706 .83 .941 r
.84685 .59951 .87325 .62254 .90333 .61335 .87706 .58667 Metetra
.712 .806 .923 r
.87706 .58667 .90333 .61335 .93362 .6041 .90742 .57337 Metetra
.713 .78 .905 r
.90742 .57337 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.539 .694 .94 r
.49498 .6552 .52593 .68772 .55403 .68293 .5233 .65398 Metetra
.532 .718 .958 r
.5233 .65398 .55403 .68293 .58238 .6779 .55191 .65234 Metetra
.532 .745 .973 r
.55191 .65234 .58238 .6779 .61096 .67244 .58081 .64992 Metetra
.54 .773 .984 r
.58081 .64992 .61096 .67244 .63977 .66638 .60998 .64638 Metetra
.557 .802 .99 r
.60998 .64638 .63977 .66638 .6688 .65956 .63941 .64142 Metetra
.583 .828 .991 r
.63941 .64142 .6688 .65956 .69804 .65188 .66905 .63482 Metetra
.615 .848 .987 r
.66905 .63482 .69804 .65188 .72747 .64326 .69889 .62643 Metetra
.651 .862 .98 r
.69889 .62643 .72747 .64326 .75708 .63367 .72889 .61617 Metetra
.684 .867 .968 r
.72889 .61617 .75708 .63367 .78685 .62314 .75901 .60412 Metetra
.712 .864 .954 r
.75901 .60412 .78685 .62314 .81678 .61172 .78924 .59038 Metetra
.733 .852 .937 r
.78924 .59038 .81678 .61172 .84685 .59951 .81956 .57517 Metetra
.746 .834 .919 r
.81956 .57517 .84685 .59951 .87706 .58667 .84996 .55877 Metetra
.751 .813 .901 r
.84996 .55877 .87706 .58667 .90742 .57337 .88045 .54153 Metetra
.751 .789 .884 r
.88045 .54153 .90742 .57337 .93794 .55978 .91103 .52381 Metetra
.461 .66 .947 r
.4632 .62183 .49498 .6552 .5233 .65398 .4917 .62382 Metetra
.455 .682 .962 r
.4917 .62382 .5233 .65398 .55191 .65234 .52054 .62525 Metetra
.461 .709 .975 r
.52054 .62525 .55191 .65234 .58081 .64992 .54972 .6256 Metetra
.483 .742 .985 r
.54972 .6256 .58081 .64992 .60998 .64638 .57921 .62435 Metetra
.519 .776 .99 r
.57921 .62435 .60998 .64638 .63941 .64142 .609 .62107 Metetra
.565 .809 .99 r
.609 .62107 .63941 .64142 .66905 .63482 .63903 .61543 Metetra
.615 .835 .984 r
.63903 .61543 .66905 .63482 .69889 .62643 .66926 .60722 Metetra
.664 .852 .972 r
.66926 .60722 .69889 .62643 .72889 .61617 .69965 .59633 Metetra
.706 .859 .955 r
.69965 .59633 .72889 .61617 .75901 .60412 .73015 .58283 Metetra
.739 .856 .935 r
.73015 .58283 .75901 .60412 .78924 .59038 .76072 .56693 Metetra
.761 .846 .915 r
.76072 .56693 .78924 .59038 .81956 .57517 .79134 .54892 Metetra
.774 .831 .896 r
.79134 .54892 .81956 .57517 .84996 .55877 .82198 .52923 Metetra
.78 .813 .879 r
.82198 .52923 .84996 .55877 .88045 .54153 .85265 .50836 Metetra
.779 .793 .864 r
.85265 .50836 .88045 .54153 .91103 .52381 .88337 .48685 Metetra
.384 .623 .947 r
.43058 .58756 .4632 .62183 .4917 .62382 .45921 .59224 Metetra
.382 .642 .958 r
.45921 .59224 .4917 .62382 .52054 .62525 .48824 .59624 Metetra
.399 .671 .97 r
.48824 .59624 .52054 .62525 .54972 .6256 .51765 .5989 Metetra
.438 .708 .98 r
.51765 .5989 .54972 .6256 .57921 .62435 .54743 .59957 Metetra
.492 .749 .986 r
.54743 .59957 .57921 .62435 .609 .62107 .57754 .59768 Metetra
.556 .787 .985 r
.57754 .59768 .609 .62107 .63903 .61543 .60794 .59282 Metetra
.619 .816 .976 r
.60794 .59282 .63903 .61543 .66926 .60722 .63856 .58472 Metetra
.676 .835 .96 r
.63856 .58472 .66926 .60722 .69965 .59633 .66934 .57323 Metetra
.722 .843 .939 r
.66934 .57323 .69965 .59633 .73015 .58283 .70023 .55846 Metetra
.756 .842 .916 r
.70023 .55846 .73015 .58283 .76072 .56693 .73117 .54065 Metetra
.779 .835 .895 r
.73117 .54065 .76072 .56693 .79134 .54892 .76212 .5202 Metetra
.793 .823 .876 r
.76212 .5202 .79134 .54892 .82198 .52923 .79306 .49764 Metetra
.798 .809 .86 r
.79306 .49764 .82198 .52923 .85265 .50836 .82399 .47363 Metetra
.798 .793 .848 r
.82399 .47363 .85265 .50836 .88337 .48685 .85493 .44884 Metetra
.319 .589 .941 r
.39706 .55236 .43058 .58756 .45921 .59224 .42581 .55903 Metetra
.325 .607 .95 r
.42581 .55903 .45921 .59224 .48824 .59624 .455 .56495 Metetra
.355 .638 .961 r
.455 .56495 .48824 .59624 .51765 .5989 .48461 .56933 Metetra
.409 .679 .972 r
.48461 .56933 .51765 .5989 .54743 .59957 .51464 .57141 Metetra
.479 .724 .978 r
.51464 .57141 .54743 .59957 .57754 .59768 .54505 .57053 Metetra
.553 .764 .976 r
.54505 .57053 .57754 .59768 .60794 .59282 .57578 .56621 Metetra
.624 .794 .964 r
.57578 .56621 .60794 .59282 .63856 .58472 .60676 .55812 Metetra
.684 .814 .945 r
.60676 .55812 .63856 .58472 .66934 .57323 .63793 .54609 Metetra
.731 .822 .922 r
.63793 .54609 .66934 .57323 .70023 .55846 .66922 .53026 Metetra
.765 .824 .898 r
.66922 .53026 .70023 .55846 .73117 .54065 .70055 .5109 Metetra
.788 .819 .877 r
.70055 .5109 .73117 .54065 .76212 .5202 .73188 .48848 Metetra
.802 .812 .859 r
.73188 .48848 .76212 .5202 .79306 .49764 .76318 .46363 Metetra
.809 .802 .845 r
.76318 .46363 .79306 .49764 .82399 .47363 .79444 .43713 Metetra
.81 .791 .835 r
.79444 .43713 .82399 .47363 .85493 .44884 .82567 .40974 Metetra
.275 .564 .934 r
.36263 .5162 .39706 .55236 .42581 .55903 .39148 .52405 Metetra
.291 .583 .942 r
.39148 .52405 .42581 .55903 .455 .56495 .4208 .5311 Metetra
.334 .616 .953 r
.4208 .5311 .455 .56495 .48461 .56933 .4506 .53649 Metetra
.4 .658 .963 r
.4506 .53649 .48461 .56933 .51464 .57141 .48085 .53938 Metetra
.478 .702 .967 r
.48085 .53938 .51464 .57141 .54505 .57053 .51152 .53905 Metetra
.557 .741 .962 r
.51152 .53905 .54505 .57053 .57578 .56621 .54255 .53497 Metetra
.628 .77 .948 r
.54255 .53497 .57578 .56621 .60676 .55812 .57388 .52678 Metetra
.688 .789 .927 r
.57388 .52678 .60676 .55812 .63793 .54609 .60543 .51429 Metetra
.734 .799 .904 r
.60543 .51429 .63793 .54609 .66922 .53026 .63711 .49765 Metetra
.767 .803 .882 r
.63711 .49765 .66922 .53026 .70055 .5109 .66885 .47718 Metetra
.79 .802 .862 r
.66885 .47718 .70055 .5109 .73188 .48848 .70059 .45337 Metetra
.805 .799 .846 r
.70059 .45337 .73188 .48848 .76318 .46363 .7323 .42692 Metetra
.813 .794 .834 r
.7323 .42692 .76318 .46363 .79444 .43713 .76396 .39869 Metetra
.816 .788 .826 r
.76396 .39869 .79444 .43713 .82567 .40974 .79557 .36951 Metetra
.259 .555 .931 r
.32723 .47902 .36263 .5162 .39148 .52405 .3562 .48717 Metetra
.286 .574 .938 r
.3562 .48717 .39148 .52405 .4208 .5311 .38566 .49448 Metetra
.338 .605 .947 r
.38566 .49448 .4208 .5311 .4506 .53649 .41562 .5001 Metetra
.409 .645 .954 r
.41562 .5001 .4506 .53649 .48085 .53938 .44607 .50312 Metetra
.488 .685 .954 r
.44607 .50312 .48085 .53938 .51152 .53905 .47698 .50283 Metetra
.564 .719 .946 r
.47698 .50283 .51152 .53905 .54255 .53497 .5083 .49865 Metetra
.632 .746 .93 r
.5083 .49865 .54255 .53497 .57388 .52678 .53995 .49023 Metetra
.688 .764 .91 r
.53995 .49023 .57388 .52678 .60543 .51429 .57186 .47737 Metetra
.731 .775 .888 r
.57186 .47737 .60543 .51429 .63711 .49765 .60393 .46022 Metetra
.763 .782 .868 r
.60393 .46022 .63711 .49765 .66885 .47718 .63608 .43911 Metetra
.787 .785 .851 r
.63608 .43911 .66885 .47718 .70059 .45337 .66826 .41456 Metetra
.803 .786 .837 r
.66826 .41456 .70059 .45337 .7323 .42692 .70041 .38729 Metetra
.812 .785 .827 r
.70041 .38729 .7323 .42692 .76396 .39869 .73252 .35817 Metetra
.816 .784 .822 r
.73252 .35817 .76396 .39869 .79557 .36951 .76458 .32809 Metetra
.275 .564 .934 r
.29083 .44079 .32723 .47902 .3562 .48717 .31995 .44828 Metetra
.309 .58 .938 r
.31995 .44828 .3562 .48717 .38566 .49448 .34957 .45495 Metetra
.364 .607 .942 r
.34957 .45495 .38566 .49448 .41562 .5001 .3797 .45995 Metetra
.433 .64 .943 r
.3797 .45995 .41562 .5001 .44607 .50312 .41035 .4624 Metetra
.506 .672 .939 r
.41035 .4624 .44607 .50312 .47698 .50283 .44149 .46159 Metetra
.575 .7 .927 r
.44149 .46159 .47698 .50283 .5083 .49865 .47307 .45697 Metetra
.635 .723 .911 r
.47307 .45697 .5083 .49865 .53995 .49023 .50502 .44819 Metetra
.685 .74 .892 r
.50502 .44819 .53995 .49023 .57186 .47737 .53726 .43505 Metetra
.725 .752 .874 r
.53726 .43505 .57186 .47737 .60393 .46022 .5697 .4177 Metetra
.755 .761 .857 r
.5697 .4177 .60393 .46022 .63608 .43911 .60226 .39646 Metetra
.779 .767 .843 r
.60226 .39646 .63608 .43911 .66826 .41456 .63488 .37185 Metetra
.795 .772 .832 r
.63488 .37185 .66826 .41456 .70041 .38729 .6675 .34457 Metetra
.806 .776 .825 r
.6675 .34457 .70041 .38729 .73252 .35817 .70009 .31548 Metetra
.812 .779 .822 r
.70009 .31548 .73252 .35817 .76458 .32809 .73265 .28543 Metetra
.319 .589 .941 r
.25338 .40146 .29083 .44079 .31995 .44828 .28271 .40737 Metetra
.355 .599 .939 r
.28271 .40737 .31995 .44828 .34957 .45495 .31252 .4125 Metetra
.406 .618 .937 r
.31252 .4125 .34957 .45495 .3797 .45995 .34286 .41605 Metetra
.467 .641 .932 r
.34286 .41605 .3797 .45995 .41035 .4624 .37372 .41723 Metetra
.529 .664 .922 r
.37372 .41723 .41035 .4624 .44149 .46159 .40509 .41537 Metetra
.587 .685 .909 r
.40509 .41537 .44149 .46159 .47307 .45697 .43691 .40996 Metetra
.637 .703 .893 r
.43691 .40996 .47307 .45697 .50502 .44819 .46913 .40068 Metetra
.681 .718 .877 r
.46913 .40068 .50502 .44819 .53726 .43505 .50168 .38735 Metetra
.716 .73 .862 r
.50168 .38735 .53726 .43505 .5697 .4177 .53447 .37011 Metetra
.744 .74 .849 r
.53447 .37011 .5697 .4177 .60226 .39646 .56743 .34925 Metetra
.766 .75 .838 r
.56743 .34925 .60226 .39646 .63488 .37185 .60048 .32525 Metetra
.783 .758 .83 r
.60048 .32525 .63488 .37185 .6675 .34457 .63357 .29876 Metetra
.795 .766 .826 r
.63357 .29876 .6675 .34457 .70009 .31548 .66666 .27057 Metetra
.802 .773 .826 r
.66666 .27057 .70009 .31548 .73265 .28543 .69976 .24147 Metetra
.384 .623 .947 r
.21484 .36098 .25338 .40146 .28271 .40737 .24445 .36443 Metetra
.416 .626 .939 r
.24445 .36443 .28271 .40737 .31252 .4125 .27453 .36717 Metetra
.459 .634 .93 r
.27453 .36717 .31252 .4125 .34286 .41605 .30511 .36852 Metetra
.507 .646 .919 r
.30511 .36852 .34286 .41605 .37372 .41723 .33621 .36777 Metetra
.555 .66 .906 r
.33621 .36777 .37372 .41723 .40509 .41537 .3678 .36435 Metetra
.6 .673 .892 r
.3678 .36435 .40509 .41537 .43691 .40996 .39987 .35784 Metetra
.64 .686 .878 r
.39987 .35784 .43691 .40996 .46913 .40068 .43235 .34794 Metetra
.675 .698 .864 r
.43235 .34794 .46913 .40068 .50168 .38735 .46518 .3345 Metetra
.705 .71 .852 r
.46518 .3345 .50168 .38735 .53447 .37011 .49829 .31765 Metetra
.73 .722 .843 r
.49829 .31765 .53447 .37011 .56743 .34925 .5316 .29764 Metetra
.75 .733 .836 r
.5316 .29764 .56743 .34925 .60048 .32525 .56506 .27487 Metetra
.767 .744 .832 r
.56506 .27487 .60048 .32525 .63357 .29876 .59861 .24991 Metetra
.779 .755 .831 r
.59861 .24991 .63357 .29876 .66666 .27057 .63221 .22344 Metetra
.788 .766 .833 r
.63221 .22344 .66666 .27057 .69976 .24147 .66586 .19616 Metetra
.461 .66 .947 r
.17516 .3193 .21484 .36098 .24445 .36443 .20514 .31952 Metetra
.485 .654 .934 r
.20514 .31952 .24445 .36443 .27453 .36717 .23556 .31913 Metetra
.515 .652 .92 r
.23556 .31913 .27453 .36717 .30511 .36852 .26645 .31758 Metetra
.548 .654 .905 r
.26645 .31758 .30511 .36852 .33621 .36777 .29783 .31434 Metetra
.581 .659 .89 r
.29783 .31434 .33621 .36777 .3678 .36435 .32968 .30893 Metetra
.613 .665 .877 r
.32968 .30893 .3678 .36435 .39987 .35784 .36199 .30102 Metetra
.642 .673 .864 r
.36199 .30102 .39987 .35784 .43235 .34794 .39471 .29039 Metetra
.669 .682 .854 r
.39471 .29039 .43235 .34794 .46518 .3345 .4278 .27692 Metetra
.692 .693 .846 r
.4278 .27692 .46518 .3345 .49829 .31765 .46118 .2607 Metetra
.713 .704 .84 r
.46118 .2607 .49829 .31765 .5316 .29764 .49482 .24193 Metetra
.731 .717 .837 r
.49482 .24193 .5316 .29764 .56506 .27487 .52864 .22094 Metetra
.746 .73 .837 r
.52864 .22094 .56506 .27487 .59861 .24991 .56262 .19816 Metetra
.758 .744 .839 r
.56262 .19816 .59861 .24991 .63221 .22344 .5967 .17414 Metetra
.767 .758 .844 r
.5967 .17414 .63221 .22344 .66586 .19616 .63089 .14942 Metetra
.539 .694 .94 r
.13429 .27638 .17516 .3193 .20514 .31952 .16475 .27272 Metetra
.552 .68 .923 r
.16475 .27272 .20514 .31952 .23556 .31913 .1956 .26859 Metetra
.569 .67 .907 r
.1956 .26859 .23556 .31913 .26645 .31758 .22688 .26361 Metetra
.588 .663 .891 r
.22688 .26361 .26645 .31758 .29783 .31434 .25859 .25741 Metetra
.607 .661 .876 r
.25859 .25741 .29783 .31434 .32968 .30893 .29073 .24966 Metetra
.626 .661 .864 r
.29073 .24966 .32968 .30893 .36199 .30102 .32329 .24014 Metetra
.645 .664 .854 r
.32329 .24014 .36199 .30102 .39471 .29039 .35625 .22869 Metetra
.663 .67 .846 r
.35625 .22869 .39471 .29039 .4278 .27692 .38956 .21523 Metetra
.679 .678 .842 r
.38956 .21523 .4278 .27692 .46118 .2607 .42319 .19983 Metetra
.695 .688 .84 r
.42319 .19983 .46118 .2607 .49482 .24193 .4571 .18262 Metetra
.709 .701 .84 r
.4571 .18262 .49482 .24193 .52864 .22094 .49124 .16382 Metetra
.721 .715 .844 r
.49124 .16382 .52864 .22094 .56262 .19816 .52559 .14373 Metetra
.732 .731 .85 r
.52559 .14373 .56262 .19816 .5967 .17414 .56011 .12273 Metetra
.74 .748 .858 r
.56011 .12273 .5967 .17414 .63089 .14942 .59481 .1012 Metetra
.608 .72 .924 r
.09217 .23214 .13429 .27638 .16475 .27272 .12323 .22415 Metetra
.612 .701 .908 r
.12323 .22415 .16475 .27272 .1956 .26859 .15462 .21586 Metetra
.618 .686 .891 r
.15462 .21586 .1956 .26859 .22688 .26361 .18636 .20707 Metetra
.625 .674 .877 r
.18636 .20707 .22688 .26361 .25859 .25741 .21847 .19759 Metetra
.632 .665 .864 r
.21847 .19759 .25859 .25741 .29073 .24966 .25094 .18727 Metetra
.64 .66 .854 r
.25094 .18727 .29073 .24966 .32329 .24014 .28377 .17598 Metetra
.648 .659 .846 r
.28377 .17598 .32329 .24014 .35625 .22869 .31696 .16364 Metetra
.657 .661 .842 r
.31696 .16364 .35625 .22869 .38956 .21523 .35048 .15023 Metetra
.666 .666 .841 r
.35048 .15023 .38956 .21523 .42319 .19983 .38431 .13576 Metetra
.675 .674 .842 r
.38431 .13576 .42319 .19983 .4571 .18262 .41844 .12031 Metetra
.683 .686 .846 r
.41844 .12031 .4571 .18262 .49124 .16382 .45284 .10398 Metetra
.692 .7 .853 r
.45284 .10398 .49124 .16382 .52559 .14373 .48751 .08693 Metetra
.699 .716 .862 r
.48751 .08693 .52559 .14373 .56011 .12273 .52241 .06935 Metetra
.706 .735 .873 r
.52241 .06935 .56011 .12273 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12323 .22415 .08051 .17394 Metetra
.663 .718 .889 r
.08051 .17394 .12323 .22415 .15462 .21586 .11254 .16124 Metetra
.66 .699 .875 r
.11254 .16124 .15462 .21586 .18636 .20707 .14483 .14843 Metetra
.658 .684 .863 r
.14483 .14843 .18636 .20707 .21847 .19759 .1774 .13551 Metetra
.655 .671 .853 r
.1774 .13551 .21847 .19759 .25094 .18727 .21025 .12249 Metetra
.653 .662 .846 r
.21025 .12249 .25094 .18727 .28377 .17598 .24339 .10934 Metetra
.652 .657 .842 r
.24339 .10934 .28377 .17598 .31696 .16364 .27681 .09609 Metetra
.651 .655 .84 r
.27681 .09609 .31696 .16364 .35048 .15023 .31052 .08272 Metetra
.652 .657 .842 r
.31052 .08272 .35048 .15023 .38431 .13576 .34452 .06923 Metetra
.653 .662 .846 r
.34452 .06923 .38431 .13576 .41844 .12031 .37882 .05563 Metetra
.655 .671 .853 r
.37882 .05563 .41844 .12031 .45284 .10398 .41342 .04191 Metetra
.658 .684 .863 r
.41342 .04191 .45284 .10398 .48751 .08693 .44833 .02806 Metetra
.66 .699 .875 r
.44833 .02806 .48751 .08693 .52241 .06935 .48355 .01409 Metetra
.663 .718 .889 r
.48355 .01409 .52241 .06935 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY]n?o0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVg
h`?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY]n<00ol0003oZKOSo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY]n<00ol0003oZKOSojVgh`03ojVgh`04o`000?nY]n?oZKOSo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVgh`04o`000?nY]n?oZKOSo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onX/]oo0000ojVgh`09
ojVgh`05o`000?nY]n?oZKOSojVghol00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojRbgol0003oZ;;O00;oZ;;O
00?o0000ojVghonY]n<01onY]n<00ol0003oZKOSojVgh`02ojVgh`03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nX/]l00ol0003oZKOSojVgh`06ojVgh`03o`000?nY]n?oZKOS00?oZKOS00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000;ojRbg`03o`000?nY]n?oZKOS00KoZKOS00?o0000
ojVghonY]n<00onY]n<00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ;;O00?o0000ojVg
honY]n<01OnY]n<00ol0003oZKOSojVgh`04ojVgh`03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnX[m`00ol0003oZ;;OojRbg`0:ojRbg`03o`000?nY]n?oZKOS00CoZKOS00?o0000ojVghonY
]n<01OnY]n<00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZ:oL00?o0000ojRb
gonX/]l02_nX/]l00ol0003oZKOSojVgh`03ojVgh`03o`000?nY]n?oZKOS00KoZKOS00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onX[mco0000ojR_g009ojR_g003o`000?nX/]oo
Z;;O00[oZ;;O00?o0000ojVghonY]n<00onY]n<00ol0003oZKOSojVgh`06ojVgh`03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnWZm[o0000ojR_g?nX[mco000000[oZ:oL00?o0000ojRbgonX/]l0
2_nX/]l00ol0003oZKOSojVgh`02ojVgh`03o`000?nY]n?oZKOS00OoZKOS00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`05
o`000?nY]n?oZKOSojVghol000002_nY]n<00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oYj_J
o`000?nWZmX01OnWZmX00ol0003oZ:oLojR_g00:ojR_g003o`000?nX/]ooZ;;O00[oZ;;O00Go0000
ojVghonY]n?oZKOSo`00000:ojVgh`;o0000Toooool006gooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo01Gooooo0ol0000;ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o
0000ojRbgonX/]l02_nX/]l01?l0003oZKOSojVghol00008ojVgh`;o000000?o];cOo`000?ooool0
T_ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01?ooooo
1?l0000=ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o0000ojRbgonX/]l02_nX/]l00ol0003oZKOS
o`000006ojVgh`;o00001?nd_=l00ol0003oooooooooo`2@ooooo`00KOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3oooool2o`0000;oYjWH00?o0000ojNYf?l0
00003?nWZmX00ol0003oZ:oLojR_g00;ojR_g003o`000?nX/]ooZ;;O00_oZ;;O0_l00005ojVgh`03
o`000?nd_=oo];cO00Go];cO00?o0000ooooooooool0Soooool008kooooo0ol00007ojNYf003o`00
0?nWZm[oYj_J00[oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`;o0000
0onY]n<2o`0000Wo];cO00?o0000ooooooooool0S_ooool008cooooo0ol00009ojNYf003o`000?nW
Zm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRbg`0:ojRbg`04o`000?nY
]n?o0000o`0000_o];cO0_l0002?ooooo`00ROooool4o`000003ojNYf?l0003oYjWH00WoYjWH00?o
0000ojN[f_nWZmX02_nWZmX00ol0003oZ:oLojR_g00;ojR_g003o`000?nX/]ooZ;;O00[oZ;;O0_l0
000>okBlg`03o`000?oooooooooo08gooooo001@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0Pooooo`Co000000?oYZSGo`000?nWZMP02onW
ZMP00ol0003oYj_JojN[fP0;ojN[fP03o`000?nX[mcoZ:oL00_oZ:oL00?o0000ojRbgonX/]l01onX
/]l4o`0000oo];cO00?o0000ooooooooool0S?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`Co00001OnVZ=L00ol0003oYjWHojNY
f00:ojNYf003o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`00ol0003oZ;;OojRb
g`04ojRbg`;o00000_nb]m`00ol0003o/[OLo`00000?okBlg`03o`000?oooooooooo08_ooooo001@
ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001gooooo0ol000000onVZ=Oo0000ojJX
e`06ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nWZmX02_nWZmX00ol0003oZ:oLojR_
g00;ojR_g003o`000?nX/]ooZ;;O00;oZ;;O0_l00004ok:gg004o`000?nb]mco/[OLo`0000ko];cO
0_l0002<ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00006oooool3o`0000GoYZSG00?o0000ojJXeonVZ=L01?nVZ=L00ol0003oYjWHojNYf00:ojNYf003
o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02onX[m`01?l0003oZ;;Oo`000?l00006ok:g
g005o`000?nb]mco/[OLok:gg?l000003_nd_=l2o`0008_ooooo001@ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool0000Iooooo`?o000000?oYZOGo`000?nVZ=L03?nV
Z=L00ol0003oYjWHojNYf00:ojNYf003o`000?nWZm[oYj_J00_oYj_J00?o0000ojR_g?nX[m`02_nX
[m`2o`0000So/[OL00Go0000ok:gg?nb]mco/[OLo`00000?okBlg`03o`000?oooooooooo08Wooooo
001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Fooooo`?o0000
0_nVYmL01?l0003oYZOGojJWeol0000<ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nW
ZmX02onWZmX00ol0003oZ:oLojR_g008ojR_g0;o000000?o/K?Jo`000?nb]m`01onb]m`00ol0003o
/[OLok:gg002ok:gg003o`000?nd_=oo];cO00go];cO00?o0000ooooooooool0R?ooool0053ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo0ol00007ojJWe`03
o`000?nVZ=OoYZSG00_oYZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0;ojN[fP03
o`000?nX[mcoZ:oL00CoZ:oL0ol00004ok6cfP03o`000?nb]mco/[OL00Go/[OL00?o0000ok:gg?nb
]m`00onb]m`00ol0003o];cOokBlg`0<okBlg`;o0000ROooool0053ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojJWe`03o`000?nVZ=OoYZSG00_o
YZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0:ojN[fP03o`000?nX[mcoZ:oL00;o
Z:oL0_l00008ok6cfP03o`000?nb]mco/[OL00Co/[OL00?o0000ok:gg?nb]m`01?nb]m`00ol0003o
];cOokBlg`0<okBlg`;o0000R?ooool007?ooooo0ol000000onVZ=Oo0000o`00000;ojJWe`03o`00
0?nVZ=OoYZSG00[oYZSG00?o0000ojNYf?nWZMP02_nWZMP00ol0003oYj_JojN[fP0;ojN[fP04o`00
0?nX[mco0000o`0000[o/K?J00?o0000ok:gg?nb]m`01?nb]m`00ol0003o/[OLok:gg004ok:gg003
o`000?nd_=oo];cO00go];cO0_l00027ooooo`00L?ooool3o`0000GoYZSG00?o0000ojJWeonVYmL0
2OnVYmL00ol0003oYZSGojJXe`0;ojJXe`03o`000?nWZMSoYjWH00[oYjWH00?o0000ojN[f_nWZmX0
2_nWZmX2o`0000go/K?J00?o0000ok:gg?nb]m`00onb]m`00ol0003o/[OLok:gg005ok:gg003o`00
0?nd_=oo];cO00_o];cO00?o0000okfofol00000Qoooool006kooooo0ol00007ojJXe`03o`000?nV
YmOoYZOG00[oYZOG00?o0000ojJXeonVZ=L02_nVZ=L00ol0003oYjWHojNYf00:ojNYf003o`000?nW
Zm[oYj_J00SoYj_J0_l000000on^[mSo0000ok6cfP0<ok6cfP03o`000?nb]mco/[OL00?o/[OL00?o
0000ok:gg?nb]m`01_nb]m`00ol0003o];cOokBlg`08okBlg`;o00000_nm_m/2o`0008Kooooo000c
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Sooooo`?o00000_nV
Z=L00ol0003oYZSGojJXe`06ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onV
Z=L00ol0003oYjWHojNYf00:ojNYf003o`000?nWZm[oYj_J00CoYj_J0ol00004ojj_f003o`000?na
/m[o/K?J00_o/K?J00?o0000ok:gg?nb]m`00_nb]m`00ol0003o/[OLok:gg007ok:gg003o`000?nd
_=oo];cO00Go];cO0_l00005okfof`;o0000QOooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo0ol000000onWZMSo0000
ojJXe`0;ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onVZ=L00ol0003oYjWH
ojNYf00:ojNYf004o`000?nWZm[oYj_JojN[fP;o00002?n^[mP00ol0003o/K?Jok6cfP0;ok6cfP05
o`000?nb]mco/[OLok:gg?l000002Onb]m`00ol0003o];cOokBlg`04okBlg`03o`000?nm_m_o_KoK
00Ko_KoK0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h07oooool4o`0000CoYjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJW
e`03o`000?nVZ=OoYZSG00_oYZSG00?o0000ojNYf?nWZMP02_nWZMP01?l0003oYj_Jo`000?l0000:
ojj_f003o`000?na/m[o/K?J00_o/K?J00Go0000ok:gg?nb]mco/[OLo`00000:ok:gg004o`000?nd
_=oo];cOokBlg`;o00002_nm_m/00ol0003oooooooooo`22ooooo`00<oooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06oooool3o`0000CoYjWH00Go0000ojNYf?nWZMSo
YjWHo`00000<ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L02onVZ=L00ol0003o
YjWHojNYf009ojNYf0;o00003On^[mP00ol0003o/K?Jok6cfP0;ok6cfP04o`000?nb]mco/[OLo`00
00_o/[OL00?o0000okBlgol000003?nm_m/2o`0008?ooooo000cooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00002onWZMP00ol0003oYZSGojJXe`09ojJX
e`03o`000?nVYmOoYZOG00[oYZOG00?o0000ojJXeonVZ=L02_nVZ=L00ol0003oYjWHojNYf007ojNY
f0;o000000?o[:cGo`000?n^[mP03?n^[mP00ol0003o/K?Jok6cfP0;ok6cfP04o`000?nb]mco/[OL
o`0000_o/[OL0_l0000>okfof`;o0000P_ooool003?ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo01Cooooo0ol000000onWZm[o0000ojNYf00<ojNYf003o`000?nVZ=Oo
YZSG00WoYZSG00?o0000ojJWeonVYmL02OnVYmL00ol0003oYZSGojJXe`0;ojJXe`03o`000?nWZMSo
YjWH00CoYjWH0_l00004ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02ona/mX0
0ol0003o/[OLo`00000:ok:gg003o`000?nk^mWo000000oo_KoK0_l00021ooooo`00<oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o00001?nW
ZmX00ol0003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL02_nV
YmL00ol0003oYZSGojJXe`0;ojJXe`04o`000?nWZMSoYjWHojNYf0;o00001on/[=L00ol0003o[ZoH
ojj_f00;ojj_f003o`000?na/m[o/K?J00_o/K?J0_l00008ok:gg0;o00000onk^mT00ol0003o_KoK
okfof`0=okfof`03o`000?oooooooooo07oooooo000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0ol00008ojN[fP03o`000?nWZMSoYjWH00[o
YjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJWe`03o`000?nVZ=OoYZSG00_o
YZSG00Co0000ojNYf?l0003o00002On/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o/K?J
00_o/K?J0_l00006ok:gg0;o00001_nk^mT00ol0003o_KoKokfof`0<okfof`;o0000P?ooool005Oo
oooo0ol000000onWZm[o0000ojN[fP07ojN[fP03o`000?nWZMSoYjWH00[oYjWH00?o0000ojJXeonV
Z=L02_nVZ=L00ol0003oYZOGojJWe`09ojJWe`03o`000?nVZ=OoYZSG00[oYZSG0_l0000<ojb/e`03
o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02ona/mX00ol0003o/[OLok:gg003ok:gg003
o`000?nk^mWo^k_I00Ko^k_I00?o0000okfofonm_m/03Onm_m/2o`0007oooooo001Dooooo`?o0000
00?oZ:oLo`000?nWZmX02onWZmX00ol0003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG
00?o0000ojJWeonVYmL02OnVYmL00ol0003oYZSGojJXe`08ojJXe`;o000000?oZZ[Go`000?n/[=L0
2on/[=L00ol0003o[ZoHojj_f00<ojj_f003o`000?na/m[o/K?J00[o/K?J00Co0000ok:gg?nb]mco
/[OL0_l0000:ok^kf@03o`000?nm_m_o_KoK00go_KoK00?o0000ooooooooool0OOooool005;ooooo
0ol00004ojR_g003o`000?nWZm[oYj_J00[oYj_J00?o0000ojNYf?nWZMP02OnWZMP00ol0003oYZSG
ojJXe`0:ojJXe`03o`000?nVYmOoYZOG00WoYZOG00?o0000ojJXeonVZ=L01?nVZ=L3o`0000CoZZ[G
00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o/K?J00[o/K?J
0_l000000onb]mco0000ok^kf@0<ok^kf@03o`000?nm_m_o_KoK00go_KoK00?o0000ooooooooool0
O?ooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`Co000000?oZ:oLo`000?nX[m`0
1?nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00[oYjWH00?o0000ojJXeonVZ=L0
2OnVZ=L00ol0003oYZOGojJWe`0:ojJWe`04o`000?nVZ=OoYZSGojJXe`;o00002?nZZ]L00ol0003o
[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6cf_na/mX02Ona/mX3o`0000ko
^k_I00?o0000okfofonm_m/03Onm_m/2o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mg
MgL08Oooool3o`0000[oZ:oL00?o0000ojN[f_nWZmX02_nWZmX00ol0003oYjWHojNYf00:ojNYf003
o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL02OnVYmL01?l0003oYZSGo`000?l0000:ojZZ
e`03o`000?n/[=Oo[:cG00[o[:cG00?o0000ojj_f?n^[mP03?n^[mP00ol0003o/K?Jok6cfP07ok6c
fP;o000000?o^;OHo`000?nk^mT03_nk^mT00ol0003o_KoKokfof`0=okfof`;o0000O?ooool002Oo
oooo00Go410@oooooooooooooooooa0@400Nooooo`Go00003?nX[m`00ol0003oYj_JojN[fP0:ojN[
fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L02OnVZ=L00ol0003oYZOGojJWe`09ojJW
e`;o00003OnZZ]L00ol0003o[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH00?o0000ok6c
f_na/mX01_na/mX00ol0003o^;OHo`000002okRgf003o`000?nk^mWo^k_I00go^k_I00?o0000okfo
fonm_m/02onm_m/00ol0003oa<;Ho`00001looooo`009oooool01Ol0003ooooooooooooooooo0000
01cooooo0ol00002ojRbg`03o`000?nX/]oo000000coZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0
003oYjWHojNYf00:ojNYf003o`000?nVZ=OoYZSG00WoYZSG00?o0000ojJWeonVYmL01OnVYmL3o`00
0003ojRYeol0003oZZ[G00coZZ[G00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00<ojj_
f003o`000?na/m[o/K?J00?o/K?J0_l00002okRgf005o`000?nh]mSo^;OHokRgf?l000003onk^mT0
0ol0003o_KoKokfof`09okfof`05o`000?o4`]Soa<;HolC2f?l00000Noooool002Oooooo00Go0000
ooooooooooooooooo`00000Iooooo`Co00001OnX/]l00ol0003oZ;;Oo`00000;ojR_g003o`000?nW
Zm[oYj_J00[oYj_J00?o0000ojNYf?nWZMP02OnWZMP00ol0003oYZSGojJXe`0:ojJXe`03o`000?nV
YmOoYZOG00;oYZOG0_l00005ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02_n/
[=L00ol0003o[ZoHojj_f00;ojj_f004o`000?na/m[o/K?Jok6cfP;o00001?nh]mP00ol0003o^;OH
okRgf002okRgf003o`000?nk^mWo^k_I00co^k_I00?o0000okfofonm_m/01onm_m/2o`0000Coa<;H
0_l0001jooooo`009oooool01Ol@413ooooooooooooooooo410@01Oooooo0ol0000;ojRbg`03o`00
0?nX[mcoZ:oL00WoZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNYf00:ojNYf003o`00
0?nVZ=OoYZSG00WoYZSG00?o0000ojJWeol000000_l00008ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G
00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f00;ojj_f003o`000?na/m[o000000Ko^;OH
00?o0000okRgf?nh]mP00_nh]mP00ol0003o^k_Iok^kf@0=ok^kf@03o`000?nm_m_o_KoK00Go_KoK
00?o0000olC2f?o4`]P01Oo4`]P2o`0007Wooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5?ooool5o`000003ojRbgol0003oZ;;O00WoZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_J
ojN[fP09ojN[fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L02OnVZ=L2o`0000_oZ:WG
00?o0000ojZZeonZZ]L02onZZ]L00ol0003o[:cGojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00_o[ZoH
0_l00007okRgf003o`000?nh]mSo^;OH00?o^;OH00?o0000ok^kfOnk^mT03Onk^mT00ol0003o_KoK
okfof`02okfof`;o00002Oo4`]P00ol0003oooooooooo`1gooooo`009oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01;ooooo0ol00004ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR_g?nX[m`0
2_nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00WoYjWH00?o0000ojJXeonVZ=L0
1OnVZ=L3o`000003ojFXf?l0003oZ:WG00_oZ:WG00?o0000ojZZeonZZ]L02onZZ]L00ol0003o[:cG
ojb/e`0:ojb/e`03o`000?n^[mSo[ZoH00So[ZoH0_l000000one/mOo0000okRgf006okRgf003o`00
0?nh]mSo^;OH00Co^;OH00?o0000ok^kfOnk^mT03?nk^mT01Ol0003o_KoKokfofonm_m_o000000co
a<;H00?o0000ooooooooool0M_ooool003_ooooo1Ol00006ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O
00?o0000ojR_g?nX[m`02OnX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSoYjWH00[oYjWH
00?o0000ojJXeonVZ=L00_nVZ=L2o`0000GoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[G
ojZZe`0:ojZZe`03o`000?n/[=Oo[:cG00[o[:cG00?o0000ojj_f?n^[mP01_n^[mP2o`0000Co]K?G
00?o0000okRgf?nh]mP01?nh]mP00ol0003o^;OHokRgf005okRgf003o`000?nk^mWo^k_I00co^k_I
00?o0000okfofol000003Oo4`]P2o`0007Oooooo000iooooo`?o00002onY]n<00ol0003oZ;;OojRb
g`09ojRbg`03o`000?nX[mcoZ:oL00[oZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNY
f009ojNYf003o`000?nVZ=Oo000000;o00002?nUZ=P00ol0003oZ:WGojRYe`09ojRYe`03o`000?nZ
Z]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02_n/[=L00ol0003o[ZoHojj_f004ojj_f003o`000?ne
/mOo]K?G00Go]K?G00?o0000okRgf?nh]mP00onh]mP00ol0003o^;OHokRgf005okRgf003o`000?nk
^mWo^k_I00co^k_I0_l0000?olC2f0;o0000M_ooool003Oooooo1?l0000<ojVgh`03o`000?nX/]oo
Z;;O00[oZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_JojN[fP09ojN[fP03o`000?nWZMSo
YjWH00OoYjWH0ol0000;ojFXf003o`000?nXZMOoZ:WG00[oZ:WG00?o0000ojZZeonZZ]L02onZZ]L0
0ol0003o[:cGojb/e`0:ojb/e`04o`000?n^[mSo[ZoHojj_f0;o00002?ne/mL00ol0003o^;OHokRg
f003okRgf003o`000?nh]mSo^;OH00Ko^;OH00?o0000ok^kfOnk^mT02_nk^mT00ol0003o`[kFo`00
000@olC2f003o`000?oooooooooo07Cooooo000dooooo`?o000000GoZ[cWo`000?nZ_>OoZ[cWo`00
000<ojVgh`03o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR_g?nX[m`02OnX[m`00ol0003oYj_JojN[
fP09ojN[fP03o`000?nWZMSoYjWH00CoYjWH0ol00002oj>XfP03o`000?nUZ=SoYJSH00[oYJSH00?o
0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`0:ojZZe`03o`000?n/[=Oo[:cG00[o[:cG00Co
0000ojj_f?l0003o00002one/mL00ol0003o^;OHokRgf002okRgf003o`000?nh]mSo^;OH00Oo^;OH
00?o0000ok^kfOnk^mT01onk^mT2o`0000?o`[kF00?o0000olC2f?o4`]P03_o4`]P00ol0003ooooo
ooooo`1cooooo`00<_ooool3o`0000OoZ[cW00?o0000ojVghonY]n<02_nY]n<00ol0003oZ;;OojRb
g`0:ojRbg`03o`000?nX[mcoZ:oL00WoZ:oL00?o0000ojN[f_nWZmX02OnWZmX00ol0003oYjWHojNY
f003o`0000KoXjSJ00?o0000ojFXf?nUZ=P02OnUZ=P00ol0003oZ:WGojRYe`0:ojRYe`03o`000?nZ
Z]OoZZ[G00_oZZ[G00?o0000ojb/eon/[=L02On/[=L2o`0000ko]K?G00Go0000okRgf?nh]mSo^;OH
o`00000:okRgf003o`000?nk^mWo^k_I00Go^k_I00?o0000ol:ne_o2_]H01?o2_]H00ol0003oa<;H
olC2f00=olC2f0;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003oZKOSojVg
h`0:ojVgh`03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR_g?nX[m`02_nX[m`00ol0003oYj_JojN[
fP07ojN[fPCo00002_nSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOoZ:WG00[oZ:WG00?o
0000ojZZeonZZ]L02_nZZ]L00ol0003o[:cGojb/e`07ojb/e`;o000000?o/K3Go`000?ne/mL03One
/mL01Ol0003o^;OHokRgf?nh]mSo000000[o^;OH00?o0000ok^kfOnk^mT01?nk^mT00ol0003o`[kF
ol:neP06ol:neP03o`000?o4`]Soa<;H00goa<;H00?o0000ooooooooool0L_ooool0037ooooo0_l0
000;ojZli`03o`000?nY]n?oZKOS00[oZKOS00?o0000ojRbgonX/]l02OnX/]l00ol0003oZ:oLojR_
g009ojR_g003o`000?nWZm[oYj_J00CoYj_J0ol00002oj6Zg@03o`000?nSZ=[oXjSJ00WoXjSJ00?o
0000ojFXf?nUZ=P02_nUZ=P00ol0003oZ:WGojRYe`09ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00?o
0000ojb/eon/[=L01?n/[=L2o`0000Co/K3G00?o0000okFceone/mL03?ne/mL01?l0003o^;OHokRg
f?l0000;okRgf004o`000?nk^mWo^k_Iok^kf@;o00002Oo2_]H00ol0003oa<;HolC2f00>olC2f003
o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000co
Z[cW00?o0000ojVghonY]n<02OnY]n<00ol0003oZ;;OojRbg`0:ojRbg`03o`000?nX[mcoZ:oL00Wo
Z:oL00?o0000ojN[f_nWZmX00ol00006oj6Zg@03o`000?nSZ=[oXjSJ00WoXjSJ00?o0000ojFXf?nU
Z=P02OnUZ=P00ol0003oZ:WGojRYe`0:ojRYe`03o`000?nZZ]OoZZ[G00_oZZ[G00Co0000ojb/eon/
[=Oo[:cG0_l00007ok6`e`03o`000?ne/mOo]K?G00co]K?G00?o0000okRgf?l000003?nh]mP00ol0
003o^k_Io`00000<ol:neP03o`000?o4`]Soa<;H00koa<;H00?o0000ooooooooool0L?ooool002Go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o0000ojVg
honY]n<02OnY]n<00ol0003oZ;;OojRbg`09ojRbg`03o`000?nX[mcoZ:oL00SoZ:oL1?l0000:oj6Z
g@03o`000?nSZ=[oXjSJ00SoXjSJ00?o0000ojFXf?nUZ=P02_nUZ=P00ol0003oZ:WGojRYe`0:ojRY
e`03o`000?nZZ]OoZZ[G00[oZZ[G00Co0000ojb/eol0003o00002Ona/=L00ol0003o]K?GokFce`0<
okFce`03o`000?nh]mSo000000co^;OH0_l0000>ol:neP03o`000?o4`]Soa<;H00goa<;H0_l0001a
ooooo`009Oooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000oooooooooooo00003?nZ
_>L00ol0003oZKOSojVgh`09ojVgh`03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR_g?nX[m`01?nX
[m`3o`0000;oWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nU
Z=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`0:ojZZe`;o00003?na
/=L00ol0003o]K?GokFce`0<okFce`;o00002onh]mP00ol0003o_[[Fo`00000?ol:neP03o`000?o4
`]Soa<;H00_oa<;H00?o0000olW4eOl00000LOooool002Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o00000oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]n?oZKOS00[oZKOS00?o
0000ojRbgonX/]l02OnX/]l00ol0003oZ:oLojR_g003o`0000KoWjcP00?o0000oj6ZgOnQZ]d02OnQ
Z]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nX
ZML00ol0003oZZ[GojZZe`07ojZZe`;o000000?o[JgGo`000?na/=L03?na/=L00ol0003o]K?GokFc
e`0;okFce`;o00002Onh]mP2o`0000?o_[[F00?o0000ol:ne_o2_]H03?o2_]H00ol0003oa<;HolC2
f00:olC2f005o`000?o9a=GobLCEolW4eOl00000L?ooool002Gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003oZKOS
ojVgh`09ojVgh`03o`000?nX/]ooZ;;O00SoZ;;O1?l0000:oin/h003o`000?nQZ]goXJ[M00SoXJ[M
00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf00:ojFXf003o`000?nXZMOoZ:WG00[oZ:WG
00?o0000ojZZeonZZ]L01?nZZ]L2o`0000Co[JgG00?o0000ok6`eona/=L02_na/=L00ol0003o]K?G
okFce`0<okFce`03o`000?nh]mSo^;OH00Go^;OH0_l00006okjjeP03o`000?o2_]Ko`[kF00co`[kF
00?o0000olC2f?o4`]P01oo4`]P2o`0000GobLCE00?o0000ooooooooool0KOooool002Gooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L0
2OnZ_>L00ol0003oZKOSojVgh`09ojVgh`03o`000?nX/]ooZ;;O00CoZ;;O0ol00002oij_i003o`00
0?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`00
0?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML02_nXZML00ol0003oZZ[GojZZe`02ojZZe`;o0000
1on][ML00ol0003o/K3Gok6`e`0:ok6`e`03o`000?ne/mOo]K?G00_o]K?G0_l00005okRgf003o`00
0?nn^]Ko_[[F00Ko_[[F00?o0000ol:ne_o2_]H03Oo2_]H00ol0003oa<;HolC2f005olC2f003o`00
0?o9a=GobLCE00GobLCE0_l0001^ooooo`009Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01Oooool00ol0003oZ[cWojZli`09ojZli`03o`000?nY]n?oZKOS00WoZKOS
00?o0000ojRbgonX/]l00ol00006oij_i003o`000?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d0
2OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML0
2_nXZML01?l0003oZZ[Go`000?l00009ojf]e`03o`000?na/=Oo/K3G00_o/K3G00?o0000okFceone
/mL02_ne/mL2o`0000?o^;OH0_l0000:okjjeP03o`000?o2_]Ko`[kF00co`[kF00?o0000olC2f?o4
`]P00oo4`]P2o`0000WobLCE00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0003o
ZKOSojVgh`07ojVgh`Co00002_nN[n@00ol0003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00Wo
XJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOoZ:WG00[o
Z:WG0_l0000<ojf]e`03o`000?na/=Oo/K3G00[o/K3G00?o0000okFceone/mL02_ne/mL01Ol0003o
]K?Go`000?nh]mSo000000go_[[F00?o0000ol:ne_o2_]H03?o2_]H01Ol0003oa<;HolC2f?o4`]So
000000cobLCE00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0
003oZ[cWojZli`09ojZli`04o`000?nY]n?oZKOSojVgh`Go00000_nL/nP00ol0003oWZoToij_i009
oij_i003o`000?nO[>3oWjcP00WoWjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09
oj>XfP03o`000?nUZ=SoYJSH00WoYJSH00?o0000ojRYeonXZML01_nXZML3o`000003ojV[f?l0003o
[JgG00_o[JgG00?o0000ok6`eona/=L02ona/=L00ol0003o]K?GokFce`09okFce`04o`000?ne/mOo
0000o`0000ko_[[F00?o0000ol:ne_o2_]H03Oo2_]H00ol0003oa<;Ho`00000>olW4e@03o`000?oo
oooooooo06[ooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ojZlionZ_>L02?nZ_>L4
o`0000SoW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0003oWjcPoin/h009oin/h003o`000?nQZ]go
XJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf009ojFXf003o`000?nXZMOo
Z:WG00;oZ:WG0ol00005ojV[f003o`000?n][MOo[JgG00[o[JgG00?o0000ok6`eona/=L02ona/=L0
0ol0003o]K?GokFce`08okFce`;o000000?o^kOFo`000?nn^]H03_nn^]H00ol0003o`[kFol:neP0<
ol:neP;o00003oo9a=D00ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000ojZl
ionZ_>L01?nZ_>L3o`000003oi^hk?l0003oW;?X00[oW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0
003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0
003oYJSHojFXf009ojFXf003o`000?nXZMOo000000;o00002?nYZmP00ol0003o[JgGojf]e`0;ojf]
e`03o`000?na/=Oo/K3G00[o/K3G00?o0000okFceone/mL01one/mL2o`0000?o^kOF00?o0000okjj
e_nn^]H03Onn^]H00ol0003o`[kFol:neP0:ol:neP03o`000?o7`MCo0000013obLCE00?o0000oooo
ooooool0JOooool0033ooooo00?o0000ooooooooool02_ooool00ol0003oZ[cWojZli`03o`0000Go
VkS/00?o0000oibcj?nL/nP02OnL/nP00ol0003oWZoToij_i008oij_i003o`000?nO[>3oWjcP00Wo
WjcP00?o0000oj6ZgOnQZ]d02OnQZ]d00ol0003oXjSJoj>XfP09oj>XfP03o`000?nUZ=SoYJSH00Oo
YJSH0ol0000<ojV[f003o`000?n][MOo[JgG00[o[JgG00?o0000ok6`eona/=L02ona/=L00ol0003o
]K?GokFce`05okFce`03o`000?nk]mKo000000Co^kOF00?o0000okjje_nn^]H03Onn^]H00ol0003o
`[kFol:neP08ol:neP05o`000?o7`MCoal7DolO1e?l000004?o9a=D00ol0003oooooooooo`1Xoooo
o`00;oooool00ol0003oooooooooo`0<ooooo`;o00002OnK^>`00ol0003oW;?Xoibcj009oibcj003
o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>002OnO[>000ol0003oXJ[Moj6Zg@09oj6Zg@03
o`000?nSZ=[oXjSJ00SoXjSJ00?o0000ojFXf?nUZ=P01?nUZ=P3o`0000;oYJWJ00?o0000ojV[f?nY
ZmP02onYZmP00ol0003o[JgGojf]e`0:ojf]e`03o`000?na/=Oo/K3G00_o/K3G00?o0000okFceone
/mL00one/mL01?l0003o^kOFok^ge_l00004ok^geP03o`000?nn^]Ko_[[F00go_[[F00?o0000ol:n
e_o2_]H01oo2_]H00ol0003oal7DolO1e003olO1e003o`000?o9a=GobLCE00kobLCE00?o0000oooo
ooooool0Ioooool002oooooo00?o0000ooooooooool03Oooool00ol0003oVkS/oi^hk008oi^hk003
o`000?nL/nSoW;?X00SoW;?X00?o0000oij_i?nN[n@02OnN[n@00ol0003oWjcPoin/h008oin/h003
o`000?nQZ]goXJ[M00WoXJ[M00?o0000oj>Xf_nSZ=X02OnSZ=X00ol0003oYJSHojFXf003o`0000Ko
YJWJ00?o0000ojV[f?nYZmP02_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00[o
/K3G00Co0000okFceone/mOo]K?G0_l00003ok^geP03o`000?nk]mKo^kOF00?o^kOF00?o0000okjj
e_nn^]H03Onn^]H00ol0003o`[kFol:neP04ol:neP;o00001oo7`M@00ol0003obLCEolW4e@0=olW4
e@03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo00kooooo00?o0000oi^hk?nK
^>`02?nK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO
[>002OnO[>000ol0003oXJ[Moj6Zg@09oj6Zg@03o`000?nSZ=[oXjSJ00OoXjSJ1?l0000:ojFYfP03
o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML00ol0003o/K3Gok6`e`0;ok6`e`03
o`000?ne/mOo000000Go^kOF00?o0000ok^ge_nk]mH01?nk]mH00ol0003o_[[FokjjeP0=okjjeP03
o`000?o2_]Ko`[kF00;o`[kF00?o0000olO1e?o7`M@01oo7`M@00ol0003obLCEolW4e@0>olW4e@03
o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000oi^hk?nK^>`0
2?nK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>00
2OnO[>000ol0003oXJ[Moj6Zg@08oj6Zg@03o`000?nSZ=[oXjSJ00CoXjSJ0ol00002oj2Yg@03o`00
0?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP02_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`00
0?na/=Oo/K3G00[o/K3G0_l00006ok^geP03o`000?nk]mKo^kOF00Go^kOF00?o0000okjje_nn^]H0
3?nn^]H01Ol0003o`[kFol:ne_o2_]Ko000000_oal7D00?o0000olW4eOo9a=D03Oo9a=D2o`0006Oo
oooo000^ooooo`?o00004Oooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL/nSoW;?X00SoW;?X
00?o0000oij_i?nN[n@02?nN[n@00ol0003oWjcPoin/h008oin/h003o`000?nQZ]goXJ[M00WoXJ[M
00?o0000oj>Xf_nSZ=X00ol00006oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP0
2_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00Oo/K3G0_l000000onf]=Oo0000
ok^geP05ok^geP03o`000?nk]mKo^kOF00Go^kOF00?o0000okjje_nn^]H03Onn^]H00ol0003o`[kF
o`00000=olO1e003o`000?o9a=GobLCE00_obLCE00Co0000olg5dol0003o0000I_ooool002oooooo
00?o0000ooooooooool04Oooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL/nSoW;?X00SoW;?X
00?o0000oij_i?nN[n@01onN[n@00ol0003oWjcPoin/h009oin/h003o`000?nQZ]goXJ[M00OoXJ[M
1?l0000:oj2Yg@03o`000?nUZM[oYJWJ00SoYJWJ00?o0000ojV[f?nYZmP02onYZmP00ol0003o[JgG
ojf]e`0:ojf]e`03o`000?na/=Oo/K3G00Ko/K3G00?o0000okJdeonf]=L00_nf]=L00ol0003o^kOF
ok^geP03ok^geP03o`000?nk]mKo^kOF00Ko^kOF00?o0000okjje_nn^]H03?nn^]H2o`0000ooal7D
00?o0000olW4eOo9a=D02Oo9a=D01Ol0003ocLGColg5doo=aM?o000006Kooooo000_ooooo`03o`00
0?oooooooooo01;ooooo00?o0000oi^hk?nK^>`01onK^>`00ol0003oW;?Xoibcj009oibcj003o`00
0?nN[nCoWZoT00OoWZoT00?o0000oin/h?nO[>002?nO[>000ol0003oXJ[Moj6Zg@04oj6Zg@?o0000
0_nKZN000ol0003oX:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP0
2_nYZmP00ol0003o[JgGojf]e`0;ojf]e`03o`000?na/=Oo/K3G00?o/K3G0_l00006okJde`03o`00
0?nk]mKo^kOF00;o^kOF00?o0000ok^ge_nk]mH01onk]mH00ol0003o_[[FokjjeP0:okjjeP03o`00
0?o4_]Co000000ooal7D00?o0000olW4eOo9a=D02?o9a=D00ol0003ocLGColg5d`03olg5d`03o`00
0?oooooooooo06?ooooo000_ooooo`03o`000?oooooooooo01?ooooo00?o0000oi^hk?nK^>`01onK
^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00SoWZoT00?o0000oin/h?nO[>002?nO
[>000ol0003oXJ[Moj6Zg@03o`0000KoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFY
fP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML01?l0003o/K3Gok6`
eona/=L2o`0000So][CG00?o0000ok^ge_nk]mH00_nk]mH00ol0003o^kOFok^geP07ok^geP03o`00
0?nn^]Ko_[[F00Wo_[[F00Go0000olBne?o4_]Coa;kDo`00000?olO1e003o`000?o9a=GobLCE00Ko
bLCE00?o0000olg5doo=aM<01Oo=aM<00ol0003oooooooooo`1Rooooo`00;oooool00ol0003ooooo
ooooo`0Cooooo`;o00002OnK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00OoWZoT
00?o0000oin/h?nO[>001onO[>04o`0000[oVjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0003oYJWJ
ojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02on][ML00ol0003o/K3G
o`00000;okJde`05o`000?nk]mKo^kOFok^ge_l000002_nk]mH00ol0003o_[[FokjjeP07okjjeP03
o`000?o4_]Coa;kD00?oa;kD00?o0000olO1e?o7`M@03Oo7`M@00ol0003obLCEolW4e@04olW4e@03
o`000?o=aM?ocLGC00KocLGC0_l0001Sooooo`00;_ooool00ol0003oooooooooo`0Eooooo`;o0000
2OnK^>`00ol0003oW;?Xoibcj008oibcj003o`000?nN[nCoWZoT00OoWZoT00Co0000oin/h?nO[>3o
WjcP1Ol00002oiJYi003o`000?nKZN3oVjWP00WoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003o
YJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML02_n][ML2o`0000go
][CG00Co0000ok^ge_nk]mKo00002onk]mH00ol0003o_[[FokjjeP04okjjeP;o00001oo4_]@00ol0
003oal7DolO1e00<olO1e003o`000?o9a=GobLCE00?obLCE00?o0000olg5doo=aM<02?o=aM<00ol0
003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l00009oi^hk003o`000?nL/nSoW;?X00So
W;?X00?o0000oij_i?nN[n@00onN[n@7o`0000SoUZWT00?o0000oi^Yh?nKZN002OnKZN000ol0003o
X:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[f?nYZmP02OnYZmP00ol0003o
[JgGojf]e`08ojf]e`;o000000?o/K7Ho`000?nf]=L03?nf]=L01?l0003o^kOFok^ge_l0000<ok^g
eP03o`000?nn^]Ko_[[F00;o_[[F00?o0000olBne?o4_]@01oo4_]@00ol0003oal7DolO1e00=olO1
e005o`000?o9a=GobLCEolW4eOl000003?o=aM<00ol0003oooooooooo`1Pooooo`00;_ooool00ol0
003oooooooooo`0Gooooo`;o00002OnK^>`00ol0003oW;?Xoibcj003oibcj0[o00001?nAZnP00ol0
003oUZWToiJYi009oiJYi003o`000?nKZN3oVjWP00WoVjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0
003oYJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00[oZJ_H00?o0000ojf]eon][ML01?n][ML3o`00
00Co/K7H00?o0000okJdeonf]=L02onf]=L00ol0003o^kOFo`00000<ok^geP05o`000?nn^]Ko_[[F
okjje_l000002oo4_]@00ol0003oal7DolO1e00=olO1e003o`000?o9a=Go000000kocLGC00?o0000
ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000GoVkS/2Ol00005ohf^k003o`000?nAZnSo
TJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Yh003o`000?nPZMgo
X:WM00WoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0003oZJ_HojV[f00:ojV[f004o`000?n][MOo
[JgGojf]e`;o00002?na/MP00ol0003o][CGokJde`0;okJde`;o00003Onk]mH00ol0003o_[[Fo`00
000=olBne003o`000?o7`MCoal7D00coal7D0_l0000@olg5d`03o`000?oooooooooo05kooooo000B
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03o`000?oooooooooo01Wooooo1_l00004ohVal003o`000?n=[^coSJk/00SoSJk/
00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi008oiJYi003o`000?nKZN3oVjWP00WoVjWP
00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFYfP09ojFYfP03o`000?nYZmSoZJ_H00WoZJ_H
00Co0000ojf]eol0003o00002_na/MP00ol0003o][CGokJde`0;okJde`;o00003Onk]mH2o`0000oo
a;kD00?o0000olO1e?o7`M@02_o7`M@00ol0003oblCCo`00000@olg5d`03o`000?oooooooooo05ko
oooo000Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k008ohf^k003
o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Yh003
o`000?nPZMgoX:WM00SoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0003oZJ_HojV[f009ojV[f0;o
00003Ona/MP00ol0003o][CGokJde`0;okJde`03o`000?nk]mKo^kOF00[o^kOF00?o0000oknke_l0
00003oo4_]@00ol0003oal7DolO1e009olO1e005o`000?o;a=?oblCCol_4dol000004?o=aM<00ol0
003oooooooooo`1Mooooo`004_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01oooool00ol0003oooooooooo`0Kooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^
k?n=[^`02?n=[^`00ol0003oTJ_Xoi6[j007oi6[j003o`000?nFZNCoUZWT00SoUZWT00?o0000oi^Y
h?nKZN002?nKZN000ol0003oX:WMoj2Yg@09oj2Yg@03o`000?nUZM[oYJWJ00WoYJWJ00?o0000ojV[
f?nYZmP01OnYZmP3o`000003oj^^f_l0003o/K7H00go/K7H00?o0000okJdeonf]=L02_nf]=L00ol0
003o^kOFok^geP08ok^geP;o00000ono^mH00ol0003oa;kDolBne00=olBne003o`000?o7`MCoal7D
00Ooal7D00?o0000ol_4doo;a=<00oo;a=<00ol0003ocLGColg5d`0>olg5d`03o`000?oooooooooo
05cooooo000Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^
k003o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh009oi^Y
h003o`000?nPZMgoX:WM00WoX:WM00?o0000ojFYf_nUZMX02?nUZMX00ol0003oZJ_HojV[f003ojV[
f0;o00001On[[]X00ol0003o/K7Hok6af00;ok6af003o`000?nf]=Oo][CG00[o][CG0_l00007ok^g
eP;o00001_no^mH00ol0003oa;kDolBne00=olBne003o`000?o7`MCoal7D00Coal7D0_l00007ol_4
d`03o`000?o=aM?ocLGC00gocLGC0_l0001Mooooo`004_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00?o0000ohVal?n9/O001on9/O000ol0
003oSJk/ohf^k007ohf^k003o`000?nAZnSoTJ_X00OoTJ_X00?o0000oiJYi?nFZN@02?nFZN@00ol0
003oVjWPoi^Yh009oi^Yh003o`000?nPZMgoX:WM00SoX:WM00?o0000ojFYf_nUZMX02OnUZMX00ol0
003oZJ_Ho`000002o`0000SoZjkJ00?o0000ok6af?na/MP02ona/MP00ol0003o][CGokJde`09okJd
e`03o`000?nf]=Oo000000Go^kOF00?o0000oknke_no^mH01ono^mH00ol0003oa;kDolBne00<olBn
e003o`000?o7`MCoal7D00?oal7D00?o0000ol_4doo;a=<01oo;a=<00ol0003ocLGColg5d`0<olg5
d`03o`000?o?am;o000005gooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool07oooool00ol0003oRK7`ohVal007
ohVal003o`000?n=[^coSJk/00OoSJk/00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi008
oiJYi003o`000?nKZN3oVjWP00SoVjWP00?o0000oj2YgOnPZMd02OnPZMd00ol0003oYJWJojFYfP07
ojFYfP?o00002on[[]X00ol0003o/K7Hok6af00<ok6af003o`000?nf]=Oo][CG00So][CG00?o0000
okJdeol000000onk]mH2o`0000[o_k_F00?o0000olBne?o4_]@03Oo4_]@01Ol0003oal7DolO1e?o7
`MCo000000_oblCC00?o0000olg5doo=aM<02_o=aM<01Ol0003oclOBolo7d_o?am;o000005cooooo
000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool08?ooool00ol0003oRK7`ohVal007ohVal003o`000?n=[^coSJk/00Oo
SJk/00?o0000oi6[j?nAZnP01onAZnP00ol0003oUZWToiJYi007oiJYi003o`000?nKZN3oVjWP00Wo
VjWP00?o0000oj2YgOnPZMd02?nPZMd00ol0003oYJWJojFYfP04ojFYfP?o00000_nT[=d00ol0003o
ZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o/K7H00?o0000okJdeonf]=L02?nf]=L01_l0003o
][CGokJdeol0003o^kOFo`0000go_k_F00?o0000olBne?o4_]@03Oo4_]@00ol0003oal7Do`00000=
ol_4d`03o`000?o=aM?ocLGC00SocLGC00?o0000olo7d_o?am800oo?am800ol0003oooooooooo`1I
ooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^
k?n=[^`01_n=[^`00ol0003oTJ_Xoi6[j008oi6[j003o`000?nFZNCoUZWT00OoUZWT00?o0000oi^Y
h?nKZN002OnKZN000ol0003oX:WMoj2Yg@08oj2Yg@03o`000?nUZM[oYJWJ00?o00001_nT[=d00ol0
003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o/K7H00?o0000okJdeonf]=L01onf]=L00ol0
003o][CGokJde`02o`0000oo_k_F00?o0000olBne?o4_]@03?o4_]@2o`0000ooblCC00?o0000olg5
doo=aM<01_o=aM<00ol0003oclOBolo7dP05olo7dP03o`000?oooooooooo05Sooooo000]ooooo`03
o`000?oooooooooo027ooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^k003
o`000?nAZnSoTJ_X00SoTJ_X00?o0000oiJYi?nFZN@01onFZN@00ol0003oVjWPoi^Yh008oi^Yh003
o`000?nPZMgoX:WM00OoX:WM1?l0000:ojB/g@03o`000?n[[][oZjkJ00[oZjkJ00?o0000ok6af?na
/MP02_na/MP00ol0003o][CGokJde`07okJde`?o000000?o^[SGo`000?no^mH03ono^mH00ol0003o
a;kDolBne00:olBne003o`000?o8`]Co0000013oblCC00?o0000olg5doo=aM<01?o=aM<00ol0003o
clOBolo7dP06olo7dP03o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo
00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k007ohf^k003o`000?nAZnSoTJ_X00OoTJ_X
00?o0000oiJYi?nFZN@02?nFZN@00ol0003oVjWPoi^Yh008oi^Yh004o`000?nPZMgoX:WMoj2Yg@Go
00000_nLZ^000ol0003oY:cMojB/g@09ojB/g@03o`000?n[[][oZjkJ00[oZjkJ00?o0000ok6af?na
/MP02ona/MP00ol0003o][CGokJde`06okJde`03o`000?nj^=Oo^[SG00;o^[SG00?o0000oknke_no
^mH03Ono^mH00ol0003oa;kDolBne009olBne005o`000?o8`]Cob<;DolS2e?l000003oo;a=<00ol0
003ocLGColg5d`03olg5d`03o`000?o?am;oclOB00SoclOB00?o0000ooooooooool0Eoooool002co
oooo0ol0000Tooooo`03o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^k?n=[^`01on=[^`00ol0003o
TJ_Xoi6[j007oi6[j003o`000?nFZNCoUZWT00OoUZWT00?o0000oi^Yh?nKZN001onKZN05o`0000So
W:[P00?o0000ojB/gOnT[=d02OnT[=d00ol0003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00_o
/K7H00?o0000okJdeonf]=L00onf]=L3o`0000Go^[SG00?o0000oknke_no^mH03Ono^mH00ol0003o
a;kDolBne007olBne003o`000?o8`]Cob<;D00?ob<;D00?o0000ol_4doo;a=<03Oo;a=<01Ol0003o
cLGColg5doo=aM?o000000coclOB00?o0000ooooooooool0E_ooool002gooooo00?o0000oooooooo
ool09?ooool00ol0003oRK7`ohVal007ohVal003o`000?n=[^coSJk/00KoSJk/00?o0000oi6[j?nA
ZnP02?nAZnP00ol0003oUZWToiJYi007oiJYi004o`000?nKZN3oVjWPoi^Yh0Go00000_nDZ><00ol0
003oW:[PoibZh009oibZh003o`000?nT[=goY:cM00WoY:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0
003o/K7Hok6af00:ok6af004o`000?nf]=Oo][CGokJde`;o00000_nj^=L00ol0003o^[SGokZhe`03
okZhe`03o`000?no^mKo_k_F00ko_k_F00?o0000olBne?o4_]@01?o4_]@2o`0000Oob<;D00?o0000
ol_4doo;a=<03Oo;a=<00ol0003ocLGCo`00000>olo7dP03o`000?oooooooooo05Gooooo000]oooo
o`03o`000?oooooooooo02Gooooo00?o0000ohVal?n9/O001on9/O000ol0003oSJk/ohf^k006ohf^
k003o`000?nAZnSoTJ_X00SoTJ_X00?o0000oiJYi?nFZN@00onFZN@7o`0000SoU:SS00?o0000oibZ
h?nLZ^002?nLZ^000ol0003oY:cMojB/g@0:ojB/g@03o`000?n[[][oZjkJ00WoZjkJ00?o0000ok6a
f?na/MP02ona/MP00ol0003o][CGo`000004okZhe`03o`000?nj^=Oo^[SG00Co^[SG00?o0000oknk
e_no^mH03Ono^mH00ol0003oa;kDolBne003olBne003o`000?o8`]Cob<;D00Oob<;D00?o0000ol_4
doo;a=<03Oo;a=<2o`0000ooclOB0_l0001Fooooo`00;Oooool00ol0003oooooooooo`0Vooooo`03
o`000?n9/O3oRK7`00OoRK7`00?o0000ohf^k?n=[^`01_n=[^`00ol0003oTJ_Xoi6[j003oi6[j0[o
00001?n<YnL00ol0003oU:SSoiBXh`09oiBXh`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOnT
[=d02OnT[=d00ol0003oZjkJoj^^fP0:oj^^fP03o`000?na/MSo/K7H00[o/K7H0_l00005okZhe`03
o`000?nj^=Oo^[SG00Go^[SG00?o0000oknke_no^mH03Ono^mH01Ol0003oa;kDolBne?o4_]Co0000
00_ob<;D00?o0000ol_4doo;a=<02oo;a=<00ol0003oc/KCo`00000@olo7dP03o`000?oooooooooo
05Cooooo000/ooooo`03o`000?oooooooooo02Sooooo6?l00005oh>Vj`03o`000?n<YnOoS:OW00Oo
S:OW00?o0000oiBXhonDZ><02?nDZ><00ol0003oW:[PoibZh009oibZh003o`000?nT[=goY:cM00Wo
Y:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af007ok6af0;o000000?o];GJo`000?nj
^=L01?nj^=L00ol0003o^[SGokZhe`05okZhe`03o`000?no^mKo_k_F00ko_k_F00?o0000olBne?l0
00003Oo8`]@00ol0003oblCCol_4d`09ol_4d`05o`000?o>a]?oc/KColk6dol000004?o?am800ol0
003oooooooooo`1Cooooo`00;?ooool00ol0003oooooooooo`0Yooooo`03o`000?mfZ?;oMZSb00Ko
MZSb00?o0000ogbWkomlYnl01_mlYnl00ol0003oPjK[oh>Vj`08oh>Vj`03o`000?n<YnOoS:OW00Oo
S:OW00?o0000oiBXhonDZ><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00[o
Y:cM00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af004ok6af0;o00001?nd]MX00ol0003o
^[SGokZhe`02okZhe`03o`000?nj^=Oo^[SG00Ko^[SG00?o0000oknke_no^mH03Ono^mH2o`0000ko
b<;D00?o0000ol_4doo;a=<02?o;a=<00ol0003oc/KColk6d`03olk6d`03o`000?o?am;oclOB00ko
clOB00?o0000ooooooooool0D_ooool002cooooo0_l0000[ooooo`03o`000?mfZ?;oMZSb00KoMZSb
00?o0000ogbWkomlYnl01_mlYnl00ol0003oPjK[oh>Vj`08oh>Vj`03o`000?n<YnOoS:OW00KoS:OW
00?o0000oiBXhonDZ><02OnDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00WoY:cM
00?o0000oj^^f_n[[]X02_n[[]X00ol0003o/K7Hok6af002ok6af0;o00001ond]MX01Ol0003o^[SG
okZheonj^=Oo000000Wo^[SG00?o0000oknke_no^mH02ono^mH00ol0003oa;oFo`00000?olS2e003
o`000?o;a=?oblCC00KoblCC00?o0000olk6doo>a]<01Oo>a]<00ol0003oclOBolo7dP0=olo7dP;o
0000Doooool002cooooo00?o0000ooooooooool0:oooool00ol0003oMZSbogJXlP06ogJXlP03o`00
0?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/02?n3Y^/00ol0003oS:OWohbWi`06ohbWi`03o`00
0?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002OnLZ^000ol0003oY:cMojB/g@09ojB/g@03o`00
0?n[[][oZjkJ00[oZjkJ00Co0000ok6af?l0003o00002Ond]MX01Ol0003o^[SGokZheonj^=Oo0000
00[o^[SG00?o0000oknke_no^mH02Ono^mH01Ol0003oa;oFolBoe_o4_mKo000000oob<;D00?o0000
ol_4doo;a=<01?o;a=<00ol0003oc/KColk6d`06olk6d`03o`000?o?am;oclOB00goclOB0_l0001C
ooooo`00;?ooool00ol0003oooooooooo`0/ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogbW
komlYnl01_mlYnl00ol0003oPjK[oh>Vj`07oh>Vj`03o`000?n<YnOoS:OW00OoS:OW00?o0000oiBX
honDZ><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00[oY:cM00?o0000oj^^
f_n[[]X02On[[]X2o`0000co];GJ00Co0000okZheonj^=Oo00002_nj^=L00ol0003o_k_FoknkeP07
oknkeP;o00001Oo4_mH00ol0003ob<;DolS2e00=olS2e003o`000?o;a=?oblCC00;oblCC00?o0000
olk6doo>a]<02?o>a]<00ol0003oclOBolo7dP0;olo7dP04o`000?o@b=;od<SBo`0005;ooooo000/
ooooo`03o`000?oooooooooo02gooooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oO:O_ogbWk`06
ogbWk`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<YnL01on<YnL00ol0003oU:SSoiBXh`08
oiBXh`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOnT[=d02_nT[=d00ol0003oZjkJoj^^fP05
oj^^fP?o000000?o[;;Mo`000?nd]MX03?nd]MX00ol0003o^[SGo`00000;okZhe`03o`000?no^mKo
_k_F00Go_k_F00?o0000olBoe_o4_mH01Oo4_mH00ol0003ob<;DolS2e00=olS2e005o`000?o;a=?o
blCCol_4dol000003?o>a]<00ol0003oclOBolo7dP09olo7dP03o`000?o@b=;od<SB00;od<SB00?o
0000ooooooooool0Coooool002cooooo00?o0000ooooooooool0;_ooool00ol0003oMZSbogJXlP06
ogJXlP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/01on3Y^/00ol0003oS:OWohbWi`06
ohbWi`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002OnLZ^000ol0003oY:cMojB/g@09
ojB/g@03o`000?n[[][oZjkJ00?oZjkJ0_l00005ojbbg@03o`000?nd]M[o];GJ00[o];GJ00?o0000
okZheol000003?nj^=L00ol0003o_k_FoknkeP02oknkeP;o00002Oo4_mH00ol0003ob<;DolS2e00=
olS2e003o`000?o;a=?o000000goc/KC00?o0000olo7d_o?am802?o?am800ol0003od<SBom38dP03
om38dP;o0000D?ooool002cooooo00?o0000ooooooooool0;oooool00ol0003oMZSbogJXlP06ogJX
lP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>Vjon3Y^/01on3Y^/00ol0003oS:OWohbWi`06ohbW
i`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZh?nLZ^002?nLZ^000ol0003oY:cMojB/g@0:ojB/
g@03o`000?n[[][o000000;o00002?n//]d00ol0003o];GJokBefP0:okBefP;o00003?nj^=L01Ol0
003o_k_Foknke_no^mKo000000coa;oF00?o0000olS2e?o8`]@03?o8`]@2o`0000ooc/KC00?o0000
olo7d_o?am801_o?am800ol0003od<SBom38dP05om38dP03o`000?oooooooooo04kooooo000/oooo
o`;o0000<Oooool00ol0003oMZSbogJXlP05ogJXlP03o`000?mlYnooO:O_00KoO:O_00?o0000oh>V
jon3Y^/01on3Y^/00ol0003oS:OWohbWi`07ohbWi`03o`000?nDZ>?oU:SS00SoU:SS00?o0000oibZ
h?nLZ^002?nLZ^000ol0003oY:cMojB/g@09ojB/g@;o00002on//]d00ol0003o];GJokBefP0;okBe
fP03o`000?nj^=Oo^[SG00_o^[SG00?o0000oknke_l000003Oo4_mH00ol0003ob<;DolS2e00;olS2
e003o`000?o;aMCo0000013oc/KC00?o0000olo7d_o?am801?o?am800ol0003od<SBom38dP07om38
dP03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo00?o0000ogJXl_mf
Z?801OmfZ?800ol0003oO:O_ogbWk`06ogbWk`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<
YnL01_n<YnL00ol0003oU:SSoiBXh`08oiBXh`03o`000?nLZ^3oW:[P00WoW:[P00?o0000ojB/gOnT
[=d01OnT[=d3o`000003oj>_h?l0003o[;;M00_o[;;M00?o0000okBef_nd]MX02_nd]MX2o`0000co
^[SG0_l0000?olBoeP03o`000?o8`]Cob<;D00Wob<;D00Go0000ol_5e?o;aMCoblGDo`00000@olk6
d`03o`000?o?am;oclOB00;oclOB00?o0000om38d_o@b=802Oo@b=800ol0003oooooooooo`1<oooo
o`00:oooool00ol0003oooooooooo`0cooooo`03o`000?mfZ?;oMZSb00GoMZSb00?o0000ogbWkoml
Ynl01_mlYnl00ol0003oPjK[oh>Vj`07oh>Vj`03o`000?n<YnOoS:OW00KoS:OW00?o0000oiBXhonD
Z><02?nDZ><00ol0003oW:[PoibZh008oibZh003o`000?nT[=goY:cM00?oY:cM0_l00005oj>_h003
o`000?n//]go[;;M00[o[;;M00?o0000okBef_nd]MX02Ond]MX2o`0000[o^[SG0_l000000onn_MWo
0000olBoeP0?olBoeP03o`000?o8`]Cob<;D00Oob<;D00?o0000ol_5e?o;aM@00oo;aM@00ol0003o
c/KColk6d`0=olk6d`05o`000?o?am;oclOBolo7d_l000003?o@b=82o`0004gooooo000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo03Cooooo00?o0000ogJXl_mfZ?801OmfZ?800ol0003oO:O_ogbWk`06ogbW
k`03o`000?n3Y^_oPjK[00OoPjK[00?o0000ohbWion<YnL01_n<YnL00ol0003oU:SSoiBXh`08oiBX
h`03o`000?nLZ^3oW:[P00SoW:[P00?o0000ojB/gOl000000_l00008oj>_h003o`000?n//]go[;;M
00Wo[;;M00?o0000okBef_nd]MX02Ond]MX00ol0003o];GJo`000008okZhe`03o`000?nn_MWo_[gI
00;o_[gI00?o0000olBoe_o4_mH03Oo4_mH00ol0003ob<;DolS2e006olS2e003o`000?o;aMCoblGD
00GoblGD00?o0000olk6doo>a]<03Oo>a]<00ol0003oclOBo`00000>om38dP;o0000C?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Gooooo00?o0000ogJXl_mfZ?801OmfZ?800ol0003oO:O_ogbWk`06ogbW
k`03o`000?n3Y^_oPjK[00KoPjK[00?o0000ohbWion<YnL01on<YnL00ol0003oU:SSoiBXh`07oiBX
h`03o`000?nLZ^3oW:[P00OoW:[P0ol0000;oj>_h003o`000?n//]go[;;M00[o[;;M00?o0000okBe
f_nd]MX02?nd]MX01?l0003o];GJokBef_l00005okZhe`;o00001_nn_MT00ol0003oa;oFolBoeP0=
olBoeP03o`000?o8`]Cob<;D00Cob<;D00?o0000ol_5e?o;aM@01_o;aM@00ol0003oc/KColk6d`0=
olk6d`;o00004?o@b=800ol0003oooooooooo`1:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo1_l00002ogJXlP03o`000?mlYnoo
O:O_00KoO:O_00?o0000oh>Vjon3Y^/01_n3Y^/00ol0003oS:OWohbWi`06ohbWi`03o`000?nDZ>?o
U:SS00SoU:SS00Co0000oibZh?nLZ^3oW:[P1Ol00002oiV/i003o`000?nS[n3oXjoP00[oXjoP00?o
0000ojbbgOn//]d02_n//]d00ol0003o];GJokBefP07okBefP04o`000?nd]M[o];GJo`0000?o^[SG
0_l00009okjmf@03o`000?o4_mKoa;oF00goa;oF00?o0000olS2e?o8`]@00_o8`]@00ol0003oblGD
ol_5e008ol_5e003o`000?o>a]?oc/KC00_oc/KC00?o0000olo8dol000004Oo@b=800ol0003ooooo
ooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0gooooo`03o`000?mRWo;oHYob00;oHYob4_l00003oh>Vj`03
o`000?n<YnOoS:OW00KoS:OW00?o0000oiBXhonDZ><00onDZ><8o`0000SoVJcT00?o0000oj>_h?nS
[n002_nS[n000ol0003o[;;Mojbbg@09ojbbg@03o`000?nd]M[o];GJ00Oo];GJ00Oo0000okBef_nd
]M[o];GJo`000?nj^=Oo000000co_[gI00?o0000olBoe_o4_mH03?o4_mH01Ol0003ob<;DolS2e?o8
`]Co000000coblGD00?o0000olk6doo>a]<02Oo>a]<01Ol0003oclSColo8doo?b=?o0000013od<SB
0_l0001:ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo
00001oooool00ol0003oooooooooo`0hooooo`03o`000?mRWo;oHYob00CoHYob00?o0000ofZPl?mZ
X?001_mZX?000ol0003oMJ;^ogFRkP03ogFRkQ;o00001On>Z>L00ol0003oVJcToiV/i009oiV/i003
o`000?nS[n3oXjoP00WoXjoP00?o0000ojbbgOn//]d02_n//]d00ol0003o];GJokBefP06okBefP04
o`000?nd]M[o];GJokBefP;o00003Onn_MT00ol0003oa;oFolBoeP0=olBoeP03o`000?o8`]Co0000
00goblGD00?o0000olk6doo>a]<02?o>a]<00ol0003oclSColo8d`03olo8d`03o`000?o@b=;od<SB
00kod<SB0_l00019ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<
c?l000001_ooool2o`0003_ooooo00?o0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZP
l003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjX
i`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002_nS[n000ol0003o[;;Mojbbg@09ojbb
g@03o`000?nd]M[o];GJ00Ko];GJ00Ko0000okBef_l0003o0000okNjg?l0000>okjmf@03o`000?o4
_mKoa;oF00coa;oF0_l0000?ol_5e003o`000?o>a]?oc/KC00Koc/KC00?o0000olo8doo?b=<01Oo?
b=<00ol0003od<SBom38dP0<om38dP03o`000?o@bM?o000004Wooooo000@ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo00?o
0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o
0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o
0000oj>_h?nS[n002_nS[n000ol0003o[;;Mojbbg@09ojbbg@03o`000?nd]M[o];GJ00Go];GJ0_l0
0004okNjg003o`000?nn_MWo_[gI00co_[gI00?o0000olBoe_o4_mH02_o4_mH00ol0003oalCGo`00
000@ol_5e003o`000?o>a]?oc/KC00Coc/KC00?o0000olo8doo?b=<01oo?b=<00ol0003od<SBom38
dP0:om38dP05o`000?o@bM?od<WCom39dol00000B?ooool0013ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003oHYob
of:OlP04of:OlP03o`000?mZX?3oJZ3`00KoJZ3`00?o0000ogFRk_meX^h01_meX^h00ol0003oPJG[
oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00SoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoP
oj>_h009oj>_h003o`000?n//]go[;;M00[o[;;M00?o0000okBef_nd]MX00ond]MX2o`0000Ko]k[L
00?o0000okjmfOnn_MT03?nn_MT00ol0003oa;oFolBoeP07olBoeP;o00000oo7a=L00ol0003oblGD
ol_5e00>ol_5e003o`000?o>a]?oc/KC00;oc/KC00?o0000olo8doo?b=<02Oo?b=<00ol0003od<SB
om38dP08om38dP03o`000?o@bM?od<WC00;od<WC0_l00017ooooo`00:_ooool00ol0003ooooooooo
o`0mooooo`03o`000?mRWo;oHYob00CoHYob00?o0000ofZPl?mZX?001_mZX?000ol0003oMJ;^ogFR
kP06ogFRkP03o`000?n1YN_oPJG[00KoPJG[00?o0000ohjXion>Z>L01on>Z>L00ol0003oVJcToiV/
i008oiV/i003o`000?nS[n3oXjoP00[oXjoP00?o0000ojbbgOn//]d02On//]d01?l0003o];GJokBe
f_nd]MX2o`000003okNjg?l0003o]k[L00Ko]k[L00?o0000okjmfOnn_MT02onn_MT00ol0003oa;oF
olBoeP06olBoeP03o`000?o7a=OoalCG00CoalCG00?o0000ol_5e?o;aM@03Oo;aM@01Ol0003oc/KC
olk6doo>a]?o000000coclSC00?o0000om38d_o@b=801oo@b=800ol0003od<WCom39d`04om39d`03
o`000?oooooooooo04Gooooo000Zooooo`03o`000?oooooooooo03kooooo00?o0000of:Ol_mRWo80
1?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/0
1_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n00
2OnS[n000ol0003o[;;Mojbbg@0:ojbbg@03o`000?nd]M[o000000?o]k[L00?o0000okNjg?ng^]`0
1Ong^]`00ol0003o_[gIokjmf@0<okjmf@03o`000?o4_mKoa;oF00Coa;oF00?o0000olO4eoo7a=L0
1_o7a=L00ol0003oblGDol_5e00=ol_5e003o`000?o>a]?o000000koclSC00?o0000om38d_o@b=80
1Oo@b=800ol0003od<WCom39d`06om39d`03o`000?oooooooooo04Cooooo000Zooooo`03o`000?oo
oooooooo03oooooo00?o0000of:Ol_mRWo801?mRWo800ol0003oJZ3`ofZPl006ofZPl003o`000?me
X^koMJ;^00GoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`08ohjXi`03o`000?nI
[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mojbbg@09ojbbg@;o00001?ng
^]`00ol0003o]k[LokNjg006okNjg003o`000?nn_MWo_[gI00co_[gI00Co0000olBoe_o4_mKoa;oF
0_l00009olO4e`03o`000?o;aMCoblGD00goblGD0_l0000@olo8d`03o`000?o@b=;od<SB00?od<SB
00?o0000om39doo@bM<02?o@bM<00ol0003oooooooooo`13ooooo`00:Oooool3o`00043ooooo0_l0
0006of:OlP03o`000?mZX?3oJZ3`00GoJZ3`00?o0000ogFRk_meX^h01_meX^h00ol0003oPJG[oh6U
j`06oh6Uj`03o`000?n>Z>OoSZSW00SoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoPoj>_
h009oj>_h003o`000?n//]go[;;M00Go[;;M0ol000000on^]n3o0000okNjg003okNjg003o`000?ng
^]co]k[L00Oo]k[L00?o0000okjmfOnn_MT03?nn_MT00ol0003oa;oFo`00000<olO4e`03o`000?o;
aMCoblGD00_oblGD00?o0000olg9e_l000004Oo?b=<01Ol0003od<SBom38d_o@b=;o000000_od<WC
0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o00001_mRWo800ol0003oJZ3`ofZP
l005ofZPl003o`000?meX^koMJ;^00KoMJ;^00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjX
i`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mojbb
g@03ojbbg@;o00001On^]n001Ol0003o]k[LokNjg?ng^]co000000[o]k[L00?o0000okjmfOnn_MT0
2onn_MT2o`0000koalCG00?o0000ol_5e?o;aM@02Oo;aM@01Ol0003ocLWFolg9e_o=bMKo0000017o
clSC00?o0000om38d_l000003Oo@bM<00ol0003oooooooooo`12ooooo`00:_ooool00ol0003ooooo
ooooo`11ooooo`;o00001_mRWo800ol0003oJZ3`ofZPl005ofZPl003o`000?meX^koMJ;^00KoMJ;^
00?o0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT
00?o0000oj>_h?nS[n002OnS[n000ol0003o[;;Mo`000002o`0000So[[OP00Co0000okNjg?ng^]co
00002_ng^]`00ol0003o_[gIokjmf@0:okjmf@03o`000?o1`]_o000000ooalCG00?o0000ol_5e?o;
aM@01oo;aM@00ol0003ocLWFolg9eP03olg9eP03o`000?o?b=?oclSC00koclSC0_l0000?om39d`03
o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooooooo04;ooooo1?l00004of:OlP03o`00
0?mZX?3oJZ3`00GoJZ3`00?o0000ogFRk_meX^h01OmeX^h00ol0003oPJG[oh6Uj`07oh6Uj`03o`00
0?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@02?nI[>@00ol0003oXjoPoj>_h007oj>_h0?o0000
3?n^]n000ol0003o]k[Lo`00000;okNjg003o`000?nn_MWo_[gI00Oo_[gI0_l00003ol72f`03o`00
0?o7a=OoalCG00goalCG00?o0000ol_5e?o;aM@01?o;aM@2o`0000OocLWF00?o0000olo8doo?b=<0
3?o?b=<00ol0003od<_Eo`00000@om39d`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oo
oooooooo04Cooooo00?o0000oe6Fl?mAU_001_l00007ofZPl003o`000?meX^koMJ;^00GoMJ;^00?o
0000oh6Ujon1YN/01_n1YN/00ol0003oSZSWohjXi`07ohjXi`03o`000?nI[>CoVJcT00SoVJcT00?o
0000oj>_h?nS[n001?nS[n03o`0000;oXk?T00?o0000ojjgh?n^]n002on^]n02o`0000co]k[L00?o
0000okjmfOnn_MT01Onn_MT00ol0003o`L;Kol72f`04ol72f`03o`000?o7a=OoalCG00coalCG00?o
0000ol_5e?o;aM@00oo;aM@00ol0003ocLWFolg9eP08olg9eP03o`000?o?b=?oclSC00[oclSC00Go
0000om3;eOo@bmGod<_Eo`00000?om39d`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oo
oooooooo04Gooooo00?o0000oe6Fl?mAU_001?mAU_07o`0000;oJZ3`00?o0000ogFRk_meX^h01Ome
X^h00ol0003oPJG[oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@02?nI
[>@00ol0003oXjoPoj>_h003o`0000KoXk?T00?o0000ojjgh?n^]n002_n^]n02o`0000co]k[L00?o
0000okjmfOnn_MT01?nn_MT00ol0003o`L;Kol72f`06ol72f`03o`000?o7a=OoalCG00coalCG00Go
0000ol_5e?o;aMCoblGDo`00000<olg9eP03o`000?o?b=?oclSC00SoclSC00?o0000om3;eOo@bmD0
0oo@bmD00ol0003od<WCom39d`0=om39d`03o`000?oooooooooo03oooooo000Yooooo`03o`000?oo
oooooooo04Kooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZIl003oeZIl0Wo00000_me
X^h00ol0003oPJG[oh6Uj`06oh6Uj`03o`000?n>Z>OoSZSW00OoSZSW00?o0000oiV/i?nI[>@00onI
[>@7o`0000[oXk?T00?o0000ojjgh?n^]n002_n^]n000ol0003o]k[LokNjg00;okNjg004o`000?nn
_MWo_[gIokjmf@;o00002Oo1`]/00ol0003oalCGolO4e`0=olO4e`03o`000?o;aMCo000000gocLWF
00?o0000olo8doo?b=<01oo?b=<00ol0003od<_Eom3;e@05om3;e@03o`000?o@bM?od<WC00cod<WC
0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZI
l005oeZIl003o`000?mWW^ooIik_00?oIik_2Ol00003oh6Uj`03o`000?n>Z>OoSZSW00?oSZSW2Ol0
0005oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o0000ojjgh?n^]n002On^]n02o`0000go]k[L00?o
0000okjmfOl000003?o1`]/00ol0003oalCGolO4e`0<olO4e`;o00003oo=bMH00ol0003oclSColo8
d`05olo8d`03o`000?o@bmGod<_E00Kod<_E00?o0000om39doo@bM<02oo@bM<01?l0003ocl[Eo`00
0?l0000oooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?mAU_3oDIK`00CoDIK`00?o
0000oeZIl?mJVO001OmJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00?oMjC^2Ol0
0004ohNYk003o`000?nF[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02_nS/n@00ol0003o[[OPojjg
h008ojjgh003o`000?n^]n3o000000co]k[L0_l0000>ol72f`03o`000?o7a=OoalCG00[oalCG00?o
0000olW8fOl000004?o=bMH00ol0003oclSColo8d`03olo8d`03o`000?o@bmGod<_E00Sod<_E00?o
0000om39doo@bM<02Oo@bM<01Ol0003ocl[Eolo:eOo?b]Go000003oooooo000Yooooo`03o`000?oo
oooooooo04Wooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`oeZIl005oeZIl003o`000?mW
W^ooIik_00GoIik_00?o0000ogNTk_mgY>h01_mgY>h00ol0003oQjW/ohNYk007ohNYk003o`000?nF
[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o[[OPojjgh008ojjgh003o`000?n^
]n3o000000[o]k[L0_l000000oni`=oo0000ol72f`0=ol72f`03o`000?o7a=OoalCG00WoalCG00Go
0000olW8fOo9b=WobLSIo`00000@olg9eP05o`000?o?b=?oclSColo8dol000003?o@bmD00ol0003o
d<WCom39d`07om39d`03o`000?o?b]Gocl[E00?ocl[E00?o0000ooooooooool0??ooool002Wooooo
00?o0000ooooooooool0B_ooool00ol0003oDIK`oe6Fl004oe6Fl003o`000?mJVO3oFYW`00GoFYW`
00?o0000ofNNkomWW^l01OmWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/00OoQjW/
00?o0000oiJ_j?nF[nP02?nF[nP00ol0003oXk?Toj>ci009oj>ci003o`000?n^]n3o[[OP00Oo[[OP
00Co0000ojjgh?n^]n3o00001ong^]`2o`0000Co^L3O00?o0000ol72foo1`]/03?o1`]/00ol0003o
alCGolO4e`07olO4e`03o`000?o9b=WobLSI00?obLSI00?o0000olg9e_o=bMH03_o=bMH00ol0003o
clSCo`00000>om3;e@03o`000?o@bM?od<WC00Cod<WC0_l00007olo:e@03o`000?oooooooooo03_o
oooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oFYW`
oeZIl005oeZIl003o`000?mWW^ooIik_00GoIik_00?o0000ogNTk_mgY>h01_mgY>h00ol0003oQjW/
ohNYk007ohNYk003o`000?nF[nSoUZoX00SoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o[[OP
ojjgh006ojjgh005o`000?n^]n3o[[OPojjgh?l000001?ng^]`2o`0000Oo^L3O00?o0000ol72foo1
`]/03?o1`]/00ol0003oalCGolO4e`04olO4e`;o00001oo9b=T00ol0003ocLWFolg9eP0=olg9eP;o
00003oo@bmD00ol0003od<WCom39d`03om39d`03o`000?o?b]Gocl[E00Oocl[E0_l0000looooo`00
:Oooool00ol0003oooooooooo`1<ooooo`03o`000?mAU_3oDIK`00CoDIK`00?o0000oeZIl?mJVO00
1OmJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`0
1on7ZN`00ol0003oUZoXoiJ_j007oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o0000ojjgh?n^]n00
1On^]n000ol0003o[[OPojjgh002ojjgh004o`000?ng^]co0000o`0000[o^L3O00?o0000ol72foo1
`]/03?o1`]/00ol0003oalCGolO4e`02olO4e`03o`000?o9b=WobLSI00SobLSI00?o0000olg9e_o=
bMH02oo=bMH00ol0003oc/cHo`00000@om3;e@05o`000?o@bM?od<WCom39dol000002oo?b]D00ol0
003oooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003o
FYW`oeZIl005oeZIl003o`000?mWW^ooIik_00CoIik_00?o0000ogNTk_mgY>h01omgY>h00ol0003o
QjW/ohNYk007ohNYk003o`000?nF[nSoUZoX00OoUZoX00?o0000oj>ci?nS/n@02OnS/n@00ol0003o
[[OPojjgh005ojjgh003o`000?n^]n3o[[OP00;o[[OP0_l0000=okW0g`03o`000?o1`]_o`L;K00_o
`L;K00Go0000olO4eoo7a=OoalCGo`00000<olW8f@03o`000?o=bMKocLWF00WocLWF00Go0000olk<
f?o>c=Soc/cHo`00000@om3;e@03o`000?o@bM?o000000gocl[E00?o0000ooooooooool0>Oooool0
02Sooooo00?o0000ooooooooool0Coooool00ol0003oDIK`oe6Fl004oe6Fl003o`000?mJVO3oFYW`
00CoFYW`00?o0000ofNNkomWW^l01OmWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/
00SoQjW/00?o0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci009oj>ci003o`000?n^]n3o[[OP
00Co[[OP00?o0000ojjgh?l000000_l000000on__NCo0000okW0g`0=okW0g`03o`000?o1`]_o`L;K
00_o`L;K00?o0000olO4eol000003Oo9b=T00ol0003ocLWFolg9eP08olg9eP03o`000?o>c=Soc/cH
00?oc/cH00?o0000om3;eOo@bmD03Oo@bmD2o`0000oocl[E00?o0000ooooooooool0>?ooool000co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Oooooo00?o0000ooooooooool0D?ooool3o`0000CoDIK`00?o0000oeZIl?mJVO001?mJVO00
0ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`01on7ZN`0
0ol0003oUZoXoiJ_j008oiJ_j003o`000?nS/nCoXk?T00WoXk?T00?o0000ojjgh?n^]n000on^]n02
o`0000Go[kgT00?o0000okW0goni`=l03?ni`=l00ol0003o`L;Kol72f`0:ol72f`;o00003oo9b=T0
0ol0003ocLWFolg9eP05olg9eP;o00001oo>c=P00ol0003od<_Eom3;e@0;om3;e@03o`000?o?cMSo
000000oocl[E0_l0000iooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1@ooooo`03o`000?m6
T>ooAY3_00Ko00001_mJVO000ol0003oIik_ofNNk`05ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o
0000ohNYk?n7ZN`01on7ZN`00ol0003oUZoXoiJ_j007oiJ_j003o`000?nS/nCoXk?T00[oXk?T00?o
0000ojjgh?l000000ol00007ojnmi003o`000?ni`=oo^L3O00_o^L3O00?o0000ol72foo1`]/02Oo1
`]/01?l0003o`lSNol?8g_l0000?olW8f@03o`000?o=bMKocLWF00?ocLWF00?o0000olk<f?o>c=P0
2?o>c=P00ol0003od<_Eom3;e@09om3;e@05o`000?o?cMSoclgHolo=f?l000003oo?b]D00ol0003o
ooooooooo`0gooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo057ooooo00?o0000odJ@kom6T>l01?m6T>l4o`00
00CoFYW`00?o0000ofNNkomWW^l01?mWW^l00ol0003oMjC^ogNTkP07ogNTkP03o`000?n7ZNcoQjW/
00OoQjW/00?o0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci008oj>ci0Go000000?o[kgTo`00
0?n__N@01on__N@00ol0003o^L3OokW0g`0;okW0g`03o`000?o1`]_o`L;K00Ko`L;K0_l00004ol?8
gP03o`000?o9b=WobLSI00gobLSI00Go0000olg9e_o=bMKocLWFo`00000<olk<f003o`000?o@bmGo
d<_E00Ood<_E00?o0000olo=f?o?cMP00oo?cMP00ol0003ocl[Eolo:e@0=olo:e@03o`000?oooooo
oooo03Kooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q00Oooooo00?o0000ooooooooool0D_ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?
U?3oCiC`00Ko00001_mWW^l00ol0003oMjC^ogNTkP06ogNTkP03o`000?n7ZNcoQjW/00SoQjW/00?o
0000oiJ_j?nF[nP01onF[nP00ol0003oXk?Toj>ci004oj>ci0Ko00001?n__N@00ol0003o[kgTojnm
i006ojnmi003o`000?ni`=oo^L3O00_o^L3O00?o0000ol72foo1`]/01?o1`]/00ol0003o`lSNol?8
gP05ol?8gP03o`000?o9b=WobLSI00gobLSI00?o0000olg9e_l000003_o>c=P00ol0003od<_Eom3;
e@05om3;e@03o`000?o?cMSoclgH00GoclgH00?o0000olo:eOo?b]D03?o?b]D2o`0003Oooooo000<
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo
00?o0000ooooooooool0Doooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`
1?l00004ofNNk`03o`000?mgY>koMjC^00KoMjC^00?o0000ohNYk?n7ZN`02?n7ZN`00ol0003oUZoX
oiJ_j007oiJ_j003o`000?nS/nCoXk?T00Go00001?nR^NT00ol0003o[kgTojnmi002ojnmi003o`00
0?n__NCo[kgT00Ko[kgT00?o0000okW0goni`=l02oni`=l01?l0003o`L;Kol72foo1`]/2o`0000Wo
`lSN00?o0000olW8fOo9b=T03?o9b=T2o`00013oc/cH00?o0000om3;eOo@bmD00oo@bmD00ol0003o
clgHolo=f007olo=f003o`000?o?b]Gocl[E00[ocl[E00Co0000olc;fOl0003o0000=_ooool000co
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`00?o0000oefK
lOmMVo401_l00008ogNTkP03o`000?n7ZNcoQjW/00SoQjW/00?o0000oiJ_j?nF[nP00onF[nP8o`00
00SoX[WY00?o0000ojnmi?n__N@00_n__N@00ol0003o[kgTojnmi006ojnmi003o`000?ni`=oo^L3O
00_o^L3O00?o0000ol72fol000003?o3b=h00ol0003obLSIolW8f@0:olW8f@03o`000?o:cMco0000
017oc/cH00Go0000om3;eOo@bmGod<_Eo`00000;olo=f003o`000?o?b]Gocl[E00Oocl[E0_l00003
olc;f@03o`000?oooooooooo03Cooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV008ooooo`;o0000Eoooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3o
CiC`00CoCiC`00?o0000oefKlOmMVo401?mMVo47o`0000?oMjC^00?o0000ohNYk?n7ZN`00on7ZN`:
o`0000;oTk?]0ol0000<oj:ij@03o`000?n__NCo[kgT00;o[kgT00?o0000ojnmi?n__N@01On__N@0
0ol0003o^L3OokW0g`0;okW0g`;o00003_o3b=h00ol0003obLSIolW8f@08olW8f@05o`000?o:cMco
b/gLol[=g?l000004Oo>c=P00ol0003od<_Eo`00000<olo=f003o`000?o?b]Gocl[E00Kocl[E00?o
0000olc;fOo<bmT01?o<bmT00ol0003oooooooooo`0cooooo`003?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Gooooo`03o`00
0?m6T>ooAY3_00CoAY3_00?o0000odnDl?m?U?001?m?U?000ol0003oGI_aoefKl@05oefKl@03o`00
0?m^Xo7oKZ?a00;oKZ?a2Ol00005oh6/l004o`000?nC/ngoTk?]oi>ck@?o00000onC/nd00ol0003o
X[WYoj:ij@0:oj:ij@03o`000?n__NCo[kgT00;o[kgT00?o0000ojnmi?n__N@01On__N@00ol0003o
^L3OokW0g`08okW0g`;o000000?o^lKSo`000?o3b=h03_o3b=h00ol0003obLSIolW8f@05olW8f@;o
00001Oo:cM`00ol0003oc/cHolk<f00>olk<f0;o00003_o?cMP00ol0003ocl[Eolo:e@04olo:e@03
o`000?o<bmWoc<_I00Koc<_I00?o0000ooooooooool0<_ooool002Oooooo00?o0000ooooooooool0
F?ooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`00?o0000oefKlOmMVo40
1OmMVo400ol0003oKZ?aofjSl@05ofjSl@03o`000?n1[?3oPJc`00SoPJc`0ol00007oi>ck@03o`00
0?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n__N@00_n__N@00ol0003o[kgTojnmi005ojnmi003o`00
0?ni`=oo^L3O00Go^L3O0_l00004ok_6h`03o`000?o3b=ko`lSN00go`lSN00?o0000olW8fOo9b=T0
0oo9b=T00ol0003ob/gLol[=g006ol[=g003o`000?o>c=Soc/cH00coc/cH00?o0000olg?fol00000
3oo?cMP01?l0003ocl[Eolo:eOo?b]D2o`0000[oc<_I00?o0000ooooooooool0<Oooool002Oooooo
00?o0000ooooooooool0FOooool00ol0003oAY3_odJ@k`04odJ@k`03o`000?m?U?3oCiC`00CoCiC`
00?o0000oefKlOmMVo401OmMVo400ol0003oKZ?aofjSl@05ofjSl@03o`000?n1[?3oPJc`00CoPJc`
0ol000000on1[?3o0000oi>ck@08oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n__N@0
0_n__N@00ol0003o[kgTojnmi005ojnmi003o`000?ni`=oo^L3O00;o^L3O0_l00007ok_6h`03o`00
0?o3b=ko`lSN00go`lSN00Go0000olW8fOo9b=WobLSIo`00000:ol[=g003o`000?o>c=Soc/cH00[o
c/cH00Go0000olg?foo=cm_ocLoKo`00000?olo=f003o`000?o?b]Go000000coc<_I0_l0000boooo
o`009oooool00ol0003oooooooooo`1Jooooo`03o`000?m6T>ooAY3_00CoAY3_00?o0000odnDl?m?
U?001?m?U?000ol0003oGI_aoefKl@05oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/l?n1
[?000ol00005oh6/l003o`000?nC/ngoTk?]00OoTk?]00?o0000oj:ijOnR^NT02OnR^NT00ol0003o
[kgTojnmi002ojnmi003o`000?n__NCo[kgT00Ko[kgT00Co0000okW0gol0003o00002_nka^<00ol0
003o`lSNol?8gP0=ol?8gP03o`000?o9b=Wo000000cob/gL00?o0000olk<f?o>c=P02?o>c=P00ol0
003ocLoKolg?f`03olg?f`03o`000?o?cMSoclgH00coclgH0_l0000>olc;f@03o`000?oooooooooo
033ooooo000Wooooo`03o`000?oooooooooo05_ooooo00?o0000odJ@kom6T>l01?m6T>l00ol0003o
CiC`odnDl004odnDl003o`000?mMVo7oGI_a00GoGI_a00?o0000ofjSlOm^Xo401?m^Xo43o`0000So
PJc`00?o0000oi>ckOnC/nd02?nC/nd00ol0003oX[WYoj:ij@09oj:ij@03o`000?n__NCo[kgT00;o
[kgT00?o0000ojnmi?n__N@01On__N@2o`0000go^lKS00?o0000ol?8g_o3b=h03?o3b=h2o`0000ko
b/gL00?o0000olk<f?o>c=P01Oo>c=P2o`0000OocLoK00?o0000olo=f?o?cMP02_o?cMP00ol0003o
c<oLo`00000?olc;f@03o`000?oooooooooo02oooooo000Wooooo`;o0000GOooool3o`0000CoAY3_
00?o0000odnDl?m?U?000om?U?000ol0003oGI_aoefKl@06oefKl@03o`000?m^Xo7oKZ?a00?o0000
0_m^Xo400ol0003oPJc`oh6/l007oh6/l003o`000?nC/ngoTk?]00SoTk?]00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003o[kgTojnmi002ojnmi004o`000?n__NCo[kgTojnmi0?o000000?o/<?Xo`000?nk
a^<03Onka^<00ol0003o`lSNol?8gP0:ol?8gP03o`000?o4cN7o000000oob/gL00?o0000olk<f?o>
c=P00oo>c=P00ol0003ocLoKolg?f`08olg?f`03o`000?o?cMSoclgH00SoclgH00Go0000olc?g?o<
cmcoc<oLo`00000?olc;f@03o`000?oooooooooo02kooooo000Vooooo`;o0000Goooool00ol0003o
@Xk^o`000005o`0000GoCiC`00?o0000oefKlOmMVo401OmMVo43o`0000KoKZ?a00?o0000oh6/l?n1
[?001on1[?000ol0003oTk?]oi>ck@07oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnmi?n_
_N@00_n__N@3o`0000Go/<?X00?o0000ok_6honka^<02onka^<00ol0003o`lSNol?8gP08ol?8gP;o
00000oo4cN400ol0003ob/gLol[=g00=ol[=g005o`000?o>c=Soc/cHolk<f?l000003?o=cm/00ol0
003oclgHolo=f006olo=f003o`000?o<cmcoc<oL00?oc<oL00?o0000olc;fOo<bmT03?o<bmT2o`00
02oooooo000Wooooo`03o`000?oooooooooo05kooooo00?o0000od:>k_m2S^h00om2S^h4o`0000?o
CiC`00Co0000oefKlOmMVo7oGI_a0ol00002oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/
l?n1[?001on1[?000ol0003oTk?]oi>ck@07oi>ck@03o`000?nR^NWoX[WY00[oX[WY00?o0000ojnm
i?l000000ol00007ok33j003o`000?nka^?o^lKS00_o^lKS00?o0000ol?8g_o3b=h01_o3b=h00ol0
003oa<gQolC=h@04olC=h@03o`000?o:cMcob/gL00gob/gL00?o0000olk<f?l000003Oo=cm/00ol0
003oclgHolo=f005olo=f003o`000?o<cmcoc<oL00Goc<oL00?o0000olc;fOo<bmT03?o<bmT2o`00
02kooooo000Wooooo`03o`000?oooooooooo05oooooo00?o0000od:>k_m2S^h00om2S^h00ol0003o
BI;`odVBl003o`000004odnDl?l0003o0000o`0000KoGI_a00?o0000ofjSlOm^Xo401Om^Xo400ol0
003oPJc`oh6/l007oh6/l003o`000?nC/ngoTk?]00OoTk?]00?o0000oj:ijOnR^NT02?nR^NT3o`00
00Co/<?X00?o0000ok33j?n``nP01On``nP00ol0003o^lKSok_6h`0;ok_6h`03o`000?o3b=ko`lSN
00Co`lSN00?o0000olC=hOo4cN401_o4cN400ol0003ob/gLol[=g00<ol[=g0;o00003oo=cm/00ol0
003oclgHolo=f003olo=f003o`000?o<cmcoc<oL00Ooc<oL00?o0000olc;fOo<bmT02_o<bmT00ol0
003oal_Mo`00000^ooooo`009_ooool00ol0003oooooooooo`1Qooooo`03o`000?m2S^ko@Xk^00?o
@Xk^00?o0000odVBl?m9T_001Ol00008oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/l?n1
[?001_n1[?000ol0003oTk?]oi>ck@08oi>ck@03o`000?nR^NWoX[WY00CoX[WY0ol00002oj6nkP03
o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01On``nP00ol0003o^lKSok_6h`0;ok_6h`04
o`000?o3b=ko`lSNol?8gP;o00002_o4cN400ol0003ob/gLol[=g00:ol[=g003o`000?o9dN3o0000
013ocLoK00Go0000olo=f?o?cMSoclgHo`00000;olc?g003o`000?o<bmWoc<_I00Ooc<_I0_l00003
olO;g@03o`000?oooooooooo02_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?o0000od:>
k_m2S^h00_m2S^h3o`0000GoBI;`1_l00003oefKl@03o`000?m^Xo7oKZ?a00GoKZ?a00?o0000oh6/
l?n1[?001_n1[?000ol0003oTk?]oi>ck@08oi>ck@03o`000?nR^NWoX[WY00?o00001_nQ_^h00ol0
003o/<?Xok33j003ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<02onka^<00ol0
003o`lSNo`00000=olC=h@03o`000?o:cMcob/gL00Oob/gL0_l00003olWAh003o`000?o=cm_ocLoK
00kocLoK00?o0000olo=f?l000003?o<cm`00ol0003oc<_Iolc;f@06olc;f@03o`000?o7bmgoal_M
00?oal_M0_l0000/ooooo`009_ooool00ol0003oooooooooo`1Sooooo`Co00000_m2S^h00ol0003o
BI;`odVBl004odVBl003o`000?mFV_;oEY[b00;oEY[b2_l00002ofjSl@03o`000?n1[?3oPJc`00Ko
PJc`00?o0000oi>ckOnC/nd00onC/nd7o`0000[oXKk^00?o0000ok33j?n``nP00_n``nP00ol0003o
/<?Xok33j005ok33j003o`000?nka^?o^lKS00_o^lKS0_l0000>olC=h@03o`000?o:cMcob/gL00Ko
b/gL00?o0000olWAh?o9dN001?o9dN000ol0003ocLoKolg?f`0=olg?f`;o00003_o<cm`00ol0003o
c<_Iolc;f@04olc;f@03o`000?o7bmgoal_M00Goal_M00?o0000ooooooooool0:_ooool002Kooooo
0_l0001Sooooo`?o00001Om2S^h00ol0003oBI;`odVBl004odVBl003o`000?mFV_;oEY[b00GoEY[b
00?o0000ofRUm?mXYO@00omXYO@Ao`0000KoT;Sb00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003o/<?X
ok33j002ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<02?nka^<2o`0000;o^lcW
00?o0000olC=hOo4cN403?o4cN400ol0003ob/gLol[=g004ol[=g003o`000?o9dN3obM7P00KobM7P
00?o0000olg?foo=cm/02oo=cm/01?l0003obm;Pol_Bh?l0000>olc?g004o`000?o<bmWoc<_Iolc;
f@;o00002Oo7bmd00ol0003oooooooooo`0Yooooo`009_ooool00ol0003oooooooooo`1Oooooo`?o
00000oooool00ol0003o@Xk^od:>kP03od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mF
V_801OmFV_800ol0003oJ:GdofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@
^?802?n@^?800ol0003oXKk^oj6nkP09oj6nkP03o`000?n``nSo/<?X00;o/<?X00?o0000ok33j?n`
`nP01On``nP00ol0003o^lKSok_6h`05ok_6h`;o00001Onkc>L00ol0003oa<gQolC=h@0<olC=h@04
o`000?o:cMcob/gLol[=g0;o00002_o9dN000ol0003ocLoKolg?f`08olg?f`;o00001?o;d^000ol0
003oc<oLolc?g00<olc?g003o`000?o<bmWo000000coal_M00?o0000ooooooooool0:?ooool002Ko
oooo00?o0000ooooooooool0G?ooool3o`0000Oooooo00?o0000od:>k_m2S^h00om2S^h00ol0003o
BI;`odVBl004odVBl003o`000?mFV_;oEY[b00GoEY[b00?o0000ofRUm?mXYO@01_mXYO@00ol0003o
O:odogb_m006ogb_m003o`000?n@^?;oT;Sb00SoT;Sb00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003o
/<?Xok33j002ok33j003o`000?n``nSo/<?X00Go/<?X00?o0000ok_6honka^<00_nka^<2o`0000So
^lcW00?o0000olC=hOo4cN403?o4cN400ol0003ob/gLo`00000=olWAh003o`000?o=cm_ocLoK00Ko
cLoK00?o0000ol_Bh?o;d^001Oo;d^000ol0003oc<oLolc?g00;olc?g0;o00003Oo7bmd00ol0003o
ooooooooo`0Xooooo`009_ooool00ol0003oooooooooo`1Iooooo`?o00002oooool00ol0003o@Xk^
od:>kP03od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mFV_801OmFV_800ol0003oJ:Gd
ofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@^?802?n@^?800ol0003oXKk^
oj6nkP08oj6nkP03o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01On``nP01?l0003o^lKS
o`000?l0000;ok_<i`03o`000?o4cN7oa<gQ00_oa<gQ0ol0000>olWAh003o`000?o=cm_ocLoK00Co
cLoK00?o0000ol_Bh?o;d^001oo;d^000ol0003oc<oLolc?g009olc?g003o`000?o7d>7o000000ko
al_M00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool0E_ooool3o`0000oooooo
0ol00003od:>kP03o`000?m9T_3oBI;`00CoBI;`00?o0000oeJJl_mFV_801OmFV_800ol0003oJ:Gd
ofRUm006ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2hl_n@^?802?n@^?800ol0003oXKk^
oj6nkP08oj6nkP03o`000?n``nSo/<?X00?o/<?X00?o0000ok33j?n``nP01?n``nP2o`0000ko^lcW
00?o0000olC=hOo4cN402Oo4cN401Ol0003o`m;Uol?BiOo3d^Go000000kobM7P00Co0000olg?foo=
cm_ocLoK0_l0000;ol_Bh003o`000?o<cmcoc<oL00Koc<oL0_l00003olO@h@03o`000?o7bmgoal_M
00coal_M00?o0000ooooooooool09_ooool002Kooooo00?o0000ooooooooool0Doooool3o`0001?o
oooo00?o0000odJ@kol000000_l000000om2S^ko0000odVBl005odVBl003o`000?mFV_;oEY[b00Go
EY[b00?o0000ofRUm?mXYO@01_mXYO@00ol0003oO:odogb_m006ogb_m003o`000?n@^?;oT;Sb00So
T;Sb00?o0000oj6nk_nQ_^h02?nQ_^h00ol0003o/<?Xok33j003ok33j003o`000?n``nSo/<?X00?o
00000_n`bNd00ol0003o^lcWok_<i`0<ok_<i`03o`000?o4cN7oa<gQ00Koa<gQ0_l00005ol?Bi@03
o`000?o9dN3obM7P00cobM7P00?o0000olg?fol000003_o;d^000ol0003oc<oLolc?g004olc?g003
o`000?o7d>7oam3Q00Coam3Q00?o0000olO;gOo7bmd02oo7bmd2o`0002Oooooo000Uooooo`03o`00
0?oooooooooo057ooooo0ol0000Gooooo`04o`000?m6T>ooAY3_odJ@k`?o00001_m9T_000ol0003o
EY[boeJJlP04oeJJlP03o`000?mXYOCoJ:Gd00OoJ:Gd00?o0000ogb_m?ml[o@01_ml[o@00ol0003o
T;Sboi2hlP08oi2hlP03o`000?nQ_^koXKk^00SoXKk^00?o0000ok33j?n``nP00_n``nP3o`0000Ko
/<W]00?o0000ok_<ionkc>L03?nkc>L00ol0003oa<gQolC=h@04olC=h@03o`000?o3d^Go`m;U00Ko
`m;U00?o0000olWAh?o9dN002oo9dN03o`0000oobm;P00Co0000olc?g?o<cmcoc<oL0_l00008olO@
h@03o`000?o7bmgoal_M00_oal_M00?o0000ooooooooool09Oooool002Gooooo0ol0001>ooooo`?o
00006_ooool2o`0000GoAY3_0ol00004odVBl003o`000?mFV_;oEY[b00CoEY[b00?o0000ofRUm?mX
YO@01omXYO@00ol0003oO:odogb_m006ogb_m003o`000?n@^?;oT;Sb00SoT;Sb00?o0000oj6nk_nQ
_^h02?nQ_^h00ol0003o/<?Xo`000003o`0000So/<W]00?o0000ok_<ionkc>L03?nkc>L01?l0003o
a<gQolC=hOo4cN42o`0000[o`m;U00?o0000olWAh?o9dN002Oo9dN001Ol0003oamGUolOEiOo7eNGo
000000oobm;P00?o0000olc?g?l000002oo7d>400ol0003oal_MolO;g@0:olO;g@;o00009_ooool0
02Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00005odJ@k`03o`000?m:UO7o0000
00Go00001_mFV_800ol0003oJ:GdofRUm007ofRUm003o`000?ml[oCoO:od00KoO:od00?o0000oi2h
l_n@^?802?n@^?800ol0003oXKk^oj6nkP06oj6nkPCo00000on`bNd00ol0003o/<W]ok39k@06ok39
k@03o`000?nkc>Oo^lcW00co^lcW00?o0000olC=hOl000003Oo3d^D00ol0003obM7PolWAh006olWA
h0;o00001Oo7eND00ol0003obm;Pol_Bh00<ol_Bh0;o00003Oo7d>400ol0003oal_MolO;g@07olO;
g@;o000000?o`<WRo`000?l000009Oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0B?ooool3
o`0002;ooooo0_l00005odJ@k`03o`000?m:UO7oBYGa00?oBYGa1?l00004oeJJlP03o`000?mXYOCo
J:Gd00OoJ:Gd00?o0000ogb_m?ml[o@01_ml[o@00ol0003oT;Sboi2hlP08oi2hlP03o`000?nQ_^ko
XKk^00Go00001?nPaO801Ol0003o/<W]ok39kOn`bNgo000000So/<W]00?o0000ok_<ionkc>L02onk
c>L3o`0000ko`m;U00?o0000olWAh?o9dN001?o9dN000ol0003oamGUolOEi@06olOEi@03o`000?o;
d^3obm;P00Wobm;P0_l000000oo6e>Go0000olO@h@0=olO@h@03o`000?o7bmgoal_M00Coal_M0_l0
0004ol39hP;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Kooooo
0_l00005odJ@k`03o`000?m:UO7oBYGa00GoBYGa1ol00009ofRUm003o`000?ml[oCoO:od00KoO:od
00?o0000oi2hl_n@^?800on@^?87o`0000[oX<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03
o`000?nkc>Oo^lcW00So^lcW0_l00003ok_Bk003o`000?o3d^Go`m;U00co`m;U00Co0000olWAh?o9
dN3obM7P0_l0000:olOEi@03o`000?o;d^3obm;P00Oobm;P00?o0000olKDiOo6e>D00_o6e>D00ol0
003oam3QolO@h@0<olO@h@03o`000?o7bmgoal_M00;oal_M00?o0000ol39h_o0bN801Oo0bN800ol0
003oooooooooo`0Rooooo`002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo04;ooooo0ol0000Zooooo`;o00001Om6T>l0
0ol0003oBYGaodZEl@05odZEl@03o`000?mEWO?oEIgc00;oEIgc6Ol00006ohjmmP03o`000?nPaO;o
X<Gb00WoX<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03o`000?nkc>Oo^lcW00Go^lcW0_l0
0006ok_Bk003o`000?o3d^Go`m;U00co`m;U00?o0000olWAh?l000003Oo7eND00ol0003obm;Pol_B
h004ol_Bh0;o00001_o6e>D00ol0003oam3QolO@h@0<olO@h@04o`000?o7bmgo0000o`0000Wo`<WR
00?o0000ooooooooool08Oooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b
<_nHV9SooooooiRHV?lb<S801oooool00ol0003oooooooooo`0oooooo`?o0000;_ooool2o`0000Go
AY3_00?o0000odZElOm:UO401Om:UO400ol0003oEIgcoeFMl`04oeFMl`03o`000?mVZ?KoIZSf00Ko
IZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjmmP08ohjmmP03o`000?nPaO;oX<Gb00Wo
X<Gb00Go0000ok39kOn`bNgo/<W]o`000008ok39k@03o`000?nkc>Oo^lcW00;o^lcW0_l00009ok_B
k003o`000?o3d^Go`m;U00_o`m;U0ol0000>olOEi@04o`000?o;d^3obm;Pol_Bh0;o00002Oo6e>D0
0ol0003oam3QolO@h@0;olO@h@;o00002oo0bN82o`0002;ooooo0009ooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0??oo
ool3o`0003;ooooo0_l00005odJ@k`03o`000?m:UO7oBYGa00GoBYGa00?o0000oeFMlomEWO<01?mE
WO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>
_OH00ol0003oX<Gboj35lP09oj35lP05o`000?n`bNgo/<W]ok39kOl000002?n`bNd01?l0003o^lcW
o`000?l0000<ok_Bk003o`000?o3d^Go`m;U00So`m;U0_l00003ol7GjP03o`000?o7eNGoamGU00co
amGU00?o0000ol_Bh?l000003?o6e>D00ol0003oam3QolO@h@08olO@h@;o000000?o`=3Vo`000?o0
bN802oo0bN82o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00005odJ@
k`03o`000?m:UO7oBYGa00GoBYGa00?o0000oeFMlomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJX
mP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>_OH00ol0003oX<Gboj35lP09oj35
lP04o`000?n`bNgo/<W]o`0000Oo/<W]1?l0000>ok_Bk003o`000?o3d^Go`m;U00Go`m;U0_l00006
ol7GjP03o`000?o7eNGoamGU00_oamGU0ol0000=olKDi@03o`000?o7d>7oam3Q00Goam3Q0_l00004
ol3@iP03o`000?o0bN;o`<WR00[o`<WR00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`0gooooo`?o0000>_ooool4o`0000?oAY3_00?o0000odZElOm:UO401Om:UO400ol0003oEIgcoeFM
l`04oeFMl`03o`000?mVZ?KoIZSf00KoIZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjm
mP08ohjmmP03o`000?nPaO;oX<Gb00WoX<Gb00Co0000ok39kOn`bNgo00000on`bNd3o`0000Co[m3a
00?o0000ok_Bk?nkd^`03?nkd^`00ol0003o`m;Uol?Bi@02ol?Bi@;o00002Oo1enX00ol0003oamGU
olOEi@09olOEi@05o`000?o2f>[o`]SZol;Hj_l000003Oo6e>D00ol0003oam3QolO@h@02olO@h@;o
00001oo0d>H00ol0003o`<WRol39hP09ol39hP;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0doooo
o`?o0000?_ooool00ol0003oDIK`oe6Fl003o`000003odJ@kol0003oBYGa00KoBYGa00?o0000oeFM
lomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjm
m_n>_OH02?n>_OH00ol0003oX<Gboj35lP09oj35lP03o`000?n`bNgo/<W]00?o00002?n_d?400ol0
003o^m;/ok_Bk00<ok_Bk004o`000?o3d^Go0000o`0000co`MOZ00?o0000olOEiOo7eND01_o7eND2
o`0000Go`]SZ00?o0000olKDiOo6e>D02oo6e>D01?l0003oam3Qo`000?l0000:ol3@iP03o`000?o0
bN;o`<WR00Wo`<WR0_l0000Oooooo`009?ooool00ol0003oooooooooo`0aooooo`?o0000@_ooool0
0ol0003oDIK`oe6Fl002oe6Fl0?o00001om:UO400ol0003oEIgcoeFMl`04oeFMl`03o`000?mVZ?Ko
IZSf00KoIZSf00?o0000ogZcmomj/oL01_mj/oL00ol0003oS[gfohjmmP08ohjmmP03o`000?nPaO;o
X<Gb00SoX<Gb0ol000000on_d?7o0000ojo@l@09ojo@l@03o`000?nkd^co^m;/00_o^m;/0ol0000>
ol7GjP03o`000?o7eNGoamGU00CoamGU00?o0000ol;Hj_o2f>X01_o2f>X00ol0003oa]CUolKDi@0:
olKDi@;o00003Oo0d>H00ol0003o`<WRol39hP09ol39hP;o00007_ooool002Cooooo00?o0000oooo
ooooool0;oooool2o`0004Kooooo00?o0000oe6Fl?mAU_001?mAU_06o`0000;oBYGa00?o0000oeFM
lomEWO<01?mEWO<00ol0003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjm
m_n>_OH02?n>_OH00ol0003oX<Gboj35lP04oj35lP?o00000onOboH00ol0003o[m3ao`00000:ojo@
l@;o00002Onkd^`2o`0000?o^=O`00?o0000ol7Gj_o1enX03?o1enX01?l0003oamGUolOEiOo7eND2
o`0000[o`]SZ00?o0000olKDiOo6e>D01oo6e>D2o`0000;o_]G[00?o0000ol3@i_o0d>H02_o0d>H0
0ol0003o`<WRol39hP09ol39hP;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`00
04Wooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`02oe>Kl`Ko00001?mEWO<00ol0
003oIZSfofJXmP06ofJXmP03o`000?mj/oOoN[?g00KoN[?g00?o0000ohjmm_n>_OH02?n>_OH00ol0
003oX<Gboj35lP03o`0000OoWl_f00?o0000ojo@lOl000002on_d?400ol0003o^m;/ok_Bk004ok_B
k0;o00001_nheo000ol0003o`MOZol7GjP0<ol7GjP03o`000?o7eNGo000000go`]SZ00?o0000olKD
iOo6e>D01?o6e>D2o`0000Go_]G[00?o0000ol3@i_o0d>H02_o0d>H00ol0003o`<WRol39hP06ol39
hP;o000000?o]/OWo`000?l000007Oooool002Cooooo00?o0000ooooooooool0:Oooool3o`0004go
oooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`05oe>Kl`03o`000?mJXoKo000000Go
00002?mVZ?H00ol0003oN[?gogZcm`06ogZcm`03o`000?n>_OKoS[gf00?oS[gf1ol0000;oio;mP03
o`000?n_d?7o000000_o[m3a00?o0000ok_Bk?nkd^`00_nkd^`00ol0003o^=O`okSGl007okSGl003
o`000?o1en[o`MOZ00_o`MOZ0ol0000>ol;HjP03o`000?o6e>Goa]CU00;oa]CU00?o0000okkEjonn
eN/01_nneN/00ol0003o`=3Vol3@iP0:ol3@iP03o`000?o0bN;o`<WR00;o`<WR0ol00004okK7i`;o
00007?ooool002Cooooo00?o0000ooooooooool09_ooool3o`00057ooooo00?o0000oe6Fl?mAU_00
1?mAU_000ol0003oDi_coe>Kl`05oe>Kl`03o`000?mJXoKoFZ?f00?oFZ?f6?l00007ohg3n@03o`00
0?nOboKoWl_f00WoWl_f0ol0000;ojo@l@04o`000?nkd^co0000o`0000_o^=O`00?o0000ol7Gj_o1
enX02?o1enX2o`0000?o_M__00?o0000ol;Hj_o2f>X03?o2f>X01?l0003oa]CUo`000?l0000:okkE
j`03o`000?o0d>Ko`=3V00[o`=3V00Co0000ol39h_l0003o00002?nfanL2o`0001_ooooo000Soooo
o`;o00009Oooool3o`0005Gooooo00?o0000oe6Fl?mAU_001?mAU_000ol0003oDi_coe>Kl`05oe>K
l`03o`000?mJXoKoFZ?f00GoFZ?f00?o0000ofR]n?mX[OP01_mX[OP00ol0003oN[WjogZinP06ogZi
nP03o`000?n=`oWoSL?i00SoSL?i00?o0000oio;m_nOboH02_nOboH00ol0003o[m3aojo@l@08ojo@
l@Co00003Onheo000ol0003o`MOZol7GjP05ol7GjP;o00001_nmfnl00ol0003o`]SZol;HjP0;ol;H
jP;o00003OnneN/00ol0003o`=3Vol3@iP09ol3@iP;o00002onfanL00ol0003oooooooooo`0Ioooo
o`009?ooool00ol0003oooooooooo`0Pooooo`?o0000FOooool00ol0003oDIK`oe6Fl004oe6Fl003
o`000?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003
o`000?mj^O[oN[Wj00KoN[Wj00?o0000ohg3nOn=`oT02?n=`oT00ol0003oWl_foio;mP0:oio;mP03
o`000?n_d?7o[m3a00Co[m3a0ol00004ojgEm@03o`000?nheo3o^=O`00_o^=O`00?o0000ol7Gj_o1
enX00_o1enX2o`0000Wo_M__0_l00009ol;HjP;o00000_nkf^l00ol0003o_]G[okkEj`0;okkEj`03
o`000?o0d>Ko`=3V00Ko`=3V0_l000000onfc^co0000okK7i`0;okK7i`03o`000?oooooooooo01So
oooo000Sooooo`03o`000?oooooooooo01kooooo0ol0001Mooooo`03o`000?mAU_3oDIK`00CoDIK`
00?o0000oe>KlomCVo<01OmCVo<00ol0003oFZ?foeZSmP05oeZSmP03o`000?mX[OSoJ:gh00KoJ:gh
00?o0000ogZin_mj^OX01_mj^OX00ol0003oSL?iohg3n@08ohg3n@;o00002onOboH00ol0003o[m3a
ojo@l@03o`0000So[MGe00?o0000okSGl?nheo002onheo001?l0003o`MOZo`000?l0000=okgKk`03
o`000?o2f>[o`]SZ00Co`]SZ0_l00005ok_Jk`03o`000?nneN_o_]G[00_o_]G[00?o0000ol3@i_o0
d>H00_o0d>H3o`0000Co]/k/00?o0000okK7ionfanL02_nfanL00ol0003oooooooooo`0Gooooo`00
8oooool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oDIK`oe6Fl004oe6Fl003o`00
0?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003o`00
0?mj^O[oN[Wj00KoN[Wj0_l0000:ohg3n@03o`000?nOboKoWl_f00SoWl_f0ol0000<ojgEm@;o0000
2onheo03o`0000oo_M__00?o0000ol;Hj_o2f>X00_o2f>X00ol0003o^m[_ok_Jk`06ok_Jk`03o`00
0?nneN_o_]G[00_o_]G[00Co0000ol3@i_l0003o00002?nfc^`00ol0003o]/OWokK7i`09okK7i`;o
00006?ooool002?ooooo00?o0000ooooooooool06?ooool3o`0006Gooooo0ol00004oe6Fl003o`00
0?mCVo?oDi_c00GoDi_c00?o0000oeZSm_mJXoH01OmJXoH00ol0003oJ:ghofR]n006ofR]n003o`00
0?mj^O[oN[Wj00OoN[Wj00?o0000ohg3nOn=`oT02?n=`oT00ol0003oWl_foio;mP04oio;mP?o0000
0_nNd?T2o`0000go[MGe00?o0000okSGl?nheo001_nheo02o`0000?o]=_d00?o0000okgKkonmfnl0
3Onmfnl01?l0003o`]SZo`000?l0000:ok_Jk`03o`000?nneN_o_]G[00[o_]G[0_l0000;okK>k003
o`000?nfanOo]/OW00Wo]/OW00?o0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0
5Oooool3o`0006Sooooo00?o0000of:Ol_mRWo801_l00007oe>Kl`03o`000?mJXoKoFZ?f00GoFZ?f
00?o0000ofR]n?mX[OP01_mX[OP00ol0003oN[WjogZinP07ogZinP03o`000?n=`oWoSL?i00SoSL?i
00?o0000oio;m_nOboH00ol00006oik@n@?o00003?n]eOD00ol0003o^=O`okSGl002okSGl0?o0000
1_ndfo@2o`0000go_M__0ol0000<ok_Jk`03o`000?nneN_o_]G[00Ko_]G[0ol00002okCDl003o`00
0?nfc^co]/k/00Wo]/k/00?o0000okK7ionfanL02OnfanL00ol0003oooooooooo`0Eooooo`008ooo
ool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oHYobof:OlP04of:OlPOo00000_mC
Vo<00ol0003oFZ?foeZSmP05oeZSmP03o`000?mX[OSoJ:gh00KoJ:gh00?o0000ogZin_mj^OX01omj
^OX00ol0003oSL?iohg3n@03ohg3n@Oo00002_nNd?T00ol0003oW]3io`00000<ojgEm@04o`000?nh
eo3o0000o`0000_o]=_d00?o0000okgKkonmfnl01onmfnl3o`0000?o]]gd00?o0000ok_Jkonkf^l0
2_nkf^l00ol0003o_]G[okkEj`03okkEj`;o00001_nde?000ol0003o]/k/okK>k009okK>k003o`00
0?nfanOo]/OW00Wo]/OW00?o0000ooooooooool05?ooool002;ooooo0ol0000@ooooo`?o0000L?oo
ool00ol0003oHYobof:OlP06of:OlP04o`000?mQY?GoHJCeof6Tm@Wo00000_mJXoH00ol0003oJ:gh
ofR]n006ofR]n003o`000?mj^O[oN[Wj00?oN[Wj2Ol00007ohk9o003o`000?nNd?WoW]3i00SoW]3i
00?o0000oik@nOl000002on]eOD3o`0000go]=_d0_l00005okgKk`;o00001onfgO@00ol0003o^m[_
ok_Jk`0:ok_Jk`03o`000?nneN_o000000;o00002Onde?000ol0003o]/k/okK>k009okK>k003o`00
0?nfanOo]/OW00Oo]/OW0ol0000Eooooo`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?oo
ool00ol0003oHYobof:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe00Co0000ofJ[n?mVZoSoIZ_h
4Ol00006ogfoo003o`000?n>bOcoS/Wl00SoS/Wl00?o0000oik@nOnNd?T01onNd?T00ol0003oW]3i
oik@n@02o`0000Ko[MGe0ol00003ojWJn003o`000?ndfoCo]=_d00co]=_d00?o0000okgKkol00000
0_l0000:okKMm003o`000?nkf^oo^m[_00Wo^m[_0ol0000<okCDl003o`000?nfc^co]/k/00Wo]/k/
00Co0000okK7ionfanOo]/OW1Ol00002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`00
0?oooooooooo00Wooooo0ol0001hooooo`03o`000?mRWo;oHYob00KoHYob00?o0000of6TmOmQY?D0
1OmQY?D00ol0003oIZ_hofJ[n005ofJ[n003o`000?m`]O[oL;Gj00KoL;Gj00?o0000ogfoo?mm_o`0
1omm_o`00ol0003oS/Wlohk9o008ohk9o0;o00002?nNd?T01Ol0003oW]3ioik@nOnNd?Wo000000;o
[MGe0ol00007ojWJn0;o00003?ndfo@3o`0000go]]gd00?o0000ok_Jkonkf^l01_nkf^l2o`0000?o
/MWd00?o0000okCDl?nde?002_nde?000ol0003o]/k/okK>k008okK>k0Ko00001Oooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06ooooo`?o0000O?ooool00ol0003oHYob
of:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe00?o0000ofJ[n?mVZoP01OmVZoP00ol0003oL;Gj
og2enP06og2enP03o`000?mm_ocoOKol00OoOKol00?o0000ohk9o?n>bO`02On>bO`00ol0003oW]3i
oik@n@06oik@n@03o`000?nNd?Wo000000?o00003?nYf_P00ol0003o]=_dokCKm007okCKm0;o0000
0on_gOL00ol0003o]]gdokKMm00;okKMm003o`000?nkf^oo^m[_00;o^m[_0ol00006ok7Im003o`00
0?nde?3o]=C`00[o]=C`00?o0000okK>k?nfc^`01?nfc^`6o`0000Sooooo00?o0000ooooooooool0
4oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo00?o0000of:Ol_mRWo801_mR
Wo800ol0003oHJCeof6Tm@05of6Tm@03o`000?mVZoSoIZ_h00GoIZ_h00?o0000og2en_m`]OX01_m`
]OX00ol0003oOKologfoo007ogfoo0;o00002_n>bO`00ol0003oW]3ioik@n@04oik@n@?o00001?nM
eO/00ol0003oZM[hojWJn00:ojWJn0;o00001?ndfo@3o`0000Ko[mgg0_l0000<okKMm004o`000?nk
f^oo0000o`0000[o/MWd0_l0000;okCDl003o`000?nfc^co]/k/00Go00003?ooool00ol0003ooooo
ooooo`0Cooooo`008_ooool01?l0003oooooooooooooool3o`0008Cooooo00?o0000of:Ol_mRWo80
1_mRWo800ol0003oHJCeof6Tm@05of6Tm@03o`000?mVZoSoIZ_h00GoIZ_h0_l00007og2enP;o0000
2Omm_o`00ol0003oS/Wlohk9o008ohk9o003o`000?nNd?WoW]3i00?o00000onMeO/00ol0003oWMGk
oigEn`02oigEn`;o00003?nYf_P01?l0003o]=_do`000?l0000;ojoMm`03o`000?nfgOCo]]gd00Wo
]]gd0ol0000=ok7Im003o`000?nde?3o]=C`00So]=C`1Ol0000?ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`Co0000R?ooool00ol0003oHYobof:OlP06of:OlP03o`000?mQY?GoHJCe00GoHJCe
00?o0000ofJ[n?mVZoP01_mVZoP00ol0003oL;Gjog2enP06og2enP03o`000?mm_ocoOKol00OoOKol
00?o0000ohk9o?n>bO`01_n>bO`4o`0000OoWMGk00?o0000oigEnonMeO/00onMeO/00ol0003oZM[h
ojWJn009ojWJn0?o00003On_gOL2o`0000Ko]]gd0ol00003ojgLn003o`000?nafOCo/MWd00_o/MWd
00?o0000okCDl?nde?001?nde?05o`0001;ooooo00?o0000ooooooooool04oooool002;ooooo0ol0
002:ooooo`03o`000?mRWo;oHYob00KoHYob00?o0000of6TmOmQY?D01OmQY?D00ol0003oIZ_hofJ[
n006ofJ[n003o`000?m`]O[oL;Gj00KoL;Gj00?o0000ogfoo?mm_o`01omm_o`00ol0003oS/Wlohk9
o005o`0000CoT<om0_l00006oigEn`03o`000?nMeO_oWMGk00?oWMGk0_l00006ojWJn0?o00000onV
g?X00ol0003o[mggojoMm`0<ojoMm`03o`000?nfgOCo]]gd00?o00001on]g?P00ol0003o/MWdok7I
m00;ok7Im003o`000?nde?3o]=C`00Co00005oooool00ol0003oooooooooo`0Booooo`009?ooool0
0ol0003oooooooooo`29ooooo`oo00000_mQY?D00ol0003oIZ_hofJ[n006ofJ[n003o`000?m`]O[o
L;Gj00KoL;Gj00?o0000ogfoo?mm_o`00omm_o`6o`0000_oT<om00?o0000oigEnonMeO/00onMeO/0
0ol0003oWMGkoigEn`05oigEn`03o`000?nYf_SoZM[h00?o00001onVg?X2o`0000co[mgg0ol0000;
ojgLn0;o00002_nafO@5o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^o`00
0?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000ogJX
l_mfZ?801_mfZ?800ol0003oM:kfogB^mP02ogB^mQ[o00001_n4a_d00ol0003oT<omoi3?o@09oi3?
o@;o00001?nMeO/00ol0003oWMGkoigEn`04oigEn`?o00003?nVg?X00ol0003o[mggojoMm`07ojoM
m`;o00000onXg_X00ol0003o[MchojgLn00:ojgLn003o`000?nafOCo/MWd00Co/MWd1Ol0000Moooo
o`03o`000?oooooooooo01;ooooo000Fooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool00ol0
003oooooooooo`29ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^m_md[_H01_md[_H00ol0
003oM[GiogJen@06ogJen@03o`000?mk_OcoNkgl00KoNkgl00?o0000ohC6oOn4a_d01on4a_d2o`00
00_oT<om0_l00003oigEn`03o`000?nMeO_oWMGk00?o00000onMfO`2o`0000_oY]cj0_l00004ojoM
m`?o00001_nXg_X00ol0003o[MchojgLn00:ojgLn003o`000?nafOCo/MWd00Co00008Oooool00ol0
003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00cooooo00?o0000oooo
ooooool0ROooool00ol0003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf00KoM:kf00?o0000ogJe
nOmf]OT01_mf]OT00ol0003oNkglog^mo006og^mo0;o00002On4a_d00ol0003oT<omoi3?o@0:oi3?
o@03o`000?nMeO_oWMGk00?o00002?nMfO`2o`0000_oY]cj00Co0000ojoMmol0003o00002_nXg_X2
o`0000[o[Mch1?l0000Tooooo`03o`000?oooooooooo01;ooooo000Fooooo`03o`000?oooooooooo
00;o00003Oooool00ol0003oooooooooo`29ooooo`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^
m_md[_H01_md[_H00ol0003oM[GiogJen@06ogJen@03o`000?mk_OcoNkgl00OoNkgl00?o0000ohC6
oOn4a_d01on4a_d2o`0000WoT<om1?l00002oigIo003o`000?nMfOcoWMWl00SoWMWl00?o0000ojKL
n_nVg?X01onVg?X4o`0000goZ=kj00?o0000ojgLn?n]g?P01?n]g?P4o`0002Oooooo00?o0000oooo
ooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo08Wo
oooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oM:kfogB^mP06ogB^mP;o00001omf]OT00ol0003o
Nkglog^mo007og^mo0;o00002On4a_d01?l0003oT<omoi3?oOn@cod5o`0000CoUM?m0_l000000onM
fOco0000oigIo009oigIo0;o00000_nVg?X5o`0000CoXmgl0_l0000<ojSNnP03o`000?n]g?So[Mch
00Co0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@
00oooooo00?o0000ooooooooool0ROooool00ol0003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf
00OoM:kf00?o0000ogJenOmf]OT01Omf]OT00ol0003oNkglog^mo008og^mo003o`000?n4a_goQ<Km
00?oQ<Km1ol0000;oiGCo@?o00002_nMfO`3o`0000_oXmgl0_l00009ojSNnPCo0000;_ooool00ol0
003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003oMgMg013ooooo0_l0002:oooo
o`03o`000?mfZ?;oMZSb00KoMZSb00?o0000ogB^m_md[_H01omd[_H00ol0003oM[GiogJen@05ogJe
n@03o`000?mk_OcoNkgl00KoNkgl1ol00006ohk=o@;o00003?nEdod2o`0000KoWMWl0ol00003oikK
o003o`000?nSgOcoXmgl00[oXmgl0_l00002ojSNnPKo0000<Oooool00ol0003oooooooooo`0Boooo
o`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0R?ooool00ol0
003oMZSbogJXlP06ogJXlP03o`000?md[_KoM:kf00OoM:kf00?o0000ogJenOmf]OT01Omf]OT00ol0
003oNkglog^mo005o`0000CoR/Gk00?o0000ohk=oOn>cOd02?n>cOd2o`0000_oUM?m0_l00002oigI
o0?o00001onNfo`2o`0000_oXmgl1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03
o`000?oooooo000008[ooooo00?o0000ogJXl_mfZ?801_mfZ?800ol0003oM:kfogB^mP03ogB^mPko
00002_n:aO/2o`0000[oS/gm0_l00009oiGCo@Co00003?nNfo`2o`0000KoXmgl1Ol0000hooooo`03
o`000?oooooooooo01;ooooo000_ooooo`03o`000?oooooooooo08Sooooo3_l00006ohRgm@03o`00
0?n8__WoR;ki00GoR;ki0_l0000:oh[5n`03o`000?n>cOgoS/gm00WoS/gm0_l00002oiGCo@Go0000
0_nKeo`00ol0003oVmOlo`00000=oikKo003o`000?nSgOcoXmgl00Go0000??ooool00ol0003ooooo
ooooo`0Aooooo`00<?ooool00ol0003oooooooooo`27ooooo`;o00002?n9/O000ol0003oR;OeohRg
m@08ohRgm@03o`000?n8__WoR;ki00KoR;ki00?o0000oh[5non:aO/02?n:aO/00ol0003oS/gmohk=
o@09ohk=o@?o00002?nKeo`01?l0003oVmOlo`000?l0000;oikKo0Go0000?oooool00ol0003ooooo
ooooo`0Aooooo`00<Oooool00ol0003oooooooooo`27ooooo`;o00002?n9/O000ol0003oR;OeohRg
m@08ohRgm@03o`000?n8__WoR;ki00KoR;ki0_l00009oh[5n`;o00001_n>cOd3o`0000?oVM;l00?o
0000oi_Go?nKeo`01_nKeo`00ol0003oVmOloi_Go002o`0000KoW]_l1?l00013ooooo`03o`000?oo
oooooooo017ooooo000booooo`03o`000?oooooooooo08Oooooo0_l00008ohVal003o`000?n8]oGo
R;Oe00SoR;Oe00?o0000ohRnnOn8__T01on8__T2o`0000WoR/Gk00?o0000ohk=oOn>cOd00ol00007
oiWBo003o`000?nKeocoVmOl00KoVmOl00Go0000oi_Go?nKeocoVmOlo`000002oikKo0Co0000A_oo
ool00ol0003oooooooooo`0Aooooo`00<oooool00ol0003oooooooooo`27ooooo`;o00002?n9/O00
0ol0003oR;OeohRgm@08ohRgm@03o`000?n8__WoR;ki00SoR;ki00?o0000oh[5non:aO/00on:aO/6
o`0000_oVM;l0_l00007oi_Go003o`000?nKeocoVmOl00Co0000BOooool00ol0003oooooooooo`0A
ooooo`00=?ooool2o`0008Sooooo0_l00008ohVal003o`000?n8]oGoR;Oe00SoR;Oe00?o0000ohRn
nOn8__T01_n8__T7o`0000KoVLci00?o0000oiWBo?nId_`02_nId_`00ol0003oVmOloi_Go004oi_G
o0?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o
00002?n9/O000ol0003oR;OeohRgm@08ohRgm@03o`000?n8__WoR;ki00Go00001?nIaOH00ol0003o
VLcioiW<n@07oiW<n@;o00002onId_`00ol0003oVmOloi_Go003o`000003ooooool0003ooooo04go
oooo00?o0000ooooooooool04Oooool003Oooooo0_l00027ooooo`;o00002?n9/O000ol0003oR;Oe
ohRgm@06ohRgm@Co00002_nIaOH00ol0003oVLcioiW<n@08oiW<n@;o00002?nId_`4o`0000Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003oooooo`00
0028ooooo`;o00002?n9/O000ol0003oR;OeohRgm@05o`0000CoV[ka00?o0000oiW5m_nIaOH02?nI
aOH2o`0000[oVLci00?o0000oiWBo?nId_`01Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000CoRK7`1_l0000:
oiZnl@03o`000?nIaOKoVLGf00WoVLGf00?o0000oiW<nOnIc?T01onIc?T5o`0000kooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Aooooo`00>_ooool00ol0003oooooooooo`26oooo
o`Go00001_nK^>`00ol0003oV[kaoiZnl@08oiZnl@03o`000?nIaOKoVLGf00WoVLGf00?o0000oiW<
nOnIc?T00onIc?T5o`0001;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Aoooo
o`00>oooool00ol0003oooooooooo`26ooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oiZnlOnJ
__402?nJ__400ol0003oVLGfoiW5mP09oiW5mP03o`000?nIc?Wo000000?o00005oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo013ooooo000looooo`03o`000?oooooooooo08Kooooo
00?o0000oi^hk?nK^>`02?nK^>`00ol0003oV[kaoiZnl@08oiZnl@03o`000?nIaOKoVLGf00SoVLGf
0ol0000Kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04?ooool003gooooo0_l0
0027ooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oiZnlOnJ__402?nJ__400ol0003oVLGfoiW5
mP04oiW5mP?o00007oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo013ooooo000o
ooooo`03o`000?oooooooooo08Gooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oV[kaoiZnl@08
oiZnl@03o`000?nIaOKoVLGf00?o00008_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo013ooooo0010ooooo`03o`000?oooooooooo08Gooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0
003oV[kaoiZnl@06oiZnl@Co00009_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
013ooooo0011ooooo`;o0000Q_ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nJ__7oV[ka00Go
0000:oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo0010ooooo`03o`00
0?oooooo000008Oooooo00?o0000oi^hk?nK^>`01onK^>`5o`0002oooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`25ooooo`03o`000?nK
^>coVkS/00?oVkS/1?l0000dooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool04?oo
ool004Cooooo00?o0000ooooooooool0QOooool00ol0003oVkS/o`000003o`0003Sooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0@ooooo`00AOooool00ol0003oooooooooo`25oooo
o`;o0000??ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo0016ooooo`;o
0000QOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool04?ooool004Sooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool03oooool004Wooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03ooo
ool004[ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03oooool004[ooooo0_l00021ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`00C?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0?ooooo`00COooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`00C_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0?ooooo`00Coooool2o`0007cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00oooooo001Aooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo001Booooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00oooooo001Cooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00oooooo001Dooooo`?o0000M_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03ooo
ool005Cooooo0_l0001gooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Sooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Sooooo0_l0001cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool02oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00kooooo
000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`00013ooooo0_l0001^ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0>ooooo`00Goooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`00H?ooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`00HOooool2o`0006[ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00gooooo001Sooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00go
oooo001Tooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00gooooo001Uooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo001V
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00gooooo001Vooooo`?o0000I?ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool006Sooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool03Oooool006Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006[ooooo0_l0001Qooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`00K?ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0=ooooo`00KOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`00K_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0<ooooo`00Koooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`00Koooool3o`0005_ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo001a
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00cooooo001booooo`03o`000?oooooooooo05Sooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo001cooooo`;o
0000F?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03?ooool007Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool03?ooool007Kooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?oo
ool007Oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?o
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00co
oooo001jooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00cooooo001kooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo001l
ooooo`;o0000Coooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02oooool007kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool007oooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02oooool0083ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02oooool0087ooooo0ol00019ooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`00M_ooool4
o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool007Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00[ooooo0_l00016ooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`00G?oo
ool3o`000003oa0@4?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`00G_ooool00ol@413o^[Zjooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02_ooool005kooooo00?oV9RHoc8b<_ooool05oooool00ol0003oooooooooo`0>oooo
o`;o0000@_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool005kooooo00?ogMgMo`000?nj^[X05Oooool00omEEEGoIVIVo`00000@ooooo`;o
0000@_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool02_ooool005kooooo00?oEEEEogMgMom4A4@0:_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00GOoo
ool01OoMgMgo410@oooooolQ8B7ogMgM02[ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005gooooo00Go
IVIVohN7QoooooooV9RHoeEEE@0[ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Looooo`03onk^k_l0
003ok^k^00;ooooo00?o0000omgMgOooool0:_ooool2o`0003gooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo001Looooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool0:oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`00TOooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`00TOooool2o`0003[ooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo002Cooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo002Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo002Eooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo002F
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo002Gooooo`;o0000=?ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool009Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02Oooool009Wooooo0ol0000aooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`00Voooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`00W?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`00WOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00W_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`00Woooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00X?ooool2o`0002_ooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo002Q
ooooo`;o0000:_ooool00ol0003oooooooooo`22ooooo`05o`000?ooooooooooooooool000002_oo
ool00:?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`23ooooo`04o`000?oooooo
ooooo`0000[ooooo002Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooo`00000:ooooo`00YOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
08Gooooo0_l0000:ooooo`00Y_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Co
oooo0ol0000:ooooo`00Yoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo083ooooo
1?l0000=ooooo`00Z?ooool01?l0003oooooo`000?l0000Qooooo`03o`000?oooooooooo07cooooo
1?l0000Aooooo`00S_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01_ooool2o`0002;ooooo00?o0000ooooooooool0N?ooool4o`0001Gooooo
002@ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1dooooo`Co00006Oooool0093ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0L?ooool4o`0001gooooo002@ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06gooooo0ol0000Qoooo
o`00T?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo06Wooooo1?l0000Tooooo`00T?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Uooooo`Co0000:?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0?ooooo`?o00006_ooool00ol0003oooooooooo`1Qooooo`Co0000;?ooool008kooooo00?o
EEEEofIVI_l000003Oooool4o`0000kooooo0_l0000Kooooo`03o`000?oooooooooo05gooooo1?l0
000`ooooo`00/_ooool2o`0001Wooooo00?o0000ooooooooool0FOooool4o`0003Cooooo002doooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0EOooool4o`0003Sooooo002eooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool4o`0003cooooo002fooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0COooool4o`00043ooooo002gooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0BOooool4o`0004Cooooo002hooooo`;o00004oooool0
0ol0003oooooooooo`15ooooo`Co0000B?ooool00;Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`11ooooo`Co0000C?ooool00;[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0nooooo`?o0000D?ooool00;_ooooo0_l0000@ooooo`03o`000?oooooooooo03[ooooo
1?l0001Cooooo`00_Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo1?l0
001Gooooo`00__ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo1?l0001K
ooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0;_ooool4o`0005oooooo002oooooo`;o
00003?ooool00ol0003oooooooooo`0Zooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Vooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Rooooo`Co0000Joooool00<?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Nooooo`Co0000Koooool00<Cooooo0_l00007ooooo`03o`000?oooooooooo
01[ooooo1?l0001cooooo`00a_ooool3o`0000Cooooo00?o0000ooooooooool05_ooool4o`0007Oo
oooo0036ooooo`;o00001Oooool00ol0003oooooooooo`0Cooooo`?o0000Noooool00<Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`Co0000O_ooool00<Wooooo00Go0000
ooooooooooooooooo`00000=ooooo`Co0000P_ooool00<[ooooo00Co0000oooooooooooo00002Ooo
ool4o`0008Kooooo003;ooooo`03o`000?oooooo000000Gooooo1?l0002:ooooo`00c?ooool7o`00
08kooooo0032ooooo`Go00001_ooool2o`0009;ooooo0032ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0V_ooool00<?ooooo00?oV9RHob4Q8Oo^k^h0Voooool00<Cooooo00?oV9RHob4Q8Oo^k^h0V_oo
ool00<Gooooo00?oMgMgofIVI_ooool0VOooool00<Kooooo00?o0000ooooooooool0V?ooool00<;o
oooo00Go0000okZj^_ooooooV9RHoa0@402Jooooo`00`_ooool01OnHV9So410@o`000?lQ8B7oc<c<
09[ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003ooooo
of;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo003ooooo
of;ooooo003oooooof;ooooo003oooooof;ooooo003oooooof;ooooo002Uooooo`?o000000?o410@
ooooooooool0]_ooool009?ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00Cooooo00?o410@okZj
^_ooool01Oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2Ioooo
o`00Toooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8booooo`05ooooo`;o
<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8bV_ooool008Sooooo00Go410@o`000?l0003o
0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`00
0?nj^[X01?ooool00ooMgMgo0000okZj^P05ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM073ooooo002:ooooo`03o`000?oooooooooo00Kooooo
00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@
4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Koooool008[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgM
g@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1^ooooo`00R_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^
2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`1_ooooo`00R_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02oooo
o`03o`000?oMgMgooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0L?ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0L_ooool008Oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo07;ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000oooo
ooooool01Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0001aooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.625 .726 .919 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68189 Metetra
.623 .745 .934 r
.55403 .68189 .58394 .7109 .61197 .70234 .58236 .67587 Metetra
.623 .764 .947 r
.58236 .67587 .61197 .70234 .64019 .69372 .61092 .66952 Metetra
.624 .783 .958 r
.61092 .66952 .64019 .69372 .66861 .68504 .63969 .6627 Metetra
.628 .801 .965 r
.63969 .6627 .66861 .68504 .69723 .6763 .66869 .65531 Metetra
.634 .815 .97 r
.66869 .65531 .69723 .6763 .72605 .6675 .69789 .64727 Metetra
.643 .826 .97 r
.69789 .64727 .72605 .6675 .75507 .65863 .72729 .63852 Metetra
.655 .832 .968 r
.72729 .63852 .75507 .65863 .7843 .6497 .75687 .62905 Metetra
.667 .832 .963 r
.75687 .62905 .7843 .6497 .81374 .64071 .78663 .61886 Metetra
.678 .828 .955 r
.78663 .61886 .81374 .64071 .84339 .63166 .81656 .608 Metetra
.688 .818 .945 r
.81656 .608 .84339 .63166 .87325 .62254 .84666 .59655 Metetra
.696 .804 .933 r
.84666 .59655 .87325 .62254 .90333 .61335 .87691 .58461 Metetra
.7 .788 .919 r
.87691 .58461 .90333 .61335 .93362 .6041 .90734 .57231 Metetra
.701 .769 .905 r
.90734 .57231 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.578 .709 .932 r
.49498 .6552 .52593 .68772 .55403 .68189 .52331 .65194 Metetra
.576 .727 .945 r
.52331 .65194 .55403 .68189 .58236 .67587 .5519 .64834 Metetra
.579 .747 .957 r
.5519 .64834 .58236 .67587 .61092 .66952 .58076 .64416 Metetra
.587 .768 .965 r
.58076 .64416 .61092 .66952 .63969 .6627 .60988 .63913 Metetra
.601 .788 .97 r
.60988 .63913 .63969 .6627 .66869 .65531 .63923 .63304 Metetra
.618 .806 .972 r
.63923 .63304 .66869 .65531 .69789 .64727 .66881 .62572 Metetra
.64 .819 .969 r
.66881 .62572 .69789 .64727 .72729 .63852 .69858 .61708 Metetra
.662 .828 .963 r
.69858 .61708 .72729 .63852 .75687 .62905 .72853 .60705 Metetra
.683 .831 .954 r
.72853 .60705 .75687 .62905 .78663 .61886 .75863 .59568 Metetra
.701 .829 .943 r
.75863 .59568 .78663 .61886 .81656 .608 .78886 .58306 Metetra
.716 .821 .93 r
.78886 .58306 .81656 .608 .84666 .59655 .81922 .56933 Metetra
.725 .809 .917 r
.81922 .56933 .84666 .59655 .87691 .58461 .8497 .55471 Metetra
.73 .794 .903 r
.8497 .55471 .87691 .58461 .90734 .57231 .8803 .53945 Metetra
.73 .777 .89 r
.8803 .53945 .90734 .57231 .93794 .55978 .91103 .52381 Metetra
.529 .69 .941 r
.4632 .62183 .49498 .6552 .52331 .65194 .49173 .62087 Metetra
.529 .707 .953 r
.49173 .62087 .52331 .65194 .5519 .64834 .52056 .61946 Metetra
.536 .727 .962 r
.52056 .61946 .5519 .64834 .58076 .64416 .5497 .61724 Metetra
.552 .749 .969 r
.5497 .61724 .58076 .64416 .60988 .63913 .57913 .61382 Metetra
.577 .772 .972 r
.57913 .61382 .60988 .63913 .63923 .63304 .60882 .60889 Metetra
.606 .792 .97 r
.60882 .60889 .63923 .63304 .66881 .62572 .63875 .60221 Metetra
.638 .809 .965 r
.63875 .60221 .66881 .62572 .69858 .61708 .6689 .59362 Metetra
.669 .82 .956 r
.6689 .59362 .69858 .61708 .72853 .60705 .69921 .58306 Metetra
.697 .825 .944 r
.69921 .58306 .72853 .60705 .75863 .59568 .72966 .57057 Metetra
.72 .824 .93 r
.72966 .57057 .75863 .59568 .78886 .58306 .76023 .55629 Metetra
.737 .818 .915 r
.76023 .55629 .78886 .58306 .81922 .56933 .79089 .54045 Metetra
.747 .809 .901 r
.79089 .54045 .81922 .56933 .8497 .55471 .82163 .52335 Metetra
.753 .796 .888 r
.82163 .52335 .8497 .55471 .8803 .53945 .85245 .50535 Metetra
.753 .782 .876 r
.85245 .50535 .8803 .53945 .91103 .52381 .88337 .48685 Metetra
.482 .67 .946 r
.43058 .58756 .4632 .62183 .49173 .62087 .45928 .58851 Metetra
.484 .685 .955 r
.45928 .58851 .49173 .62087 .52056 .61946 .48832 .58892 Metetra
.498 .705 .963 r
.48832 .58892 .52056 .61946 .5497 .61724 .5177 .58832 Metetra
.524 .729 .968 r
.5177 .58832 .5497 .61724 .57913 .61382 .54741 .58623 Metetra
.558 .754 .969 r
.54741 .58623 .57913 .61382 .60882 .60889 .57742 .58224 Metetra
.598 .777 .966 r
.57742 .58224 .60882 .60889 .63875 .60221 .6077 .57606 Metetra
.638 .795 .958 r
.6077 .57606 .63875 .60221 .6689 .59362 .6382 .56748 Metetra
.676 .808 .946 r
.6382 .56748 .6689 .59362 .69921 .58306 .66888 .55641 Metetra
.707 .814 .931 r
.66888 .55641 .69921 .58306 .72966 .57057 .6997 .54291 Metetra
.733 .815 .916 r
.6997 .54291 .72966 .57057 .76023 .55629 .73062 .52718 Metetra
.751 .811 .9 r
.73062 .52718 .76023 .55629 .79089 .54045 .76162 .50948 Metetra
.763 .804 .886 r
.76162 .50948 .79089 .54045 .82163 .52335 .79266 .4902 Metetra
.769 .794 .874 r
.79266 .4902 .82163 .52335 .85245 .50535 .82376 .46983 Metetra
.77 .783 .864 r
.82376 .46983 .85245 .50535 .88337 .48685 .85493 .44884 Metetra
.443 .652 .948 r
.39706 .55236 .43058 .58756 .45928 .58851 .42592 .55471 Metetra
.45 .666 .955 r
.42592 .55471 .45928 .58851 .48832 .58892 .45515 .55645 Metetra
.47 .686 .96 r
.45515 .55645 .48832 .58892 .5177 .58832 .48475 .55704 Metetra
.504 .71 .964 r
.48475 .55704 .5177 .58832 .54741 .58623 .51472 .5559 Metetra
.547 .736 .963 r
.51472 .5559 .54741 .58623 .57742 .58224 .54503 .55257 Metetra
.594 .76 .958 r
.54503 .55257 .57742 .58224 .6077 .57606 .57563 .5467 Metetra
.639 .779 .948 r
.57563 .5467 .6077 .57606 .6382 .56748 .60648 .53805 Metetra
.68 .793 .934 r
.60648 .53805 .6382 .56748 .66888 .55641 .63753 .52651 Metetra
.714 .8 .918 r
.63753 .52651 .66888 .55641 .6997 .54291 .66872 .51217 Metetra
.74 .803 .902 r
.66872 .51217 .6997 .54291 .73062 .52718 .70001 .49523 Metetra
.759 .801 .887 r
.70001 .49523 .73062 .52718 .76162 .50948 .73137 .47602 Metetra
.772 .797 .873 r
.73137 .47602 .76162 .50948 .79266 .4902 .76277 .455 Metetra
.779 .79 .862 r
.76277 .455 .79266 .4902 .82376 .46983 .7942 .43272 Metetra
.781 .783 .854 r
.7942 .43272 .82376 .46983 .85493 .44884 .82567 .40974 Metetra
.417 .639 .948 r
.36263 .5162 .39706 .55236 .42592 .55471 .39163 .51934 Metetra
.429 .652 .952 r
.39163 .51934 .42592 .55471 .45515 .55645 .42104 .52184 Metetra
.456 .671 .956 r
.42104 .52184 .45515 .55645 .48475 .55704 .45085 .52309 Metetra
.496 .695 .957 r
.45085 .52309 .48475 .55704 .51472 .5559 .48106 .52246 Metetra
.544 .72 .955 r
.48106 .52246 .51472 .5559 .54503 .55257 .51163 .51946 Metetra
.594 .743 .948 r
.51163 .51946 .54503 .55257 .57563 .5467 .54254 .51368 Metetra
.64 .762 .936 r
.54254 .51368 .57563 .5467 .60648 .53805 .57373 .50488 Metetra
.682 .775 .921 r
.57373 .50488 .60648 .53805 .63753 .52651 .60513 .49293 Metetra
.716 .784 .905 r
.60513 .49293 .63753 .52651 .66872 .51217 .6367 .47792 Metetra
.743 .788 .889 r
.6367 .47792 .66872 .51217 .70001 .49523 .66838 .46009 Metetra
.762 .789 .875 r
.66838 .46009 .70001 .49523 .73137 .47602 .70012 .43978 Metetra
.776 .788 .863 r
.70012 .43978 .73137 .47602 .76277 .455 .73191 .41751 Metetra
.783 .785 .854 r
.73191 .41751 .76277 .455 .7942 .43272 .76372 .39388 Metetra
.786 .781 .848 r
.76372 .39388 .7942 .43272 .82567 .40974 .79557 .36951 Metetra
.408 .635 .948 r
.32723 .47902 .36263 .5162 .39163 .51934 .35639 .4823 Metetra
.424 .645 .95 r
.35639 .4823 .39163 .51934 .42104 .52184 .38598 .48492 Metetra
.456 .662 .951 r
.38598 .48492 .42104 .52184 .45085 .52309 .41599 .48625 Metetra
.499 .684 .949 r
.41599 .48625 .45085 .52309 .48106 .52246 .44642 .48565 Metetra
.547 .706 .944 r
.44642 .48565 .48106 .52246 .51163 .51946 .47726 .48258 Metetra
.596 .727 .935 r
.47726 .48258 .51163 .51946 .54254 .51368 .50845 .47666 Metetra
.642 .744 .923 r
.50845 .47666 .54254 .51368 .57373 .50488 .53995 .46761 Metetra
.682 .757 .908 r
.53995 .46761 .57373 .50488 .60513 .49293 .57171 .4553 Metetra
.715 .766 .893 r
.57171 .4553 .60513 .49293 .6367 .47792 .60365 .43984 Metetra
.741 .773 .879 r
.60365 .43984 .6367 .47792 .66838 .46009 .63572 .42146 Metetra
.761 .776 .866 r
.63572 .42146 .66838 .46009 .70012 .43978 .66787 .40053 Metetra
.775 .778 .856 r
.66787 .40053 .70012 .43978 .73191 .41751 .70007 .37757 Metetra
.783 .778 .848 r
.70007 .37757 .73191 .41751 .76372 .39388 .73231 .35321 Metetra
.787 .778 .844 r
.73231 .35321 .76372 .39388 .79557 .36951 .76458 .32809 Metetra
.417 .639 .948 r
.29083 .44079 .32723 .47902 .35639 .4823 .32018 .44351 Metetra
.437 .647 .947 r
.32018 .44351 .35639 .4823 .38598 .48492 .34995 .44558 Metetra
.469 .66 .944 r
.34995 .44558 .38598 .48492 .41599 .48625 .38017 .44638 Metetra
.511 .677 .94 r
.38017 .44638 .41599 .48625 .44642 .48565 .41083 .44527 Metetra
.557 .695 .932 r
.41083 .44527 .44642 .48565 .47726 .48258 .44191 .44175 Metetra
.602 .712 .922 r
.44191 .44175 .47726 .48258 .50845 .47666 .47338 .43542 Metetra
.643 .727 .909 r
.47338 .43542 .50845 .47666 .53995 .46761 .50519 .42602 Metetra
.68 .739 .896 r
.50519 .42602 .53995 .46761 .57171 .4553 .53727 .41342 Metetra
.711 .749 .882 r
.53727 .41342 .57171 .4553 .60365 .43984 .56957 .39773 Metetra
.736 .757 .87 r
.56957 .39773 .60365 .43984 .63572 .42146 .60203 .37917 Metetra
.755 .763 .859 r
.60203 .37917 .63572 .42146 .66787 .40053 .6346 .35811 Metetra
.769 .767 .851 r
.6346 .35811 .66787 .40053 .70007 .37757 .66723 .33505 Metetra
.779 .771 .846 r
.66723 .33505 .70007 .37757 .73231 .35321 .69992 .31062 Metetra
.784 .773 .844 r
.69992 .31062 .73231 .35321 .76458 .32809 .73265 .28543 Metetra
.443 .652 .948 r
.25338 .40146 .29083 .44079 .32018 .44351 .28295 .40293 Metetra
.463 .655 .943 r
.28295 .40293 .32018 .44351 .34995 .44558 .31295 .40379 Metetra
.493 .663 .937 r
.31295 .40379 .34995 .44558 .38017 .44638 .3434 .40345 Metetra
.53 .675 .93 r
.3434 .40345 .38017 .44638 .41083 .44527 .37429 .40134 Metetra
.57 .688 .92 r
.37429 .40134 .41083 .44527 .44191 .44175 .40562 .39696 Metetra
.609 .7 .909 r
.40562 .39696 .44191 .44175 .47338 .43542 .43736 .38997 Metetra
.645 .712 .896 r
.43736 .38997 .47338 .43542 .50519 .42602 .46945 .38012 Metetra
.677 .723 .884 r
.46945 .38012 .50519 .42602 .53727 .41342 .50185 .3673 Metetra
.704 .733 .873 r
.50185 .3673 .53727 .41342 .56957 .39773 .53449 .35159 Metetra
.727 .741 .863 r
.53449 .35159 .56957 .39773 .60203 .37917 .56733 .33321 Metetra
.746 .749 .855 r
.56733 .33321 .60203 .37917 .6346 .35811 .6003 .3125 Metetra
.76 .756 .849 r
.6003 .3125 .6346 .35811 .66723 .33505 .63338 .28992 Metetra
.77 .763 .847 r
.63338 .28992 .66723 .33505 .69992 .31062 .66654 .26605 Metetra
.776 .769 .846 r
.66654 .26605 .69992 .31062 .73265 .28543 .69976 .24147 Metetra
.482 .67 .946 r
.21484 .36098 .25338 .40146 .28295 .40293 .2447 .36057 Metetra
.5 .668 .938 r
.2447 .36057 .28295 .40293 .31295 .40379 .27497 .35959 Metetra
.525 .67 .929 r
.27497 .35959 .31295 .40379 .3434 .40345 .30568 .35755 Metetra
.555 .675 .919 r
.30568 .35755 .3434 .40345 .37429 .40134 .33683 .35394 Metetra
.586 .683 .907 r
.33683 .35394 .37429 .40134 .40562 .39696 .36841 .34834 Metetra
.617 .691 .896 r
.36841 .34834 .40562 .39696 .43736 .38997 .40041 .34045 Metetra
.647 .699 .885 r
.40041 .34045 .43736 .38997 .46945 .38012 .43277 .33006 Metetra
.673 .708 .874 r
.43277 .33006 .46945 .38012 .50185 .3673 .46547 .31707 Metetra
.697 .718 .865 r
.46547 .31707 .50185 .3673 .53449 .35159 .49844 .30155 Metetra
.716 .727 .858 r
.49844 .30155 .53449 .35159 .56733 .33321 .53163 .28368 Metetra
.733 .736 .853 r
.53163 .28368 .56733 .33321 .6003 .3125 .565 .26377 Metetra
.747 .745 .85 r
.565 .26377 .6003 .3125 .63338 .28992 .5985 .24221 Metetra
.757 .754 .85 r
.5985 .24221 .63338 .28992 .66654 .26605 .63213 .21951 Metetra
.763 .763 .852 r
.63213 .21951 .66654 .26605 .69976 .24147 .66586 .19616 Metetra
.529 .69 .941 r
.17516 .3193 .21484 .36098 .2447 .36057 .20537 .31642 Metetra
.542 .683 .93 r
.20537 .31642 .2447 .36057 .27497 .35959 .23597 .31306 Metetra
.56 .679 .919 r
.23597 .31306 .27497 .35959 .30568 .35755 .26699 .30882 Metetra
.581 .679 .907 r
.26699 .30882 .30568 .35755 .33683 .35394 .29842 .30329 Metetra
.604 .68 .895 r
.29842 .30329 .33683 .35394 .36841 .34834 .33028 .29615 Metetra
.627 .684 .884 r
.33028 .29615 .36841 .34834 .40041 .34045 .36254 .28715 Metetra
.648 .689 .875 r
.36254 .28715 .40041 .34045 .43277 .33006 .39517 .27613 Metetra
.669 .696 .866 r
.39517 .27613 .43277 .33006 .46547 .31707 .42815 .26301 Metetra
.687 .704 .86 r
.42815 .26301 .46547 .31707 .49844 .30155 .46141 .24785 Metetra
.704 .713 .856 r
.46141 .24785 .49844 .30155 .53163 .28368 .49493 .23079 Metetra
.718 .723 .853 r
.49493 .23079 .53163 .28368 .565 .26377 .52867 .21207 Metetra
.73 .733 .853 r
.52867 .21207 .565 .26377 .5985 .24221 .56258 .192 Metetra
.739 .744 .856 r
.56258 .192 .5985 .24221 .63213 .21951 .59666 .17099 Metetra
.746 .755 .86 r
.59666 .17099 .63213 .21951 .66586 .19616 .63089 .14942 Metetra
.578 .709 .932 r
.13429 .27638 .17516 .3193 .20537 .31642 .16493 .27056 Metetra
.586 .698 .92 r
.16493 .27056 .20537 .31642 .23597 .31306 .19593 .26436 Metetra
.596 .69 .907 r
.19593 .26436 .23597 .31306 .26699 .30882 .22731 .2575 Metetra
.609 .684 .895 r
.22731 .2575 .26699 .30882 .29842 .30329 .25908 .24972 Metetra
.622 .681 .884 r
.25908 .24972 .29842 .30329 .33028 .29615 .29123 .24077 Metetra
.636 .68 .875 r
.29123 .24077 .33028 .29615 .36254 .28715 .32377 .2305 Metetra
.65 .682 .867 r
.32377 .2305 .36254 .28715 .39517 .27613 .35666 .21878 Metetra
.664 .686 .861 r
.35666 .21878 .39517 .27613 .42815 .26301 .38989 .20556 Metetra
.677 .692 .857 r
.38989 .20556 .42815 .26301 .46141 .24785 .42343 .19089 Metetra
.689 .701 .855 r
.42343 .19089 .46141 .24785 .49493 .23079 .45725 .17487 Metetra
.7 .71 .856 r
.45725 .17487 .49493 .23079 .52867 .21207 .49131 .15764 Metetra
.71 .721 .859 r
.49131 .15764 .52867 .21207 .56258 .192 .5256 .13944 Metetra
.718 .734 .863 r
.5256 .13944 .56258 .192 .59666 .17099 .5601 .12053 Metetra
.724 .746 .87 r
.5601 .12053 .59666 .17099 .63089 .14942 .59481 .1012 Metetra
.625 .726 .919 r
.09217 .23214 .13429 .27638 .16493 .27056 .12333 .22304 Metetra
.627 .712 .907 r
.12333 .22304 .16493 .27056 .19593 .26436 .15481 .21368 Metetra
.631 .7 .895 r
.15481 .21368 .19593 .26436 .22731 .2575 .18661 .20393 Metetra
.635 .69 .884 r
.18661 .20393 .22731 .2575 .25908 .24972 .21875 .19365 Metetra
.641 .683 .874 r
.21875 .19365 .25908 .24972 .29123 .24077 .25124 .18271 Metetra
.647 .679 .867 r
.25124 .18271 .29123 .24077 .32377 .2305 .28406 .17104 Metetra
.653 .678 .861 r
.28406 .17104 .32377 .2305 .35666 .21878 .31722 .15857 Metetra
.66 .679 .857 r
.31722 .15857 .35666 .21878 .38989 .20556 .35069 .14528 Metetra
.667 .683 .856 r
.35069 .14528 .38989 .20556 .42343 .19089 .38448 .13118 Metetra
.674 .69 .857 r
.38448 .13118 .42343 .19089 .45725 .17487 .41855 .11633 Metetra
.68 .699 .86 r
.41855 .11633 .45725 .17487 .49131 .15764 .45291 .10081 Metetra
.687 .709 .866 r
.45291 .10081 .49131 .15764 .5256 .13944 .48753 .08473 Metetra
.692 .722 .873 r
.48753 .08473 .5256 .13944 .5601 .12053 .52242 .06821 Metetra
.696 .736 .881 r
.52242 .06821 .5601 .12053 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12333 .22304 .08051 .17394 Metetra
.664 .723 .893 r
.08051 .17394 .12333 .22304 .15481 .21368 .11254 .16124 Metetra
.662 .709 .883 r
.11254 .16124 .15481 .21368 .18661 .20393 .14483 .14843 Metetra
.66 .697 .874 r
.14483 .14843 .18661 .20393 .21875 .19365 .1774 .13551 Metetra
.658 .688 .866 r
.1774 .13551 .21875 .19365 .25124 .18271 .21025 .12249 Metetra
.657 .681 .861 r
.21025 .12249 .25124 .18271 .28406 .17104 .24339 .10934 Metetra
.656 .676 .857 r
.24339 .10934 .28406 .17104 .31722 .15857 .27681 .09609 Metetra
.656 .675 .856 r
.27681 .09609 .31722 .15857 .35069 .14528 .31052 .08272 Metetra
.656 .676 .857 r
.31052 .08272 .35069 .14528 .38448 .13118 .34452 .06923 Metetra
.657 .681 .861 r
.34452 .06923 .38448 .13118 .41855 .11633 .37882 .05563 Metetra
.658 .688 .866 r
.37882 .05563 .41855 .11633 .45291 .10081 .41342 .04191 Metetra
.66 .697 .874 r
.41342 .04191 .45291 .10081 .48753 .08473 .44833 .02806 Metetra
.662 .709 .883 r
.44833 .02806 .48753 .08473 .52242 .06821 .48355 .01409 Metetra
.664 .723 .893 r
.48355 .01409 .52242 .06821 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY^NCo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVi
i0?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY^N@00ol0003oZKWTo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY^N@00ol0003oZKWTojVii003ojVii004o`000?nY^NCoZKWTo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVii004o`000?nY^NCoZKWTo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY]N;o0000ojVii009
ojVii005o`000?nY^NCoZKWTojVii?l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVeh_l0003oZKGR00;oZKGR
00?o0000ojVii?nY^N@01onY^N@00ol0003oZKWTojVii002ojVii003o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY]N800ol0003oZKWTojVii006ojVii003o`000?nY^NCoZKWT00?oZKWT00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVehP03o`000?nY^NCoZKWT00GoZKWT00?o0000
ojVii?nY^N@00onY^N@00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKGR00?o0000ojVi
i?nY^N@01OnY^N@00ol0003oZKWTojVii004ojVii003o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnX/]l00ol0003oZKGRojVehP0:ojVehP03o`000?nY^NCoZKWT00CoZKWT00?o0000ojVii?nY
^N@01OnY^N@00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZ;;O00?o0000ojVe
h_nY]N802_nY]N800ol0003oZKWTojVii003ojVii003o`000?nY^NCoZKWT00KoZKWT00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onX/]oo0000ojRbg`09ojRbg`03o`000?nY]N;o
ZKGR00_oZKGR00?o0000ojVii?nY^N@00_nY^N@00ol0003oZKWTojVii006ojVii003o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnX/=go0000ojRbgonX/]oo000000[oZ;;O00?o0000ojVeh_nY]N80
2_nY]N800ol0003oZKWTojVii002ojVii003o`000?nY^NCoZKWT00OoZKWT00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZ;3M00?o0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP05
o`000?nY^NCoZKWTojVii?l000002_nY^N@00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZ;3M
o`000?nX/=d01OnX/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY]N;oZKGR00[oZKGR00Co0000
ojVii?nY^NCo00002_nY^N@2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onX/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY
]N;oZKGR00_oZKGR00?o0000ojVii?l000002?nY^N@2o`000003ok:lhOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnX
/=d00ol0003oZ;;OojRbg`0;ojRbg`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVii?l000001OnY
^N@3o`0000Co/[cQ00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojR^g003o`000?nX[]co000000goZ;3M
00?o0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP;o00000onY^N@2o`0000So/[cQ
00?o0000ooooooooool0Soooool008kooooo0ol00007ojR^g003o`000?nX/=goZ;3M00[oZ;3M00?o
0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0;ojVehP04o`000?nY^NCo0000o`0000_o/[cQ
00?o0000ooooooooool0S_ooool008cooooo0ol00009ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o
0000ojRbgonX/]l02onX/]l00ol0003oZKGRojVehP0:ojVehP;o00003Onb_>42o`0008oooooo0029
ooooo`Co000000?oZ:kLo`000?nX[]`02OnX[]`00ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]oo
Z;;O00_oZ;;O00?o0000ojVeh_nY]N801onY]N84o`0000ko/[cQ00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onW[M_o0000ojR^g00;ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o0000
ojRbgonX/]l03?nX/]l00ol0003oZKGRojVehP04ojVehP;o00000_na^=l00ol0003o/KSOo`00000>
ok:lh@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoYjgK00?o0000ojR^g?nX[]`02_nX[]`0
0ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00_oZ;;O00?o0000ojVeh_nY]N800_nY]N82
o`0000Co/KSO00Co0000ok6hgona^=oo00003_nb_>400ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oYjgKo`000?nW[M/01_nW
[M/00ol0003oZ:kLojR^g00:ojR^g003o`000?nX/=goZ;3M00_oZ;3M00?o0000ojRbgonX/]l02onX
/]l01?l0003oZKGRo`000?l00006ok6hg`05o`000?na^=oo/KSOok6hgol000003Onb_>42o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnW[M/00ol0003oYjgKojN]f`04ojN]f`03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojR`
gOnX/=d02onX/=d00ol0003oZ;;OojRbg`0;ojRbg`;o00002?na^=l01Ol0003o/KSOok6hgona^=oo
000000ko/[cQ0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojN/fol0003oYjgK00coYjgK00?o0000ojR^g?nX[]`02_nX
[]`00ol0003oZ;3MojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00SoZ;;O0_l000000on_]Mgo0000ok6h
g`07ok6hg`03o`000?na^=oo/KSO00;o/KSO00?o0000ok:lhOnb_>403?nb_>400ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oYjcK00Co0000ojN/fonW[=_o00003?nW[M/00ol0003oZ:kLojR^g00;ojR^g003o`00
0?nX/=goZ;3M00_oZ;3M00?o0000ojRbgonX/]l01?nX/]l3o`0000Co[kGM00?o0000ok6hgona^=l0
1Ona^=l00ol0003o/KSOok6hg`03ok6hg`03o`000?nb_>7o/[cQ00co/[cQ00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojN/f`03o`000?nW[M_oYjgK00[oYjgK00?o0000ojR^g?nX[]`02_nX[]`00ol0003oZ;3M
ojR`g@0;ojR`g@03o`000?nX/]ooZ;;O00;oZ;;O0_l00008ojneg@03o`000?na^=oo/KSO00Co/KSO
00?o0000ok6hgona^=l01?na^=l00ol0003o/[cQok:lh@0;ok:lh@;o0000ROooool0053ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000;ojN/f`03o`00
0?nW[M_oYjgK00_oYjgK00?o0000ojR^g?nX[]`02_nX[]`00ol0003oZ;3MojR`g@0;ojR`g@04o`00
0?nX/]oo0000o`0000[o[kGM00?o0000ok6hgona^=l01?na^=l00ol0003o/KSOok6hg`04ok6hg`03
o`000?nb_>7o/[cQ00co/[cQ0_l00028ooooo`00Loooool3o`000003ojN]fol0003o000000_oYjcK
00?o0000ojN]fonW[M/02_nW[M/00ol0003oZ:kLojR^g00;ojR^g003o`000?nX/=goZ;3M00[oZ;3M
0_l0000=ojneg@03o`000?na^=oo/KSO00?o/KSO00?o0000ok6hgona^=l01Ona^=l00ol0003o/[cQ
ok:lh@0<ok:lh@;o0000Qoooool0073ooooo0ol00005ojN]f`03o`000?nW[=_oYjcK00[oYjcK00?o
0000ojN]fonW[M/02_nW[M/00ol0003oZ:kLojR^g00:ojR^g003o`000?nX/=goZ;3M00SoZ;3M0_l0
00000on^/]co0000ojneg@0=ojneg@03o`000?na^=oo/KSO00;o/KSO00?o0000ok6hgona^=l01_na
^=l00ol0003o/[cQok:lh@09ok:lh@;o000000?o^KkNo`000?ooool0Q_ooool006kooooo0ol00008
ojN]f`03o`000?nW[=_oYjcK00WoYjcK00?o0000ojN]fonW[M/02onW[M/00ol0003oZ:kLojR^g00:
ojR^g003o`000?nX/=goZ;3M00CoZ;3M0ol00004ojjbg003o`000?n_]Mgo[kGM00_o[kGM00?o0000
ok6hgona^=l00_na^=l00ol0003o/KSOok6hg`07ok6hg`03o`000?nb_>7o/[cQ00Ko/[cQ0_l00003
okVngP;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0002?ooooo0ol00002ojN]f`03o`000?nW[M_oYjgK00KoYjgK00?o0000ojN/fonW[=/02_nW[=/0
0ol0003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojR`gOnX/=d00_nX/=d2
o`0000So[[;L00?o0000ojnegOn_]Md02on_]Md01Ol0003o/KSOok6hgona^=oo000000Wo/KSO00?o
0000ok:lhOnb_>401Onb_>400ol0003o^KkNokVngP04okVngP;o0000QOooool003?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4027ooooo
0ol000000onX[]co0000ojN]f`0;ojN]f`03o`000?nW[=_oYjcK00[oYjcK00?o0000ojN]fonW[M/0
2_nW[M/00ol0003oZ:kLojR^g00:ojR^g004o`000?nX/=go0000o`0000[o[[;L00?o0000ojnegOn_
]Md03?n_]Md01?l0003o/KSOok6hgol0000:ok6hg`03o`000?nb_>7o/[cQ00;o/[cQ0_l00008okVn
gP;o0000Q?ooool003?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
01oooooo1?l00004ojR^g003o`000?nW[M_oYjgK00WoYjgK00?o0000ojN/fonW[=/02onW[=/00ol0
003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00WoZ:kL0_l0000=ojjbg003o`000?n_]Mgo[kGM
00_o[kGM00Co0000ok6hgona^=oo00002ona^=l01?l0003o/[cQo`000?l0000;okVngP03o`000?oo
oooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP0Kooooo`?o00001?nX[]`00ol0003oZ:kLojR^g002ojR^g003o`000?nW[M_oYjgK00WoYjgK00?o
0000ojN/fonW[=/02_nW[=/00ol0003oYjgKojN]f`0:ojN]f`03o`000?nX[]coZ:kL00OoZ:kL0_l0
00000on//=_o0000ojjbg00=ojjbg003o`000?n_]Mgo[kGM00_o[kGM00?o0000ok6hgol000002ona
^=l2o`0000go^KkN0_l00023ooooo`00<oooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool06?ooool3o`0000_oZ:kL00?o0000ojN]fonW[M/02_nW[M/00ol0003oYjcKojN/
f`0:ojN/f`03o`000?nW[M_oYjgK00[oYjgK00?o0000ojR^g?nX[]`01?nX[]`2o`0000Co[;3K00?o
0000ojjbg?n^/]`02on^/]`00ol0003o[kGMojneg@0;ojneg@03o`000?na^=oo000000Wo/KSO0_l0
00000ong^mco0000okVngP0=okVngP;o0000P_ooool003?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo01Cooooo0ol000000onX/=go0000ojR^g00<ojR^g003o`000?nW
[M_oYjgK00WoYjgK00?o0000ojN/fonW[=/02onW[=/00ol0003oYjgKojN]f`09ojN]f`03o`000?nX
[]coZ:kL00;oZ:kL0_l00007ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojnegOn_]Md02on_
]Md2o`0000Oo/KSO0_l00004okNkg003o`000?ni_]ko^KkN00co^KkN0_l00021ooooo`00<oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`?o0000
1?nX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/0
2_nW[=/00ol0003oYjgKojN]f`0:ojN]f`04o`000?nX[]co0000o`0000Wo[;3K00?o0000ojjbg?n^
/]`03?n^/]`00ol0003o[kGMojneg@0;ojneg@03o`000?na^=oo/KSO00Co/KSO00?o0000okNkg?ng
^m`01Ong^m`00ol0003o^KkNokVngP0<okVngP03o`000?oooooooooo07oooooo000cooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0ol00008ojR`
g@03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojN]fonW[M/02_nW[M/00ol0003oYjcKojN/f`0:ojN/
f`03o`000?nW[M_oYjgK00WoYjgK0_l0000<ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojne
gOn_]Md02on_]Md00ol0003o/KSOok6hg`02ok6hg`;o00002?ng^m`00ol0003o^KkNokVngP0<okVn
gP;o0000P?ooool005Oooooo0ol000000onX/=go0000ojR`g@07ojR`g@03o`000?nX[]coZ:kL00_o
Z:kL00?o0000ojN]fonW[M/02OnW[M/00ol0003oYjcKojN/f`0;ojN/f`03o`000?nW[M_oYjgK00Go
YjgK0ol000000onZ[]_o0000ojb`f`0<ojb`f`03o`000?n^/]co[[;L00_o[[;L00?o0000ojnegOn_
]Md02_n_]Md2o`000003ok6hgol0003o000000_o]k_L00?o0000okVng_ni_]h03?ni_]h2o`0007oo
oooo001Dooooo`?o000000?oZ;;Oo`000?nX/=d02onX/=d00ol0003oZ:kLojR^g00:ojR^g003o`00
0?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/02_nW[=/00ol0003oYjgKojN]f`03ojN]f`;o0000
1OnZ[]/00ol0003o[;3Kojb`f`0:ojb`f`03o`000?n^/]co[[;L00co[[;L00?o0000ojnegOn_]Md0
2On_]Md3o`0000ko]k_L00?o0000okVng_ni_]h03?ni_]h00ol0003oooooooooo`1mooooo`00D_oo
ool3o`0000CoZ;;O00?o0000ojR`gOnX/=d02_nX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW
[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/02_nW[=/00ol0003oYjgKo`000002o`0000SoZZkK00?o
0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00;ojjbg003o`000?n_]Mgo[kGM00So[kGM0_l0
00000one^=_o0000okNkg00=okNkg003o`000?ni_]ko^KkN00go^KkN00?o0000ooooooooool0O?oo
ool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Sooooo`Co000000?oZ;;Oo`000?nX/]l01?nX
/]l00ol0003oZ;3MojR`g@09ojR`g@03o`000?nX[]coZ:kL00_oZ:kL00?o0000ojN]fonW[M/02OnW
[M/00ol0003oYjcKojN/f`0:ojN/f`;o00002onZ[]/00ol0003o[;3Kojb`f`0;ojb`f`03o`000?n^
/]co[[;L00_o[[;L00?o0000ojnegOn_]Md01_n_]Md00ol0003o]KSKo`000002okFhf`03o`000?ng
^mco]k_L00co]k_L00?o0000okVng_ni_]h03?ni_]h2o`0007gooooo000Wooooo`05ogMgMonHV9So
oooooiRHV?mgMgL08Oooool3o`0000_oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^
g00:ojR^g003o`000?nW[M_oYjgK00[oYjgK00?o0000ojN/fonW[=/01_nW[=/3o`000003ojR]fol0
003oZZkK00_oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00<ojjbg003o`000?n_
]Mgo[kGM00?o[kGM0_l00002okFhf`05o`000?ne^=_o]KSKokFhfol000003_ng^m`00ol0003o^KkN
okVngP0<okVngP;o0000O?ooool002Oooooo00Go410@oooooooooooooooooa0@400Nooooo`Go0000
3?nX/]l00ol0003oZ;3MojR`g@0:ojR`g@03o`000?nX[]coZ:kL00[oZ:kL00?o0000ojN]fonW[M/0
2OnW[M/00ol0003oYjcKojN/f`03ojN/f`?o00001OnX[M/00ol0003oZZkKojZ^f`0:ojZ^f`03o`00
0?n//=_o[;3K00[o[;3K00?o0000ojjbg?n^/]`02on^/]`01?l0003o[kGMojnegOn_]Md2o`0000Co
]KSK00?o0000okFhfone^=/00_ne^=/00ol0003o]k_LokNkg00<okNkg003o`000?ni_]ko^KkN00[o
^KkN00?o0000okk1g?l00000O?ooool002Oooooo00Go0000ooooooooooooooooo`00000Looooo`?o
00000_nY]N800ol0003oZKGRo`00000<ojRbg`03o`000?nX/=goZ;3M00[oZ;3M00?o0000ojR^g?nX
[]`02_nX[]`00ol0003oYjgKojN]f`09ojN]f`03o`000?nW[=_o000000;o00002OnX[M/00ol0003o
ZZkKojZ^f`09ojZ^f`03o`000?n//=_o[;3K00_o[;3K00?o0000ojjbg?n^/]`02on^/]`00ol0003o
[kGMo`000006okFhf`03o`000?ne^=_o]KSK00;o]KSK00?o0000okNkg?ng^m`03?ng^m`00ol0003o
^KkNokVngP08okVngP;o00000onn`M`00ol0003oooooooooo`1iooooo`009oooool01Ol0003ooooo
oooooooooooo000001Wooooo1?l00005ojVehP03o`000?nY]N;o000000coZ;;O00?o0000ojR`gOnX
/=d02OnX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00WoYjgK0_l0000<ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg00;ojjbg0;o
00001one^=/00ol0003o]KSKokFhf`03okFhf`03o`000?ng^mco]k_L00co]k_L00?o0000okVng_ni
_]h01Oni_]h2o`0000Go_/7L0_l0001jooooo`009oooool01Ol@413ooooooooooooooooo410@01Oo
oooo0ol0000;ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX/=d02_nX/=d00ol0003o
Z:kLojR^g00:ojR^g003o`000?nW[M_oYjgK00GoYjgK0ol000000onW[Mco0000ojR]f`0<ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/00ol0003o[[;Lojjbg008ojjbg0;o
000000?o/kGKo`000?ne^=/01_ne^=/00ol0003o]KSKokFhf`04okFhf`03o`000?ng^mco]k_L00co
]k_L00?o0000okVng_ni_]h00oni_]h00ol0003o_/7Lokk1g006okk1g0;o0000NOooool002Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`Go000000?oZKGRo`000?nY]N802OnY]N800ol0003o
Z;;OojRbg`0:ojRbg`03o`000?nX/=goZ;3M00[oZ;3M00?o0000ojR^g?nX[]`02OnX[]`00ol0003o
YjgKojN]f`03ojN]f`;o00001OnW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[o
ZZkK00?o0000ojb`fon//=/02on//=/00ol0003o[[;Lojjbg004ojjbg0?o00001?nc]M/00ol0003o
]KSKokFhf`04okFhf`03o`000?ne^=_o]KSK00Go]KSK00?o0000okNkg?ng^m`02ong^m`01?l0003o
^KkNokVng_ni_]h2o`0000[o_/7L00?o0000ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Booooo`?o00001?nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O
00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^g00:ojR^g003o`000?nW[M_o0000
00;o00002?nW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`
fon//=/02_n//=/00ol0003o[[;Lojjbg002ojjbg0;o00002?nc]M/00ol0003o]KSKokFhf`03okFh
f`03o`000?ne^=_o]KSK00Go]KSK00?o0000okNkg?ng^m`03?ng^m`00ol0003o^KkNo`00000=okk1
g003o`000?oooooooooo07Kooooo000kooooo`Go00001_nY^N@00ol0003oZKGRojVehP0:ojVehP03
o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLojR^g009ojR^g0;o
00002onW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon/
/=/02_n//=/01?l0003o[[;Lo`000?l0000:ok>ef`03o`000?ne^=_o]KSK00?o]KSK00?o0000okFh
fone^=/01_ne^=/00ol0003o]k_LokNkg00;okNkg0;o00003_nn`M`2o`0007Oooooo000iooooo`?o
00002onY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX
/=d02_nX/=d00ol0003oZ:kLojR^g005ojR^g0?o000000?oYJgMo`000?nW[M`02onW[M`00ol0003o
Z:gKojR]f`0:ojR]f`03o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/02_n//=/2o`0000go
/kGK00?o0000okFhfone^=/00_ne^=/00ol0003o]KSKokFhf`07okFhf`03o`000?ng^mco]k_L00So
]k_L0_l000000onm_]_o0000okk1g00>okk1g0;o0000M_ooool003Oooooo1?l0000=ojVii003o`00
0?nY]N;oZKGR00[oZKGR00?o0000ojRbgonX/]l02OnX/]l00ol0003oZ;3MojR`g@09ojR`g@03o`00
0?nX[]coZ:kL00?oZ:kL0_l00005ojF]g@03o`000?nW[McoYjgL00WoYjgL00?o0000ojR]fonX[M/0
2onX[M/00ol0003oZZkKojZ^f`0:ojZ^f`03o`000?n//=_o[;3K00Oo[;3K0_l000000on`/m[o0000
ok>ef`0=ok>ef`05o`000?ne^=_o]KSKokFhfol000002_ne^=/00ol0003o]k_LokNkg006okNkg003
o`000?nm_]_o_KkK00;o_KkK00?o0000okk1g?nn`M`03Onn`M`00ol0003oooooooooo`1dooooo`00
=?ooool3o`000005ojZliol0003oZ[cWojZliol000003?nY^N@00ol0003oZKGRojVehP0:ojVehP03
o`000?nX/]ooZ;;O00[oZ;;O00?o0000ojR`gOnX/=d02OnX/=d00ol0003oZ:kLo`000002o`0000So
YJgM00?o0000ojN]g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00[o
ZZkK00?o0000ojb`fon//=/01?n//=/2o`0000Co/;?J00?o0000ok>efonc]M/02onc]M/01Ol0003o
]KSKokFhfone^=_o000000[o]KSK00?o0000okNkg?ng^m`01?ng^m`2o`0000Ko_KkK00?o0000okk1
g?nn`M`03Onn`M`00ol0003oooooooooo`1cooooo`00<_ooool3o`0000OoZ[cW00?o0000ojVii?nY
^N@02_nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O00WoZ;;O00?o0000ojR`gOnX
/=d02?nX/=d3o`0000_oYJgM00?o0000ojN]g?nW[M`02_nW[M`00ol0003oZ:gKojR]f`0:ojR]f`03
o`000?nZ[]_oZZkK00[oZZkK00?o0000ojb`fon//=/00_n//=/2o`0000Oo/;?J00?o0000ok>efonc
]M/02onc]M/01?l0003o]KSKokFhfol0000;okFhf`04o`000?ng^mco]k_LokNkg0;o00002Onm_]/0
0ol0003o_/7Lokk1g00<okk1g0;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0
003oZKWTojVii00:ojVii003o`000?nY]N;oZKGR00[oZKGR00?o0000ojRbgonX/]l02OnX/]l00ol0
003oZ;3MojR`g@04ojR`g@?o00000_nT[]l00ol0003oYJgMojF]g@0:ojF]g@03o`000?nW[McoYjgL
00WoYjgL00?o0000ojR]fonX[M/02onX[M/00ol0003oZZkKojZ^f`0:ojZ^f`04o`000?n//=_o0000
o`0000Wo/;?J00?o0000ok>efonc]M/03?nc]M/00ol0003o]KSKo`00000<okFhf`03o`000?ng^mco
000000_o_KkK00?o0000okk1g?nn`M`03Onn`M`00ol0003oooooooooo`1booooo`00<Oooool2o`00
00_oZ[cW00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKGRojVehP0:ojVehP03o`000?nX/]ooZ;;O
00WoZ;;O00?o0000ojR`gOnX/=d00ol00006ojB^g`03o`000?nU[MgoYJgM00[oYJgM00?o0000ojN]
g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0;ojR]f`03o`000?nZ[]_oZZkK00WoZZkK0_l0000<ok2c
fP03o`000?nc]M_o/kGK00_o/kGK00?o0000okFhfol000003?ne^=/2o`0000go_KkK00?o0000okk1
g?nn`M`03Onn`M`00ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Oooooo0_l0000<ojZli`03o`000?nY^NCoZKWT00[oZKWT00?o0000ojVeh_nY]N802OnY]N800ol0
003oZ;;OojRbg`08ojRbg`Co00002_nT[]l00ol0003oYJgMojF]g@09ojF]g@03o`000?nW[McoYjgL
00[oYjgL00?o0000ojR]fonX[M/02_nX[M/00ol0003oZZkKojZ^f`07ojZ^f`;o000000?o[K7Ko`00
0?n`/mX03?n`/mX00ol0003o/kGKok>ef`0;ok>ef`;o00002one^=/00ol0003o^[_Jo`00000>okfn
f`03o`000?nn`Mco_/7L00go_/7L00?o0000ooooooooool0L?ooool002Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o0000ojVii?nY^N@02_nY^N@00ol0
003oZKGRojVehP09ojVehP03o`000?nX/]ooZ;;O00CoZ;;O0ol00002oj:`hP03o`000?nT[]ooY:kO
00WoY:kO00?o0000ojF]gOnU[Md02_nU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX[M_oZ:gK
00_oZ:gK00?o0000ojZ^fonZ[]/01?nZ[]/2o`0000Co[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0
003o/kGKok>ef`0:ok>ef`;o00002One^=/2o`0000?o^[_J00?o0000okfnfonm_]/03?nm_]/00ol0
003o_/7Lokk1g00<okk1g0;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007oooo
o`04o`000?ooooooooooo`0000coZ[cW00?o0000ojVii?nY^N@02OnY^N@00ol0003oZKGRojVehP0:
ojVehP03o`000?nX/]ooZ;;O00?o00001_nR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[Mgo
YJgM00[oYJgM00?o0000ojN]g?nW[M`02OnW[M`00ol0003oZ:gKojR]f`0:ojR]f`03o`000?nZ[]_o
ZZkK00;oZZkK0_l00007ojfaf`03o`000?n`/m[o/;?J00[o/;?J00?o0000ok>efonc]M/02onc]M/0
0ol0003o]KSKokFhf`05okFhf`;o00001_nj^mX00ol0003o_KkKokfnf`0;okfnf`03o`000?nn`Mco
_/7L00_o_/7L00?o0000ol?3f_l00000LOooool002Gooooo00Go0000ooooooooooooooooo`000006
ooooo`;o00000oooool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^NCoZKWT00WoZKWT00?o0000
ojVeh_nY]N802?nY]N84o`0000[oX[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09
ojF]g@03o`000?nW[McoYjgL00[oYjgL00?o0000ojR]fonX[M/02_nX[M/01?l0003oZZkKo`000?l0
0009ojfaf`03o`000?n`/m[o/;?J00_o/;?J00?o0000ok>efonc]M/02_nc]M/2o`0000Go]KSK00?o
0000okZkf_nj^mX01_nj^mX00ol0003o_KkKokfnf`0<okfnf`03o`000?nn`Mco_/7L00So_/7L0_l0
0003ol?3fP03o`000?oooooooooo06kooooo000Uooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojVii?nY^N@02OnY
^N@00ol0003oZKGRojVehP04ojVehP?o00000_nQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT
[]ooY:kO00[oY:kO00?o0000ojF]gOnU[Md02OnU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX
[M_oZ:gK00[oZ:gK0_l0000<ojfaf`03o`000?n`/m[o/;?J00_o/;?J00?o0000ok>efonc]M/02Onc
]M/2o`0000?o]KSK0_l0000:okZkfP03o`000?nm_]_o_KkK00co_KkK00?o0000okk1g?nn`M`01Onn
`M`2o`0000Ko`l?J00?o0000ooooooooool0KOooool002Gooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZKWTojVi
i009ojVii003o`000?nY]N;oZKGR00?o00001_nQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT
[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md02_nU[Md00ol0003oYjgLojN]g009ojN]g003o`000?nX
[M_oZ:gK00KoZ:gK0ol000000onY[mco0000ojfaf`0<ojfaf`03o`000?n`/m[o/;?J00[o/;?J00?o
0000ok>efonc]M/02Onc]M/01Ol0003o/kGKo`000?ne^=_o000000go^[_J00?o0000okfnfonm_]/0
2onm_]/00ol0003o_/7Lokk1g004okk1g003o`000?o3`m[o`l?J00Ko`l?J0_l0001^ooooo`009Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oZ[cW
ojZli`0:ojZli`03o`000?nY^NCoZKWT00SoZKWT0ol0000:oj6ci@03o`000?nR/>;oX[3R00WoX[3R
00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09ojF]g@03o`000?nW[McoYjgL00WoYjgL
00?o0000ojR]fonX[M/00onX[M/3o`0000GoZJoL00?o0000ojfafon]/M/02_n]/M/00ol0003o/;?J
ok2cfP0;ok2cfP03o`000?nc]M_o/kGK00So/kGK00Co0000ok>efol0003o00003_nj^mX00ol0003o
_KkKokfnf`0<okfnf`04o`000?nn`Mco_/7Lokk1g0;o00002_o3`mX00ol0003oooooooooo`1/oooo
o`009Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0
003oZ[cWojZli`0:ojZli`03o`000?nY^NCoZKWT00CoZKWT0ol000000onP]^So0000oj6ci@0;oj6c
i@03o`000?nR/>;oX[3R00WoX[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@09ojF]
g@03o`000?nW[McoYjgL00WoYjgL00?o0000ojR]fol000000_l00009ojV_g003o`000?n]/M_o[K7K
00[o[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0003o/kGKok>ef`07ok>ef`;o000000?o]kWJo`00
0?nj^mX03_nj^mX00ol0003o_KkKokfnf`0<okfnf`03o`000?nn`Mco000000go`l?J00?o0000oooo
ooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0003oZ[cWojZli`0:ojZli`03
o`000?nY^NCoZKWT00?o00001OnP]^P00ol0003oXK?Uoj6ci@09oj6ci@03o`000?nR/>;oX[3R00Wo
X[3R00?o0000ojB^gonT[]l02OnT[]l00ol0003oYJgMojF]g@0:ojF]g@03o`000?nW[McoYjgL00Oo
YjgL0ol0000<ojV_g003o`000?n]/M_o[K7K00_o[K7K00?o0000ok2cf_n`/mX02on`/mX00ol0003o
/kGKok>ef`04ok>ef`?o00000ong^MX00ol0003o^[_JokZkfP0=okZkfP03o`000?nm_]_o_KkK00_o
_KkK0_l0000?ol?3fP03o`000?oooooooooo06[ooooo000`ooooo`03o`000?oooooooooo00Sooooo
00?o0000ojZlionZ_>L02?nZ_>L4o`0000WoX;KX00?o0000oj6ciOnQ/nD02OnQ/nD00ol0003oX[3R
oj:`hP09oj:`hP03o`000?nT[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md02OnU[Md00ol0003oYjgL
ojN]g004ojN]g0?o00000_nV[]d00ol0003oZJoLojV_g00;ojV_g003o`000?n]/M_o[K7K00[o[K7K
00?o0000ok2cf_n`/mX02on`/mX00ol0003o/kGKok>ef`02ok>ef`;o00000_ng^MX00ol0003o]kWJ
okNifP02okNifP03o`000?nj^m[o^[_J00go^[_J00?o0000okfnfonm_]/02Onm_]/00ol0003o`L7I
o`00000?ol?3fP03o`000?oooooooooo06[ooooo000_ooooo`;o00002oooool00ol0003oZ[cWojZl
i`04ojZli`?o00000_nO^N/00ol0003oX;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00WoXK?U00?o
0000oj:`h_nR/>802OnR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[MgoYJgM00WoYJgM00?o
0000ojN]g?nW[M`00ol00006ojJ^g@03o`000?nY[mcoZJoL00_oZJoL00?o0000ojfafon]/M/02_n]
/M/00ol0003o/;?Jok2cfP0;ok2cfP04o`000?nc]M_o0000o`0000Co]kWJ00?o0000okNif_ng^MX0
0ong^MX00ol0003o^[_JokZkfP0<okZkfP03o`000?nm_]_o_KkK00Oo_KkK0_l00003ol71f@03o`00
0?o3`m[o`l?J00go`l?J00?o0000ooooooooool0JOooool0033ooooo00?o0000ooooooooool02_oo
ool00ol0003oZ[cWojZli`03o`0000KoWkW[00?o0000oj2fj?nP]^P02OnP]^P00ol0003oXK?Uoj6c
i@09oj6ci@03o`000?nR/>;oX[3R00SoX[3R00?o0000ojB^gonT[]l02_nT[]l00ol0003oYJgMojF]
g@07ojF]g@Co00002_nV[]d00ol0003oZJoLojV_g00:ojV_g003o`000?n]/M_o[K7K00_o[K7K00?o
0000ok2cf_n`/mX02_n`/mX2o`0000Ko]kWJ00?o0000okNif_ng^MX00ong^MX00ol0003o^[_JokZk
fP0=okZkfP03o`000?nm_]_o_KkK00Go_KkK00?o0000ol71fOo1`MT01?o1`MT00ol0003o`l?Jol?3
fP0=ol?3fP03o`000?oooooooooo06Sooooo000_ooooo`03o`000?oooooooooo00cooooo0_l0000:
oinij`03o`000?nP]^SoX;KX00SoX;KX00?o0000oj6ciOnQ/nD02_nQ/nD00ol0003oX[3Roj:`hP08
oj:`hP03o`000?nT[]ooY:kO00WoY:kO00?o0000ojF]gOnU[Md01?nU[Md3o`0000;oXZkO00?o0000
ojJ^gOnV[]d02OnV[]d00ol0003oZJoLojV_g00;ojV_g003o`000?n]/M_o[K7K00[o[K7K00?o0000
ok2cf_n`/mX02?n`/mX2o`000003okBffol0003o]kWJ00Go]kWJ00?o0000okNif_ng^MX01?ng^MX0
0ol0003o^[_JokZkfP0=okZkfP03o`000?nm_]_o_KkK00?o_KkK00?o0000ol71fOo1`MT01_o1`MT0
0ol0003o`l?Jol?3fP0=ol?3fP03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo
00gooooo00?o0000oinijonO^N/02OnO^N/00ol0003oX;KXoj2fj008oj2fj003o`000?nQ/nGoXK?U
00WoXK?U00?o0000oj:`h_nR/>802OnR/>800ol0003oY:kOojB^g`09ojB^g`03o`000?nU[MgoYJgM
00?o00001_nR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00_oZJoL00?o0000ojfa
fon]/M/02_n]/M/00ol0003o/;?Jok2cfP06ok2cfP03o`000?nd]]_o];KK00;o];KK00?o0000okNi
f_ng^MX00ong^MX00ol0003o]kWJokNifP05okNifP03o`000?nj^m[o^[_J00co^[_J00Co0000okfn
fonm_]_o_KkK0_l0000:ol71f@03o`000?o3`m[o`l?J00co`l?J00?o0000ooooooooool0Ioooool0
02oooooo00?o0000ooooooooool03_ooool00ol0003oWkW[oinij`09oinij`03o`000?nP]^SoX;KX
00SoX;KX00?o0000oj6ciOnQ/nD02OnQ/nD00ol0003oX[3Roj:`hP09oj:`hP03o`000?nT[]ooY:kO
00OoY:kO1?l0000:oj:^g`03o`000?nV[]goYZkM00WoYZkM00?o0000ojV_g?nY[m`02_nY[m`00ol0
003o[K7Kojfaf`0;ojfaf`03o`000?n`/m[o/;?J00?o/;?J0_l00006okBff`03o`000?ng^M[o]kWJ
00;o]kWJ00?o0000okNif_ng^MX01_ng^MX00ol0003o^[_JokZkfP0<okZkfP03o`000?nm_]_o0000
00co`L7I00?o0000ol?3f_o3`mX03Oo3`mX00ol0003oooooooooo`1Vooooo`00;oooool00ol0003o
ooooooooo`0?ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2fj?nP]^P02OnP]^P00ol0003o
XK?Uoj6ci@09oj6ci@03o`000?nR/>;oX[3R00SoX[3R00?o0000ojB^gonT[]l01?nT[]l3o`0000;o
WjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@0:ojJ^g@03o`000?nY[mcoZJoL00[o
ZJoL00?o0000ojfafon]/M/02_n]/M/01?l0003o/;?Jok2cf_n`/mX2o`0000So];KK00?o0000okNi
f_ng^MX00_ng^MX00ol0003o]kWJokNifP06okNifP03o`000?nj^m[o^[_J00co^[_J0_l0000>ol71
f@03o`000?o3`m[o`l?J00co`l?J0_l0001Wooooo`00;_ooool3o`00017ooooo00?o0000oinijonO
^N/02?nO^N/00ol0003oX;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00WoXK?U00?o0000oj:`h_nR
/>802?nR/>800ol0003oY:kOojB^g`03o`0000KoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003o
YZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00[oZJoL00?o0000ojfafon]/M/02on]/M/00ol0003o
/;?Jo`00000;okBff`05o`000?ng^M[o]kWJokNif_l000002Ong^MX00ol0003o^[_JokZkfP0:okZk
fP03o`000?no_]Wo000000oo`L7I00?o0000ol?3f_o3`mX02_o3`mX01?l0003oa/CHo`000?l0001V
ooooo`00;oooool00ol0003oooooooooo`0Aooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2f
j?nP]^P02OnP]^P00ol0003oXK?Uoj6ci@08oj6ci@03o`000?nR/>;oX[3R00SoX[3R0ol0000:oin^
hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOnV[]d02OnV[]d00ol0003oZJoLojV_g00:ojV_
g003o`000?n]/M_o[K7K00[o[K7K0_l0000=okBff`04o`000?ng^M[o]kWJo`0000[o]kWJ00?o0000
okZkf_nj^mX01onj^mX2o`0000?o_kkI00?o0000ol71fOo1`MT03Oo1`MT00ol0003o`l?Jol?3fP07
ol?3fP;o00000oo6a=P00ol0003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Boooo
o`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2fj?nP]^P02?nP]^P00ol0003oXK?Uoj6ci@09oj6c
i@03o`000?nR/>;oX[3R00CoX[3R0ol000000onK[nGo0000oin^hP0:oin^hP03o`000?nR[]ooXZkO
00WoXZkO00?o0000ojJ^gOnV[]d02_nV[]d00ol0003oZJoLojV_g00:ojV_g003o`000?n]/M_o[K7K
00Ko[K7K0ol000000on_]=co0000okBff`0<okBff`04o`000?ng^M[o]kWJo`0000_o]kWJ00?o0000
okZkf_nj^mX01Onj^mX00ol0003o_kkIoknnf@04oknnf@03o`000?o1`MWo`L7I00co`L7I00?o0000
ol?3f_o3`mX01_o3`mX00ol0003oa/CHolK4f004olK4f003o`000?oooooooooo06?ooooo000_oooo
o`03o`000?oooooooooo01?ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oX;KXoj2fj008oj2f
j003o`000?nQ/nGoXK?U00WoXK?U00?o0000oj:`h_nR/>800ol00005oi^_i@03o`000?nO[^;oWjkR
00WoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL
00[oZJoL00?o0000ojfafon]/M/00on]/M/3o`0000Go[kCL00?o0000okBffond]]/02ond]]/00ol0
003o]kWJo`00000;okNifP03o`000?nj^m[o^[_J00Co^[_J00?o0000oknnfOno_]T01_no_]T00ol0
003o`L7Iol71f@0<ol71f@03o`000?o3`m[o`l?J00Co`l?J00?o0000olK4f?o6a=P01_o6a=P00ol0
003oooooooooo`1Rooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o00002OnO^N/00ol0003o
X;KXoj2fj009oj2fj003o`000?nQ/nGoXK?U00OoXK?U1?l00009oi^_i@03o`000?nO[^;oWjkR00Wo
WjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@09ojJ^g@03o`000?nY[mcoZJoL00[o
ZJoL00?o0000ojfafol000000_l00009ojndg003o`000?nd]]_o];KK00_o];KK0_l0000<okNifP04
o`000?nj^m[o^[_JokZkfP;o00002Ono_]T00ol0003o`L7Iol71f@0=ol71f@04o`000?o3`m[o`l?J
ol?3fP;o00002Oo6a=P2o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l00009oini
j`03o`000?nP]^SoX;KX00WoX;KX00Co0000oj6ciOnQ/nGoXK?U1Ol00002oiR`j003o`000?nK[nGo
VjoU00SoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]go
YZkM00[oYZkM00?o0000ojV_g?nY[m`02OnY[m`2o`0000co[kCL00?o0000okBffond]]/02ond]]/2
o`0000go]kWJ00?o0000okZkf_l000003?no_]T00ol0003o`L7Iol71f@0=ol71f@03o`000?o3`m[o
000000coa/CH00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00002OnO^N/00ol0
003oX;KXoj2fj007oj2fj0Go00002?nH/>P00ol0003oVjoUoi^_i@08oi^_i@03o`000?nO[^;oWjkR
00WoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^g@0:ojJ^g@03o`000?nY[mcoZJoL
00GoZJoL0ol000000on[/]go0000ojndg00<ojndg003o`000?nd]]_o];KK00_o];KK00?o0000okNi
f_ng^MX02ong^MX2o`0000ko_kkI00?o0000ol71fOo1`MT03?o1`MT2o`0000koa/CH00?o0000oooo
ooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000WoWkW[00Co0000oj2fj?nP
]^SoX;KX1Ol00002oiJbj`03o`000?nH/>SoV;3X00WoV;3X00?o0000oi^_iOnK[nD02?nK[nD00ol0
003oWjkRoin^hP09oin^hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOnV[]d02OnV[]d00ol0
003oZJoLojV_g003ojV_g0;o00001On[/]d00ol0003o[kCLojndg00;ojndg003o`000?nd]]_o];KK
00[o];KK00?o0000okNif_ng^MX02Ong^MX2o`000003ok^lf_l0003o_kkI00ko_kkI00?o0000ol71
fOo1`MT02_o1`MT00ol0003oaL?Ho`00000?olK4f003o`000?oooooooooo05oooooo000Booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo
01Sooooo0_l00005oinij`Oo00002?nF/^/00ol0003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU
00SoVjoU00?o0000oin^h_nO[^802?nO[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]goYZkM
00[oYZkM00?o0000ojV_g?l000000_l00008oj^bg@03o`000?n_]=co[kCL00[o[kCL00?o0000okBf
fond]]/02_nd]]/2o`0000So]kWJ0_l00004ok^lfP03o`000?no_]Wo_kkI00co_kkI00?o0000ol71
fOo1`MT02Oo1`MT01Ol0003oaL?HolG3f?o5`mSo000000ooa/CH00?o0000ooooooooool0G_ooool0
01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?o0000ooooooooool06Oooool6o`0000CoTkG^00?o0000oiJbjonF/^/02OnF
/^/00ol0003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802OnO
[^800ol0003oXZkOoj:^g`09oj:^g`03o`000?nV[]goYZkM00WoYZkM0_l0000;oj^bg@03o`000?n_
]=co[kCL00_o[kCL00?o0000okBffond]]/02Ond]]/00ol0003o];KKo`000006okNifP03o`000?nk
_=[o^kcJ00Go^kcJ00?o0000oknnfOno_]T03?no_]T00ol0003o`L7Iol71f@07ol71f@03o`000?o5
`mSoaL?H00?oaL?H00?o0000olK4f?o6a=P03?o6a=P00ol0003oooooooooo`1Nooooo`004_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02OnF/^/00ol0003oV;3XoiR`
j008oiR`j003o`000?nK[nGoVjoU00SoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^
g`09oj:^g`03o`000?nV[]goYZkM00GoYZkM0ol000000onU/=oo0000oj^bg@0;oj^bg@03o`000?n_
]=co[kCL00_o[kCL00?o0000okBffond]]/02?nd]]/00ol0003o];KKo`000004okNifP;o00002?nk
_=X00ol0003o_kkIoknnf@0=oknnf@03o`000?o1`MWo`L7I00Co`L7I0_l00007olG3f003o`000?o6
a=Soa/CH00coa/CH00?o0000ooooooooool0GOooool001;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003oTkG^oi>e
kP07oi>ekP03o`000?nF/^_oU[;[00WoU[;[00?o0000oiR`j?nH/>P02?nH/>P00ol0003oVjoUoi^_
i@08oi^_i@03o`000?nO[^;oWjkR00SoWjkR00?o0000oj:^gonR[]l02OnR[]l00ol0003oYZkMojJ^
g@03ojJ^g@;o00001OnU/=l00ol0003oZk;Moj^bg@0:oj^bg@03o`000?n_]=co[kCL00_o[kCL00?o
0000okBffond]]/01ond]]/01Ol0003o];KKokBffol0003o]kWJ00;o00002onk_=X00ol0003o_kkI
oknnf@0<oknnf@03o`000?o1`MWo`L7I00?o`L7I00?o0000olG3f?o5`mP01oo5`mP00ol0003oa/CH
olK4f00=olK4f003o`000?oooooooooo05cooooo000Booooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000oi>ek_nC]Nh0
1onC]Nh00ol0003oU[;[oiJbj`08oiJbj`03o`000?nH/>SoV;3X00WoV;3X00?o0000oi^_iOnK[nD0
1onK[nD00ol0003oWjkRoin^hP09oin^hP03o`000?nR[]ooXZkO00WoXZkO00?o0000ojJ^gOl00000
0_l00008ojF`g`03o`000?n[/]goZk;M00[oZk;M00?o0000ojndg?n_]=`02_n_]=`00ol0003o];KK
okBff`07okBff`03o`000?nd]]_o];KK00;o00003_nk_=X00ol0003o_kkIoknnf@0<oknnf@05o`00
0?o1`MWo`L7Iol71fOl000002oo5`mP00ol0003oa/CHolK4f00<olK4f0;o0000GOooool001;ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03
o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02?nF/^/00ol0003oV;3XoiR`j009oiR`j003
o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802OnO[^800ol0003oXZkOoj:^g`07oj:^g`?o
00002onU/=l00ol0003oZk;Moj^bg@0:oj^bg@03o`000?n_]=co[kCL00_o[kCL00?o0000okBffond
]]/01_nd]]/3o`000003okNjfol0003o^kcJ00go^kcJ00?o0000oknnfOno_]T03Ono_]T00ol0003o
`L7Io`00000=olG3f003o`000?o6a=Soa/CH00[oa/CH00?o0000olS5f?l00000GOooool001;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0
003oooooooooo`0Oooooo`03o`000?nC]NkoTkG^00OoTkG^00?o0000oiJbjonF/^/02?nF/^/00ol0
003oV;3XoiR`j009oiR`j003o`000?nK[nGoVjoU00OoVjoU00?o0000oin^h_nO[^802?nO[^800ol0
003oXZkOoj:^g`04oj:^g`?o00000_nP[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M
00[oZk;M00?o0000ojndg?n_]=`02on_]=`00ol0003o];KKokBff`04okBff`;o00001?ng^]/00ol0
003o^kcJok^lfP0<ok^lfP03o`000?no_]Wo_kkI00co_kkI0_l0000>olG3f003o`000?o6a=Soa/CH
00Woa/CH00Go0000olS5f?o8aMSob<GHo`00001Looooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo023ooooo00?o
0000oi>ek_nC]Nh01onC]Nh00ol0003oU[;[oiJbj`08oiJbj`03o`000?nH/>SoV;3X00SoV;3X00?o
0000oi^_iOnK[nD02?nK[nD00ol0003oWjkRoin^hP08oin^hP03o`000?nR[]ooXZkO00?o00001_nP
[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M00[oZk;M00?o0000ojndg?n_]=`02_n_
]=`00ol0003o];KKokBff`02okBff`;o000000?o]k[Ko`000?ng^]/01?ng^]/00ol0003o^kcJok^l
fP0<ok^lfP03o`000?no_]Wo_kkI00[o_kkI00?o0000ol;1fOl000003oo5`mP00ol0003oa/CHolK4
f007olK4f003o`000?o8aMSob<GH00?ob<GH00?o0000ooooooooool0FOooool002gooooo00?o0000
ooooooooool08Oooool00ol0003oTkG^oi>ekP07oi>ekP03o`000?nF/^_oU[;[00SoU[;[00?o0000
oiR`j?nH/>P02?nH/>P00ol0003oVjoUoi^_i@07oi^_i@03o`000?nO[^;oWjkR00OoWjkR1?l0000:
oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02On[/]d00ol0003o[kCLojndg00;
ojndg004o`000?nd]]_o0000o`0000?o]k[K00?o0000okNjfong^]/01?ng^]/00ol0003o^kcJok^l
fP0;ok^lfP03o`000?no_]Wo_kkI00So_kkI0_l00003ol;1f@03o`000?o5`mSoaL?H00goaL?H00?o
0000olK4f?o6a=P01?o6a=P2o`0000Oob<GH00?o0000ooooooooool0F?ooool002gooooo00?o0000
ooooooooool08Oooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_oU[;[00OoU[;[00?o0000
oiR`j?nH/>P02OnH/>P00ol0003oVjoUoi^_i@07oi^_i@04o`000?nO[^;oWjkRoin^hPGo00000_nJ
[^D00ol0003oX:oRoj2_hP0:oj2_hP03o`000?nU/=ooYK3O00WoYK3O00?o0000oj^bgOn[/]d02_n[
/]d00ol0003o[kCLojndg00:ojndg0;o00001Ong^]/00ol0003o]k[KokNjf`04okNjf`03o`000?nk
_=[o^kcJ00co^kcJ00?o0000oknnfOno_]T01Ono_]T2o`0000Ko`/7I00?o0000olG3f?o5`mP03Oo5
`mP00ol0003oa/CHolK4f002olK4f003o`000?o8aMSob<GH00Oob<GH00?o0000ooooooooool0F?oo
ool002gooooo00?o0000ooooooooool08_ooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_o
U[;[00OoU[;[00?o0000oiR`j?nH/>P02OnH/>P00ol0003oVjoUoi^_i@03oi^_i@Oo00002?nJ[^D0
0ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02_n[/]d0
0ol0003o[kCLojndg007ojndg0;o000000?o/[OMo`000?ng^]/01?ng^]/00ol0003o]k[KokNjf`05
okNjf`03o`000?nk_=[o^kcJ00co^kcJ00?o0000oknnfOno_]T00ono_]T00ol0003o`/7Iol;1f@07
ol;1f@03o`000?o5`mSoaL?H00coaL?H00Go0000olK4f?o6a=Soa/CHo`00000;olS5f003o`000?oo
oooooooo05Oooooo000/ooooo`?o00009?ooool00ol0003oTkG^oi>ekP08oi>ekP03o`000?nF/^_o
U[;[00OoU[;[00?o0000oiR`j?nH/>P01onH/>P7o`0000CoU:gX00?o0000oiZ^iOnJ[^D02OnJ[^D0
0ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[/]d02_n[/]d0
0ol0003o[kCLojndg004ojndg0;o00001?nb]md00ol0003o]k[KokNjf`02okNjf`03o`000?ng^]_o
]k[K00Ko]k[K00?o0000ok^lf_nk_=X02onk_=X01?l0003o_kkIoknnfOno_]T2o`0000[o`/7I00?o
0000olG3f?o5`mP03Oo5`mP00ol0003oa/CHo`00000=olS5f003o`000?oooooooooo05Kooooo000]
ooooo`03o`000?oooooooooo02Cooooo00?o0000oi>ek_nC]Nh02?nC]Nh00ol0003oU[;[oiJbj`07
oiJbj`04o`000?nH/>SoV;3XoiR`j0Go00000_n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ
[^GoVZkU00WoVZkU00?o0000oj2_h_nP[n802OnP[n800ol0003oYK3OojF`g`09ojF`g`03o`000?n[
/]goZk;M00[oZk;M00?o0000ojndg?n_]=`00_n_]=`2o`0000Oo/[OM00Go0000okNjfong^]_o]k[K
o`000009okNjf`03o`000?nk_=[o^kcJ00_o^kcJ00?o0000oknnfOl000003Oo2`MT00ol0003oaL?H
olG3f00<olG3f0;o00003oo8aMP00ol0003oooooooooo`1Eooooo`00;Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?nC]NkoTkG^00SoTkG^00?o0000oiJbjonF/^/00onF/^/7o`0000SoSjg[00?o
0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^i@03o`000?nP[n;oX:oR00[oX:oR00?o
0000ojF`gonU/=l02OnU/=l00ol0003oZk;Moj^bg@0:oj^bg@04o`000?n_]=co0000o`0000Wo/[OM
00Go0000okNjfong^]_o]k[Ko`000009okNjf`03o`000?nk_=[o^kcJ00_o^kcJ0_l0000?ol;1f@03
o`000?o5`mSoaL?H00[oaL?H00?o0000olO5f?l000003oo8aMP2o`0005Kooooo000]ooooo`03o`00
0?oooooooooo02Kooooo00?o0000oi>ek_nC]Nh00onC]Nh:o`0000CoRZk^00?o0000ohn]jon?[N/0
2On?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ[^GoVZkU00SoVZkU00?o0000oj2_h_nP[n80
2OnP[n800ol0003oYK3OojF`g`0:ojF`g`03o`000?n[/]goZk;M00WoZk;M0_l0000<ok:gg@04o`00
0?ng^]_o]k[Ko`0000[o]k[K00?o0000ok^lf_nk_=X02?nk_=X2o`000003okjof_l0003o`/7I00ko
`/7I00?o0000olG3f?o5`mP02Oo5`mP01Ol0003oalGHolO5f?o7aMSo000000oob<GH00?o0000oooo
ooooool0E?ooool002cooooo00?o0000ooooooooool0:?ooool5o`0000GoQk3`00?o0000ohZ^k_n:
[^h01on:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000oiZ^iOnJ
[^D02?nJ[^D00ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00[oYK3O00?o0000oj^bgOn[
/]d01On[/]d3o`000003ojbegol0003o/[OM00co/[OM00?o0000okNjfol000002ong^]/00ol0003o
^kcJok^lfP06ok^lfP03o`000?nn_m[o_[oJ00;o_[oJ00?o0000ol;1fOo2`MT03Oo2`MT00ol0003o
aL?HolG3f007olG3f003o`000?o7aMSoalGH00?oalGH00?o0000olS5f?o8aMP03Oo8aMP00ol0003o
ooooooooo`1Cooooo`00;?ooool00ol0003oooooooooo`0Yooooo`03o`000?n7/?3oQk3`00OoQk3`
00?o0000ohZ^k_n:[^h01on:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00KoU:gX
00?o0000oiZ^iOnJ[^D02OnJ[^D00ol0003oX:oRoj2_hP09oj2_hP03o`000?nU/=ooYK3O00WoYK3O
00?o0000oj^bgOn[/]d00on[/]d2o`0000Go[;GO00?o0000ok:ggOnb]md02_nb]md00ol0003o]k[K
o`00000;okNjf`03o`000?nk_=[o^kcJ00Co^kcJ0_l00006okjofP03o`000?o2`MWo`/7I00go`/7I
00?o0000olG3f?o5`mP01?o5`mP2o`0000OoalGH00?o0000olS5f?o8aMP03Oo8aMP00ol0003ooooo
ooooo`1Booooo`00;?ooool2o`0002_ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^
kP07ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^
i@08oiZ^i@03o`000?nP[n;oX:oR00[oX:oR00?o0000ojF`gonU/=l02OnU/=l00ol0003oZk;Mo`00
0002o`0000So[;GO00?o0000ok:ggOnb]md02_nb]md2o`0000co]k[K00Co0000ok^lf_nk_=[o^kcJ
0_l00009okjofP03o`000?o2`MWo`/7I00go`/7I00?o0000olG3f?o5`mP00_o5`mP00ol0003oalGH
olO5f007olO5f003o`000?o8aMSob<GH00gob<GH0_l0001Cooooo`00;?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohZ^k_n:[^h01on:[^h00ol0003oSjg[ohn]
j`08ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000oiZ^iOnJ[^D02?nJ[^D00ol0003oX:oRoj2_
hP09oj2_hP03o`000?nU/=ooYK3O00SoYK3O0ol0000<ojbeg`03o`000?nb]mgo/[OM00[o/[OM00?o
0000okNjfong^]/02ong^]/00ol0003o^kcJo`00000<okjofP03o`000?o2`MWo`/7I00co`/7I00Go
0000olG3f?o5`mSoaL?Ho`00000;olO5f003o`000?o8aMSob<GH00_ob<GH00?o0000olW7f?l00000
Doooool002cooooo00?o0000ooooooooool0;?ooool00ol0003oQk3`ohN`l007ohN`l003o`000?n:
[^koRZk^00OoRZk^00?o0000ohn]jon?[N/02?n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ
[^GoVZkU00SoVZkU00?o0000oj2_h_nP[n802OnP[n800ol0003oYK3OojF`g`04ojF`g`?o00000_nU
/^800ol0003o[;GOojbeg`0:ojbeg`03o`000?nb]mgo/[OM00[o/[OM0_l0000<okNjf`;o00003Onn
_mX00ol0003o`/7Iol;1f@0=ol;1f@03o`000?o5`mSo000000goalGH00?o0000olS5f?o8aMP02Oo8
aMP01Ol0003obLOHolW7f?o9amSo000005;ooooo000/ooooo`03o`000?oooooooooo02gooooo00?o
0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^kP07ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o
0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^i@03o`000?nP[n;oX:oR00WoX:oR00?o
0000ojF`gonU/=l00ol00006ojFbhP03o`000?n/]Moo[;GO00[o[;GO00?o0000ok:ggOnb]md02Onb
]md2o`0000[o]k[K0_l000000onj_Mco0000okjofP0=okjofP03o`000?o2`MWo`/7I00co`/7I0_l0
000?olO5f003o`000?o8aMSob<GH00Oob<GH00?o0000olW7f?o9amP00oo9amP00ol0003ooooooooo
o`1?ooooo`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000
ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`09ohn]j`03o`000?nD[NSoU:gX00KoU:gX00?o0000
oiZ^iOnJ[^D02?nJ[^D00ol0003oX:oRoj2_hP08oj2_hPCo00002_nU/^800ol0003o[;GOojbeg`0:
ojbeg`03o`000?nb]mgo/[OM00So/[OM00?o0000ok:ggOl000002?ng^]/00ol0003o^[gLokZmg002
okZmg003o`000?nn_m[o_[oJ00co_[oJ00?o0000ol;1fOo2`MT02_o2`MT00ol0003oa<CIo`00000@
olO5f003o`000?o8aMSob<GH00Cob<GH0_l00006olW7f0;o0000D?ooool002cooooo00?o0000oooo
ooooool0;oooool00ol0003oQk3`ohN`l007ohN`l003o`000?n:[^koRZk^00KoRZk^00?o0000ohn]
jon?[N/02?n?[N/00ol0003oU:gXoiB]j007oiB]j003o`000?nJ[^GoVZkU00SoVZkU00?o0000oj2_
h_nP[n801?nP[n83o`0000;oWK3U00?o0000ojFbh_nU/^802_nU/^800ol0003o[;GOojbeg`0:ojbe
g`03o`000?nb]mgo/[OM00Oo/[OM00Co0000ok:ggOnb]mgo00001Ong^]/2o`0000Ko^[gL00?o0000
okjof_nn_mX03?nn_mX00ol0003o`/7Iol;1f@07ol;1f@;o00000oo4a=T00ol0003oalGHolO5f00=
olO5f003o`000?o8aMSob<GH00?ob<GH00?o0000olW7f?o9amP01oo9amP00ol0003oooooooooo`1>
ooooo`00;?ooool2o`00037ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^kP06ohZ^
kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP01onD[NP00ol0003oVZkUoiZ^i@08oiZ^
i@03o`000?nP[n;oX:oR00?o00001_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO
00[o[;GO00?o0000ok:ggOnb]md01onb]md01?l0003o/[OMok:ggOl00003okNjf`;o00002Onj_M`0
0ol0003o_[oJokjofP0;okjofP03o`000?o2`MWo`/7I00Ko`/7I00?o0000olC4fOo4a=T01?o4a=T0
0ol0003oalGHolO5f00=olO5f005o`000?o8aMSob<GHolS5f?l000002oo9amP00ol0003ooooooooo
o`1=ooooo`00:oooool00ol0003oooooooooo`0booooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000
ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`08ohn]j`03o`000?nD[NSoU:gX00OoU:gX00?o0000
oiZ^iOnJ[^D00onJ[^D7o`0000[oWK3U00?o0000ojFbh_nU/^802OnU/^800ol0003o[;GOojbeg`0:
ojbeg`03o`000?nb]mgo/[OM00Ko/[OM00Oo0000ok:ggOnb]mgo/[OMo`000?ng^]_o000000co^[gL
00?o0000okjof_nn_mX02onn_mX00ol0003o`/7Iol;1f@04ol;1f@03o`000?o4a=Woa<CI00Koa<CI
00?o0000olO5f?o7aMP03Oo7aMP00ol0003ob<GHo`00000=olW7f003o`000?oooooooooo04cooooo
000[ooooo`03o`000?oooooooooo03?ooooo00?o0000ohN`l?n7/?001on7/?000ol0003oRZk^ohZ^
kP06ohZ^kP03o`000?n?[N_oSjg[00SoSjg[00?o0000oiB]j?nD[NP00onD[NP9o`0000GoUZkX00?o
0000oif`iOnM/>D02_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00[o[;GO00?o
0000ok:ggOnb]md01Onb]md01?l0003o/[OMok:ggOnb]md2o`0000go^[gL00?o0000okjof_nn_mX0
3?nn_mX01?l0003o`/7Iol;1fOo2`MT2o`0000Woa<CI00?o0000olO5f?o7aMP03Oo7aMP2o`0000ko
bLOH0_l0001=ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?n7/?3oQk3`00Oo
Qk3`00?o0000ohZ^k_n:[^h01_n:[^h00ol0003oSjg[ohn]j`03ohn]j`[o00001?n>[>/00ol0003o
UZkXoiJ^j008oiJ^j003o`000?nM/>GoWK3U00WoWK3U00?o0000ojFbh_nU/^802_nU/^800ol0003o
[;GOojbeg`09ojbeg`03o`000?nb]mgo/[OM00Go/[OM1?l000000ond^moo0000okZmg00=okZmg003
o`000?nn_m[o_[oJ00co_[oJ00?o0000ol;1fOl000003?o4a=T00ol0003oalGHolO5f00;olO5f003
o`000?o8amWo000000oobLOH0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003o
Qk3`ohN`l003ohN`l1;o00001On6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00So
UZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00[o
[;GO00?o0000ok:ggOnb]md00onb]md2o`0000Go];_O00?o0000okZmg?nj_M`03?nj_M`00ol0003o
_[oJokjofP0;okjofP;o00003_o4a=T00ol0003oalGHolO5f009olO5f005o`000?o8amWob<OIolS7
fOl000003oo9amP00ol0003oooooooooo`1:ooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo1Ol00004og^[lP03o`000?moZo3oOj_`
00KoOj_`00?o0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX
00SoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO
00[o[;GO00?o0000ok:ggOl000000_l000000ond^moo0000okBkg`05okBkg`03o`000?nj_Mco^[gL
00co^[gL00?o0000okjof_nn_mX02?nn_mX2o`000003ol73fol0003oa<CI00koa<CI00?o0000olO5
f?o7aMP01oo7aMP00ol0003ob<OIolS7f@03olS7f@03o`000?o9amSobLOH00gobLOH00?o0000oooo
ooooool0BOooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0=oooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3o
Oj_`00KoOj_`00?o0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^So
UZkX00OoUZkX00?o0000oif`iOnM/>D02_nM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo
[;GO00Wo[;GO0_l00004okBkg`03o`000?nd^moo];_O00Go];_O00?o0000okZmg?nj_M`02onj_M`0
0ol0003o_[oJokjofP07okjofP03o`000?o1`m_o`L?K00;o`L?K00?o0000olC4fOo4a=T03Oo4a=T0
0ol0003oalGHolO5f004olO5f0;o00001oo8amT00ol0003obLOHolW7f00<olW7f0;o0000B_ooool0
013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool0>?ooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`00KoOj_`00?o
0000ohJ[kOn6Znd02?n6Znd00ol0003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00OoUZkX00?o
0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP09ojFbhP03o`000?n/]Moo[;GO00Ko[;GO0ol0
00000on]^N;o0000okBkg`03okBkg`03o`000?nd^moo];_O00Ko];_O00?o0000okZmg?nj_M`02onj
_M`00ol0003o_[oJokjofP04okjofP;o00001_o1`m/00ol0003oa<CIolC4f@0<olC4f@03o`000?o7
aMSoalGH00?oalGH00?o0000olS7fOo8amT01oo8amT00ol0003obLOHolW7f00=olW7f0;o0000BOoo
ool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0
000kooooo`03o`000?mkZo;oNj_b00KoNj_b00?o0000ogn[l?moZo001_moZo000ol0003oQZ_]ohJ[
k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000oiJ^j?nF[^P02?nF[^P00ol0003oWK3Uoif`
i@09oif`i@03o`000?nU/^;oYK;R00WoYK;R00?o0000ojbegon/]Ml00on/]Ml2o`0000Go[KWR00Go
0000okBkgond^moo];_Oo`000008okBkg`03o`000?nj_Mco^[gL00co^[gL00Co0000okjof_nn_m[o
_[oJ0_l00009ol73f`03o`000?o4a=Woa<CI00coa<CI00Go0000olO5f?o7aMSoalGHo`00000;olS7
f@03o`000?o9amSobLOH00_obLOH00?o0000olW7fOl00000BOooool0013ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0>_ooool00ol0
003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`00KoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0
003oSZc[ohj/j`07ohj/j`03o`000?nF[^SoUZkX00SoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0
003oYK;RojFbhP09ojFbhP03o`000?n/]Moo000000;o00002?n]^N801?l0003o];_OokBkgol00009
okBkg`03o`000?nj_Mco^[gL00co^[gL00?o0000okjof_l000002oo1`m/00ol0003oa<CIolC4f@0=
olC4f@03o`000?o7aMSo000000gob<OI00?o0000olW7f?o9amP02Oo9amP01Ol0003obLOIolW7fOo9
amWo000004Sooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000oooo
o`05ooooo`03o`000?oooooooooo03cooooo00?o0000og^[l_mkZo801_mkZo800ol0003oOj_`ogn[
l006ogn[l003o`000?n6ZngoQZ_]00OoQZ_]00?o0000ohj/jon>[>/01on>[>/00ol0003oUZkXoiJ^
j007oiJ^j003o`000?nM/>GoWK3U00WoWK3U00?o0000ojFbh_nU/^802?nU/^83o`0000co[KWR00?o
0000okBkgol000002_nd^ml00ol0003o^[gLokZmg00;okZmg0;o00003Oo1`m/00ol0003oa<CIolC4
f@0<olC4f@;o00003oo8amT00ol0003obLOHolW7f007olW7f003o`000?o9amWobLOI00;obLOI0_l0
0017ooooo`00:_ooool00ol0003oooooooooo`0mooooo`03o`000?mkZo;oNj_b00KoNj_b00?o0000
ogn[l?moZo001_moZo000ol0003oQZ_]ohJ[k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000
oiJ^j?nF[^P01onF[^P00ol0003oWK3Uoif`i@09oif`i@03o`000?nU/^;oYK;R00CoYK;R0ol00002
ojFfi@03o`000?n]^N;o[KWR00[o[KWR00?o0000okBkgol000002ond^ml00ol0003o^[gLokZmg008
okZmg0;o000000?o_<7No`000?o1`m/03Oo1`m/00ol0003oa<CIolC4f@0:olC4f@03o`000?o6am_o
0000013ob<OI00?o0000olW7f?o9amP01?o9amP2o`0000KobLOI00?o0000ooooooooool0AOooool0
02[ooooo00?o0000ooooooooool0?_ooool00ol0003oNj_bog^[lP06og^[lP03o`000?moZo3oOj_`
00GoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0003oSZc[ohj/j`08ohj/j`03o`000?nF[^SoUZkX
00OoUZkX00?o0000oif`iOnM/>D02OnM/>D00ol0003oYK;RojFbhP03o`0000KoYKKU00?o0000ojfi
h_n]^N802_n]^N82o`0000_o];_O00?o0000okZmg?nj_M`01onj_M`00ol0003o_<7Nokc1gP02okc1
gP03o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOo4a=T01oo4a=T2o`0000?oa/OK00?o0000olS7
fOo8amT03Oo8amT00ol0003obLOHolW7f003olW7f003o`000?o9amWobLOI00OobLOI00?o0000oooo
ooooool0A?ooool002[ooooo00?o0000ooooooooool0?oooool00ol0003oNj_bog^[lP06og^[lP03
o`000?moZo3oOj_`00GoOj_`00?o0000ohJ[kOn6Znd01on6Znd00ol0003oSZc[ohj/j`07ohj/j`03
o`000?nF[^SoUZkX00OoUZkX00?o0000oif`iOnM/>D02?nM/>D4o`0000[oYKKU00?o0000ojfih_n]
^N802_n]^N800ol0003o];_OokBkg`0:okBkg`03o`000?nj_Mco^[gL00Co^[gL0_l00006okc1gP03
o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOo4a=T01Oo4a=T00ol0003oa/OKolK7f`04olK7f`03
o`000?o8amWob<OI00gob<OI00Go0000olW7f?o9amSobLOHo`00000;olW7f@03o`000?oooooooooo
04?ooooo000Yooooo`?o0000@?ooool2o`0000SoNj_b00?o0000ogn[l?moZo001OmoZo000ol0003o
QZ_]ohJ[k@07ohJ[k@03o`000?n>[>_oSZc[00OoSZc[00?o0000oiJ^j?nF[^P01onF[^P00ol0003o
WK3Uoif`i@04oif`i@?o00000_nK/nP00ol0003oYKKUojFfi@0:ojFfi@03o`000?n]^N;o[KWR00Wo
[KWR0_l0000<okBkg`04o`000?nj_Mco^[gLokZmg0;o00002Onl`Mh00ol0003o`L?Kol73f`0;ol73
f`03o`000?o4a=Woa<CI00Coa<CI00?o0000olK7foo6am/01_o6am/00ol0003ob<OIolS7f@0=olS7
f@03o`000?o9amSo000000cobLOI0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o
00002?mkZo800ol0003oOj_`ogn[l005ogn[l003o`000?n6ZngoQZ_]00KoQZ_]00?o0000ohj/jon>
[>/02?n>[>/00ol0003oUZkXoiJ^j007oiJ^j003o`000?nM/>GoWK3U00?o00001_nK/nP00ol0003o
YKKUojFfi@09ojFfi@03o`000?n]^N;o[KWR00Wo[KWR0_l0000=okBkg`03o`000?nj_Mco000000_o
_<7N00?o0000ol73foo1`m/03?o1`m/01?l0003oa<CIolC4fOo4a=T2o`0000[oa/OK00?o0000olS7
fOo8amT03?o8amT2o`0000kobLOI00?o0000ooooooooool0@_ooool002[ooooo00?o0000oooooooo
ool0@Oooool2o`0000SoNj_b00?o0000ogn[l?moZo001OmoZo000ol0003oQZ_]ohJ[k@06ohJ[k@03
o`000?n>[>_oSZc[00SoSZc[00?o0000oiJ^j?nF[^P00onF[^P6o`0000[oVk?X00?o0000ojFfiOnU
]^D02OnU]^D00ol0003o[KWRojfihP08ojfihP03o`000?n]^N;o000000co];_O0_l0000=okc1gP03
o`000?o1`m_o`L?K00co`L?K00?o0000olC4fOl000003Oo6am/00ol0003ob<OIolS7f@0:olS7f@03
o`000?o8b=[o000000oobLOI00?o0000ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0
@_ooool@o`0000;oOj_`00?o0000ohJ[kOn6Znd01_n6Znd00ol0003oSZc[ohj/j`03ohj/j`[o0000
1?nA/>/00ol0003oVk?Xoi^cj00:oi^cj003o`000?nU]^GoYKKU00WoYKKU00?o0000ojfih_n]^N80
1on]^N801?l0003o[KWRojfih_l00009okBkg`;o000000?o][oQo`000?nl`Mh03Onl`Mh00ol0003o
`L?Kol73f`0;ol73f`;o00003_o6am/00ol0003ob<OIolS7f@08olS7f@;o00000oo8b=X00ol0003o
bLOIolW7f@0=olW7f@03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Cooooo
00?o0000og6Vl_maY_801_maY_800ol0003oMZOaogJWl@03ogJWlA7o00001On7[>h00ol0003oTK3[
oi6`j`07oi6`j`03o`000?nK/nSoVk?X00[oVk?X00?o0000ojFfiOnU]^D02OnU]^D00ol0003o[KWR
ojfihP06ojfihP04o`000?n]^N;o[KWRo`0000Oo];_O0_l00004okJoh@03o`000?nl`Mko_<7N00co
_<7N00?o0000ol73foo1`m/02?o1`m/2o`000003ol;6gOl0003oa/OK00koa/OK00?o0000olS7fOo8
amT01_o8amT00ol0003ob<SJolS8fP04olS8fP03o`000?o9amWobLOI00cobLOI00?o0000oooooooo
ool0@?ooool002Wooooo00?o0000ooooooooool0AOooool00ol0003oLJKbog6VlP06og6VlP03o`00
0?mfYo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP08ohN/kP03o`00
0?nA/>_oTK3[00OoTK3[00?o0000oi^cj?nK/nP02OnK/nP00ol0003oYKKUojFfi@09ojFfi@03o`00
0?n]^N;o[KWR00Ko[KWR00Go0000ojfih_n]^N;o[KWRo`000004okBkg`;o00001onf_n400ol0003o
_<7Nokc1gP0<okc1gP03o`000?o1`m_o`L?K00Ko`L?K00?o0000ol;6gOo2a]d00_o2a]d00ol0003o
a/OKolK7f`0=olK7f`03o`000?o8amWob<OI00Cob<OI00?o0000olS8f_o8b=X01_o8b=X00ol0003o
bLOIolW7f@0<olW7f@03o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo04Kooooo
00?o0000og6Vl_maY_801_maY_800ol0003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_
00?o0000ohN/k_n7[>h02?n7[>h00ol0003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X
00?o0000ojFfiOnU]^D02OnU]^D00ol0003o[KWRojfihP05ojfihP03o`000?n]^N;o[KWR00;o[KWR
00Co0000okBkgol0003o00002_nf_n400ol0003o_<7Nokc1gP0;okc1gP03o`000?o1`m_o`L?K00Co
`L?K0_l00006ol;6g@03o`000?o6am_oa/OK00goa/OK00Co0000olS7fOo8amWob<OI0_l00009olS8
fP03o`000?o9amWobLOI00cobLOI0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000og6Vl_ma
Y_801_maY_800ol0003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_00?o0000ohN/k_n7
[>h02?n7[>h00ol0003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X00?o0000ojFfiOnU
]^D02OnU]^D00ol0003o[KWRojfihP04ojfihP03o`000?n]^N;o[KWR00;o[KWR0_l0000<okJoh@03
o`000?nl`Mko_<7N00co_<7N00Co0000ol73foo1`m_o`L?K0_l00009ol;6g@03o`000?o6am_oa/OK
00goa/OK00?o0000olS7fOl000003?o8b=X00ol0003obLOIolW7f@0:olW7f@04o`000?o7b=[o0000
o`0003oooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000og6Vl_maY_801_maY_800ol0
003oMZOaogJWl@05ogJWl@03o`000?mnZNooOZW_00KoOZW_00?o0000ohN/k_n7[>h02?n7[>h00ol0
003oTK3[oi6`j`07oi6`j`03o`000?nK/nSoVk?X00WoVk?X00?o0000ojFfiOnU]^D02?nU]^D00ol0
003o[KWRojfihP04ojfihP03o`000?n]^N;o000000;o000000?o[[gUo`000?nf_n403?nf_n400ol0
003o_<7Nokc1gP0<okc1gP03o`000?o1`m_o000000co`/KM00?o0000olK7foo6am/03?o6am/2o`00
00kob<SJ00?o0000olW7fOo9amT01oo9amT2o`0000?oalSJ00?o0000ooooooooool0?Oooool002Wo
oooo00?o0000ooooooooool0BOooool00ol0003oLJKbog6VlP06og6VlP03o`000?mfYo7oMZOa00Go
MZOa00?o0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP08ohN/kP03o`000?nA/>_oTK3[00Oo
TK3[00?o0000oi^cj?nK/nP02?nK/nP00ol0003oYKKUojFfi@09ojFfi@03o`000?n]^N;o[KWR00?o
[KWR0_l00005ojjmi@03o`000?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh02onl`Mh2o`0000ko
`/KM00?o0000olK7foo6am/02_o6am/00ol0003oa/WLo`00000?olS8fP03o`000?o9amWobLOI00Go
bLOI00?o0000olO8f_o7b=X01?o7b=X00ol0003oooooooooo`0looooo`00:Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?maY_;oLJKb00KoLJKb00?o0000ogJWlOmfYo401OmfYo400ol0003oOZW_
ogjYk`06ogjYk`03o`000?n7[>koQjc^00SoQjc^00?o0000oi6`jonA/>/01onA/>/00ol0003oVk?X
oi^cj008oi^cj003o`000?nU]^GoYKKU00WoYKKU00?o0000ojfih_l000000ol00007ojjmi@03o`00
0?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh02?nl`Mh2o`000003okg5hOl0003o`/KM00go`/KM
00?o0000olK7foo6am/02?o6am/2o`0000?oa/WL00?o0000olS8f_o8b=X03?o8b=X00ol0003obLOI
olW7f@04olW7f@03o`000?o7b=[oalSJ00KoalSJ00?o0000ooooooooool0>oooool002Wooooo00?o
0000ooooooooool0Boooool00ol0003oLJKbog6VlP05og6VlP03o`000?mfYo7oMZOa00KoMZOa00?o
0000ogjYkomnZNl01_mnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA/>_oTK3[00SoTK3[00?o
0000oi^cj?nK/nP02?nK/nP00ol0003oYKKUojFfi@07ojFfi@?o00000on^_ND00ol0003o[[gUojjm
i@06ojjmi@03o`000?nf_n7o][oQ00_o][oQ00?o0000okc1g_nl`Mh01_nl`Mh00ol0003o_LGQokg5
h@02okg5h@03o`000?o2a]go`/KM00co`/KM00?o0000olK7foo6am/01_o6am/00ol0003oa/WLolK9
g004olK9g003o`000?o8b=[ob<SJ00cob<SJ00Co0000olW7fOo9amWobLOI0_l00009olO8fP;o0000
??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003oLJKbog6VlP05og6VlP03o`000?mf
Yo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA
/>_oTK3[00SoTK3[00?o0000oi^cj?nK/nP02?nK/nP01?l0003oYKKUojFfiOnU]^D5o`0000;oY;[X
00Go0000ojjmiOn^_NGo[[gUo`000009ojjmi@03o`000?nf_n7o][oQ00[o][oQ00?o0000okc1g_nl
`Mh01?nl`Mh2o`0000Ko_LGQ00?o0000ol;6gOo2a]d03?o2a]d00ol0003oa/OKolK7f`04olK7f`03
o`000?o6bMcoa/WL00Koa/WL00?o0000olS8f_o8b=X03?o8b=X00ol0003obLOIo`00000<olO8fP03
o`000?oooooooooo03[ooooo000Xooooo`?o0000C_ooool00ol0003oLJKbog6VlP05og6VlP03o`00
0?mfYo7oMZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`00
0?nA/>_oTK3[00SoTK3[00?o0000oi^cj?nK/nP01_nK/nP5o`0000SoY;[X00Co0000ojjmiOn^_NGo
00002_n^_ND00ol0003o][oQokJoh@0:okJoh@04o`000?nl`Mko_<7Nokc1gP;o00002OnmaN400ol0
003o`/KMol;6g@0<ol;6g@04o`000?o6am_oa/OKolK7f`;o00002_o6bM`00ol0003ob<SJolS8fP0;
olS8fP;o00003_o7b=X00ol0003oooooooooo`0iooooo`00:?ooool00ol0003oooooooooo`1?oooo
o`03o`000?maY_;oLJKb00GoLJKb00?o0000ogJWlOmfYo401OmfYo400ol0003oOZW_ogjYk`07ogjY
k`03o`000?n7[>koQjc^00OoQjc^00?o0000oi6`jonA/>/02?nA/>/00ol0003oVk?Xoi^cj005o`00
00;oV[K/00?o0000ojBjj?nT^^P02OnT^^P00ol0003o[[gUo`00000;ojjmi@03o`000?nf_n7o][oQ
00[o][oQ00?o0000okc1g_l000003?nmaN400ol0003o`/KMol;6g@0<ol;6g@03o`000?o6am_o0000
00goa/WL00?o0000olS8f_o8b=X02Oo8b=X00ol0003oal[Lo`00000?olO8fP03o`000?oooooooooo
03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c007ooooo`03o`000?oooooooooo053ooooo1_l00002og6VlP03o`000?mfYo7o
MZOa00GoMZOa00?o0000ogjYkomnZNl01omnZNl00ol0003oQjc^ohN/kP07ohN/kP03o`000?nA/>_o
TK3[00?oTK3[1ol00008oiZfk003o`000?nT^^SoY;[X00WoY;[X0_l0000;ojjmi@03o`000?nf_n7o
][oQ00[o][oQ0_l0000>okg5h@03o`000?o2a]go`/KM00_o`/KM0_l0000?olK9g003o`000?o8b=[o
b<SJ00Kob<SJ0_l00003olO:g003o`000?o7b=[oalSJ00coalSJ0_l0000iooooo`003?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?mZXo;oJZ?b00?oJZ?b2Ol00002ogJWl@03o`000?mn
ZNooOZW_00OoOZW_00?o0000ohN/k_n7[>h00on7[>h9o`0000GoS[7^00?o0000oiZfk?nJ]^`02?nJ
]^`00ol0003oY;[XojBjj008ojBjj0;o00003?n^_ND00ol0003o][oQokJoh@07okJoh@;o000000?o
]lCTo`000?nmaN403OnmaN400ol0003o`/KMol;6g@09ol;6g@;o000000?o`lWOo`000?o6bM`03oo6
bM`00ol0003ob<SJolS8fP04olS8fP03o`000?o7b]coal[L00Coal[L00?o0000olO8f_o7b=X03?o7
b=X00ol0003oooooooooo`0gooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo057ooooo00?o0000ofZSl_mZXo80
1OmZXo800ol0003oKjGbofnUlP03ofnUlQ;o00001?n2[O000ol0003oS[7^ohjakP08ohjakP03o`00
0?nJ]^coV[K/00SoV[K/00?o0000ojBjj?nT^^P01?nT^^P3o`000003ojBjj?l0003o000000co[[gU
00?o0000okJohOnf_n401?nf_n42o`0000Co]lCT00?o0000okg5hOnmaN403?nmaN400ol0003o`/KM
ol;6g@07ol;6g@03o`000?o3bMoo`lWO00;o`lWO00?o0000olK9g?o6bM`03_o6bM`01?l0003ob<SJ
olS8f_o8b=X2o`0000Soal[L00?o0000olO8f_o7b=X03?o7b=X00ol0003oooooooooo`0fooooo`00
3?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07oooo
o`03o`000?oooooooooo05;ooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnU
lP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohja
kP03o`000?nJ]^coV[K/00SoV[K/00?o0000ojBjj?nT^^P00ol00005ojBjj0;o00003?n^_ND00ol0
003o][oQokJoh@02okJoh@03o`000?nga>Co]lCT00Go]lCT00?o0000okg5hOnmaN403?nmaN400ol0
003o`/KMol;6g@04ol;6g@;o00001_o3bMl00ol0003oa/WLolK9g00>olK9g003o`000?o8b=[o0000
00_oal[L00?o0000olO8f_o7b=X02oo7b=X2o`0003Oooooo000<ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0Doooool0
0ol0003oJZ?bofZSlP05ofZSlP03o`000?m_YO;oKjGb00GoKjGb00?o0000ogRXlOmhZ?401omhZ?40
0ol0003oPZg`oh:]l007oh:]l003o`000?n>/NkoS[7^00SoS[7^00?o0000oiZfk?nJ]^`01onJ]^`3
o`0000WoY;[X0_l0000<ojjmi@04o`000?nf_n7o0000o`0000Wo]lCT00?o0000okg5hOnmaN403?nm
aN401?l0003o`/KMol;6gOo2a]d2o`0000Wo`lWO00?o0000olK9g?o6bM`03Oo6bM`2o`0000goal[L
00?o0000olO8f_o7b=X02?o7b=X2o`000003olG8gOl0003o000003Kooooo000<ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`09ooooo`03o`000?oooooooooo05Cooooo
00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa
00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohjakP03o`000?nJ]^coV[K/00?oV[K/
0ol00002oiZfk003o`000?nT^^SoY;[X00SoY;[X0_l0000:ojjmi@?o00003?nga>@00ol0003o_LGQ
okg5h@0<okg5h@03o`000?o2a]go000000co`lWO00?o0000olK9g?o6bM`02oo6bM`00ol0003oaLcO
o`00000=olO:g003o`000?o7b=[oalSJ00OoalSJ00?o0000olG8gOo5b=d00_o5b=d00ol0003ooooo
ooooo`0dooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool2o`0005Oooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`00
0?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003oS[7^ohjakP08ohjakP03o`00
0?nJ]^co000000;o00001OnJ]^`00ol0003oY;[XojBjj009ojBjj0;o00001_n^_ND3o`0000;o[/7X
00?o0000okO4i?nga>@02onga>@00ol0003o_LGQokg5h@0;okg5h@;o00003_o3bMl00ol0003oa/WL
olK9g008olK9g0;o00000oo5c=l00ol0003oal[LolO:g00;olO:g003o`000?o7b=[oalSJ00CoalSJ
0_l00006olG8g@03o`000?oooooooooo03?ooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo05Oooooo00?o0000ofZSl_mZ
Xo801OmZXo800ol0003oKjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2
[O001on2[O000ol0003oS[7^ohjakP06ohjakP?o00002OnJ]^`00ol0003oY;[XojBjj009ojBjj0;o
00000_n^_ND3o`0000Ko[/7X00?o0000okO4i?nga>@02onga>@00ol0003o_LGQokg5h@09okg5h@03
o`000?nnbN?o000000oo`lWO00?o0000olK9g?o6bM`01_o6bM`00ol0003oaLcOolG<g`04olG<g`03
o`000?o7b]coal[L00_oal[L00Co0000olO8f_o7b=[oalSJ0_l00009olG8g@03o`000?oooooooooo
03;ooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o0000ofZSl_mZXo801OmZXo800ol0003o
KjGbofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001on2[O000ol0003o
S[7^ohjakP02ohjakP?o00000_n>/Nh00ol0003oV[K/oiZfk008oiZfk003o`000?nT^^SoY;[X00So
Y;[X1?l0000:ojk1j003o`000?nga>Co]lCT00_o]lCT00?o0000okg5hOnmaN401_nmaN42o`0000?o
_/WS00?o0000ol?9goo3bMl03Oo3bMl00ol0003oa/WLolK9g004olK9g003o`000?o5c=ooaLcO00Ko
aLcO00?o0000olO:g?o7b]`02oo7b]`00ol0003oalSJo`00000<olG8g@03o`000?oooooooooo037o
oooo000Wooooo`03o`000?oooooooooo05Wooooo00?o0000ofZSl_mZXo801OmZXo800ol0003oKjGb
ofnUlP05ofnUlP03o`000?mhZ?7oN:Sa00OoN:Sa00?o0000oh:]l?n2[O001_n2[O000ol0003oS[7^
o`000002o`0000KoS[7^00?o0000oiZfk?nJ]^`02?nJ]^`00ol0003oY;[XojBjj004ojBjj0?o0000
0_nT_^`00ol0003o[/7Xojk1j00:ojk1j003o`000?nga>Co]lCT00_o]lCT00?o0000okg5hOnmaN40
1?nmaN400ol0003o_/WSokk9h`04okk9h`03o`000?o3bMoo`lWO00go`lWO00Co0000olK9g?o6bMco
a/WL0_l0000:olG<g`03o`000?o7b]coal[L00[oal[L0_l0000=olG8g@;o0000<_ooool002Oooooo
00?o0000ooooooooool0F_ooool00ol0003oJZ?bofZSlP05ofZSlP03o`000?m_YO;oKjGb00GoKjGb
00?o0000ogRXlOmhZ?401omhZ?400ol0003oPZg`oh:]l004oh:]l0?o00002_n>/Nh00ol0003oV[K/
oiZfk008oiZfk003o`000?nT^^SoY;[X00?o00001OnT_^`2o`0000co[/7X00?o0000okO4i?nga>@0
2onga>@01?l0003o_LGQokg5hOnmaN42o`0000So_/WS00?o0000ol?9goo3bMl03Oo3bMl00ol0003o
a/WLo`00000=olG<g`03o`000?o7b]coal[L00Soal[L00?o0000olC;gol000003_o5b=d00ol0003o
ooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Kooooo`03o`000?mZXo;oJZ?b00GoJZ?b
00?o0000ofnUl_m_YO801Om_YO800ol0003oN:SaogRXl@07ogRXl@03o`000?n2[O3oPZg`00?o0000
0on2[O000ol0003oS[7^ohjakP08ohjakP03o`000?nJ]^coV[K/00KoV[K/1?l00009ojBnk0;o0000
3?n^`NP00ol0003o]lCTokO4i00;okO4i003o`000?nmaN7o000000_o_/WS00?o0000ol?9goo3bMl0
3?o3bMl2o`0000koaLcO00?o0000olO:g?o7b]`01_o7b]`2o`0000?oa<_O00?o0000olG8gOo5b=d0
3?o5b=d00ol0003oooooooooo`0_ooooo`009oooool2o`0005gooooo1_l00002ofZSlP03o`000?m_
YO;oKjGb00GoKjGb00?o0000ogRXlOmhZ?401_mhZ?43o`0000OoPZg`00?o0000ohjak_n>/Nh02?n>
/Nh00ol0003oV[K/oiZfk005o`0000;oV;[_00?o0000ojBnk?nT_^`02OnT_^`2o`0000co[/7X00?o
0000okO4i?nga>@02_nga>@2o`0000go_/WS00?o0000ol?9goo3bMl02Oo3bMl2o`000003ol;=hol0
003oaLcO00koaLcO00?o0000olO:g?o7b]`01?o7b]`00ol0003oa<_OolC;g`04olC;g`03o`000?o5
b=goaLSM00coaLSM00?o0000ooooooooool0;_ooool002Kooooo0_l0001Oooooo`03o`000?mXX_;o
J:;b00;oJ:;b2Ol00002ofnUlP03o`000?mhZ?7oN:Sa00;oN:Sa0ol00002ogRXl@03o`000?n2[O3o
PZg`00KoPZg`00?o0000ohjak_n>/Nh00on>/Nh7o`0000SoV;[_00?o0000ojBnk?nT_^`02OnT_^`2
o`0000co[/7X00?o0000okO4i?nga>@01_nga>@3o`0000;o]lSW00?o0000okk9honnbN<02onnbN<0
0ol0003o`lWOol?9g`07ol?9g`03o`000?o2cN?o`/gS00;o`/gS00?o0000olG<goo5c=l03Oo5c=l0
1?l0003oal[LolO:g?o7b]`2o`0000Soa<_O00?o0000olG8gOo5b=d02oo5b=d2o`0002oooooo000W
ooooo`03o`000?oooooooooo05kooooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`02
ofbUla_o00001On<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00WoY;k/0_l0000<
ojk1j003o`000?nga>Co]lCT00?o]lCT0_l00006okO8i`03o`000?nnbN?o_/WS00_o_/WS00?o0000
ol?9goo3bMl01?o3bMl2o`0000Ko`/gS00?o0000olG<goo5c=l03Oo5c=l00ol0003oal[Lo`00000;
olC;g`03o`000?o5b=goaLSM00_oaLSM0_l0000^ooooo`009oooool00ol0003oooooooooo`1Ooooo
o`03o`000?mXX_;oJ:;b00GoJ:;b00?o0000ofbUlom/YO<00_m/YO<4o`0000SoM:Wc00?o0000ogn_
l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_00?o0000ojBn
k?nT_^`02OnT_^`00ol0003o[/7Xojk1j00;ojk1j003o`000?nga>Co000000;o00002Ongb>L00ol0
003o_/WSokk9h`0;okk9h`04o`000?o3bMoo`lWOol?9g`;o00002Oo2cN<00ol0003oaLcOolG<g`0<
olG<g`;o00003Oo4bml00ol0003oaLSMolG8g@08olG8g@;o000000?o`<SPo`000?ooool0;Oooool0
02Kooooo00?o0000ooooooooool0HOooool00ol0003oJ:;bofRRlP05ofRRlPCo00001?m/YO<00ol0
003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?401on<]?400ol0
003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00WoY;k/00?o0000ojk1j?n^`NP02_n^`NP2o`00
00go]lSW00?o0000okk9honnbN<02onnbN<00ol0003o`lWOo`00000<ol;=h`03o`000?o5c=ooaLcO
00WoaLcO0_l000000oo3cN;o0000olC;g`0<olC;g`03o`000?o5b=goaLSM00OoaLSM00?o0000ol38
h?o0b>000_o0b>000ol0003oooooooooo`0[ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03
o`000?mXX_;oJ:;b00;oJ:;b1?l00007ofbUl`03o`000?mdZO?oM:Wc00KoM:Wc00?o0000ogn_l_mo
[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_00?o0000ojBnk?nT
_^`02OnT_^`00ol0003o[/7Xojk1j006ojk1j0?o00000_n^a^/00ol0003o]lSWokO8i`0;okO8i`03
o`000?nnbN?o_/WS00[o_/WS0_l0000>ol;=h`03o`000?o5c=ooaLcO00OoaLcO00?o0000ol?=h_o3
cN800_o3cN800ol0003oa<_OolC;g`0;olC;g`03o`000?o5b=goaLSM00CoaLSM0_l00005ol38h0;o
0000;?ooool002Kooooo00?o0000ooooooooool0Hoooool4o`0000CoJ:;b00?o0000ofbUlom/YO<0
1Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?40
1on<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00SoY;k/0_l00005ojk1j0;o0000
1_n^a^/00ol0003o]lSWokO8i`0;okO8i`03o`000?nnbN?o_/WS00Oo_/WS0_l00002okg=iP03o`00
0?o2cN?o`/gS00co`/gS00?o0000olG<goo5c=l01?o5c=l2o`0000Ko`lgR00?o0000olC;goo4bml0
2oo4bml01?l0003oaLSMolG8gOo5b=d2o`0000So`<SP00?o0000ooooooooool0:_ooool002Kooooo
0_l0001Sooooo`?o00001omXX_800ol0003oK:GcofbUl`05ofbUl`03o`000?mdZO?oM:Wc00KoM:Wc
00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00SoV;[_
00?o0000ojBnk?nT_^`02?nT_^`2o`000004ojk1j?l0003o0000o`0000Wo[/K[00?o0000okO8iong
b>L02ongb>L00ol0003o_/WSokk9h`04okk9h`;o00001OnmcNH00ol0003o`/gSol;=h`0<ol;=h`04
o`000?o5c=ooaLcOolG<g`;o00002Oo3cN800ol0003oa<_OolC;g`0;olC;g`03o`000?o5b=go0000
00_o`<SP00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`0000?o
oooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`05ofbUl`03o`000?mdZO?oM:Wc00Ko
M:Wc00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`000?nH^^ooV;[_00So
V;[_00?o0000ojBnk?nT_^`02?nT_^`2o`0000go[/K[00?o0000okO8iongb>L02ongb>L00ol0003o
_/WSokk9h`02okk9h`03o`000?nmcNKo_LgV00Ko_LgV00?o0000ol;=hoo2cN<03?o2cN<00ol0003o
aLcOo`00000<ol?=hP03o`000?o4bmooa<_O00[oa<_O0_l0000=ol38h003o`000?oooooooooo02So
oooo000Vooooo`03o`000?oooooooooo05cooooo0ol00007ooooo`03o`000?mXX_;oJ:;b00GoJ:;b
00?o0000ofbUlom/YO<01Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob
00?o0000ohbdlOn<]?401on<]?400ol0003oV;[_oiRjk`08oiRjk`03o`000?nT_^coY;k/00CoY;k/
0ol000000onS`noo0000o`00000=ojk6j`03o`000?ngb>Oo]lSW00_o]lSW00Co0000okk9hol0003o
00002_nmcNH00ol0003o`/gSol;=h`0;ol;=h`;o00003_o3cN800ol0003oa<_OolC;g`08olC;g`03
o`000?o0bn?o000000go`<SP00?o0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0
FOooool3o`0000_ooooo00?o0000ofRRl_mXX_801OmXX_800ol0003oK:GcofbUl`05ofbUl`03o`00
0?mdZO?oM:Wc00KoM:Wc00?o0000ogn_l_mo[o801omo[o800ol0003oS;Caohbdl@07ohbdl@03o`00
0?nH^^ooV;[_00SoV;[_00?o0000ojBnk?nT_^`00ol00005oj?3k`;o00003On^a^/00ol0003o]lSW
okO8i`0:okO8i`;o00003OnmcNH00ol0003o`/gSol;=h`09ol;=h`03o`000?o0cnKo000000ko`lgR
00?o0000olC;goo4bml01_o4bml2o`0000?o`<_S00?o0000ol38h?o0b>002oo0b>000ol0003ooooo
ooooo`0Wooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o00003oooool6o`0000;oJ:;b00?o
0000ofbUlom/YO<01Om/YO<00ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o
0000ohbdlOn<]?401on<]?400ol0003oV;[_oiRjk`03oiRjk`Oo00002OnS`nl2o`0000go[/K[00?o
0000okO8iongb>L01_ngb>L3o`000003okK<jol0003o_LgV00go_LgV00?o0000ol;=hoo2cN<01_o2
cN<2o`0000?o`<oV00?o0000ol?=h_o3cN803?o3cN800ol0003oa<_OolC;g`04olC;g`03o`000?o0
bn?o`<_S00Co`<_S00?o0000ol38h?o0b>002oo0b>000ol0003oooooooooo`0Vooooo`009_ooool0
0ol0003oooooooooo`1Cooooo`?o00004oooool00ol0003oJZ?bofZSlP02ofZSlPWo00000_m/YO<0
0ol0003oM:WcogBYl`06ogBYl`03o`000?mo[o;oOjob00OoOjob00?o0000ohbdlOn<]?400on<]?49
o`0000KoV;kb00?o0000oj?3konS`nl02?nS`nl2o`0000go[/K[00?o0000okO8iongb>L00ongb>L2
o`0000Go]/c[00?o0000okg=i_nmcNH03?nmcNH00ol0003o`/gSol;=h`04ol;=h`03o`000?o0cnKo
`<oV00Co`<oV00?o0000ol?=h_o3cN803?o3cN801?l0003oa<_OolC;goo4bml2o`0000So`<_S00?o
0000ol38h?o0b>002_o0b>02o`0002Oooooo000Uooooo`03o`000?oooooooooo057ooooo0ol0000G
ooooo`03o`000?mZXo;oJZ?b00GoJZ?b00?o0000offVlom]Y_<00_m]Y_<Ko`0000CoRkSd00?o0000
oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07oj?3k`03o`000?nS`noo000000go[/K[00?o0000
okO8iol000000_l00008okK<j`03o`000?nmcNKo_LgV00co_LgV00Co0000ol;=hoo2cN?o`/gS0_l0
0008ol3?iP03o`000?o3cN;o`lgR00co`lgR00?o0000olC;gol000002oo0bn<00ol0003o`<SPol38
h00:ol38h003o`000?oooooooooo02Gooooo000Uooooo`?o0000C_ooool3o`0001[ooooo0_l00007
ofZSlP03o`000?m]Y_?oKJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006
ogjam003o`000?n;^?CoRkSd00OoRkSd00?o0000oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07
oj?3k`03o`000?nS`noo000000co[/K[0_l0000<okK<j`03o`000?nmcNKo_LgV00co_LgV00?o0000
ol;=hol000002oo0cnH00ol0003o`lgRol?=hP0;ol?=hP;o00003Oo0bn<00ol0003o`<SPol38h009
ol38h0;o00009_ooool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00007ofZS
lP03o`000?m]Y_?oKJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogja
m003o`000?n;^?CoRkSd00OoRkSd00?o0000oiRnl_nH__802OnH__800ol0003oXl?_oj?3k`07oj?3
k`03o`000?nS`noo000000So[/K[0ol00002ojk;k`03o`000?nfc>_o]/c[00[o]/c[00?o0000okg=
i_nmcNH02onmcNH2o`0000go`<oV00?o0000ol?=h_o3cN802?o3cN82o`000003oko?i_l0003o`<_S
00go`<_S00?o0000ol38h?o0b>001_o0b>02o`000003ok[6hol0003o000002Gooooo0009ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c007
ooooo`03o`000?oooooooooo04Sooooo0ol0000Rooooo`;o00001omZXo800ol0003oKJKcoffVl`05
offVl`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^hm007
oh^hm003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl00ol0003oXl?_o`000005
ojk6j`;o00001_n^bnl00ol0003o]/c[okK<j`0:okK<j`03o`000?nmcNKo_LgV00So_LgV0_l00002
ok_@jP03o`000?o0cnKo`<oV00_o`<oV00?o0000ol?=h_o3cN801Oo3cN82o`0000Co_loV00?o0000
ol3;hoo0bn<03?o0bn<00ol0003o`<SPol38h002ol38h0?o00001?nja^<2o`0002Cooooo0009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@07ooooo`03o`000?oooooooooo04Gooooo0ol0000Vooooo`;o00001omZXo800ol0003oKJKcoffV
l`05offVl`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^h
m007oh^hm003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl01?l0003oXl?_o`00
0?n^a^/3o`0000Wo[/__00?o0000okK<jonfc>/02_nfc>/00ol0003o_LgVokg=iP05okg=iP;o0000
1Onkd>X00ol0003o`<oVol3?iP0;ol3?iP03o`000?o3cN;o`lgR00;o`lgR0_l00007oko?iP03o`00
0?o0bn?o`<_S00co`<_S00Co0000ol38h?l0003o00002?nja^<00ol0003oooooooooo`0Rooooo`00
2Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo04;ooooo0ol0000Zooooo`;o00001omZXo800ol0003oKJKcoffVl`05offV
l`03o`000?mdZoCoM:_d00KoM:_d00?o0000ogjam?mn/O@01_mn/O@00ol0003oRkSdoh^hm007oh^h
m003o`000?nH__;oV;kb00WoV;kb00?o0000oj?3konS`nl01onS`nl4o`0000co[/__00?o0000okK<
jonfc>/02_nfc>/00ol0003o_LgVokg=iP02okg=iP;o00002?nkd>X00ol0003o`<oVol3?iP0;ol3?
iP04o`000?o3cN;o0000o`0000[o_loV00?o0000ol3;hoo0bn<02oo0bn<2o`0000_o^/KS00?o0000
ooooooooool08Oooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801oooool00ol0003oooooooooo`0oooooo`?o0000;_ooool2o`0000OoJZ?b00?o
0000offVlom]Y_<01Om]Y_<00ol0003oM:_dogB[m006ogB[m003o`000?mn/OCoO[7d00KoO[7d00?o
0000oh^hm?n;^?@01on;^?@00ol0003oV;kboiRnlP09oiRnlP03o`000?nS`nooXl?_00CoXl?_1?l0
0002oj?7lP03o`000?n^bnoo[/__00[o[/__00?o0000okK<jonfc>/02_nfc>/01?l0003o_LgVo`00
0?l0000;ok_@jP03o`000?o0cnKo`<oV00[o`<oV0_l0000=oko?iP03o`000?o0bn?o`<_S00So`<_S
0_l000000onjbnOo0000ok[6h`0:ok[6h`;o00008_ooool000Wooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o
0000<_ooool2o`0000OoJZ?b00?o0000offVlom]Y_<01Om]Y_<00ol0003oM:_dogB[m006ogB[m003
o`000?mn/OCoO[7d00KoO[7d00?o0000oh^hm?n;^?@01on;^?@00ol0003oV;kboiRnlP09oiRnlP03
o`000?nS`nooXl?_00?o00001?nSao801?l0003oXlOboj?7l_l0000<ojk;k`03o`000?nfc>_o]/c[
00Wo]/c[0ol0000=ok_@jP03o`000?o0cnKo`<oV00Oo`<oV0_l00002okcAjP03o`000?nocnKo_loV
00_o_loV00?o0000ol3;hoo0bn<01Oo0bn<2o`0000Co^/_W00?o0000ok[6honja^<02Onja^<2o`00
027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00007ofZSlP03o`000?m]Y_?o
KJKc00GoKJKc00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogjam003o`000?n;^?Co
RkSd00OoRkSd00?o0000oiRnl_nH__801onH__84o`0000OoXlOb00Go0000oj?7l_nSao;oXlObo`00
000<ojk;k`03o`000?nfc>_o]/c[00Ko]/c[0_l00003okC@kP03o`000?nkd>[o^m3Z00_o^m3Z00?o
0000ol3?i_o0cnH01?o0cnH2o`0000Go_=7Z00?o0000oko?i_nocnH02onocnH00ol0003o`<_Sol3;
h`02ol3;h`;o00001onjbnL00ol0003o^/KSok[6h`09ok[6h`03o`000?oooooooooo01oooooo0009
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0=oooool3o`0003[ooooo1ol00002ofZSlP03o`000?m]Y_?oKJKc00GoKJKc
00?o0000ogB[m?mdZo@01_mdZo@00ol0003oO[7dogjam006ogjam003o`000?n;^?CoRkSd00OoRkSd
00Co0000oiRnl_nH__;oV;kb1Ol00004oiS2m@03o`000?nSao;oXlOb00GoXlOb00Go0000oj?7l_nS
ao;oXlObo`00000<ojk;k`03o`000?nfc>_o]/c[00;o]/c[0ol00006okC@kP03o`000?nkd>[o^m3Z
00_o^m3Z00?o0000ol3?i_o0cnH00_o0cnH00ol0003o_=7ZokcAjP06okcAjP03o`000?nocnKo_loV
00_o_loV00Co0000ol3;hol0003o00002_njbnL00ol0003o^/KSok[6h`08ok[6h`;o00008?ooool0
00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`0dooooo`?o0000?_ooool00ol0003oLJKbog6VlP03og6VlPWo00000_m]
Y_<00ol0003oM:_dogB[m006ogB[m003o`000?mn/OCoO[7d00KoO[7d00?o0000oh^hm?n;^?@00on;
^?@7o`0000[oV<;e00?o0000oj?7l_nSao801OnSao801Ol0003oXlOboj?7l_nSao;o000000co[/__
00Co0000okK<jol0003o00002_ndd>h00ol0003o^m3Zok_@jP0;ok_@jP04o`000?o0cnKo0000o`00
00[o_=7Z00?o0000oko?i_nocnH02_nocnH2o`0000co^/_W00?o0000ok[6honja^<02Onja^<2o`00
01oooooo000Tooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?maY_;oLJKb00Go
LJKb00?o0000og>Zm?mcZ_@00omcZ_@Jo`0000KoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP05oj?7lP05o`000?nSao;oXlOboj?7l_l000002_n^bnl4o`0000co]=3^00?o0000ok_@
j_nkd>X02_nkd>X3o`0000co_=7Z00?o0000oko?i_nocnH01onocnH2o`0000;o^LoZ00?o0000ok[;
ionjbnL02_njbnL00ol0003o^/KSok[6h`09ok[6h`;o00007_ooool002Cooooo00?o0000oooooooo
ool0;oooool2o`0004Kooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003
o`000?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP03
o`000?nH`_GoV<;e00WoV<;e00?o0000oj?7l_nSao801OnSao801Ol0003oXlOboj?7l_nSao;o0000
00Ko[/__0ol00004ojg>lP03o`000?ndd>ko]=3^00[o]=3^00?o0000ok_@j_nkd>X01_nkd>X3o`00
00?o^=;^00?o0000okcAj_nldNX02_nldNX00ol0003o_loVoko?iP04oko?iP;o00001OnicnX00ol0
003o^/_Wok[;i`0:ok[;i`03o`000?nja^?o^/KS00So^/KS0_l0000Nooooo`009?ooool00ol0003o
ooooooooo`0/ooooo`?o0000BOooool00ol0003oLJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00Ko
Lj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003oPKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00Oo
S;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003oXlOboj?7lP05oj?7lP05o`000?nSao;oXlOboj?7
l_l000000_n^bnl3o`0000So[Lkb00?o0000okC@k_ndd>h02_ndd>h00ol0003o^m3Zok_@jP03ok_@
jP;o00001onhd^h00ol0003o_=7ZokcAjP0:okcAjP03o`000?nocnKo_loV00;o_loV00?o0000okW?
j_nicnX01_nicnX00ol0003o^/_Wok[;i`09ok[;i`03o`000?nja^?o^/KS00Ko^/KS0_l000000onc
a>Oo0000o`00000Mooooo`009?ooool00ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003o
LJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00KoLj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003o
PKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00OoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP05oj?7lP03o`000?nSao;oXlOb00?o00003?n]c_800ol0003o]=3^okC@kP0:okC@kP03
o`000?nkd>[o000000;o00002_nhd^h00ol0003o_=7ZokcAjP0:okcAjP04o`000?nocnKo0000o`00
00[o^LoZ00?o0000ok[;ionjbnL02OnjbnL00ol0003o^/KSok[6h`02ok[6h`?o00001?nca>L2o`00
01cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aooooo`03o`000?maY_;oLJKb00Go
LJKb00?o0000og>Zm?mcZ_@01_mcZ_@00ol0003oN:oeogR_m@06ogR_m@03o`000?n1]OKoPKGf00Oo
PKGf00?o0000ohblm_n<_?H01on<_?H00ol0003oV<;eoiS2m@09oiS2m@03o`000?nSao;oXlOb00Co
XlOb0ol00003oj?;m@03o`000?n]c_;o[Lkb00[o[Lkb00?o0000okC@k_ndd>h02Ondd>h3o`0000go
^=;^00?o0000okcAj_nldNX02OnldNX2o`0000go^LoZ00?o0000ok[;ionjbnL02OnjbnL01?l0003o
^/KSo`000?l00008ok?4i`;o00006oooool002?ooooo0_l0000Uooooo`?o0000EOooool00ol0003o
LJKbog6VlP05og6VlP03o`000?mcZ_CoLj[d00KoLj[d00?o0000ogR_mOmh[oD01_mh[oD00ol0003o
PKGfoh6emP07oh6emP03o`000?n<_?KoS;cf00OoS;cf00?o0000oiS2mOnH`_D02OnH`_D00ol0003o
XlOboj?7lP03o`000003oj?;mOl0003oXl_e00CoXl_e00?o0000ojg>l_n]c_802_n]c_800ol0003o
]=3^okC@kP06okC@kP;o00000onbdo400ol0003o^=;^okSBkP0;okSBkP03o`000?nldN[o_=7Z00Ko
_=7Z0_l00002okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL02?njbnL2o`0000_o
/lCW00?o0000ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?ooool3o`0005Wooooo
00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003o`000?mh[oGoN:oe00KoN:oe
00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP03o`000?nH`_GoV<;e00OoV<;e
1?l00005oj?;m@03o`000?nSboGoXl_e00?oXl_e00?o0000ojg>l_n]c_802_n]c_800ol0003o]=3^
okC@kP02okC@kP?o00001_nbdo400ol0003o^=;^okSBkP0;okSBkP03o`000?nldN[o_=7Z00;o_=7Z
0ol00005okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL01?njbnL3o`000003ok?9
jol0003o/lCW00_o/lCW00?o0000ooooooooool06?ooool002?ooooo00?o0000ooooooooool07_oo
ool3o`0005gooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003o`000?mh
[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP07ohblmP04o`000?nH
`_GoV<;eoiS2m@Go00001?nIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00?oXl_e
0_l0000;ojg>lP04o`000?ndd>ko0000o`0000[o/]?a00?o0000okSBk_nhd^h02onhd^h01?l0003o
_=7Zo`000?l00009okOBkP03o`000?nicn[o^LoZ00_o^LoZ00?o0000ok[;ionjbnL00ol00005ok?9
j`03o`000?nca>Oo/lCW00[o/lCW00?o0000ooooooooool05oooool002?ooooo00?o0000oooooooo
ool06oooool3o`00067ooooo00?o0000og6Vl_maY_801OmaY_800ol0003oLj[dog>Zm006og>Zm003
o`000?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH01on1]OH00ol0003oS;cfohblmP03ohblmPOo
00002_nIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00CoXl_e00?o0000ojg>l_n]
c_802?n]c_83o`0000co/]?a00?o0000okSBk_nhd^h02_nhd^h2o`0000co]m;^00?o0000okW?j_ni
cnX02_nicnX3o`0000Wo/lW[00?o0000ok?4ionca>L02Onca>L2o`0001Sooooo000Sooooo`03o`00
0?oooooooooo01Sooooo0ol0001Uooooo`Ko00000_maY_800ol0003oLj[dog>Zm006og>Zm003o`00
0?mh[oGoN:oe00KoN:oe00?o0000oh6em_n1]OH00on1]OH9o`0000KoS/7h00?o0000oiW6monIa_L0
2OnIa_L00ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00CoXl_e00?o0000ojg>l_n]c_80
1?n]c_83o`0000?oZm7d00?o0000ok;ClOnbdo402_nbdo400ol0003o^=;^okSBkP06okSBkP?o0000
0_nce?400ol0003o]m;^okOBkP0:okOBkP03o`000?nicn[o^LoZ00Ko^LoZ0ol000000onbcNko0000
ok?9j`0:ok?9j`03o`000?nca>Oo/lCW00Wo/lCW00?o0000ooooooooool05_ooool002?ooooo00?o
0000ooooooooool05Oooool3o`0006Sooooo00?o0000og^[l_mkZo800omkZo8Jo`0000KoQ[[g00?o
0000ohk1n?n>`OP01on>`OP00ol0003oVLKgoiW6m`09oiW6m`03o`000?nSboGoXl_e00?oXl_e00?o
0000oj?;mOnSboD01?nSboD00ol0003o[Lkbojg>lP03o`0000OoZm7d00?o0000ok;ClOnbdo402_nb
do400ol0003o^=;^okSBkP03okSBkP;o00001_nce?400ol0003o]m;^okOBkP0:okOBkP03o`000?ni
cn[o^LoZ00?o^LoZ0_l00005ok;=kP03o`000?ncbN_o/lW[00Wo/lW[00?o0000ok?4ionca>L02Onc
a>L00ol0003oooooooooo`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool0
0ol0003oNj_bog^[lP06og^[lP03o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H01_mo]?H0
0ol0003oQ[[gohJjm`07ohJjm`03o`000?n>`OSoS/7h00OoS/7h00?o0000oiW6monIa_L02OnIa_L0
0ol0003oXl_eoj?;m@03oj?;m@03o`000?nSboGoXl_e00;oXl_e1?l0000;oj_Am0;o00002onbdo40
0ol0003o^=;^o`000002o`0000Wo/mCa00?o0000okOBk_ngd^h02_ngd^h00ol0003o^LoZo`000002
o`0000So//g^00?o0000ok?9joncbN/02OncbN/00ol0003o/lCWok?4i`09ok?4i`03o`000?oooooo
oooo01Cooooo000Rooooo`?o00004?ooool3o`00073ooooo00?o0000og^[l_mkZo801_mkZo800ol0
003oNjodog^_m007og^_m003o`000?mo]?KoOkCf00KoOkCf00?o0000ohJjmon6^_L01on6^_L00ol0
003oS/7hohk1n007ohk1n0;o00002_nIa_L00ol0003oXl_eoj?;m@03oj?;m@Co00001?nScoL00ol0
003oZm7doj_Am00:oj_Am003o`000?nbdo7o/]?a00So/]?a0ol0000<ok?Dl@03o`000?ngd^ko]m;^
00Wo]m;^0ol0000;ok;=kP03o`000?ncbN_o/lW[00Wo/lW[00?o0000ok?4ionca>L01onca>L3o`00
01Gooooo000Sooooo`03o`000?oooooooooo00cooooo0ol0001dooooo`03o`000?mkZo;oNj_b00Ko
Nj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP06ogndmP03o`000?n6^_OoQ[[g00Oo
Q[[g0_l00009ohk1n003o`000?nIa_OoVLKg00SoVLKg00?o0000oj?;mOnSboD00ol00008oj??m`03
o`000?n[dOCoZm7d00[oZm7d00?o0000ok;ClOnbdo401?nbdo43o`0000?o[]Cd00?o0000ok?DlOnc
e?402_nce?400ol0003o]m;^okOBkP06okOBkP;o00000on`dO400ol0003o//g^ok;=kP09ok;=kP03
o`000?ncbN_o/lW[00Wo/lW[00Co0000ok?4ionca>Oo/lCW1Ol00002ooooo`03o`000?oooooooooo
01?ooooo000Sooooo`03o`000?oooooooooo00Wooooo0ol0001hooooo`03o`000?mkZo;oNj_b00Ko
Nj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP06ogndmP;o00002On6^_L00ol0003o
S/7hohk1n007ohk1n003o`000?nIa_OoVLKg00KoVLKg1?l00003oj??m`03o`000?nScoOoXlog00Ko
Xlog0_l0000;oj_Am003o`000?nbdo7o/]?a00?o00001on^e?@00ol0003o/mCaok?Dl@0:ok?Dl@03
o`000?ngd^ko]m;^00;o]m;^0ol00006ok3Al@03o`000?nbcNko//g^00Wo//g^00?o0000ok?9jonc
bN/02?ncbN/6o`0000Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0
1_ooool3o`0007cooooo00?o0000og^[l_mkZo801_mkZo800ol0003oNjodog^_m007og^_m003o`00
0?mo]?KoOkCf00OoOkCf00?o0000ohJjmon6^_L01on6^_L00ol0003oS/7hohk1n007ohk1n003o`00
0?nIa_OoVLKg00Go00001?nKb_P01Ol0003oXlogoj??monScoOo000000WoXlog00?o0000oj_Am?n[
dO@02?n[dO@3o`0000_o[]Cd0_l0000;ok?Dl@04o`000?ngd^ko0000o`0000[o/=7a00?o0000ok;=
k_nbcNh02OnbcNh00ol0003o/lW[ok?9j`04ok?9j`Ko00002?ooool00ol0003oooooooooo`0Coooo
o`008_ooool00ol0003oooooooooo`04ooooo`?o0000P?ooool00ol0003oNj_bog^[lP06og^[lP03
o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H01omo]?H00ol0003oQ[[gohJjm`07ohJjm`03
o`000?n>`OSoS/7h00?oS/7h1_l0000:oi_:n0;o00000_nScoL00ol0003oXlogoj??m`07oj??m`03
o`000?n[dOCoZm7d00CoZm7d0ol00003ojWCmP03o`000?n^e?Co[]Cd00[o[]Cd00?o0000ok?DlOnc
e?402?nce?43o`0000co/=7a00?o0000ok;=k_nbcNh02OnbcNh00ol0003o/lW[ok?9j`05o`0000co
oooo00?o0000ooooooooool04oooool002;ooooo00Co0000oooooooooooooooo0ol00024ooooo`03
o`000?mkZo;oNj_b00KoNj_b00?o0000og^_m?mk[o@01omk[o@00ol0003oOkCfogndmP07ogndmP03
o`000?n6^_OoQ[[g00?oQ[[g2Ol00006oi?5n003o`000?nKb_SoVl[h00WoVl[h00Co0000oj??monS
coOo00002OnScoL00ol0003oZm7doj_Am003o`0000OoZM?f00?o0000ojkDm?n^e?@02_n^e?@00ol0
003o/mCaok?Dl@04ok?Dl@?o00000on]do@00ol0003o/=7aok3Al@0:ok3Al@03o`000?nbcNko//g^
00So//g^1Ol0000?ooooo`03o`000?oooooooooo01?ooooo000Rooooo`Co0000R?ooool00ol0003o
Nj_bog^[lP06og^[lP03o`000?mk[oCoNjod00OoNjod00?o0000ogndm_mo]?H00omo]?H9o`0000Ko
SKoh00?o0000oi?5n?nCaOP01onCaOP00ol0003oVl[hoi_:n009oi_:n004o`000?nScoOoXlogo`00
00SoXlog0ol0000;ojWCmP;o00002on^e?@00ol0003o/mCaok?Dl@03o`0000Oo[M?d00?o0000ok3A
lOn`dO402_n`dO400ol0003o//g^ok;=kP04ok;=kPGo00004_ooool00ol0003oooooooooo`0Coooo
o`008_ooool3o`0008[ooooo00?o0000og^[l_mkZo801_mkZo800ol0003oNjodog^_m003og^_m0Wo
00001On9^_H00ol0003oSKohohfon008ohfon003o`000?nCaOSoTlGh00OoTlGh0_l0000:oi_:n0;o
000000?oXlogo`000?nScoL00onScoL3o`0000?oXm7h00?o0000ojWCm_nYdoH02_nYdoH00ol0003o
[]CdojkDm008ojkDm0?o00002on]do@00ol0003o/=7aok3Al@0:ok3Al@03o`000?nbcNko//g^00Co
00005oooool00ol0003oooooooooo`0Booooo`009?ooool00ol0003oooooooooo`29ooooo`ko0000
1_n7]?<00ol0003oRK[fohVjmP06ohVjmP03o`000?n=_oSoSKoh00SoSKoh00?o0000oi?5n?nCaOP0
2?nCaOP00ol0003oVl[hoi_:n009oi_:n0;o000000CoXlogo`000?l0003o00001onSdOP00ol0003o
ZM?fojWCmP0:ojWCmP03o`000?n^e?Co[]Cd00Co[]Cd0ol00003oj[DmP03o`000?n]doCo[M?d00Wo
[M?d00?o0000ok3AlOn`dO402?n`dO45o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo
00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo
00?o0000ohN`l?n7/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f
00?o0000ohfon?n=_oP02?n=_oP00ol0003oTlGhoi?5n008oi?5n003o`000?nKb_SoVl[h00OoVl[h
1?l0000;oj?An0;o00002onYdoH00ol0003o[]CdojkDm003o`0000OoZ]Cf00?o0000ojgCm?n]do@0
2On]do@00ol0003o/=7aok3Al@04ok3Al@Go00007Oooool00ol0003oooooooooo`0Booooo`005_oo
ool01OmgMgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oQk3`
ohN`l007ohN`l003o`000?n7]??oQkCc00OoQkCc00?o0000ohVjm_n9^_H01_n9^_H00ol0003oSKoh
ohfon008ohfon003o`000?nCaOSoTlGh00SoTlGh00Co0000oi_:n?nKb_SoVl[h1Ol00004oik>n003
o`000?nSdOSoXm7h00[oXm7h00?o0000ojWCm_nYdoH02?nYdoH3o`0000_oZ]Cf00?o0000ojgCm?n]
do@02On]do@00ol0003o/=7aok3Al@04o`00027ooooo00?o0000ooooooooool04_ooool001Kooooo
00Go410@oooooooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000ohN`l?n7
/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f00?o0000ohfon?n=
_oP02?n=_oP00ol0003oTlGhoi?5n006oi?5n0Go00002_nNc_P00ol0003oXm7hoj?An00:oj?An003
o`000?nYdoKoZM?f00CoZM?f0ol00003ojODm`03o`000?nZe?KoZ]Cf00WoZ]Cf00?o0000ojgCm?n]
do@02?n]do@4o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool0
0_l0000=ooooo`03o`000?oooooooooo08Wooooo00?o0000ohN`l?n7/?001on7/?000ol0003oQkCc
ohNdl`07ohNdl`03o`000?n9^_KoRK[f00KoRK[f00?o0000ohfon?n=_oP02?n=_oP00ol0003oTlGh
oi?5n005o`0000CoVLWh00?o0000oik>n?nNc_P02OnNc_P2o`0000_oXm7h00?o0000ojWCm_nYdoH0
0ol00007ojODm`03o`000?nZe?KoZ]Cf00WoZ]Cf00?o0000ojgCm?n]do@01?n]do@4o`0002Oooooo
00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oo
oooooooo08Wooooo00?o0000ohN`l?n7/?001on7/?000ol0003oQkCcohNdl`07ohNdl`03o`000?n9
^_KoRK[f00KoRK[f00?o0000ohfon?n=_oP01_n=_oP4o`0000[oVLWh0_l0000:oik>n0;o00002_nS
dOP3o`0000_oYmCg0_l0000:oj[DmP03o`000?n]doCo[M?d00Co0000:_ooool00ol0003ooooooooo
o`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0ROoo
ool00ol0003oQk3`ohN`l007ohN`l003o`000?n7]??oQkCc00OoQkCc00?o0000ohVjm_n9^_H01_n9
^_H00ol0003oSKohohfon005o`0000CoU/Cg00?o0000oiW9n?nIbOP02OnIbOP00ol0003oW/khoik>
n008oik>n0;o00001_nSdOP3o`0000?oY=?h00?o0000ojODmonWe?L02_nWe?L00ol0003oZ]Cfoj[D
mP06oj[DmPCo0000;_ooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0
003oMgMg013ooooo0_l0002:ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohNdlon7]?<01on7
]?<00ol0003oRK[fohVjmP02ohVjmPKo00002_nFa?L2o`0000[oVLWh00?o0000oik>n?nNc_P02?nN
c_P2o`0000;oXm7h0ol00007ojCCn003o`000?nWe?OoYmCg00[oYmCg00?o0000oj[Dm_nZe?H01_l0
000aooooo`03o`000?oooooooooo01;ooooo000Fooooo`05onk^k_l30`?o0000o`000?o^k^h04_oo
ool00ol0003oooooooooo`28ooooo`03o`000?n7/?3oQk3`00OoQk3`00?o0000ohNdlon7]?<00on7
]?<8o`0000KoU;od00?o0000oiK4monFa?L02OnFa?L00ol0003oVLWhoiW9n008oiW9n0;o00002?nN
c_P4o`0000_oY=?h0_l0000:ojODm`Ko0000=?ooool00ol0003oooooooooo`0Booooo`00;?ooool0
0ol0003oooooo`00002:ooooo`03o`000?n7/?3oQk3`00?oQk3`2Ol00005oi>jl@03o`000?nD_oCo
U;od00OoU;od00?o0000oiK4monFa?L02OnFa?L00ol0003oVLWhoiW9n009oiW9n003o`000?nNc_So
W/kh00Go000000GoX]3ho`000?nRd?SoX]3ho`00000<ojCCn003o`000?nWe?OoYmCg00CoYmCg1Ol0
000hooooo`03o`000?oooooooooo01;ooooo000_ooooo`03o`000?oooooooooo08Sooooo1Ol00005
oi>ekP03o`000?nC^_7oTk[a00OoTk[a00?o0000oiBom?nD_o@01onD_o@00ol0003oU/CgoiK4m`09
oiK4m`;o00002?nIbOP4o`0000OoX]3h00Co0000oj;@n?nRd?So00003?nTdoP00ol0003oYmCgojOD
m`05o`0003cooooo00?o0000ooooooooool04Oooool0033ooooo00?o0000ooooooooool0Qoooool2
o`0000WoTkG^00?o0000oi>jlOnC^_401onC^_400ol0003oU;odoiBom007oiBom0;o00002onFa?L0
0ol0003oVLWhoiW9n005o`0000CoX<gg00?o0000oj;@n?nRd?P01OnRd?P00ol0003oX]3hoj;@n002
o`0000[oY=?h1Ol0000oooooo`03o`000?oooooooooo017ooooo000aooooo`03o`000?oooooooooo
08Oooooo0_l00009oi>ekP03o`000?nC^_7oTk[a00OoTk[a00?o0000oiBom?nD_o@02?nD_o@00ol0
003oU/CgoiK4m`08oiK4m`?o00002_nPcOL00ol0003oX]3hoj;@n005oj;@n005o`000?nRd?SoX]3h
oj;@n?l000001_nTdoP4o`0004?ooooo00?o0000ooooooooool04Oooool003;ooooo00?o0000oooo
ooooool0Qoooool2o`0000WoTkG^00?o0000oi>jlOnC^_401onC^_400ol0003oU;odoiBom008oiBo
m003o`000?nFa?OoU/Cg00CoU/Cg0ol00003oio8m@03o`000?nPcOOoX<gg00SoX<gg00?o0000oj;@
n?nRd?P01OnRd?P01Ol0003oX]3hoj;@n?nRd?So000000;oY=?h1?l00016ooooo`03o`000?oooooo
oooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo0_l00009oi>ekP03o`000?nC^_7oTk[a
00OoTk[a00?o0000oiBom?nD_o@02?nD_o@00ol0003oU/CgoiK4m`03o`0000OoWlSe00?o0000oj3=
monPcOL02?nPcOL00ol0003oX]3hoj;@n005oj;@n003o`000?nRd?SoX]3h00Co0000BOooool00ol0
003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oi>ekP03o`000?nC^_7oTk[a00Oo
Tk[a00?o0000oiBom?nD_o@01_nD_o@4o`0000_oWlSe00?o0000oj3=monPcOL02?nPcOL00ol0003o
X]3hoj;@n004oj;@n0?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool00ol0003ooooo
ooooo`26ooooo`;o00002OnC]Nh00ol0003oTk[aoi>jl@07oi>jl@03o`000?nD_oCoU;od00Go0000
1?nO`o800ol0003oWlSeoio8m@09oio8m@03o`000?nPcOOoX<gg00SoX<gg00?o0000oj;@n?nRd?P0
0ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000gooooo`;o0000Qooo
ool2o`0000WoTkG^00?o0000oi>jlOnC^_400onC^_46o`0000[oWl?b00?o0000oio8mOnOb?D02OnO
b?D00ol0003oX<ggoj3=m`06oj3=m`Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00007oi>ekPOo00001_nO_^l0
0ol0003oWl?boio3lP08oio3lP;o00002_nOb?D00ol0003oX<ggoj3=m`05o`0000[ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`00>Oooool00ol0003oooooooooo`26oooo
o`;o00000_nC]Nh4o`0000?oWkW[00?o0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP09oio3
lP03o`000?nOb?GoWlSe00OoWlSe1Ol0000>ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool04Oooool003[ooooo00?o0000ooooooooool0Q_ooool3o`0000SoWkW[00?o0000oinnkonO
_^l02?nO_^l00ol0003oWl?boio3lP09oio3lP03o`000?nOb?GoWlSe00?oWlSe1Ol0000Booooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool04Oooool003_ooooo00?o0000ooooooooool0
Q_ooool00ol0003oWkW[oinij`08oinij`03o`000?nO_^ooWkk_00SoWkk_00?o0000oio3l_nO`o80
2OnO`o800ol0003oWlSeo`000003o`0001Oooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0@ooooo`00??ooool00ol0003oooooooooo`26ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o
0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP08oio3lP?o00006oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo013ooooo000mooooo`;o0000Qoooool00ol0003oWkW[oinij`08
oinij`03o`000?nO_^ooWkk_00SoWkk_00?o0000oio3l_nO`o801?nO`o83o`0001oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00?oooool00ol0003oooooooooo`25oooo
o`03o`000?nO^N_oWkW[00SoWkW[00?o0000oinnkonO_^l02?nO_^l00ol0003oWl?boio3lP03o`00
02;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003o
ooooooooo`25ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oinnkonO_^l01_nO_^l4o`0002Ko
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0@ooooo`00@Oooool2o`0008Kooooo
00?o0000oinijonO^N/02?nO^N/00ol0003oWkk_oinnk`05o`0002_ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0003oooooo`000027ooooo`03o`000?nO
^N_oWkW[00OoWkW[1Ol0000_ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?oo
ool004?ooooo00?o0000ooooooooool0QOooool00ol0003oWkW[oinij`03oinij`Co0000=?ooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo013ooooo0014ooooo`03o`000?oooooooooo
08Gooooo00?o0000oinijol000000ol0000hooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool04?ooool004Gooooo00?o0000ooooooooool0QOooool2o`0003cooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0@ooooo`00A_ooool2o`0008Gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo013ooooo0018ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00oooooo0019ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
00oooooo001:ooooo`;o0000POooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool03oooool004cooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03oooool004gooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03oooool004kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool004oooooo0_l0001loooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?oooo
o`00DOooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`00Dooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Kooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo001Dooooo`;o0000Moooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hoooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`08ooooo`;o0000Loooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool0
03Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000K_oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03_oo
ool005oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03_ooool0063ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool0067o
oooo0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`00I?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0=ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`00I_ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=oooo
o`00I_ooool3o`0006Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo001Yooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00gooooo001Zooooo`;o0000HOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03Oooool006cooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool006go
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool006kooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool006oooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool03?ooool006oooooo0ol0001Kooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0<ooooo`00LOooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<oooo
o`00L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0<ooooo`00Loooool2o`0005Sooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo001eooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00cooooo001fooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo001gooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00cooooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03?ooool007Sooooo0_l0001Cooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`00N_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0<ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`00O?ooool2o`0004oooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo001nooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00_ooooo001oooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo0020ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00_ooooo0021ooooo`?o0000BOooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02oooool007Kooooo1?l000000ol@413oooooooooo`05oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02oooool007Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00N?oo
ool00ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool005cooooo0ol000000ol@413oooooooooo`0F
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool005kooooo00?o410@okZj
^_ooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo001Nooooo`03
oiRHV?lb<S;ooooo01Oooooo00?o0000ooooooooool03_ooool2o`0004;ooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo001Nooooo`03omgM
gOl0003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2o`0004;ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo001Nooooo`03oeEEEOmg
MgOoA4A402[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02_ooool005gooooo00GogMgMoa0@4?oooooo8B4QomgM
g@0Zooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0L_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05ofIVI_n7QhOooooooiRHV?mEEED0:ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgo
oooo02[ooooo0_l0000mooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`00G?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
oooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool0097ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool0097o
oooo0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`00Toooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00U?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`00UOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00U_ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`00Uoooool2o`0003Cooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo002Iooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo002Iooooo`?o0000<Ooo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool009_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool009cooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool009go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool009kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`00XOooool2o`0002[ooooo00?o0000oooo
ooooool0P_ooool01Ol0003ooooooooooooooooo000000[ooooo002Sooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Poooool01?l0003oooooooooool0000:ooooo`00Y?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo00?o0000ooooool000002_ooool00:Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`25ooooo`;o00002_ooool00:Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`24ooooo`?o00002_ooool00:Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`20ooooo`Co00003Oooool00:Sooooo00Co0000
ooooool0003o00008Oooool00ol0003oooooooooo`1looooo`Co00004Oooool008kooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo0_l0
000Rooooo`03o`000?oooooooooo07Sooooo1?l0000Eooooo`00T?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0M?ooool4o`0001Wooooo002@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo073ooooo1?l0000Moooo
o`00T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Wooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1]ooooo`?o00008Oooool0093ooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0IOooool4o`0002Sooooo
002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool3o`0001[ooooo00?o
0000ooooooooool0HOooool4o`0002cooooo002>ooooo`03oeEEEOmVIVKo000000gooooo1?l0000>
ooooo`;o00006oooool00ol0003oooooooooo`1Mooooo`Co0000<?ooool00;;ooooo0_l0000Ioooo
o`03o`000?oooooooooo05Wooooo1?l0000dooooo`00]?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo05Gooooo1?l0000hooooo`00]Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo057ooooo1?l0000looooo`00]_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04gooooo1?l00010ooooo`00]oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo00?o0000ooooooooool0AOooool4o`00
04Sooooo002iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@Oooool4o`0004co
oooo002jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool3o`00053ooooo
002kooooo`;o00004?ooool00ol0003oooooooooo`0jooooo`Co0000Doooool00;gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0fooooo`Co0000Eoooool00;kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0booooo`Co0000Foooool00;oooooo0_l0000<ooooo`03
o`000?oooooooooo02kooooo1?l0001Oooooo`00_oooool2o`0000cooooo00?o0000ooooooooool0
:_ooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_oo
ool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool4
o`0006_ooooo0033ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool4o`00
06oooooo0034ooooo`;o00001oooool00ol0003oooooooooo`0Jooooo`Co0000Loooool00<Kooooo
0ol00004ooooo`03o`000?oooooooooo01Kooooo1?l0001gooooo`00a_ooool2o`0000Gooooo00?o
0000ooooooooool04oooool3o`0007_ooooo0038ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03oooool4o`0007kooooo0039ooooo`05o`000?ooooooooooooooool000003Oooool4
o`0008;ooooo003:ooooo`04o`000?ooooooooooo`0000Wooooo1?l00026ooooo`00boooool00ol0
003oooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0002>ooooo`00`_ooool5o`0000Kooooo
0_l0002Booooo`00`_ooool01OnHV9So8B4Qonk^k_ooooooA4A409[ooooo0033ooooo`03oiRHV?lQ
8B7ok^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[ooooo0035ooooo`03ogMgMomVIVKooooo
09Wooooo0036ooooo`03o`000?oooooooooo09Sooooo0032ooooo`05o`000?nj^[[ooooooiRHV?l@
4100V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Jooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00YOooool3o`000003oa0@4?oooooooooo0;Kooooo002Cooooo`;o
00002oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj^[[ooooo00Gooooo00?o0000okZj^_oo
ool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOooool009?ooooo00?o0000ooooooooool0
2_ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgMo`000?nj
^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0
003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P09
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c01aooooo`00R_ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B40LOooool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000077ooooo002:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05
ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40LOooool008[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000
ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo07?ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV01cooooo`00Qoooool7o`0000Gooooo0_l0000Qooooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@477ooooo003oooooof;ooooo003oooooof;ooooo003o
ooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.636 .729 .915 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68113 Metetra
.636 .743 .926 r
.55403 .68113 .58394 .7109 .61197 .70234 .58235 .67438 Metetra
.636 .758 .936 r
.58235 .67438 .61197 .70234 .64019 .69372 .61088 .66736 Metetra
.639 .771 .944 r
.61088 .66736 .64019 .69372 .66861 .68504 .63964 .65999 Metetra
.642 .784 .949 r
.63964 .65999 .66861 .68504 .69723 .6763 .66861 .65219 Metetra
.647 .794 .953 r
.66861 .65219 .69723 .6763 .72605 .6675 .69778 .64388 Metetra
.654 .802 .954 r
.69778 .64388 .72605 .6675 .75507 .65863 .72715 .63504 Metetra
.661 .806 .952 r
.72715 .63504 .75507 .65863 .7843 .6497 .75672 .62565 Metetra
.669 .806 .948 r
.75672 .62565 .7843 .6497 .81374 .64071 .78647 .61571 Metetra
.677 .803 .942 r
.78647 .61571 .81374 .64071 .84339 .63166 .81641 .60527 Metetra
.683 .796 .935 r
.81641 .60527 .84339 .63166 .87325 .62254 .84652 .59437 Metetra
.688 .786 .925 r
.84652 .59437 .87325 .62254 .90333 .61335 .87681 .58309 Metetra
.691 .774 .915 r
.87681 .58309 .90333 .61335 .93362 .6041 .90728 .57153 Metetra
.691 .761 .905 r
.90728 .57153 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.604 .719 .925 r
.49498 .6552 .52593 .68772 .55403 .68113 .52331 .65044 Metetra
.604 .732 .935 r
.52331 .65044 .55403 .68113 .58235 .67438 .55189 .64541 Metetra
.608 .747 .943 r
.55189 .64541 .58235 .67438 .61088 .66736 .58073 .63993 Metetra
.614 .761 .95 r
.58073 .63993 .61088 .66736 .63964 .65999 .6098 .63381 Metetra
.624 .775 .953 r
.6098 .63381 .63964 .65999 .66861 .65219 .63911 .62689 Metetra
.637 .787 .954 r
.63911 .62689 .66861 .65219 .69778 .64388 .66863 .61905 Metetra
.651 .797 .953 r
.66863 .61905 .69778 .64388 .72715 .63504 .69835 .61022 Metetra
.666 .803 .948 r
.69835 .61022 .72715 .63504 .75672 .62565 .72826 .60035 Metetra
.68 .805 .942 r
.72826 .60035 .75672 .62565 .78647 .61571 .75834 .58948 Metetra
.692 .804 .934 r
.75834 .58948 .78647 .61571 .81641 .60527 .78858 .57768 Metetra
.702 .798 .925 r
.78858 .57768 .81641 .60527 .84652 .59437 .81897 .56504 Metetra
.709 .79 .915 r
.81897 .56504 .84652 .59437 .87681 .58309 .8495 .55173 Metetra
.713 .78 .904 r
.8495 .55173 .87681 .58309 .90728 .57153 .88019 .53792 Metetra
.714 .768 .895 r
.88019 .53792 .90728 .57153 .93794 .55978 .91103 .52381 Metetra
.572 .707 .933 r
.4632 .62183 .49498 .6552 .52331 .65044 .49175 .61869 Metetra
.573 .72 .942 r
.49175 .61869 .52331 .65044 .55189 .64541 .52058 .61521 Metetra
.58 .734 .948 r
.52058 .61521 .55189 .64541 .58073 .63993 .54969 .6111 Metetra
.592 .749 .953 r
.54969 .6111 .58073 .63993 .6098 .63381 .57906 .6061 Metetra
.608 .765 .954 r
.57906 .6061 .6098 .63381 .63911 .62689 .60869 .59996 Metetra
.628 .778 .953 r
.60869 .59996 .63911 .62689 .66863 .61905 .63855 .59252 Metetra
.649 .79 .949 r
.63855 .59252 .66863 .61905 .69835 .61022 .66863 .58366 Metetra
.67 .797 .943 r
.66863 .58366 .69835 .61022 .72826 .60035 .69889 .57333 Metetra
.689 .801 .934 r
.69889 .57333 .72826 .60035 .75834 .58948 .72931 .56158 Metetra
.705 .801 .924 r
.72931 .56158 .75834 .58948 .78858 .57768 .75987 .54849 Metetra
.718 .797 .914 r
.75987 .54849 .78858 .57768 .81897 .56504 .79056 .53423 Metetra
.727 .791 .903 r
.79056 .53423 .81897 .56504 .8495 .55173 .82137 .51902 Metetra
.731 .782 .893 r
.82137 .51902 .8495 .55173 .88019 .53792 .8523 .50313 Metetra
.732 .772 .885 r
.8523 .50313 .88019 .53792 .91103 .52381 .88337 .48685 Metetra
.542 .695 .939 r
.43058 .58756 .4632 .62183 .49175 .61869 .45932 .58576 Metetra
.545 .707 .946 r
.45932 .58576 .49175 .61869 .52058 .61521 .48838 .58355 Metetra
.556 .721 .95 r
.48838 .58355 .52058 .61521 .54969 .6111 .51774 .58056 Metetra
.573 .737 .953 r
.51774 .58056 .54969 .6111 .57906 .6061 .5474 .57646 Metetra
.596 .753 .953 r
.5474 .57646 .57906 .6061 .60869 .59996 .57733 .57094 Metetra
.621 .767 .95 r
.57733 .57094 .60869 .59996 .63855 .59252 .60753 .56379 Metetra
.648 .78 .944 r
.60753 .56379 .63855 .59252 .66863 .58366 .63794 .55487 Metetra
.674 .789 .935 r
.63794 .55487 .66863 .58366 .69889 .57333 .66855 .5441 Metetra
.696 .794 .925 r
.66855 .5441 .69889 .57333 .72931 .56158 .69932 .53153 Metetra
.715 .795 .914 r
.69932 .53153 .72931 .56158 .75987 .54849 .73022 .51731 Metetra
.729 .793 .903 r
.73022 .51731 .75987 .54849 .79056 .53423 .76124 .50161 Metetra
.739 .789 .892 r
.76124 .50161 .79056 .53423 .82137 .51902 .79237 .48474 Metetra
.744 .782 .883 r
.79237 .48474 .82137 .51902 .8523 .50313 .82359 .46703 Metetra
.746 .774 .876 r
.82359 .46703 .8523 .50313 .88337 .48685 .85493 .44884 Metetra
.518 .685 .943 r
.39706 .55236 .43058 .58756 .45932 .58576 .42599 .55152 Metetra
.523 .695 .947 r
.42599 .55152 .45932 .58576 .48838 .58355 .45526 .55022 Metetra
.538 .708 .95 r
.45526 .55022 .48838 .58355 .51774 .58056 .48486 .54803 Metetra
.56 .724 .951 r
.48486 .54803 .51774 .58056 .5474 .57646 .51478 .54455 Metetra
.587 .74 .949 r
.51478 .54455 .5474 .57646 .57733 .57094 .54501 .53943 Metetra
.618 .755 .944 r
.54501 .53943 .57733 .57094 .60753 .56379 .57552 .53244 Metetra
.648 .768 .936 r
.57552 .53244 .60753 .56379 .63794 .55487 .60627 .52339 Metetra
.676 .778 .926 r
.60627 .52339 .63794 .55487 .66855 .5441 .63723 .5122 Metetra
.701 .784 .915 r
.63723 .5122 .66855 .5441 .69932 .53153 .66836 .49895 Metetra
.721 .786 .904 r
.66836 .49895 .69932 .53153 .73022 .51731 .69962 .48376 Metetra
.736 .786 .893 r
.69962 .48376 .73022 .51731 .76124 .50161 .73099 .46689 Metetra
.747 .784 .883 r
.73099 .46689 .76124 .50161 .79237 .48474 .76246 .44866 Metetra
.753 .78 .875 r
.76246 .44866 .79237 .48474 .82359 .46703 .79402 .42947 Metetra
.755 .774 .868 r
.79402 .42947 .82359 .46703 .85493 .44884 .82567 .40974 Metetra
.502 .678 .944 r
.36263 .5162 .39706 .55236 .42599 .55152 .39174 .51587 Metetra
.51 .687 .947 r
.39174 .51587 .42599 .55152 .45526 .55022 .42121 .51505 Metetra
.528 .699 .948 r
.42121 .51505 .45526 .55022 .48486 .54803 .45103 .51327 Metetra
.553 .713 .946 r
.45103 .51327 .48486 .54803 .51478 .54455 .48121 .51009 Metetra
.584 .728 .943 r
.48121 .51009 .51478 .54455 .54501 .53943 .51172 .50513 Metetra
.616 .743 .936 r
.51172 .50513 .54501 .53943 .57552 .53244 .54253 .49812 Metetra
.648 .755 .928 r
.54253 .49812 .57552 .53244 .60627 .52339 .57361 .48889 Metetra
.678 .765 .917 r
.57361 .48889 .60627 .52339 .63723 .5122 .60491 .47732 Metetra
.703 .772 .906 r
.60491 .47732 .63723 .5122 .66836 .49895 .6364 .4635 Metetra
.724 .776 .894 r
.6364 .4635 .66836 .49895 .69962 .48376 .66803 .44758 Metetra
.74 .778 .884 r
.66803 .44758 .69962 .48376 .73099 .46689 .69978 .42983 Metetra
.751 .778 .875 r
.69978 .42983 .73099 .46689 .76246 .44866 .73162 .41061 Metetra
.758 .776 .868 r
.73162 .41061 .76246 .44866 .79402 .42947 .76355 .39035 Metetra
.76 .773 .863 r
.76355 .39035 .79402 .42947 .82567 .40974 .79557 .36951 Metetra
.496 .676 .945 r
.32723 .47902 .36263 .5162 .39174 .51587 .35653 .47872 Metetra
.507 .682 .945 r
.35653 .47872 .39174 .51587 .42121 .51505 .38621 .47791 Metetra
.526 .692 .944 r
.38621 .47791 .42121 .51505 .45103 .51327 .41626 .47611 Metetra
.553 .705 .941 r
.41626 .47611 .45103 .51327 .48121 .51009 .44668 .47287 Metetra
.585 .718 .935 r
.44668 .47287 .48121 .51009 .51172 .50513 .47746 .46779 Metetra
.617 .731 .927 r
.47746 .46779 .51172 .50513 .54253 .49812 .50856 .46059 Metetra
.649 .743 .918 r
.50856 .46059 .54253 .49812 .57361 .48889 .53995 .45109 Metetra
.678 .752 .907 r
.53995 .45109 .57361 .48889 .60491 .47732 .5716 .43919 Metetra
.702 .76 .896 r
.5716 .43919 .60491 .47732 .6364 .4635 .60344 .42495 Metetra
.723 .765 .886 r
.60344 .42495 .6364 .4635 .66803 .44758 .63545 .40855 Metetra
.739 .768 .877 r
.63545 .40855 .66803 .44758 .69978 .42983 .66758 .39026 Metetra
.751 .77 .869 r
.66758 .39026 .69978 .42983 .73162 .41061 .69982 .37045 Metetra
.758 .771 .864 r
.69982 .37045 .73162 .41061 .76355 .39035 .73215 .34957 Metetra
.762 .771 .861 r
.73215 .34957 .76355 .39035 .79557 .36951 .76458 .32809 Metetra
.502 .678 .944 r
.29083 .44079 .32723 .47902 .35653 .47872 .32034 .44 Metetra
.514 .682 .942 r
.32034 .44 .35653 .47872 .38621 .47791 .35023 .43871 Metetra
.534 .689 .939 r
.35023 .43871 .38621 .47791 .41626 .47611 .38051 .43644 Metetra
.56 .699 .933 r
.38051 .43644 .41626 .47611 .44668 .47287 .41118 .43274 Metetra
.59 .709 .926 r
.41118 .43274 .44668 .47287 .47746 .46779 .44222 .42725 Metetra
.62 .72 .918 r
.44222 .42725 .47746 .46779 .50856 .46059 .47361 .41967 Metetra
.65 .73 .908 r
.47361 .41967 .50856 .46059 .53995 .45109 .50531 .40983 Metetra
.677 .739 .898 r
.50531 .40983 .53995 .45109 .5716 .43919 .53728 .39763 Metetra
.7 .747 .888 r
.53728 .39763 .5716 .43919 .60344 .42495 .56948 .38314 Metetra
.719 .753 .879 r
.56948 .38314 .60344 .42495 .63545 .40855 .60186 .36652 Metetra
.735 .758 .871 r
.60186 .36652 .63545 .40855 .66758 .39026 .63439 .34804 Metetra
.747 .762 .865 r
.63439 .34804 .66758 .39026 .69982 .37045 .66704 .32807 Metetra
.755 .765 .862 r
.66704 .32807 .69982 .37045 .73215 .34957 .69979 .30704 Metetra
.759 .768 .86 r
.69979 .30704 .73215 .34957 .76458 .32809 .73265 .28543 Metetra
.518 .685 .943 r
.25338 .40146 .29083 .44079 .32034 .44 .28314 .39968 Metetra
.53 .686 .938 r
.28314 .39968 .32034 .44 .35023 .43871 .31327 .39741 Metetra
.548 .689 .932 r
.31327 .39741 .35023 .43871 .38051 .43644 .3438 .39422 Metetra
.572 .695 .925 r
.3438 .39422 .38051 .43644 .41118 .43274 .37472 .38971 Metetra
.598 .703 .917 r
.37472 .38971 .41118 .43274 .44222 .42725 .40602 .3835 Metetra
.625 .711 .908 r
.40602 .3835 .44222 .42725 .47361 .41967 .43769 .37536 Metetra
.65 .719 .899 r
.43769 .37536 .47361 .41967 .50531 .40983 .46968 .3651 Metetra
.674 .727 .889 r
.46968 .3651 .50531 .40983 .53728 .39763 .50197 .35264 Metetra
.695 .734 .881 r
.50197 .35264 .53728 .39763 .56948 .38314 .53451 .33805 Metetra
.713 .741 .874 r
.53451 .33805 .56948 .38314 .60186 .36652 .56726 .32147 Metetra
.728 .748 .868 r
.56726 .32147 .60186 .36652 .63439 .34804 .60018 .30316 Metetra
.74 .754 .864 r
.60018 .30316 .63439 .34804 .66704 .32807 .63325 .28344 Metetra
.748 .759 .862 r
.63325 .28344 .66704 .32807 .69979 .30704 .66644 .26274 Metetra
.752 .764 .862 r
.66644 .26274 .69979 .30704 .73265 .28543 .69976 .24147 Metetra
.542 .695 .939 r
.21484 .36098 .25338 .40146 .28314 .39968 .24488 .35772 Metetra
.552 .692 .932 r
.24488 .35772 .28314 .39968 .31327 .39741 .27529 .35402 Metetra
.568 .692 .925 r
.27529 .35402 .31327 .39741 .3438 .39422 .30609 .34951 Metetra
.587 .695 .916 r
.30609 .34951 .3438 .39422 .37472 .38971 .33728 .34381 Metetra
.608 .698 .908 r
.33728 .34381 .37472 .38971 .40602 .3835 .36885 .33663 Metetra
.63 .704 .899 r
.36885 .33663 .40602 .3835 .43769 .37536 .4008 .32774 Metetra
.652 .71 .89 r
.4008 .32774 .43769 .37536 .46968 .3651 .43308 .31699 Metetra
.672 .716 .882 r
.43308 .31699 .46968 .3651 .50197 .35264 .46568 .30431 Metetra
.69 .723 .875 r
.46568 .30431 .50197 .35264 .53451 .33805 .49854 .28976 Metetra
.705 .73 .87 r
.49854 .28976 .53451 .33805 .56726 .32147 .53165 .27346 Metetra
.719 .737 .866 r
.53165 .27346 .56726 .32147 .60018 .30316 .56495 .25563 Metetra
.729 .745 .864 r
.56495 .25563 .60018 .30316 .63325 .28344 .59843 .23656 Metetra
.737 .752 .864 r
.59843 .23656 .63325 .28344 .66644 .26274 .63207 .21662 Metetra
.742 .758 .866 r
.63207 .21662 .66644 .26274 .69976 .24147 .66586 .19616 Metetra
.572 .707 .933 r
.17516 .3193 .21484 .36098 .24488 .35772 .20554 .31415 Metetra
.58 .701 .925 r
.20554 .31415 .24488 .35772 .27529 .35402 .23627 .3086 Metetra
.591 .697 .916 r
.23627 .3086 .27529 .35402 .30609 .34951 .26738 .30238 Metetra
.605 .696 .907 r
.26738 .30238 .30609 .34951 .33728 .34381 .29886 .29519 Metetra
.621 .696 .898 r
.29886 .29519 .33728 .34381 .36885 .33663 .33072 .28679 Metetra
.637 .698 .89 r
.33072 .28679 .36885 .33663 .4008 .32774 .36294 .27699 Metetra
.653 .702 .882 r
.36294 .27699 .4008 .32774 .43308 .31699 .39551 .26569 Metetra
.668 .707 .876 r
.39551 .26569 .43308 .31699 .46568 .30431 .4284 .25283 Metetra
.683 .713 .871 r
.4284 .25283 .46568 .30431 .49854 .28976 .46158 .23843 Metetra
.696 .72 .868 r
.46158 .23843 .49854 .28976 .53165 .27346 .49502 .22262 Metetra
.707 .727 .866 r
.49502 .22262 .53165 .27346 .56495 .25563 .52868 .20556 Metetra
.716 .735 .866 r
.52868 .20556 .56495 .25563 .59843 .23656 .56256 .18748 Metetra
.723 .744 .868 r
.56256 .18748 .59843 .23656 .63207 .21662 .59663 .16867 Metetra
.728 .752 .872 r
.59663 .16867 .63207 .21662 .66586 .19616 .63089 .14942 Metetra
.604 .719 .925 r
.13429 .27638 .17516 .3193 .20554 .31415 .16507 .26896 Metetra
.609 .71 .916 r
.16507 .26896 .20554 .31415 .23627 .3086 .19617 .26125 Metetra
.616 .703 .907 r
.19617 .26125 .23627 .3086 .26738 .30238 .22763 .25302 Metetra
.624 .699 .898 r
.22763 .25302 .26738 .30238 .29886 .29519 .25943 .24407 Metetra
.634 .696 .89 r
.25943 .24407 .29886 .29519 .33072 .28679 .2916 .23425 Metetra
.644 .695 .882 r
.2916 .23425 .33072 .28679 .36294 .27699 .32411 .22342 Metetra
.655 .696 .876 r
.32411 .22342 .36294 .27699 .39551 .26569 .35696 .21151 Metetra
.665 .699 .872 r
.35696 .21151 .39551 .26569 .4284 .25283 .39013 .19847 Metetra
.675 .704 .869 r
.39013 .19847 .4284 .25283 .46158 .23843 .4236 .18434 Metetra
.684 .71 .868 r
.4236 .18434 .46158 .23843 .49502 .22262 .45735 .16918 Metetra
.693 .717 .868 r
.45735 .16918 .49502 .22262 .52868 .20556 .49136 .15311 Metetra
.7 .726 .87 r
.49136 .15311 .52868 .20556 .56256 .18748 .52561 .13629 Metetra
.706 .735 .874 r
.52561 .13629 .56256 .18748 .59663 .16867 .5601 .11892 Metetra
.71 .745 .879 r
.5601 .11892 .59663 .16867 .63089 .14942 .59481 .1012 Metetra
.636 .729 .915 r
.09217 .23214 .13429 .27638 .16507 .26896 .12341 .22222 Metetra
.638 .719 .907 r
.12341 .22222 .16507 .26896 .19617 .26125 .15495 .21208 Metetra
.64 .71 .898 r
.15495 .21208 .19617 .26125 .22763 .25302 .1868 .20162 Metetra
.643 .703 .89 r
.1868 .20162 .22763 .25302 .25943 .24407 .21897 .19075 Metetra
.647 .697 .882 r
.21897 .19075 .25943 .24407 .2916 .23425 .25146 .17936 Metetra
.652 .694 .876 r
.25146 .17936 .2916 .23425 .32411 .22342 .28428 .16741 Metetra
.657 .693 .872 r
.28428 .16741 .32411 .22342 .35696 .21151 .31741 .15484 Metetra
.662 .694 .869 r
.31741 .15484 .35696 .21151 .39013 .19847 .35085 .14164 Metetra
.667 .697 .868 r
.35085 .14164 .39013 .19847 .4236 .18434 .3846 .12782 Metetra
.672 .702 .869 r
.3846 .12782 .4236 .18434 .45735 .16918 .41863 .11341 Metetra
.677 .708 .871 r
.41863 .11341 .45735 .16918 .49136 .15311 .45296 .09848 Metetra
.682 .717 .875 r
.45296 .09848 .49136 .15311 .52561 .13629 .48755 .0831 Metetra
.686 .726 .881 r
.48755 .0831 .52561 .13629 .5601 .11892 .52242 .06738 Metetra
.689 .737 .887 r
.52242 .06738 .5601 .11892 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12341 .22222 .08051 .17394 Metetra
.664 .727 .896 r
.08051 .17394 .12341 .22222 .15495 .21208 .11254 .16124 Metetra
.663 .717 .888 r
.11254 .16124 .15495 .21208 .1868 .20162 .14483 .14843 Metetra
.662 .708 .882 r
.14483 .14843 .1868 .20162 .21897 .19075 .1774 .13551 Metetra
.66 .7 .876 r
.1774 .13551 .21897 .19075 .25146 .17936 .21025 .12249 Metetra
.66 .695 .872 r
.21025 .12249 .25146 .17936 .28428 .16741 .24339 .10934 Metetra
.659 .692 .869 r
.24339 .10934 .28428 .16741 .31741 .15484 .27681 .09609 Metetra
.659 .69 .868 r
.27681 .09609 .31741 .15484 .35085 .14164 .31052 .08272 Metetra
.659 .692 .869 r
.31052 .08272 .35085 .14164 .3846 .12782 .34452 .06923 Metetra
.66 .695 .872 r
.34452 .06923 .3846 .12782 .41863 .11341 .37882 .05563 Metetra
.66 .7 .876 r
.37882 .05563 .41863 .11341 .45296 .09848 .41342 .04191 Metetra
.662 .708 .882 r
.41342 .04191 .45296 .09848 .48755 .0831 .44833 .02806 Metetra
.663 .717 .888 r
.44833 .02806 .48755 .0831 .52242 .06738 .48355 .01409 Metetra
.664 .727 .896 r
.48355 .01409 .52242 .06738 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onY^^Go0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojVj
i@?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nY^^D00ol0003oZK[Uo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nY^^D00ol0003oZK[UojVji@03ojVji@04o`000?nY^^GoZK[Uo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojVji@04o`000?nY^^GoZK[Uo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY]n?o0000ojVji@09
ojVji@05o`000?nY^^GoZK[UojVjiOl00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVghol0003oZKOS00;oZKOS
00?o0000ojVjiOnY^^D01onY^^D00ol0003oZK[UojVji@02ojVji@03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY]n<00ol0003oZK[UojVji@06ojVji@03o`000?nY^^GoZK[U00?oZK[U00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVgh`03o`000?nY^^GoZK[U00GoZK[U00?o0000
ojVjiOnY^^D00onY^^D00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKOS00?o0000ojVj
iOnY^^D01OnY^^D00ol0003oZK[UojVji@04ojVji@03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY]N400ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^^GoZK[U00CoZK[U00?o0000ojVjiOnY
^^D01OnY^^D00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKGQ00?o0000ojVg
honY]n<02_nY]n<00ol0003oZK[UojVji@03ojVji@03o`000?nY^^GoZK[U00KoZK[U00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY]N7o0000ojVeh@09ojVeh@03o`000?nY]n?o
ZKOS00_oZKOS00?o0000ojVjiOnY^^D00_nY^^D00ol0003oZK[UojVji@06ojVji@03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnX/n3o0000ojVehOnY]N7o000000[oZKGQ00?o0000ojVghonY]n<0
2_nY]n<00ol0003oZK[UojVji@02ojVji@03o`000?nY^^GoZK[U00OoZK[U00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZ;?P00?o0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`05
o`000?nY^^GoZK[UojVjiOl000002_nY^^D00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZ;?P
o`000?nX/n001OnX/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY]n?oZKOS00[oZKOS00Co0000
ojVjiOnY^^Go00002_nY^^D2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onX/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY
]n?oZKOS00_oZKOS00?o0000ojVjiOl000002?nY^^D2o`000003ok2lhol0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnX
/n000ol0003oZKGQojVeh@0;ojVeh@03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVjiOl000001OnY
^^D3o`0000Co/;cS00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojRag`03o`000?nX/Moo000000goZ;?P
00?o0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`;o00000onY^^D2o`0000So/;cS
00?o0000ooooooooool0Soooool008kooooo0ol00007ojRag`03o`000?nX/n3oZ;?P00[oZ;?P00?o
0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0;ojVgh`04o`000?nY^^Go0000o`0000_o/;cS
00?o0000ooooooooool0S_ooool008cooooo0ol00009ojRag`03o`000?nX/n3oZ;?P00_oZ;?P00?o
0000ojVehOnY]N402onY]N400ol0003oZKOSojVgh`0:ojVgh`;o00003On`_><2o`0008oooooo0029
ooooo`Co000000?oZ;7Oo`000?nX/Ml02OnX/Ml00ol0003oZ;?PojRch00;ojRch003o`000?nY]N7o
ZKGQ00_oZKGQ00?o0000ojVghonY]n<01onY]n<4o`0000ko/;cS00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onX/Mko0000ojRag`0<ojRag`03o`000?nX/n3oZ;?P00[oZ;?P00?o0000
ojVehOnY]N403?nY]N400ol0003oZKOSojVgh`04ojVgh`;o00000_n_^N400ol0003o[kWQo`00000>
ok2lh`03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZ;7N00?o0000ojRagonX/Ml02_nX/Ml0
0ol0003oZ;?PojRch00;ojRch003o`000?nY]N7oZKGQ00_oZKGQ00?o0000ojVghonY]n<00_nY]n<2
o`0000Co[kWQ00Co0000ojnihOn_^N7o00003_n`_><00ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oZ;7No`000?nX/Mh01_nX
/Mh00ol0003oZ;7OojRag`0:ojRag`03o`000?nX/n3oZ;?P00_oZ;?P00?o0000ojVehOnY]N402onY
]N401?l0003oZKOSo`000?l00006ojnih@05o`000?n_^N7o[kWQojnihOl000003On`_><2o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnX/Mh00ol0003oZ;7NojRagP04ojRagP03o`000?nX/MooZ;7O00_oZ;7O00?o0000ojRc
h?nX/n002_nX/n000ol0003oZKGQojVeh@0;ojVeh@;o00002?n_^N401Ol0003o[kWQojnihOn_^N7o
000000ko/;cS0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojR`g_l0003oZ;7N00coZ;7N00?o0000ojRagonX/Ml02_nX
/Ml00ol0003oZ;?PojRch00;ojRch003o`000?nY]N7oZKGQ00SoZKGQ0_l000000on^]moo0000ojni
h@07ojnih@03o`000?n_^N7o[kWQ00;o[kWQ00?o0000ok2lhon`_><03?n`_><00ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oZ;3N00Co0000ojR`g_nX/=ko00003OnX/Mh00ol0003oZ;7OojRag`0:ojRag`03o`00
0?nX/n3oZ;?P00_oZ;?P00?o0000ojVehOnY]N401?nY]N43o`0000Co[[OO00?o0000ojnihOn_^N40
1On_^N400ol0003o[kWQojnih@03ojnih@03o`000?n`_>?o/;cS00co/;cS00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojR`gP03o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojRagonX/Ml02onX/Ml00ol0003oZ;?P
ojRch00:ojRch003o`000?nY]N7oZKGQ00;oZKGQ0_l00008ojjgg`03o`000?n_^N7o[kWQ00Co[kWQ
00?o0000ojnihOn_^N401?n_^N400ol0003o/;cSok2lh`0;ok2lh`;o0000ROooool0053ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo013ooooo0ol0000<ojR`gP03o`00
0?nX/MkoZ;7N00[oZ;7N00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZ;?PojRch00;ojRch004o`00
0?nY]N7o0000o`0000[o[[OO00?o0000ojnihOn_^N401?n_^N400ol0003o[kWQojnih@04ojnih@03
o`000?n`_>?o/;cS00co/;cS0_l00028ooooo`00Loooool3o`000003ojRag_l0003o000000_oZ;3N
00?o0000ojRag_nX/Mh02onX/Mh00ol0003oZ;7OojRag`0:ojRag`03o`000?nX/n3oZ;?P00[oZ;?P
0_l0000=ojjgg`03o`000?n_^N7o[kWQ00?o[kWQ00?o0000ojnihOn_^N401On_^N400ol0003o/;cS
ok2lh`0<ok2lh`;o0000Qoooool0073ooooo0ol00005ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o
0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`0;ojRag`03o`000?nX/n3oZ;?P00KoZ;?P0ol0
00000on]]Mko0000ojjgg`0=ojjgg`03o`000?n_^N7o[kWQ00;o[kWQ00?o0000ojnihOn_^N401_n_
^N400ol0003o/;cSok2lh`09ok2lh`;o000000?o]KkQo`000?ooool0Q_ooool006kooooo0ol00008
ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`0:
ojRag`03o`000?nX/n3oZ;?P00?oZ;?P0ol00005ojfegP03o`000?n^]moo[[OO00_o[[OO00?o0000
ojnihOn_^N400_n_^N400ol0003o[kWQojnih@07ojnih@03o`000?n`_>?o/;cS00Ko/;cS0_l00003
okFnh@;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0002?ooooo0ol00002ojRagP03o`000?nX/MkoZ;7N00KoZ;7N00?o0000ojR`g_nX/=h02_nX/=h0
0ol0003oZ;7NojRagP0;ojRagP03o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRch?l000000_l00009
ojfegP03o`000?n^]moo[[OO00_o[[OO00Go0000ojnihOn_^N7o[kWQo`000009ojnih@03o`000?n`
_>?o/;cS00Go/;cS00?o0000okFnhOne_^401?ne_^42o`0008Gooooo000cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o0000
00?oZ;7Oo`000?nX/Mh02onX/Mh00ol0003oZ;3NojR`gP0:ojR`gP03o`000?nX/MkoZ;7N00[oZ;7N
00?o0000ojRagonX/Ml02_nX/Ml2o`0000go[KGN00?o0000ojjggon^]ml02on^]ml01?l0003o[kWQ
ojnihOl0000:ojnih@03o`000?n`_>?o/;cS00;o/;cS0_l00008okFnh@;o0000Q?ooool003?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00004ojRag`03
o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojR`g_nX/=h02_nX/=h00ol0003oZ;7NojRagP0:ojRagP03
o`000?nX/MooZ;7O00OoZ;7O0_l000000on//mko0000ojfegP0<ojfegP03o`000?n^]moo[[OO00co
[[OO00?o0000ojnihOl000002on_^N401?l0003o/;cSo`000?l0000;okFnh@03o`000?oooooooooo
08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Koooo
o`?o00001?nX/Ml00ol0003oZ;7OojRag`02ojRag`03o`000?nX/MkoZ;7N00WoZ;7N00?o0000ojR`
g_nX/=h02onX/=h00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/MooZ;7O00CoZ;7O0_l00004ojbc
gP03o`000?n]]Mko[KGN00_o[KGN00?o0000ojjggon^]ml02on^]ml00ol0003o[kWQo`00000;ojni
h@;o00003One_^42o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`0Hooooo`?o00002onX/Ml00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/=koZ;3N
00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh00ol0003oZ;7OojRag`02ojRag`;o00001on//mh00ol0
003o[KGNojfegP0;ojfegP03o`000?n^]moo[[OO00_o[[OO0_l00009ojnih@;o000000?o];cOo`00
0?ne_^403One_^42o`0008;ooooo000cooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`0Dooooo`?o000000?oZ;?Po`000?nX/Ml03?nX/Ml00ol0003oZ;7NojRagP0:ojRa
gP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh02_nX/Mh01?l0003oZ;7Oo`000?l00009
ojbcgP03o`000?n]]Mko[KGN00co[KGN00?o0000ojjggon^]ml02on^]ml00ol0003o[kWQojnih@04
ojnih@?o00001?nd_=l00ol0003o]KkQokFnh@0<okFnh@;o0000POooool003?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41005?ooool3o`0000CoZ;?P00?o
0000ojRagonX/Ml02onX/Ml00ol0003oZ;7NojRagP09ojRagP03o`000?nX/=koZ;3N00_oZ;3N00?o
0000ojRag_nX/Mh02OnX/Mh2o`0000co[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjg
g`0;ojjgg`03o`000?n_^N7o[kWQ00;o[kWQ0_l00008okBlg`03o`000?ne_^7o]KkQ00co]KkQ00?o
0000ooooooooool0Ooooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool3o`0000SoZ;?P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZ;7N
ojRagP0:ojRagP03o`000?nX/=koZ;3N00[oZ;3N00?o0000ojRag_nX/Mh01_nX/Mh3o`000003ojZb
g_l0003o[;?N00co[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjgg`0:ojjgg`;o0000
00?o[kWQo`000?l000002ond_=l00ol0003o]KkQokFnh@0;okFnh@;o0000P?ooool005Oooooo0ol0
00000onX/n3o0000ojRch008ojRch003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRag_nX/Mh02_nX
/Mh00ol0003oZ;3NojR`gP0:ojR`gP03o`000?nX/MkoZ;7N00?oZ;7N0_l00005ojZbgP03o`000?n/
/mko[;?N00_o[;?N00?o0000ojfeg_n]]Mh02on]]Mh00ol0003o[[OOojjgg`09ojjgg`?o00003Ond
_=l00ol0003o]KkQokFnh@0<okFnh@;o0000Ooooool005Cooooo0ol000000onY]N7o0000ojRch00;
ojRch003o`000?nX/MooZ;7O00_oZ;7O00?o0000ojRag_nX/Mh02OnX/Mh00ol0003oZ;3NojR`gP0;
ojR`gP03o`000?nX/Mko000000;o00002?nZ/]h00ol0003o[;?NojbcgP0:ojbcgP03o`000?n]]Mko
[KGN00co[KGN00?o0000ojjggon^]ml01on^]ml2o`000003ok>ig_l0003o];cO00go];cO00?o0000
okFnhOne_^403?ne_^400ol0003oooooooooo`1mooooo`00D_ooool3o`0000CoZKGQ00?o0000ojRc
h?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00[oZ;7N00?o0000ojR`
g_nX/=h02_nX/=h2o`0000_oZ[;N00?o0000ojbcg_n//mh02on//mh00ol0003o[KGNojfegP0;ojfe
gP03o`000?n^]moo[[OO00Go[[OO0_l000001Onc^Mko0000ok>ig_nc^Mko000000ko];cO00?o0000
okFnhOne_^403?ne_^400ol0003oooooooooo`1looooo`009oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo1?l000000onY]N7o0000ojVeh@04ojVeh@03o`000?nX/n3oZ;?P00[oZ;?P00?o0000
ojRagonX/Ml02_nX/Ml00ol0003oZ;7NojRagP0:ojRagP03o`000?nX/=koZ;3N00KoZ;3N0ol00000
0onY/Mko0000ojZbgP0;ojZbgP03o`000?n//mko[;?N00_o[;?N00?o0000ojfeg_n]]Mh02on]]Mh0
0ol0003o[[OOojjgg`02ojjgg`;o00000onc^Mh01Ol0003o/kWNok>ig_nc^Mko000000ko];cO00?o
0000okFnhOne_^402one_^42o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Ooo
ool3o`0000_oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003oZ;7OojRag`0;ojRag`03o`000?nX
/MkoZ;7N00WoZ;7N00?o0000ojR`g_nX/=h00onX/=h3o`0000GoZK7N00?o0000ojZbg_nZ/]h02_nZ
/]h00ol0003o[;?NojbcgP0:ojbcgP03o`000?n]]Mko[KGN00co[KGN00Co0000ojjggol0003o0000
1Onc^Mh00ol0003o/kWNok>igP02ok>igP03o`000?nd_=oo];cO00_o];cO00?o0000okFnhOne_^40
3?ne_^42o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@41007_ooool5o`0000coZKGQ
00?o0000ojRch?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00[oZ;7N
00?o0000ojR`g_l000000_l00009ojVagP03o`000?nZ/]koZ[;N00[oZ[;N00?o0000ojbcg_n//mh0
2_n//mh00ol0003o[KGNojfegP0;ojfegP;o00001onc^Mh00ol0003o/kWNok>igP02ok>igP03o`00
0?nd_=oo];cO00co];cO00?o0000okFnhOne_^402One_^42o`000003ok[0gol0003ooooo07_ooooo
000Wooooo`05o`000?ooooooooooooooool000007?ooool3o`0000;oZKOS00?o0000ojVghol00000
3?nY]N400ol0003oZ;?PojRch00:ojRch003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojRag_nX/Mh0
2OnX/Mh2o`0000coZK7N00?o0000ojZbg_nZ/]h02_nZ/]h00ol0003o[;?NojbcgP0;ojbcgP03o`00
0?n]]Mko[KGN00So[KGN0_l000000ona]mko0000ok>igP06ok>igP03o`000?nc^Mko/kWN00?o/kWN
00?o0000okBlgond_=l03?nd_=l00ol0003o]KkQokFnh@06okFnh@;o00001?nj`=l00ol0003ooooo
ooooo`1iooooo`009oooool01Ol0003ooooooooooooooooo000001Wooooo1?l00005ojVgh`03o`00
0?nY]n?o000000coZKGQ00?o0000ojRch?nX/n002_nX/n000ol0003oZ;7OojRag`0:ojRag`03o`00
0?nX/MkoZ;7N00GoZ;7N0ol000000onX/Moo0000ojVagP0<ojVagP03o`000?nZ/]koZ[;N00[oZ[;N
00?o0000ojbcg_n//mh02on//mh00ol0003o[KGNojfegP04ojfegP?o00001?na]mh00ol0003o/kWN
ok>igP04ok>igP03o`000?nc^Mko/kWN00Co/kWN00?o0000okBlgond_=l02ond_=l00ol0003o]KkQ
okFnh@05okFnh@03o`000?nj`=oo^/3O00Co^/3O0_l0001jooooo`009oooool01Ol@413ooooooooo
oooooooo410@01Oooooo0ol0000;ojVgh`03o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n00
2OnX/n000ol0003oZ;7OojRag`0:ojRag`03o`000?nX/MkoZ;7N00?oZ;7N0_l00005ojRag`03o`00
0?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ/]h02_nZ/]h00ol0003o[;?NojbcgP0:ojbcgP03o`00
0?n]]Mko[KGN00;o[KGN0_l00008ok6ggP03o`000?nc^Mko/kWN00?o/kWN00?o0000ok>ig_nc^Mh0
1Onc^Mh00ol0003o];cOokBlg`0;okBlg`03o`000?ne_^7o]KkQ00;o]KkQ0_l00008ok[0g`;o0000
NOooool002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`Go000000?oZKOSo`000?nY]n<0
2_nY]n<00ol0003oZKGQojVeh@0:ojVeh@03o`000?nX/n3oZ;?P00WoZ;?P00?o0000ojRagonX/Ml0
2_nX/Ml00ol0003oZ;7No`000002o`0000SoZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003oZ[;N
ojZbgP09ojZbgP03o`000?n//mko[;?N00_o[;?N00Co0000ojfeg_l0003o00002_na]mh00ol0003o
/kWNok>igP03ok>igP03o`000?nc^Mko/kWN00Go/kWN00?o0000okBlgond_=l03?nd_=l01?l0003o
]KkQo`000?l0000;ok[0g`03o`000?oooooooooo07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04_ooool3o`0000CoZK[U00?o0000ojVghonY]n<02_nY]n<00ol0003oZKGQojVeh@0:ojVe
h@03o`000?nX/n3oZ;?P00[oZ;?P00?o0000ojRagonX/Ml02OnX/Ml2o`0000_oZ;7O00?o0000ojVa
g_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP0:ojZbgP03o`000?n//mko[;?N00[o[;?N0_l0000=ok6g
gP03o`000?nc^Mko/kWN00;o/kWN00?o0000ok>ig_nc^Mh01_nc^Mh00ol0003o];cOokBlg`0;okBl
g`;o00003_nj`=l00ol0003oooooooooo`1fooooo`00>oooool5o`0000KoZK[U00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKGQojVeh@0:ojVeh@03o`000?nX/n3oZ;?P00WoZ;?P00?o0000ojRagonX
/Ml01_nX/Ml3o`000003ojJah?l0003oZ;7O00_oZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003o
Z[;NojZbgP0:ojZbgP03o`000?n//mko[;?N00Oo[;?N0_l000000on_]Mko0000ok6ggP0=ok6ggP05
o`000?nc^Mko/kWNok>ig_l000002Onc^Mh00ol0003o];cOokBlg`08okBlg`;o000000?o^KkNo`00
0?nj`=l03Onj`=l2o`0007Oooooo000iooooo`?o00002onY^^D00ol0003oZKOSojVgh`0:ojVgh`03
o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003oZ;7OojRag`03ojRag`;o
00001OnV/N000ol0003oZ;7OojRag`0:ojRag`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ
/]h02_nZ/]h00ol0003o[;?NojbcgP04ojbcgP;o00001?n_]Mh00ol0003o/KONok6ggP0;ok6ggP05
o`000?nc^Mko/kWNok>ig_l000002_nc^Mh00ol0003o];cOokBlg`06okBlg`03o`000?ni_]ko^KkN
00;o^KkN00?o0000ok[0gonj`=l03?nj`=l2o`0007Kooooo000gooooo`Co00003OnY^^D00ol0003o
ZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00[oZKGQ00?o0000ojRch?nX/n002OnX/n000ol0003o
Z;7Oo`000002o`0000SoY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP0:ojVagP03
o`000?nZ/]koZ[;N00[oZ[;N00?o0000ojbcg_n//mh00_n//mh2o`0000Oo[kGN00?o0000ok6gg_na
]mh02ona]mh01?l0003o/kWNok>ig_l0000:ok>igP03o`000?nd_=oo];cO00Co];cO0_l00006okVn
gP03o`000?nj`=oo^/3O00co^/3O00?o0000ooooooooool0M?ooool003Cooooo0ol000001OnZ_>Oo
0000ojZlionZ_>Oo000000coZK[U00?o0000ojVghonY]n<02onY]n<00ol0003oZKGQojVeh@09ojVe
h@03o`000?nX/n3oZ;?P00SoZ;?P0ol0000;ojJah003o`000?nX/MooZ;7O00[oZ;7O00?o0000ojVa
g_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP0:ojZbgP04o`000?n//mko0000o`0000Wo[kGN00?o0000
ok6gg_na]mh03?na]mh00ol0003o/kWNo`00000;ok>igP04o`000?nd_=oo];cOokBlg`;o00002Oni
_]h00ol0003o^/3Ook[0g`0<ok[0g`03o`000?oooooooooo07?ooooo000booooo`?o00001onZ_>L0
0ol0003oZK[UojVji@0:ojVji@03o`000?nY]n?oZKOS00_oZKOS00?o0000ojVehOnY]N402OnY]N40
0ol0003oZ;?PojRch004ojRch0?o00000_nU/^400ol0003oY[7PojJah00:ojJah003o`000?nX/Moo
Z;7O00[oZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003oZ[;NojZbgP09ojZbgP;o00003?n_]Mh0
0ol0003o/KONok6ggP0;ok6ggP03o`000?nc^Mko000000co/kWN00?o0000okBlgol000002oni_]h0
0ol0003o^/3Ook[0g`0<ok[0g`;o0000M?ooool0037ooooo00?o0000ojZlionZ_>L02OnZ_>L00ol0
003oZK[UojVji@0:ojVji@03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVehOnY]N402_nY]N400ol0
003oZ;?PojRch003o`0000KoYK;Q00?o0000ojJah?nV/N002_nV/N000ol0003oZ;7OojRag`0:ojRa
g`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_nZ/]h01OnZ/]h3o`000003ojbdg_l0003o[kGN
00co[kGN00?o0000ok6gg_na]mh02ona]mh2o`0000co/kWN0_l0000=okVngP03o`000?nj`=oo^/3O
00co^/3O00?o0000ooooooooool0L_ooool0037ooooo0_l0000;ojZli`03o`000?nY^^GoZK[U00[o
ZK[U00?o0000ojVghonY]n<02_nY]n<00ol0003oZKGQojVeh@08ojVeh@Co00002_nU/^400ol0003o
Y[7PojJah00:ojJah003o`000?nX/MooZ;7O00WoZ;7O00?o0000ojVag_nY/Mh02onY/Mh00ol0003o
Z[;NojZbgP03ojZbgP;o00001On/]=h00ol0003o[kGNojnegP0;ojnegP03o`000?na]mko/KON00[o
/KON0_l0000:ok>igP;o000000?o]kcMo`000?ni_]h03Oni_]h00ol0003o^/3Ook[0g`0<ok[0g`03
o`000?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000co
Z[cW00?o0000ojVjiOnY^^D02_nY^^D00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00Co
ZKGQ0ol00002ojBch`03o`000?nU/^7oYK;Q00[oYK;Q00?o0000ojJah?nV/N002OnV/N000ol0003o
Z;7OojRag`0:ojRag`03o`000?nY/MkoZK7N00_oZK7N00?o0000ojZbg_l000000_l00008ojbdgP03
o`000?n_]Mko[kGN00[o[kGN00?o0000ok6gg_na]mh02ona]mh00ol0003o/kWNok>igP06ok>igP;o
00001?ng_=d00ol0003o^KkNokVngP0<okVngP03o`000?nj`=oo^/3O00co^/3O00?o0000oooooooo
ool0L?ooool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000co
Z[cW00?o0000ojVjiOnY^^D02_nY^^D00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N7oZKGQ00?o
00001_nT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P00[oY[7P00?o0000ojRagonX
/Ml02_nX/Ml00ol0003oZK7NojVagP0:ojVagP;o00002on/]=h00ol0003o[kGNojnegP0;ojnegP03
o`000?na]mko/KON00[o/KON0_l00006ok>igP03o`000?ng_=go]kcM00Go]kcM00?o0000okVng_ni
_]h02oni_]h00ol0003o^/3Ook[0g`0<ok[0g`;o0000LOooool002Gooooo00Go410@oooooooooooo
oooooa0@4007ooooo`04o`000?ooooooooooo`0000coZ[cW00?o0000ojVjiOnY^^D02OnY^^D00ol0
003oZKOSojVgh`0:ojVgh`?o00002_nT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P
00[oY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP06ojVagP?o000000?oZ[;Oo`00
0?n/]=h02on/]=h00ol0003o[kGNojnegP0;ojnegP03o`000?na]mko/KON00Wo/KON0_l00004ok>i
gP;o00002Ong_=d00ol0003o^KkNokVngP0;okVngP03o`000?nj`=oo^/3O00Wo^/3O0_l000000onm
`]go0000ooooo`1`ooooo`009Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00003oooo
o`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojVjiOnY^^D02OnY^^D00ol0003oZKOSojVgh`06ojVg
h`?o000000?oXkGUo`000?nT/n<02onT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P
00WoY[7P00?o0000ojRagonX/Ml02_nX/Ml00ol0003oZK7NojVagP03ojVagP?o00001OnZ/]l00ol0
003o[;CNojbdgP0:ojbdgP03o`000?n_]Mko[kGN00[o[kGN00?o0000ok6gg_na]mh02Ona]mh01?l0
003o/KONo`000?nc^Mh2o`0000_o]kcM00?o0000okVng_ni_]h03?ni_]h00ol0003o^/3Ook[0g`06
ok[0g`;o00001?nm`]d00ol0003oooooooooo`1^ooooo`009Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00oooool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^Go
ZK[U00WoZK[U00?o0000ojVghonY]n<00onY]n<2o`0000GoXkGU00?o0000ojBchonT/n<02OnT/n<0
0ol0003oYK;QojFbh@0:ojFbh@03o`000?nV/N3oY[7P00WoY[7P00?o0000ojRagonX/Ml02_nX/Ml0
0ol0003oZK7No`000002o`0000WoZ[;O00?o0000ojbdg_n/]=h02_n/]=h00ol0003o[kGNojnegP0:
ojnegP03o`000?na]mko/KON00So/KON00Co0000ok6gg_l0003o00003_ng_=d00ol0003o^KkNokVn
gP0;okVngP03o`000?nj`=oo^/3O00Go^/3O00?o0000okg2gOnm`]d01Onm`]d00ol0003ooooooooo
o`1]ooooo`009Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^GoZK[U00WoZK[U00?o0000ojVghol000000_l0
0008oj>ei@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402OnU/^400ol0003oY[7PojJa
h00:ojJah003o`000?nX/MooZ;7O00WoZ;7O0_l0000<ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o
0000ojneg_n_]Mh02on_]Mh00ol0003o/KONok6ggP07ok6ggP;o000000?o];[Mo`000?ng_=d03_ng
_=d00ol0003o^KkNokVngP0;okVngP03o`000?nj`=oo^/3O00;o^/3O0_l00008okg2g@;o0000K_oo
ool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ojZlionZ_>L02_nZ_>L00ol0003oZK[UojVji@08ojVji@;o00003?nS]ND00ol0003oY;?SojBc
h`09ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N002_nV/N000ol0003oZ;7OojRa
g`05ojRag`?o000000?oYk;Po`000?nZ/]l03?nZ/]l00ol0003o[;CNojbdgP0:ojbdgP03o`000?n_
]Mko[kGN00_o[kGN00?o0000ok6gg_na]mh01?na]mh3o`0000?o];[M00?o0000okNlgOng_=d03Ong
_=d00ol0003o^KkNokVngP0;okVngP04o`000?nj`=oo0000o`0000_o_L;M00?o0000ooooooooool0
K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZK[UojVji@04ojVji@?o000000?oXkSXo`000?nS]ND0
3?nS]ND00ol0003oY;?SojBch`09ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N00
2OnV/N000ol0003oZ;7OojRag`03ojRag`;o00001OnW/^000ol0003oZ[;OojZbg`0;ojZbg`03o`00
0?n/]=ko[;CN00[o[;CN00?o0000ojneg_n_]Mh02_n_]Mh00ol0003o/KONok6ggP02ok6ggP;o0000
0_nd^]d00ol0003o];[MokBjg@02okBjg@03o`000?ng_=go]kcM00co]kcM00?o0000okVng_ni_]h0
2oni_]h2o`0000ko_L;M00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01ooo
ool00ol0003oZ[cWojZli`0:ojZli`03o`000?nY^^GoZK[U00?o00001OnS^>P00ol0003oXkGUoj>e
i@0:oj>ei@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402_nU/^400ol0003oY[7PojJa
h009ojJah003o`000?nX/Moo000000;o00002?nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/
]=ko[;CN00[o[;CN00?o0000ojneg_n_]Mh02on_]Mh01?l0003o/KONo`000?l00004okBjg@03o`00
0?nd^]go];[M00?o];[M00?o0000okNlgOng_=d03?ng_=d00ol0003o^KkNokVngP08okVngP;o0000
00?o_<3Mo`000?nm`]d03_nm`]d00ol0003oooooooooo`1Zooooo`00<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?nZ_>OoZ[cW00SoZ[cW1?l00009oj>hj003o`000?nS]NGoXkGU00[oXkGU00?o
0000ojBchonT/n<02OnT/n<00ol0003oYK;QojFbh@09ojFbh@03o`000?nV/N3oY[7P00SoY[7P0ol0
000;ojNbh003o`000?nZ/]ooZ[;O00_oZ[;O00?o0000ojbdg_n/]=h02_n/]=h00ol0003o[kGNojne
gP0:ojnegP;o00001_nd^]d00ol0003o];[MokBjg@04okBjg@03o`000?ng_=go]kcM00co]kcM00?o
0000okVng_ni_]h01_ni_]h00ol0003o_<3Mokc0g@02okc0g@03o`000?nm`]go_L;M00co_L;M00?o
0000ooooooooool0J_ooool002oooooo0_l0000;ooooo`03o`000?nZ_>OoZ[cW00CoZ[cW0ol00002
oj:jjP03o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`09
ojBch`03o`000?nU/^7oYK;Q00WoYK;Q00?o0000ojJah?nV/N001?nV/N03o`0000;oY;7Q00?o0000
ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0;ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o0000
ojneg_n_]Mh01on_]Mh2o`000003ok:hg_l0003o];[M00Go];[M00?o0000okBjgOnd^]d01?nd^]d0
0ol0003o]kcMokNlg@0<okNlg@03o`000?ni_]ko^KkN00Co^KkN0_l00006okc0g@03o`000?nm`]go
_L;M00co_L;M00?o0000ooooooooool0JOooool0033ooooo00?o0000ooooooooool02_ooool00ol0
003oZ[cWojZli`03o`0000KoX[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@0:oj>e
i@03o`000?nT/n?oY;?S00WoY;?S00?o0000ojFbhOnU/^402OnU/^400ol0003oY[7PojJah003o`00
00KoY;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN
00_o[;CN00?o0000ojneg_n_]Mh01?n_]Mh2o`0000Co/[SN00?o0000okBjgOnd^]d00ond^]d00ol0
003o];[MokBjg@05okBjg@03o`000?ng_=go]kcM00co]kcM00Co0000okVng_ni_]ko^KkN0_l00009
okc0g@03o`000?nm`]go_L;M00co_L;M00?o0000ooooooooool0J?ooool002oooooo00?o0000oooo
ooooool03?ooool2o`0000[oX[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@0:oj>e
i@03o`000?nT/n?oY;?S00SoY;?S00?o0000ojFbhOnU/^402?nU/^44o`0000[oY;7Q00?o0000ojNb
h?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN00[o[;CN00?o0000ojne
g_n_]Mh00_n_]Mh2o`0000Oo/[SN00?o0000okBjgOnd^]d00_nd^]d00ol0003o];[MokBjg@06okBj
g@03o`000?ng_=go]kcM00co]kcM00?o0000okVng_l000003?nl`=d00ol0003o_L;Mokg2g@0<okg2
g@03o`000?oooooooooo06Oooooo000_ooooo`03o`000?oooooooooo00gooooo00?o0000oj:jj_nR
^^X02OnR^^X00ol0003oXkSXoj>hj009oj>hj003o`000?nS]NGoXkGU00[oXkGU00?o0000ojBchonT
/n<02?nT/n<00ol0003oYK;QojFbh@04ojFbh@?o00000_nR/^<00ol0003oY;7QojBah@09ojBah@03
o`000?nW/^3oYk;P00[oYk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP0;ojbdgP04
o`000?n_]Mko0000o`0000Wo/[SN00?o0000okBjgOnd^]d00_nd^]d00ol0003o];[MokBjg@07okBj
g@03o`000?ng_=go]kcM00_o]kcM0_l0000=okc0g@03o`000?nm`]go_L;M00co_L;M00?o0000oooo
ooooool0Ioooool002oooooo00?o0000ooooooooool03_ooool00ol0003oX[[Zoj:jjP09oj:jjP03
o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02OnS]ND00ol0003oY;?SojBch`09ojBch`03
o`000?nU/^7oYK;Q00?o00001_nR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[o
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP0:ojbdgP;o00003?nb^=h01Ol0003o
];[MokBjgOnd^]go000000[o];[M00?o0000okNlgOng_=d02?ng_=d2o`000003okZngOl0003o_<3M
00go_<3M00?o0000okg2gOnm`]d03?nm`]d00ol0003oooooooooo`1Vooooo`00;oooool00ol0003o
ooooooooo`0?ooooo`03o`000?nR^^[oX[[Z00WoX[[Z00?o0000oj>hj?nS^>P02?nS^>P00ol0003o
XkGUoj>ei@0:oj>ei@03o`000?nT/n?oY;?S00SoY;?S0ol0000:oj:bh`03o`000?nT/N7oY;7Q00Wo
Y;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`0:ojZbg`03o`000?n/]=ko[;CN00Ko
[;CN0ol000000on^]]ko0000ok:hgP0<ok:hgP04o`000?nd^]go];[Mo`0000[o];[M00?o0000okNl
gOng_=d01ong_=d00ol0003o^[kMokZng@02okZng@03o`000?nl`=go_<3M00co_<3M00?o0000okg2
gOnm`]d02onm`]d2o`0006Oooooo000^ooooo`?o00004Oooool00ol0003oX[[Zoj:jjP09oj:jjP03
o`000?nS^>SoXkSX00SoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`04ojBch`?o
000000?oWk;Uo`000?nR/^<02_nR/^<00ol0003oY;7QojBah@0:ojBah@03o`000?nW/^3oYk;P00Wo
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNojbdgP03ojbdgP?o00001On^]]h00ol0003o
/[SNok:hgP0:ok:hgP04o`000?nd^]go];[Mo`0000_o];[M00?o0000okNlgOng_=d01?ng_=d2o`00
00Ko^[kM00?o0000okc0gOnl`=d03?nl`=d00ol0003o_L;Mokg2g@08okg2g@;o000000?o`<?Lo`00
0?l00000I_ooool002oooooo00?o0000ooooooooool04Oooool00ol0003oX[[Zoj:jjP08oj:jjP03
o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND02_nS]ND00ol0003oY;?SojBch`03o`0000Go
Wk;U00?o0000oj:bhonR/^<02OnR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[o
Yk;P00?o0000ojZbgonZ/]l02_nZ/]l00ol0003o[;CNo`000002o`0000Wo[[KN00?o0000ok:hg_nb
^=h02_nb^=h00ol0003o];[Mo`00000<okBjg@04o`000?ng_=go]kcMokNlg@;o00002Onj_]d00ol0
003o_<3Mokc0g@0;okc0g@03o`000?nm`]go_L;M00Oo_L;M00?o0000ol33g?o0`m`00_o0`m`00ol0
003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Booooo`03o`000?nR^^[oX[[Z00So
X[[Z00?o0000oj>hj?nS^>P02OnS^>P00ol0003oXkGUoj>ei@08oj>ei@Co00002OnO/^D00ol0003o
X[;Soj:bh`09oj:bh`03o`000?nT/N7oY;7Q00WoY;7Q00?o0000ojNbh?nW/^002_nW/^000ol0003o
Z[;OojZbg`09ojZbg`;o00003?n^]]h00ol0003o/[SNok:hgP0;ok:hgP;o00003Ond^]d00ol0003o
]kcMo`00000;okZng@03o`000?nl`=go_<3M00co_<3M00?o0000okg2gOnm`]d01?nm`]d2o`0000Ko
`<?L00?o0000ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oX[[Z
oj:jjP08oj:jjP03o`000?nS^>SoXkSX00WoXkSX00?o0000oj>eiOnS]ND01?nS]ND3o`0000;oWK?X
00?o0000oinbiOnO/^D02OnO/^D00ol0003oX[;Soj:bh`09oj:bh`03o`000?nT/N7oY;7Q00WoY;7Q
00?o0000ojNbh?nW/^002_nW/^000ol0003oZ[;OojZbg`05ojZbg`?o000000?oZkCPo`000?n^]]h0
3?n^]]h00ol0003o/[SNok:hgP0;ok:hgP03o`000?nd^]go];[M00_o];[M0_l0000=okZng@03o`00
0?nl`=go_<3M00co_<3M00Co0000okg2gOnm`]go_L;M0_l00009ol33g003o`000?oooooooooo06;o
oooo000_ooooo`03o`000?oooooooooo01?ooooo0_l0000:oj:jjP03o`000?nS^>SoXkSX00WoXkSX
00?o0000oj>eiOnS]ND00ol00006oifcj003o`000?nO/^GoWk;U00WoWk;U00?o0000oj:bhonR/^<0
2?nR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[oYk;P00?o0000ojZbgonZ/]l0
0onZ/]l2o`0000GoZkCP00?o0000ojjfg_n^]]h02on^]]h00ol0003o/[SNok:hgP0:ok:hgP03o`00
0?nd^]go];[M00Wo];[M0_l000000onh_=go0000okZng@0=okZng@03o`000?nl`=go_<3M00co_<3M
00?o0000okg2gOl000002oo0`m`2o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l0
000:oj:jjP03o`000?nS^>SoXkSX00OoXkSX1?l0000:oifcj003o`000?nO/^GoWk;U00SoWk;U00?o
0000oj:bhonR/^<02OnR/^<00ol0003oY;7QojBah@09ojBah@03o`000?nW/^3oYk;P00[oYk;P00?o
0000ojZbgol000000_l00008oj^dh003o`000?n^]]ko[[KN00[o[[KN00?o0000ok:hg_nb^=h02_nb
^=h2o`0000So];[M0_l00004okRlg@03o`000?nj_]go^[kM00co^[kM00?o0000okc0gOnl`=d02onl
`=d2o`0000go`<?L00?o0000ooooooooool0HOooool002kooooo0ol0000Fooooo`;o00002_nR^^X0
1?l0003oXkSXoj>hj?nS^>P5o`0000;oVkGZ00?o0000oifcj?nM/nP02_nM/nP00ol0003oWk;Uoinb
i@08oinbi@03o`000?nR/^?oX[;S00WoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;PojNb
h009ojNbh0;o00003?n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`000?nb^=ko/[SN00Wo/[SN00?o
0000ok:hg_l000001_nd^]d00ol0003o^;cMokRlg@05okRlg@03o`000?nj_]go^[kM00_o^[kM00?o
0000okc0gOnl`=d02_nl`=d00ol0003o_l;Lo`00000>ol33g003o`000?oooooooooo063ooooo000^
ooooo`03o`000?oooooooooo01Oooooo0_l00008oj:jjPGo00002?nK]NX00ol0003oWK?Xoifcj00:
oifcj003o`000?nO/^GoWk;U00SoWk;U00?o0000oj:bhonR/^<02?nR/^<00ol0003oY;7QojBah@0:
ojBah@03o`000?nW/^3oYk;P00GoYk;P0ol000000onW/n7o0000oj^dh00;oj^dh003o`000?n^]]ko
[[KN00_o[[KN00?o0000ok:hg_nb^=h02?nb^=h00ol0003o/[SNo`000004okBjg@;o00002?nh_=d0
0ol0003o^[kMokZng@0<okZng@03o`000?nl`=go_<3M00Oo_<3M0_l00003oko2g003o`000?o0`mco
`<?L00co`<?L00?o0000ooooooooool0Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Oooooo00?o0000ooooooooool06?ooool2o`0000;oX[[Z1Ol00002
oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;Uoinbi@09
oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;PojNbh003
ojNbh0;o00001OnW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00_o[[KN00?o0000
ok:hg_nb^=h01onb^=h01Ol0003o/[SNok:hg_l0003o];[M00;o00002onh_=d00ol0003o^[kMokZn
g@0<okZng@03o`000?nl`=go_<3M00Go_<3M00?o0000oko2g?no`]`01?no`]`00ol0003o`<?Lol33
g00<ol33g003o`000?oooooooooo05kooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03o`000?oooooooooo01Wooooo
0ol00008oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;U
oinbi@09oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N402OnT/N400ol0003oYk;P
o`000002o`0000SoYk?Q00?o0000oj^dh?n[]>002_n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`00
0?nb^=ko/[SN00Oo/[SN00?o0000ok:hg_nb^=h00_l0000>okRlg@03o`000?nj_]go^[kM00_o^[kM
00?o0000okc0gOnl`=d01?nl`=d00ol0003o_l;Loko2g006oko2g003o`000?o0`mco`<?L00_o`<?L
00?o0000ooooooooool0G_ooool001;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_ooool00ol0003oV[S/oiZhk008oiZhk003o`00
0?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003oWk;Uoinbi@09oinbi@03o`00
0?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N401onT/N43o`0000coYk?Q00?o0000oj^dh?n[]>00
2_n[]>000ol0003o[[KNojjfgP0:ojjfgP03o`000?nb^=ko/[SN00Ko/[SN0ol000000ond^]ko0000
okRlg@0=okRlg@03o`000?nj_]go^[kM00co^[kM00Co0000okc0gOnl`=go_<3M0_l00009oko2g003
o`000?o0`mco`<?L00co`<?L00?o0000ooooooooool0GOooool001;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06oooool00ol0003o
V[S/oiZhk008oiZhk003o`000?nK]N[oVkGZ00WoVkGZ00?o0000oifcj?nM/nP02OnM/nP00ol0003o
Wk;Uoinbi@08oinbi@03o`000?nR/^?oX[;S00SoX[;S00?o0000ojBahOnT/N401?nT/N43o`0000;o
Xk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00_o
[[KN00?o0000ok:hg_nb^=h01?nb^=h2o`0000Co];[N00?o0000okRlgOnh_=d03?nh_=d00ol0003o
^[kMokZng@0<okZng@03o`000?nl`=go000000co_l;L00?o0000ol33g?o0`m`03?o0`m`00ol0003o
ooooooooo`1Looooo`004_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?nJ^>coV[S/00SoV[S/00?o0000oi^ej_nK
]NX02OnK]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00SoWk;U00?o0000oj:bhonR
/^<02?nR/^<00ol0003oY;7QojBah@03o`0000KoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003o
ZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00[o[[KN00?o0000ok:hg_nb^=h00_nb^=h2o`000003
okBjg_l0003o];[N00Co];[N00?o0000okRlgOnh_=d03?nh_=d00ol0003o^[kMokZng@0;okZng@;o
00003_no`]`00ol0003o`<?Lol33g00;ol33g0;o0000GOooool001;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00Cooooo0_l0000Oooooo`03o`000?nJ^>coV[S/00So
V[S/00?o0000oi^ej_nK]NX02?nK]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00Wo
Wk;U00?o0000oj:bhonR/^<01_nR/^<4o`0000[oXk;S00?o0000ojNchOnW/n402_nW/n400ol0003o
ZkCPoj^dh00:oj^dh003o`000?n^]]ko[[KN00[o[[KN00Co0000ok:hg_l0003o00000ond^]h00ol0
003o];[NokBjgP04okBjgP03o`000?nh_=go^;cM00_o^;cM00?o0000okZngOnj_]d02Onj_]d2o`00
0003okg1gOl0003o_l;L00go_l;L00?o0000ol33g?o0`m`02_o0`m`00ol0003o`/CLo`00001Moooo
o`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo01oooooo00?o0000oiZhk?nJ^>`02?nJ^>`00ol0003oVkGZoi^ejP08
oi^ejP03o`000?nM/nSoWK?X00WoWK?X00?o0000oinbiOnO/^D02OnO/^D00ol0003oX[;Soj:bh`05
o`0000;oW[;U00?o0000oj>bhonS/^<02_nS/^<00ol0003oYk?QojNch@0:ojNch@03o`000?n[]>3o
ZkCP00[oZkCP00?o0000ojjfg_n^]]h02On^]]h2o`0000Go];[N00?o0000okBjg_nd^]h01Ond^]h0
0ol0003o^;cMokRlg@0;okRlg@03o`000?nj_]go^[kM00Ko^[kM0_l00004okg1g@03o`000?no`]co
_l;L00co_l;L00?o0000ol33g?o0`m`01oo0`m`2o`0000?o`/CL00?o0000ooooooooool0F_ooool0
01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?nJ^>coV[S/00SoV[S/00?o0000oi^ej_nK]NX02?nK
]NX00ol0003oWK?Xoifcj009oifcj003o`000?nO/^GoWk;U00OoWk;U1?l00008oijbi@03o`000?nS
/^?oXk;S00[oXk;S00?o0000ojNchOnW/n402OnW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^
]]ko[[KN00Ko[[KN0ol000000on`^Moo0000okBjgP04okBjgP03o`000?nd^]ko];[N00Go];[N00?o
0000okRlgOnh_=d03?nh_=d00ol0003o^[kMokZng@04okZng@03o`000?nm`Mgo_L7M00Go_L7M00?o
0000oko2g?no`]`03?no`]`00ol0003o`<?Lol33g005ol33g003o`000?o2a=co`/CL00Co`/CL00?o
0000ooooooooool0FOooool002gooooo00?o0000ooooooooool08Oooool00ol0003oV[S/oiZhk008
oiZhk003o`000?nK]N[oVkGZ00SoVkGZ00?o0000oifcj?nM/nP02OnM/nP01?l0003oWk;UoinbiOnO
/^D5o`0000;oV[;X00?o0000oijbiOnN/^D02?nN/^D00ol0003oXk;Soj>bh`09oj>bh`03o`000?nW
/n7oYk?Q00[oYk?Q00?o0000oj^dh?n[]>002_n[]>000ol0003o[[KNojjfgP03ojjfgP;o00001On`
^Ml00ol0003o];[NokBjgP02okBjgP03o`000?nd^]ko];[N00Ko];[N00?o0000okRlgOnh_=d02onh
_=d00ol0003o^[kMokZng@02okZng@;o00002Onm`Md00ol0003o_l;Loko2g00<oko2g003o`000?o0
`mco`<?L00?o`<?L00?o0000ol;4g?o2a=`01_o2a=`00ol0003oooooooooo`1Hooooo`00;Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?nJ^>coV[S/00WoV[S/00?o0000oi^ej_nK]NX02?nK]NX0
0ol0003oWK?Xoifcj007oifcj0Go00002?nJ/^P00ol0003oW[;Uoijbi@08oijbi@03o`000?nS/^?o
Xk;S00WoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPoj^dh00:oj^dh003o`000?n^]]ko
000000;o00002?n`^Ml01Ol0003o];[NokBjg_nd^]ko000000Wo];[N00?o0000okRlgOnh_=d02onh
_=d01?l0003o^[kMo`000?l0000;okg1g@03o`000?no`]co_l;L00co_l;L00Co0000ol33g?o0`mco
`<?L0_l00009ol;4g003o`000?oooooooooo05Sooooo000]ooooo`03o`000?oooooooooo02;ooooo
00?o0000oiZhk?nJ^>`02OnJ^>`00ol0003oVkGZoi^ejP08oi^ejP04o`000?nM/nSoWK?Xoifcj0Go
00000_nG/^X00ol0003oV[;XoiZbj009oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS
/^<02OnS/^<00ol0003oYk?QojNch@0:ojNch@03o`000?n[]>3oZkCP00WoZkCP0_l0000<ok2ig`04
o`000?nd^]ko];[No`0000[o];[N00?o0000okRlgOnh_=d02_nh_=d2o`0000ko_L7M00?o0000oko2
g?no`]`03?no`]`00ol0003o`<?Lo`00000<ol;4g003o`000?oooooooooo05Oooooo000/ooooo`?o
00009?ooool00ol0003oV[S/oiZhk009oiZhk003o`000?nK]N[oVkGZ00KoVkGZ1Ol00008oiNbjP03
o`000?nJ/^SoV[;X00WoV[;X00?o0000oijbiOnN/^D01onN/^D00ol0003oXk;Soj>bh`0:oj>bh`03
o`000?nW/n7oYk?Q00WoYk?Q00?o0000oj^dh?n[]>001_n[]>03o`000003ojbghOl0003o/;WO00co
/;WO00?o0000okBjg_l000002_nd^]h00ol0003o^;cMokRlg@08okRlg@;o000000?o^[oNo`000?nm
`Md03_nm`Md00ol0003o_l;Loko2g00;oko2g0;o00003_o2a=`00ol0003oooooooooo`1Fooooo`00
;Oooool00ol0003oooooooooo`0Tooooo`03o`000?nJ^>coV[S/00WoV[S/00?o0000oi^ej_nK]NX0
1Ol00002oiBck003o`000?nG/^[oUk;Z00WoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;U
oijbi@08oijbi@03o`000?nS/^?oXk;S00[oXk;S00?o0000ojNchOnW/n402OnW/n400ol0003oZkCP
oj^dh003oj^dh0;o00001On/]n400ol0003o/;WOok2ig`0:ok2ig`03o`000?nd^]ko000000_o];[N
00?o0000okRlgOnh_=d01Onh_=d2o`0000Co^[oN00?o0000okg1gOnm`Md03Onm`Md00ol0003o_l;L
oko2g008oko2g0;o000000?o`L?Lo`000?o2a=`03_o2a=`00ol0003oooooooooo`1Eooooo`00;Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?nJ^>coV[S/00OoV[S/1?l00008oiBck003o`000?nG
/^[oUk;Z00WoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;Uoijbi@08oijbi@03o`000?nS
/^?oXk;S00WoXk;S00?o0000ojNchOnW/n402_nW/n400ol0003oZkCPo`000002o`0000So[;OQ00?o
0000ok2igon`^Ml02_n`^Ml2o`0000co];[N00?o0000okRlgOnh_=d00_nh_=d2o`0000Oo^[oN00?o
0000okg1gOnm`Md03Onm`Md00ol0003o_l;Loko2g006oko2g003o`000?o1`mco`L?L00;o`L?L00?o
0000ol;4g?o2a=`03?o2a=`2o`0005Kooooo000]ooooo`03o`000?oooooooooo02Kooooo00Co0000
oiZhk?nJ^>coV[S/1Ol00002oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNbj_nG/^X02OnG
/^X00ol0003oV[;XoiZbj008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS/^<02OnS
/^<00ol0003oYk?QojNch@08ojNch@?o00003?n/]n400ol0003o/;WOok2ig`0:ok2ig`03o`000?nd
^]ko];[N00_o];[N00Co0000okRlgOl0003o00002_nj_mh00ol0003o_L7Mokg1g@0<okg1g@03o`00
0?no`]co_l;L00Co_l;L0_l00006ol73g003o`000?o2a=co`/CL00co`/CL00?o0000ooooooooool0
E?ooool002cooooo00?o0000ooooooooool0:?ooool3o`0000SoT[C^00?o0000oiBck?nD/n`02?nD
/n`00ol0003oUk;ZoiNbjP08oiNbjP03o`000?nJ/^SoV[;X00WoV[;X00?o0000oijbiOnN/^D02?nN
/^D00ol0003oXk;Soj>bh`09oj>bh`03o`000?nW/n7oYk?Q00CoYk?Q0ol00002ojJeh`03o`000?n/
]n7o[;OQ00[o[;OQ00?o0000ok2igon`^Ml02_n`^Ml2o`0000co];[N0_l0000=okZogP03o`000?nm
`Mgo_L7M00co_L7M00Co0000oko2g?no`]co_l;L0_l00009ol73g003o`000?o2a=co`/CL00co`/CL
00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0:Oooool00ol0003oT[C^oi:d
kP08oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNbj_nG/^X02?nG/^X00ol0003oV[;XoiZb
j008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>bhonS/^<02_nS/^<00ol0003oYk?QojNc
h@03o`0000KoY[GS00?o0000ojbghOn/]n402_n/]n400ol0003o/;WOok2ig`09ok2ig`;o00002_nd
^]h2o`000003okJmgol0003o^[oN00co^[oN00?o0000okg1gOnm`Md03Onm`Md00ol0003o_l;Lo`00
000;ol73g003o`000?o2a=co`/CL00go`/CL00?o0000ooooooooool0D_ooool002cooooo0_l0000[
ooooo`03o`000?nB]>koT[C^00SoT[C^00?o0000oiBck?nD/n`02?nD/n`00ol0003oUk;ZoiNbjP08
oiNbjP03o`000?nJ/^SoV[;X00SoV[;X00?o0000oijbiOnN/^D02?nN/^D00ol0003oXk;Soj>bh`08
oj>bh`Co00002_nV]N<00ol0003o[;OQojbgh@0:ojbgh@03o`000?n`^Moo/;WO00So/;WO00?o0000
ok2igol000001ond^]h2o`0000Co][gO00?o0000okZog_nj_mh02onj_mh00ol0003o_L7Mokg1g@0<
okg1g@;o00003Oo1`m`00ol0003o`/CLol;4g00<ol;4g0;o0000Doooool002cooooo00?o0000oooo
ooooool0:oooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00SoU;?/00?o0000oiNb
j_nG/^X02?nG/^X00ol0003oV[;XoiZbj008oiZbj003o`000?nN/^GoW[;U00SoW[;U00?o0000oj>b
honS/^<01?nS/^<3o`0000;oXKCV00?o0000ojJehonV]N<02_nV]N<00ol0003o[;OQojbgh@0:ojbg
h@03o`000?n`^Moo/;WO00Oo/;WO00Co0000ok2igon`^Moo00001?nd^]h2o`0000Oo][gO00?o0000
okZog_nj_mh02onj_mh00ol0003o_L7Mokg1g@0:okg1g@03o`000?no`mgo000000ko`L?L00?o0000
ol;4g?o2a=`02_o2a=`00ol0003o`lGLo`00001Cooooo`00;?ooool00ol0003oooooooooo`0/oooo
o`03o`000?nB]>koT[C^00SoT[C^00?o0000oiBck?nD/n`01onD/n`00ol0003oUk;ZoiNbjP09oiNb
jP03o`000?nJ/^SoV[;X00OoV[;X00?o0000oijbiOnN/^D02OnN/^D00ol0003oXk;Soj>bh`03o`00
00KoXKCV00?o0000ojJehonV]N<02OnV]N<00ol0003o[;OQojbgh@0:ojbgh@03o`000?n`^Moo/;WO
00Oo/;WO00Ko0000ok2igon`^Moo/;WOo`000?nd^]h2o`0000[o][gO00?o0000okZog_nj_mh02onj
_mh00ol0003o_L7Mokg1g@07okg1g@;o00000ono`md00ol0003o`L?Lol73g00<ol73g003o`000?o2
a=co`/CL00Oo`/CL0_l00003ol?5g003o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooo
oooo02gooooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[o
Uk;Z00SoUk;Z00?o0000oiZbj?nJ/^P02?nJ/^P00ol0003oW[;Uoijbi@07oijbi@Co00002_nQ]>H0
0ol0003oY[GSojJeh`09ojJeh`03o`000?n/]n7o[;OQ00[o[;OQ00?o0000ok2igon`^Ml01_n`^Ml0
1?l0003o/;WOok2igon`^Ml2o`0000go][gO00?o0000okZog_nj_mh02_nj_mh00ol0003o_L7Mokg1
g@06okg1g@03o`000?no`mgo_l?M00Co_l?M00?o0000ol73g?o1`m`03?o1`m`00ol0003o`/CLol;4
g005ol;4g003o`000?o3aMco`lGL00Co`lGL00?o0000ooooooooool0Coooool002cooooo00?o0000
ooooooooool0;_ooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00OoU;?/00?o0000
oiNbj_nG/^X02?nG/^X00ol0003oV[;XoiZbj008oiZbj004o`000?nN/^GoW[;Uoijbi@Go00000_nK
/^P00ol0003oXKCVoj6diP0:oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n402_n/
]n400ol0003o/;WOok2ig`05ok2ig`06o`000?n`^Moo0000o`000?na^n7o00003Onf_Ml00ol0003o
^[oNokZogP0;okZogP03o`000?nm`Mgo_L7M00Co_L7M00?o0000oko3gOno`md01_no`md00ol0003o
`L?Lol73g00;ol73g003o`000?o2a=co`/CL00Co`/CL00?o0000ol?5g?o3aM`01Oo3aM`2o`00053o
oooo000/ooooo`03o`000?oooooooooo02oooooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/
oiBck007oiBck003o`000?nG/^[oUk;Z00SoUk;Z00?o0000oiZbj?nJ/^P01_nJ/^P5o`0000SoVk;X
00?o0000oj6di_nQ]>H02OnQ]>H00ol0003oY[GSojJeh`0:ojJeh`03o`000?n/]n7o[;OQ00Wo[;OQ
00?o0000ok2igon`^Ml01On`^Ml2o`0000Co/K_Q00?o0000okJmgonf_Ml02onf_Ml00ol0003o^[oN
okZogP0;okZogP04o`000?nm`Mgo_L7Mokg1g@;o00002Ono`md00ol0003o`L?Lol73g00<ol73g004
o`000?o2a=co`/CLol;4g0;o00002Oo3aM`00ol0003oooooooooo`1>ooooo`00;?ooool2o`00037o
oooo00?o0000oi:dk_nB]>h02?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[oUk;Z00So
Uk;Z00?o0000oiZbj?nJ/^P01Ol00002oiJajP03o`000?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ
]>H02OnQ]>H00ol0003oY[GSojJeh`09ojJeh`03o`000?n/]n7o[;OQ00[o[;OQ00?o0000ok2igon`
^Ml00_n`^Ml3o`0000Ko/K_Q00?o0000okJmgonf_Ml02onf_Ml00ol0003o^[oNokZogP0;okZogP03
o`000?nm`Mgo000000co_l?M00?o0000ol73g?o1`m`03?o1`m`00ol0003o`/CLo`00000<ol?5g003
o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo00?o0000oi:dk_nB]>h0
2?nB]>h00ol0003oU;?/oiBck007oiBck003o`000?nG/^[oUk;Z00?oUk;Z1ol00008oiJajP03o`00
0?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ]>H02OnQ]>H00ol0003oY[GSojJeh`09ojJeh`03o`00
0?n/]n7o[;OQ00[o[;OQ00Co0000ok2igol0003o00000_na^n400ol0003o/K_Qok6kh@05ok6kh@03
o`000?nf_Moo][gO00_o][gO00?o0000okZog_nj_mh02_nj_mh2o`0000ko_l?M00?o0000ol73g?o1
`m`02oo1`m`2o`0000ko`lGL00?o0000ooooooooool0C?ooool002_ooooo00?o0000ooooooooool0
<oooool00ol0003oT[C^oi:dkP08oi:dkP03o`000?nD/ncoU;?/00?oU;?/2Ol00005oi6ak003o`00
0?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P02OnK/^P00ol0003oXKCVoj6diP09oj6diP03o`00
0?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n402On/]n42o`0000Co/K_Q00?o0000ok6khOna^n40
1_na^n400ol0003o][gOokJmg`0:okJmg`03o`000?nj_mko^[oN00So^[oN0_l000000onl`]ko0000
oko3g@0>oko3g@03o`000?o1`mco`L?L00So`L?L0_l000000oo2aMgo0000ol?5g00=ol?5g0;o0000
COooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oT[C^oi:dkP06oi:dkPOo0000
1?n=/Nh00ol0003oTK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P0
2OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOn/]n40
1_n/]n43o`000003ojbjhol0003o/K_Q00?o/K_Q00?o0000ok6khOna^n401_na^n400ol0003o][gO
okJmg`0;okJmg`03o`000?nj_mko^[oN00Go^[oN0_l00004okc2gP03o`000?no`mgo_l?M00go_l?M
00?o0000ol73g?o1`m`01_o1`m`00ol0003o`/GMol;5g@02ol;5g@03o`000?o3aMco`lGL00co`lGL
0_l0001<ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oT[C^oi:dkP05o`0000;oR[7`
00?o0000ohfak_n=/Nh01on=/Nh00ol0003oTK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z
00?o0000oi^bj?nK/^P02OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00WoY[GS
00?o0000ojbghOn/]n400on/]n42o`0000Go[;[S00Go0000ok6khOna^n7o/K_Qo`000009ok6kh@03
o`000?nf_Moo][gO00_o][gO00?o0000okZog_nj_mh00_nj_mh2o`0000Oo_<;N00?o0000oko3gOno
`md03?no`md00ol0003o`L?Lol73g004ol73g0;o00001_o2aMd00ol0003o`lGLol?5g00<ol?5g003
o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo00?o0000ooooooooool0=_ooool2o`0000SoR[7`00?o0000ohfak_n=/Nh01on=/Nh00ol0003o
TK7/oi6ak008oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK/^P02?nK/^P00ol0003o
XKCVoj6diP09oj6diP03o`000?nV]N?oY[GS00WoY[GS00?o0000ojbghOl000000_l00008ojbjh`04
o`000?na^n7o/K_Qo`0000[o/K_Q00?o0000okJmgonf_Ml02onf_Ml01?l0003o^[oNo`000?l0000:
okc2gP03o`000?no`mgo_l?M00co_l?M00Co0000ol73g?o1`mco`L?L0_l00009ol;5g@03o`000?o3
aMco`lGL00co`lGL00?o0000ooooooooool0BOooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0=oooool00ol0003oR[7`
ohZal007ohZal003o`000?n=/NkoSK7^00OoSK7^00?o0000oi6ak?nA/N`02?nA/N`00ol0003oU[7Z
oiJajP08oiJajP03o`000?nK/^SoVk;X00SoVk;X00?o0000oj6di_nQ]>H02?nQ]>H00ol0003oY[GS
ojJeh`08ojJeh`?o00003?n/^^<00ol0003o/K_Qo`00000;ok6kh@03o`000?nf_Moo][gO00[o][gO
0_l0000<okc2gP03o`000?no`mgo_l?M00go_l?M00?o0000ol73g?l000002oo2aMd00ol0003o`lGL
ol?5g00<ol?5g0;o0000B_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0>?ooool00ol0003oR[7`ohZal007ohZal003
o`000?n=/NkoSK7^00OoSK7^00?o0000oi6ak?nA/N`01onA/N`00ol0003oU[7ZoiJajP08oiJajP03
o`000?nK/^SoVk;X00WoVk;X00?o0000oj6di_nQ]>H02?nQ]>H00ol0003oY[GSojJeh`04ojJeh`?o
00000_nV^>H00ol0003o[;[Sojbjh`0;ojbjh`;o00002ona^n400ol0003o][gOokJmg`08okJmg`;o
000000?o^<3Qo`000?nl`]h03?nl`]h00ol0003o_l?Moko3g@0<oko3g@;o00003Oo2aMd00ol0003o
`lGLol?5g00<ol?5g0;o0000BOooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Kooooo0_l0000kooooo`03o`000?n:/O3oR[7`00OoR[7`00?o0000ohfak_n=
/Nh01on=/Nh00ol0003oTK7/oi6ak007oi6ak003o`000?nF/N[oU[7Z00SoU[7Z00?o0000oi^bj?nK
/^P02OnK/^P00ol0003oXKCVoj6diP08oj6diP03o`000?nV]N?oY[GS00?o00001_nV^>H00ol0003o
[;[Sojbjh`0:ojbjh`;o00003?na^n400ol0003o][gOokJmg`05okJmg`;o00001?nh`>400ol0003o
_<;Nokc2gP0;okc2gP03o`000?no`mgo_l?M00[o_l?M00?o0000ol35g_l000003_o2aMd00ol0003o
`lGLol?5g00:ol?5g003o`000?o2aMco000004Wooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo03[ooooo00?o0000ohZal?n:
/O001on:/O000ol0003oSK7^ohfakP07ohfakP03o`000?nA/NcoTK7/00OoTK7/00?o0000oiJaj_nF
/NX02?nF/NX00ol0003oVk;Xoi^bj009oi^bj003o`000?nQ]>KoXKCV00KoXKCV1?l0000:ojJhiP03
o`000?n/^^?o[;[S00[o[;[S00?o0000ok6khOna^n402ona^n400ol0003o][gOokJmg`02okJmg`;o
00001onh`>400ol0003o_<;Nokc2gP0;okc2gP03o`000?no`mgo_l?M00Oo_l?M0_l00003ol35gP03
o`000?o2aMgo`/GM00co`/GM00?o0000ol?5g?o3aM`01oo3aM`2o`0000?o`/GL00?o0000oooooooo
ool0A_ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Go
oooo00?o0000ooooooooool0??ooool00ol0003oR[7`ohZal007ohZal003o`000?n=/NkoSK7^00Ko
SK7^00?o0000oi6ak?nA/N`02?nA/N`00ol0003oU[7ZoiJajP08oiJajP03o`000?nK/^SoVk;X00Wo
Vk;X00?o0000oj6di_nQ]>H01Ol00002oinfj003o`000?nV^>KoY[SV00[oY[SV00?o0000ojbjhon/
^^<02On/^^<2o`0000go/K_Q00Co0000okJmgol0003o00002_nh`>400ol0003o_<;Nokc2gP0;okc2
gP03o`000?no`mgo_l?M00Go_l?M00?o0000ol35g_o0aMh01?o0aMh00ol0003o`/GMol;5g@0<ol;5
g@03o`000?o3aMco`lGL00Go`lGL00?o0000ol;5g?o2aM`00oo2aM`2o`0004Oooooo000Zooooo`03
o`000?oooooooooo03gooooo00?o0000ohZal?n:/O001on:/O000ol0003oSK7^ohfakP06ohfakP03
o`000?nA/NcoTK7/00OoTK7/00?o0000oiJaj_nF/NX02OnF/NX00ol0003oVk;Xoi^bj007oi^bj0Co
00002?nO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o[;[S00So[;[S00?o0000ojbjhol0
00003?na^n42o`0000co^<3Q00?o0000okc2g_nl`]h02onl`]h00ol0003o_l?Moko3g@04oko3g@03
o`000?o0aMko`<GN00Ko`<GN00?o0000ol;5gOo2aMd02oo2aMd00ol0003o`lGLol?5g004ol?5g003
o`000?o2aMco`/GL00Go`/GL00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0
?_ooool00ol0003oR[7`ohZal007ohZal003o`000?n=/NkoSK7^00KoSK7^00?o0000oi6ak?nA/N`0
1onA/N`00ol0003oU[7ZoiJajP09oiJajP04o`000?nK/^SoVk;Xoi^bj0Go00000_nI/nX00ol0003o
WkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbjhon/^^<02?n/^^<00ol0003o
[;[So`00000:ok6kh@;o000000?o/koSo`000?nh`>403?nh`>400ol0003o_<;Nokc2gP0;okc2gP04
o`000?no`mgo_l?Moko3g@;o00002Oo0aMh00ol0003o`/GMol;5g@0<ol;5g@04o`000?o3aMco`lGL
ol?5g0;o00002Oo2aM`00ol0003oooooooooo`14ooooo`00:_ooool00ol0003oooooooooo`0ooooo
o`03o`000?n:/O3oR[7`00OoR[7`00?o0000ohfak_n=/Nh01_n=/Nh00ol0003oTK7/oi6ak007oi6a
k003o`000?nF/N[oU[7Z00OoU[7Z1Ol00008oiVcjP03o`000?nO]^SoWkKX00SoWkKX00?o0000ojJh
i_nV^>H02OnV^>H00ol0003o[;[Sojbjh`07ojbjh`04o`000?n/^^?o[;[So`0000Oo/K_Q0_l00004
ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o0000okc2g_nl`]h02onl`]h00ol0003o_l?Mo`00000<
ol35gP03o`000?o2aMgo`/GM00co`/GM00?o0000ol?5g?l000003?o2aM`00ol0003oooooooooo`13
ooooo`00:Oooool3o`00043ooooo0_l00009ohZal003o`000?n=/NkoSK7^00KoSK7^00?o0000oi6a
k?nA/N`01onA/N`01?l0003oU[7ZoiJaj_nF/NX5o`0000;oT[7/00?o0000oiVcj_nI/nX02OnI/nX0
0ol0003oWkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbjhon/^^<01_n/^^<0
1Ol0003o[;[Sojbjhon/^^?o000000Co/K_Q0_l00007ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o
0000okc2g_nl`]h02_nl`]h2o`0000ko`<GN00?o0000ol;5gOo2aMd02oo2aMd2o`0000go`/GL0_l0
0014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o00002On:/O000ol0003oSK7^ohfakP06
ohfakP03o`000?nA/NcoTK7/00?oTK7/1ol00008oi:ak003o`000?nI/n[oVK?Z00WoVK?Z00?o0000
oinfj?nO]^P01onO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o[;[S00Go[;[S00?o0000
ojbjhon/^^<00_n/^^<01?l0003o/K_Qo`000?l0000:ok>oh`03o`000?nh`>7o^<3Q00_o^<3Q00?o
0000okc2g_nl`]h01onl`]h2o`000003okg4h?l0003o`<GN00ko`<GN00?o0000ol;5gOo2aMd02?o2
aMd2o`000003ol;6g_l0003o`/GL00go`/GL00?o0000ooooooooool0@_ooool002[ooooo00?o0000
ooooooooool0@Oooool2o`0000GoR[7`4_l00004ohb`kP03o`000?nB/NcoT[7/00WoT[7/00?o0000
oiVcj_nI/nX02OnI/nX00ol0003oWkKXoinfj007oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000
ojbjhon/^^<01On/^^<00ol0003o[;[Sojbjh`02ojbjh`;o00003?nc_n<00ol0003o^<3QokS0h@0;
okS0h@03o`000?nl`]ko_<;N00Go_<;N0_l00004okg4h003o`000?o0aMko`<GN00go`<GN00?o0000
ol;5gOo2aMd01_o2aMd00ol0003o`/KNol;6gP02ol;6gP03o`000?o2aMco`/GL00co`/GL00?o0000
ooooooooool0@Oooool002[ooooo00?o0000ooooooooool0@_ooool6o`0000CoQ:oa00?o0000ohN_
l?n7[o001_n7[o000ol0003oS;3^ohb`kP07ohb`kP03o`000?nB/NcoT[7/00WoT[7/00?o0000oiVc
j_nI/nX02?nI/nX00ol0003oWkKXoinfj008oinfj003o`000?nV^>KoY[SV00WoY[SV00?o0000ojbj
hon/^^<01?n/^^<00ol0003o[;[So`000002o`000003ojfmiOl0003o/koS00co/koS00?o0000okS0
hOnh`>402onh`>400ol0003o_<;Nokc2gP02okc2gP;o00001onma>000ol0003o`<GNol35gP0<ol35
gP03o`000?o2aMgo`/GM00Co`/GM0_l00006ol;6gP03o`000?o2aMco`/GL00co`/GL00?o0000oooo
ooooool0@?ooool002Wooooo00?o0000ooooooooool0A?ooool00ol0003oQ:oaohB_l@07ohB_l@03
o`000?n7[o3oQjo`00KoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak009oi:ak003
o`000?nI/n[oVK?Z00SoVK?Z00?o0000oinfj?nO]^P02?nO]^P00ol0003oY[SVojJhiP09ojJhiP03
o`000?n/^^?o[;[S00?o[;[S0_l00005ojfmi@03o`000?nc_n?o/koS00_o/koS00?o0000okS0hOnh
`>402onh`>401?l0003o_<;No`000?l0000:okg4h003o`000?o0aMko`<GN00co`<GN00Co0000ol;5
gOo2aMgo`/GM0_l00009ol;6gP03o`000?o2aMco`/GL00_o`/GL00?o0000ooooooooool0@?ooool0
02Wooooo00?o0000ooooooooool0AOooool00ol0003oQ:oaohB_l@07ohB_l@03o`000?n7[o3oQjo`
00KoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak008oi:ak003o`000?nI/n[oVK?Z
00WoVK?Z00?o0000oinfj?nO]^P01onO]^P00ol0003oY[SVojJhiP0:ojJhiP03o`000?n/^^?o0000
00?o00001on]_ND00ol0003o/koSok>oh`0;ok>oh`03o`000?nh`>7o^<3Q00[o^<3Q0_l0000=okg4
h003o`000?o0aMko`<GN00co`<GN00?o0000ol;5gOl000002oo2a]h00ol0003o`/GLol;5g00<ol;5
g003o`000?oooooooooo03oooooo000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ohB_lOn4
[o401on4[o400ol0003oQjo`ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^00?o0000oi:ak?nB
/N`02?nB/N`00ol0003oVK?ZoiVcjP09oiVcjP03o`000?nO]^SoWkKX00OoWkKX00?o0000ojJhi_nV
^>H02?nV^>H3o`0000?o[KgU00?o0000ojfmiOn]_ND01_n]_ND00ol0003o/koSok>oh`0;ok>oh`03
o`000?nh`>7o^<3Q00Oo^<3Q0_l000000oni`n;o0000okg4h00=okg4h003o`000?o0aMko`<GN00_o
`<GN0_l0000=ol;6gP03o`000?o2aMco`/GL00_o`/GL0_l00010ooooo`00:Oooool2o`0004Sooooo
00?o0000ohB_lOn4[o401on4[o400ol0003oQjo`ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^
00?o0000oi:ak?nB/N`02?nB/N`00ol0003oVK?ZoiVcjP08oiVcjP03o`000?nO]^SoWkKX00SoWkKX
00?o0000ojJhi_nV^>H01?nV^>H3o`0000;oY[[X00Go0000ojfmiOn]_NGo[KgUo`000009ojfmi@03
o`000?nc_n?o/koS00[o/koS00?o0000okS0hOnh`>401Onh`>42o`0000Co^L?R00?o0000okg4h?nm
a>002onma>000ol0003o`<GNol35gP09ol35gP;o000000?o`<OOo`000?o2a]h03Oo2a]h00ol0003o
`/GLol;5g008ol;5g0;o000000?o`LKNo`000?l00000?oooool002Wooooo00?o0000ooooooooool0
B?ooool00ol0003oQ:oaohB_l@07ohB_l@03o`000?n7[o3oQjo`00KoQjo`00?o0000ohb`k_n</>h0
1on</>h00ol0003oT[7/oi:ak008oi:ak003o`000?nI/n[oVK?Z00SoVK?Z00?o0000oinfj?nO]^P0
2?nO]^P00ol0003oY[SVojJhiP03o`0000KoY[[X00Co0000ojfmiOn]_NGo00002_n]_ND00ol0003o
/koSok>oh`0:ok>oh`03o`000?nh`>7o^<3Q00;o^<3Q0_l00007okW3hP03o`000?nma>3o_LCP00_o
_LCP00?o0000ol35g_o0aMh01oo0aMh00ol0003o`<OOol37g`02ol37g`03o`000?o2a]ko`/KN00co
`/KN00?o0000ol;5g?o2aM`01_o2aM`00ol0003o`LKNol76gP02ol76gP03o`000?oooooooooo03go
oooo000Yooooo`03o`000?oooooooooo04Wooooo00?o0000ohB_lOn4[o401on4[o400ol0003oQjo`
ohN_l006ohN_l003o`000?n</>koS;3^00OoS;3^00?o0000oi:ak?nB/N`01onB/N`00ol0003oVK?Z
oiVcjP09oiVcjP03o`000?nO]^SoWkKX00KoWkKX1?l0000:ojJjj003o`000?n]_NGo000000_o[KgU
00?o0000ok>ohonc_n<02_nc_n<01?l0003o^<3Qo`000?l0000:okW3hP03o`000?nma>3o_LCP00_o
_LCP00?o0000ol35g_o0aMh01?o0aMh2o`0000Ko`<OO00?o0000ol;6g_o2a]h02oo2a]h00ol0003o
`/GLol;5g004ol;5g0;o00001_o1a]h00ol0003oooooooooo`0looooo`00:Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohN_l?n7[o001on7[o000ol0003oS;3^
ohb`kP07ohb`kP03o`000?nB/NcoT[7/00OoT[7/00?o0000oiVcj_nI/nX02OnI/nX00ol0003oWkKX
oinfj005o`0000;oW[S[00?o0000ojJjj?nV^^P02_nV^^P2o`0000_o[KgU00?o0000ok>ohonc_n<0
2_nc_n<2o`0000go^L?R00?o0000okg4h?nma>002onma>001?l0003o`<GNol35g_o0aMh2o`0000Wo
`<OO00?o0000ol;6g_o2a]h02oo2a]h01?l0003o`/GLol;5g?o2aM`2o`0000Wo`LKN00?o0000oooo
ooooool0>oooool002Wooooo00?o0000ooooooooool0Boooool00ol0003oQ:oaohB_l@06ohB_l@03
o`000?n7[o3oQjo`00OoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/oi:ak007oi:ak003
o`000?nI/n[oVK?Z00OoVK?Z1?l00008oijhj`03o`000?nV^^SoY[[X00[oY[[X00?o0000ojfmiOn]
_ND02_n]_ND00ol0003o/koSok>oh`07ok>oh`;o000000?o/l;Uo`000?ni`n803Oni`n800ol0003o
_LCPokg4h00;okg4h003o`000?o0aMko000000_o`<OO00?o0000ol;6g_o2a]h03?o2a]h00ol0003o
`/GLo`00000;ol76gP;o0000??ooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003oQ:oa
ohB_l@06ohB_l@03o`000?n7[o3oQjo`00OoQjo`00?o0000ohb`k_n</>h01on</>h00ol0003oT[7/
oi:ak007oi:ak004o`000?nI/n[oVK?ZoiVcjPGo00000_nG]Nd00ol0003oW[S[oijhj`08oijhj`03
o`000?nV^^SoY[[X00WoY[[X0_l0000<ojfmi@03o`000?nc_n?o/koS00Co/koS0_l00004ok?2i@03
o`000?ni`n;o^L?R00_o^L?R00?o0000okg4h?nma>002onma>02o`0000go`<OO00?o0000ol;6g_o2
a]h02oo2a]h2o`0000go`LKN00?o0000ooooooooool0>_ooool002Sooooo0ol0001>ooooo`03o`00
0?n4[o7oQ:oa00KoQ:oa00?o0000ohN_l?n7[o001on7[o000ol0003oS;3^ohb`kP07ohb`kP03o`00
0?nB/NcoT[7/00?oT[7/1ol00008oiNek@03o`000?nN^>_oW[S[00SoW[S[00?o0000ojJjj?nV^^P0
2?nV^^P00ol0003oY[[Xo`00000<ojfmi@03o`000?nc_n?o/koS00;o/koS00?o0000ok?2iOnc`^D0
1Onc`^D00ol0003o^L?RokW3hP0;okW3hP03o`000?nma>3o_LCP00So_LCP0_l000000onman;o0000
ol37g`0=ol37g`03o`000?o2a]ko`/KN00So`/KN0_l000000oo0amoo0000ol76gP0=ol76gP03o`00
0?oooooooooo03Wooooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000ohB_lOn4[o401_n4
[o400ol0003oQjo`ohN_l003ohN_l1?o00001?n?/^h00ol0003oUkG]oiNek@09oiNek@03o`000?nN
^>_oW[S[00SoW[S[00?o0000ojJjj?nV^^P01onV^^P01?l0003oY[[XojJjj?l0000<ojfmi@04o`00
0?nc_n?o0000o`0000Wo/l;U00?o0000okW3h_ni`n802oni`n800ol0003o_LCPokg4h005okg4h0;o
00001?nman800ol0003o`<OOol37g`0<ol37g`03o`000?o2a]ko`/KN00Ko`/KN00?o0000ol37goo0
aml00_o0aml00ol0003o`LKNol76gP0<ol76gP03o`000?oooooooooo03Sooooo000<ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007oooo
o`03o`000?oooooooooo053ooooo3_l00004oh>^l@03o`000?n8/?3oR;3`00OoR;3`00?o0000ohnb
k_n?/^h01on?/^h00ol0003oUkG]oiNek@09oiNek@03o`000?nN^>_oW[S[00SoW[S[00?o0000ojJj
j?nV^^P01_nV^^P01Ol0003oY[[XojJjj?nV^^So000000[o[KgU0ol0000<ok?2i@03o`000?ni`n;o
^L?R00_o^L?R00?o0000okg4h?nma>000_nma>02o`0000Oo_LOR00?o0000ol37goo0aml02oo0aml0
0ol0003o`/KNol;6gP04ol;6gP;o00001_o0aml00ol0003o`LKNol76gP0;ol76gP;o0000>Oooool0
00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Oooooo00?o0000ooooooooool0D?ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3
[_7oPjka00OoPjka00?o0000ohR`l?n8/?001on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG
]NgoUkG]00WoUkG]00?o0000oijhjonN^>/02?nN^>/00ol0003oY[[XojJjj004ojJjj0;o00001?nV
^^P00ol0003o[KgUojfmi@04ojfmi@?o00000_n]`>P00ol0003o/l;Uok?2i@0;ok?2i@03o`000?ni
`n;o^L?R00_o^L?R00Co0000okg4h?l0003o00002_nman800ol0003o`<OOol37g`0;ol37g`04o`00
0?o2a]ko`/KNol;6gP;o00002Oo0aml00ol0003o`LKNol76gP0;ol76gP03o`000?oooooooooo03Oo
oooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0DOooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka
00OoPjka00?o0000ohR`l?n8/?001on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG]NgoUkG]
00WoUkG]00?o0000oijhjonN^>/02?nN^>/00ol0003oY[[XojJjj003o`000003ojJjj?l0003oY[[X
00CoY[[X00?o0000ojfmiOn]_ND00ol00006ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3
h_ni`n802_ni`n82o`0000go_LOR00?o0000ol37goo0aml02oo0aml00ol0003o`/KNo`00000<ol37
g`03o`000?o1a]ko`LKN00_o`LKN00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1B
ooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401on3[_400ol0003oR;3`ohR`l007
ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOnG]Nd02OnG]Nd00ol0003oW[S[oijhj`07
oijhj`?o00001OnV^^P01?l0003oY[[XojJjj?nV^^P4o`0000[o[L3X00?o0000ok?2iOnc`^D02onc
`^D00ol0003o^L?RokW3hP07okW3hP;o000000?o^LKTo`000?nman803Onman800ol0003o`<OOol37
g`0:ol37g`;o00003_o0aml00ol0003o`LKNol76gP0:ol76gP;o0000=oooool000cooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401on3[_400ol0003oR;3`
ohR`l007ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOnG]Nd02OnG]Nd00ol0003oW[S[
oijhj`03oijhj`?o00000_nN^>/00ol0003oY[[XojJjj004ojJjj0?o00000_nV_^/00ol0003o[L3X
ojg0j00:ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3h_ni`n801?ni`n82o`0000Co^LKT
00?o0000okg7h_nman803?nman800ol0003o`<OOol37g`07ol37g`;o000000?o_lSRo`000?o0aml0
3Oo0aml00ol0003o`LKNol76gP08ol76gP;o000000?o_/KPo`000?l00000=_ooool000cooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo00?o0000ooooooooool0
E?ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00OoPjka00?o0000ohR`l?n8/?00
1on8/?000ol0003oSk;^ohnbkP07ohnbkP03o`000?nG]NgoUkG]00WoUkG]00?o0000oijhjol00000
0_l00006oijhj`03o`000?nV^^SoY[[X00?o000000?oY[k[o`000?nV_^/00onV_^/00ol0003o[L3X
ojg0j00:ojg0j003o`000?nc`^Go/l;U00_o/l;U00?o0000okW3h_ni`n800_ni`n800ol0003o^LKT
okW6i005okW6i003o`000?nman;o_LOR00co_LOR00?o0000ol37goo0aml01?o0aml2o`0000Co_lSR
00?o0000ol37goo0aml03?o0aml00ol0003o`LKNol76gP05ol76gP;o00001?nna^000ol0003ooooo
ooooo`0dooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0
2?ooool2o`0005Oooooo00?o0000oh2]lOn0[O401_n0[O400ol0003oPjkaoh>^l@07oh>^l@03o`00
0?n8/?3oR;3`00OoR;3`00?o0000ohnbk_n?/^h01on?/^h00ol0003oUkG]oiNek@07oiNek@?o0000
2?nN^>/4o`0000GoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o[L3Xojg0j00:ojg0j003o`00
0?nc`^Go/l;U00_o/l;U00Co0000okW3h_l0003o00002Onia^@00ol0003o_LORokg7hP0<okg7hP03
o`000?o0amoo`<OO00;o`<OO00?o0000oko8h_nob>801Onob>800ol0003o`<OOol37g`0<ol37g`03
o`000?o1a]ko`LKN00;o`LKN0_l00007okk6h003o`000?oooooooooo03?ooooo000<ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
05Oooooo00?o0000oh2]lOn0[O401_n0[O400ol0003oPjkaoh>^l@06oh>^l@03o`000?n8/?3oR;3`
00SoR;3`00?o0000ohnbk_n?/^h01on?/^h00ol0003oUkG]oiNek@03oiNek@?o00000onG]Nd00ol0
003oW[S[oijhj`05o`0000;oWK_]00?o0000ojJnjonV_^/01OnV_^/00ol0003oY[k[ojJnj`02ojJn
j`03o`000?n]`>So[L3X00[o[L3X00?o0000ok?2iOnc`^D02_nc`^D2o`0000co^LKT00?o0000okg7
h_nman803?nman801?l0003o`<OOo`000?l00009oko8hP03o`000?o0amoo`<OO00co`<OO00Co0000
ol76g_l0003o00002_nna^000ol0003oooooooooo`0booooo`009oooool00ol0003oooooooooo`1H
ooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^lOn3[_401_n3[_400ol0003oR;3`ohR`l008
ohR`l003o`000?n?/^koSk;^00OoSk;^00?o0000oiNekOl000000_l00005oiNek@Co00002?nM^nd0
0ol0003oY[k[ojJnj`05ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0j?n]`>P02_n]`>P0
0ol0003o/l;Uok?2i@06ok?2i@?o000000?o/lGWo`000?nia^@03?nia^@00ol0003o_LORokg7hP0;
okg7hP;o00003?nob>800ol0003o`<OOol37g`0;ol37g`;o00003Onna^000ol0003oooooooooo`0a
ooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`000?n0[O7oP:ga00KoP:ga00?o0000oh>^
lOn3[_401_n3[_400ol0003oR;3`ohR`l008ohR`l003o`000?n?/^koSk;^00GoSk;^0ol00003oiNe
k@Go00000_nE]nl00ol0003oWK_]oifkk@08oifkk@03o`000?nV_^_oY[k[00GoY[k[00?o0000ojJn
jonV_^/00_nV_^/00ol0003o[L3Xojg0j00:ojg0j003o`000?nc`^Go/l;U00?o/l;U0_l00005ok?5
i`03o`000?nia^Co^LKT00_o^LKT00?o0000okg7h_nman802?nman82o`000003okc9i?l0003o_lSR
00co_lSR00?o0000ol37goo0aml02Oo0aml00ol0003o_/SRo`00000=okk6h0;o0000<_ooool002Oo
oooo00?o0000ooooooooool0F_ooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00Ko
Pjka00?o0000ohR`l?n8/?002?n8/?001?l0003oSk;^ohnbk_n?/^h9o`0000SoUKO_00?o0000oifk
kOnM^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0
j?n]`>P02on]`>P00ol0003o/l;Uo`000002o`0000So/lGW00?o0000okW6i?nia^@02onia^@00ol0
003o_LORokg7hP05okg7hP;o00001?nlbN@00ol0003o_lSRoko8hP0;oko8hP03o`000?o0amoo`<OO
00Ko`<OO0_l00003okk8hP03o`000?nna^3o_/KP00_o_/KP00?o0000ooooooooool0<?ooool002Oo
oooo00?o0000ooooooooool0Foooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n3[_7oPjka00Ko
Pjka00?o0000ohR`l?n8/?000on8/?0:o`0000GoSKC`00?o0000oiFgkonE]nl02?nE]nl00ol0003o
WK_]oifkk@08oifkk@03o`000?nV_^_oY[k[00CoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o
[L3Xojg0j00:ojg0j0;o00003?ncaNL00ol0003o^LKTokW6i00;okW6i003o`000?nman;o_LOR00;o
_LOR0_l00007okc9i003o`000?nob>;o_lSR00_o_lSR00?o0000ol37goo0aml01?o0aml00ol0003o
_/SRokk8hP04okk8hP03o`000?nna^3o_/KP00_o_/KP00?o0000ooooooooool0;oooool002Oooooo
0_l0001MoooooaOo00000_n6/O44o`0000[oSKC`00?o0000oiFgkonE]nl02?nE]nl00ol0003oWK_]
oifkk@08oifkk@03o`000?nV_^_oY[k[00CoY[k[00?o0000ojJnjonV_^/00_nV_^/00ol0003o[L3X
ojg0j006ojg0j0?o000000?o[L?Zo`000?ncaNL03?ncaNL00ol0003o^LKTokW6i00;okW6i004o`00
0?nman;o0000o`0000[o_<WT00?o0000oko8h_nob>802onob>801?l0003o`<OOol37goo0aml2o`00
00So_/SR00?o0000okk6h?nna^002onna^000ol0003oooooooooo`0^ooooo`009_ooool2o`0005oo
oooo00?o0000ogj]lOmn[O401_mn[O400ol0003oPJkaoh6^l@06oh6^l@03o`000?n6/O7oQ[7a00?o
00001?n6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00SoUKO_00?o0000oifkkOnM
^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`000?nV_^_oY[k[00;oY[k[00?o0000ojg0j?n]
`>P00on]`>P2o`0000Go[L?Z00?o0000ok?5ioncaNL02oncaNL00ol0003o^LKTokW6i00:okW6i0;o
00003OnlbN@00ol0003o_lSRoko8hP0;oko8hP03o`000?o0amoo000000_o_/SR00?o0000okk6h?nn
a^002_nna^02o`0002oooooo000Wooooo`03o`000?oooooooooo05kooooo00?o0000ogj]lOmn[O40
1_mn[O400ol0003oPJkaoh6^l@05oh6^l@?o00002?n6/O400ol0003oSKC`ohfdl008ohfdl003o`00
0?nE]nooUKO_00SoUKO_00?o0000oifkkOnM^nd02?nM^nd00ol0003oY[k[ojJnj`04ojJnj`03o`00
0?nV_^_oY[k[00;oY[k[00?o0000ojg0j?l000000_l00008ojg3jP03o`000?ncaNOo/lGW00[o/lGW
00?o0000okW6i?nia^@02?nia^@2o`000003okS9iol0003o_<WT00go_<WT00?o0000oko8h_nob>80
2_nob>82o`0000go_/SR00?o0000okk6h?nna^002_nna^02o`0002kooooo000Wooooo`03o`000?oo
oooooooo05oooooo00?o0000ogj]lOmn[O401_mn[O401?l0003oPJkaoh6^lOn1[_43o`0000;oPJka
00?o0000ohJalOn6/O401on6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_
00?o0000oifkkOnM^nd02OnM^nd00ol0003oY[k[ojJnj`04ojJnj`04o`000?nV_^_oY[k[ojJnj`;o
00003?n]`nX00ol0003o/lGWok?5i`0:ok?5i`03o`000?nia^Co^LKT00Go^LKT0_l00004okS9i`03
o`000?nlbNCo_<WT00_o_<WT00?o0000oko8h_nob>802?nob>82o`000003okg9i?l0003o_/SR00co
_/SR00?o0000okk6h?nna^002?nna^02o`000003ok_5h_l0003ooooo02gooooo000Vooooo`03o`00
0?oooooooooo067ooooo00?o0000ogj]lOmn[O401_mn[O43o`0000KoPJka00?o0000ohJalOn6/O40
1on6/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_00?o0000oifkkOnM^nd0
2OnM^nd00ol0003oY[k[ojJnj`04ojJnj`?o000000?oYL7]o`000?n]`nX03?n]`nX00ol0003o/lGW
ok?5i`0:ok?5i`03o`000?nia^Co^LKT00;o^LKT0_l00007okS9i`03o`000?nlbNCo_<WT00_o_<WT
00?o0000oko8h_nob>801Onob>82o`0000Co_LWT00?o0000okk8h_nnb>802onnb>800ol0003o_/KP
okk6h005okk6h0;o00001?nkaN800ol0003oooooooooo`0[ooooo`009_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?mn[O7oOZga00;oOZga0ol000000omn[O7o0000oh6^l@07oh6^l@03o`000?n6
/O7oQ[7a00OoQ[7a00?o0000ohfdl?n=]?002?n=]?000ol0003oUKO_oiFgk`07oiFgk`03o`000?nM
^ngoWK_]00WoWK_]00?o0000ojJnjonV_^/00ol000000onU`Ngo0000ojG1k@02ojG1k@03o`000?n]
`n[o[L?Z00_o[L?Z00?o0000ok?5ioncaNL02_ncaNL01?l0003o^LKTo`000?l0000:okS9i`03o`00
0?nlbNCo_<WT00_o_<WT00?o0000oko8h_nob>800_nob>82o`0000Oo_LWT00?o0000okk8h_nnb>80
2onnb>800ol0003o_/KPokk6h002okk6h0;o00001_nkaN82o`0002cooooo000Vooooo`03o`000?oo
oooooooo06?ooooo1?l00005ogj]l@03o`000?n1[_7oPJka00KoPJka00?o0000ohJalOn6/O401on6
/O400ol0003oSKC`ohfdl008ohfdl003o`000?nE]nooUKO_00OoUKO_00?o0000oifkkOnM^nd01onM
^nd4o`0000CoYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3jP0;ojg3jP03o`000?nc
aNOo/lGW00Wo/lGW0_l0000=okS9i`03o`000?nlbNCo_<WT00_o_<WT00Co0000oko8h_l0003o0000
2_nmbN@00ol0003o_/SRokk8hP0;okk8hP04o`000?nna^3o0000o`0000Wo^lGR00?o0000oooooooo
ool0:_ooool002Kooooo0_l0001Sooooo`?o00002?mn[O400ol0003oPJkaoh6^l@06oh6^l@03o`00
0?n6/O7oQ[7a00OoQ[7a00?o0000ohfdl?n=]?002?n=]?000ol0003oUKO_oiFgk`07oiFgk`04o`00
0?nM^ngoWK_]oifkk@Go00000onM_^l00ol0003oYL7]ojG1k@03ojG1k@03o`000?nU`NgoYL7]00;o
YL7]00?o0000ojg3j_n]`nX02on]`nX00ol0003o/lGWok?5i`06ok?5i`;o00000_ncb>X00ol0003o
^<WWokS9i`0;okS9i`03o`000?nlbNCo_<WT00[o_<WT0_l0000=okg9i003o`000?nnb>;o_/SR00[o
_/SR0_l0000<ok_5hP03o`000?oooooooooo02Wooooo000Vooooo`03o`000?oooooooooo05oooooo
0ol00003ooooo`03o`000?mn[O7oOZga00KoOZga00?o0000oh6^lOn1[_401_n1[_400ol0003oQ[7a
ohJal@07ohJal@03o`000?n=]?3oSKC`00SoSKC`00?o0000oiFgkonE]nl00onE]nl7o`0000WoWKk_
00?o0000ojG1kOnU`Nd00onU`Nd00ol0003oYL7]ojG1k@02ojG1k@03o`000?n]`n[o[L?Z00_o[L?Z
00?o0000ok?5ioncaNL00_ncaNL3o`0000Go/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WT
okc9i008okc9i0;o000000?o^/_Wo`000?nmbN@03OnmbN@00ol0003o_/SRokk8hP07okk8hP;o0000
00?o^lSTo`000?nkaN803?nkaN800ol0003oooooooooo`0Xooooo`009_ooool00ol0003ooooooooo
o`1Looooo`?o00001oooool00ol0003oOZgaogj]l@06ogj]l@03o`000?n1[_7oPJka00KoPJka00?o
0000ohJalOn6/O401on6/O400ol0003oSKC`ohfdl003ohfdl0[o00001OnE^_400ol0003oWKk_oifn
k`09oifnk`03o`000?nU`NgoYL7]00?oYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3
jP0;ojg3jP04o`000?ncaNOo0000o`0000Wo/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WT
okc9i005okc9i0;o00001?njbnL00ol0003o_LWTokg9i00<okg9i003o`000?nnb>;o_/SR00Co_/SR
0_l00004ok_8i003o`000?nkaN;o^lGR00[o^lGR00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0FOooool3o`0000_ooooo00?o0000ogj]lOmn[O401_mn[O400ol0003oPJkaoh6^
l@06oh6^l@03o`000?n6/O7oQ[7a00?oQ[7a2Ol00005ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o
0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@03ojG1k@03o`000?nU`NgoYL7]00;oYL7]00?o
0000ojg3j_n]`nX02_n]`nX2o`0000co/lSZ00?o0000okS9ionhbNL02_nhbNL00ol0003o_<WTokc9
i002okc9i0;o00001onjbnL00ol0003o_LWTokg9i00<okg9i003o`000?nnb>;o_/SR00;o_/SR00?o
0000ok_8i?nkb>@01Onkb>@00ol0003o^lGRok_5hP0:ok_5hP03o`000?oooooooooo02Oooooo000V
ooooo`03o`000?oooooooooo05Kooooo0ol0000?oooooaOo00001On7/_800ol0003oSKKbohfflP07
ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@03
ojG1k@03o`000?nU`NgoYL7]00;oYL7]00?o0000ojg3j_n]`nX01_n]`nX3o`000003ojg7kOl0003o
/lSZ00co/lSZ00?o0000okS9ionhbNL02_nhbNL01?l0003o_<WTo`000?l0000:ok[;i`03o`000?nm
bNCo_LWT00co_LWT00Co0000okk8h_l0003o00002Onkb>@00ol0003o^lGRok_5hP0:ok_5hP03o`00
0?oooooooooo02Kooooo000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`03o`000?n0
[O7oP:ga00KoP:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=
]_;oSKKb00OoSKKb00?o0000oiFjlOnE^_402?nE^_400ol0003oWKk_oifnk`09oifnk`03o`000?nU
`NgoYL7]00?oYL7]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o[L?Zojg3jP03ojg3jP;o00001On]
and00ol0003o/lSZok?8jP0;ok?8jP03o`000?nhbNOo^<WW00Wo^<WW0ol0000<ok[;i`03o`000?nm
bNCo_LWT00_o_LWT0_l0000<ok_8i003o`000?nkaN;o^lGR00Wo^lGR0_l0000Wooooo`009Oooool0
0ol0003oooooooooo`1Aooooo`?o00005oooool00ol0003oP:gaoh2]l@06oh2]l@03o`000?n2[o;o
PZob00KoPZob00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7o
UK[a00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@02ojG1k@03o`000?nU`Ngo
YL7]00?oYL7]00?o0000ojg3j_l000000_l00008ojg7k@03o`000?ncb>[o/lSZ00_o/lSZ00?o0000
okS9ionhbNL01_nhbNL2o`0000?o]l_Y00?o0000ok[;ionjbnL02_njbnL00ol0003o_LWTokg9i008
okg9i0;o000000?o^/[Wo`000?nkb>@03?nkb>@00ol0003o^lGRok_5hP09ok_5hP03o`000?oooooo
oooo02Gooooo000Uooooo`?o0000C_ooool3o`0001[ooooo0_l00008oh2]l@03o`000?n2[o;oPZob
00KoPZob00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a
00SoUK[a00?o0000oifnkonM_^l02OnM_^l00ol0003oYL7]ojG1k@02ojG1k@04o`000?nU`NgoYL7]
ojG1k@Co00002on]and00ol0003o/lSZok?8jP0;ok?8jP03o`000?nhbNOo^<WW00;o^<WW0ol00006
okO;j@03o`000?njbnOo^/_W00[o^/_W00?o0000okg9i?nmbN@01OnmbN@2o`0000Co^/[W00?o0000
ok_8i?nkb>@02_nkb>@00ol0003o^lGRok_5hP09ok_5hP;o00009_ooool002Gooooo00?o0000oooo
ooooool0Boooool3o`0001kooooo0_l00008oh2]l@03o`000?n2[o;oPZob00KoPZob00?o0000ohNb
l_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a00SoUK[a00?o0000oifn
konM_^l02OnM_^l00ol0003oYL7]ojG1k@05o`0000CoYLC_00?o0000ojg7kOn]and02On]and00ol0
003o/lSZok?8jP0;ok?8jP04o`000?nhbNOo0000o`0000[o]l_Y00?o0000ok[;ionjbnL02_njbnL0
0ol0003o_LWTokg9i002okg9i0;o00001onjb^L00ol0003o^lSTok_8i00:ok_8i003o`000?nkaN;o
^lGR00Ko^lGR0_l000000onfa>Go0000o`00000Uooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003ooooooooo
o`18ooooo`?o00008_ooool2o`0000SoP:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNb
lP07ohNblP03o`000?n=]_;oSKKb00OoSKKb00?o0000oiFjlOnE^_402?nE^_400ol0003oWKk_oifn
k`07oifnk`Co00000onUa>l00ol0003oYLC_ojG4k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o
0000ok?8j_ncb>X02_ncb>X2o`0000go]l_Y00?o0000ok[;ionjbnL02_njbnL01?l0003o_LWTo`00
0?l0000:ok[:i`03o`000?nkb>Co^lST00[o^lST00?o0000ok_5h_nkaN800_nkaN83o`0000Co]/CU
0_l0000Tooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`15ooooo`?o00009_ooool2o`0000So
P:ga00?o0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=]_;oSKKb00Oo
SKKb00?o0000oiFjlOnE^_402?nE^_401?l0003oWKk_oifnkonM_^l5o`0000?oW/7a00?o0000ojG4
konUa>l00_nUa>l00ol0003oYLC_ojG4k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o0000ok?8
j_ncb>X01_ncb>X3o`0000;o//_/00?o0000okO;jOngbnT02ongbnT00ol0003o^/_Wok[;i`09ok[;
i`;o00003Onjb^L00ol0003o^lSTok_8i00:ok_8i004o`000?nkaN;o0000o`0000So]/CU00?o0000
ooooooooool08_ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000SoP:ga00?o
0000oh:_l_n2[o801_n2[o800ol0003oQk;bohNblP07ohNblP03o`000?n=]_;oSKKb00OoSKKb00?o
0000oiFjlOnE^_401_nE^_45o`0000WoW/7a00?o0000ojG4konUa>l00_nUa>l00ol0003oYLC_ojG4
k`04ojG4k`03o`000?n]ango[LO]00Wo[LO]00?o0000ok?8j_ncb>X00oncb>X2o`0000Ko//_/00?o
0000okO;jOngbnT02ongbnT00ol0003o^/_Wok[;i`06ok[;i`;o00000_ngc>T00ol0003o^/[Wok[:
i`0:ok[:i`03o`000?nkb>Co^lST00[o^lST0_l0000;okK4i@03o`000?oooooooooo027ooooo0009
ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo
00?o0000ooooooooool0?oooool3o`0002kooooo0_l00008oh2]l@03o`000?n2[o;oPZob00KoPZob
00?o0000ohNbl_n7/_801on7/_800ol0003oSKKbohfflP07ohfflP03o`000?nE^_7oUK[a00Go0000
0onF_O800ol0003oW/7aoik1l@09oik1l@03o`000?nUa>ooYLC_00;oYLC_00?o0000ojG4konUa>l0
1?nUa>l00ol0003o[LO]ojg7k@09ojg7k@03o`000?ncb>[o000000;o00002Onbbn`00ol0003o]l_Y
okO;j@0;okO;j@03o`000?njbnOo^/_W00;o^/_W0ol00005okO<j@03o`000?njb^Oo^/[W00[o^/[W
00?o0000ok_8i?nkb>@01_nkb>@3o`000003okK7iol0003o]/CU00[o]/CU0_l0000Rooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c007ooooo`03
o`000?oooooooooo03cooooo0ol0000booooo`;o00002?n0[O400ol0003oPZoboh:_lP06oh:_lP03
o`000?n7/_;oQk;b00OoQk;b00?o0000ohffl_n=]_800on=]_86o`0000WoU[gb00?o0000oik1lOnN
`O402OnN`O400ol0003oYLC_ojG4k`02ojG4k`03o`000?nUa>ooYLC_00CoYLC_00?o0000ojg7kOn]
and02?n]and3o`0000co//_/00?o0000okO;jOngbnT02ongbnT01?l0003o^/_Wo`000?l00009okO<
j@03o`000?njb^Oo^/[W00[o^/[W00?o0000ok_8i?nkb>@00onkb>@2o`0000Go]/OW00?o0000okK4
iOnfa>D02Onfa>D2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Kooooo0_l00008
oh2]l@03o`000?n2[o;oPZob00KoPZob00?o0000ohNbl_n7/_800on7/_89o`0000GoSkWc00?o0000
oiJml_nF_O802?nF_O800ol0003oW/7aoik1l@09oik1l@05o`000?nUa>ooYLC_ojG4kol000001onU
a>l00ol0003o[LO]ojg7k@04ojg7k@?o00000on/bNl00ol0003o//_/ok;;k00:ok;;k003o`000?ng
bnWo]l_Y00[o]l_Y0_l0000<okO<j@03o`000?njb^Oo^/[W00[o^/[W00?o0000ok_8i?l000000_l0
0008okK7i`03o`000?nfa>Go]/CU00Wo]/CU00?o0000ooooooooool07oooool000Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooo
ooooo`0gooooo`?o0000>_oooolHo`0000GoRKGc00?o0000ohnilon?^O<01on?^O<00ol0003oU[gb
oiJmlP08oiJmlP03o`000?nN`O7oW/7a00WoW/7a00Go0000ojG4konUa>ooYLC_o`000007ojG4k`03
o`000?n]ango[LO]00?o00001on/bNl00ol0003o//_/ok;;k00:ok;;k003o`000?ngbnWo]l_Y00Ko
]l_Y0ol000000ondcNco0000okO<j@0<okO<j@03o`000?njb^Oo^/[W00Wo^/[W0_l0000<okK7i`03
o`000?nfa>Go]/CU00So]/CU0_l0000Pooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo03Cooooo0ol0000noooo
o`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVe
l`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O802?nF_O800ol0003oW/7aoik1l@09oik1
l@05o`000?nUa>ooYLC_ojG4kol000001_nUa>l3o`0000_o[<W_00?o0000ok;;k?nbbn`02_nbbn`0
0ol0003o]l_YokO;j@03okO;j@;o00001OndcN`00ol0003o]lcYokO<j@0;okO<j@03o`000?njb^Oo
^/[W00Ko^/[W0_l000000oneb^[o0000okK7i`0<okK7i`03o`000?nfa>Go]/CU00So]/CU0_l0000O
ooooo`009?ooool00ol0003oooooooooo`0aooooo`?o0000@_ooool00ol0003oQ:oaohB_l@06ohB_
l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<01on9]O<00ol0003oSkWcohnil`07ohni
l`03o`000?nF_O;oU[gb00SoU[gb00?o0000oik1lOnN`O402OnN`O401Ol0003oYLC_ojG4konUa>oo
000000;oYLC_0ol00003ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00?o0000ok;;k?nbbn`02_nbbn`0
0ol0003o]l_Yo`000002o`0000So]<g/00?o0000okO<jOngc>T02ongc>T00ol0003o^/[Wok[:i`02
ok[:i`?o00001?neb^X00ol0003o]/OWokK7i`0:okK7i`03o`000?nfa>Go]/CU00Wo]/CU0_l0000N
ooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool00ol0003oQ:oaohB_l@06ohB_
l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<01on9]O<00ol0003oSkWcohnil`07ohni
l`03o`000?nF_O;oU[gb00SoU[gb00?o0000oik1lOnN`O402OnN`O400ol0003oYLC_ojG4k`03o`00
00OoYLOa00?o0000ojc9kon/bNl02On/bNl00ol0003o//_/ok;;k009ok;;k0;o00003?ndcN`00ol0
003o]lcYokO<j@0;okO<j@04o`000?njb^Oo0000o`0000So]L[Z00?o0000okK7ionfanL02_nfanL0
0ol0003o]/CUokK4i@08okK4i@;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`00
04Wooooo00?o0000ohB_lOn4[o401_n4[o400ol0003oQK7bohFalP07ohFalP03o`000?n9]O?oRKGc
00OoRKGc00?o0000ohnilon?^O<01on?^O<00ol0003oU[gboiJmlP08oiJmlP03o`000?nN`O7oW/7a
00OoW/7a1?l00002ojG7l@03o`000?nUao7oYLOa00KoYLOa00?o0000ojc9kon/bNl02On/bNl00ol0
003o//_/ok;;k006ok;;k0;o00000_n`cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo]lcY
00[o]lcY0_l0000;okG:jP03o`000?nfanOo]/OW00[o]/OW00?o0000okK4iOnfa>D01?nfa>D3o`00
0003ok32iol0003o000001gooooo000Tooooo`03o`000?oooooooooo02Wooooo0ol0001=ooooo`03
o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVel`03
o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O802?nF_O801?l0003oW/7aoik1lOnN`O45o`00
00?oW/Cc00Go0000ojG7lOnUao7oYLOao`000008ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00?o0000
ok;;k?nbbn`00_nbbn`3o`0000Go/<g_00?o0000okC=k?ndcN`02_ndcN`00ol0003o]lcYokO<j@06
okO<j@?o000000?o/lc/o`000?neb^X02oneb^X00ol0003o]/OWokK7i`0:okK7i`03o`000?nfa>Go
]/CU00?o00001On``^L2o`0001cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aoooo
o`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07ohVe
l`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O801_nF_O85o`0000WoW/Cc00Go0000ojG7
lOnUao7oYLOao`000008ojG7l@03o`000?n/bNoo[<W_00Wo[<W_00Co0000ok;;k?l0003o00002On`
cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo]lcY00?o]lcY0_l00005ok?<k003o`000?ne
b^[o]L[Z00[o]L[Z00?o0000okK7ionfanL02OnfanL3o`0000Wo/<;W0_l0000Kooooo`008oooool2
o`0002Gooooo0ol0001Eooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O80
0ol0003oRKGcohVel`07ohVel`03o`000?n?^O?oSkWc00OoSkWc00?o0000oiJml_nF_O801Ol00004
oiS0l`03o`000?nNa??oW/Cc00SoW/Cc00Co0000ojG7lOnUao7o00002OnUao400ol0003o[<W_ojc9
k`08ojc9k`?o00002on`cNl00ol0003o]<g/okC=k00:okC=k003o`000?ngc>Wo000000;o00002?nc
c>`00ol0003o]L[ZokG:jP0:okG:jP03o`000?nfanOo]/OW00Ko]/OW0_l000000on`a^[o0000ok32
i`0:ok32i`03o`000?oooooooooo01Wooooo000Tooooo`03o`000?oooooooooo023ooooo0ol0001I
ooooo`03o`000?n4[o7oQ:oa00KoQ:oa00?o0000ohFal_n5/O801on5/O800ol0003oRKGcohVel`07
ohVel`03o`000?n?^O?oSkWc00?oSkWc1_l0000:oiS0l`03o`000?nNa??oW/Cc00SoW/Cc00Co0000
ojG7lOnUao7o00002OnUao400ol0003o[<W_ojc9k`04ojc9k`?o00000on[c?400ol0003o/<g_ok3=
k`09ok3=k`03o`000?ndcNco]<g/00Wo]<g/0_l0000<ok?<k003o`000?neb^[o]L[Z00[o]L[Z00?o
0000okK7ionfanL00_nfanL3o`0000Co/<KZ00?o0000ok32ion``^L02On``^L00ol0003ooooooooo
o`0Hooooo`008oooool00ol0003oooooooooo`0Nooooo`?o0000GOooool00ol0003oQ:oaohB_l@06
ohB_l@03o`000?n5/O;oQK7b00OoQK7b00?o0000ohVelon9]O<00on9]O<9o`0000KoT[cc00?o0000
oiS0lonH`?<02?nH`?<00ol0003oW/Ccoik4l`08oik4l`04o`000?nUao7oYLOao`0000WoYLOa00?o
0000ojc9kon/bNl00ol00007oj_<l@03o`000?n`cNoo/<g_00Wo/<g_00?o0000okC=k?ndcN`01_nd
cN`2o`0000;o/Lg_00?o0000ok?<k?ncc>`02_ncc>`00ol0003o]L[ZokG:jP0:okG:jP04o`000?nf
anOo0000o`0000So/<KZ00?o0000ok32ion``^L02On``^L00ol0003oooooooooo`0Gooooo`008ooo
ool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oQ:oaohB_l@06ohB_l@03o`000?n5
/O;oQK7b00?oQK7b2Ol00005ohjhl`03o`000?nB_??oT[cc00SoT[cc00?o0000oiS0lonH`?<02?nH
`?<00ol0003oW/Ccoik4l`08oik4l`04o`000?nUao7oYLOao`0000OoYLOa1?l0000;oj_<l@03o`00
0?n`cNoo/<g_00Wo/<g_00?o0000okC=k?ndcN`00_ndcN`3o`0000Go/Lg_00?o0000ok?<k?ncc>`0
2_ncc>`00ol0003o]L[ZokG:jP08okG:jP?o00002on`a^X00ol0003o/<;Wok32i`08ok32i`;o0000
6?ooool002?ooooo00?o0000ooooooooool06?ooool3o`0006Gooooo3_l00005oh^dlP03o`000?n>
^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08oiS0l`03o`000?nN
a??oW/Cc00SoW/Cc00Co0000ojG7lOnUao7o00000onUao43o`0000CoY/[b00?o0000oj_<lOn[c?40
2On[c?400ol0003o/<g_ok3=k`09ok3=k`04o`000?ndcNco0000o`0000Wo/Lg_00?o0000ok?<k?nc
c>`02_ncc>`00ol0003o]L[ZokG:jP04okG:jP?o00000_n`bN`00ol0003o/<KZok36jP0:ok36jP03
o`000?n``^Oo/<;W00So/<;W00?o0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0
5Oooool3o`0006Sooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCboh^dlP07oh^dlP03o`00
0?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08oiS0l`03o`00
0?nNa??oW/Cc00SoW/Cc00?o0000ojG7lOnUao400ol00008ojK:lP03o`000?n[c?7oZlca00WoZlca
00?o0000ok3=kon`cNl02?n`cNl3o`0000_o/Lg_00?o0000ok?<k?ncc>`02_ncc>`00ol0003o]L[Z
okG:jP03o`0000Ko/<W/00?o0000ok36j_n`a^X02On`a^X00ol0003o/<;Wok32i`09ok32i`03o`00
0?oooooooooo01Gooooo000Sooooo`03o`000?oooooooooo01;ooooo0ol0001/ooooo`03o`000?n:
/O3oR[7`00OoR[7`00?o0000oh^dl_n;]?801on;]?800ol0003oS[Scohjhl`07ohjhl`03o`000?nB
_??oT[cc00SoT[cc00?o0000oiS0lonH`?<02?nH`?<00ol0003oW/Ccoik4l`06oik4l`Co000000?o
Y/[bo`000?nVb_802OnVb_800ol0003oZlcaoj_<l@09oj_<l@03o`000?n`cNoo/<g_00Co/<g_0ol0
0003ojk>l@03o`000?nacNoo/Lg_00Wo/Lg_00?o0000ok?<k?ncc>`02Oncc>`3o`0000[o/<W/00?o
0000ok36j_n`a^X02On`a^X00ol0003o/<;Wok32i`09ok32i`03o`000?oooooooooo01Cooooo000R
ooooo`?o00004?ooool3o`00073ooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCboh^dlP07
oh^dlP03o`000?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0003oV<3coiS0l`08
oiS0l`03o`000?nNa??oW/Cc00Go00001?nPao<00ol0003oY/[bo`00000:ojK:lP03o`000?n[c?7o
Zlca00WoZlca00?o0000ok3=kon`cNl00ol00007ojk>l@03o`000?nacNoo/Lg_00Wo/Lg_00?o0000
ok?<k?ncc>`01_ncc>`2o`0000;o[/__00?o0000ok39k?n`bN`02On`bN`00ol0003o/<KZok36jP09
ok36jP03o`000?n``^Oo/<;W00Oo/<;W0ol0000Eooooo`008oooool00ol0003oooooooooo`0<oooo
o`?o0000M?ooool00ol0003oR[7`ohZal007ohZal003o`000?n;]?;oRkCb00OoRkCb00?o0000ohjh
lon>^?<01on>^?<00ol0003oT[ccoi:ll`08oi:ll`03o`000?nH`??oV<3c00KoV<3c1?l0000:oj37
l`;o00002onVb_800ol0003oZlcaoj_<l@08oj_<l@?o00002on^c_400ol0003o/Lg_ok7=k`09ok7=
k`03o`000?ncc>co/lc/00;o/lc/0ol00005ojk;k`03o`000?n`bNco/<W/00Wo/<W/00?o0000ok36
j_n`a^X02On`a^X01?l0003o/<;Wok32ion``^L5o`0000;ooooo00?o0000ooooooooool04oooool0
02?ooooo00?o0000ooooooooool02Oooool3o`0007Sooooo00?o0000ohZal?n:/O001on:/O000ol0
003oRkCboh^dlP07oh^dlP03o`000?n>^??oS[Sc00OoS[Sc00?o0000oi:llonB_?<02?nB_?<00ol0
003oV<3coiS0l`05o`0000CoVl?d00?o0000oj37lonPao<02?nPao<2o`0000_oY/[b00?o0000oj_<
lOn[c?401?n[c?43o`0000?oZ/gb00?o0000ojk>lOn^c_402On^c_400ol0003o/Lg_ok7=k`09ok7=
k`04o`000?ncc>co0000o`0000Wo[/__00?o0000ok39k?n`bN`02On`bN`00ol0003o/<KZok36jP08
ok36jPKo00001Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06oooo
o`?o0000O?ooool00ol0003oR[7`ohZal007ohZal003o`000?n;]?;oRkCb00OoRkCb00?o0000ohjh
lon>^?<01on>^?<00ol0003oT[ccoi:ll`06oi:ll`Co00002_nK`o@00ol0003oX<Ocoj37l`08oj37
l`;o00002onVb_800ol0003oZlcaoj_<l@03o`0000OoZ/gb00?o0000ojk>lOn^c_402On^c_400ol0
003o/Lg_ok7=k`08ok7=k`;o00003?n^bnl00ol0003o/<W/ok39k009ok39k003o`000?n`a^[o/<KZ
00Co/<KZ1_l00008ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Co
oooo0ol00020ooooo`03o`000?n:/O3oR[7`00OoR[7`00?o0000oh^dl_n;]?801on;]?800ol0003o
S[Scohjhl`07ohjhl`03o`000?nB_??oT[cc00Go00000onG_o<00ol0003oVl?doi_3m009oi_3m003
o`000?nPao?oX<Oc00WoX<Oc00?o0000ojK:l_nVb_802?nVb_83o`0000_oZ/gb00?o0000ojk>lOn^
c_402On^c_400ol0003o/Lg_ok7=k`04ok7=k`?o00000_n]cO400ol0003o[/__ojk;k`0:ojk;k`03
o`000?n`bNco/<W/00Wo/<W/00?o0000ok36j_n`a^X01Ol0000<ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`04o`000?ooooooooooooooo`?o0000Q?ooool00ol0003oR[7`ohZal007ohZal003
o`000?n;]?;oRkCb00OoRkCb00?o0000ohjhlon>^?<00on>^?<6o`0000WoUkoc00?o0000oi_3m?nK
`o@02OnK`o@00ol0003oX<Ocoj37l`09oj37l`03o`000?nVb_;oY/[b00CoY/[b0ol00003ojK<l`03
o`000?nZcO;oZ/gb00WoZ/gb00?o0000ojk>lOn^c_402On^c_400ol0003o/Lg_ok7=k`03o`0000Ko
[Lga00?o0000ojk;kon^bnl02_n^bnl00ol0003o/<W/ok39k008ok39k0Go00003oooool00ol0003o
ooooooooo`0Cooooo`008_ooool4o`0008Sooooo00?o0000ohZal?n:/O001on:/O000ol0003oRkCb
oh^dlP03oh^dlPWo00001_nD^o800ol0003oUkocoiNol`07oiNol`03o`000?nK`oCoVl?d00WoVl?d
00?o0000oj37lonPao<02OnPao<00ol0003oY/[bojK:lP03o`0000OoY/cc00?o0000oj[=l_nZcO80
2OnZcO800ol0003o[/kaojk>l@08ojk>l@?o00002_n]cO400ol0003o[/__ojk;k`0:ojk;k`03o`00
0?n`bNco/<W/00Co/<W/1Ol0000Booooo`03o`000?oooooooooo01?ooooo000Rooooo`?o0000R_oo
ool00ol0003oR[7`ohZal003ohZal0Wo00001_nB^?400ol0003oU;_boiBklP07oiBklP03o`000?nG
_o?oUkoc00OoUkoc00?o0000oi_3m?nK`o@02OnK`o@00ol0003oX<Ocoj37l`07oj37l`Co00002onV
c?<00ol0003oZ/gboj[=lP09oj[=lP03o`000?n^c_7o[/ka00Co[/ka0ol00002oj_>lP03o`000?n]
cO7o[Lga00Wo[Lga00?o0000ojk;kon^bnl02_n^bnl00ol0003o/<W/ok39k004o`0001Oooooo00?o
0000ooooooooool04_ooool002Cooooo00?o0000ooooooooool0ROooool5o`0000GoT[C^00?o0000
oi:hlOnB^?402?nB^?400ol0003oU;_boiBklP07oiBklP03o`000?nG_o?oUkoc00OoUkoc00?o0000
oi_3m?nK`o@02OnK`o@01?l0003oX<Ocoj37lonPao<5o`0000;oXlWd0_l0000<ojK<l`03o`000?nZ
cO;oZ/gb00WoZ/gb00?o0000ojk>lOn^c_400ol00006oj_>lP03o`000?n]cO7o[Lga00Wo[Lga00?o
0000ojk;kon^bnl02?n^bnl5o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^
o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000
oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00OoU;_b00?o0000
oiNolonG_o<01onG_o<00ol0003oVl?doi_3m008oi_3m0Co00002?nSbO@2o`0000coY/cc00?o0000
oj[=l_nZcO802?nZcO83o`0000[oZlkb00?o0000ojg=lOn]cO402On]cO400ol0003o[/__ojk;k`04
ojk;k`Go00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01OmgMgOoV9RHooooool0003o
MgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7o
T[Sa00SoT[Sa00?o0000oiBkl_nD^o801onD^o800ol0003oUkocoiNol`07oiNol`03o`000?nK`oCo
Vl?d00CoVl?d0ol00003oio6l`03o`000?nSbOCoXlWd00OoXlWd0_l0000<ojK<l`03o`000?nZcO;o
Z/gb00CoZ/gb0ol00003ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=lOn]cO402On]cO40
0ol0003o[/__ojk;k`04o`00027ooooo00?o0000ooooooooool04_ooool001Kooooo00Go410@oooo
oooooooo0000oa0@400<ooooo`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h0
0ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00OoU;_b00?o0000oiNolonG_o<01onG_o<0
0ol0003oVl?doi_3m003o`0000OoWlKc00?o0000oj?9m?nSbO@01onSbO@2o`0000coY/cc00?o0000
oj[=l_nZcO800ol00007ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=lOn]cO402?n]cO44
o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:h
l@03o`000?nD^o;oU;_b00OoU;_b00?o0000oiNolonG_o<00onG_o<6o`0000_oWlKc00?o0000oj?9
m?nSbO@01onSbO@2o`0000[oY/cc1?l0000;ojW>l`03o`000?n[c_;oZlkb00SoZlkb00?o0000ojg=
lOn]cO401?n]cO44o`0002Oooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000oooooooo
ool00_l0000>ooooo`03o`000?oooooooooo08Wooooo00?o0000oi:dk_nB]>h01onB]>h00ol0003o
T[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00GoU;_b1ol00006oig2l`03o`000?nOa_?oWlKc00Wo
WlKc00?o0000oj?9m?nSbO@01onSbO@2o`0000KoY/cc0ol00004ojO=m003o`000?nYc_?oZLkc00Wo
ZLkc00?o0000oj_>l_n[c_802?n[c_800ol0003o[Lgaojg=l@04o`0002[ooooo00?o0000oooooooo
ool04_ooool001Kooooo00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo08Wo
oooo00?o0000oi:dk_nB]>h01onB]>h00ol0003oT[Saoi:hl@08oi:hl@03o`000?nD^o;oU;_b00Co
00001?nK_o400ol0003oWL;coig2l`07oig2l`03o`000?nOa_?oWlKc00WoWlKc00?o0000oj?9m?nS
bO@01onSbO@2o`0000;oY/cc0ol00008ojO=m003o`000?nYc_?oZLkc00WoZLkc00?o0000oj_>l_n[
c_801_n[c_84o`0002kooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo
0000ogMgM`0@ooooo`;o0000R_ooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7oT[Sa00Ko
T[Sa1?l00009oi^ol@03o`000?nM`_?oWL;c00OoWL;c00?o0000oio6lonOa_<02OnOa_<00ol0003o
XlWdoj?9m006oj?9m0Co00003?nWcO@00ol0003oZLkcojW>l`09ojW>l`03o`000?n[c_;oZlkb00Ko
0000<Oooool00ol0003oooooooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;o
oooo00?o0000ooooooooool0R?ooool00ol0003oT[C^oi:dkP07oi:dkP03o`000?nB^?7oT[Sa00Go
00000onJ^nl00ol0003oVkoaoi^ol@08oi^ol@03o`000?nM`_?oWL;c00OoWL;c0_l0000:oio6l`03
o`000?nSbOCoXlWd00Go000000GoYL_co`000?nUbo?oYL_co`00000<ojO=m003o`000?nYc_?oZLkc
00SoZLkc1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000008[o
oooo00?o0000oi:dk_nB]>h00onB]>h6o`0000WoV[__00?o0000oi^olOnK_o402?nK_o400ol0003o
WL;coig2l`08oig2l`03o`000?nOa_?oWlKc00OoWlKc0ol00007ojG;l`04o`000?nUbo?oYL_co`00
00coYlgd00?o0000ojW>lonYc_<01?nYc_<5o`0003Sooooo00?o0000ooooooooool04_ooool002oo
oooo00?o0000ooooooooool0R?ooool5o`0000GoV[S/00?o0000oiZkkonJ^nl02?nJ^nl00ol0003o
Vkoaoi^ol@08oi^ol@03o`000?nM`_?oWL;c00SoWL;c00?o0000oio6lonOa_<00onOa_<3o`0000?o
Y<Sb00?o0000ojG;lonUbo<01OnUbo<00ol0003oYL_cojG;l`02o`0000_oYlgd00?o0000ojW>lonY
c_<01Ol0000looooo`03o`000?oooooooooo017ooooo000`ooooo`03o`000?oooooooooo08Oooooo
0_l00009oiZhk003o`000?nJ^nooV[__00SoV[__00?o0000oi^olOnK_o402?nK_o400ol0003oWL;c
oig2l`08oig2l`03o`000?nOa_?o000000;o00001onTb?800ol0003oYL_cojG;l`05ojG;l`05o`00
0?nUbo?oYL_cojG;lol000002_nWcO@5o`0003oooooo00?o0000ooooooooool04Oooool0037ooooo
00?o0000ooooooooool0Qoooool2o`0000WoV[S/00?o0000oiZkkonJ^nl02?nJ^nl00ol0003oVkoa
oi^ol@08oi^ol@03o`000?nM`_?oWL;c00KoWL;c1?l0000:ojC8lP03o`000?nUbo?oYL_c00GoYL_c
00Go0000ojG;lonUbo?oYL_co`000006ojO=m0Co0000@oooool00ol0003oooooooooo`0Aooooo`00
<_ooool00ol0003oooooooooo`27ooooo`;o00002OnJ^>`00ol0003oV[__oiZkk`08oiZkk`03o`00
0?nK_o7oVkoa00SoVkoa00?o0000oig2lonM`_<01Ol00004oj?5l@03o`000?nTb?;oY<Sb00SoY<Sb
00?o0000ojG;lonUbo<01OnUbo<01Ol0003oYL_cojG;lonUbo?o000000;oYlgd1?l00016ooooo`03
o`000?oooooooooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo0_l00009oiZhk003o`00
0?nJ^nooV[__00SoV[__00?o0000oi^olOnK_o401_nK_o44o`0000[oXlGa00?o0000ojC8l_nTb?80
2?nTb?800ol0003oYL_cojG;l`05ojG;l`03o`000?nUbo?oYL_c00Co0000BOooool00ol0003ooooo
ooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oiZhk003o`000?nJ^nooV[__00SoV[__00?o
0000oi^olOnK_o401Ol00004oj;2k`03o`000?nSaO7oXlGa00SoXlGa00?o0000ojC8l_nTb?802?nT
b?800ol0003oYL_cojG;l`04ojG;l`?o0000COooool00ol0003oooooooooo`0Aooooo`00=_ooool0
0ol0003oooooooooo`26ooooo`;o00002OnJ^>`00ol0003oV[__oiZkk`06oiZkk`Co00002_nR`^l0
0ol0003oXlGaoj?5l@08oj?5l@03o`000?nTb?;oY<Sb00SoY<Sb00?o0000ojG;lonUbo<00ol00000
0ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000gooooo`;o0000Qoooool2o`00
00WoV[S/00?o0000oiZkkonJ^nl01Ol00003oj:nk@03o`000?nR`^ooX/;_00WoX/;_00?o0000oj?5
lOnSaO402?nSaO400ol0003oY<SbojC8lP06ojC8lPCo00001Oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo000008Sooooo0_l00007oiZhk0Co
00002OnR_^d00ol0003oX/;_oj;2k`09oj;2k`03o`000?nSaO7oXlGa00SoXlGa00?o0000ojC8l_nT
b?801Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04Oooool003Wooooo
00?o0000ooooooooool0Q_ooool2o`0000;oV[S/1?l00003oj:jjP03o`000?nR_^goX[k]00SoX[k]
00?o0000oj;2konR`^l02OnR`^l00ol0003oXlGaoj?5l@07oj?5l@Go00003_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`000?oooooooooo08Kooooo0ol0
0008oj:jjP03o`000?nR_^goX[k]00SoX[k]00?o0000oj;2konR`^l02OnR`^l00ol0003oXlGaoj?5
l@03oj?5l@Go00004_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo017ooooo000k
ooooo`03o`000?oooooooooo08Kooooo00?o0000oj:jj_nR^^X02?nR^^X00ol0003oX[k]oj:nk@08
oj:nk@03o`000?nR`^ooX/;_00WoX/;_00?o0000oj?5lOl000000ol0000Gooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool04?ooool003cooooo00?o0000ooooooooool0Q_ooool00ol0
003oX[[Zoj:jjP08oj:jjP03o`000?nR_^goX[k]00SoX[k]00?o0000oj;2konR`^l02?nR`^l3o`00
01_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0@ooooo`00?Oooool2o`0008Oo
oooo00?o0000oj:jj_nR^^X02?nR^^X00ol0003oX[k]oj:nk@08oj:nk@03o`000?nR`^ooX/;_00Co
X/;_0ol0000Oooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool04?ooool003oooooo
00?o0000ooooooooool0QOooool00ol0003oX[[Zoj:jjP08oj:jjP03o`000?nR_^goX[k]00SoX[k]
00?o0000oj;2konR`^l00ol0000Rooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
4?ooool0043ooooo00?o0000ooooooooool0QOooool00ol0003oX[[Zoj:jjP08oj:jjP03o`000?nR
_^goX[k]00KoX[k]1?l0000Vooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?oo
ool0047ooooo0_l00026ooooo`03o`000?nR^^[oX[[Z00SoX[[Z00?o0000oj:nkOnR_^d01Ol0000[
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool0043ooooo00?o0000oooo
ool00000Qoooool00ol0003oX[[Zoj:jjP07oj:jjPGo0000;oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo08Gooooo00?o0000oj:jj_nR
^^X00onR^^X4o`0003Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0@ooooo`00
A?ooool00ol0003oooooooooo`25ooooo`03o`000?nR^^[o000000?o0000>?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo013ooooo0015ooooo`03o`000?oooooooooo08Gooooo0_l0
000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool04?ooool004Kooooo0_l00025
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0@
ooooo`00B?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`00
B_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0?ooooo`00B_ooool2o`00087ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo001<ooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00oooooo001=ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo001>ooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oo
oooo001?ooooo`;o0000O?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool03oooool0057ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03oooool005;ooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool03oooool005?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool005Cooooo0ol0001fooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`00
E?ooool2o`0007Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02?ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool02?ooool2o`0007?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00kooooo000hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0;ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool003So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0K_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00004?ooool2o`0006kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo06_ooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo001Pooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00kooooo001Qooooo`;o0000J_ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool03Oooool006?ooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool0
06Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03Oooool006Gooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool006Kooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool03Oooool006Kooooo0ol0001Tooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`00J?ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=
ooooo`00JOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0=ooooo`00J_ooool2o`00067ooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo001/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo001^ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00cooooo001_ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo001_ooooo`?o0000Foooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool0077ooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool007;ooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007?ooooo0_l0001H
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0<
ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`00
Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo001hooooo`;o0000Doooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool0
07[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool007cooooo
0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Ooooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;
ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`0004Wooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo001fooooo`Co0000
00?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2o`0004Kooooo00?o0000oooo
ooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo001Looooo`?o
000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_o
oooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`000?oooooooooo00kooooo0_l0
0012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmVIVKo0000013ooooo0_l00012
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:
ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05
omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00GOooool01OmVIVKo
QhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool005cooooo00?ok^k^o`000?o^
k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo002Aooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
09Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo002Looooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Nooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Pooooo`;o0000:oooool00ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00:7ooooo
0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000ooooooooooooooooo`00000:ooooo`00
Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo
00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0QOoo
ool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Q?ooool3
o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0P?ooool4o`00
00gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000ooooooooool0O?ooool4o`00
017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1hooooo`Co00005Oooool0093o
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Iooooo`00T?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0KOooool3o`00027ooooo002@
ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo002@ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/ooooo`00S_ooool00omEEEGo
IVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000ooooooooool0GOooool4o`00033o
oooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co0000=?ooool00;Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000>?ooool00;Gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??ooool00;Kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool00;Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;Sooooo0_l0000Cooooo`03o`00
0?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000ooooooooool0>_ooool4o`00
05?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0=_ooool4o`0005Oo
oooo002nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool4o`0005_ooooo
002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000Goooool00;oooooo0_l0000<
ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo00?o0000ooooooooool06_oo
ool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003oooooooooo`0Fooooo`Co0000Moooool0
0<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001kooooo`00b?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001nooooo`00bOooool01Ol0003ooooo
oooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003oooooooooool00009ooooo`Co
0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[ooooo003<ooooo`Oo0000S_oo
ool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02J
ooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onHV9So8B4Qonk^kP2Jooooo`00
aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003oooooooooo`2Hooooo`00`_ooool0
1Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0V_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_oo
ool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:Gooooo0ol000000ol@413ooooo
ooooo`2fooooo`00Toooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjoooo
o`05ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo09Wooooo002C
ooooo`03o`000?oooooooooo00[ooooo0_lb<S85ooooo`03oiRHV?lb<S;ooooo00Gooooo0_lb<S8>
ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Jooooo`00R?ooool01Ol@413o0000o`000?l0003o
410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj
^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRH
V?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo077ooooo002:ooooo`03o`000?oooooooooo00Kooooo00[o0000oooooooo
ooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`03oeEE
EOmgMgOoA4A400Gooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Co
oooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?o
EEEEojVYZOooool0LOooool008[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`04omgMgOl0003o410@olc<c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`05oa0@
4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`1aooooo`00R_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKo
QhN7oooooonHV9SoEEEE00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`1`ooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgo
oooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo073ooooo0027
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
073ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b077ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool01Oooool2
o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
001aooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.644 .732 .913 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68056 Metetra
.644 .742 .92 r
.55403 .68056 .58394 .7109 .61197 .70234 .58234 .67328 Metetra
.645 .753 .927 r
.58234 .67328 .61197 .70234 .64019 .69372 .61086 .66578 Metetra
.647 .762 .933 r
.61086 .66578 .64019 .69372 .66861 .68504 .6396 .658 Metetra
.65 .771 .937 r
.6396 .658 .66861 .68504 .69723 .6763 .66855 .64989 Metetra
.654 .779 .94 r
.66855 .64989 .69723 .6763 .72605 .6675 .6977 .64139 Metetra
.659 .784 .941 r
.6977 .64139 .72605 .6675 .75507 .65863 .72705 .63248 Metetra
.664 .787 .94 r
.72705 .63248 .75507 .65863 .7843 .6497 .75661 .62315 Metetra
.669 .787 .937 r
.75661 .62315 .7843 .6497 .81374 .64071 .78635 .6134 Metetra
.674 .785 .932 r
.78635 .6134 .81374 .64071 .84339 .63166 .81629 .60326 Metetra
.679 .78 .927 r
.81629 .60326 .84339 .63166 .87325 .62254 .84641 .59276 Metetra
.682 .773 .92 r
.84641 .59276 .87325 .62254 .90333 .61335 .87673 .58197 Metetra
.684 .765 .913 r
.87673 .58197 .90333 .61335 .93362 .6041 .90723 .57095 Metetra
.685 .755 .905 r
.90723 .57095 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.622 .725 .92 r
.49498 .6552 .52593 .68772 .55403 .68056 .52331 .64933 Metetra
.623 .735 .927 r
.52331 .64933 .55403 .68056 .58234 .67328 .55189 .64325 Metetra
.626 .745 .933 r
.55189 .64325 .58234 .67328 .61086 .66578 .5807 .63682 Metetra
.631 .756 .937 r
.5807 .63682 .61086 .66578 .6396 .658 .60974 .6299 Metetra
.638 .766 .94 r
.60974 .6299 .6396 .658 .66855 .64989 .63901 .62237 Metetra
.647 .774 .941 r
.63901 .62237 .66855 .64989 .6977 .64139 .6685 .61415 Metetra
.657 .781 .94 r
.6685 .61415 .6977 .64139 .72705 .63248 .69819 .60518 Metetra
.667 .785 .937 r
.69819 .60518 .72705 .63248 .75661 .62315 .72807 .59544 Metetra
.677 .787 .932 r
.72807 .59544 .75661 .62315 .78635 .6134 .75813 .58493 Metetra
.685 .786 .926 r
.75813 .58493 .78635 .6134 .81629 .60326 .78837 .57373 Metetra
.693 .782 .92 r
.78837 .57373 .81629 .60326 .84641 .59276 .81878 .56189 Metetra
.698 .776 .912 r
.81878 .56189 .84641 .59276 .87673 .58197 .84936 .54953 Metetra
.701 .769 .905 r
.84936 .54953 .87673 .58197 .90723 .57095 .88011 .53679 Metetra
.702 .76 .898 r
.88011 .53679 .90723 .57095 .93794 .55978 .91103 .52381 Metetra
.6 .717 .926 r
.4632 .62183 .49498 .6552 .52331 .64933 .49177 .6171 Metetra
.602 .727 .932 r
.49177 .6171 .52331 .64933 .55189 .64325 .52059 .61209 Metetra
.607 .737 .937 r
.52059 .61209 .55189 .64325 .5807 .63682 .54968 .6066 Metetra
.615 .748 .94 r
.54968 .6066 .5807 .63682 .60974 .6299 .57902 .60043 Metetra
.627 .758 .941 r
.57902 .60043 .60974 .6299 .63901 .62237 .6086 .5934 Metetra
.641 .768 .94 r
.6086 .5934 .63901 .62237 .6685 .61415 .63841 .58541 Metetra
.655 .775 .937 r
.63841 .58541 .6685 .61415 .69819 .60518 .66843 .57635 Metetra
.67 .781 .933 r
.66843 .57635 .69819 .60518 .72807 .59544 .69865 .5662 Metetra
.683 .784 .927 r
.69865 .5662 .72807 .59544 .75813 .58493 .72904 .55498 Metetra
.695 .784 .92 r
.72904 .55498 .75813 .58493 .78837 .57373 .7596 .54276 Metetra
.704 .782 .912 r
.7596 .54276 .78837 .57373 .81878 .56189 .79032 .52966 Metetra
.711 .778 .904 r
.79032 .52966 .81878 .56189 .84936 .54953 .82118 .51584 Metetra
.715 .771 .897 r
.82118 .51584 .84936 .54953 .88011 .53679 .85219 .5015 Metetra
.716 .764 .89 r
.85219 .5015 .88011 .53679 .91103 .52381 .88337 .48685 Metetra
.581 .71 .931 r
.43058 .58756 .4632 .62183 .49177 .6171 .45936 .58375 Metetra
.583 .718 .936 r
.45936 .58375 .49177 .6171 .52059 .61209 .48842 .5796 Metetra
.591 .728 .939 r
.48842 .5796 .52059 .61209 .54968 .6066 .51776 .57487 Metetra
.603 .739 .941 r
.51776 .57487 .54968 .6066 .57902 .60043 .54738 .56929 Metetra
.618 .75 .94 r
.54738 .56929 .57902 .60043 .6086 .5934 .57727 .56265 Metetra
.636 .76 .938 r
.57727 .56265 .6086 .5934 .63841 .58541 .6074 .5548 Metetra
.654 .768 .933 r
.6074 .5548 .63841 .58541 .66843 .57635 .63775 .54562 Metetra
.672 .775 .927 r
.63775 .54562 .66843 .57635 .69865 .5662 .6683 .53507 Metetra
.688 .779 .92 r
.6683 .53507 .69865 .5662 .72904 .55498 .69904 .52319 Metetra
.702 .78 .912 r
.69904 .52319 .72904 .55498 .7596 .54276 .72993 .51006 Metetra
.713 .779 .904 r
.72993 .51006 .7596 .54276 .79032 .52966 .76097 .49584 Metetra
.721 .776 .896 r
.76097 .49584 .79032 .52966 .82118 .51584 .79215 .48073 Metetra
.725 .772 .89 r
.79215 .48073 .82118 .51584 .85219 .5015 .82347 .46497 Metetra
.727 .766 .884 r
.82347 .46497 .85219 .5015 .88337 .48685 .85493 .44884 Metetra
.565 .704 .935 r
.39706 .55236 .43058 .58756 .45936 .58375 .42605 .54919 Metetra
.569 .711 .938 r
.42605 .54919 .45936 .58375 .48842 .5796 .45534 .54564 Metetra
.579 .72 .939 r
.45534 .54564 .48842 .5796 .51776 .57487 .48494 .54141 Metetra
.594 .73 .939 r
.48494 .54141 .51776 .57487 .54738 .56929 .51483 .53622 Metetra
.612 .741 .937 r
.51483 .53622 .54738 .56929 .57727 .56265 .545 .52981 Metetra
.633 .751 .933 r
.545 .52981 .57727 .56265 .6074 .5548 .57544 .52199 Metetra
.654 .76 .928 r
.57544 .52199 .6074 .5548 .63775 .54562 .60612 .51265 Metetra
.674 .767 .921 r
.60612 .51265 .63775 .54562 .6683 .53507 .63701 .50173 Metetra
.692 .771 .913 r
.63701 .50173 .6683 .53507 .69904 .52319 .66809 .48926 Metetra
.707 .774 .905 r
.66809 .48926 .69904 .52319 .72993 .51006 .69933 .47536 Metetra
.719 .775 .897 r
.69933 .47536 .72993 .51006 .76097 .49584 .73072 .46019 Metetra
.727 .773 .889 r
.73072 .46019 .76097 .49584 .79215 .48073 .76224 .444 Metetra
.733 .771 .883 r
.76224 .444 .79215 .48073 .82347 .46497 .79389 .42709 Metetra
.735 .767 .879 r
.79389 .42709 .82347 .46497 .85493 .44884 .82567 .40974 Metetra
.555 .7 .937 r
.36263 .5162 .39706 .55236 .42605 .54919 .39182 .51333 Metetra
.56 .706 .938 r
.39182 .51333 .42605 .54919 .45534 .54564 .42134 .51006 Metetra
.572 .713 .938 r
.42134 .51006 .45534 .54564 .48494 .54141 .45117 .50606 Metetra
.589 .723 .936 r
.45117 .50606 .48494 .54141 .51483 .53622 .48133 .50101 Metetra
.609 .733 .933 r
.48133 .50101 .51483 .53622 .545 .52981 .51178 .49464 Metetra
.631 .742 .928 r
.51178 .49464 .545 .52981 .57544 .52199 .54253 .48674 Metetra
.653 .751 .921 r
.54253 .48674 .57544 .52199 .60612 .51265 .57353 .47718 Metetra
.674 .758 .914 r
.57353 .47718 .60612 .51265 .63701 .50173 .60475 .4659 Metetra
.693 .763 .906 r
.60475 .4659 .63701 .50173 .66809 .48926 .63618 .45294 Metetra
.709 .767 .897 r
.63618 .45294 .66809 .48926 .69933 .47536 .66778 .43842 Metetra
.722 .769 .89 r
.66778 .43842 .69933 .47536 .73072 .46019 .69953 .42254 Metetra
.731 .769 .884 r
.69953 .42254 .73072 .46019 .76224 .444 .73141 .40554 Metetra
.736 .768 .878 r
.73141 .40554 .76224 .444 .79389 .42709 .76342 .38775 Metetra
.739 .766 .875 r
.76342 .38775 .79389 .42709 .82567 .40974 .79557 .36951 Metetra
.551 .699 .938 r
.32723 .47902 .36263 .5162 .39182 .51333 .35664 .47609 Metetra
.558 .703 .937 r
.35664 .47609 .39182 .51333 .42134 .51006 .38638 .47276 Metetra
.571 .709 .935 r
.38638 .47276 .42134 .51006 .45117 .50606 .41645 .46867 Metetra
.588 .716 .932 r
.41645 .46867 .45117 .50606 .48133 .50101 .44687 .4635 Metetra
.609 .725 .927 r
.44687 .4635 .48133 .50101 .51178 .49464 .4776 .45695 Metetra
.631 .734 .921 r
.4776 .45695 .51178 .49464 .54253 .48674 .50864 .44884 Metetra
.654 .742 .914 r
.50864 .44884 .54253 .48674 .57353 .47718 .53995 .43901 Metetra
.674 .749 .906 r
.53995 .43901 .57353 .47718 .60475 .4659 .57152 .42739 Metetra
.693 .754 .899 r
.57152 .42739 .60475 .4659 .63618 .45294 .60329 .41405 Metetra
.709 .759 .891 r
.60329 .41405 .63618 .45294 .66778 .43842 .63525 .3991 Metetra
.721 .762 .884 r
.63525 .3991 .66778 .43842 .69953 .42254 .66737 .38273 Metetra
.731 .764 .879 r
.66737 .38273 .69953 .42254 .73141 .40554 .69964 .36521 Metetra
.737 .765 .875 r
.69964 .36521 .73141 .40554 .76342 .38775 .73204 .34689 Metetra
.74 .765 .873 r
.73204 .34689 .76342 .38775 .79557 .36951 .76458 .32809 Metetra
.555 .7 .937 r
.29083 .44079 .32723 .47902 .35664 .47609 .32046 .43743 Metetra
.562 .702 .935 r
.32046 .43743 .35664 .47609 .38638 .47276 .35044 .43366 Metetra
.575 .706 .931 r
.35044 .43366 .38638 .47276 .41645 .46867 .38076 .42915 Metetra
.592 .712 .927 r
.38076 .42915 .41645 .46867 .44687 .4635 .41144 .42356 Metetra
.612 .718 .921 r
.41144 .42356 .44687 .4635 .4776 .45695 .44245 .41663 Metetra
.633 .725 .914 r
.44245 .41663 .4776 .45695 .50864 .44884 .47377 .40815 Metetra
.654 .732 .907 r
.47377 .40815 .50864 .44884 .53995 .43901 .5054 .39799 Metetra
.674 .739 .9 r
.5054 .39799 .53995 .43901 .57152 .42739 .53729 .38607 Metetra
.691 .745 .892 r
.53729 .38607 .57152 .42739 .60329 .41405 .56941 .37245 Metetra
.706 .75 .886 r
.56941 .37245 .60329 .41405 .63525 .3991 .60173 .35726 Metetra
.719 .754 .88 r
.60173 .35726 .63525 .3991 .66737 .38273 .63423 .34066 Metetra
.728 .758 .876 r
.63423 .34066 .66737 .38273 .69964 .36521 .66689 .32294 Metetra
.735 .76 .873 r
.66689 .32294 .69964 .36521 .73204 .34689 .6997 .30442 Metetra
.738 .762 .872 r
.6997 .30442 .73204 .34689 .76458 .32809 .73265 .28543 Metetra
.565 .704 .935 r
.25338 .40146 .29083 .44079 .32046 .43743 .28327 .39728 Metetra
.572 .704 .931 r
.28327 .39728 .32046 .43743 .35044 .43366 .3135 .39272 Metetra
.584 .705 .926 r
.3135 .39272 .35044 .43366 .38076 .42915 .34409 .38745 Metetra
.599 .709 .921 r
.34409 .38745 .38076 .42915 .41144 .42356 .37502 .38118 Metetra
.617 .713 .914 r
.37502 .38118 .41144 .42356 .44245 .41663 .40631 .37365 Metetra
.636 .719 .907 r
.40631 .37365 .44245 .41663 .47377 .40815 .43793 .36466 Metetra
.654 .724 .9 r
.43793 .36466 .47377 .40815 .5054 .39799 .46985 .35411 Metetra
.672 .73 .893 r
.46985 .35411 .5054 .39799 .53729 .38607 .50206 .34192 Metetra
.688 .736 .887 r
.50206 .34192 .53729 .38607 .56941 .37245 .53452 .32813 Metetra
.702 .741 .882 r
.53452 .32813 .56941 .37245 .60173 .35726 .56721 .31287 Metetra
.714 .746 .877 r
.56721 .31287 .60173 .35726 .63423 .34066 .60009 .2963 Metetra
.723 .751 .874 r
.60009 .2963 .63423 .34066 .66689 .32294 .63315 .27868 Metetra
.729 .755 .873 r
.63315 .27868 .66689 .32294 .6997 .30442 .66637 .2603 Metetra
.733 .759 .873 r
.66637 .2603 .6997 .30442 .73265 .28543 .69976 .24147 Metetra
.581 .71 .931 r
.21484 .36098 .25338 .40146 .28327 .39728 .24502 .35563 Metetra
.587 .707 .926 r
.24502 .35563 .28327 .39728 .3135 .39272 .27553 .34993 Metetra
.597 .707 .92 r
.27553 .34993 .3135 .39272 .34409 .38745 .30639 .3436 Metetra
.609 .707 .914 r
.30639 .3436 .34409 .38745 .37502 .38118 .33761 .33638 Metetra
.624 .71 .907 r
.33761 .33638 .37502 .38118 .40631 .37365 .36918 .32804 Metetra
.64 .713 .9 r
.36918 .32804 .40631 .37365 .43793 .36466 .40108 .31842 Metetra
.655 .717 .894 r
.40108 .31842 .43793 .36466 .46985 .35411 .43331 .30742 Metetra
.67 .722 .888 r
.43331 .30742 .46985 .35411 .50206 .34192 .46583 .29497 Metetra
.684 .727 .883 r
.46583 .29497 .50206 .34192 .53452 .32813 .49862 .28112 Metetra
.696 .733 .879 r
.49862 .28112 .53452 .32813 .56721 .31287 .53166 .26597 Metetra
.707 .738 .876 r
.53166 .26597 .56721 .31287 .60009 .2963 .56492 .24966 Metetra
.715 .744 .875 r
.56492 .24966 .60009 .2963 .63315 .27868 .59837 .23241 Metetra
.721 .749 .875 r
.59837 .23241 .63315 .27868 .66637 .2603 .63202 .21449 Metetra
.725 .755 .876 r
.63202 .21449 .66637 .2603 .69976 .24147 .66586 .19616 Metetra
.6 .717 .926 r
.17516 .3193 .21484 .36098 .24502 .35563 .20566 .31247 Metetra
.605 .713 .92 r
.20566 .31247 .24502 .35563 .27553 .34993 .23649 .30533 Metetra
.612 .709 .914 r
.23649 .30533 .27553 .34993 .30639 .3436 .26766 .29766 Metetra
.622 .708 .907 r
.26766 .29766 .30639 .3436 .33761 .33638 .29918 .28925 Metetra
.633 .708 .9 r
.29918 .28925 .33761 .33638 .36918 .32804 .33104 .27992 Metetra
.644 .709 .894 r
.33104 .27992 .36918 .32804 .40108 .31842 .36324 .26955 Metetra
.656 .711 .888 r
.36324 .26955 .40108 .31842 .43331 .30742 .39576 .25804 Metetra
.668 .715 .883 r
.39576 .25804 .43331 .30742 .46583 .29497 .42859 .24536 Metetra
.679 .719 .88 r
.42859 .24536 .46583 .29497 .49862 .28112 .4617 .23153 Metetra
.689 .724 .877 r
.4617 .23153 .49862 .28112 .53166 .26597 .49508 .21663 Metetra
.697 .73 .876 r
.49508 .21663 .53166 .26597 .56492 .24966 .5287 .20078 Metetra
.705 .737 .876 r
.5287 .20078 .56492 .24966 .59837 .23241 .56254 .18416 Metetra
.71 .743 .878 r
.56254 .18416 .59837 .23241 .63202 .21449 .59661 .16697 Metetra
.713 .75 .88 r
.59661 .16697 .63202 .21449 .66586 .19616 .63089 .14942 Metetra
.622 .725 .92 r
.13429 .27638 .17516 .3193 .20566 .31247 .16516 .26779 Metetra
.625 .718 .914 r
.16516 .26779 .20566 .31247 .23649 .30533 .19635 .25896 Metetra
.629 .713 .907 r
.19635 .25896 .23649 .30533 .26766 .29766 .22786 .24972 Metetra
.635 .709 .9 r
.22786 .24972 .26766 .29766 .29918 .28925 .2597 .23993 Metetra
.642 .707 .894 r
.2597 .23993 .29918 .28925 .33104 .27992 .29187 .22946 Metetra
.65 .706 .888 r
.29187 .22946 .33104 .27992 .36324 .26955 .32437 .21823 Metetra
.658 .707 .884 r
.32437 .21823 .36324 .26955 .39576 .25804 .35719 .20618 Metetra
.666 .709 .88 r
.35719 .20618 .39576 .25804 .42859 .24536 .39031 .19327 Metetra
.673 .713 .878 r
.39031 .19327 .42859 .24536 .4617 .23153 .42373 .17952 Metetra
.68 .717 .877 r
.42373 .17952 .4617 .23153 .49508 .21663 .45743 .165 Metetra
.687 .723 .877 r
.45743 .165 .49508 .21663 .5287 .20078 .4914 .14977 Metetra
.692 .729 .879 r
.4914 .14977 .5287 .20078 .56254 .18416 .52562 .13397 Metetra
.696 .736 .882 r
.52562 .13397 .56254 .18416 .59661 .16697 .56009 .11773 Metetra
.699 .744 .886 r
.56009 .11773 .59661 .16697 .63089 .14942 .59481 .1012 Metetra
.644 .732 .913 r
.09217 .23214 .13429 .27638 .16516 .26779 .12347 .22161 Metetra
.645 .724 .906 r
.12347 .22161 .16516 .26779 .19635 .25896 .15505 .2109 Metetra
.647 .718 .9 r
.15505 .2109 .19635 .25896 .22786 .24972 .18693 .19993 Metetra
.649 .712 .894 r
.18693 .19993 .22786 .24972 .2597 .23993 .21912 .18862 Metetra
.652 .708 .888 r
.21912 .18862 .2597 .23993 .29187 .22946 .25162 .1769 Metetra
.655 .705 .884 r
.25162 .1769 .29187 .22946 .32437 .21823 .28443 .16474 Metetra
.659 .704 .88 r
.28443 .16474 .32437 .21823 .35719 .20618 .31755 .1521 Metetra
.663 .705 .878 r
.31755 .1521 .35719 .20618 .39031 .19327 .35097 .13897 Metetra
.667 .707 .877 r
.35097 .13897 .39031 .19327 .42373 .17952 .38469 .12534 Metetra
.671 .711 .878 r
.38469 .12534 .42373 .17952 .45743 .165 .4187 .11126 Metetra
.675 .716 .88 r
.4187 .11126 .45743 .165 .4914 .14977 .45299 .09677 Metetra
.678 .722 .883 r
.45299 .09677 .4914 .14977 .52562 .13397 .48757 .08191 Metetra
.681 .729 .887 r
.48757 .08191 .52562 .13397 .56009 .11773 .52242 .06677 Metetra
.683 .737 .892 r
.52242 .06677 .56009 .11773 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12347 .22161 .08051 .17394 Metetra
.665 .73 .898 r
.08051 .17394 .12347 .22161 .15505 .2109 .11254 .16124 Metetra
.664 .722 .893 r
.11254 .16124 .15505 .2109 .18693 .19993 .14483 .14843 Metetra
.663 .716 .887 r
.14483 .14843 .18693 .19993 .21912 .18862 .1774 .13551 Metetra
.662 .71 .883 r
.1774 .13551 .21912 .18862 .25162 .1769 .21025 .12249 Metetra
.661 .706 .88 r
.21025 .12249 .25162 .1769 .28443 .16474 .24339 .10934 Metetra
.661 .703 .878 r
.24339 .10934 .28443 .16474 .31755 .1521 .27681 .09609 Metetra
.661 .702 .878 r
.27681 .09609 .31755 .1521 .35097 .13897 .31052 .08272 Metetra
.661 .703 .878 r
.31052 .08272 .35097 .13897 .38469 .12534 .34452 .06923 Metetra
.661 .706 .88 r
.34452 .06923 .38469 .12534 .4187 .11126 .37882 .05563 Metetra
.662 .71 .883 r
.37882 .05563 .4187 .11126 .45299 .09677 .41342 .04191 Metetra
.663 .716 .887 r
.41342 .04191 .45299 .09677 .48757 .08191 .44833 .02806 Metetra
.664 .722 .893 r
.44833 .02806 .48757 .08191 .52242 .06677 .48355 .01409 Metetra
.665 .73 .898 r
.48355 .01409 .52242 .06677 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^^Go0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZj
i@?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^^D00ol0003oZ[[Uo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^^D00ol0003oZ[[UojZji@03ojZji@04o`000?nZ^^GoZ[[Uo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZji@04o`000?nZ^^GoZ[[Uo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY^>Co0000ojZji@09
ojZji@05o`000?nZ^^GoZ[[UojZjiOl00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojVhi?l0003oZKST00;oZKST
00?o0000ojZjiOnZ^^D01onZ^^D00ol0003oZ[[UojZji@02ojZji@03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY^>@00ol0003oZ[[UojZji@06ojZji@03o`000?nZ^^GoZ[[U00?oZ[[U00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVhi003o`000?nZ^^GoZ[[U00GoZ[[U00?o0000
ojZjiOnZ^^D00onZ^^D00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKST00?o0000ojZj
iOnZ^^D01OnZ^^D00ol0003oZ[[UojZji@04ojZji@03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY]n<00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^^GoZ[[U00CoZ[[U00?o0000ojZjiOnZ
^^D01OnZ^^D00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKOS00?o0000ojVh
i?nY^>@02_nY^>@00ol0003oZ[[UojZji@03ojZji@03o`000?nZ^^GoZ[[U00KoZ[[U00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY]n?o0000ojVgh`09ojVgh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojZjiOnZ^^D00_nZ^^D00ol0003oZ[[UojZji@06ojZji@03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY]N;o0000ojVghonY]n?o000000[oZKOS00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZ[[UojZji@02ojZji@03o`000?nZ^^GoZ[[U00OoZ[[U00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKGR00?o0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi005
o`000?nZ^^GoZ[[UojZjiOl000002_nZ^^D00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKGR
o`000?nY]N801OnY]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00[oZKST00Co0000
ojZjiOnZ^^Go00002_nZ^^D2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onY]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY
^>CoZKST00_oZKST00?o0000ojZjiOl000002?nZ^^D2o`000003ojjli?l0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
]N800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00[oZKST00?o0000ojZjiOl000001OnZ
^^D3o`0000Co[[cT00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVdh@03o`000?nY]>7o000000goZKGR
00?o0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi0;o00000onZ^^D2o`0000So[[cT
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o
0000ojVghonY]n<02_nY]n<00ol0003oZKSTojVhi00;ojVhi004o`000?nZ^^Go0000o`0000_o[[cT
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVdh@03o`000?nY]N;oZKGR00[oZKGR00?o
0000ojVghonY]n<02onY]n<00ol0003oZKSTojVhi00:ojVhi0;o00003On^_>@2o`0008oooooo0029
ooooo`Co000000?oZKCQo`000?nY]>402OnY]>400ol0003oZKGRojVehP0;ojVehP03o`000?nY]n?o
ZKOS00_oZKOS00?o0000ojVhi?nY^>@01onY^>@4o`0000ko[[cT00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY/n3o0000ojVdh@0<ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o0000
ojVghonY]n<02onY]n<00ol0003oZKSTojVhi004ojVhi0;o00000_n^^^<00ol0003o[[[So`00000>
ojjli003o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZK?P00?o0000ojVdhOnY]>402onY]>40
0ol0003oZKGRojVehP0:ojVehP03o`000?nY]n?oZKOS00_oZKOS00?o0000ojVhi?nY^>@00_nY^>@2
o`0000Co[[[S00Co0000ojjjhon^^^?o00003_n^_>@00ol0003oooooooooo`2;ooooo`00D?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Mooooo`?o000000?oZK?Po`000?nY/n001_nY
/n000ol0003oZKCQojVdh@0:ojVdh@03o`000?nY]N;oZKGR00_oZKGR00?o0000ojVghonY]n<02onY
]n<01?l0003oZKSTo`000?l00006ojjjh`05o`000?n^^^?o[[[Sojjjhol000003On^_>@2o`0008co
oooo001@ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Koooo
o`?o00001OnY/n000ol0003oZK?PojVch004ojVch003o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVe
h_nY]N802onY]N800ol0003oZKOSojVgh`0:ojVgh`;o00002?n^^^<01Ol0003o[[[Sojjjhon^^^?o
000000ko[[cT0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00006Oooool3o`000003ojVch?l0003oZK?P00coZK?P00?o0000ojVdhOnY]>402onY
]>400ol0003oZKGRojVehP0;ojVehP03o`000?nY]n?oZKOS00KoZKOS0ol000000on]^>;o0000ojjj
h`07ojjjh`03o`000?n^^^?o[[[S00;o[[[S00?o0000ojjli?n^_>@03?n^_>@00ol0003ooooooooo
o`29ooooo`00D?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005_oo
ool3o`0000;oZK?P00Co0000ojVch?nY/n3o00003OnY/n000ol0003oZKCQojVdh@0;ojVdh@03o`00
0?nY]N;oZKGR00[oZKGR00?o0000ojVghonY]n<00onY]n<3o`0000Go[KSR00?o0000ojjjhon^^^<0
1On^^^<00ol0003o[[[Sojjjh`03ojjjh`03o`000?n^_>Co[[cT00co[[cT00?o0000ooooooooool0
R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Cooooo
0ol00008ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVdhOnY]>402_nY]>400ol0003oZKGR
ojVehP0;ojVehP03o`000?nY]n?o000000;o00002On]^>800ol0003o[[[Sojjjh`04ojjjh`03o`00
0?n^^^?o[[[S00Co[[[S00?o0000ojjli?n^_>@02on^_>@2o`0008Wooooo001@ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY/n000ol0003oZK?P
ojVch00:ojVch003o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVeh_nY]N802_nY]N82o`0000co[KSR
00?o0000ojjjhon^^^<01?n^^^<00ol0003o[[[Sojjjh`04ojjjh`03o`000?n^_>Co[[cT00co[[cT
0_l00028ooooo`00Loooool3o`000003ojVch?l0003o000000_oZK?P00?o0000ojVch?nY/n002onY
/n000ol0003oZKCQojVdh@0;ojVdh@03o`000?nY]N;oZKGR00OoZKGR0_l000000on/]n7o0000ojfh
hP0<ojfhhP03o`000?n^^^?o[[[S00?o[[[S00?o0000ojjjhon^^^<01On^^^<00ol0003o[[cTojjl
i00<ojjli0;o0000Qoooool0073ooooo0ol00005ojVch003o`000?nY/n3oZK?P00[oZK?P00?o0000
ojVch?nY/n002onY/n000ol0003oZKCQojVdh@0:ojVdh@03o`000?nY]N;oZKGR00GoZKGR0_l00004
ojbgh@03o`000?n]^>;o[KSR00_o[KSR00?o0000ojjjhon^^^<00_n^^^<00ol0003o[[[Sojjjh`06
ojjjh`03o`000?n^_>Co[[cT00Wo[[cT0_l000000onb_^;o0000ooooo`26ooooo`00K_ooool3o`00
00SoZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00:ojVch003o`000?nY]>7oZKCQ
00_oZKCQ00?o0000ojVeh_nY]N800_nY]N82o`0000Oo[;OQ00?o0000ojfhh_n]^>802_n]^>800ol0
003o[[[Sojjjh`02ojjjh`03o`000?n^^^?o[[[S00Oo[[[S00?o0000ojjli?n^_>@01_n^_>@2o`00
00?o/[kR0_l00026ooooo`00<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00008oooool3o`0000;oZK?P00?o0000ojVch?nY/n001_nY/n000ol0003oZK?PojVch00;ojVc
h003o`000?nY/n3oZK?P00[oZK?P00?o0000ojVdhOnY]>402onY]>401?l0003oZKGRo`000?l0000:
ojbgh@03o`000?n]^>;o[KSR00[o[KSR00Go0000ojjjhon^^^?o[[[So`000009ojjjh`03o`000?n^
_>Co[[cT00Go[[cT00?o0000ok:nh_nb_^801?nb_^82o`0008Gooooo000cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`?o0000
00?oZKCQo`000?nY/n002onY/n000ol0003oZK?PojVch00;ojVch003o`000?nY/n3oZK?P00[oZK?P
00?o0000ojVdhOnY]>402_nY]>42o`0000co[;OQ00?o0000ojfhh_n]^>802on]^>801?l0003o[[[S
ojjjhol0000:ojjjh`03o`000?n^_>Co[[cT00;o[[cT0_l00008ok:nhP;o0000Q?ooool003?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01oooooo1?l00004ojVdh@03
o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00;ojVch003
o`000?nY]>7oZKCQ00KoZKCQ0ol000000on[]^3o0000ojbgh@0<ojbgh@03o`000?n]^>;o[KSR00_o
[KSR00?o0000ojjjhol000002on^^^<01?l0003o[[cTo`000?l0000;ok:nhP03o`000?oooooooooo
08;ooooo000cooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Koooo
o`?o00001?nY]>400ol0003oZKCQojVdh@02ojVdh@03o`000?nY/n3oZK?P00[oZK?P00?o0000ojVc
h?nY/n002_nY/n000ol0003oZK?PojVch00:ojVch003o`000?nY]>7oZKCQ00?oZKCQ0ol00005oj^f
h003o`000?n/]n7o[;OQ00_o[;OQ00?o0000ojfhh_n]^>802_n]^>800ol0003o[[[So`00000;ojjj
h`;o00003Onb_^82o`0008?ooooo000cooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`0Hooooo`?o00002onY]>400ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P
00_oZK?P00?o0000ojVch?nY/n002_nY/n000ol0003oZKCQo`000002o`0000WoZkKP00?o0000ojbg
hOn/]n402on/]n400ol0003o[KSRojfhhP0:ojfhhP;o00002On^^^<2o`000003ok:lhOl0003o/[kR
00go/[kR0_l00022ooooo`00<oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool05?ooool3o`000003ojVeh_l0003oZKCQ00coZKCQ00?o0000ojVch?nY/n002_nY/n000ol0
003oZK?PojVch00;ojVch003o`000?nY/n3oZK?P00WoZK?P0_l0000<oj^fh003o`000?n/]n7o[;OQ
00_o[;OQ00?o0000ojfhh_n]^>802on]^>800ol0003o[[[Sojjjh`04ojjjh`?o00001?nb_>400ol0
003o/[kRok:nhP0<ok:nhP;o0000POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41005?ooool3o`0000CoZKGR00?o0000ojVdhOnY]>402onY]>40
0ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n001_nY/n03
o`000003ojZdh?l0003oZkKP00coZkKP00?o0000ojbghOn/]n402on/]n400ol0003o[KSRojfhhP0:
ojfhhP03o`000?n^^^?o[[[S00;o[[[S0_l00008ok:lh@03o`000?nb_^;o/[kR00co/[kR00?o0000
ooooooooool0Ooooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`04Oooool3o`0000SoZKGR00?o0000ojVdhOnY]>402onY]>400ol0003oZK?PojVc
h009ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVch?nY/n000onY/n02o`0000GoZ[CP00?o
0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbgh@03o`000?n]^>;o[KSR00Wo[KSR0_l0
00000on^^^?o0000o`00000;ok:lh@03o`000?nb_^;o/[kR00_o/[kR0_l00020ooooo`00Eoooool3
o`000003ojVeh_l0003oZKGR00SoZKGR00?o0000ojVdhOnY]>402_nY]>400ol0003oZK?PojVch00:
ojVch003o`000?nY/n3oZK?P00_oZK?P00?o0000ojVch?l000000_l00008ojZdh003o`000?n[]^3o
ZkKP00[oZkKP00?o0000ojbghOn/]n403?n/]n400ol0003o[KSRojfhhP08ojfhhP?o00003Onb_>40
0ol0003o/[kRok:nhP0<ok:nhP;o0000Ooooool005Cooooo0ol000000onY]n?o0000ojVehP0;ojVe
hP03o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVch?nY/n002_nY/n000ol0003oZK?PojVch00:ojVc
h0;o00002onZ]>000ol0003oZkKPoj^fh00;oj^fh003o`000?n/]n7o[;OQ00_o[;OQ00?o0000ojfh
h_n]^>801_n]^>83o`000003ok6jhOl0003o/[cQ00go/[cQ00?o0000ok:nh_nb_^803?nb_^800ol0
003oooooooooo`1mooooo`00D_ooool3o`0000CoZKOS00?o0000ojVeh_nY]N802_nY]N800ol0003o
ZKCQojVdh@0;ojVdh@03o`000?nY/n3oZK?P00[oZK?P00?o0000ojVch?nY/n001_nY/n03o`000003
ojVdh?l0003oZ[CP00_oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbgh@03
o`000?n]^>;o[KSR00?o[KSR0_l00002ok6jh@04o`000?na^^7o/K[Qo`0000ko/[cQ00?o0000ok:n
h_nb_^803?nb_^800ol0003oooooooooo`1looooo`009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
02?ooooo1?l000000onY]n?o0000ojVgh`04ojVgh`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVd
hOnY]>402_nY]>400ol0003oZK?PojVch00:ojVch003o`000?nY/n3oZK?P00?oZK?P0ol00005ojVd
h003o`000?nZ]>3oZ[CP00[oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@0;ojbg
h@03o`000?n]^>;o000000;o00001?na^^401Ol0003o/K[Qok6jhOna^^7o000000ko/[cQ00?o0000
ok:nh_nb_^802onb_^82o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3
o`0000_oZKOS00?o0000ojVeh_nY]N802_nY]N800ol0003oZKCQojVdh@0:ojVdh@03o`000?nY/n3o
ZK?P00[oZK?P00?o0000ojVch?l000000_l00009ojVdh003o`000?nZ]>3oZ[CP00[oZ[CP00?o0000
oj^fh?n[]^002_n[]^000ol0003o[;OQojbgh@0;ojbgh@;o00001ona^^400ol0003o/K[Qok6jh@02
ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000ok:nh_nb_^803?nb_^82o`0007cooooo000Woooo
o`05oa0@4?ooooooooooooooool@41007_ooool5o`0000goZKOS00?o0000ojVeh_nY]N802_nY]N80
0ol0003oZKCQojVdh@0:ojVdh@03o`000?nY/n3oZK?P00WoZK?P0_l0000<ojVdh003o`000?nZ]>3o
Z[CP00[oZ[CP00?o0000oj^fh?n[]^002on[]^000ol0003o[;OQojbgh@08ojbgh@;o000000?o[kWP
o`000?na^^401_na^^400ol0003o/K[Qok6jh@03ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000
ok:nh_nb_^802Onb_^82o`000003okJohOl0003ooooo07_ooooo000Wooooo`05o`000?oooooooooo
ooooool000007?ooool3o`0000;oZKST00?o0000ojVhi?l000003?nY]n<00ol0003oZKGRojVehP0:
ojVehP03o`000?nY]>7oZKCQ00_oZKCQ00?o0000ojVch?nY/n001OnY/n03o`000003ojRdhOl0003o
ZKCP00coZKCP00?o0000ojZdh?nZ]>002_nZ]>000ol0003oZkKPoj^fh00;oj^fh003o`000?n/]n7o
[;OQ00Co[;OQ0ol00004ojnih003o`000?na^^7o/K[Q00Co/K[Q00?o0000ok6jhOna^^400ona^^40
0ol0003o/[cQok:lh@0<ok:lh@03o`000?nb_^;o/[kR00Ko/[kR0_l00004okJoh@03o`000?oooooo
oooo07Wooooo000Wooooo`05o`000?ooooooooooooooool000006Oooool4o`0000GoZKST00?o0000
ojVhi?l000003?nY]n<00ol0003oZKGRojVehP0:ojVehP03o`000?nY]>7oZKCQ00[oZKCQ00?o0000
ojVch?nY/n000onY/n02o`0000GoZ;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh00:
ojZdh003o`000?n[]^3oZkKP00[oZkKP00?o0000ojbghOn/]n400_n/]n42o`0000So[kWP00?o0000
ok6jhOna^^400ona^^400ol0003o/K[Qok6jh@04ok6jh@03o`000?nb_>7o/[cQ00_o/[cQ00?o0000
ok:nh_nb_^801Onb_^800ol0003o][oQokJoh@04okJoh@;o0000N_ooool002Oooooo00Go410@oooo
oooooooooooooa0@400Gooooo`?o00002onY^>@00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]N;o
ZKGR00[oZKGR00?o0000ojVdhOnY]>402_nY]>400ol0003oZK?Po`000002o`0000SoZ;CQ00?o0000
ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh009ojZdh003o`000?n[]^3oZkKP00_oZkKP00Co0000
ojbghOl0003o00002_n_^N000ol0003o/K[Qok6jh@03ok6jh@03o`000?na^^7o/K[Q00Go/K[Q00?o
0000ok:lhOnb_>402onb_>400ol0003o/[kRok:nhP02ok:nhP;o00002?nf_n42o`0007Wooooo000W
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool5o`000003ojVhi?l0003oZKST00[oZKST00?o
0000ojVghonY]n<02_nY]n<00ol0003oZKGRojVehP0:ojVehP03o`000?nY]>7oZKCQ00WoZKCQ0_l0
000<ojRdh@03o`000?nY]>3oZKCP00[oZKCP00?o0000ojZdh?nZ]>002_nZ]>000ol0003oZkKPoj^f
h00:oj^fh0;o00003On_^N000ol0003o/K[Qok6jh@02ok6jh@03o`000?na^^7o/K[Q00Ko/K[Q00?o
0000ok:lhOnb_>402onb_>401?l0003o/[kRo`000?l0000;okJoh@03o`000?oooooooooo07Oooooo
000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_ooool3o`0000CoZ[[U00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZKOSojVgh`0;ojVgh`03o`000?nY]N;oZKGR00WoZKGR00?o0000ojVdhOnY]>40
1_nY]>43o`000003ojNdh_l0003oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CP
ojZdh00:ojZdh003o`000?n[]^3oZkKP00OoZkKP0_l000000on^]n3o0000ojnih00=ojnih005o`00
0?na^^7o/K[Qok6jhOl000002Ona^^400ol0003o/[cQok:lh@0:ok:lh@;o00003_nf_n400ol0003o
ooooooooo`1fooooo`00>oooool5o`0000KoZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOS
ojVgh`0;ojVgh`03o`000?nY]N;oZKGR00WoZKGR00?o0000ojVdhOnY]>400onY]>42o`0000GoYkCR
00?o0000ojRdhOnX]>402_nX]>400ol0003oZKCPojVdh00;ojVdh003o`000?nZ]>3oZ[CP00[oZ[CP
00?o0000oj^fh?n[]^001?n[]^02o`0000Co[[OP00?o0000ojnih?n_^N002on_^N001Ol0003o/K[Q
ok6jhOna^^7o000000Wo/K[Q00?o0000ok:lhOnb_>402?nb_>42o`000003okFnh?l0003o][oQ00go
][oQ0_l0001gooooo`00>Oooool3o`0000_oZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOS
ojVgh`0:ojVgh`03o`000?nY]N;oZKGR00[oZKGR00?o0000ojVdhOl000000_l00008ojNdhP03o`00
0?nX]>7oZ;CQ00[oZ;CQ00?o0000ojVdh?nY]>002_nY]>000ol0003oZ[CPojZdh00:ojZdh003o`00
0?n[]^3oZkKP00;oZkKP0_l00007ojjgh003o`000?n_^N3o[kWP00_o[kWP00Co0000ok6jhOna^^7o
00002_na^^400ol0003o/[cQok:lh@05ok:lh@;o00001?ne_^000ol0003o][oQokJoh@0<okJoh@;o
0000M_ooool003Oooooo1?l0000=ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<0
2_nY]n<00ol0003oZKGRojVehP08ojVehP?o00002onW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`00
0?nY]>3oZKCP00[oZKCP00?o0000ojZdh?nZ]>002_nZ]>001?l0003oZkKPo`000?l0000:ojjgh003
o`000?n_^N3o[kWP00_o[kWP00?o0000ok6jhOl000002ona^^400ol0003o/[cQok:lh@02ok:lh@;o
00001one_^000ol0003o][oQokJoh@0<okJoh@03o`000?oooooooooo07Cooooo000dooooo`?o0000
00GoZ[cWo`000?nZ_>OoZ[cWo`00000=ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKGRojVehP04ojVehP?o00000_nV]N<00ol0003oYkCRojNdhP0:ojNdhP03
o`000?nX]>7oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>002_nY]>000ol0003oZ[CPojZdh009ojZdh0;o
00003?n^]n000ol0003o[kWPojnih00<ojnih0;o00003?na^^401?l0003o/[cQo`000?l0000:okFn
h003o`000?nf_n7o][oQ00co][oQ00?o0000ooooooooool0Loooool003;ooooo0ol00007ojZli`03
o`000?nZ^^GoZ[[U00_oZ[[U00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOSojVgh`0:ojVgh`03
o`000?nY]N;oZKGR00?o00001_nV]N<00ol0003oYkCRojNdhP0:ojNdhP03o`000?nX]>7oZ;CQ00[o
Z;CQ00?o0000ojVdh?nY]>002onY]>000ol0003oZ[CPojZdh005ojZdh0?o000000?o[;KPo`000?n^
]n003?n^]n000ol0003o[kWPojnih00;ojnih0;o00003?na^^42o`0000go]KkP00?o0000okJohOnf
_n402onf_n42o`0007Cooooo000aooooo`03o`000?nZ_>OoZ[cW00WoZ[cW00?o0000ojZjiOnZ^^D0
2onZ^^D00ol0003oZKSTojVhi009ojVhi003o`000?nY]n?oZKOS00[oZKOS0ol0000:ojJeh`03o`00
0?nW]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402_nX]>400ol0003oZKCPojVdh00:ojVdh003o`00
0?nZ]>3oZ[CP00?oZ[CP0_l00005ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o0000ojnih?n_^N00
2on_^N000ol0003o/K[Qok6jh@08ok6jh@;o000000?o];cPo`000?ne_^003?ne_^000ol0003o][oQ
okJoh@0<okJoh@03o`000?oooooooooo07;ooooo000aooooo`;o00002onZ_>L00ol0003oZ[[UojZj
i@0:ojZji@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<01_nY]n<3o`000003ojJfi?l0
003oY[GS00_oY[GS00?o0000ojNdh_nW]>802OnW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`000?nY
]>3oZKCP00[oZKCP00?o0000ojZdh?l000000_l00008ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o
0000ojnih?n_^N002_n_^N02o`0000Ko/K[Q0ol00004okBlh003o`000?ne_^3o]KkP00_o]KkP00?o
0000okJohOnf_n403?nf_n400ol0003oooooooooo`1aooooo`009Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo0_l0000<ojZli`03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojVhi?nY^>@02_nY
^>@00ol0003oZKOSojVgh`03ojVgh`;o00001OnV]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW
]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402onX]>400ol0003oZKCPojVdh009ojVdh0;o00003?n/
]^000ol0003o[[OPojjgh00:ojjgh003o`000?n_^N3o[kWP00[o[kWP0_l00004ok6jh@;o00002?nd
_>000ol0003o]KkPokFnh00;okFnh003o`000?nf_n7o][oQ00co][oQ00?o0000ooooooooool0L?oo
ool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03o`000?oooooo000000coZ[cW00?o
0000ojZjiOnZ^^D02_nZ^^D00ol0003oZKSTojVhi00:ojVhi003o`000?nY]n?o000000;o00002?nV
]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW]>;oYkCR00[oYkCR00?o0000ojRdhOnX]>402_nX
]>400ol0003oZKCPojVdh006ojVdh0?o000000?oZ[GQo`000?n/]^002on/]^000ol0003o[[OPojjg
h00;ojjgh003o`000?n_^N3o[kWP00Wo[kWP00Co0000ojnih?l0003o/K[Q0_l0000;okBlh003o`00
0?ne_^3o]KkP00_o]KkP00?o0000okJohOnf_n402onf_n42o`00077ooooo000Uooooo`05oa0@4?oo
ooooooooooooool@41001oooool01?l0003oooooooooool0000<ojZli`03o`000?nZ^^GoZ[[U00[o
Z[[U00?o0000ojVhi?nY^>@02?nY^>@3o`0000coY[KT00?o0000ojJehonV]N<02OnV]N<00ol0003o
YkCRojNdhP09ojNdhP03o`000?nX]>7oZ;CQ00_oZ;CQ00?o0000ojVdh?nY]>000onY]>02o`0000Go
Z[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh00;ojjgh003o`000?n_^N3o[kWP00So
[kWP00Co0000ojnih?l0003o00003Ond_>000ol0003o]KkPokFnh00;okFnh003o`000?nf_n7o][oQ
00Wo][oQ0_l000000oni`N3o0000ooooo`1`ooooo`009Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojZjiOnZ^^D02_nZ^^D00ol0
003oZKSTojVhi004ojVhi0?o00000_nU]nH00ol0003oY[KTojJfi00;ojJfi003o`000?nV]N?oY[GS
00WoY[GS00?o0000ojNdh_nW]>802OnW]>800ol0003oZ;CQojRdh@0;ojRdh@03o`000?nY]>3o0000
00;o00002?nZ]N400ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP00_o[[OP00?o0000ojni
h?n_^N001on_^N02o`000003ok:jh?l0003o];cP00go];cP00?o0000okFnh?ne_^002one_^000ol0
003o][oQokJoh@05okJoh@?o00001?ni`N000ol0003oooooooooo`1^ooooo`009Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oZ[cWojZli`0:ojZl
i`03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojVhi?nY^>@00ol00006ojFgiP03o`000?nV]^CoY[KT
00[oY[KT00?o0000ojJehonV]N<02OnV]N<00ol0003oYkCRojNdhP0:ojNdhP03o`000?nX]>7oZ;CQ
00[oZ;CQ0_l0000<ojZeh@03o`000?n/]^3o[;KP00[o[;KP00?o0000ojjgh?n^]n002_n^]n000ol0
003o[kWPojnih005ojnih0?o00000onb^^000ol0003o];cPokBlh00<okBlh003o`000?ne_^3o]KkP
00_o]KkP00?o0000okJohOnf_n400_nf_n42o`0000So^L7P00?o0000ooooooooool0KOooool002Go
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZl
ionZ_>L02_nZ_>L00ol0003oZ[[UojZji@09ojZji@?o00002_nU]nH00ol0003oY[KTojJfi00:ojJf
i003o`000?nV]N?oY[GS00WoY[GS00?o0000ojNdh_nW]>802_nW]>800ol0003oZ;CQojRdh@06ojRd
h@?o000000?oZ;CRo`000?nZ]N402onZ]N400ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP
00_o[[OP00?o0000ojnih?n_^N000_n_^N02o`0000;o/[[P00?o0000ok:jh?nb^^000_nb^^000ol0
003o];cPokBlh00<okBlh003o`000?ne_^3o]KkP00_o]KkP00Co0000okJohOl0003o00002_ni`N02
o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05
ooooo`03o`000?nZ_>OoZ[cW00[oZ[cW00?o0000ojZjiOnZ^^D01_nZ^^D2o`000003ojFiiol0003o
YKOV00_oYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJeh`09ojJeh`03o`000?nW]>;o
YkCR00WoYkCR00?o0000ojRdhOnX]>400onX]>43o`0000GoZ;CR00?o0000ojZehOnZ]N402_nZ]N40
0ol0003o[;KPojbfh00:ojbfh003o`000?n^]n3o[[OP00_o[[OP00Co0000ojnih?l0003o00001?nb
^^000ol0003o/[[Pok:jh003ok:jh003o`000?nd_>3o];cP00_o];cP00?o0000okFnh?ne_^002one
_^02o`0000go^L7P00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZ[[UojZj
i@02ojZji@?o00001?nU^NL00ol0003oYKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00[oY[KT00?o
0000ojJehonV]N<02OnV]N<00ol0003oYkCRojNdhP09ojNdhP03o`000?nX]>7o000000;o00002OnX
]>800ol0003oZ[GQojZeh@0:ojZeh@03o`000?n/]^3o[;KP00[o[;KP00?o0000ojjgh?n^]n002_n^
]n02o`0000Ko/[[P00?o0000ok:jh?nb^^001?nb^^000ol0003o];cPokBlh00;okBlh003o`000?ne
_^3o]KkP00So]KkP0_l000000onh_moo0000okW1h00=okW1h003o`000?oooooooooo06_ooooo000`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZlionZ_>L02_nZ_>L01?l0003oZ[[Uo`000?l0
0008ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJe
h`08ojJeh`03o`000?nW]>;oYkCR00SoYkCR0ol0000<ojRdhP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o
0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh007ojjgh0;o000000?o/;WPo`000?nb^^001Onb
^^000ol0003o/[[Pok:jh004ok:jh003o`000?nd_>3o];cP00co];cP00?o0000okFnh?ne_^001_ne
_^000ol0003o^;oOokRog`02okRog`03o`000?ni`N3o^L7P00co^L7P00?o0000ooooooooool0J_oo
ool0033ooooo00?o0000ooooooooool02?ooool00ol0003oZ[cWojZli`08ojZli`?o00002onU^NL0
0ol0003oYKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00[oY[KT00?o0000ojJehonV]N<02?nV]N<0
0ol0003oYkCRojNdhP04ojNdhP?o00000_nV]><00ol0003oZ;CRojRdhP0;ojRdhP03o`000?nZ]N7o
Z[GQ00[oZ[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh005ojjgh0;o00001?n`^N00
0ol0003o/[[Pok:jh003ok:jh003o`000?nb^^3o/[[P00Go/[[P00?o0000okBlh?nd_>002ond_>00
0ol0003o]KkPokFnh004okFnh0;o00001_nh_ml00ol0003o^L7PokW1h00;okW1h003o`000?oooooo
oooo06[ooooo000_ooooo`;o00002oooool00ol0003oZ[cWojZli`04ojZli`?o00000_nT^nT00ol0
003oYKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJfi?nV]^@02OnV]^@00ol0
003oY[GSojJeh`09ojJeh`03o`000?nW]>;oYkCR00?o00001_nV]><00ol0003oZ;CRojRdhP0;ojRd
hP03o`000?nZ]N7oZ[GQ00[oZ[GQ00?o0000ojbfh?n/]^002_n/]^000ol0003o[[OPojjgh002ojjg
h0;o00001on`^N000ol0003o/[[Pok:jh002ok:jh003o`000?nb^^3o/[[P00Ko/[[P00?o0000okBl
h?nd_>002ond_>001?l0003o]KkPokFnh?ne_^02o`0000Wo^;oO00?o0000okW1h?ni`N002oni`N00
0ol0003oooooooooo`1Yooooo`00<?ooool00ol0003oooooooooo`0:ooooo`03o`000?nZ_>OoZ[cW
00?o00001_nT^nT00ol0003oYKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00WoYKOV00?o0000ojJf
i?nV]^@02_nV]^@00ol0003oY[GSojJeh`08ojJeh`?o00002_nV]><00ol0003oZ;CRojRdhP0:ojRd
hP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o0000ojbfh?n/]^002_n/]^001?l0003o[[OPo`000?l0000:
ok2ih005o`000?nb^^3o/[[Pok:jh?l000002Onb^^000ol0003o];cPokBlh00;okBlh003o`000?ne
_^3o000000co^;oO00?o0000okW1h?ni`N002oni`N000ol0003oooooooooo`1Xooooo`00;oooool0
0ol0003oooooooooo`0<ooooo`;o00002_nT^nT00ol0003oYKWWojFii`0:ojFii`03o`000?nU]nKo
YKOV00WoYKOV00?o0000ojJfi?nV]^@02_nV]^@00ol0003oY[GSojJeh`04ojJeh`?o000000?oY;CT
o`000?nV]><02onV]><00ol0003oZ;CRojRdhP0:ojRdhP03o`000?nZ]N7oZ[GQ00_oZ[GQ00?o0000
ojbfh?n/]^002On/]^02o`0000co/;WP00Go0000ok:jh?nb^^3o/[[Po`00000:ok:jh003o`000?nd
_>3o];cP00[o];cP0_l0000=okRog`03o`000?ni`N3o^L7P00co^L7P00?o0000ooooooooool0Iooo
ool002oooooo00?o0000ooooooooool03Oooool00ol0003oY;_YojBkj@09ojBkj@03o`000?nU^NOo
YKWW00[oYKWW00?o0000ojFgi_nU]nH02OnU]nH00ol0003oY[KTojJfi00:ojJfi003o`000?nV]N?o
Y[GS00?o00001OnT]>@00ol0003oY[CSojJdh`0:ojJdh`03o`000?nX]>;oZ;CR00[oZ;CR00?o0000
ojZehOnZ]N402_nZ]N400ol0003o[;KPojbfh006ojbfh0?o000000?o[KSQo`000?n`^N003?n`^N00
1?l0003o/[[Pok:jh?l0000:ok:jh003o`000?nd_>3o];cP00So];cP0_l000000ong_]oo0000okRo
g`0=okRog`03o`000?ni`N3o^L7P00_o^L7P00?o0000ooooooooool0Ioooool002oooooo00?o0000
ooooooooool03_ooool00ol0003oY;_YojBkj@09ojBkj@03o`000?nU^NOoYKWW00WoYKWW00?o0000
ojFgi_nU]nH02_nU]nH00ol0003oY[KTojJfi008ojJfi0Co00002OnT]>@00ol0003oY[CSojJdh`09
ojJdh`03o`000?nX]>;oZ;CR00_oZ;CR00?o0000ojZehOnZ]N402_nZ]N400ol0003o[;KPojbfh003
ojbfh0;o00001On]^>400ol0003o/;WPok2ih00;ok2ih003o`000?nb^^3o000000_o/[[P00?o0000
okBlh?nd_>001Ond_>02o`0000Co]kkO00?o0000okRogonh_ml03?nh_ml00ol0003o^L7PokW1h00;
okW1h003o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ojBk
jOnT^nT02OnT^nT00ol0003oYKWWojFii`09ojFii`03o`000?nU]nKoYKOV00[oYKOV00?o0000ojJf
i?nV]^@01?nV]^@3o`0000;oX[GV00?o0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJdh`09ojJd
h`03o`000?nX]>;oZ;CR00[oZ;CR00?o0000ojZehOnZ]N402onZ]N400ol0003o[;KPo`000002o`00
00So[KSQ00?o0000ok2ih?n`^N002on`^N02o`0000co/[[P00?o0000okBlh?nd_>000_nd_>02o`00
00Oo]kkO00?o0000okRogonh_ml03?nh_ml00ol0003o^L7PokW1h00:okW1h0;o0000Ioooool002ko
oooo0ol0000Aooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojFiionU^NL02OnU^NL00ol0003o
YKOVojFgiP0:ojFgiP03o`000?nV]^CoY[KT00?o00001_nR]NH00ol0003oY;CTojBdi009ojBdi003
o`000?nV]>?oY[CS00WoY[CS00?o0000ojRdh_nX]>802_nX]>800ol0003oZ[GQojZeh@0:ojZeh@;o
00003?n]^>400ol0003o/;WPok2ih00:ok2ih0;o00003Onb^^001?l0003o];cPo`000?l0000:okNn
g`03o`000?nh_moo^;oO00_o^;oO00?o0000okW1h?ni`N002?ni`N02o`000003ok_2gol0003o0000
06Kooooo000_ooooo`03o`000?oooooooooo017ooooo00?o0000ojBkjOnT^nT02?nT^nT00ol0003o
YKWWojFii`0:ojFii`03o`000?nU]nKoYKOV00SoYKOV1?l0000:oj:eiP03o`000?nT]>CoY;CT00So
Y;CT00?o0000ojJdhonV]><02_nV]><00ol0003oZ;CRojRdhP0:ojRdhP03o`000?nZ]N7oZ[GQ00Ko
Z[GQ0ol000000on[]n;o0000ojfhh@0;ojfhh@03o`000?n`^N3o/;WP00_o/;WP00?o0000ok:jh?nb
^^002onb^^02o`0000go]kkO00?o0000okRogonh_ml02onh_ml00ol0003o^L7PokW1h005okW1h0;o
00001?nk`]l00ol0003oooooooooo`1Tooooo`00;oooool00ol0003oooooooooo`0Booooo`03o`00
0?nT^nWoY;_Y00SoY;_Y00?o0000ojFiionU^NL02_nU^NL00ol0003oYKOVojFgiP04ojFgiP?o0000
0_nQ]^P00ol0003oX[GVoj:eiP0:oj:eiP03o`000?nT]>CoY;CT00SoY;CT00?o0000ojJdhonV]><0
2_nV]><00ol0003oZ;CRojRdhP09ojRdhP03o`000?nZ]N7oZ[GQ00?oZ[GQ0ol00005oj^ghP03o`00
0?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N002_n`^N02o`0000[o/[[P0_l000000ond_>3o0000
okNng`0<okNng`03o`000?nh_moo^;oO00co^;oO00?o0000okW1h?ni`N000_ni`N02o`0000Oo^l;O
00?o0000ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oY;_YojBk
j@08ojBkj@03o`000?nU^NOoYKWW00[oYKWW00?o0000ojFgi_nU]nH00ol00006oj6fj003o`000?nR
]NKoX[GV00[oX[GV00?o0000ojBdi?nT]>@02?nT]>@00ol0003oY[CSojJdh`09ojJdh`03o`000?nX
]>;oZ;CR00[oZ;CR00?o0000ojZehOl000000_l00009oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o
0000ok2ih?n`^N002On`^N02o`0000Oo/[[P0ol00004okBlh003o`000?ng_]oo]kkO00_o]kkO00?o
0000okRogonh_ml03?nh_ml01?l0003o^L7Po`000?l0000:ok_2g`03o`000?oooooooooo06;ooooo
000_ooooo`03o`000?oooooooooo01?ooooo0_l0000:ojBkj@03o`000?nU^NOoYKWW00SoYKWW1?l0
000:oj6fj003o`000?nR]NKoX[GV00WoX[GV00?o0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJd
h`09ojJdh`03o`000?nX]>;oZ;CR00SoZ;CR0ol0000=oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o
0000ok2ih?n`^N002?n`^N000ol0003o/;WPo`000004ok:jh0;o00002?nd_>000ol0003o]kkOokNn
g`0;okNng`03o`000?nh_moo^;oO00_o^;oO0_l0000<ok_2g`;o0000Hoooool002kooooo00?o0000
ooooooooool05Oooool2o`0000[oY;_Y00?o0000ojFiionU^NL01?nU^NL3o`0000;oWkOY00?o0000
oj6fj?nQ]^P02_nQ]^P00ol0003oX[GVoj:eiP09oj:eiP03o`000?nT]>CoY;CT00WoY;CT00?o0000
ojJdhonV]><02OnV]><00ol0003oZ;CRojRdhP04ojRdhP?o00000_nW]^<00ol0003oZkORoj^ghP0;
oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N002?n`^N001Ol0003o/;WPok2ih?l0
003o/[[P00;o00002_nd_>000ol0003o]kkOokNng`0<okNng`03o`000?nh_moo^;oO00So^;oO0_l0
00000onj`Moo0000ok_2g`0<ok_2g`03o`000?oooooooooo067ooooo000^ooooo`?o00005_ooool2
o`0000[oY;_Y00?o0000ojFiionU^NL00ol00006oingj@03o`000?nQ]^SoXKKX00[oXKKX00?o0000
oj:ei_nR]NH02OnR]NH00ol0003oY;CTojBdi009ojBdi003o`000?nV]>?oY[CS00WoY[CS00?o0000
ojRdh_nX]>800ol00006ojNfh`03o`000?n[]n;oZkOR00_oZkOR00?o0000ojfhhOn]^>402_n]^>40
0ol0003o/;WPok2ih007ok2ih003o`000?n`^N3o/;WP00;o00003Ond_>000ol0003o]kkOokNng`0;
okNng`03o`000?nh_moo^;oO00Oo^;oO00?o0000ok[1gonj`Ml00_nj`Ml00ol0003o^l;Ook_2g`0;
ok_2g`03o`000?oooooooooo063ooooo000^ooooo`03o`000?oooooooooo01Oooooo0_l00008ojBk
j@Co00002_nO]nT00ol0003oXKKXoj6fj009oj6fj003o`000?nR]NKoX[GV00[oX[GV00?o0000ojBd
i?nT]>@02?nT]>@00ol0003oY[CSojJdh`09ojJdh`?o00002_nW]^<00ol0003oZkORoj^ghP0;oj^g
hP03o`000?n]^>7o[KSQ00[o[KSQ00?o0000ok2ih?n`^N001_n`^N03o`000003ok:khOl0003o];cP
00go];cP00?o0000okNngong_]l02ong_]l00ol0003o^;oOokRog`04okRog`;o00001_nj`Ml00ol0
003o^l;Ook_2g`0;ok_2g`03o`000?oooooooooo05oooooo000Booooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00007ooooo`03o`000?oooooooooo01Sooooo0_l00002ojBk
j@Go00000_nO^N/00ol0003oWkOYoingj@0:oingj@03o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:e
i_nR]NH02_nR]NH00ol0003oY;CTojBdi008ojBdi003o`000?nV]>?oY[CS00KoY[CS0_l000000onT
]NCo0000ojNfh`0;ojNfh`03o`000?n[]n;oZkOR00_oZkOR00?o0000ojfhhOn]^>402On]^>400ol0
003o/;WPok2ih005ok2ih0;o00001?nb^n400ol0003o];cPokBlh00;okBlh003o`000?ng_]oo]kkO
00co]kkO00Co0000okRogonh_moo^;oO0_l00009ok[1g`03o`000?nk`]oo^l;O00_o^l;O00?o0000
ooooooooool0G_ooool001;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool06Oooool3o`0000SoWkW[00?o
0000oingjOnO]nT02_nO]nT00ol0003oXKKXoj6fj009oj6fj003o`000?nR]NKoX[GV00WoX[GV00?o
0000ojBdi?nT]>@02OnT]>@00ol0003oY[CSojJdh`02ojJdh`?o00001?nT]N@00ol0003oYkKSojNf
h`0:ojNfh`03o`000?n[]n;oZkOR00[oZkOR00?o0000ojfhhOn]^>402_n]^>400ol0003o/;WPok2i
h002ok2ih0;o000000?o/[_Qo`000?nb^n401?nb^n400ol0003o];cPokBlh00;okBlh003o`000?ng
_]oo]kkO00co]kkO00?o0000okRogol000002onj`Ml00ol0003o^l;Ook_2g`0;ok_2g`03o`000?oo
oooooooo05kooooo000Booooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP08ooooo`03o`000?oooooooooo01[ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWkOYoing
j@0:oingj@03o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:ei_nR]NH02OnR]NH00ol0003oY;CTojBd
i009ojBdi004o`000?nV]>?o0000o`0000SoY;GT00?o0000ojNfhonW]^<02OnW]^<00ol0003oZkOR
oj^ghP0;oj^ghP03o`000?n]^>7o[KSQ00[o[KSQ00Co0000ok2ih?l0003o00000onb^n400ol0003o
/[_Qok:kh@04ok:kh@03o`000?nd_>3o];cP00_o];cP00?o0000okNngong_]l02ong_]l2o`0000go
^/7O00?o0000ok_2gonk`]l02onk`]l00ol0003oooooooooo`1Mooooo`004_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Kooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02_nO]nT00ol0003oXKKXoj6fj009oj6fj003
o`000?nR]NKoX[GV00WoX[GV00?o0000ojBdi?nT]>@01onT]>@3o`0000_oY;GT00?o0000ojNfhonW
]^<02OnW]^<00ol0003oZkORoj^ghP0;oj^ghP03o`000?n]^>7o[KSQ00Wo[KSQ0_l00005ok:kh@03
o`000?nb^n7o/[_Q00Co/[_Q00?o0000okBlh?nd_>002ond_>000ol0003o]kkOokNng`09okNng`;o
000000?o^L3Oo`000?nj`Ml03Onj`Ml00ol0003o^l;Ook_2g`0;ok_2g`03o`000?oooooooooo05co
oooo000Booooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`06ooooo`03
o`000?oooooooooo01cooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWkOYoingj@09oingj@03
o`000?nQ]^SoXKKX00WoXKKX00?o0000oj:ei_nR]NH02_nR]NH01?l0003oY;CTojBdi?nT]>@5o`00
00;oX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`09ojNfh`03o`000?n[]n;oZkOR
00[oZkOR00?o0000ojfhhOn]^>401_n]^>43o`000003ojnjh_l0003o/[_Q00Co/[_Q00?o0000ok:k
hOnb^n401Onb^n400ol0003o];cPokBlh00;okBlh003o`000?ng_]oo]kkO00Ko]kkO0_l00004okW0
g`03o`000?nj`Moo^/7O00_o^/7O00?o0000ok_2gonk`]l02onk`]l2o`0005gooooo000Booooo`05
oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o00007oooool00ol0
003oWkW[oinij`08oinij`03o`000?nO]nWoWkOY00WoWkOY00?o0000oj6fj?nQ]^P02OnQ]^P00ol0
003oX[GVoj:eiP08oj:eiPGo00002?nR]NH00ol0003oY;GTojBei009ojBei003o`000?nW]^?oYkKS
00[oYkKS00?o0000oj^gh_n[]n802_n[]n800ol0003o[KSQojfhh@03ojfhh@;o00001On_^^800ol0
003o/[_Qok:kh@02ok:kh@03o`000?nb^n7o/[_Q00Ko/[_Q00?o0000okBlh?nd_>002ond_>000ol0
003o]kkOokNng`04okNng`03o`000?ni`=oo^L3O00Go^L3O00?o0000ok[1gonj`Ml02onj`Ml00ol0
003o^l;Ook_2g`08ok_2g`;o000000?o_<?Oo`000?ooool0G?ooool001;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0O
ooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02OnO]nT00ol0003oXKKXoj6fj009
oj6fj003o`000?nR]NKoX[GV00CoX[GV0ol00002oinej003o`000?nR]NKoX[GV00WoX[GV00?o0000
ojBei?nT]N@02OnT]N@00ol0003oYkKSojNfh`0:ojNfh`03o`000?n[]n;oZkOR00[oZkOR00?o0000
ojfhhOl000000_l00008ojnjhP05o`000?nb^n7o/[_Qok:khOl000002Onb^n400ol0003o];cPokBl
h00:okBlh003o`000?ng_]oo]kkO00;o]kkO0_l00009okW0g`03o`000?nj`Moo^/7O00_o^/7O00?o
0000ok_2gonk`]l01_nk`]l00ol0003o_<?Ookc3g`02okc3g`03o`000?oooooooooo05[ooooo000B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo
00?o0000ooooooooool08?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO]nWoWkOY00WoWkOY
00?o0000oj6fj?nQ]^P02OnQ]^P00ol0003oX[GVoj:eiP03o`0000KoWkGX00?o0000oj:ei_nR]NH0
2OnR]NH00ol0003oY;GTojBei009ojBei003o`000?nW]^?oYkKS00WoYkKS00?o0000oj^gh_n[]n80
2_n[]n82o`0000co[k[R00Co0000ok:khOnb^n7o00002Onb^n400ol0003o];cPokBlh00;okBlh004
o`000?ng_]oo0000o`0000_o^L3O00?o0000ok[1gonj`Ml03?nj`Ml00ol0003o^l;Ook_2g`03ok_2
g`;o00001_nl`ml00ol0003oooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oingjOnO]nT02OnO]nT00ol0003oXKKXoj6fj007oj6fj0Co
00002_nO]NP00ol0003oX[GVoj:eiP09oj:eiP03o`000?nT]NCoY;GT00WoY;GT00?o0000ojNfhonW
]^<02OnW]^<00ol0003oZkORoj^ghP06oj^ghP?o000000?oZkSSo`000?n_^^803?n_^^800ol0003o
/[_Qo`00000:ok:kh@03o`000?nd_>3o];cP00[o];cP0_l0000>okW0g`03o`000?nj`Moo^/7O00_o
^/7O00Co0000ok_2gonk`]oo^l;O0_l00009okc3g`03o`000?oooooooooo05Sooooo000]ooooo`03
o`000?oooooooooo027ooooo00?o0000oinijonO^N/02OnO^N/00ol0003oWkOYoingj@09oingj@04
o`000?nQ]^SoXKKXoj6fj0Go00000_nL]NT00ol0003oWkGXoinej00:oinej003o`000?nR]NKoX[GV
00SoX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`09ojNfh`03o`000?n[]n;oZkOR
00?oZkOR0_l00005oj^hh`03o`000?n_^^;o[k[R00[o[k[R00?o0000ok:khOl000002onb^n400ol0
003o];cPokBlh007okBlh0;o000000?o][kPo`000?ni`=l03_ni`=l00ol0003o^/7Ook[1g`0;ok[1
g`03o`000?nk`]oo000000_o_<?O00?o0000ooooooooool0F?ooool002gooooo00?o0000oooooooo
ool08_ooool00ol0003oWkW[oinij`09oinij`03o`000?nO]nWoWkOY00SoWkOY1?l00008oibej@03
o`000?nO]NSoWkGX00[oWkGX00?o0000oj:ei_nR]NH02?nR]NH00ol0003oY;GTojBei009ojBei003
o`000?nW]^?oYkKS00[oYkKS00?o0000oj^gh_l000000_l00008oj^hh`03o`000?n_^^;o[k[R00[o
[k[R0_l0000;ok:kh@03o`000?nd_>3o];cP00Go];cP0_l00004okJnh003o`000?ni`=oo^L3O00co
^L3O00?o0000ok[1gonj`Ml02onj`Ml2o`0000go_<?O00?o0000ooooooooool0Eoooool002cooooo
0ol0000Tooooo`03o`000?nO^N_oWkW[00WoWkW[00?o0000oingjOnO]nT01?nO]nT3o`000003oiZf
jol0003oW;GY00[oW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GVoj:eiP09oj:eiP03o`00
0?nT]NCoY;GT00WoY;GT00?o0000ojNfhonW]^<02?nW]^<3o`0000coZkSS00?o0000ojnjh_n_^^80
2_n_^^800ol0003o/[_Qok:kh@0:ok:kh@03o`000?nd_>3o];cP00;o];cP0_l00007okJnh003o`00
0?ni`=oo^L3O00co^L3O00?o0000ok[1gonj`Ml02?nj`Ml2o`000003okc2gol0003o_<?O00go_<?O
00?o0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003oWkW[oini
j`09oinij`03o`000?nO]nWoWkOY00?o00001OnJ]^/00ol0003oW;GYoibej@09oibej@03o`000?nO
]NSoWkGX00WoWkGX00?o0000oj:ei_nR]NH02OnR]NH00ol0003oY;GTojBei009ojBei003o`000?nW
]^?oYkKS00CoYkKS0ol00002ojNgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojnjh_n_^^802_n_
^^82o`0000co/[_Q00Co0000okBlh?l0003o00002_nf_^000ol0003o^L3OokW0g`0<okW0g`03o`00
0?nj`Moo^/7O00Ko^/7O00?o0000okc2gonl`]l00_nl`]l00ol0003o_<?Ookc3g`0<okc3g`03o`00
0?oooooooooo05Gooooo000]ooooo`03o`000?oooooooooo02Gooooo00?o0000oinijonO^N/01onO
^N/4o`0000WoV[K[00?o0000oibejOnL]NT02OnL]NT00ol0003oWkGXoinej009oinej003o`000?nR
]NKoX[GV00SoX[GV00?o0000ojBei?nT]N@02_nT]N@00ol0003oYkKSojNfh`03o`0000KoYkOT00?o
0000oj^hhon[^><02_n[^><00ol0003o[k[RojnjhP09ojnjhP;o00003?nb^n42o`0000go][kP00?o
0000okW0goni`=l03?ni`=l00ol0003o^/7Ook[1g`03ok[1g`;o00001_nl`]l00ol0003o_<?Ookc3
g`0;okc3g`;o0000E_ooool002gooooo00?o0000ooooooooool09_ooool01?l0003oWkW[oinijonO
^N/5o`0000;oVKO]00?o0000oiZfjonJ]^/02OnJ]^/00ol0003oW;GYoibej@09oibej@03o`000?nO
]NSoWkGX00WoWkGX00?o0000oj:ei_nR]NH02?nR]NH00ol0003oY;GTojBei008ojBei0Co00002_nW
]n@00ol0003oZkSSoj^hh`0:oj^hh`03o`000?n_^^;o[k[R00So[k[R00?o0000ojnjh_l000002?nb
^n43o`000003ok>mhOl0003o][kP00go][kP00?o0000okW0goni`=l02oni`=l01?l0003o^/7Ook[1
gonj`Ml2o`0000Wo_<;O00?o0000okc3gonl`ml02onl`ml00ol0003oooooooooo`1Dooooo`00;?oo
ool00ol0003oooooooooo`0Xooooo`?o00002?nI]nd00ol0003oV[K[oiZfj`09oiZfj`03o`000?nL
]NWoW;GY00WoW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GVoj:eiP08oj:eiP03o`000?nT
]NCoY;GT00CoY;GT0ol00002oj>fiP03o`000?nW]nCoYkOT00[oYkOT00?o0000oj^hhon[^><02_n[
^><00ol0003o[k[RojnjhP07ojnjhP04o`000?n_^^;o[k[Ro`0000Go/[_Q0_l00005ok>mh@03o`00
0?nf_^3o][kP00co][kP00?o0000okW0goni`=l02oni`=l00ol0003o^/7Oo`00000;okc2g`03o`00
0?nl`moo_<?O00co_<?O00?o0000ooooooooool0Doooool002cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00WoV[K[00?o0000oibejOnL]NT02?nL
]NT00ol0003oWkGXoinej009oinej003o`000?nR]NKoX[GV00WoX[GV00?o0000ojBei?nT]N@00ol0
0006oj>fiP03o`000?nW]nCoYkOT00[oYkOT00?o0000oj^hhon[^><02On[^><00ol0003o[k[Rojnj
hP07ojnjhP06o`000?n_^^;o[k[Rojnjh_l0003o/[_Q0ol00008ok>mh@03o`000?nf_^3o][kP00_o
][kP00?o0000okW0goni`=l02oni`=l2o`0000go_<;O00?o0000okc3gonl`ml03?nl`ml00ol0003o
ooooooooo`1Booooo`00;?ooool2o`0002_ooooo00?o0000oiVgkOnI]nd02?nI]nd00ol0003oV[K[
oiZfj`09oiZfj`03o`000?nL]NWoW;GY00SoW;GY00?o0000oinej?nO]NP02OnO]NP00ol0003oX[GV
oj:eiP08oj:eiP?o00002_nS]^H00ol0003oYkOTojNgi009ojNgi003o`000?n[^>?oZkSS00[oZkSS
00?o0000ojnjh_n_^^801_n_^^801?l0003o[k[Rojnjh_n_^^82o`0000co/kgQ00?o0000okJnh?nf
_^002onf_^000ol0003o^L3OokW0g`08okW0g`;o000000?o^/;Po`000?nl`]l03Onl`]l00ol0003o
_<?Ookc3g`0;okc3g`;o0000Doooool002cooooo00?o0000ooooooooool0:oooool00ol0003oVKO]
oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00SoV[K[00?o0000oibejOnL]NT02OnL]NT00ol0003oWkGX
oinej009oinej003o`000?nR]NKoX[GV00CoX[GV0ol000000onO]NSo0000oj>fiP0;oj>fiP03o`00
0?nW]nCoYkOT00WoYkOT00?o0000oj^hhon[^><02_n[^><00ol0003o[k[RojnjhP05ojnjhP06o`00
0?n_^^;o0000o`000?n`_>?o00003Onc_N400ol0003o][kPokJnh00;okJnh003o`000?ni`=oo^L3O
00Go^L3O0_l00004ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3gonl`ml02?nl`ml2o`00
0003okg3gol0003ooooo05;ooooo000/ooooo`03o`000?oooooooooo02cooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`03o`000?nL]NWoW;GY00WoW;GY00?o0000oinej?nO
]NP02OnO]NP00ol0003oX[GVoj:eiP03o`0000GoWkGX00?o0000oj>fi_nS]^H02OnS]^H00ol0003o
YkOTojNgi00:ojNgi003o`000?n[^>?oZkSS00WoZkSS00?o0000ojnjh_n_^^801On_^^82o`0000Co
/;cS00?o0000ok>mhOnc_N402onc_N400ol0003o][kPokJnh00;okJnh003o`000?ni`=oo^L3O00;o
^L3O0_l00007ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3gonl`ml01_nl`ml00ol0003o
_L?Ookg3g`02okg3g`03o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooooooo02gooooo
00?o0000oiVgkOnI]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`03o`000?nL]NWoW;GY00WoW;GY
00?o0000oinej?nO]NP01onO]NP4o`0000WoWkGX00?o0000oj>fi_nS]^H02OnS]^H00ol0003oYkOT
ojNgi00:ojNgi003o`000?n[^>?oZkSS00WoZkSS00?o0000ojnjh_n_^^800_n_^^83o`0000Ko/;cS
00?o0000ok>mhOnc_N402onc_N400ol0003o][kPokJnh00;okJnh004o`000?ni`=oo0000o`0000[o
^/;P00?o0000okc2gonl`]l02onl`]l00ol0003o_<?Ookc3g`04okc3g`;o00001_nm`ml00ol0003o
ooooooooo`1?ooooo`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?nI]ngoVKO]00SoVKO]
00?o0000oiZfjonJ]^/02?nJ]^/00ol0003oW;GYoibej@09oibej@04o`000?nO]NSoWkGXoinej0Go
00000_nK]>T00ol0003oWkGXoinej009oinej003o`000?nS]^KoXkKV00WoXkKV00?o0000ojNgi?nW
]n@02OnW]n@00ol0003oZkSSoj^hh`0:oj^hh`04o`000?n_^^;o0000o`0000;o/;cS00?o0000ok2l
hon`_><01On`_><00ol0003o/kgQok>mh@0:ok>mh@03o`000?nf_^3o][kP00_o][kP0_l0000<ok[2
h003o`000?nl`]oo_<;O00co_<;O00Co0000okc3gonl`moo_<?O0_l00008okg3g`;o0000D?ooool0
02cooooo00?o0000ooooooooool0;oooool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[
00SoV[K[00?o0000oibejOnL]NT01onL]NT5o`0000SoVkCY00?o0000oinej?nO]NP02OnO]NP00ol0
003oXkKVoj>fiP09oj>fiP03o`000?nW]nCoYkOT00WoYkOT00?o0000oj^hhon[^><02?n[^><3o`00
00Co/;cS00?o0000ok2lhon`_><01_n`_><00ol0003o/kgQok>mh@0:ok>mh@03o`000?nf_^3o][kP
00So][kP0_l000000onh`N7o0000ok[2h00<ok[2h003o`000?nl`]oo_<;O00co_<;O00?o0000okc3
gol000002onm`ml00ol0003oooooooooo`1>ooooo`00;?ooool2o`00037ooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[K[oiZfj`08oiZfj`04o`000?nL]NWoW;GYoibej@Go00000_nH]>/00ol0
003oVkCYoi^dj@09oi^dj@03o`000?nO]NSoWkGX00WoWkGX00?o0000oj>fi_nS]^H02?nS]^H00ol0
003oYkOTojNgi00:ojNgi003o`000?n[^>?oZkSS00CoZkSS0ol00002ojbji003o`000?n`_>?o/;cS
00;o/;cS00?o0000ok2lhon`_><01_n`_><00ol0003o/kgQok>mh@0;ok>mh@03o`000?nf_^3o][kP
00Go][kP0_l00004okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o0000okc2gonl`]l02onl`]l2o`00
00go_L?O00?o0000ooooooooool0COooool002_ooooo00?o0000ooooooooool0<_ooool00ol0003o
VKO]oiVgk@08oiVgk@03o`000?nJ]^_oV[K[00KoV[K[1Ol00008oiRdj`03o`000?nK]>WoVkCY00Wo
VkCY00?o0000oinej?nO]NP02OnO]NP00ol0003oXkKVoj>fiP08oj>fiP03o`000?nW]nCoYkOT00[o
YkOT00?o0000oj^hhon[^><00ol00006ojbji005o`000?n`_>?o/;cSok2lhol000002On`_><00ol0
003o/kgQok>mh@0;ok>mh@03o`000?nf_^3o][kP00;o][kP0_l00007okS1h@03o`000?nj`^3o^/;P
00_o^/;P00?o0000okc2gonl`]l02?nl`]l2o`000003okc3gol0003o_L?O00go_L?O00?o0000oooo
ooooool0C?ooool002_ooooo00?o0000ooooooooool0<oooool00ol0003oVKO]oiVgk@08oiVgk@03
o`000?nJ]^_oV[K[00Go00000_nF]>d00ol0003oV;C[oiRdj`09oiRdj`03o`000?nK]>WoVkCY00Wo
VkCY00?o0000oinej?nO]NP02?nO]NP00ol0003oXkKVoj>fiP09oj>fiP03o`000?nW]nCoYkOT00Wo
YkOT0ol0000:ojbji004o`000?n`_>?o/;cSo`0000[o/;cS00?o0000ok>mhOnc_N402onc_N401?l0
003o][kPo`000?l0000:okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o0000okc2gonl`]l01_nl`]l0
0ol0003o_<?Ookc3g`02okc3g`03o`000?nm`moo_L?O00_o_L?O0_l0001=ooooo`004?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`0dooooo`03o`000?nI]ngoVKO]00KoVKO]1?l00008oiJdk@03o`000?nH]>_o
V;C[00WoV;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej009oinej003o`000?nS]^Ko
XkKV00SoXkKV00?o0000ojNgi?nW]n@01_nW]n@3o`000003ojNii_l0003o[;[T00_o[;[T00?o0000
ok2lhol000002on`_><00ol0003o/kgQok>mh@0:ok>mh@;o00003?nh`N400ol0003o^/;Pok[2h00;
ok[2h003o`000?nl`]oo_<;O00Co_<;O0_l00006okc3g`03o`000?nm`moo_L?O00_o_L?O0_l0001<
ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=Oooool00ol0003oVKO]oiVgk@05o`0000;oU;G^00?o0000
oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`09oiRdj`03o`000?nK]>WoVkCY00SoVkCY00?o0000
oinej?nO]NP02OnO]NP00ol0003oXkKVoj>fiP08oj>fiP03o`000?nW]nCoYkOT00?oYkOT0_l00005
ojNiiP03o`000?n/^^Co[;[T00[o[;[T0_l0000;ok2lh`03o`000?nc_N7o/kgQ00So/kgQ0_l00000
0ond_n;o0000okS1h@0<okS1h@03o`000?nj`^3o^/;P00_o^/;P00Co0000okc2gonl`]oo_<;O0_l0
0009okc3g`03o`000?nm`moo_L?O00_o_L?O00?o0000ooooooooool0B_ooool0013ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`0fooooo`;o00002?nD
]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`000?nH]>_oV;C[00WoV;C[00?o0000oi^djOnK]>T02?nK
]>T00ol0003oWkGXoinej009oinej003o`000?nS]^KoXkKV00SoXkKV00?o0000ojNgi?l000000_l0
0008ojNiiP03o`000?n/^^Co[;[T00[o[;[T00?o0000ok2lhon`_><02_n`_><00ol0003o/kgQok>m
h@05ok>mh@;o00001?nd_n800ol0003o^<7QokS1h@0;okS1h@03o`000?nj`^3o^/;P00_o^/;P00?o
0000okc2gol000002onl`ml00ol0003o_L?Ookg3g`0<okg3g`03o`000?oooooooooo04Wooooo000@
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo03Oooooo00?o0000oiBek_nD]Nh01onD]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`00
0?nH]>_oV;C[00WoV;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej009oinej003o`00
0?nS]^KoXkKV00KoXkKV0ol0000<ojNiiP03o`000?n/^^Co[;[T00Wo[;[T0_l0000<ok2lh`03o`00
0?nc_N7o/kgQ00;o/kgQ0_l00007okBohP03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ok[2h?nj`^00
2_nj`^02o`0000go_<?O00?o0000okg3gonm`ml02onm`ml2o`0004[ooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03So
oooo00?o0000oiBek_nD]Nh01onD]Nh00ol0003oU[C]oiJdk@08oiJdk@03o`000?nH]>_oV;C[00So
V;C[00?o0000oi^djOnK]>T02?nK]>T00ol0003oWkGXoinej00:oinej003o`000?nS]^KoXkKV00Go
00000_nR^>P00ol0003oYkWVojNiiP0;ojNiiP03o`000?n/^^Co[;[T00So[;[T0_l0000=ok2lh`04
o`000?nc_N7o0000o`0000[o];oR00?o0000okS1hOnh`N402onh`N400ol0003o^/;Pok[2h007ok[2
h0;o000000?o^l?Qo`000?nl`ml03Onl`ml00ol0003o_L?Ookg3g`0;okg3g`;o0000BOooool0013o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo0_l0000koooo
o`03o`000?nD]NkoU;G^00OoU;G^00?o0000oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`08oiRd
j`03o`000?nK]>WoVkCY00SoVkCY00?o0000oinej?nO]NP02?nO]NP4o`0000SoX[SX00?o0000ojNi
i_nW^NH02_nW^NH00ol0003o[;[Tojbji008ojbji003o`000?n/^^Co000000co/;cS0_l0000<okBo
hP03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ok[2h?nj`^001Onj`^02o`0000Co^l?Q00?o0000okc3
gonl`ml03?nl`ml00ol0003o_L?Ookg3g`08okg3g`;o000000?o_LCOo`000?ooool0B?ooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool0>_ooool00ol0003oU;G^oiBekP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000oiRd
jonH]>/02?nH]>/00ol0003oVkCYoi^dj@08oi^dj@03o`000?nO]NSoWkGX00CoWkGX0ol00002oiff
j@03o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02_nW^NH00ol0003o[;[Tojbji007ojbj
i004o`000?n/^^Co[;[To`0000So/;cS0ol000000on`_^Co0000okBohP0<okBohP03o`000?nh`N7o
^<7Q00_o^<7Q00?o0000ok[2h?nj`^000_nj`^02o`0000Oo^l?Q00?o0000okc3gonl`ml03?nl`ml0
0ol0003o_L?Ookg3g`06okg3g`03o`000?nma=oo_LCO00;o_LCO00?o0000ooooooooool0A_ooool0
013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000
ooooooooool0??ooool00ol0003oU;G^oiBekP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000
oiRdjonH]>/02?nH]>/00ol0003oVkCYoi^dj@08oi^dj@03o`000?nO]NSoWkGX00?o00001_nM]^T0
0ol0003oX[SXoj:hj008oj:hj003o`000?nW^NKoYkWV00[oYkWV00?o0000ojbji?n/^^@01_n/^^@0
1Ol0003o[;[Tojbji?n/^^Co000000Go/;cS0_l00005ok2ni003o`000?nd_n;o];oR00_o];oR00?o
0000okS1hOnh`N402onh`N401?l0003o^/;Po`000?l0000:ok_3h@03o`000?nl`moo_<?O00_o_<?O
00?o0000okg3gonm`ml01?nm`ml2o`0000Go_LCO0_l00017ooooo`00:_ooool00ol0003ooooooooo
o`0mooooo`03o`000?nD]NkoU;G^00OoU;G^00?o0000oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRd
j`08oiRdj`03o`000?nK]>WoVkCY00KoVkCY1?l0000:oiffj@03o`000?nR^>SoX[SX00SoX[SX00?o
0000ojNii_nW^NH02_nW^NH00ol0003o[;[Tojbji005ojbji003o`000?n/^^Co[;[T00;o[;[T00?o
0000ok2lhol000000_l00008ok2ni003o`000?nd_n;o];oR00_o];oR00?o0000okS1hOnh`N402_nh
`N42o`0000go^l?Q00?o0000okc3gonl`ml02onl`ml01?l0003o_L?Ookg3gonm`ml2o`0000So_LCO
00?o0000ooooooooool0AOooool002[ooooo00?o0000ooooooooool0?_ooool00ol0003oU;G^oiBe
kP07oiBekP03o`000?nF]>goU[C]00SoU[C]00?o0000oiRdjonH]>/02?nH]>/00ol0003oVkCYoi^d
j@05o`0000;oVKG[00?o0000oiffjOnM]^T02_nM]^T00ol0003oX[SXoj:hj008oj:hj003o`000?nW
^NKoYkWV00WoYkWV00?o0000ojbji?n/^^@01On/^^@00ol0003o[;[Tojbji002ojbji0;o00003?n`
_^@00ol0003o];oRokBohP0;okBohP03o`000?nh`N7o^<7Q00Oo^<7Q0_l000000onh`n;o0000ok_3
h@0=ok_3h@03o`000?nl`moo_<?O00_o_<?O00?o0000okg3gol000002onma=l00ol0003ooooooooo
o`14ooooo`00:_ooool00ol0003oooooooooo`0oooooo`03o`000?nD]NkoU;G^00OoU;G^00?o0000
oiJdkOnF]>d02?nF]>d00ol0003oV;C[oiRdj`03oiRdj`Oo00002?nI]N/00ol0003oWKKYoiffj@0:
oiffj@03o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02OnW^NH00ol0003o[;[Tojbji004
ojbji003o`000?n/^^Co000000;o000000?o[;gVo`000?n`_^@02on`_^@00ol0003o];oRokBohP0;
okBohP03o`000?nh`N7o^<7Q00Go^<7Q0_l00004okS3hP03o`000?nk`n7o^l?Q00_o^l?Q00?o0000
okc3gonl`ml02onl`ml2o`0000go_LCO00?o0000ooooooooool0@oooool002Wooooo0ol00010oooo
o`;o00002OnD]Nh00ol0003oU[C]oiJdk@06oiJdk@Oo00001OnE]>d00ol0003oVKG[oiVej`08oiVe
j`03o`000?nM]^WoWKKY00WoWKKY00?o0000oj:hj?nR^>P02?nR^>P00ol0003oYkWVojNiiP0:ojNi
iP03o`000?n/^^Co[;[T00?o[;[T0_l00005ojbmiP03o`000?n`_^Co/;kT00[o/;kT00?o0000okBo
h_nd_n802ond_n800ol0003o^<7QokS1h@02okS1h@;o00001onh`n800ol0003o^l?Qok_3h@0;ok_3
h@03o`000?nl`moo_<?O00So_<?O0_l000000onla>3o0000okg4g`0<okg4g`;o0000A?ooool002[o
oooo00?o0000ooooooooool0@?ooool2o`0000WoU;G^00?o0000oiJdkOnF]>d01Ol00002oi:dkP03
o`000?nE]>goUKC]00SoUKC]00?o0000oiVejonI]N/02?nI]N/00ol0003oWKKYoiffj@09oiffj@03
o`000?nR^>SoX[SX00SoX[SX00?o0000ojNii_nW^NH02_nW^NH00ol0003o[;[To`000003o`0000Oo
[;gV00?o0000ok2ni?n`_^@02_n`_^@00ol0003o];oRokBohP0;okBohP04o`000?nh`N7o0000o`00
00[o^<?R00?o0000ok_3hOnk`n402onk`n400ol0003o_<?Ookc3g`05okc3g`;o00001?nla>000ol0
003o_LCOokg4g`0;okg4g`03o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooooooo047o
oooo0_l00005oiBekPKo00002?nB]>h00ol0003oUKC]oiFdk@08oiFdk@03o`000?nI]N_oVKG[00So
VKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SXoj:hj008oj:hj003o`000?nW^NKoYkWV00So
YkWV0ol00003ojbmiP03o`000?n/_NKo[;gV00Ko[;gV00?o0000ok2ni?n`_^@02_n`_^@00ol0003o
];oRokBohP0:okBohP;o00003Onh`n800ol0003o^l?Qok_3h@0;ok_3h@03o`000?nl`moo_<?O00;o
_<?O0_l00007okc4h003o`000?nma=oo_LCO00_o_LCO00?o0000ooooooooool0@Oooool002[ooooo
00?o0000ooooooooool0@_ooool6o`0000CoT;C_00?o0000oi:dk_nB]>h02?nB]>h00ol0003oUKC]
oiFdk@08oiFdk@03o`000?nI]N_oVKG[00SoVKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SX
oj:hj008oj:hj003o`000?nW^NKoYkWV00CoYkWV0ol00002ojNkj005o`000?n/_NKo[;gVojbmi_l0
00002On/_NH00ol0003o/;kTok2ni00:ok2ni003o`000?nd_n;o];oR00Oo];oR0_l000000one`^Co
0000okS3hP0=okS3hP03o`000?nk`n7o^l?Q00_o^l?Q00Co0000okc3gol0003o00002_nla>000ol0
003o_LCOokg4g`0;okg4g`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Co
oooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:dkP08oi:dkP03o`000?nE]>goUKC]00So
UKC]00?o0000oiVejonI]N/02?nI]N/00ol0003oWKKYoiffj@08oiffj@03o`000?nR^>SoX[SX00Wo
X[SX00?o0000ojNii_nW^NH00ol00006ojNkj004o`000?n/_NKo[;gVo`0000[o[;gV00?o0000ok2n
i?n`_^@02On`_^@00ol0003o];oRokBohP05okBohP;o00001?ne`^@00ol0003o^<?RokS3hP0;okS3
hP03o`000?nk`n7o^l?Q00_o^l?Q0_l0000<okc4h003o`000?nma=oo_LCO00_o_LCO00?o0000oooo
ooooool0@?ooool002Wooooo00?o0000ooooooooool0AOooool00ol0003oT;C_oi2dk`07oi2dk`03
o`000?nB]>koT[C^00SoT[C^00?o0000oiFdkOnE]>d02?nE]>d00ol0003oVKG[oiVej`07oiVej`03
o`000?nM]^WoWKKY00WoWKKY00?o0000oj:hj?nR^>P02?nR^>P3o`0000[oYk_X00?o0000ojbmi_l0
00002on/_NH00ol0003o/;kTok2ni009ok2ni003o`000?nd_n;o];oR00;o];oR0_l00007okG2i003
o`000?nh`n;o^<?R00_o^<?R00?o0000ok_3hOnk`n402?nk`n42o`000003ok_4h_l0003o_<CP00co
_<CP00?o0000okg4gonma=l02onma=l00ol0003oooooooooo`0oooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h02?nB]>h00ol0003oUKC]
oiFdk@08oiFdk@03o`000?nI]N_oVKG[00OoVKG[00?o0000oiffjOnM]^T02OnM]^T00ol0003oX[SX
oj:hj004oj:hj0?o000000?oX[WYo`000?nW^nP02onW^nP2o`0000_o[;gV00?o0000ok2ni?n`_^@0
2_n`_^@01?l0003o];oRo`000?l0000:okG2i003o`000?nh`n;o^<?R00_o^<?R00?o0000ok_3hOnk
`n401Onk`n42o`0000Co^lCR00?o0000okc4h?nla>002onla>000ol0003o_LCOokg4g`0:okg4g`;o
0000@?ooool002Wooooo0_l00018ooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h0
2?nB]>h00ol0003oUKC]oiFdk@07oiFdk@03o`000?nI]N_oVKG[00SoVKG[00?o0000oiffjOnM]^T0
2OnM]^T00ol0003oX[SXoj:hj003o`0000GoX[WY00?o0000ojNkj?nW^nP02_nW^nP00ol0003o[;gV
ojbmiP0:ojbmiP03o`000?n`_^Co/;kT00Wo/;kT0_l0000=okG2i003o`000?nh`n;o^<?R00_o^<?R
00?o0000ok_3hOnk`n400_nk`n42o`0000Oo^lCR00?o0000okc4h?nla>002onla>000ol0003o_LCO
okg4g`07okg4g`;o000000?o_<CQo`000?l00000?oooool002Wooooo00?o0000ooooooooool0B?oo
ool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nB]>koT[C^00OoT[C^00?o0000oiFdkOnE]>d02?nE
]>d00ol0003oVKG[oiVej`08oiVej`03o`000?nM]^WoWKKY00OoWKKY1?l00009oj:ij@03o`000?nW
^nSoYk_X00WoYk_X0_l0000<ojbmiP03o`000?n`_^Co/;kT00Ko/;kT0_l000000ona`NKo0000okG2
i00=okG2i003o`000?nh`n;o^<?R00_o^<?R00Co0000ok_3hOl0003o00002_nka>800ol0003o_<CP
okc4h00:okc4h003o`000?nma=oo_LCO00Go_LCO0_l00004okc4h@03o`000?oooooooooo03gooooo
000Yooooo`03o`000?oooooooooo04Wooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:d
kP07oi:dkP03o`000?nE]>goUKC]00SoUKC]00?o0000oiVejonI]N/02?nI]N/01?l0003oWKKYoiff
jOnM]^T5o`0000;oW;O[00?o0000oj:ijOnR^NT02OnR^NT00ol0003oYk_XojNkj008ojNkj003o`00
0?nW^nSo000000co[;gV00?o0000ok2ni?n`_^@00_n`_^@3o`0000Co/L7V00?o0000okG2i?ne`^@0
2one`^@00ol0003o^<?RokS3hP0;okS3hP;o00003?nka>800ol0003o_<CPokc4h00;okc4h003o`00
0?nma=oo_LCO00;o_LCO0_l00007okc4h@03o`000?oooooooooo03cooooo000Yooooo`03o`000?oo
oooooooo04[ooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^oi:dkP07oi:dkP03o`000?nE
]>goUKC]00SoUKC]00?o0000oiVejonI]N/01_nI]N/5o`0000SoW;O[00?o0000oj:ijOnR^NT02OnR
^NT00ol0003oYk_XojNkj007ojNkj003o`000?nW^nSo000000go[;gV00Co0000ok2ni?l0003o0000
2?na`NH00ol0003o]L;TokG2i00;okG2i003o`000?nh`n;o^<?R00So^<?R0_l000000onha>?o0000
ok_4hP0<ok_4hP03o`000?nla>3o_<CP00_o_<CP00Co0000okg4gol0003o00002_nla>400ol0003o
ooooooooo`0kooooo`00:Oooool00ol0003oooooooooo`1;ooooo`03o`000?n@]>ooT;C_00OoT;C_
00?o0000oi:dk_nB]>h01onB]>h00ol0003oUKC]oiFdk@08oiFdk@03o`000?nI]N_oVKG[00Go0000
0_nG]^d00ol0003oW;O[oibgj`09oibgj`03o`000?nR^NWoX[WY00WoX[WY00?o0000ojNkj?nW^nP0
1_nW^nP01?l0003oYk_XojNkj?l0000<ojbmiP;o00002ona`NH00ol0003o]L;TokG2i00;okG2i003
o`000?nh`n;o^<?R00Go^<?R0_l00004okS4h`03o`000?nka>;o^lCR00_o^lCR00?o0000okc4h?nl
a>002_nla>02o`0000co_<CQ0_l0000looooo`00:Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?n@]>ooT;C_00OoT;C_00?o0000oi:dk_nB]>h01onB]>h00ol0003oUKC]oiFdk@03oiFdk@Oo0000
2?nG]^d00ol0003oW;O[oibgj`09oibgj`03o`000?nR^NWoX[WY00WoX[WY00?o0000ojNkj?nW^nP0
1OnW^nP01Ol0003oYk_XojNkj?nW^nSo000000So[;gV0ol000000on/_nOo0000ok71iP0;ok71iP03
o`000?ne`^Co]L;T00_o]L;T00?o0000okS3h_nh`n800_nh`n82o`0000Oo^<CS00?o0000ok_4h_nk
a>802onka>800ol0003o_<CPokc4h007okc4h0;o000000?o^lGRo`000?nla>403?nla>400ol0003o
ooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oT[C^
oi:dkP03oi:dkPWo00001OnC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[
00?o0000oj:ijOnR^NT02?nR^NT00ol0003oYk_XojNkj005ojNkj003o`000?nW^nSoYk_X00;oYk_X
00?o0000ojbmi_n/_NH00on/_NH2o`0000Go[;oW00?o0000ok71i_na`NH02_na`NH00ol0003o]L;T
okG2i00;okG2i004o`000?nh`n;o0000o`0000[o^<CS00?o0000ok_4h_nka>802_nka>800ol0003o
_<CPokc4h005okc4h0;o00001?nkaN800ol0003o_<CQokc4h@0;okc4h@03o`000?oooooooooo03Wo
oooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000oi2dkon@]>l00on@]>l9o`0000GoSk?_
00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[
00?o0000oj:ijOnR^NT02?nR^NT00ol0003oYk_XojNkj004ojNkj003o`000?nW^nSoYk_X00?oYk_X
00?o0000ojbmi_l000000_l00008ojboi`03o`000?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@0
2_ne`^@2o`0000go^<CS00?o0000ok_4h_nka>802_nka>800ol0003o_<CPokc4h002okc4h0;o0000
1onkaN800ol0003o_<CQokc4h@0;okc4h@03o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03
o`000?oooooooooo053ooooo1Ol00004ohjck`03o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC
]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`000?nL]n_oW;O[00WoW;O[00?o0000oj:ijOnR
^NT02?nR^NT00ol0003oYk_XojNkj003ojNkj003o`000?nW^nSoYk_X00;oYk_X0ol0000<ojboi`03
o`000?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@01one`^@2o`000003okG4iOl0003o^<CS00go
^<CS00?o0000ok_4h_nka>802_nka>801?l0003o_<CPo`000?l0000:ok_5hP03o`000?nla>7o_<CQ
00[o_<CQ0_l0000iooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1@ooooo`03o`000?n>/noo
S[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003oTkC^oi>dkP07oi>dkP03o`000?nG]^go
UkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0003oX[WYoj:ij@08oj:ij@04o`000?nW^nSo
Yk_XojNkj0;o000000CoYk_Xo`000?l0003o00000_nW_NT00ol0003o[;oWojboi`0;ojboi`03o`00
0?na`NKo/L7V00[o/L7V00?o0000okG2i?ne`^@01?ne`^@2o`0000Co]LCU00?o0000okS4honha><0
2onha><00ol0003o^lCRok_4hP0:ok_4hP;o00003?nkaN800ol0003o_<CQokc4h@0;okc4h@03o`00
0?oooooooooo03Oooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0DOooool00ol0003oS[?_ohjck`07ohjck`03
o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03
o`000?nL]n_oW;O[00WoW;O[00?o0000oj:ijOnR^NT02?nR^NT6o`0000KoYkgY00?o0000ojboion/
_nL02on/_nL00ol0003o/L7Vok71iP0:ok71iP03o`000?ne`^Co]L;T00;o]L;T00?o0000okG4iOne
a>D01Onea>D00ol0003o^<CSokS4h`0;okS4h`03o`000?nka>;o^lCR00Oo^lCR0_l000000onjaN?o
0000ok_5hP0<ok_5hP03o`000?nla>7o_<CQ00_o_<CQ00?o0000ooooooooool0=_ooool000cooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0
003oooooooooo`1Booooo`03o`000?n>/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0
003oTkC^oi>dkP07oi>dkP03o`000?nG]^goUkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0
003oX[WYoj:ij@04oj:ij@Ko00000_nW_NT00ol0003oYkgYojNmj@05ojNmj@03o`000?n/_nOo[;oW
00[o[;oW00?o0000ok71i_na`NH02ona`NH01?l0003o]L;To`000?l00009okG4i@03o`000?nha>?o
^<CS00_o^<CS00?o0000ok_4h_nka>801?nka>82o`0000Co^/GS00?o0000ok_5h_nkaN802onkaN80
0ol0003o_<CQokc4h@0:okc4h@;o0000=oooool000cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01oooool00ol0003oooooooooo`1Cooooo`03o`000?n>
/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003oTkC^oi>dkP07oi>dkP03o`000?nG
]^goUkK]00SoUkK]00?o0000oibgjonL]n/02OnL]n/00ol0003oX[WYoj:ij@05o`0000?oXK_[00Go
0000ojNmjOnW_NWoYkgYo`000007ojNmj@03o`000?n/_nOo[;oW00[o[;oW00?o0000ok71i_na`NH0
2_na`NH2o`0000co]LCU00?o0000okS4honha><02onha><00ol0003o^lCRok_4hP02ok_4hP03o`00
0?njaN?o^/GS00Go^/GS00?o0000ok_5h_nkaN802onkaN800ol0003o_<CQokc4h@07okc4h@;o0000
00?o^/CRo`000?l00000=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oS[?_ohjck`07ohjck`03o`00
0?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@08oiNfk@03o`00
0?nL]n_oW;O[00OoW;O[1?l00009oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0003o
[;oWojboi`0:ojboi`03o`000?na`NKo/L7V00Ko/L7V0ol000000ona`nOo0000okG4i@0<okG4i@03
o`000?nha>?o^<CS00_o^<CS00Co0000ok_4h_l0003o00002OnjaN<00ol0003o^lGRok_5hP0:ok_5
hP03o`000?nla>7o_<CQ00Go_<CQ0_l00004ok[4hP03o`000?oooooooooo03Cooooo000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`;o0000Eoooool00ol0
003oS[?_ohjck`07ohjck`03o`000?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0
003oUkK]oiNfk@08oiNfk@04o`000?nL]n_oW;O[oibgj`Ko000000?oVkW]o`000?nQ^n/02_nQ^n/0
1Ol0003oYkgYojNmjOnW_NWo000000OoYkgY00?o0000ojboion/_nL02_n/_nL00ol0003o/L7Vok71
iP03ok71iP;o00001Ona`nL00ol0003o]LCUokG4i@0:okG4i@03o`000?nha>?o^<CS00_o^<CS0_l0
000<ok[5h`03o`000?nkaN;o^lGR00[o^lGR00?o0000okc4hOnla>400_nla>42o`0000Oo^/CR00?o
0000ooooooooool0<oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0Eoooool00ol0003oS[?_ohjck`07ohjck`03o`00
0?n?/nooSk?_00SoSk?_00?o0000oi>dk_nC]>h01onC]>h00ol0003oUkK]oiNfk@06oiNfk@So0000
1OnK^Nd00ol0003oXK_[oj6kj`09oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0003o
[;oWojboi`0:ojboi`03o`000?na`NKo000000;o00002?na`nL00ol0003o]LCUokG4i@0:okG4i@03
o`000?nha>?o^<CS00So^<CS0_l000000onha^Go0000ok[5h`0<ok[5h`03o`000?nkaN;o^lGR00[o
^lGR00Co0000okc4hOl0003o00002_nja>800ol0003oooooooooo`0booooo`009oooool00ol0003o
ooooooooo`1Hooooo`03o`000?n>/nooS[?_00OoS[?_00?o0000ohnckon?/nl02?n?/nl00ol0003o
TkC^oi>dkP07oi>dkP03o`000?nG]^goUkK]00Go00000_nF]nh3o`0000WoVkW]00?o0000oj6kjonQ
^n/02OnQ^n/01Ol0003oYkgYojNmjOnW_NWo000000OoYkgY00?o0000ojboion/_nL02?n/_nL3o`00
00co/L?W00?o0000okG4iOnea>D02_nea>D00ol0003o^<CSokS4h`05okS4h`;o00001?nha^D00ol0
003o^/GSok[5h`0;ok[5h`03o`000?nkaN;o^lGR00Wo^lGR0_l0000=ok[4hP03o`000?oooooooooo
037ooooo000Wooooo`03o`000?oooooooooo05Wooooo00?o0000ohjckon>/nl01on>/nl00ol0003o
Sk?_ohnck`08ohnck`03o`000?nC]>koTkC^00?oTkC^1_l00004oiJgkP?o000000?oU[O^o`000?nK
^Nd02_nK^Nd00ol0003oXK_[oj6kj`09oj6kj`05o`000?nW_NWoYkgYojNmjOl000001onW_NT00ol0
003o[;oWojboi`04ojboi`?o00000_n/`^T00ol0003o/L?Wok73i`0;ok73i`03o`000?nea>Go]LCU
00[o]LCU00?o0000okS4honha><00_nha><2o`0000Oo^<KU00?o0000ok[5honjaN<02onjaN<00ol0
003o^lGRok_5hP06ok_5hP;o000000?o^LGSo`000?nja>803?nja>82o`0003;ooooo000Wooooo`03
o`000?oooooooooo05[ooooo00?o0000ohjckon>/nl01on>/nl00ol0003oSk?_ohnck`03ohnck`[o
00001OnB]Nl00ol0003oU[O^o`000002o`0000GoU[O^00?o0000oi^ikOnK^Nd02OnK^Nd00ol0003o
XK_[oj6kj`09oj6kj`04o`000?nW_NWoYkgYo`0000SoYkgY00?o0000ojboion/_nL00ol00006ojc2
j@03o`000?na`nOo/L?W00_o/L?W00?o0000okG4iOnea>D02_nea>D01?l0003o^<CSo`000?l0000:
okS6i@03o`000?njaN?o^/GS00_o^/GS00?o0000ok_5h_nkaN800_nkaN83o`0000Co^LGS00?o0000
ok[4h_nja>802onja>800ol0003oooooooooo`0`ooooo`009oooool00ol0003oooooooooo`1Koooo
o`03o`000?n>/nooS[?_00?oS[?_2Ol00005ohjck`03o`000?nB]NooT[G_00KoT[G_0ol00009oiJg
kP03o`000?nK^NgoVkW]00WoVkW]00?o0000oj6kjonQ^n/02OnQ^n/01?l0003oYkgYojNmjOl00007
ojNmj@?o00002_n/`^T00ol0003o/L?Wok73i`0:ok73i`03o`000?nea>Go]LCU00[o]LCU0_l0000=
okS6i@03o`000?njaN?o^/GS00_o^/GS00Co0000ok_5h_l0003o00002?niaN<00ol0003o^/CRok[4
hP0;ok[4hP03o`000?oooooooooo02oooooo000Wooooo`;o0000GOooool5o`0000GoSK;`00?o0000
ohjckon>/nl01on>/nl00ol0003oT[G_oi:ek`02oi:ek`?o00000onB]Nl00ol0003oU[O^oiJgkP07
oiJgkP03o`000?nK^NgoVkW]00SoVkW]00?o0000oj6kjonQ^n/02_nQ^n/01?l0003oYkgYojNmjOl0
0003ojNmj@?o000000?oYl3[o`000?n/`^T02on/`^T00ol0003o/L?Wok73i`0:ok73i`03o`000?ne
a>Go]LCU00Ko]LCU0ol000000onda^Oo0000okS6i@0=okS6i@03o`000?njaN?o^/GS00[o^/GS0_l0
000;okW5h`03o`000?nja>;o^/CR00_o^/CR00?o0000ooooooooool0;_ooool002Kooooo0_l0001O
ooooo`03o`000?n=/_3oSK;`00OoSK;`00?o0000ohjckon>/nl01on>/nl4o`0000OoT[G_00?o0000
oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^ik@03o`000?nQ^n_oXK_[00[oXK_[00?o0000
ojNmjOnW_NT00ol00005ojO0j`03o`000?n/`^Wo[<;Y00[o[<;Y00?o0000ok73iona`nL02_na`nL0
0ol0003o]LCUokG4i@03okG4i@;o00001Onda^L00ol0003o^<KUokS6i@0;okS6i@03o`000?njaN?o
^/GS00So^/GS0_l000000onha^Go0000okW5h`0;okW5h`03o`000?nja>;o^/CR00[o^/CR0_l0000_
ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`000?n=/_3oSK;`00OoSK;`00?o0000ohjc
kon>/nl01?n>/nl4o`0000[oT[G_00?o0000oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^i
k@03o`000?nQ^n_oXK_[00SoXK_[1?l000000onW`>_o0000ojO0j`06ojO0j`03o`000?n/`^Wo[<;Y
00[o[<;Y00?o0000ok73iona`nL02_na`nL00ol0003o]LCUo`000002o`0000So]<KW00?o0000okS6
iOnha^D02onha^D00ol0003o^/GSok[5h`05ok[5h`;o00001?nha^D00ol0003o^LGSokW5h`0:okW5
h`03o`000?nja>;o^/CR00[o^/CR0_l0000^ooooo`009oooool00ol0003oooooooooo`1Oooooo`03
o`000?n=/_3oSK;`00OoSK;`00?o0000ohjckon>/nl00ol00004ohjck`03o`000?nB]NooT[G_00So
T[G_00?o0000oiJgk_nF]nh01onF]nh00ol0003oVkW]oi^ik@08oi^ik@03o`000?nQ^n_oXK_[00Co
XK_[0ol00002oj6mk@05o`000?nW`>_oYl3[ojO0jol000001onW`>/00ol0003o[<;Yojc2j@0:ojc2
j@03o`000?na`nOo/L?W00Wo/L?W0_l0000<okC6i`03o`000?nha^Go^<KU00_o^<KU00?o0000ok[5
honjaN<00_njaN<2o`0000Oo^<KU00?o0000okW5honiaN<02OniaN<00ol0003o^/CRok[4hP08ok[4
hP;o000000?o]l?So`000?ooool0;Oooool002Kooooo00?o0000ooooooooool0HOooool00ol0003o
SK;`ohfbl006ohfbl0?o00002?n>/nl00ol0003oT[G_oi:ek`08oi:ek`03o`000?nF]nkoU[O^00Oo
U[O^00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003oXK_[oj6kj`03o`0000KoXKg]00Go0000ojO0jonW
`>_oYl3[o`000007ojO0j`03o`000?n/`^Wo[<;Y00[o[<;Y00?o0000ok73iona`nL01_na`nL2o`00
00;o/LGY00?o0000okC6ionda^L02_nda^L00ol0003o^<KUokS6i@0;okS6i@04o`000?njaN?o0000
o`0000[o^<KU00?o0000okW5honiaN<02OniaN<00ol0003o^/CRok[4hP05ok[4hP;o00001?ng`n<0
0ol0003oooooooooo`0[ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03o`000?n=/_3oSK;`
00;oSK;`0ol00002ohfbl003o`000?n>/nooS[?_00OoS[?_00?o0000oi:ekonB]Nl02?nB]Nl00ol0
003oU[O^oiJgkP07oiJgkP03o`000?nK^NgoVkW]00KoVkW]1?l0000:oj6mk@05o`000?nW`>_oYl3[
ojO0jol000001onW`>/00ol0003o[<;Yojc2j@0:ojc2j@03o`000?na`nOo/L?W00;o/L?W0ol00005
ok75j@03o`000?nda^Oo]<KW00[o]<KW00?o0000okS6iOnha^D02_nha^D2o`0000co^<KU00?o0000
okW5honiaN<02_niaN<00ol0003o^/CRok[4hP02ok[4hP;o00001_ng`n<2o`0002cooooo000Voooo
o`03o`000?oooooooooo06?ooooo1?l00006ohfbl003o`000?n>/nooS[?_00OoS[?_00?o0000oi:e
konB]Nl02?nB]Nl00ol0003oU[O^oiJgkP07oiJgkP03o`000?nK^NgoVkW]00Go00000_nK^nh00ol0
003oXKg]oj6mk@0:oj6mk@04o`000?nW`>_oYl3[o`0000SoYl3[00?o0000ojc2jOn/`^T02_n/`^T0
1?l0003o/L?Wo`000?l00009ok75j@03o`000?nda^Oo]<KW00[o]<KW00?o0000okS6iOnha^D01_nh
a^D3o`000003okK7iol0003o^<KU00co^<KU00?o0000okW5honiaN<02_niaN<01?l0003o^/CRo`00
0?l00009okO3h`03o`000?oooooooooo02[ooooo000Vooooo`;o0000Hoooool3o`0000WoSK;`00?o
0000ohjckon>/nl01on>/nl00ol0003oT[G_oi:ek`08oi:ek`03o`000?nF]nkoU[O^00?oU[O^1_l0
0008oi^kkP03o`000?nQ_NgoXKg]00[oXKg]00Co0000ojO0jonW`>_o00002?nW`>/00ol0003o[<;Y
ojc2j@08ojc2j@?o00003?naaNT00ol0003o]<KWokC6i`0:okC6i`03o`000?nha^Go^<KU00?o^<KU
0_l00005okK7i`03o`000?nha^Go^<KU00_o^<KU00?o0000okW5honiaN<02OniaN<2o`0000co]l?S
00?o0000ooooooooool0:Oooool002Kooooo00?o0000ooooooooool0Goooool3o`0000?ooooo00?o
0000ohfbl?n=/_001on=/_000ol0003oS[?_ohjck`07ohjck`03o`000?nB]NooT[G_00?oT[G_2_l0
0005oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd02_nQ_Nd01?l0003oYl3[ojO0
jol00008ojO0j`03o`000?n/`^Wo[<;Y00Co[<;Y0ol00002ojc4j`03o`000?naaNWo/LGY00_o/LGY
00?o0000okC6ionda^L02_nda^L00ol0003o^<KUo`000002o`0000So]/OW00?o0000okS6iOnha^D0
2_nha^D00ol0003o^LGSokW5h`06okW5h`?o000000?o]lGUo`000?ng`n<03?ng`n<00ol0003ooooo
ooooo`0Xooooo`009_ooool00ol0003oooooooooo`1Looooo`?o00001oooool00ol0003oSK;`ohfb
l007ohfbl003o`000?n>/nooS[?_00?oS[?_2Ol00005oi:fl003o`000?nF^NooU[W_00SoU[W_00?o
0000oi^kk_nK^nh01onK^nh00ol0003oXKg]oj6mk@0:oj6mk@04o`000?nW`>_oYl3[o`0000SoYl3[
00?o0000ojc2jOn/`^T00ol00006ojc4j`03o`000?naaNWo/LGY00_o/LGY00?o0000okC6ionda^L0
2Onda^L2o`0000co]/OW00?o0000okS6iOnha^D02_nha^D00ol0003o^LGSokW5h`03okW5h`;o0000
1OngaND00ol0003o]l?SokO3h`0:okO3h`03o`000?oooooooooo02Sooooo000Vooooo`03o`000?oo
oooooooo05Wooooo0ol0000;ooooo`03o`000?n=/_3oSK;`00?oSK;`2Ol00005ohndl003o`000?nB
]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF^Nl00ol0003oVk_^oi^kkP07oi^kkP03o`000?nQ
_NgoXKg]00[oXKg]00Co0000ojO0jonW`>_o00001onW`>/3o`0000[o[<C[00?o0000ok75jOnaaNT0
2onaaNT00ol0003o]<KWokC6i`06okC6i`;o00000_ncanT00ol0003o]/OWokK7i`0:okK7i`03o`00
0?nha^Go^<KU00[o^<KU00?o0000okW5hol000000_l00008okO5i@03o`000?ng`n?o]l?S00[o]l?S
00?o0000ooooooooool09oooool002Kooooo00?o0000ooooooooool0E_ooool3o`0000oooooo1Ol0
0005ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_001onB]_000ol0003oU[W_oiJi
k`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd02_nQ_Nd01?l0003oYl3[ojO0
jol00003ojO0j`?o00000_nW`^d00ol0003o[<C[ojc4j`09ojc4j`03o`000?naaNWo/LGY00_o/LGY
00?o0000okC6ionda^L00_nda^L3o`0000Go/lOY00?o0000okK7ionfanL02_nfanL00ol0003o^<KU
okS6i@09okS6i@;o00003?ngaND00ol0003o]l?SokO3h`0:okO3h`03o`000?oooooooooo02Kooooo
000Vooooo`03o`000?oooooooooo05?ooooo0ol0000Cooooo`03o`000?n>/nooS[?_00OoS[?_00?o
0000ohndl?n?]?001on?]?000ol0003oT[K`oi:fl007oi:fl003o`000?nF^NooU[W_00SoU[W_00?o
0000oi^kk_nK^nh01onK^nh00ol0003oXKg]oj6mk@0:oj6mk@03o`000?nW`>_oYl3[00?o00001_nW
`^d00ol0003o[<C[ojc4j`09ojc4j`03o`000?naaNWo/LGY00_o/LGY00Co0000okC6iol0003o0000
2OncanT00ol0003o]/OWokK7i`0:okK7i`03o`000?nha^Go^<KU00Ko^<KU0_l000000onfanOo0000
okO5i@0<okO5i@03o`000?ng`n?o]l?S00Wo]l?S0_l0000Wooooo`009Oooool00ol0003ooooooooo
o`1Aooooo`?o00005oooool00ol0003oS[?_ohjck`07ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o
0000oi:fl?nB]_001onB]_000ol0003oU[W_oiJik`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o
0000oj6mkOnQ_Nd02?nQ_Nd5o`0000WoYl;]00?o0000ojc4jon/a>/02On/a>/00ol0003o/LGYok75
j@0:ok75j@;o00003?ncanT00ol0003o]/OWokK7i`0:okK7i`03o`000?nha^Go^<KU00;o^<KU0ol0
0004okK7i`03o`000?ngaNGo]lGU00_o]lGU00?o0000okO3hong`n<02Ong`n<00ol0003ooooooooo
o`0Uooooo`009Oooool3o`0004kooooo0ol0000Jooooo`;o00002On>/nl00ol0003oSkC`ohndl007
ohndl003o`000?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF^Nl00ol0003oVk_^oi^kkP07
oi^kkP03o`000?nQ_NgoXKg]00CoXKg]0ol00003oj;0kP03o`000?nW`^go000000WoYl;]00?o0000
ojc4jon/a>/02On/a>/00ol0003o/LGYok75j@06ok75j@?o000000?o/<O[o`000?ncanT03?ncanT0
0ol0003o]/OWokK7i`0:okK7i`04o`000?nha^Go0000o`0000So]/OW00?o0000okO5iOngaND02_ng
aND00ol0003o]l?SokO3h`09okO3h`;o00009_ooool002Gooooo00?o0000ooooooooool0Boooool3
o`0001kooooo0_l00009ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_001onB]_00
0ol0003oU[W_oiJik`08oiJik`03o`000?nK^nkoVk_^00OoVk_^00?o0000oj6mkOnQ_Nd00ol00007
oj;0kP03o`000?nW`^go000000WoYl;]00?o0000ojc4jon/a>/02On/a>/00ol0003o/LGYok75j@03
ok75j@;o00001On`an/00ol0003o/lOYok?7j@0;ok?7j@03o`000?nfanOo]/OW00Wo]/OW0_l0000;
okK7i`03o`000?ngaNGo]lGU00[o]lGU00?o0000okO3hong`n<01_ng`n<2o`000003ok?2iOl0003o
000002Gooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c007ooooo`03o`000?oooooooooo04Sooooo0ol0000Rooooo`;o00002On>
/nl00ol0003oSkC`ohndl007ohndl003o`000?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl02?nF
^Nl00ol0003oVk_^oi^kkP03oi^kkPKo00002onR`>h00ol0003oYl;]o`000009ojO2k@03o`000?n/
a>_o[<C[00Wo[<C[00?o0000ok75jOl000000_l00008ok37j`03o`000?ncanWo/lOY00_o/lOY00?o
0000okK7ionfanL01_nfanL2o`000003okC8jOl0003o]/OW00_o]/OW00?o0000okO5iOngaND02_ng
aND00ol0003o]l?SokO3h`02okO3h`?o00001?nc`^D2o`0002Cooooo0009ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03o`00
0?oooooooooo04Gooooo0ol0000Vooooo`;o00002On>/nl00ol0003oSkC`ohndl007ohndl003o`00
0?nB]_3oT[K`00OoT[K`00?o0000oiJikonF^Nl01_nF^Nl7o`0000GoW;g_00?o0000oj;0k_nR`>h0
2_nR`>h00ol0003oYl;]o`000009ojO2k@03o`000?n/a>_o[<C[00So[<C[0_l0000<ok37j`03o`00
0?ncanWo/lOY00_o/lOY00?o0000okK7ionfanL00_nfanL3o`0000Co]<SY00?o0000okK7ionfanL0
2_nfanL00ol0003o]lGUokO5i@0:okO5i@04o`000?ng`n?o0000o`0000So/l;U00?o0000oooooooo
ool08_ooool000Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000WoS[?_00?o0000ohnd
l?n?]?001on?]?000ol0003oT[K`oi:fl007oi:fl003o`000?nF^NooU[W_00Go00000_nH^_000ol0
003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[oX/3^00?o0000ojO2kOl000002OnW`^d00ol0
003o[<C[ojc4j`04ojc4j`?o00000_n/a^d00ol0003o/<O[ok37j`0:ok37j`03o`000?ncanWo/lOY
00_o/lOY00Co0000okK7iol0003o00002?ndb>T00ol0003o]/OWokK7i`09okK7i`03o`000?ngaNGo
]lGU00[o]lGU0_l0000;ok?2i@03o`000?oooooooooo027ooooo0009ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o0000ooooooooool0?ooo
ool3o`0002kooooo0_l00009ohjck`03o`000?n?]?3oSkC`00OoSkC`00?o0000oi:fl?nB]_000onB
]_06o`0000SoV;[`00?o0000oibmkonL_Nl02?nL_Nl00ol0003oX/3^oj;0kP0:oj;0kP03o`000?nW
`^go000000WoYl;]00?o0000ojc4jon/a>/00ol00006ojc6k@03o`000?n`an_o/<O[00[o/<O[00?o
0000ok?7jOncanT02_ncanT2o`0000_o]<SY00?o0000okK7ionfanL02OnfanL00ol0003o]lGUokO5
i@06okO5i@?o000000?o/lCWo`000?nc`^D02_nc`^D2o`0002;ooooo0009ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Oooooo00?o0000ooooooooool0
??ooool3o`0003;ooooo0_l00009ohjck`03o`000?n?]?3oSkC`00?oSkC`2Ol00005oiBhl003o`00
0?nH^_3oV;[`00OoV;[`00?o0000oibmkonL_Nl02?nL_Nl00ol0003oX/3^oj;0kP0:oj;0kP03o`00
0?nW`^go000000SoYl;]0ol0000:ojc6k@03o`000?n`an_o/<O[00[o/<O[00?o0000ok?7jOncanT0
1_ncanT3o`000003ok78jol0003o]<SY00_o]<SY00?o0000okK7ionfanL02OnfanL00ol0003o]lGU
okO5i@03okO5i@;o00001Onca>L00ol0003o/l;Uok?2i@09ok?2i@;o00008Oooool000Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool00ol0003o
ooooooooo`0iooooo`?o0000=_ooool2o`0000GoS[?_2Ol00004oi6fl003o`000?nD^?3oU;S`00So
U;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[o
X/3^0_l00005ojO2k@?o000000?oYlC^o`000?n/a^d02on/a^d00ol0003o/<O[ok37j`0:ok37j`03
o`000?ncanWo/lOY00?o/lOY0_l00005ok78j`03o`000?ndb>Wo]<SY00[o]<SY00?o0000okK7ionf
anL02OnfanL00ol0003o]lGUo`000002o`0000So/lCW00?o0000ok?2iOnc`^D02Onc`^D00ol0003o
ooooooooo`0Oooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo03Oooooo0ol0000jooooo`Ko00001?n@]>l00ol0
003oTKK`oi6fl007oi6fl003o`000?nD^?3oU;S`00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0
003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^00[oX/3^0_l000001?nW`^go0000o`000?l00005
ojO4kP03o`000?n/a^go[<K]00[o[<K]00?o0000ok37jon`an/02_n`an/00ol0003o/lOYo`000002
o`0000So/LS[00?o0000okC8jOndb>T02_ndb>T00ol0003o]/OWokK7i`08okK7i`;o00003?nca>L0
0ol0003o/l;Uok?2i@08ok?2i@;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0dooooo`?o0000?_oo
ool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nA]_3oTKK`00OoTKK`00?o0000oiBhl?nD^?002?nD
^?000ol0003oV;[`oiRjl007oiRjl003o`000?nL_NooW;g_00SoW;g_00?o0000oj;0k_nR`>h02?nR
`>h4o`0000WoYlC^00?o0000ojc6kOn/a^d02_n/a^d00ol0003o/<O[ok37j`09ok37j`;o00003?na
b>/00ol0003o]<SYokC8j@0:okC8j@03o`000?nfanOo]/OW00Co]/OW0ol000000onba^Wo0000ok?4
i`0<ok?4i`03o`000?nc`^Go/l;U00So/l;U0_l0000Oooooo`009?ooool00ol0003oooooooooo`0a
ooooo`?o0000@_ooool00ol0003oT;C_oi2dk`07oi2dk`03o`000?nA]_3oTKK`00OoTKK`00?o0000
oiBhl?nD^?002?nD^?000ol0003oV;[`oiRjl007oiRjl003o`000?nL_NooW;g_00SoW;g_00?o0000
oj;0k_nR`>h01?nR`>h3o`0000;oX/;`00?o0000ojO4k_l000002OnWa>h00ol0003o[<K]ojc6k@0:
ojc6k@03o`000?n`an_o/<O[00Ko/<O[0_l00002ojk8k@03o`000?nab>_o/LS[00[o/LS[00?o0000
okC8jOndb>T02_ndb>T00ol0003o]/OWokK7i`03o`0000Go//KY00?o0000ok?4ionca>L02_nca>L0
0ol0003o/l;Uok?2i@09ok?2i@;o00007_ooool002Cooooo00?o0000ooooooooool0;oooool2o`00
04Kooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007oi6fl003o`000?nD^?3oU;S`
00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`08oibmk`03o`000?nR`>koX/3^
00?o00001_nR`_000ol0003oYlC^o`000009ojO4kP03o`000?n/a^go[<K]00[o[<K]00?o0000ok37
jon`an/00_n`an/3o`0000Go[/S]00?o0000ok78jonab>/02Onab>/00ol0003o]<SYokC8j@0:okC8
j@?o00002Onba^T00ol0003o/lCWok?4i`0:ok?4i`03o`000?nc`^Go/l;U00So/l;U0_l0000Noooo
o`009?ooool00ol0003oooooooooo`0/ooooo`?o0000BOooool00ol0003oT;C_oi2dk`07oi2dk`03
o`000?nA]_3oTKK`00OoTKK`00?o0000oiBhl?nD^?002?nD^?000ol0003oV;[`oiRjl007oiRjl003
o`000?nL_NooW;g_00KoW;g_1?l0000:oj;2l003o`000?nWa>ko000000WoYlC^00?o0000ojc6kOn/
a^d02_n/a^d01?l0003o/<O[o`000?l00009ojk8k@03o`000?nab>_o/LS[00Wo/LS[00?o0000okC8
jOndb>T01_ndb>T3o`000003ok78jol0003o//KY00[o//KY00?o0000ok?4ionca>L02_nca>L00ol0
003o/l;Uok?2i@04ok?2i@?o000000?o[l7Wo`000?l000007Oooool002Cooooo00?o0000oooooooo
ool0:Oooool3o`0004gooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007oi6fl003
o`000?nD^?3oU;S`00SoU;S`00?o0000oiRjl?nH^_001onH^_000ol0003oW;g_oibmk`05o`0000Co
W[o`00?o0000oj;2l?nR`_002?nR`_000ol0003oYlC^o`000009ojO4kP03o`000?n/a^go[<K]00So
[<K]0ol0000<ojk8k@03o`000?nab>_o/LS[00Wo/LS[00?o0000okC8jOndb>T00ondb>T2o`0000Go
/LS[00?o0000ok;6jOnba^T02Onba^T00ol0003o/lCWok?4i`0:ok?4i`03o`000?nc`^Go/l;U00?o
00001On_`NL2o`0001cooooo000Tooooo`03o`000?oooooooooo02Kooooo0ol0001Aooooo`03o`00
0?n@]>ooT;C_00OoT;C_00?o0000oi6fl?nA]_001onA]_000ol0003oU;S`oiBhl008oiBhl003o`00
0?nH^_3oV;[`00?oV;[`1_l0000:oijol003o`000?nR`_3oX/;`00SoX/;`00?o0000ojO4k_l00000
2OnWa>h00ol0003o[<K]ojc6k@04ojc6k@?o00000on[anh00ol0003o[/S]ojk8k@0:ojk8k@03o`00
0?nab>_o/LS[00Wo/LS[00?o0000okC8jOl000000_l00008ok78j`03o`000?nba^Wo//KY00Wo//KY
00?o0000ok?4ionca>L02Onca>L3o`0000Wo[l7W0_l0000Kooooo`008oooool2o`0002Gooooo0ol0
001Eooooo`03o`000?n@]>ooT;C_00OoT;C_00?o0000oi6fl?nA]_001onA]_000ol0003oU;S`oiBh
l006oiBhl0Oo00001_nJ_O000ol0003oW[o`oijol008oijol003o`000?nR`_3oX/;`00SoX/;`0_l0
000:ojO4kP03o`000?n/a^go[<K]00?o00001on[anh00ol0003o[/S]ojk8k@0:ojk8k@03o`000?na
b>_o/LS[00So/LS[0_l0000<ok78j`03o`000?nba^Wo//KY00Wo//KY00?o0000ok?4ionca>L01_nc
a>L2o`000003ojo3jOl0003o[l7W00[o[l7W00?o0000ooooooooool06Oooool002Cooooo00?o0000
ooooooooool08?ooool3o`0005Wooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl007
oi6fl003o`000?nD^?3oU;S`00Go00000onG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3o
W[o`00SoW[o`00?o0000oj;2l?nR`_002?nR`_02o`0000WoYlC^0ol0000;oj_7kP03o`000?n^b>go
[/S]00[o[/S]00?o0000ok78jonab>/01?nab>/3o`0000;o[lW]00?o0000ok78jonab>/02_nab>/0
0ol0003o//KYok;6j@09ok;6j@03o`000?nca>Oo/lCW00;o/lCW0ol00004ojo3j@03o`000?n_`NOo
[l7W00Wo[l7W00?o0000ooooooooool06?ooool002?ooooo00?o0000ooooooooool07_ooool3o`00
05gooooo00?o0000oi2dkon@]>l01on@]>l00ol0003oTKK`oi6fl003oi6fl0Ko00002OnG^_000ol0
003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00SoW[o`00?o0000oj;2l?nR`_002?nR`_02o`00
00GoYlC^0ol00003ojO6k`03o`000?n[ankoZlO^00WoZlO^00?o0000ojk8kOn^b>d02_n^b>d00ol0
003o/LS[ok78j`03o`0000Ko[lW]00?o0000ok78jonab>/02Onab>/00ol0003o//KYok;6j@0:ok;6
j@04o`000?nca>Oo0000o`0000So[l?Y00?o0000ojo1ion_`NL02On_`NL00ol0003oooooooooo`0G
ooooo`008oooool00ol0003oooooooooo`0Kooooo`?o0000HOooool00ol0003oT;C_oi2dk`03oi2d
k`Wo00001OnE]nl00ol0003oUk[`oiNjl008oiNjl003o`000?nJ_O3oV[g`00SoV[g`00?o0000oijo
l?nN_o002?nN_o000ol0003oX/;`oj;2l008oj;2l0;o000000CoYlC^o`000?l0003o00001onWa^l0
0ol0003oZlO^oj_7kP09oj_7kP03o`000?n^b>go[/S]00Wo[/S]0ol0000:ojo9k@03o`000?nab>_o
/LS[00Wo/LS[00?o0000ok;6jOnba^T02?nba^T3o`0000_o[l?Y00?o0000ojo1ion_`NL02?n_`NL2
o`0001Sooooo000Sooooo`03o`000?oooooooooo01Sooooo0ol0001Uooooo`Go00001OnD]Nh00ol0
003oUKO_oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O002?nJ_O000ol0
003oW[o`oijol008oijol003o`000?nR`_3oX/;`00KoX/;`1?l0000;ojO6k`03o`000?n[ankoZlO^
00WoZlO^00?o0000ojk8kOn^b>d01_n^b>d2o`0000;o[LW^00?o0000ojo9kOn_bNd02On_bNd00ol0
003o/LS[ok78j`09ok78j`03o`000?nba^Wo//KY00Co//KY0ol00002ojk5j`03o`000?n_`nWo[l?Y
00[o[l?Y00?o0000ojo1ion_`NL02?n_`NL00ol0003oooooooooo`0Fooooo`008oooool00ol0003o
ooooooooo`0Eooooo`?o0000J?ooool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00Oo
UKO_00?o0000oiNjl?nG^_002?nG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00So
W[o`00?o0000oj;2l?nR`_001Ol00004ojC4l003o`000?nWa^ooYlK_00WoYlK_00?o0000oj_7k_n[
anh02On[anh00ol0003o[/S]ojk8k@02ojk8k@?o00001On]bNh00ol0003o[lW]ojo9k@09ojo9k@03
o`000?nab>_o/LS[00Wo/LS[00?o0000ok;6jOnba^T00ol00006ojk5j`03o`000?n_`nWo[l?Y00Wo
[l?Y00?o0000ojo1ion_`NL02On_`NL00ol0003oooooooooo`0Eooooo`008oooool00ol0003ooooo
ooooo`0Booooo`?o0000K?ooool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_
00?o0000oiNjl?nG^_002?nG^_000ol0003oV[g`oiZml008oiZml003o`000?nN_o3oW[o`00KoW[o`
1?l0000:ojC4l003o`000?nWa^ooYlK_00WoYlK_00?o0000oj_7k_n[anh02On[anh01?l0003o[/S]
o`000?l00009ojg9kP03o`000?n_bNgo[lW]00Wo[lW]00?o0000ok78jonab>/02?nab>/3o`0000[o
[/G[00?o0000ojo3jOn_`nT02On_`nT00ol0003o[l7Wojo1i`09ojo1i`03o`000?oooooooooo01Co
oooo000Rooooo`?o00004?ooool3o`00073ooooo00?o0000oiBek_nD]Nh02?nD]Nh00ol0003oUKO_
oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O002?nJ_O000ol0003oW[o`
oijol005o`0000?oX<;`00?o0000ojC4l?nTa?002OnTa?000ol0003oYlK_ojO6k`09ojO6k`03o`00
0?n[ankoZlO^00SoZlO^0ol0000;ojg9kP03o`000?n_bNgo[lW]00Wo[lW]00?o0000ok78jonab>/0
1?nab>/3o`0000;o[LO]00?o0000ojk5jon^aN/02On^aN/00ol0003o[l?Yojo3j@09ojo3j@03o`00
0?n_`NOo[l7W00Oo[l7W0ol0000Eooooo`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?oo
ool00ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_00?o0000oiNjl?nG^_002?nG
^_000ol0003oV[g`oiZml006oiZml0Co00002OnP`_000ol0003oY<C`ojC4l008ojC4l0;o00002onW
a^l00ol0003oZlO^oj_7kP04oj_7kP?o00000onZb>l00ol0003o[LW^ojg9kP09ojg9kP03o`000?n_
bNgo[lW]00Wo[lW]00?o0000ok78jonab>/00ol00006ojg7k@03o`000?n^aN_o[/G[00Wo[/G[00?o
0000ojo3jOn_`nT02On_`nT01?l0003o[l7Wojo1ion_`NL5o`0000;ooooo00?o0000ooooooooool0
4oooool002?ooooo00?o0000ooooooooool02Oooool3o`0007Sooooo00?o0000oiBek_nD]Nh02?nD
]Nh00ol0003oUKO_oiFgk`07oiFgk`03o`000?nG^_3oUk[`00SoUk[`00?o0000oiZml?nJ_O001Ol0
0003oifol003o`000?nP`_3oX<;`00SoX<;`00?o0000ojC4l?nTa?002?nTa?02o`0000_oYlK_00?o
0000oj_7k_n[anh00ol00007oj[8k`03o`000?n]bNko[LW^00Wo[LW^00?o0000ojo9kOn_bNd02?n_
bNd3o`0000[o[LO]00?o0000ojk5jon^aN/02On^aN/00ol0003o[l?Yojo3j@08ojo3j@Ko00001Ooo
ool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`06ooooo`?o0000O?ooool0
0ol0003oU;G^oiBekP08oiBekP03o`000?nE]nooUKO_00OoUKO_00?o0000oiNjl?nG^_001_nG^_04
o`0000WoWKo`00?o0000oj32l?nP`_002?nP`_000ol0003oY<C`ojC4l008ojC4l0;o00002OnWa^l4
o`0000_oZ/S_00?o0000ojg9k_n]bNh02On]bNh00ol0003o[lW]ojo9k@04ojo9k@?o000000?o[<S^
o`000?n]and02on]and00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_`nWo[l?Y00Co[l?Y1_l00008
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo00Cooooo0ol00020oooo
o`03o`000?nD]NkoU;G^00SoU;G^00?o0000oiFgkonE]nl01onE]nl00ol0003oUk[`oiNjl005o`00
00?oVkc_00?o0000oifol?nM_o002?nM_o000ol0003oX<;`oj32l008oj32l003o`000?nTa?3oY<C`
00SoY<C`0_l00003ojO6k`Go00000onXao000ol0003oZ/S_oj[8k`0:oj[8k`03o`000?n]bNko[LW^
00Wo[LW^00?o0000ojo9kOn_bNd00ol00005ojc8kP03o`000?n]ango[LO]00[o[LO]00?o0000ojk5
jon^aN/02On^aN/00ol0003o[l?Yojo3j@05o`0000cooooo00?o0000ooooooooool04oooool002;o
oooo00Co0000oooooooooooooooo0ol00024ooooo`03o`000?nD]NkoU;G^00SoU;G^00?o0000oiFg
konE]nl00onE]nl6o`0000WoVkc_00?o0000oifol?nM_o002?nM_o000ol0003oX<;`oj32l008oj32
l003o`000?nTa?3oY<C`00SoY<C`1?l00009ojS7l003o`000?nZb>ooZ/S_00[oZ/S_00?o0000ojg9
k_n]bNh02?n]bNh3o`0000Wo[<S^00?o0000ojg7kOn]and02_n]and00ol0003o[/G[ojk5j`08ojk5
j`Go00003oooool00ol0003oooooooooo`0Cooooo`008_ooool4o`0008Sooooo00?o0000oiBek_nD
]Nh01_nD]Nh7o`0000KoV[[^00?o0000oi^lkonK_>l01onK_>l00ol0003oWKo`oifol008oifol003
o`000?nP`_3oX<;`00SoX<;`00?o0000ojC4l?nTa?001?nTa?03o`000003ojG6l?l0003o000000_o
Z<O`00?o0000oj[8konZb>l02_nZb>l00ol0003o[LW^ojg9kP04ojg9kP?o000000?oZlW_o`000?n/
b>h02_n/b>h00ol0003o[LO]ojg7k@0:ojg7k@03o`000?n^aN_o[/G[00Co[/G[1Ol0000Booooo`03
o`000?oooooooooo01?ooooo000Rooooo`?o0000R_ooool00ol0003oU;G^oiBekP05o`0000?oVKO]
00?o0000oiZjk_nJ^^h02?nJ^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`
00?o0000oj32l?nP`_002?nP`_000ol0003oY<C`ojC4l003o`0000GoYLK`0_l0000;ojS7l003o`00
0?nZb>ooZ/S_00[oZ/S_00?o0000ojg9k_n]bNh00ol00005oj_9k`03o`000?n/b>ko[<S^00Wo[<S^
00?o0000ojg7kOn]and02_n]and00ol0003o[/G[ojk5j`04o`0001Oooooo00?o0000ooooooooool0
4_ooool002Cooooo00?o0000ooooooooool0ROooool2o`0000WoVKO]00?o0000oiZjk_nJ^^h02?nJ
^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`00?o0000oj32l?nP`_001_nP
`_04o`0000SoYLK`00?o0000ojG6l?l000002onXao000ol0003oZ/S_oj[8k`08oj[8k`Co00002On[
bNl00ol0003o[<S^ojc8kP09ojc8kP03o`000?n]ango[LO]00So[LO]1Ol0000Jooooo`03o`000?oo
oooooooo01;ooooo000Fooooo`03onk^k_l0003o000000;o000000?o410@ooooooooool01oooool0
0ol0003oooooooooo`29ooooo`03o`000?nI]ngoVKO]00SoVKO]00?o0000oiZjk_nJ^^h02?nJ^^h0
0ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00SoWKo`00?o0000oj32l?nP`_001Ol00003
oj?4l003o`000?nUa_3oYLK`00OoYLK`00?o0000ojG6l?l000002onXao000ol0003oZ/S_oj[8k`04
oj[8k`?o00000onYbO000ol0003oZlW_oj_9k`08oj_9k`03o`000?n/b>ko[<S^00Wo[<S^00?o0000
ojg7kOn]and01?n]and5o`0001gooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0;ooooo`03o`000?oooooooooo08Wooooo00?o0000oiVgkOnI]nd02?nI]nd0
0ol0003oV[[^oiZjkP08oiZjkP03o`000?nK_>ooVkc_00OoVkc_00?o0000oifol?nM_o001_nM_o04
o`0000WoXlC`00?o0000ojG6l?nUa_001onUa_000ol0003oYLK`o`00000;ojS7l003o`000?nZb>oo
Z/S_00?o00001onYbO000ol0003oZlW_oj_9k`08oj_9k`03o`000?n/b>ko[<S^00Wo[<S^00?o0000
ojg7kOn]and01?l0000Qooooo`03o`000?oooooooooo01;ooooo000Fooooo`05oa0@4?oooooooooo
o`000?l@41003?ooool00ol0003oooooooooo`29ooooo`03o`000?nI]ngoVKO]00SoVKO]00?o0000
oiZjk_nJ^^h02?nJ^^h00ol0003oVkc_oi^lk`07oi^lk`03o`000?nM_o3oWKo`00Go00001?nQ`Nl0
0ol0003oXlC`oj?4l007oj?4l003o`000?nUa_3oYLK`00OoYLK`00?o0000ojG6l?l000002_nXao03
o`0000_oZLW`00?o0000oj_9kon[bNl02?n[bNl00ol0003o[<S^ojc8kP08ojc8kPCo00009?ooool0
0ol0003oooooooooo`0Booooo`005_ooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooo
ooooool0ROooool00ol0003oVKO]oiVgk@08oiVgk@03o`000?nJ^^koV[[^00SoV[[^00?o0000oi^l
konK_>l01OnK_>l4o`0000[oXL7_00?o0000oj?4l?nSa?001onSa?000ol0003oYLK`ojG6l007ojG6
l003o`000?nUa_3o000000KoZ<O`0ol00003ojS8l003o`000?nYbO3oZLW`00WoZLW`00?o0000oj_9
kon[bNl02?n[bNl00ol0003o[<S^ojc8kP04ojc8kPCo00009oooool00ol0003oooooooooo`0Boooo
o`005_ooool00ol0003oooooooooo`02o`0000kooooo00?o0000ooooooooool0ROooool00ol0003o
VKO]oiVgk@08oiVgk@03o`000?nJ^^koV[[^00SoV[[^00?o0000oi^lkonK_>l01?l00004oj2nkP03
o`000?nQ`NooXL7_00SoXL7_00?o0000oj?4l?nSa?001onSa?000ol0003oYLK`ojG6l007ojG6l003
o`000?nUa_3o000000;oZ<O`0ol00007ojS8l003o`000?nYbO3oZLW`00WoZLW`00?o0000oj_9kon[
bNl02?n[bNl00ol0003o[<S^ojc8kP04o`0002[ooooo00?o0000ooooooooool04_ooool001Kooooo
00Go410@oooooooooooo0000oa0@400?ooooo`03o`000?oooooooooo08Wooooo00?o0000oiVgkOnI
]nd02?nI]nd00ol0003oV[[^oiZjkP06oiZjkPCo00002OnP_^h00ol0003oXL7_oj71k`08oj71k`03
o`000?nSa?3oXlC`00OoXlC`00?o0000ojG6l?nUa_001onUa_04o`0000_oZ<S`00?o0000ojW9l?nY
bO002OnYbO000ol0003oZlW_oj_9k`06oj_9k`Co0000;_ooool00ol0003oooooooooo`0Booooo`00
5_ooool01OmgMgOoV9RHooooool0003oMgMg013ooooo0_l0002:ooooo`03o`000?nI]ngoVKO]00So
VKO]00?o0000oiZjk_nJ^^h01Ol00002oinlk@03o`000?nP_^koX;k^00WoX;k^00?o0000oj71konQ
`Nl02?nQ`Nl00ol0003oXlC`oj?4l007oj?4l003o`000?nUa_3oYLK`00CoYLK`1?l00002ojO7l003
o`000?nXb?3oZ<S`00WoZ<S`00?o0000ojW9l?nYbO002OnYbO000ol0003oZlW_oj_9k`06o`00037o
oooo00?o0000ooooooooool04_ooool001Kooooo00Gok^k^o`<30ol0003o0000onk^kP0Booooo`03
o`000?oooooooooo08Sooooo00?o0000oiVgkOnI]nd01_nI]nd4o`0000SoWkc]00?o0000oj2nk_nP
_^h02OnP_^h00ol0003oXL7_oj71k`08oj71k`03o`000?nSa?3oXlC`00OoXlC`00?o0000ojG6l?nU
a_000ol00003ojO7l005o`000?nWao3oYlO`ojO7l?l000002onXb?000ol0003oZLW`ojW9l008ojW9
l0Ko0000=?ooool00ol0003oooooooooo`0Booooo`00;?ooool00ol0003oooooo`00002:ooooo`03
o`000?nI]ngoVKO]00Go00000_nO^N/00ol0003oWkc]oinlk@08oinlk@03o`000?nP_^koX;k^00Wo
X;k^00?o0000oj71konQ`Nl02?nQ`Nl00ol0003oXlC`oj?4l005oj?4l0Co00001onWao001Ol0003o
YlO`ojO7l?nWao3o000000_oZ<S`00?o0000ojW9l?nYbO001?nYbO05o`0003Sooooo00?o0000oooo
ooooool04_ooool002oooooo00?o0000ooooooooool0R?ooool2o`0000SoWkW[00?o0000oinlkOnO
_>d02?nO_>d00ol0003oX;k^oj2nkP09oj2nkP03o`000?nQ`NooXL7_00SoXL7_00?o0000oj?4l?nS
a?001?l00004ojK5k`03o`000?nWao3oYlO`00GoYlO`00Go0000ojO7l?nWao3oYlO`o`00000;ojS8
l003o`000?nYbO3oZLW`00Go0000??ooool00ol0003oooooooooo`0Aooooo`00<?ooool00ol0003o
ooooooooo`27ooooo`;o00002OnO^N/00ol0003oWkc]oinlk@08oinlk@03o`000?nP_^koX;k^00Wo
X;k^00?o0000oj71konQ`Nl01_nQ`Nl4o`0000WoY/G_00?o0000ojO7l?nWao001OnWao001Ol0003o
YlO`ojO7l?nWao3o000000[oZ<S`1Ol0000oooooo`03o`000?oooooooooo017ooooo000aooooo`03
o`000?oooooooooo08Oooooo0_l00009oinij`03o`000?nO_>goWkc]00SoWkc]00?o0000oj2nk_nP
_^h02OnP_^h00ol0003oXL7_oj71k`05o`0000?oYL?^00?o0000ojK5konVaNl02?nVaNl00ol0003o
YlO`ojO7l005ojO7l005o`000?nWao3oYlO`ojO7l?l000001_nXb?04o`0004?ooooo00?o0000oooo
ooooool04Oooool003;ooooo00?o0000ooooooooool0Qoooool2o`0000WoWkW[00?o0000oinlkOnO
_>d02?nO_>d00ol0003oX;k^oj2nkP08oj2nkP?o00002OnU`nh00ol0003oY/G_ojK5k`08ojK5k`03
o`000?nWao3oYlO`00GoYlO`00Go0000ojO7l?nWao3oYlO`o`000002ojS8l0Co0000A_ooool00ol0
003oooooooooo`0Aooooo`00<oooool00ol0003oooooooooo`27ooooo`;o00002OnO^N/00ol0003o
Wkc]oinlk@08oinlk@03o`000?nP_^koX;k^00CoX;k^0ol00002ojG0k@03o`000?nU`nkoYL?^00So
YL?^00?o0000ojK5konVaNl02?nVaNl00ol0003oYlO`ojO7l005ojO7l003o`000?nWao3oYlO`00Co
0000BOooool00ol0003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l00009oinij`03o`00
0?nO_>goWkc]00SoWkc]00?o0000oj2nk_nP_^h00ol00006ojG0k@03o`000?nU`nkoYL?^00SoYL?^
00?o0000ojK5konVaNl02?nVaNl00ol0003oYlO`ojO7l004ojO7l0?o0000COooool00ol0003ooooo
ooooo`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o00002OnO^N/00ol0003oWkc]oinl
k@06oinlk@Co00002_nU`>d00ol0003oYL?^ojG3kP08ojG3kP03o`000?nVaNooY/G_00SoY/G_00?o
0000ojO7l?nWao000ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooooooo017ooooo000g
ooooo`;o0000Qoooool2o`0000WoWkW[00?o0000oinlkOnO_>d01Ol00003ojBmj`03o`000?nU`>go
YL3]00WoYL3]00?o0000ojG3k_nU`nh02?nU`nh00ol0003oY/G_ojK5k`06ojK5k`Co00001Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo0000
08Sooooo0_l00007oinij`Co00002OnT_N/00ol0003oYL3]ojG0k@09ojG0k@03o`000?nU`nkoYL?^
00SoYL?^00?o0000ojK5konVaNl01Ol0000:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000;oWkW[1?l00003ojBkj@03
o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d02OnU`>d00ol0003oYL?^ojG3kP07ojG3kPGo
00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo000jooooo`03o`00
0?oooooooooo08Kooooo0ol00008ojBkj@03o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d0
2OnU`>d00ol0003oYL?^ojG3kP03ojG3kPGo00004_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000ojBkjOnT^nT02?nT
^nT00ol0003oY;g[ojBmj`08ojBmj`03o`000?nU`>goYL3]00WoYL3]00?o0000ojG3k_l000000ol0
000Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04?ooool003cooooo00?o0000
ooooooooool0Q_ooool00ol0003oY;_YojBkj@08ojBkj@03o`000?nT_N_oY;g[00SoY;g[00?o0000
ojG0kOnU`>d02?nU`>d3o`0001_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0@
ooooo`00?Oooool2o`0008Oooooo00?o0000ojBkjOnT^nT02?nT^nT00ol0003oY;g[ojBmj`08ojBm
j`03o`000?nU`>goYL3]00CoYL3]0ol0000Oooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool04?ooool003oooooo00?o0000ooooooooool0QOooool00ol0003oY;_YojBkj@08ojBkj@03
o`000?nT_N_oY;g[00SoY;g[00?o0000ojG0kOnU`>d00ol0000Rooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0QOooool00ol0003oY;_Y
ojBkj@08ojBkj@03o`000?nT_N_oY;g[00KoY;g[1?l0000Vooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool04?ooool0047ooooo0_l00026ooooo`03o`000?nT^nWoY;_Y00SoY;_Y00?o
0000ojBmjonT_N/01Ol0000[ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?oo
ool0043ooooo00?o0000ooooool00000Qoooool00ol0003oY;_YojBkj@07ojBkj@Go0000;oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo
08Gooooo00?o0000ojBkjOnT^nT00onT^nT4o`0003Cooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`25ooooo`03o`000?nT^nWo000000?o
0000>?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo0015ooooo`03o`00
0?oooooooooo08Gooooo0_l0000looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
4?ooool004Kooooo0_l00025ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0@ooooo`00B?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`00BOooool00ol0
003oooooooooo`21ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`00B_ooool2o`00087ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo
001<ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo001>oooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00oooooo001?ooooo`;o0000O?ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool0057ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
3oooool005;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool03oooool005?ooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03oooool0
05Cooooo0ol0001fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0?ooooo`00E?ooool2o`0007Oooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool02?ooool2o`0007?ooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000hooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool2o`0006kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
00kooooo001Pooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o0000J_ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Oooool006?ooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03Oooool006Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool006Gooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool03Oooool006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0001Tooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`00J?oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0=ooooo`00JOooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`00J_ooool2o`00
067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00gooooo001/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo
001^ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00cooooo001_ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo001_oooo
o`?o0000Foooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool03?ooool0077ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007;ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3?ooool007?ooooo0_l0001Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`00M_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?ooool2o`0005?ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo
001hooooo`;o0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02oooool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`00O_ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`00Oooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`00POooool3o`00
04Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00_ooooo001fooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`00
N?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02_ooool2
o`0004Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8booooo`0Gooooo`03o`00
0?oooooooooo00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0Eooooo`03oeEEEOmV
IVKo0000013ooooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00[ooooo001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:
ooooo`00GOooool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool0
05cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o0000?Oooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool005co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo002Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool009?ooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool009Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0000dooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`00VOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo002Looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
002Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo002Poooo
o`;o0000:oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02?ooool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08?o
oooo00Co0000oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`24ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00027ooooo00?o0000
ooooooooool0O?ooool4o`00017ooooo002>ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0003oooooooooo`1h
ooooo`Co00005Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Cooooo1?l0000Ioooo
o`00T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
KOooool3o`00027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOooool4o`0002Cooooo
002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo067ooooo1?l0000/
ooooo`00S_ooool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_ooooo00?o0000oooo
ooooool0GOooool4o`00033ooooo002booooo`;o00006Oooool00ol0003oooooooooo`1Iooooo`Co
0000=?ooool00;Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Eooooo`Co0000
>?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`Co0000??oo
ool00;Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`Co0000@?ooool0
0;Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co0000A?ooool00;So
oooo0_l0000Cooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00013ooooo00?o0000
ooooooooool0>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0=_ooool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<_ooool4o`0005_ooooo002oooooo`;o00003?ooool00ol0003oooooooooo`0^ooooo`Co0000
Goooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001Sooooo`00`Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Wooooo`00`_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00`oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?ooool2o`0000Oooooo
00?o0000ooooooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool00ol0003ooooooooo
o`0Fooooo`Co0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0ol0001k
ooooo`00b?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo1?l0001noooo
o`00bOooool01Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00b_ooool01?l0003o
ooooooooool00009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool000001Oooool4o`0008[o
oooo003<ooooo`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool00<;ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Kooooo`00a?ooool00onH
V9So8B4Qonk^kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_ooool00ol0003ooooo
ooooo`2Hooooo`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00:Go
oooo0ol000000ol@413oooooooooo`2fooooo`00Toooool2o`0000_ooooo00?o0000okZj^_ooool0
1?ooool00ol@413o^[Zjooooo`05ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`00
0?nj^[[ooooo09Wooooo002Cooooo`03o`000?oooooooooo00[ooooo0_lb<S85ooooo`03oiRHV?lb
<S;ooooo00Gooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Jooooo`00R?ooool0
1Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool00on7QhOo0000okZj^P04ooooo`03omgMgOl0003o^[Zj00Gooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0LOooool008[ooooo00?o0000
ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00Cooooo00?oEEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o
410@00Gooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q077ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:oooo
o`05omgMgOl@413oooooob4Q8OoMgMd02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`00001aooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b077ooooo002:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c01aooooo`00Qooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00002?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00Kooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`00
0?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonj^[[o0000077ooooo0027ooooo`Oo00001Oooool2o`00027ooooo00?o0000ooooooooool0
1Oooool2o`0000gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@1aooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -44 0 ]
[.5 1.12503 44 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.65 .734 .91 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .68015 Metetra
.65 .741 .916 r
.55403 .68015 .58394 .7109 .61197 .70234 .58233 .67247 Metetra
.651 .749 .921 r
.58233 .67247 .61197 .70234 .64019 .69372 .61084 .66461 Metetra
.653 .756 .925 r
.61084 .66461 .64019 .69372 .66861 .68504 .63957 .65654 Metetra
.655 .762 .928 r
.63957 .65654 .66861 .68504 .69723 .6763 .6685 .6482 Metetra
.658 .768 .93 r
.6685 .6482 .69723 .6763 .72605 .6675 .69764 .63956 Metetra
.662 .771 .931 r
.69764 .63956 .72605 .6675 .75507 .65863 .72698 .6306 Metetra
.665 .773 .93 r
.72698 .6306 .75507 .65863 .7843 .6497 .75652 .62131 Metetra
.669 .774 .928 r
.75652 .62131 .7843 .6497 .81374 .64071 .78627 .6117 Metetra
.672 .772 .925 r
.78627 .6117 .81374 .64071 .84339 .63166 .8162 .60178 Metetra
.675 .769 .921 r
.8162 .60178 .84339 .63166 .87325 .62254 .84634 .59158 Metetra
.678 .764 .916 r
.84634 .59158 .87325 .62254 .90333 .61335 .87667 .58115 Metetra
.679 .758 .911 r
.87667 .58115 .90333 .61335 .93362 .6041 .9072 .57053 Metetra
.68 .751 .905 r
.9072 .57053 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.634 .729 .916 r
.49498 .6552 .52593 .68772 .55403 .68015 .52332 .64852 Metetra
.635 .736 .921 r
.52332 .64852 .55403 .68015 .58233 .67247 .55189 .64166 Metetra
.637 .744 .925 r
.55189 .64166 .58233 .67247 .61084 .66461 .58068 .63453 Metetra
.641 .751 .929 r
.58068 .63453 .61084 .66461 .63957 .65654 .6097 .62702 Metetra
.647 .758 .93 r
.6097 .62702 .63957 .65654 .6685 .6482 .63895 .61905 Metetra
.653 .764 .931 r
.63895 .61905 .6685 .6482 .69764 .63956 .6684 .61055 Metetra
.66 .769 .93 r
.6684 .61055 .69764 .63956 .72698 .6306 .69806 .60148 Metetra
.667 .772 .928 r
.69806 .60148 .72698 .6306 .75652 .62131 .72793 .59182 Metetra
.674 .773 .925 r
.72793 .59182 .75652 .62131 .78627 .6117 .75798 .58159 Metetra
.68 .773 .921 r
.75798 .58159 .78627 .6117 .8162 .60178 .78822 .57082 Metetra
.685 .77 .916 r
.78822 .57082 .8162 .60178 .84634 .59158 .81865 .55957 Metetra
.689 .766 .91 r
.81865 .55957 .84634 .59158 .87667 .58115 .84925 .54792 Metetra
.692 .761 .905 r
.84925 .54792 .87667 .58115 .9072 .57053 .88005 .53596 Metetra
.693 .755 .899 r
.88005 .53596 .9072 .57053 .93794 .55978 .91103 .52381 Metetra
.619 .724 .921 r
.4632 .62183 .49498 .6552 .52332 .64852 .49178 .61592 Metetra
.621 .731 .925 r
.49178 .61592 .52332 .64852 .55189 .64166 .5206 .60979 Metetra
.625 .738 .928 r
.5206 .60979 .55189 .64166 .58068 .63453 .54967 .60328 Metetra
.631 .746 .93 r
.54967 .60328 .58068 .63453 .6097 .62702 .57898 .59626 Metetra
.639 .753 .931 r
.57898 .59626 .6097 .62702 .63895 .61905 .60853 .58859 Metetra
.648 .76 .93 r
.60853 .58859 .63895 .61905 .6684 .61055 .6383 .58019 Metetra
.659 .765 .928 r
.6383 .58019 .6684 .61055 .69806 .60148 .66829 .57099 Metetra
.669 .769 .925 r
.66829 .57099 .69806 .60148 .72793 .59182 .69847 .56096 Metetra
.679 .771 .921 r
.69847 .56096 .72793 .59182 .75798 .58159 .72885 .55014 Metetra
.687 .772 .916 r
.72885 .55014 .75798 .58159 .78822 .57082 .75941 .53856 Metetra
.694 .77 .91 r
.75941 .53856 .78822 .57082 .81865 .55957 .79014 .52631 Metetra
.699 .767 .905 r
.79014 .52631 .81865 .55957 .84925 .54792 .82104 .51351 Metetra
.702 .763 .899 r
.82104 .51351 .84925 .54792 .88005 .53596 .85211 .50031 Metetra
.703 .758 .894 r
.85211 .50031 .88005 .53596 .91103 .52381 .88337 .48685 Metetra
.606 .719 .925 r
.43058 .58756 .4632 .62183 .49178 .61592 .45938 .58226 Metetra
.608 .725 .928 r
.45938 .58226 .49178 .61592 .5206 .60979 .48845 .5767 Metetra
.614 .732 .93 r
.48845 .5767 .5206 .60979 .54967 .60328 .51778 .57068 Metetra
.622 .74 .931 r
.51778 .57068 .54967 .60328 .57898 .59626 .54738 .56402 Metetra
.633 .747 .93 r
.54738 .56402 .57898 .59626 .60853 .58859 .57722 .55657 Metetra
.645 .754 .929 r
.57722 .55657 .60853 .58859 .6383 .58019 .6073 .5482 Metetra
.658 .76 .925 r
.6073 .5482 .6383 .58019 .66829 .57099 .63761 .53884 Metetra
.671 .765 .921 r
.63761 .53884 .66829 .57099 .69847 .56096 .66812 .52845 Metetra
.682 .768 .916 r
.66812 .52845 .69847 .56096 .72885 .55014 .69883 .51707 Metetra
.692 .769 .91 r
.69883 .51707 .72885 .55014 .75941 .53856 .72972 .50475 Metetra
.701 .769 .905 r
.72972 .50475 .75941 .53856 .79014 .52631 .76077 .4916 Metetra
.707 .767 .899 r
.76077 .4916 .79014 .52631 .82104 .51351 .79199 .47778 Metetra
.71 .764 .894 r
.79199 .47778 .82104 .51351 .85211 .50031 .82337 .46346 Metetra
.712 .76 .89 r
.82337 .46346 .85211 .50031 .88337 .48685 .85493 .44884 Metetra
.595 .716 .928 r
.39706 .55236 .43058 .58756 .45938 .58226 .42609 .54746 Metetra
.599 .721 .93 r
.42609 .54746 .45938 .58226 .48845 .5767 .4554 .54227 Metetra
.605 .727 .931 r
.4554 .54227 .48845 .5767 .51778 .57068 .48499 .53656 Metetra
.616 .734 .93 r
.48499 .53656 .51778 .57068 .54738 .56402 .51486 .53011 Metetra
.628 .741 .929 r
.51486 .53011 .54738 .56402 .57722 .55657 .54499 .52275 Metetra
.643 .748 .926 r
.54499 .52275 .57722 .55657 .6073 .5482 .57538 .51433 Metetra
.657 .754 .921 r
.57538 .51433 .6073 .5482 .63761 .53884 .60601 .50478 Metetra
.672 .759 .916 r
.60601 .50478 .63761 .53884 .66812 .52845 .63685 .49404 Metetra
.685 .763 .911 r
.63685 .49404 .66812 .52845 .69883 .51707 .6679 .48215 Metetra
.696 .765 .905 r
.6679 .48215 .69883 .51707 .72972 .50475 .69912 .46919 Metetra
.705 .766 .899 r
.69912 .46919 .72972 .50475 .76077 .4916 .73052 .45527 Metetra
.712 .765 .894 r
.73052 .45527 .76077 .4916 .79199 .47778 .76207 .44058 Metetra
.716 .763 .889 r
.76207 .44058 .79199 .47778 .82337 .46346 .79379 .42533 Metetra
.718 .76 .886 r
.79379 .42533 .82337 .46346 .85493 .44884 .82567 .40974 Metetra
.589 .713 .929 r
.36263 .5162 .39706 .55236 .42609 .54746 .39188 .51145 Metetra
.593 .717 .93 r
.39188 .51145 .42609 .54746 .4554 .54227 .42143 .50639 Metetra
.601 .722 .93 r
.42143 .50639 .4554 .54227 .48499 .53656 .45127 .50077 Metetra
.612 .728 .928 r
.45127 .50077 .48499 .53656 .51486 .53011 .48141 .49435 Metetra
.626 .735 .925 r
.48141 .49435 .51486 .53011 .54499 .52275 .51183 .48694 Metetra
.641 .741 .922 r
.51183 .48694 .54499 .52275 .57538 .51433 .54252 .47839 Metetra
.657 .747 .917 r
.54252 .47839 .57538 .51433 .60601 .50478 .57346 .4686 Metetra
.672 .753 .911 r
.57346 .4686 .60601 .50478 .63685 .49404 .60464 .45752 Metetra
.686 .757 .905 r
.60464 .45752 .63685 .49404 .6679 .48215 .63602 .4452 Metetra
.698 .76 .9 r
.63602 .4452 .6679 .48215 .69912 .46919 .66759 .4317 Metetra
.708 .761 .894 r
.66759 .4317 .69912 .46919 .73052 .45527 .69934 .41718 Metetra
.715 .762 .889 r
.69934 .41718 .73052 .45527 .76207 .44058 .73125 .40181 Metetra
.72 .761 .886 r
.73125 .40181 .76207 .44058 .79379 .42533 .76333 .38584 Metetra
.722 .76 .883 r
.76333 .38584 .79379 .42533 .82567 .40974 .79557 .36951 Metetra
.586 .712 .93 r
.32723 .47902 .36263 .5162 .39188 .51145 .35671 .47416 Metetra
.591 .715 .93 r
.35671 .47416 .39188 .51145 .42143 .50639 .3865 .46897 Metetra
.599 .719 .928 r
.3865 .46897 .42143 .50639 .45127 .50077 .4166 .46321 Metetra
.611 .724 .925 r
.4166 .46321 .45127 .50077 .48141 .49435 .447 .45663 Metetra
.626 .729 .922 r
.447 .45663 .48141 .49435 .51183 .48694 .47771 .44901 Metetra
.641 .735 .917 r
.47771 .44901 .51183 .48694 .54252 .47839 .5087 .44022 Metetra
.657 .741 .912 r
.5087 .44022 .54252 .47839 .57346 .4686 .53995 .43015 Metetra
.672 .746 .906 r
.53995 .43015 .57346 .4686 .60464 .45752 .57146 .41875 Metetra
.686 .75 .9 r
.57146 .41875 .60464 .45752 .63602 .4452 .60318 .40606 Metetra
.698 .754 .895 r
.60318 .40606 .63602 .4452 .66759 .4317 .63511 .39216 Metetra
.708 .756 .89 r
.63511 .39216 .66759 .4317 .69934 .41718 .66722 .3772 Metetra
.715 .758 .886 r
.66722 .3772 .69934 .41718 .73125 .40181 .6995 .36137 Metetra
.72 .759 .883 r
.6995 .36137 .73125 .40181 .76333 .38584 .73195 .34492 Metetra
.723 .759 .881 r
.73195 .34492 .76333 .38584 .79557 .36951 .76458 .32809 Metetra
.589 .713 .929 r
.29083 .44079 .32723 .47902 .35671 .47416 .32055 .43553 Metetra
.593 .714 .928 r
.32055 .43553 .35671 .47416 .3865 .46897 .35059 .42995 Metetra
.602 .716 .925 r
.35059 .42995 .3865 .46897 .4166 .46321 .38095 .42379 Metetra
.613 .72 .921 r
.38095 .42379 .4166 .46321 .447 .45663 .41162 .41683 Metetra
.627 .724 .917 r
.41162 .41683 .447 .45663 .47771 .44901 .44261 .40885 Metetra
.642 .729 .912 r
.44261 .40885 .47771 .44901 .5087 .44022 .4739 .39971 Metetra
.657 .734 .906 r
.4739 .39971 .5087 .44022 .53995 .43015 .50546 .38931 Metetra
.672 .739 .901 r
.50546 .38931 .53995 .43015 .57146 .41875 .53729 .3776 Metetra
.685 .743 .896 r
.53729 .3776 .57146 .41875 .60318 .40606 .56936 .36462 Metetra
.696 .747 .891 r
.56936 .36462 .60318 .40606 .63511 .39216 .60164 .35046 Metetra
.706 .751 .887 r
.60164 .35046 .63511 .39216 .66722 .3772 .63412 .33524 Metetra
.713 .753 .884 r
.63412 .33524 .66722 .3772 .6995 .36137 .66679 .31917 Metetra
.718 .756 .882 r
.66679 .31917 .6995 .36137 .73195 .34492 .69963 .30249 Metetra
.721 .757 .881 r
.69963 .30249 .73195 .34492 .76458 .32809 .73265 .28543 Metetra
.595 .716 .928 r
.25338 .40146 .29083 .44079 .32055 .43553 .28337 .39552 Metetra
.6 .715 .925 r
.28337 .39552 .32055 .43553 .35059 .42995 .31367 .38927 Metetra
.608 .716 .921 r
.31367 .38927 .35059 .42995 .38095 .42379 .3443 .38248 Metetra
.618 .718 .917 r
.3443 .38248 .38095 .42379 .41162 .41683 .37525 .37492 Metetra
.631 .72 .912 r
.37525 .37492 .41162 .41683 .44261 .40885 .40652 .36642 Metetra
.644 .724 .907 r
.40652 .36642 .44261 .40885 .4739 .39971 .4381 .35682 Metetra
.657 .728 .901 r
.4381 .35682 .4739 .39971 .50546 .38931 .46998 .34605 Metetra
.671 .732 .896 r
.46998 .34605 .50546 .38931 .53729 .3776 .50213 .33405 Metetra
.683 .736 .891 r
.50213 .33405 .53729 .3776 .56936 .36462 .53453 .32086 Metetra
.693 .741 .888 r
.53453 .32086 .56936 .36462 .60164 .35046 .56717 .30656 Metetra
.702 .745 .884 r
.56717 .30656 .60164 .35046 .63412 .33524 .60002 .29127 Metetra
.709 .748 .882 r
.60002 .29127 .63412 .33524 .66679 .31917 .63307 .27518 Metetra
.714 .752 .882 r
.63307 .27518 .66679 .31917 .69963 .30249 .66632 .2585 Metetra
.717 .754 .882 r
.66632 .2585 .69963 .30249 .73265 .28543 .69976 .24147 Metetra
.606 .719 .925 r
.21484 .36098 .25338 .40146 .28337 .39552 .24512 .3541 Metetra
.61 .717 .921 r
.24512 .3541 .28337 .39552 .31367 .38927 .27571 .34693 Metetra
.616 .716 .917 r
.27571 .34693 .31367 .38927 .3443 .38248 .30662 .33927 Metetra
.625 .716 .912 r
.30662 .33927 .3443 .38248 .37525 .37492 .33786 .33093 Metetra
.636 .718 .907 r
.33786 .33093 .37525 .37492 .40652 .36642 .36942 .32174 Metetra
.647 .72 .901 r
.36942 .32174 .40652 .36642 .4381 .35682 .4013 .31159 Metetra
.658 .723 .897 r
.4013 .31159 .4381 .35682 .46998 .34605 .43348 .3004 Metetra
.669 .726 .892 r
.43348 .3004 .46998 .34605 .50213 .33405 .46595 .28812 Metetra
.68 .73 .888 r
.46595 .28812 .50213 .33405 .53453 .32086 .49868 .27479 Metetra
.689 .734 .885 r
.49868 .27479 .53453 .32086 .56717 .30656 .53167 .26047 Metetra
.697 .739 .883 r
.53167 .26047 .56717 .30656 .60002 .29127 .56489 .24528 Metetra
.703 .743 .882 r
.56489 .24528 .60002 .29127 .63307 .27518 .59833 .22936 Metetra
.708 .747 .883 r
.59833 .22936 .63307 .27518 .66632 .2585 .63199 .21293 Metetra
.711 .751 .884 r
.63199 .21293 .66632 .2585 .69976 .24147 .66586 .19616 Metetra
.619 .724 .921 r
.17516 .3193 .21484 .36098 .24512 .3541 .20576 .31124 Metetra
.622 .72 .917 r
.20576 .31124 .24512 .3541 .27571 .34693 .23666 .30292 Metetra
.627 .718 .912 r
.23666 .30292 .27571 .34693 .30662 .33927 .26787 .29419 Metetra
.634 .716 .907 r
.26787 .29419 .30662 .33927 .33786 .33093 .29941 .28488 Metetra
.642 .716 .902 r
.29941 .28488 .33786 .33093 .36942 .32174 .33128 .27488 Metetra
.65 .716 .897 r
.33128 .27488 .36942 .32174 .4013 .31159 .36346 .26408 Metetra
.659 .718 .892 r
.36346 .26408 .4013 .31159 .43348 .3004 .39594 .25242 Metetra
.668 .721 .889 r
.39594 .25242 .43348 .3004 .46595 .28812 .42873 .23987 Metetra
.676 .724 .886 r
.42873 .23987 .46595 .28812 .49868 .27479 .46179 .22646 Metetra
.683 .728 .884 r
.46179 .22646 .49868 .27479 .53167 .26047 .49512 .21223 Metetra
.69 .733 .883 r
.49512 .21223 .53167 .26047 .56489 .24528 .52871 .19727 Metetra
.695 .737 .883 r
.52871 .19727 .56489 .24528 .59833 .22936 .56253 .18172 Metetra
.699 .742 .885 r
.56253 .18172 .59833 .22936 .63199 .21293 .59659 .16572 Metetra
.702 .747 .887 r
.59659 .16572 .63199 .21293 .66586 .19616 .63089 .14942 Metetra
.634 .729 .916 r
.13429 .27638 .17516 .3193 .20576 .31124 .16524 .26693 Metetra
.636 .724 .911 r
.16524 .26693 .20576 .31124 .23666 .30292 .19648 .25727 Metetra
.639 .72 .906 r
.19648 .25727 .23666 .30292 .26787 .29419 .22803 .24729 Metetra
.643 .717 .901 r
.22803 .24729 .26787 .29419 .29941 .28488 .25989 .23688 Metetra
.648 .715 .897 r
.25989 .23688 .29941 .28488 .33128 .27488 .29207 .22594 Metetra
.654 .714 .893 r
.29207 .22594 .33128 .27488 .36346 .26408 .32455 .21442 Metetra
.66 .715 .889 r
.32455 .21442 .36346 .26408 .39594 .25242 .35735 .20226 Metetra
.666 .717 .886 r
.35735 .20226 .39594 .25242 .42873 .23987 .39044 .18944 Metetra
.672 .719 .885 r
.39044 .18944 .42873 .23987 .46179 .22646 .42383 .17599 Metetra
.677 .723 .884 r
.42383 .17599 .46179 .22646 .49512 .21223 .45749 .16193 Metetra
.682 .727 .884 r
.45749 .16193 .49512 .21223 .52871 .19727 .49143 .14732 Metetra
.686 .732 .885 r
.49143 .14732 .52871 .19727 .56253 .18172 .52563 .13226 Metetra
.689 .737 .888 r
.52563 .13226 .56253 .18172 .59659 .16572 .56009 .11685 Metetra
.691 .743 .891 r
.56009 .11685 .59659 .16572 .63089 .14942 .59481 .1012 Metetra
.65 .734 .91 r
.09217 .23214 .13429 .27638 .16524 .26693 .12351 .22117 Metetra
.651 .728 .906 r
.12351 .22117 .16524 .26693 .19648 .25727 .15512 .21003 Metetra
.652 .723 .901 r
.15512 .21003 .19648 .25727 .22803 .24729 .18703 .19868 Metetra
.653 .719 .896 r
.18703 .19868 .22803 .24729 .25989 .23688 .21924 .18705 Metetra
.656 .716 .892 r
.21924 .18705 .25989 .23688 .29207 .22594 .25174 .17509 Metetra
.658 .714 .889 r
.25174 .17509 .29207 .22594 .32455 .21442 .28455 .16278 Metetra
.661 .713 .887 r
.28455 .16278 .32455 .21442 .35735 .20226 .31765 .15009 Metetra
.664 .713 .885 r
.31765 .15009 .35735 .20226 .39044 .18944 .35106 .137 Metetra
.667 .715 .884 r
.35106 .137 .39044 .18944 .42383 .17599 .38475 .12352 Metetra
.67 .718 .885 r
.38475 .12352 .42383 .17599 .45749 .16193 .41874 .10968 Metetra
.673 .722 .886 r
.41874 .10968 .45749 .16193 .49143 .14732 .45302 .0955 Metetra
.675 .726 .888 r
.45302 .0955 .49143 .14732 .52563 .13226 .48758 .08103 Metetra
.677 .732 .891 r
.48758 .08103 .52563 .13226 .56009 .11685 .52242 .06632 Metetra
.679 .738 .895 r
.52242 .06632 .56009 .11685 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12351 .22117 .08051 .17394 Metetra
.665 .732 .9 r
.08051 .17394 .12351 .22117 .15512 .21003 .11254 .16124 Metetra
.664 .726 .896 r
.11254 .16124 .15512 .21003 .18703 .19868 .14483 .14843 Metetra
.664 .721 .892 r
.14483 .14843 .18703 .19868 .21924 .18705 .1774 .13551 Metetra
.663 .717 .889 r
.1774 .13551 .21924 .18705 .25174 .17509 .21025 .12249 Metetra
.663 .714 .886 r
.21025 .12249 .25174 .17509 .28455 .16278 .24339 .10934 Metetra
.662 .712 .885 r
.24339 .10934 .28455 .16278 .31765 .15009 .27681 .09609 Metetra
.662 .712 .885 r
.27681 .09609 .31765 .15009 .35106 .137 .31052 .08272 Metetra
.662 .712 .885 r
.31052 .08272 .35106 .137 .38475 .12352 .34452 .06923 Metetra
.663 .714 .886 r
.34452 .06923 .38475 .12352 .41874 .10968 .37882 .05563 Metetra
.663 .717 .889 r
.37882 .05563 .41874 .10968 .45302 .0955 .41342 .04191 Metetra
.664 .721 .892 r
.41342 .04191 .45302 .0955 .48758 .08103 .44833 .02806 Metetra
.664 .726 .896 r
.44833 .02806 .48758 .08103 .52242 .06632 .48355 .01409 Metetra
.665 .732 .9 r
.48355 .01409 .52242 .06632 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^nKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZk
iP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^nH00ol0003oZ[_Vo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^nH00ol0003oZ[_VojZkiP03ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onY^NGo0000ojZkiP09
ojZkiP05o`000?nZ^nKoZ[_VojZki_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojViiOl0003oZKWU00;oZKWU
00?o0000ojZki_nZ^nH01onZ^nH00ol0003oZ[_VojZkiP02ojZkiP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nY^ND00ol0003oZ[_VojZkiP06ojZkiP03o`000?nZ^nKoZ[_V00?oZ[_V00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojVii@03o`000?nZ^nKoZ[_V00GoZ[_V00?o0000
ojZki_nZ^nH00onZ^nH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZKWU00?o0000ojZk
i_nZ^nH01OnZ^nH00ol0003oZ[_VojZkiP04ojZkiP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY^>@00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^nKoZ[_V00CoZ[_V00?o0000ojZki_nZ
^nH01OnZ^nH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKST00?o0000ojVi
iOnY^ND02_nY^ND00ol0003oZ[_VojZkiP03ojZkiP03o`000?nZ^nKoZ[_V00KoZ[_V00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY^>Co0000ojVhi00:ojVhi003o`000?nY^NGo
ZKWU00[oZKWU00?o0000ojZki_nZ^nH00_nZ^nH00ol0003oZ[_VojZkiP06ojZkiP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY]n?o0000ojVhi?nY^>Co000000[oZKST00?o0000ojViiOnY^ND0
2_nY^ND00ol0003oZ[_VojZkiP02ojZkiP03o`000?nZ^nKoZ[_V00OoZ[_V00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKOS00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@05
o`000?nZ^nKoZ[_VojZki_l000002_nZ^nH00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKOS
o`000?nY]n<01OnY]n<00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NGoZKWU00[oZKWU00Co0000
ojZki_nZ^nKo00002_nZ^nH2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00002onY]n<00ol0003oZKSTojVhi00<ojVhi003o`000?nY
^NGoZKWU00[oZKWU00?o0000ojZki_l000002?nZ^nH2o`000003ojfliOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
]n<00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NGoZKWU00[oZKWU00?o0000ojZki_l000001OnZ
^nH3o`0000Co[KcU00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVfhP03o`000?nY]^;o000000goZKOS
00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@;o00000onZ^nH2o`0000So[KcU
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVfhP03o`000?nY]n?oZKOS00_oZKOS00?o
0000ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@0:ojVii@04o`000?nZ^nKo0000o`0000_o[KcU
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVfhP03o`000?nY]n?oZKOS00[oZKOS00?o
0000ojVhi?nY^>@03?nY^>@00ol0003oZKWUojVii@09ojVii@;o00003On]_>D2o`0008oooooo0029
ooooo`Co000000?oZKKRo`000?nY]^802OnY]^800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojViiOnY^ND01_nY^ND5o`0000ko[KcU00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY]^;o0000ojVfhP0<ojVfhP03o`000?nY]n?oZKOS00_oZKOS00?o0000
ojVhi?nY^>@02onY^>@00ol0003oZKWUojVii@03ojVii@;o00000on]^n@00ol0003o[K_To`00000>
ojfli@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZKKR00?o0000ojVfh_nY]^802onY]^80
0ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>CoZKST00coZKST00?o0000ojViiOl000000_l00005
ojfki004o`000?n]^nCo[K_To`0000ko[KcU00?o0000ooooooooool0Roooool0053ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003ojVfh_l0003oZKKR00KoZKKR00?o
0000ojVfh_nY]^802onY]^800ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>CoZKST00_oZKST0_l0
0008ojfki005o`000?n]^nCo[K_Tojfki?l000003On]_>D2o`0008cooooo001@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`?o00001OnY]^800ol0003o
ZKKRojVfhP05ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghonY]n<02_nY]n<00ol0003o
ZKSTojVhi008ojVhi0;o000000?o[;WSo`000?n]^n@01on]^n@00ol0003o[K_Tojfki002ojfki003
o`000?n]_>Go[KcU00_o[KcU0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojVfh_l0003oZKKR00coZKKR00?o0000ojVf
h_nY]^802onY]^800ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>CoZKST00CoZKST0ol00004ojbi
h`03o`000?n]^nCo[K_T00Go[K_T00?o0000ojfki?n]^n@00_n]^n@00ol0003o[KcUojfli@0<ojfl
i@03o`000?oooooooooo08Wooooo001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`00000Fooooo`?o00000_nY]^801?l0003oZKKRojVfh_l0000=ojVfhP03o`000?nY]^;o
ZKKR00_oZKKR00?o0000ojVghonY]n<02_nY]n<00ol0003oZKSTojVhi002ojVhi0;o00002?n/^N<0
0ol0003o[K_Tojfki004ojfki003o`000?n]^nCo[K_T00?o[K_T00?o0000ojfliOn]_>D03?n]_>D0
0ol0003oooooooooo`28ooooo`00D?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000005?ooool3o`0000SoZKKR00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;
ojVfhP03o`000?nY]n?oZKOS00[oZKOS00Co0000ojVhi?l0003o00002_n/^N<00ol0003o[K_Tojfk
i004ojfki003o`000?n]^nCo[K_T00Co[K_T00?o0000ojfliOn]_>D02on]_>D2o`0008Wooooo001@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY
]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghonY]n<02OnY
]n<2o`0000go[;WS00?o0000ojfki?n]^n@00on]^n@00ol0003o[K_Tojfki005ojfki003o`000?n]
_>Go[KcU00_o[KcU0_l00028ooooo`00Loooool3o`000003ojVfh_l0003o000000_oZKKR00?o0000
ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]n?oZKOS00KoZKOS0ol00000
0on/^>;o0000ojbih`0=ojbih`03o`000?n]^nCo[K_T00;o[K_T00?o0000ojfki?n]^n@01_n]^n@0
0ol0003o[KcUojfli@0;ojfli@;o0000Qoooool0073ooooo0ol00005ojVfhP03o`000?nY]^;oZKKR
00[oZKKR00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]n?oZKOS
00?oZKOS0_l00005ojbhhP03o`000?n/^N?o[;WS00_o[;WS00?o0000ojfki?n]^n@00_n]^n@00ol0
003o[K_Tojfki006ojfki003o`000?n]_>Go[KcU00Wo[KcU0_l000000on`_^Co0000ooooo`26oooo
o`00K_ooool3o`0000SoZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03
o`000?nY]^;oZKKR00_oZKKR00?o0000ojVghol000000_l00008ojbhhP03o`000?n/^N?o[;WS00_o
[;WS00Go0000ojfki?n]^nCo[K_To`000009ojfki003o`000?n]_>Go[KcU00Go[KcU0ol00003ok2n
i0;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02?ooooo0ol00002ojVfhP03o`000?nY]^;oZKKR00KoZKKR00?o0000ojVfh_nY]^802onY]^800ol0
003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00[oZKKR0_l0000<ojbhhP03o`000?n/^N?o[;WS
00_o[;WS00Co0000ojfki?n]^nCo00002_n]^n@00ol0003o[KcUojfli@02ojfli@;o00001on`_^@2
o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oZKKRo`000?nY]^802onY]^800ol0003oZKKRojVf
hP0;ojVfhP03o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801onY]^83o`000003oj^gh_l0
003o[;SR00_o[;SR00?o0000ojbihon/^N<03?n/^N<00ol0003o[K_To`00000;ojfki004o`000?n]
_>Go0000o`0000[o/;kT0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKR
ojVfhP0:ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVfh_nY]^800onY]^83o`0000GoZkOR
00?o0000ojbhh_n/^>802_n/^>800ol0003o[;WSojbih`0;ojbih`03o`000?n]^nCo000000_o[K_T
0_l0000=ok2ni003o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Kooooo`?o00001?nY]^800ol0003oZKKRojVfhP02ojVfhP03o`00
0?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03o`00
0?nY]^;o000000;o00002On[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00_o[;WS
0_l00009ojfki0;o000000?o/;cSo`000?n`_^@03?n`_^@2o`0008?ooooo000cooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00003?nY]^800ol0003oZKKR
ojVfhP09ojVfhP03o`000?nY]^;oZKKR00_oZKKR00?o0000ojVfh_nY]^802_nY]^82o`0000coZkOR
00?o0000ojbhh_n/^>802on/^>800ol0003o[;WSojbih`0;ojbih`03o`000?n]^nCo[K_T00Co[K_T
0ol00004ok2lh`03o`000?n`_^Co/;kT00_o/;kT0_l00022ooooo`00<oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool05?ooool3o`000003ojVghol0003oZKKR00coZKKR
00?o0000ojVfh_nY]^802_nY]^800ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;oZKKR00OoZKKR
0_l000000onZ]n;o0000oj^ghP0<oj^ghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojbihon/^N<0
2on/^N<00ol0003o[K_Tojfki002ojfki0;o00002?n`_><00ol0003o/;kTok2ni00;ok2ni0;o0000
POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41005?ooool3o`0000CoZKOS00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP0:ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801OnY]^82o`0000CoZ[OR00?o0000oj^gh_n[
]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00[o[;WS0_l000000on]^nCo
0000o`00000;ok2lh`03o`000?n`_^Co/;kT00_o/;kT00?o0000ooooooooool0Ooooool003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`00
00SoZKOS00?o0000ojVfh_nY]^802onY]^800ol0003oZKKRojVfhP09ojVfhP03o`000?nY]^;oZKKR
00_oZKKR00?o0000ojVfh_nY]^800_nY]^82o`0000OoZ[OR00?o0000oj^gh_n[]n802_n[]n800ol0
003o[;SRojbhhP0;ojbhhP03o`000?n/^N?o[;WS00Wo[;WS0ol0000=ok2lh`03o`000?n`_^Co/;kT
00_o/;kT0_l00020ooooo`00Eoooool3o`000003ojVghol0003oZKOS00SoZKOS00?o0000ojVfh_nY
]^802onY]^800ol0003oZKKRojVfhP09ojVfhP03o`000?nY]^;oZKKR00_oZKKR00Co0000ojVfh_l0
003o00002OnZ]n800ol0003oZkORoj^ghP0;oj^ghP03o`000?n/^>;o[;SR00_o[;SR00?o0000ojbi
hon/^N<01on/^N<2o`000003ojnkh_l0003o/;cS00go/;cS00?o0000ok2ni?n`_^@02on`_^@2o`00
07oooooo001Dooooo`?o000000?oZKSTo`000?nY]n<03?nY]n<00ol0003oZKKRojVfhP0:ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^802_nY]^82o`0000coZ[OR00?o0000oj^gh_n[
]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00Go[;WS0_l000001On_^n;o
0000ojnkh_n_^n;o000000ko/;cS00?o0000ok2ni?n`_^@02on`_^@00ol0003oooooooooo`1moooo
o`00D_ooool3o`0000CoZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVfhP03
o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801_nY]^83o`000003ojVfh_l0003oZ[OR00co
Z[OR00?o0000oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n/^N?o[;WS00;o
[;WS0_l00003ojnkhP05o`000?n_^n;o[k_Rojnkh_l000003_n`_><00ol0003o/;kTok2ni00;ok2n
i003o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`00
0003ojVhi?l0003oZKST00CoZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVf
hP03o`000?nY]^;oZKKR00WoZKKR00?o0000ojVfh_nY]^800onY]^83o`0000GoZKKR00?o0000ojZg
h_nZ]n802onZ]n800ol0003oZkORoj^ghP0:oj^ghP03o`000?n/^>;o[;SR00_o[;SR00Co0000ojbi
hol0003o00001On_^n800ol0003o[k_RojnkhP02ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000
ok2ni?n`_^@02on`_^@2o`0007gooooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3
o`0000_oZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVfhP0;ojVfhP03o`000?nY]^;o
ZKKR00WoZKKR00?o0000ojVfh_l000000_l00009ojVfhP03o`000?nZ]n;oZ[OR00[oZ[OR00?o0000
oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP0:ojbhhP;o00001on_^n800ol0003o[k_RojnkhP03
ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2ni?n`_^@02on`_^@2o`0007cooooo000Woooo
o`05oa0@4?ooooooooooooooool@41007_ooool5o`0000goZKST00?o0000ojVghonY]n<02_nY]n<0
0ol0003oZKKRojVfhP0:ojVfhP03o`000?nY]^;oZKKR00SoZKKR0ol0000=ojVfhP03o`000?nZ]n;o
Z[OR00[oZ[OR00?o0000oj^gh_n[]n802on[]n800ol0003o[;SRojbhhP06ojbhhP?o000000?o[[[R
o`000?n_^n801_n_^n800ol0003o[k_RojnkhP03ojnkhP03o`000?n`_>?o/;cS00co/;cS00?o0000
ok2ni?n`_^@02?n`_^@2o`000003ok>ohol0003ooooo07_ooooo000Wooooo`05o`000?oooooooooo
ooooool000007?ooool3o`0000;oZKWU00?o0000ojViiOl000003?nY^>@00ol0003oZKOSojVgh`0;
ojVgh`03o`000?nY]^;oZKKR00[oZKKR00?o0000ojVfh_nY]^801?nY]^83o`0000;oZKKS00?o0000
ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0;ojZghP03o`000?n[]n;oZkOR00[oZkOR00?o0000
ojbhh_n/^>800on/^>83o`0000Go[[[R00?o0000ojnkh_n_^n801?n_^n800ol0003o[k_RojnkhP04
ojnkhP03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2ni?n`_^@01On`_^@3o`0000Co/koS00?o0000
ooooooooool0NOooool002Oooooo00Go0000ooooooooooooooooo`00000Iooooo`Co00001OnY^ND0
0ol0003oZKWUo`00000<ojVhi003o`000?nY]n?oZKOS00_oZKOS00?o0000ojVfh_nY]^802_nY]^80
0ol0003oZKKRojVfhP03o`0000KoZKKS00?o0000ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0:
ojZghP03o`000?n[]n;oZkOR00_oZkOR00?o0000ojbhh_l000000_l00009ojjjhP03o`000?n_^n;o
[k_R00?o[k_R00?o0000ojnkh_n_^n801On_^n800ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_^Co
/;kT00;o/;kT0_l00007ok>oh`;o0000N_ooool002Oooooo00Go410@oooooooooooooooooa0@400G
ooooo`?o00002onY^ND00ol0003oZKSTojVhi00:ojVhi003o`000?nY]n?oZKOS00[oZKOS00?o0000
ojVfh_nY]^802_nY]^83o`0000[oZKKS00?o0000ojVfh_nY]^802onY]^800ol0003oZ[ORojZghP0:
ojZghP03o`000?n[]n;oZkOR00[oZkOR0_l0000=ojjjhP03o`000?n_^n;o[k_R00;o[k_R00?o0000
ojnkh_n_^n801_n_^n800ol0003o/;cSok2lh`0;ok2lh`04o`000?n`_^Co0000o`0000[o/koS0_l0
001iooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onY^NGo0000ojVi
i@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<02_nY]n<00ol0003oZKKRojVf
hP06ojVfhP?o000000?oZ;KSo`000?nY]^<02onY]^<00ol0003oZKKRojVfhP0;ojVfhP03o`000?nZ
]n;oZ[OR00[oZ[OR00?o0000oj^gh_n[]n801on[]n82o`000003ojfih_l0003o[[[R00co[[[R00?o
0000ojnkh_n_^n800_n_^n800ol0003o[k_RojnkhP07ojnkhP03o`000?n`_>?o/;cS00[o/;cS0_l0
000=ok>oh`03o`000?oooooooooo07Oooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool3o`0000CoZ[_V00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKSTojVhi00;ojVhi003o`000?nY
]n?oZKOS00[oZKOS00?o0000ojVfh_nY]^800onY]^82o`0000GoZ;KS00?o0000ojVfhonY]^<02_nY
]^<00ol0003oZKKRojVfhP0:ojVfhP03o`000?nZ]n;oZ[OR00_oZ[OR00?o0000oj^gh_n[]n801?n[
]n82o`0000Co[KWR00?o0000ojjjh_n^^^802on^^^801Ol0003o[k_Rojnkh_n_^n;o000000Wo[k_R
00?o0000ok2lhon`_><02?n`_><2o`000003ok:mh_l0003o/koS00go/koS00?o0000ooooooooool0
M_ooool003_ooooo1Ol00006ojZkiP03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVhi?nY^>@02onY
^>@00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY]^;o000000;o00002?nX]^<00ol0003oZKKSojVf
h`09ojVfh`03o`000?nY]^;oZKKR00_oZKKR00?o0000ojZgh_nZ]n802_nZ]n800ol0003oZkORoj^g
hP02oj^ghP;o00001on]^N800ol0003o[[[RojjjhP0;ojjjhP04o`000?n_^n;o[k_Ro`0000[o[k_R
00?o0000ok2lhon`_><01On`_><2o`0000Co/[gR00?o0000ok>ohonc_n<02onc_n<2o`0007Oooooo
000iooooo`?o00002onZ^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o
0000ojVghonY]n<02_nY]n<2o`0000coZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVf
hP0;ojVfhP03o`000?nZ]n;oZ[OR00[oZ[OR00Co0000oj^gh_l0003o00002_n]^N800ol0003o[[[R
ojjjhP0;ojjjhP03o`000?n_^n;o000000_o[k_R00?o0000ok2lhon`_><00_n`_><2o`0000Oo/[gR
00?o0000ok>ohonc_n<02onc_n<2o`0007Kooooo000gooooo`?o000000?oZ[cWo`000?nZ^nH02onZ
^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00[oZKST00?o0000ojVghonY]n<01_nY
]n<3o`000003ojNgi?l0003oZ;KS00coZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVf
hP0;ojVfhP03o`000?nZ]n;oZ[OR00WoZ[OR0_l0000<ojfihP03o`000?n^^^;o[[[R00_o[[[R00?o
0000ojnkh_l000003?n_^n801?l0003o/;cSo`000?l0000:ok:mhP03o`000?nc_n?o/koS00_o/koS
00?o0000ooooooooool0M?ooool003Cooooo0ol000000onZ_>Oo0000ojZli`02ojZli`03o`000?nZ
^nKoZ[_V00[oZ[_V00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKSTojVhi00:ojVhi003o`000?nY
]n?oZKOS00?oZKOS0_l00005ojNgi003o`000?nX]^?oZ;KS00[oZ;KS00?o0000ojVfhonY]^<02_nY
]^<00ol0003oZKKRojVfhP0:ojVfhP03o`000?nZ]n;oZ[OR00KoZ[OR0ol000000on/^>;o0000ojfi
hP0<ojfihP03o`000?n^^^;o[[[R00_o[[[R0_l0000<ojnkhP;o00003?nb_N800ol0003o/koSok>o
h`0<ok>oh`03o`000?oooooooooo07?ooooo000booooo`?o00002?nZ_>L00ol0003oZ[_VojZkiP0:
ojZkiP03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKOSo`000002
o`0000SoYkOT00?o0000ojRfhonX]^<02_nX]^<00ol0003oZKKSojVfh`0:ojVfh`03o`000?nY]^;o
ZKKR00[oZKKR00?o0000ojZgh_nZ]n800onZ]n82o`0000Go[;SR00?o0000ojfih_n]^N802on]^N80
0ol0003o[[[RojjjhP0;ojjjhP03o`000?n_^n;o[k_R00So[k_R0_l000000ona_>;o0000ok:mhP0<
ok:mhP03o`000?nc_n?o/koS00_o/koS0_l0001dooooo`00<Oooool00ol0003oZ[cWojZli`0:ojZl
i`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000ojViiOnY^ND02OnY^ND00ol0003oZKSTojVhi00:ojVh
i0;o00003?nW]n@00ol0003oZ;KSojRfh`0:ojRfh`03o`000?nY]^?oZKKS00[oZKKS00?o0000ojVf
h_nY]^802_nY]^800ol0003oZ[ORo`000002o`0000So[;SR00?o0000ojfih_n]^N802on]^N800ol0
003o[[[RojjjhP0:ojjjhP03o`000?n_^n;o[k_R00Go[k_R0ol00004ok6lhP03o`000?nb_N;o/[gR
00_o/[gR00?o0000ok>ohonc_n<02onc_n<00ol0003oooooooooo`1booooo`00<Oooool2o`0000co
Z[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@0:ojVii@03o`000?nY^>CoZKST00Ko
ZKST0ol000000onW^>Go0000ojNgi00;ojNgi003o`000?nX]^?oZ;KS00_oZ;KS00?o0000ojVfhonY
]^<02OnY]^<00ol0003oZKKRojVfhP0:ojVfhP;o00003?n/^>800ol0003o[KWRojfihP0:ojfihP03
o`000?n^^^;o[[[R00[o[[[R0_l00004ojnkhP;o00002?na_>800ol0003o/[gRok:mhP0;ok:mhP03
o`000?nc_n?o/koS00_o/koS00?o0000ooooooooool0LOooool002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP07ooooo`;o00003OnZ_>L00ol0003oZ[_VojZkiP09ojZkiP03o`000?nY^NGoZKWU00[o
ZKWU00?o0000ojVhi?nY^>@00onY^>@2o`0000GoYkSU00?o0000ojNgi?nW]n@02_nW]n@00ol0003o
Z;KSojRfh`0;ojRfh`03o`000?nY]^?oZKKS00WoZKKS00?o0000ojVfh_nY]^801_nY]^83o`000003
ojZgh_l0003o[;SR00co[;SR00?o0000ojfih_n]^N802_n]^N800ol0003o[[[RojjjhP09ojjjhP04
o`000?n^^^;o0000ojnkhP;o00002ona_>800ol0003o/[gRok:mhP0:ok:mhP03o`000?nc_n?o/koS
00co/koS00?o0000ooooooooool0L?ooool002Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07oooo
o`03o`000?oooooo000000goZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@0:ojVi
i@03o`000?nY^>Co000000;o00002?nW^>D00ol0003oYkOTojNgi00:ojNgi003o`000?nX]^?oZ;KS
00_oZ;KS00?o0000ojVfhonY]^<02OnY]^<00ol0003oZKKRojVfhP03ojVfhP;o00001OnZ]n800ol0
003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00_o[KWR00?o0000ojjjh_n^^^802?n^^^801?l0
003o[[[Ro`000?l0000=ok6lhP03o`000?nb_N;o/[gR00_o/[gR00?o0000ok>ohonc_n<02onc_n<2
o`00077ooooo000Uooooo`05oa0@4?ooooooooooooooool@41001oooool01?l0003oooooooooool0
000=ojZli`03o`000?nZ^nKoZ[_V00WoZ[_V00?o0000ojViiOnY^ND02?nY^ND3o`0000coYkSU00?o
0000ojNgi?nW]n@02_nW]n@00ol0003oZ;KSojRfh`0:ojRfh`03o`000?nY]^?oZKKS00[oZKKS00?o
0000ojVfh_l000000_l00008ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]^N802on]
^N800ol0003o[[[RojjjhP07ojjjhP;o000000?o/;_Ro`000?na_>803Ona_>800ol0003o/[gRok:m
hP0;ok:mhP03o`000?nc_n?o/koS00So/koS0_l000000onf`>;o0000ooooo`1`ooooo`009Oooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l00003ooooo`03o`000?nZ_>OoZ[cW00_oZ[cW00?o
0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@04ojVii@?o00000_nV^NH00ol0003oYkSUojNh
i@0;ojNhi@03o`000?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02onX]^<00ol0003oZKKSojVf
h`08ojVfh`?o00003?nZ]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00[o[KWR00?o
0000ojjjh_n^^^801On^^^83o`0000?o/;_R00?o0000ok6lh_na_>803?na_>800ol0003o/[gRok:m
hP0:ok:mhP03o`000?nc_n?o/koS00Go/koS0ol00004okK0hP03o`000?oooooooooo06kooooo000U
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?nZ
_>OoZ[cW00_oZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZKWUojVii@03o`0000KoY[WV00?o
0000ojNhiOnW^>D02onW^>D00ol0003oYkOTojNgi009ojNgi003o`000?nX]^?oZ;KS00_oZ;KS00?o
0000ojVfhonY]^<01?nY]^<3o`0000;oZ;OS00?o0000ojZgh_nZ]n802onZ]n800ol0003o[;SRojbh
hP0:ojbhhP03o`000?n]^N;o[KWR00[o[KWR00?o0000ojjjh_n^^^800_n^^^82o`0000;o/;_R00?o
0000ok2kh_n`^n800_n`^n800ol0003o/KcRok6lhP0<ok6lhP03o`000?nb_N;o/[gR00[o/[gR00?o
0000ok>ohonc_n<00_nc_n<2o`0000So]/3R00?o0000ooooooooool0KOooool002Gooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojZlionZ_>L02onZ
_>L00ol0003oZ[_VojZkiP08ojZkiP?o00002_nV^NH00ol0003oYkSUojNhi@0;ojNhi@03o`000?nW
]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02onX]^<00ol0003oZKKSojVfh`03o`0000KoZ;OS00?o
0000ojZgh_nZ]n802_nZ]n800ol0003o[;SRojbhhP0;ojbhhP03o`000?n]^N;o[KWR00[o[KWR00Co
0000ojjjh_l0003o00001?n`^n800ol0003o/;_Rok2khP03ok2khP03o`000?na_>;o/KcR00_o/KcR
00?o0000ok:mh_nb_N802onb_N801?l0003o/koSo`000?l0000:okK0hP;o0000K_ooool002Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ojZlionZ
_>L02onZ_>L00ol0003oZ[_VojZkiP04ojZkiP?o000000?oY[[Wo`000?nV^NH02onV^NH00ol0003o
YkSUojNhi@0;ojNhi@03o`000?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<02_nX]^<3o`0000[o
Z;OS00?o0000ojZgh_nZ]n802_nZ]n800ol0003o[;SRojbhhP0:ojbhhP03o`000?n]^N;o[KWR00[o
[KWR0_l00006ok2khP03o`000?n`^n;o/;_R00Co/;_R00?o0000ok6lh_na_>802ona_>800ol0003o
/[gRok:mhP0:ok:mhP;o00003Onf`>800ol0003oooooooooo`1/ooooo`009Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003oZ[cWojZli`0;ojZli`03
o`000?nZ^nKoZ[_V00?o00001OnV^^L00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>GoYkSU00[o
YkSU00?o0000ojNgi?nW]n@02OnW]n@00ol0003oZ;KSojRfh`07ojRfh`?o000000?oYkKTo`000?nX
]n<02onX]n<00ol0003oZ[ORojZghP0:ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]
^N801_n]^N83o`000003ojjjh_l0003o/;_R00Go/;_R00?o0000ok2kh_n`^n801?n`^n800ol0003o
/KcRok6lhP0<ok6lhP03o`000?nb_N;o/[gR00Oo/[gR0_l000000one_n;o0000okK0hP0=okK0hP03
o`000?oooooooooo06_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ojZlionZ_>L0
2_nZ_>L3o`0000WoY[[W00?o0000ojJii_nV^NH02_nV^NH00ol0003oYkSUojNhi@0:ojNhi@03o`00
0?nW]nCoYkOT00WoYkOT00?o0000ojRfhonX]^<00onX]^<3o`0000GoYkKT00?o0000ojRghonX]n<0
2OnX]n<00ol0003oZ[ORojZghP0;ojZghP03o`000?n/^>;o[;SR00[o[;SR00?o0000ojfih_n]^N80
0on]^N82o`0000Go[[[R00?o0000ok2kh_n`^n800on`^n800ol0003o/;_Rok2khP05ok2khP03o`00
0?na_>;o/KcR00_o/KcR00?o0000ok:mh_nb_N801Onb_N82o`0000Co]KoR00?o0000okK0h_nf`>80
3?nf`>800ol0003oooooooooo`1Zooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`000?nZ
_>OoZ[cW00KoZ[cW0ol000000onV^nSo0000ojJji`0:ojJji`03o`000?nV^NKoY[WV00[oY[WV00?o
0000ojNhiOnW^>D02_nW^>D00ol0003oYkOTojNgi009ojNgi003o`000?nX]^?o000000;o00002OnW
]^@00ol0003oZ;OSojRgh`09ojRgh`03o`000?nZ]n;oZ[OR00_oZ[OR00?o0000ojbhh_n/^>802_n/
^>800ol0003o[KWRo`000002o`0000So[[[R00?o0000ok2kh_n`^n800_n`^n800ol0003o/;_Rok2k
hP06ok2khP03o`000?na_>;o/KcR00_o/KcR00?o0000ok:mh_nb_N800_nb_N82o`0000Oo]KoR00?o
0000okK0h_nf`>802onf`>800ol0003oooooooooo`1Zooooo`00;oooool2o`0000_ooooo00?o0000
ojZlionZ_>L00onZ_>L2o`0000GoY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:
ojJiiP03o`000?nW^>GoYkSU00[oYkSU00?o0000ojNgi?nW]n@02?nW]n@2o`0000coYkKT00?o0000
ojRghonX]n<02_nX]n<00ol0003oZ[ORojZghP0:ojZghP03o`000?n/^>;o[;SR00[o[;SR0_l0000<
ojjjhP05o`000?n`^n;o/;_Rok2kh_l000002On`^n800ol0003o/KcRok6lhP0;ok6lhP04o`000?nb
_N;o0000o`0000[o]KoR00?o0000okK0h_nf`>802onf`>800ol0003oooooooooo`1Yooooo`00<?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?nZ_>Oo000000;o00002?nV^nP00ol0003oY[[WojJj
i`09ojJji`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNhiOnW^>D02_nW^>D00ol0003oYkOTojNg
i004ojNgi0?o000000?oYKOUo`000?nW]^@03?nW]^@00ol0003oZ;OSojRgh`0:ojRgh`03o`000?nZ
]n;oZ[OR00[oZ[OR00?o0000ojbhh_n/^>801_n/^>83o`000003ojfih_l0003o[[[R00_o[[[R00Go
0000ok2kh_n`^n;o/;_Ro`00000:ok2khP03o`000?na_>;o/KcR00[o/KcR0_l0000=okFohP03o`00
0?nf`>;o]/3R00_o]/3R00?o0000ooooooooool0J?ooool002oooooo00?o0000ooooooooool03?oo
ool00ol0003oY[_XojJkj00:ojJkj003o`000?nV^^OoY[[W00WoY[[W00?o0000ojJii_nV^NH02_nV
^NH00ol0003oYkSUojNhi@0:ojNhi@03o`000?nW]nCoYkOT00?o00001OnU]nD00ol0003oYkKTojNf
i00;ojNfi003o`000?nX]n?oZ;OS00WoZ;OS00?o0000ojZgh_nZ]n802onZ]n800ol0003o[;SRojbh
hP03ojbhhP;o00001On]^N800ol0003o[[[RojjjhP0:ojjjhP04o`000?n`^n;o/;_Ro`0000[o/;_R
00?o0000ok6lh_na_>802?na_>82o`000003ok>nhOl0003o]KoR00co]KoR00?o0000okK0h_nf`>80
3?nf`>800ol0003oooooooooo`1Wooooo`00;oooool00ol0003oooooooooo`0=ooooo`03o`000?nV
^nSoY[_X00[oY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW
^>GoYkSU00SoYkSU1?l00009ojFgi@03o`000?nW]^CoYkKT00[oYkKT00?o0000ojRghonX]n<02_nX
]n<00ol0003oZ[ORojZghP0;ojZghP03o`000?n/^>;o000000;o00002?n]^N800ol0003o[[[Rojjj
hP0:ojjjhP03o`000?n`^n;o000000_o/;_R00?o0000ok6lh_na_>801Ona_>82o`0000Co/kkQ00?o
0000okFoh_ne_n802one_n800ol0003o]/3RokK0hP0;okK0hP03o`000?oooooooooo06Oooooo000_
ooooo`03o`000?oooooooooo00kooooo00?o0000ojJkj?nV^nP02OnV^nP00ol0003oY[[WojJji`09
ojJji`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojNhiOnW^>D01?nW^>D3o`0000;oY;OV00?o0000
ojFgiOnU]nD02OnU]nD00ol0003oYkKTojNfi00:ojNfi003o`000?nX]n?oZ;OS00[oZ;OS00?o0000
ojZgh_nZ]n802_nZ]n82o`0000co[KWR00?o0000ojjjh_n^^^802_n^^^82o`0000co/;_R00?o0000
ok6lh_na_>800_na_>82o`0000Oo/kkQ00?o0000okFoh_ne_n802one_n800ol0003o]/3RokK0hP0;
okK0hP03o`000?oooooooooo06Kooooo000_ooooo`03o`000?oooooooooo00oooooo00?o0000ojJk
j?nV^nP02OnV^nP00ol0003oY[[WojJji`09ojJji`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojNh
iOnW^>D00ol00006ojBgiP03o`000?nU]nGoYKOU00WoYKOU00?o0000ojNfi?nW]^@02_nW]^@00ol0
003oZ;OSojRgh`09ojRgh`03o`000?nZ]n;oZ[OR00OoZ[OR0ol000000on[^>?o0000ojfihP0;ojfi
hP03o`000?n^^^;o[[[R00[o[[[R0_l0000=ok2khP04o`000?na_>;o0000o`0000[o/kkQ00?o0000
okFoh_ne_n802one_n800ol0003o]/3RokK0hP0:okK0hP;o0000Ioooool002kooooo0ol0000Aoooo
o`03o`000?nV^nSoY[_X00WoY[_X00?o0000ojJjionV^^L02OnV^^L00ol0003oY[WVojJiiP0:ojJi
iP?o00002_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^CoYkKT00[oYkKT00?o0000ojRg
honX]n<02OnX]n<00ol0003oZ[ORojZghP03ojZghP?o00001On[^><00ol0003o[KWRojfihP0:ojfi
hP03o`000?n^^^;o[[[R00[o[[[R00?o0000ok2kh_n`^n802on`^n82o`0000go/kkQ00?o0000okFo
h_ne_n802_ne_n800ol0003o]/3RokK0hP08okK0hP;o000000?o]l7Qo`000?l00000I_ooool002oo
oooo00?o0000ooooooooool04Oooool00ol0003oY[_XojJkj009ojJkj003o`000?nV^^OoY[[W00Wo
Y[[W00?o0000ojJii_nV^NH01_nV^NH3o`000003oj>hiol0003oY;OV00_oY;OV00?o0000ojFgiOnU
]nD02OnU]nD00ol0003oYkKTojNfi009ojNfi003o`000?nX]n?oZ;OS00[oZ;OS00?o0000ojZgh_l0
00000_l00009oj^hh`03o`000?n]^N;o[KWR00[o[KWR00?o0000ojjjh_n^^^802On^^^82o`0000[o
/;_R0_l000000onb_N;o0000ok>nh@0<ok>nh@03o`000?ne_n;o]KoR00_o]KoR00?o0000okK0h_nf
`>801Onf`>82o`0000Co]l7Q00?o0000ooooooooool0I?ooool002oooooo00?o0000ooooooooool0
4_ooool00ol0003oY[_XojJkj009ojJkj003o`000?nV^^OoY[[W00WoY[[W00?o0000ojJii_nV^NH0
0onV^NH2o`0000GoXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`00
0?nW]^CoYkKT00WoYkKT00?o0000ojRghonX]n<02OnX]n<2o`0000goZkSS00?o0000ojfih_n]^N80
2_n]^N800ol0003o[[[RojjjhP08ojjjhP;o00001on`^n83o`0000Co/[gR00?o0000ok>nhOnc_^40
2onc_^400ol0003o]KoRokFohP0;okFohP03o`000?nf`>;o]/3R00;o]/3R0_l00007okO1h@03o`00
0?oooooooooo06?ooooo000_ooooo`03o`000?oooooooooo01?ooooo00?o0000ojJkj?nV^nP02?nV
^nP00ol0003oY[[WojJji`0:ojJji`03o`000?nV^NKo000000;o00002?nS^>L00ol0003oY;OVojBg
iP09ojBgiP03o`000?nU]nGoYKOU00WoYKOU00?o0000ojNfi?nW]^@02_nW]^@00ol0003oZ;OSojRg
h`05ojRgh`?o000000?oZ;OTo`000?n[^><03?n[^><00ol0003o[KWRojfihP0:ojfihP03o`000?n^
^^;o[[[R00So[[[R00?o0000ojjjh_l000001?n`^n82o`0000So/[gR00?o0000ok>nhOnc_^402onc
_^400ol0003o]KoRokFohP0;okFohP04o`000?nf`>;o0000o`0000[o]l7Q00?o0000ooooooooool0
H_ooool002oooooo00?o0000ooooooooool04oooool2o`0000[oY[_X00?o0000ojJjionV^^L02?nV
^^L3o`0000coXkSW00?o0000ojBgi_nT]nH02OnT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW
]^CoYkKT00WoYkKT00?o0000ojRghonX]n<00onX]n<2o`0000GoZ;OT00?o0000oj^hhon[^><02on[
^><00ol0003o[KWRojfihP0:ojfihP03o`000?n^^^;o[[[R00Oo[[[R00Go0000ojjjh_n^^^;o0000
ok2khP02o`0000_o/[gR00?o0000ok>nhOnc_^402onc_^400ol0003o]KoRokFohP0:okFohP;o0000
3?ng`N42o`0006?ooooo000^ooooo`03o`000?oooooooooo01Gooooo0_l0000:ojJkj003o`000?nV
^^OoY[[W00CoY[[W0ol00002oj:ij@03o`000?nS^>OoXkSW00_oXkSW00?o0000ojBgi_nT]nH02OnT
]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^CoYkKT00WoYkKT00?o0000ojRghol000000_l0
0008ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802_n]^N800ol0003o[[[Rojjj
hP06ojjjhP03o`000?n^^^;o[[[R00;o00003Onb_N800ol0003o/kkQok>nh@0;ok>nh@03o`000?ne
_n;o]KoR00So]KoR0_l000000onf`>7o0000okO1h@0<okO1h@03o`000?oooooooooo067ooooo000^
ooooo`?o00005_ooool2o`0000[oY[_X00?o0000ojJjionV^^L00ol00006oj:ij@03o`000?nS^>Oo
XkSW00[oXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFgi@03o`000?nW]^Co
YkKT00SoYkKT0_l0000<ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802On]^N80
0ol0003o[[[RojjjhP06ojjjhP?o000000?o/;_Ro`000?nb_N803Onb_N800ol0003o/kkQok>nh@0;
ok>nh@03o`000?ne_n;o]KoR00Go]KoR0_l00004okK0h@03o`000?ng`N7o]l7Q00_o]l7Q00?o0000
ooooooooool0H?ooool002kooooo00?o0000ooooooooool05oooool2o`0000SoY[_X1?l0000:oj:i
j@03o`000?nS^>OoXkSW00[oXkSW00?o0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@09ojFg
i@03o`000?nW]^CoYkKT00CoYkKT0ol000000onV]nGo0000ojRgi00<ojRgi003o`000?n[^>?oZkSS
00[oZkSS00?o0000ojfih_n]^N802_n]^N800ol0003o[[[RojjjhP03ojjjhP?o00001?n`^n800ol0
003o/[gRok:mhP0<ok:mhP03o`000?nc_^7o/kkQ00_o/kkQ00?o0000okFoh_ne_n800_ne_n82o`00
00Oo]/3Q00?o0000okO1hOng`N402ong`N400ol0003oooooooooo`1Oooooo`004_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001oooool00ol0003oooooooooo`0Hoooo
o`;o00000_nV^nP5o`0000?oX[[Z00?o0000oj:ijOnR^NT02OnR^NT00ol0003oXkSWoj>hi`0:oj>h
i`03o`000?nT]nKoY;OV00WoY;OV00?o0000ojFgiOnU]nD02_nU]nD00ol0003oYkKTojNfi003o`00
00GoY[OU00?o0000ojRgi?nX]n@02_nX]n@00ol0003oZkSSoj^hh`0;oj^hh`03o`000?n]^N;o[KWR
00[o[KWR00?o0000ojjjh_l000000_l00002ok2khP03o`000?n`^n;o/;_R00?o/;_R00?o0000ok:m
h_nb_N802onb_N800ol0003o/kkQok>nh@0<ok>nh@04o`000?ne_n;o0000o`0000[o]/3Q00?o0000
okO1hOng`N402ong`N400ol0003oooooooooo`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00ol0003ooooooooo
o`0Iooooo`?o00002OnR^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o
0000ojBgi_nT]nH02OnT]nH00ol0003oYKOUojFgi@08ojFgi@Co00002OnV]nD00ol0003oZ;OTojRg
i00:ojRgi003o`000?n[^>?oZkSS00_oZkSS00?o0000ojfih_n]^N802On]^N82o`0000Go/;_R00?o
0000ok2kh_n`^n801?n`^n800ol0003o/[gRok:mhP0;ok:mhP03o`000?nc_^7o/kkQ00_o/kkQ0_l0
000<okK0h@03o`000?ng`N7o]l7Q00_o]l7Q00?o0000ooooooooool0G_ooool001;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool06_oo
ool00ol0003oX[[Zoj:jjP09oj:jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000oj>hionS^>L02_nS
^>L00ol0003oY;OVojBgiP09ojBgiP03o`000?nU]nGoYKOU00CoYKOU0ol00002ojBgiP03o`000?nV
]nGoY[OU00WoY[OU00?o0000ojRgi?nX]n@02_nX]n@00ol0003oZkSSoj^hh`0:oj^hh`03o`000?n]
^N;o[KWR00Ko[KWR0ol000000on^^^?o0000ok2khP04ok2khP03o`000?n`^n;o/;_R00Go/;_R00?o
0000ok:mh_nb_N802onb_N800ol0003o/kkQok>nh@08ok>nh@;o000000?o]KoQo`000?nf`>403?nf
`>400ol0003o]l7QokO1h@0;okO1h@03o`000?oooooooooo05gooooo000Booooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo01_ooooo00?o
0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^>OoXkSW00WoXkSW00?o
0000ojBgi_nT]nH02_nT]nH00ol0003oYKOUojFgi@03o`0000KoY;OV00?o0000ojJgiOnV]nD02OnV
]nD00ol0003oZ;OTojRgi00:ojRgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojfih_n]^N800on]
^N82o`0000Go[[[S00?o0000ok2kh_n`^n800_n`^n800ol0003o/;_Rok2khP05ok2khP03o`000?nb
_N;o/[gR00co/[gR00?o0000ok>nhOnc_^401?nc_^43o`0000Co]KoQ00?o0000okK0hOnf`>402onf
`>400ol0003o]l7QokO1h@0;okO1h@03o`000?oooooooooo05cooooo000Booooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o
0000ojBgi_nT]nH02?nT]nH4o`0000[oY;OV00?o0000ojJgiOnV]nD02OnV]nD00ol0003oZ;OTojRg
i00:ojRgi003o`000?n[^>?oZkSS00[oZkSS00?o0000ojfih_l000000_l00008ojjjh`05o`000?n`
^n;o/;_Rok2kh_l000002?n`^n800ol0003o/[gRok:mhP0;ok:mhP03o`000?nc_^7o/kkQ00;o/kkQ
0_l00008okFoh@03o`000?nf`>7o]/3Q00_o]/3Q00?o0000okO1hOng`N402_ng`N42o`0005gooooo
000Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`;o0000
7oooool00ol0003oX[[Zoj:jjP09oj:jjP03o`000?nR^NWoX[WY00SoX[WY00?o0000oj>hionS^>L0
2_nS^>L00ol0003oY;OVojBgiP04ojBgiP?o00000_nR]nP00ol0003oY;OVojBgiP0:ojBgiP03o`00
0?nV]nGoY[OU00WoY[OU00?o0000ojRgi?nX]n@02OnX]n@00ol0003oZkSSoj^hh`0:oj^hh`;o0000
3?n^^^<01?l0003o/;_Rok2kh_l00009ok2khP03o`000?nb_N;o/[gR00_o/[gR00Co0000ok>nhOl0
003o00002one_n400ol0003o]/3QokK0h@0;okK0h@03o`000?ng`N7o]l7Q00Oo]l7Q0_l000000onh
`N7o0000ooooo`1Looooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo01oooooo00?o0000oj:jj_nR^^X02OnR^^X0
0ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00[oXkSW00?o0000ojBgi_nT]nH00ol00006
oj:gj003o`000?nT]nKoY;OV00[oY;OV00?o0000ojJgiOnV]nD02?nV]nD00ol0003oZ;OTojRgi00:
ojRgi003o`000?n[^>?oZkSS00KoZkSS0ol000000on[^NCo0000ojjjh`0<ojjjh`03o`000?n`^n;o
000000[o/;_R00?o0000ok:mh_nb_N802_nb_N82o`0000go]KoQ00?o0000okK0hOnf`>402onf`>40
0ol0003o]l7QokO1h@05okO1h@;o00001?nh`N400ol0003oooooooooo`1Jooooo`004_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo023ooooo00?o0000oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS
^>OoXkSW00SoXkSW1?l0000:oj:gj003o`000?nT]nKoY;OV00WoY;OV00?o0000ojJgiOnV]nD02OnV
]nD00ol0003oZ;OTojRgi00:ojRgi003o`000?n[^>?oZkSS00?oZkSS0_l00005oj^ii003o`000?n^
^^?o[[[S00[o[[[S00?o0000ok2kh_l000002_n`^n800ol0003o/[gRok:mhP08ok:mhP;o000000?o
/kkRo`000?ne_n403One_n400ol0003o]/3QokK0h@0;okK0h@03o`000?ng`N7o]l7Q00;o]l7Q0_l0
0007okS1h@03o`000?oooooooooo05Wooooo000]ooooo`03o`000?oooooooooo027ooooo00?o0000
oj:jj_nR^^X02OnR^^X00ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00CoXkSW0ol00002
oj2gj@03o`000?nR]nSoX[OX00[oX[OX00?o0000ojBgi_nT]nH02OnT]nH00ol0003oY[OUojJgi@09
ojJgi@03o`000?nX]nCoZ;OT00[oZ;OT00?o0000oj^hhol000000_l00008oj^ii003o`000?n^^^?o
[[[S00[o[[[S0_l0000;ok2khP03o`000?nb_N;o/[gR00Go/[gR0_l00004ok>nhP03o`000?ne_n7o
]KoQ00co]KoQ00?o0000okK0hOnf`>402onf`>401?l0003o]l7Qo`000?l0000:okS1h@03o`000?oo
oooooooo05Sooooo000]ooooo`03o`000?oooooooooo027ooooo00?o0000oj:jj_nR^^X02_nR^^X0
0ol0003oX[WYoj:ij@08oj:ij@03o`000?nS^>OoXkSW00?o00001_nP]nT00ol0003oX[OXoj:gj00:
oj:gj003o`000?nT]nKoY;OV00WoY;OV00?o0000ojJgiOnV]nD02OnV]nD00ol0003oZ;OTojRgi008
ojRgi0?o00003?n[^N@00ol0003o[[[Sojjjh`0:ojjjh`03o`000?n`^n;o/;_R00[o/;_R00?o0000
ok:mh_nb_N800_nb_N82o`0000Oo/kkR00?o0000okFohOne_n402one_n400ol0003o]/3QokK0h@0;
okK0h@;o00003?nh`N400ol0003oooooooooo`1Hooooo`00;Oooool00ol0003oooooooooo`0Roooo
o`03o`000?nR^^[oX[[Z00[oX[[Z00?o0000oj:ijOnR^NT01_nR^NT4o`0000[oX;OY00?o0000oj:g
j?nR]nP02_nR]nP00ol0003oY;OVojBgiP09ojBgiP03o`000?nV]nGoY[OU00WoY[OU00?o0000ojRg
i?nX]n@01?nX]n@3o`0000;oZ;WU00?o0000oj^ii?n[^N@02on[^N@00ol0003o[[[Sojjjh`09ojjj
h`;o00003?n`^n801?l0003o/[gRo`000?l0000:ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00?o0000
okK0hOnf`>402?nf`>42o`000003okO1hOl0003o^<7Q00co^<7Q00?o0000ooooooooool0Eoooool0
02cooooo0ol0000Tooooo`03o`000?nR^^[oX[[Z00[oX[[Z00?o0000oj:ijOnR^NT01Ol00002oinh
jP03o`000?nP]nWoX;OY00[oX;OY00?o0000oj:gj?nR]nP02_nR]nP00ol0003oY;OVojBgiP08ojBg
iP03o`000?nV]nGoY[OU00[oY[OU00?o0000ojRgi?nX]n@00ol00006ojRii@03o`000?n[^NCoZkWT
00[oZkWT00?o0000ojjjhon^^^<02On^^^<2o`0000co/;_R0_l0000=ok>nhP03o`000?ne_n7o]KoQ
00_o]KoQ00?o0000okK0hOnf`>401_nf`>400ol0003o]l7QokO1h@02okO1h@03o`000?nh`N7o^<7Q
00_o^<7Q00?o0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003o
X[[Zoj:jjP08oj:jjPCo00002?nO^>X00ol0003oX;OYoj2gj@0:oj2gj@03o`000?nR]nSoX[OX00Wo
X[OX00?o0000ojBgi_nT]nH02OnT]nH00ol0003oY[OUojJgi@08ojJgi@Co00002_nX^ND00ol0003o
ZkWToj^ii00:oj^ii003o`000?n^^^?o[[[S00So[[[S00?o0000ojjjhol000002?n`^n83o`000003
ok6mhol0003o/kkR00co/kkR00?o0000okFohOne_n403?ne_n400ol0003o]/3QokK0h@03okK0h@;o
00001_ng`N400ol0003o^<7QokS1h@0;okS1h@03o`000?oooooooooo05Gooooo000]ooooo`03o`00
0?oooooooooo02Gooooo00?o0000oj:jj_nR^^X01?nR^^X3o`0000;oW[W[00?o0000oinhj_nO^>X0
2?nO^>X00ol0003oX;OYoj2gj@0:oj2gj@03o`000?nR]nSoX[OX00WoX[OX00?o0000ojBgi_nT]nH0
2OnT]nH00ol0003oY[OUojJgi@04ojJgi@?o00000_nU^>H00ol0003oZ;WUojRii@0:ojRii@03o`00
0?n[^NCoZkWT00[oZkWT00?o0000ojjjhon^^^<01on^^^<01?l0003o[[[Sojjjhol00005ok2khP;o
00001Ona_N<00ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00Co0000okK0hOnf
`>7o]/3Q0_l00009okO1h@03o`000?nh`N7o^<7Q00[o^<7Q0_l0001Fooooo`00;Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?nR^^[oX[[Z00?o00001_nN^N/00ol0003oWkSZoinhjP08oinhjP03
o`000?nP]nWoX;OY00[oX;OY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oY;OVojBgiP09ojBgiP03
o`000?nV]nGoY[OU00?o00001_nU^>H00ol0003oZ;WUojRii@0:ojRii@03o`000?n[^NCoZkWT00[o
ZkWT00?o0000ojjjhon^^^<01_n^^^<01_l0003o[[[Sojjjhon^^^?o0000ok2khP?o00002?na_N<0
0ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00_o]KoQ00?o0000okK0hOl000002ong`N40
0ol0003o^<7QokS1h@0;okS1h@03o`000?oooooooooo05Cooooo000/ooooo`03o`000?oooooooooo
02Sooooo0_l0000:oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000oj2gjOnP]nT02OnP]nT00ol0
003oX[OXoj:gj00:oj:gj003o`000?nT]nKoY;OV00SoY;OV0ol0000:ojFhiP03o`000?nX^NGoZ;WU
00WoZ;WU00?o0000oj^ii?n[^N@02_n[^N@00ol0003o[[[Sojjjh`06ojjjh`04o`000?n^^^?o[[[S
ojjjh`;o00003?na_N<00ol0003o/kkRok>nhP0;ok>nhP03o`000?ne_n7o]KoQ00[o]KoQ0_l0000=
okO1h@03o`000?nh`N7o^<7Q00_o^<7Q00?o0000ooooooooool0Doooool002cooooo00?o0000oooo
ooooool0:Oooool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000oj2g
jOnP]nT02OnP]nT00ol0003oX[OXoj:gj00:oj:gj003o`000?nT]nKoY;OV00CoY;OV0ol000000onR
]nSo0000ojFhiP0;ojFhiP03o`000?nX^NGoZ;WU00WoZ;WU00?o0000oj^ii?n[^N@02_n[^N@00ol0
003o[[[Sojjjh`05ojjjh`Co000000?o[[cTo`000?na_N<03?na_N<00ol0003o/kkRok>nhP0:ok>n
hP03o`000?ne_n7o]KoQ00So]KoQ0_l000000onf`>;o0000okO1h@0=okO1h@03o`000?nh`N7o^<7Q
00_o^<7Q00?o0000ooooooooool0D_ooool002cooooo0_l0000[ooooo`03o`000?nN^N_oW[W[00Wo
W[W[00?o0000oinhj_nO^>X02?nO^>X00ol0003oX;OYoj2gj@09oj2gj@03o`000?nR]nSoX[OX00[o
X[OX00?o0000ojBgi_nT]nH00ol00005oj:gj003o`000?nU^>KoYKSV00[oYKSV00?o0000ojRiiOnX
^ND02OnX^ND00ol0003oZkWToj^ii00:oj^ii003o`000?n^^^?o[[[S00?o[[[S0_l00005ojjli003
o`000?na_N?o/KgS00_o/KgS00?o0000ok>nh_nc_^802_nc_^800ol0003o]KoQokFoh@05okFoh@;o
00001?nf`>800ol0003o]l7QokO1h@0;okO1h@03o`000?nh`N7o^<7Q00_o^<7Q0_l0001Cooooo`00
;?ooool00ol0003oooooooooo`0[ooooo`03o`000?nN^N_oW[W[00WoW[W[00?o0000oinhj_nO^>X0
2?nO^>X00ol0003oX;OYoj2gj@09oj2gj@03o`000?nR]nSoX[OX00SoX[OX1?l00009oj:gj003o`00
0?nU^>KoYKSV00WoYKSV00?o0000ojRiiOnX^ND02_nX^ND00ol0003oZkWToj^ii00:oj^ii003o`00
0?n^^^?o000000;o000000?o[[cTo`000?n^_>@01On^_>@00ol0003o/KgSok6mh`0;ok6mh`03o`00
0?nc_^;o/kkR00[o/kkR00?o0000okFohOne_n400_ne_n42o`0000Oo]/3R00?o0000okO1hOng`N40
2ong`N400ol0003o^<7QokS1h@08okS1h@;o000000?o^L;Qo`000?ooool0D_ooool002cooooo00?o
0000ooooooooool0;?ooool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00?o
0000oj2gjOnP]nT02OnP]nT00ol0003oX[OXoj:gj004oj:gj0?o00000_nO]nT00ol0003oX[OXoj:g
j009oj:gj003o`000?nU^>KoYKSV00WoYKSV00?o0000ojRiiOnX^ND02OnX^ND00ol0003oZkWToj^i
i00:oj^ii0;o00001?n^_>@00ol0003o[[cTojjli005ojjli003o`000?na_N?o/KgS00[o/KgS00?o
0000ok>nh_nc_^802onc_^801?l0003o]KoQo`000?l0000:okK0hP03o`000?ng`N7o]l7Q00_o]l7Q
00?o0000okS1hOnh`N401_nh`N400ol0003o^L;QokW2h@02okW2h@03o`000?oooooooooo053ooooo
000/ooooo`03o`000?oooooooooo02gooooo00?o0000oijijonN^N/02OnN^N/00ol0003oWkSZoinh
jP08oinhjP03o`000?nP]nWoX;OY00WoX;OY00?o0000oj:gj?nR]nP00ol00006oingj@03o`000?nR
]nSoX[OX00WoX[OX00?o0000ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@09ojRii@03o`000?n[
^NCoZkWT00KoZkWT0ol000000on[^nGo0000ojjli003ojjli003o`000?n^_>Co[[cT00Ko[[cT00?o
0000ok6mhona_N<02_na_N<00ol0003o/kkRok>nhP0:ok>nhP;o00003?nf`>800ol0003o]l7QokO1
h@0<okO1h@03o`000?nh`N7o^<7Q00?o^<7Q0_l00006okW2h@03o`000?oooooooooo04oooooo000/
ooooo`03o`000?oooooooooo02kooooo00?o0000oijijonN^N/02OnN^N/00ol0003oWkSZoinhjP08
oinhjP03o`000?nP]nWoX;OY00OoX;OY1?l0000:oingj@03o`000?nR]nSoX[OX00WoX[OX00?o0000
ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@09ojRii@03o`000?n[^NCoZkWT00?oZkWT0_l00005
oj^ki@05o`000?n^_>Co[[cTojjli?l000002?n^_>@00ol0003o/KgSok6mh`0;ok6mh`03o`000?nc
_^;o/kkR00Ko/kkR0ol000000ond`>?o0000okK0hP0<okK0hP03o`000?ng`N7o]l7Q00_o]l7Q00Co
0000okS1hOnh`N7o^<7Q0_l00008okW2h@;o0000D?ooool002cooooo00?o0000ooooooooool0;ooo
ool00ol0003oW[W[oijij`09oijij`03o`000?nO^>[oWkSZ00SoWkSZ00Co0000oj2gjOnP]nWoX;OY
1Ol00002oifgjP03o`000?nO]nWoWkOY00[oWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSV
ojFhiP08ojFhiP03o`000?nX^NGoZ;WU00[oZ;WU00?o0000oj^ii?l000000_l00008oj^ki@04o`00
0?n^_>Co[[cTo`0000Wo[[cT00?o0000ok6mhona_N<02ona_N<00ol0003o/kkRok>nhP03ok>nhP;o
00001Ond`><00ol0003o]/3RokK0hP0;okK0hP03o`000?ng`N7o]l7Q00_o]l7Q00?o0000okS1hOl0
00002oni`^400ol0003oooooooooo`1>ooooo`00;?ooool2o`00037ooooo00?o0000oijijonN^N/0
2OnN^N/00ol0003oWkSZoinhjP06oinhjPGo00002?nM]nX00ol0003oWkOYoingj@0:oingj@03o`00
0?nR]nSoX[OX00SoX[OX00?o0000ojFhi_nU^>H02OnU^>H00ol0003oZ;WUojRii@08ojRii@?o0000
3?n[^nD00ol0003o[[cTo`00000:ojjli003o`000?na_N?o/KgS00_o/KgS00?o0000ok>nh_l00000
0_l00008okC0h`03o`000?nf`>;o]/3R00_o]/3R00?o0000okO1hOng`N402_ng`N42o`0000go^L;Q
00?o0000ooooooooool0COooool002_ooooo00?o0000ooooooooool0<_ooool00ol0003oW[W[oiji
j`09oijij`03o`000?nO^>[oWkSZ00Go00000_nL]n/00ol0003oWKOZoifgjP09oifgjP03o`000?nO
]nWoWkOY00WoWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSVojFhiP09ojFhiP03o`000?nX
^NGoZ;WU00CoZ;WU0ol00002ojRjiP03o`000?n[^nGoZk_U00_oZk_U0_l0000;ojjli003o`000?na
_N?o/KgS00[o/KgS0_l0000<okC0h`03o`000?nf`>;o]/3R00_o]/3R00?o0000okO1hOng`N401ong
`N42o`000003okS2h_l0003o^L;Q00go^L;Q00?o0000ooooooooool0C?ooool002_ooooo00?o0000
ooooooooool0<oooool00ol0003oW[W[oijij`08oijij`?o00002?nL]n/00ol0003oWKOZoifgjP09
oifgjP03o`000?nO]nWoWkOY00WoWkOY00?o0000oj:gj?nR]nP02OnR]nP00ol0003oYKSVojFhiP09
ojFhiP03o`000?nX^NGoZ;WU00?o00001_nX^^H00ol0003oZk_Uoj^ki@0:oj^ki@;o00002on^_>@0
0ol0003o/KgSok6mh`08ok6mh`;o000000?o/[oTo`000?nd`><03?nd`><00ol0003o]/3RokK0hP0:
okK0hP03o`000?ng`N7o]l7Q00Go]l7Q0_l00004okS2hP03o`000?ni`^7o^L;Q00_o^L;Q0_l0001=
ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?nN^N_oW[W[00CoW[W[0ol00000
0onK^>co0000oibgj`09oibgj`03o`000?nM]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02OnO]nT0
0ol0003oX[OXoj:gj009oj:gj003o`000?nU^>KoYKSV00SoYKSV0ol0000:ojRjiP03o`000?n[^nGo
Zk_U00[oZk_U00?o0000ojjli?n^_>@02_n^_>@00ol0003o/KgSok6mh`05ok6mh`;o00001?nb_n@0
0ol0003o]<3SokC0h`0;okC0h`03o`000?nf`>;o]/3R00[o]/3R00?o0000okO1hOng`N400_ng`N42
o`0000Oo^<;R00?o0000okW2hOni`^402oni`^42o`0004cooooo000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0e
ooooo`03o`000?nN^N_oW[W[00?o00001OnK^>`00ol0003oW;O[oibgj`08oibgj`03o`000?nM]n[o
WKOZ00WoWKOZ00?o0000oingjOnO]nT02OnO]nT00ol0003oX[OXoj:gj009oj:gj003o`000?nU^>Ko
YKSV00CoYKSV0ol000000onT^NSo0000ojRjiP0;ojRjiP03o`000?n[^nGoZk_U00WoZk_U0_l0000<
ojjli003o`000?na_N?o/KgS00;o/KgS0_l00007ok:oi003o`000?nd`>?o]<3S00[o]<3S00?o0000
okK0h_nf`>802onf`>801?l0003o]l7Qo`000?l0000:okS2hP03o`000?ni`^7o^L;Q00_o^L;Q00?o
0000ooooooooool0B_ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_oo
ool00ol0003oooooooooo`0fooooo`;o00002OnK^>`00ol0003oW;O[oibgj`08oibgj`03o`000?nM
]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02?nO]nT00ol0003oX[OXoj:gj00:oj:gj003o`000?nU
^>KoYKSV00?o00001OnT^NP00ol0003oZ;[VojRjiP0:ojRjiP03o`000?n[^nGoZk_U00SoZk_U00?o
0000oj^kiOl000003?n^_>@01?l0003o/KgSo`000?l0000:ok:oi003o`000?nd`>?o]<3S00[o]<3S
00?o0000okK0h_nf`>802_nf`>82o`0000go^<;R00?o0000okW2hOni`^402oni`^400ol0003ooooo
ooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0gooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oibgjonL
]n/02?nL]n/00ol0003oWKOZoifgjP09oifgjP03o`000?nO]nWoWkOY00SoWkOY00?o0000oj:gj?nR
]nP02?nR]nP4o`0000WoY;WX00?o0000ojRji_nX^^H02_nX^^H00ol0003oZk_Uoj^ki@07oj^ki@03
o`000?n[^nGo000000co[[cT0_l0000<ok:oi003o`000?nd`>?o]<3S00_o]<3S00?o0000okK0h_nf
`>801_nf`>83o`000003okO2h_l0003o^<;R00go^<;R00?o0000okW2hOni`^402_ni`^42o`0004[o
oooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007oooo
o`03o`000?oooooooooo03Sooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oW;O[oibgj`08oibg
j`03o`000?nM]n[oWKOZ00WoWKOZ00?o0000oingjOnO]nT02?nO]nT00ol0003oX[OXoj:gj004oj:g
j0?o00000_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00[oZ;[V00?o0000oj^k
iOn[^nD01_n[^nD01?l0003oZk_Uoj^kiOl00008ojjli0?o000000?o[kkUo`000?nb_n@03?nb_n@0
0ol0003o]<3SokC0h`0;okC0h`03o`000?nf`>;o]/3R00?o]/3R0_l00005okO2hP03o`000?nh`^;o
^<;R00_o^<;R00?o0000okW2hOni`^402oni`^42o`0004Wooooo000@ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`;o0000>oooool00ol0003oVkS/oi^hk008
oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM]nX00ol0003oWkOYoingj@08
oingj@03o`000?nR]nSoX[OX00?o00001_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^Ko
Z;[V00WoZ;[V00?o0000oj^kiOn[^nD01_n[^nD01Ol0003oZk_Uoj^kiOn[^nGo000000Go[[cT0_l0
0005ojnni@03o`000?nb_nCo/[oT00_o/[oT00?o0000okC0hond`><02ond`><00ol0003o]/3Ro`00
0002o`0000So]l;R00?o0000okS2h_nh`^802onh`^800ol0003o^L;QokW2h@08okW2h@;o000000?o
^<;Ro`000?ooool0B?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0>_ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nL
]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM]nX00ol0003oWkOYoingj@06oingj@Co00002_nQ
^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o0000oj^kiOn[^nD01On[
^nD00ol0003oZk_Uoj^ki@02oj^ki@03o`000?n^_>Co000000;o00002?n__^D00ol0003o/[oTok:o
i00;ok:oi003o`000?nd`>?o]<3S00[o]<3S0_l0000<okO2hP03o`000?nh`^;o^<;R00_o^<;R00?o
0000okW2hOni`^401Oni`^42o`0000Co^<;R00?o0000ooooooooool0A_ooool0013ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??oo
ool00ol0003oVkS/oi^hk008oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX02OnM
]nX00ol0003oWkOYoingj@05o`0000;oW[OZ00?o0000oj6hjOnQ^>T02_nQ^>T00ol0003oY;WXojBi
j009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o0000oj^kiOn[^nD01?n[^nD01?l0003oZk_Uoj^k
iOn[^nD3o`0000co[kkU00?o0000ok:oi?nb_n@02onb_n@00ol0003o]<3SokC0h`07okC0h`;o0000
00?o]L7So`000?ng`^803?ng`^800ol0003o^<;RokS2hP0;okS2hP03o`000?ni`^7o^L;Q00;o^L;Q
0_l00006okS2hP;o0000Aoooool002[ooooo00?o0000ooooooooool0?Oooool00ol0003oVkS/oi^h
k008oi^hk003o`000?nL]n_oW;O[00SoW;O[00?o0000oifgj_nM]nX01onM]nX4o`0000SoW[OZ00?o
0000oj6hjOnQ^>T02_nQ^>T00ol0003oY;WXojBij009ojBij003o`000?nX^^KoZ;[V00WoZ;[V00?o
0000oj^kiOn[^nD00on[^nD4o`0000;o[;gV00?o0000ojnniOn__^D02on__^D00ol0003o/[oTok:o
i00:ok:oi003o`000?nd`>?o]<3S00Go]<3S0_l00004okG1h`03o`000?ng`^;o]l;R00_o]l;R00?o
0000okS2h_nh`^802onh`^801?l0003o^L;Qo`000?l00009okS2hP03o`000?oooooooooo04Gooooo
000Zooooo`03o`000?oooooooooo03kooooo00?o0000oi^hk?nK^>`02?nK^>`00ol0003oW;O[oibg
j`08oibgj`04o`000?nM]n[oWKOZoifgjPGo00000_nK]n/00ol0003oW[OZoijgjP08oijgjP03o`00
0?nQ^>WoXKSY00[oXKSY00?o0000ojBij?nT^NP02OnT^NP00ol0003oZ;[VojRjiP09ojRjiP03o`00
0?n[^nGoZk_U00?o00001_n/_NH00ol0003o[kkUojnni@0;ojnni@03o`000?nb_nCo/[oT00[o/[oT
00?o0000okC0hond`><00_nd`><2o`0000Oo]L7S00?o0000okO2h_ng`^802_ng`^800ol0003o^<;R
okS2hP0;okS2hP;o00003?nh`^800ol0003oooooooooo`14ooooo`00:_ooool00ol0003ooooooooo
o`0oooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oibgjonL]n/01_nL]n/5o`0000SoVkO[00?o
0000oijgj_nN]nX02?nN]nX00ol0003oXKSYoj6hj@0:oj6hj@03o`000?nT^NSoY;WX00WoY;WX00?o
0000ojRji_nX^^H02?nX^^H3o`0000;o[;gV00?o0000ojbmi_n/_NH01On/_NH00ol0003o[kkUojnn
i@0:ojnni@03o`000?nb_nCo/[oT00_o/[oT00Co0000okC0hol0003o00002_ne`N<00ol0003o]l;R
okO2hP0:okO2hP03o`000?nh`^;o^<;R00So^<;R0_l000000onh`^;o0000okS2hP0<okS2hP03o`00
0?oooooooooo04?ooooo000Yooooo`?o0000@?ooool2o`0000[oVkS/00?o0000oibgjonL]n/01Ol0
0002oiVgk003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX02?nN]nX00ol0003oXKSYoj6h
j@09oj6hj@03o`000?nT^NSoY;WX00[oY;WX00?o0000ojRji_nX^^H01?nX^^H3o`000003ojRkiol0
003o[;gV00;o[;gV00?o0000ojbmi_n/_NH01_n/_NH00ol0003o[kkUojnni@0:ojnni@03o`000?nb
_nCo/[oT00[o/[oT0_l0000<okG1h`03o`000?ng`^;o]l;R00_o]l;R00?o0000okS2h_nh`^801Onh
`^82o`0000Co^<;R00?o0000okS2h_nh`^802_nh`^82o`0004Cooooo000Zooooo`03o`000?oooooo
oooo043ooooo0_l00008oi^hk0Co00002?nI]n`00ol0003oVkO[oi^gj`09oi^gj`03o`000?nN]n[o
W[OZ00SoW[OZ00?o0000oj6hjOnQ^>T02OnQ^>T00ol0003oY;WXojBij00:ojBij003o`000?nX^^Ko
Z;[V00?o00001OnX^nL01?l0003o[;gVojbmi_l00009ojbmiP03o`000?n__^Go[kkU00[o[kkU00?o
0000ok:oi?nb_n@01_nb_n@3o`000003ok;1iOl0003o]L7S00co]L7S00?o0000okO2h_ng`^802ong
`^800ol0003o^<;RokS2hP02okS2hP;o00001onh`^800ol0003o^<;RokS2hP0:okS2hP03o`000?oo
oooooooo04;ooooo000Zooooo`03o`000?oooooooooo047ooooo0_l00002oi^hk0Go00000_nH]nd0
0ol0003oVKO/oiVgk008oiVgk003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX02?nN]nX0
0ol0003oXKSYoj6hj@09oj6hj@03o`000?nT^NSoY;WX00SoY;WX1?l00009ojRki`03o`000?n/_NKo
000000[o[;gV00?o0000ojnniOn__^D02_n__^D00ol0003o/[oTok:oi003ok:oi0;o00001Onb`ND0
0ol0003o]L7SokG1h`0;okG1h`03o`000?ng`^;o]l;R00_o]l;R00Co0000okS2h_l0003o00002_nh
`^800ol0003o^<;RokS2hP0:okS2hP03o`000?oooooooooo047ooooo000Zooooo`03o`000?oooooo
oooo04;ooooo0ol00008oiRgk@03o`000?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/02OnK]n/0
0ol0003oW[OZoijgjP07oijgjP03o`000?nQ^>WoXKSY00[oXKSY00?o0000ojBij?nT^NP01?nT^NP3
o`0000;oY;[Y00?o0000ojRkionX^nL02OnX^nL2o`0000_o[;gV00?o0000ojnniOn__^D02_n__^D0
0ol0003o/[oTo`000002o`0000So//7U00?o0000okG1hone`N<02one`N<00ol0003o]l;RokO2hP0:
okO2hP;o00003?nh`^800ol0003o^<;RokS2hP0;okS2hP03o`000?oooooooooo043ooooo000Yoooo
o`03o`000?oooooooooo04Cooooo00?o0000oiRgkOnH]nd02?nH]nd00ol0003oVKO/oiVgk008oiVg
k003o`000?nK]n_oVkO[00WoVkO[00?o0000oijgj_nN]nX01onN]nX00ol0003oXKSYoj6hj@0:oj6h
j@03o`000?nT^NSoY;WX00?o00001_nT^^T00ol0003oZ;_WojRki`09ojRki`03o`000?n/_NKo[;gV
00[o[;gV00?o0000ojnniOn__^D02On__^D2o`0000co//7U00?o0000okG1hone`N<02one`N<00ol0
003o]l;RokO2hP07okO2hP;o000000?o]l?So`000?nh`^803?nh`^800ol0003o^<;RokS2hP0:okS2
hP03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo04Gooooo00?o0000oiRgkOnH
]nd02?nH]nd00ol0003oVKO/oiVgk008oiVgk003o`000?nK]n_oVkO[00SoVkO[00?o0000oijgj_nN
]nX02?nN]nX00ol0003oXKSYoj6hj@08oj6hj@Co00002_nT^^T00ol0003oZ;_WojRki`08ojRki`;o
00003?n/_NH00ol0003o[kkUojnni@06ojnni@;o000000?o[koVo`000?nb`ND03?nb`ND00ol0003o
]L7SokG1h`0:okG1h`03o`000?ng`^;o]l;R00Go]l;R0_l00004okO3h`03o`000?nh`^;o^<;R00_o
^<;R00?o0000okS2h_nh`^802_nh`^800ol0003oooooooooo`0oooooo`00:Oooool00ol0003ooooo
ooooo`16ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`02?nI]n`00ol0003oVkO[
oi^gj`08oi^gj`03o`000?nN]n[oW[OZ00SoW[OZ00?o0000oj6hjOnQ^>T01?nQ^>T3o`0000;oX;WZ
00?o0000ojBjjOnT^^T02_nT^^T00ol0003oZ;_WojRki`07ojRki`03o`000?nX^nOo000000co[;gV
00?o0000ojnniOn__^D00_n__^D3o`0000Co[koV00?o0000ok;1iOnb`ND02onb`ND00ol0003o]L7S
okG1h`0:okG1h`03o`000?ng`^;o]l;R00;o]l;R0_l00007okO3h`03o`000?nh`^;o^<;R00_o^<;R
00?o0000okS2h_nh`^802Onh`^82o`00043ooooo000Yooooo`;o0000B?ooool00ol0003oV;O]oiRg
k@08oiRgk@03o`000?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/02?nK]n/00ol0003oW[OZoijg
jP08oijgjP03o`000?nQ^>WoXKSY00?o00001_nP^NX00ol0003oY;[YojBjj@09ojBjj@03o`000?nX
^nOoZ;_W00OoZ;_W00?o0000ojRkiol000003On/_NH01?l0003o[kkUo`000?l00008ojnoiP03o`00
0?nb`NGo//7U00[o//7U00?o0000okG1hone`N<02one`N<01?l0003o]l;Ro`000?l0000:okO3h`03
o`000?nh`^;o^<;R00[o^<;R00?o0000okS2h_nh`^801_nh`^83o`000003okO2h_l0003o000003oo
oooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000oiRgkOnH]nd02?nH]nd00ol0003oVKO/
oiVgk008oiVgk003o`000?nK]n_oVkO[00SoVkO[00?o0000oijgj_nN]nX01_nN]nX4o`0000[oX;WZ
00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`06ojRki`04o`000?nX^nOoZ;_Wo`0000co
[;gV0_l0000;ojnoiP03o`000?nb`NGo//7U00[o//7U00?o0000okG1hone`N<02_ne`N<2o`0000co
]l?S00?o0000okS2h_nh`^802onh`^800ol0003o^<;RokS2hP03okS2hP;o00001Ong`^800ol0003o
ooooooooo`0mooooo`00:Oooool00ol0003oooooooooo`19ooooo`03o`000?nH]ngoV;O]00SoV;O]
00?o0000oiVgk?nI]n`02?nI]n`00ol0003oVkO[oi^gj`08oi^gj`03o`000?nN]n[oW[OZ00Go0000
0_nL^>/00ol0003oX;WZoj2ijP0:oj2ijP03o`000?nT^^WoY;[Y00WoY;[Y00?o0000ojRkionX^nL0
1OnX^nL01Ol0003oZ;_WojRkionX^nOo000000So[;gV0ol000000on/_^Oo0000ojnoiP0;ojnoiP03
o`000?nb`NGo//7U00[o//7U00?o0000okG1hone`N<01_ne`N<3o`000003okG2i?l0003o]l?S00co
]l?S00?o0000okS2h_nh`^802onh`^800ol0003o^<;Ro`000002o`0000So]l;R00?o0000oooooooo
ool0??ooool002Wooooo00?o0000ooooooooool0B_ooool00ol0003oV;O]oiRgk@08oiRgk@03o`00
0?nI]ncoVKO/00SoVKO/00?o0000oi^gjonK]n/01_nK]n/4o`0000SoW;S[00?o0000oj2ij_nP^NX0
2_nP^NX00ol0003oY;[YojBjj@09ojBjj@03o`000?nX^nOoZ;_W00CoZ;_W00?o0000ojRkionX^nL0
0_nX^nL00ol0003o[;gVojbmiP03ojbmiP;o00001On/_^L00ol0003o[koVojnoiP0:ojnoiP03o`00
0?nb`NGo//7U00[o//7U00?o0000okG1hone`N<00one`N<2o`0000Go]L;T00?o0000okO3hong`n<0
2ong`n<00ol0003o^<;RokS2hP0:okS2hP;o00003?ng`^800ol0003oooooooooo`0kooooo`00:Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`02?nI
]n`00ol0003oVkO[oi^gj`05o`0000;oV[O/00?o0000oibhjonL^>/02?nL^>/00ol0003oX;WZoj2i
jP0:oj2ijP03o`000?nT^^WoY;[Y00WoY;[Y00?o0000ojRkionX^nL00onX^nL00ol0003oZ;_WojRk
i`03ojRki`03o`000?n/_NKo000000;o00002?n/_^L00ol0003o[koVojnoiP09ojnoiP03o`000?nb
`NGo//7U00_o//7U00?o0000okG1hol000000_l00008okG2i003o`000?ng`n?o]l?S00_o]l?S00?o
0000okS2h_nh`^801onh`^82o`000003okO3hol0003o]l;R00_o]l;R0_l0000looooo`00:Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?nH]ngoV;O]00SoV;O]00?o0000oiVgk?nI]n`00onI]n`7
o`0000SoV[O/00?o0000oibhjonL^>/02?nL^>/00ol0003oX;WZoj2ijP0:oj2ijP03o`000?nT^^Wo
Y;[Y00SoY;[Y00?o0000ojRkionX^nL00onX^nL00ol0003oZ;_WojRki`02ojRki`?o00003?n/_^L0
0ol0003o[koVojnoiP09ojnoiP03o`000?nb`NGo//7U00[o//7U0_l0000<okG2i003o`000?ng`n?o
]l?S00[o]l?S00?o0000okS2h_nh`^801Onh`^82o`0000Co]l?S00?o0000okO2h_ng`^802_ng`^80
0ol0003oooooooooo`0jooooo`00:?ooool3o`0004kooooo00?o0000oiRgkOnH]nd01_nH]nd7o`00
00GoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibhj`03o`000?nP^N[oX;WZ
00WoX;WZ00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`02ojRki`03o`000?nX^nOo0000
00;o00000_nX_NT00ol0003o[;kWojbni`0;ojbni`03o`000?n__nKo[koV00Wo[koV00?o0000ok;1
iOnb`ND01_nb`ND3o`000003ok;2i_l0003o]L;T00co]L;T00?o0000okO3hong`n<02_ng`n<00ol0
003o^<;RokS2hP02okS2hP;o00001ong`n<00ol0003o]l;RokO2hP0:okO2hP03o`000?oooooooooo
03Wooooo000Xooooo`03o`000?oooooooooo04oooooo00?o0000oiRgkOnH]nd01Ol00002oiJfk@03
o`000?nG]^goUkK]00SoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibhj`03
o`000?nP^N[oX;WZ00WoX;WZ00?o0000ojBjjOnT^^T02OnT^^T00ol0003oZ;_WojRki`03o`0000Ko
Z;gY00?o0000ojbnion/_^L02on/_^L00ol0003o[koVojnoiP09ojnoiP03o`000?nb`NGo//7U00?o
//7U0_l00005ok;2iP03o`000?ne`^Co]L;T00_o]L;T00?o0000okO3hong`n<02_ng`n<01?l0003o
^<;Ro`000?l0000:okO3h`03o`000?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0>?ooool000co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Oooooo00?o0000ooooooooool0D?ooool2o`0000SoU[K]00?o0000oiNfkOnG]^d02?nG]^d0
0ol0003oV[O/oiZgk008oiZgk003o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX02OnP^NX0
0ol0003oY;[YojBjj@08ojBjj@?o000000?oZ;gYo`000?nX_NT01onX_NT00ol0003o[;kWojbni`0:
ojbni`03o`000?n__nKo[koV00[o[koV00?o0000ok;1iOl000000_l00008ok;2iP03o`000?ne`^Co
]L;T00[o]L;T00?o0000okO3hong`n<02_ng`n<2o`0000co]l?S00?o0000okO2h_ng`^802_ng`^82
o`0003Wooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@07ooooo`03o`000?oooooooooo053ooooo00?o0000oiJfkOnF]^d02?nF
]^d00ol0003oUkK]oiNfk@08oiNfk@03o`000?nJ]ncoV[O/00SoV[O/00?o0000oibhjonL^>/02?nL
^>/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nT^^WoY;[Y00CoY;[Y0ol000000onT_>[o0000ojRm
j@02o`0000WoZ;gY00?o0000ojbnion/_^L02_n/_^L00ol0003o[koVojnoiP09ojnoiP;o00003?nb
`^H00ol0003o]L;TokG2i00:okG2i003o`000?ng`n?o]l?S00Oo]l?S0_l000000onf`nCo0000okO3
h`0<okO3h`03o`000?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0=oooool000cooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/
oiZgk008oiZgk003o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oY;[Y
ojBjj@03o`0000?oY;cZ0ol000000onX_NWo0000ojRmj@09ojRmj@03o`000?n/_^Oo[;kW00[o[;kW
00?o0000ojnoi_n__nH01_n__nH2o`000003ojo1iol0003o//;V00co//;V00?o0000okG2i?ne`^@0
2_ne`^@00ol0003o]l?SokO3h`04okO3h`;o00001?nf`n@00ol0003o]l?SokO3h`0;okO3h`03o`00
0?ng`^;o]l;R00[o]l;R00?o0000ooooooooool0=_ooool000cooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`1Booooo`03
o`000?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk008oiZgk003
o`000?nL^>_oW;S[00SoW;S[00?o0000oj2ij_nP^NX01onP^NX4o`0000?oY;cZ0ol00003ojBljP03
o`000?nX_NWo000000[oZ;gY00?o0000ojbnion/_^L02_n/_^L00ol0003o[koVojnoiP02ojnoiP?o
00001?n_`NL00ol0003o//;Vok;2iP0;ok;2iP03o`000?ne`^Co]L;T00[o]L;T00?o0000okO3hong
`n<00_ng`n<00ol0003o]/?TokK3i005okK3i003o`000?ng`n?o]l?S00_o]l?S00?o0000okO2h_ng
`^802Ong`^82o`0003Oooooo000<ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Oooooo00?o0000ooooooooool0Doooool00ol0003oU[K]oiJfk@08oiJf
k@03o`000?nG]^goUkK]00SoUkK]00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`08oibh
j`04o`000?nP^N[oX;WZoj2ijPGo00000_nP^^`00ol0003oY;cZo`000002o`0000OoY;cZ00?o0000
ojRmjOl000002OnX_NT00ol0003o[;kWojbni`0;ojbni`04o`000?n__nKo0000o`0000So[l7W00?o
0000ok;2i_nb`^H02_nb`^H00ol0003o]L;TokG2i00;okG2i004o`000?ng`n?o0000o`0000Wo]/?T
00?o0000okO3hong`n<02_ng`n<00ol0003o]l;RokO2hP06okO2hP?o000000?o]/;So`000?l00000
=_ooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Wooooo
00?o0000ooooooooool0E?ooool00ol0003oU[K]oiJfk@08oiJfk@03o`000?nG]^goUkK]00SoUkK]
00?o0000oiZgk?nJ]n`02?nJ]n`00ol0003oW;S[oibhj`06oibhj`Go00001_nP^^`3o`0000_oY;cZ
00?o0000ojRmjOl000002OnX_NT00ol0003o[;kWojbni`0:ojbni`;o00002on_`NL00ol0003o//;V
ok;2iP0:ok;2iP03o`000?ne`^Co]L;T00[o]L;T0_l0000<okK3i003o`000?ng`n?o]l?S00[o]l?S
00?o0000okO2h_ng`^800ong`^82o`0000Go]/;S00?o0000ooooooooool0=?ooool000cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo0_l0001Gooooo`03o`00
0?nF]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk008oiZgk003o`00
0?nL^>_oW;S[00Go00000_nL^N`00ol0003oX;[/oj2jk003oj2jk0?o00000onP^^`00ol0003oY;cZ
ojBljP09ojBljP03o`000?nX_NWo000000WoZ;gY00?o0000ojbnion/_^L01_n/_^L3o`000003ojc0
jOl0003o[l7W00_o[l7W00?o0000ok;2i_nb`^H02_nb`^H00ol0003o]L;TokG2i006okG2i0?o0000
00?o]<CVo`000?nf`n@03?nf`n@00ol0003o]l?SokO3h`0:okO3h`03o`000?ng`^;o000000;o0000
2?nf`^<00ol0003oooooooooo`0cooooo`003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Gooooo`03o`000?nF]^goU[K]00So
U[K]00?o0000oiNfkOnG]^d02?nG]^d00ol0003oV[O/oiZgk006oiZgk0Co00002?nL^N`00ol0003o
X;[/o`000002o`0000OoX;[/00?o0000ojBlj_nT_>X02OnT_>X00ol0003oZ;gYo`000009ojRmj@03
o`000?n/_^Oo[;kW00?o[;kW0_l00005ojc0j@03o`000?n_`NOo[l7W00[o[l7W00?o0000ok;2i_nb
`^H02_nb`^H00ol0003o]L;TokG2i003okG2i0;o00001Onda>H00ol0003o]/?TokK3i00;okK3i003
o`000?ng`n?o]l?S00Wo]l?S0_l0000<okK2h`03o`000?oooooooooo03;ooooo000Wooooo`03o`00
0?oooooooooo05Sooooo00?o0000oiJfkOnF]^d02?nF]^d00ol0003oUkK]oiNfk@08oiNfk@03o`00
0?nJ]ncoV[O/00Go00000_nI^>d00ol0003oW;W/oibik006oibik0?o00002onP^^`00ol0003oY;cZ
ojBljP09ojBljP03o`000?nX_NWo000000WoZ;gY00?o0000ojbniol000000_l00008ojc0j@03o`00
0?n_`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H02onb`^H00ol0003o]L;To`000002o`0000So]<CV
00?o0000okK3i?nf`n@02onf`n@00ol0003o]l?SokO3h`06okO3h`;o000000?o]L?To`000?nf`^<0
3?nf`^<00ol0003oooooooooo`0aooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`000?nF
]^goU[K]00SoU[K]00?o0000oiNfkOnG]^d00onG]^d7o`0000SoVKS]00?o0000oibik?nL^N`00_nL
^N`3o`0000?oW;W/00?o0000oj2jk?nP^^`02OnP^^`00ol0003oY;cZojBljP09ojBljP03o`000?nX
_NWo000000SoZ;gY0_l0000<ojc0j@03o`000?n_`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H02_nb
`^H2o`0000co]<CV00?o0000okK3i?nf`n@02onf`n@00ol0003o]l?SokO3h`02okO3h`?o00001?ne
`n@00ol0003o]/;SokK2h`0:okK2h`;o0000<_ooool002Oooooo00?o0000ooooooooool0F_ooool0
0ol0003oU[K]oiJfk@06oiJfk@Oo00001OnG]nh00ol0003oVKS]oiVhk@08oiVhk@Co00001onL^N`0
0ol0003oX;[/oj2jk009oj2jk003o`000?nT_>[oY;cZ00WoY;cZ0_l00005ojRmj@?o000000?oZ;oZ
o`000?n/`>T03?n/`>T00ol0003o[l7Wojo1i`09ojo1i`03o`000?nb`^Ko//;V00Ko//;V0ol00000
0onb`nOo0000okC4iP0<okC4iP03o`000?nf`nCo]/?T00_o]/?T00Co0000okO3hol0003o00002?ne
`n@00ol0003o]/;SokK2h`0:okK2h`03o`000?oooooooooo033ooooo000Wooooo`03o`000?oooooo
oooo05_ooooo00?o0000oiJfkOnF]^d01Ol00002oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000
oiVhkOnI^>d01OnI^>d4o`0000[oW;W/00?o0000oj2jk?nP^^`02OnP^^`00ol0003oY;cZojBljP09
ojBljP;o000000CoZ;gYo`000?l0003o00001OnX_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_
`NOo[l7W00Wo[l7W00?o0000ok;2i_nb`^H00onb`^H2o`0000Go//?W00?o0000okC4i_nda>H02ond
a>H00ol0003o]/?TokK3i00:okK3i0;o00002one`n@00ol0003o]/;SokK2h`0:okK2h`03o`000?oo
oooooooo02oooooo000Wooooo`;o0000GOooool2o`0000SoU[K^00?o0000oiNgk_nG]nh02?nG]nh0
1?l0003oVKS]oiVhkOnI^>d3o`0000CoVKS]00?o0000oibik?nL^N`02?nL^N`00ol0003oX;[/oj2j
k009oj2jk003o`000?nT_>[oY;cZ00OoY;cZ1?l00009ojRojP03o`000?n/`>Wo[<3Y00_o[<3Y00?o
0000ojo1ion_`NL02On_`NL00ol0003o//;Vo`000002o`0000So//?W00?o0000okC4i_nda>H02_nd
a>H00ol0003o]/?TokK3i008okK3i0;o000000?o]<CVo`000?ne`n@02one`n@00ol0003o]/;SokK2
h`0:okK2h`03o`000?oooooooooo02kooooo000Vooooo`;o0000Goooool00ol0003oU[K^oiJfkP07
oiJfkP03o`000?nG]nkoUkO^00SoUkO^0ol00008oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000
oj2jk?nP^^`02OnP^^`01?l0003oY;cZojBlj_nT_>X5o`0000;oY;g/00?o0000ojRoj_l000002OnX
_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00So[l7W0_l0000<ok;3i`03o`000?nd
a>Ko]<CV00[o]<CV00?o0000okK3i?nf`n@01Onf`n@2o`0000Co]<CV00?o0000okG3i?ne`n@02_ne
`n@00ol0003o]/;SokK2h`09okK2h`;o0000;oooool002Oooooo00?o0000ooooooooool0G_ooool0
0ol0003oU[K^oiJfkP07oiJfkP03o`000?nG]nkoUkO^00CoUkO^0ol000000onG]nko0000oiVhk@09
oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000oj2jk?nP^^`02?nP^^`4o`0000SoY;g/00?o0000
ojRoj_l000002OnX_nX00ol0003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00Co[l7W0ol00000
0on_`nWo0000ok;3i`0<ok;3i`03o`000?nda>Ko]<CV00[o]<CV00?o0000okK3i?nf`n@00_nf`n@2
o`0000Oo]<CV00?o0000okG3i?ne`n@02One`n@00ol0003o]/;SokK2h`0:okK2h`;o0000;_ooool0
02Oooooo00?o0000ooooooooool0Goooool00ol0003oU[K^oiJfkP07oiJfkP03o`000?nG]nkoUkO^
00?o00001OnG]nh00ol0003oVKS]oiVhk@08oiVhk@03o`000?nL^NcoW;W/00SoW;W/00?o0000oj2j
k?nP^^`01?nP^^`3o`000003oj2lk?l0003oY;g/00[oY;g/00?o0000ojRoj_l000002OnX_nX00ol0
003o[<3Yojc0j@0;ojc0j@03o`000?n_`NOo[l7W00?o00001On_`nT00ol0003o//?Wok;3i`0;ok;3
i`03o`000?nda>Ko]<CV00[o]<CV00Co0000okK3i?l0003o00002_nda>H00ol0003o]L?TokG3i009
okG3i003o`000?nf`^?o]/;S00Ko]/;S0ol000000onc`^Co0000ooooo`0]ooooo`009_ooool00ol0
003oooooooooo`1Qooooo`03o`000?nF]^koU[K^00KoU[K^0ol00009oiNgkP03o`000?nI^>goVKS]
00SoVKS]00?o0000oibik?nL^N`02?nL^N`00ol0003oX;[/oj2jk003o`0000GoX;c/00?o0000ojBm
k?nT_N`02OnT_N`00ol0003oZ;oZo`000009ojRojP03o`000?n/`>Wo[<3Y00[o[<3Y0ol00009ojo3
j@03o`000?nb`nOo//?W00[o//?W00?o0000okC4i_nda>H02_nda>H2o`0000co]<CV00?o0000okG3
i?ne`n@02_ne`n@00ol0003o]/;SokK2h`03okK2h`;o00001Onc`^@00ol0003oooooooooo`0[oooo
o`009_ooool00ol0003oooooooooo`1Rooooo`03o`000?nF]^koU[K^00;oU[K^0ol00002oiJfkP03
o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d02?nI^>d00ol0003oW;W/oibik006oibik0Co
00002OnP_>`00ol0003oY;g/ojBmk009ojBmk003o`000?nX_n[o000000WoZ;oZ00?o0000ojc0jOn/
`>T01_n/`>T3o`000003ojc2j_l0003o[l?Y00[o[l?Y00?o0000ok;3ionb`nL02_nb`nL00ol0003o
]<CVokC4iP06okC4iP?o000000?o/lCWo`000?nda>H03?nda>H00ol0003o]L?TokG3i00:okG3i003
o`000?nf`^?o000000;o00001onc`^@2o`0002cooooo000Vooooo`03o`000?oooooooooo06?ooooo
1?l00006oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d02?nI^>d00ol0003oW;W/
oibik005o`0000;oW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o0000
2_nX_nX00ol0003o[<3Yojc0j@03ojc0j@;o00001On/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`00
0?nb`nOo//?W00[o//?W00?o0000okC4i_nda>H00onda>H2o`0000Go/lCW00?o0000okC4i_nda>H0
2onda>H00ol0003o]L?TokG3i009okG3i0;o00002onc`^@00ol0003oooooooooo`0Zooooo`009_oo
ool2o`0006?ooooo0ol00009oiJfkP03o`000?nG]nkoUkO^00SoUkO^00?o0000oiVhkOnI^>d00onI
^>d7o`0000SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o00002_nX
_nX00ol0003o[<3Yo`000002o`0000So[<;Z00?o0000ojo3jOn_`nT02On_`nT00ol0003o//?Wok;3
i`0:ok;3i`03o`000?nda>Ko000000;o00002?nca>L00ol0003o]<CVokC4iP0:okC4iP03o`000?ne
`nCo]L?T00Ko]L?T0ol000000onc`nKo0000ok?2i00;ok?2i003o`000?oooooooooo02Wooooo000V
ooooo`03o`000?oooooooooo05oooooo0ol00003ooooo`03o`000?nF]^koU[K^00OoU[K^00?o0000
oiNgk_nG]nh01_nG]nh7o`0000GoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003oX;c/oj2lk009
oj2lk003o`000?nT_NcoY;g/00WoY;g/0_l00009ojRojP;o00003?n/`^X00ol0003o[l?Yojo3j@09
ojo3j@03o`000?nb`nOo//?W00Wo//?W0_l0000<ok?4i`03o`000?nda>Ko]<CV00[o]<CV00?o0000
okG3i?ne`n@00one`n@2o`0000Go/l?V00?o0000ok?2i?nc`^@02_nc`^@00ol0003oooooooooo`0X
ooooo`009_ooool00ol0003oooooooooo`1Looooo`?o00001oooool00ol0003oU[K^oiJfkP07oiJf
kP03o`000?nG]nkoUkO^00Go00000onG]nh00ol0003oVKS^oiVhkP07oiVhkP03o`000?nL^^goW;[]
00SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk009ojBmk0;o00001OnX_nX3o`00
00;oZ<7[00?o0000ojc2j_n/`^X02_n/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`000?nb`nOo//?W
00Ko//?W0_l000000onaa>So0000ok?4i`0<ok?4i`03o`000?nda>Ko]<CV00[o]<CV00?o0000okG3
i?l000000_l00008ok?3iP03o`000?nc`^Co/l;T00Wo/l;T00?o0000ooooooooool0:?ooool002Ko
oooo00?o0000ooooooooool0FOooool3o`0000_ooooo00?o0000oiJfk_nF]^h00onF]^h6o`0000Wo
UkO^00?o0000oiVhk_nI^>h01onI^>h00ol0003oW;[]oibjk@08oibjk@03o`000?nP_>coX;c/00Wo
X;c/00?o0000ojBmk?nT_N`02OnT_N`2o`000004ojRoj_l0003o0000o`0000KoZ<7[00?o0000ojc2
j_n/`^X02_n/`^X00ol0003o[l?Yojo3j@09ojo3j@03o`000?nb`nOo//?W00;o//?W0ol00004ok74
j003o`000?nca>Oo/lCW00_o/lCW00?o0000okC4i_nda>H02Onda>H2o`0000co/l?V00?o0000ok?2
i?nc`^@02Onc`^@00ol0003oooooooooo`0Wooooo`009_ooool00ol0003oooooooooo`1Fooooo`?o
00003oooool5o`0000GoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003oVKS^oiVhkP07oiVhkP03
o`000?nL^^goW;[]00SoW;[]00?o0000oj2lk?nP_>`02OnP_>`00ol0003oY;g/ojBmk007ojBmk0Co
00002_nX`N/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n_`nWo[l?Y00[o[l?Y00Co0000ok;3iol0
003o00002?naa>P00ol0003o/lCWok?4i`0;ok?4i`03o`000?nda>Ko]<CV00Ko]<CV0_l000000onb
a>Oo0000ok?3iP0<ok?3iP03o`000?nc`^Co/l;T00Wo/l;T00?o0000ooooooooool09_ooool002Ko
oooo00?o0000ooooooooool0Doooool3o`0001?ooooo00?o0000oiJfkOnF]^d01onF]^d00ol0003o
UkO^oiNgkP08oiNgkP03o`000?nI^>koVKS^00OoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003o
X;c/oj2lk009oj2lk004o`000?nT_NcoY;g/ojBmk0Go00000onT_nd2o`0000[oZ<7[00?o0000ojc2
j_n/`^X02On/`^X00ol0003o[l?Yojo3j@08ojo3j@?o00002onaa>P00ol0003o/lCWok?4i`0;ok?4
i`03o`000?nda>Ko]<CV00;o]<CV0ol00004ok;4i`03o`000?nc`nKo/l?V00_o/l?V00?o0000ok?2
i?nc`^@02?nc`^@2o`0002Oooooo000Uooooo`03o`000?oooooooooo057ooooo0ol0000Gooooo`03
o`000?nF]^goU[K]00OoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003oVKS^oiVhkP07oiVhkP03
o`000?nL^^goW;[]00SoW;[]00?o0000oj2lk?nP_>`02?nP_>`4o`0000WoY;o]00?o0000ojS1jonX
`N/02OnX`N/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n_`nWo[l?Y00Co[l?Y0ol00002ojk4jP03
o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionca>L02onca>L01?l0003o]<CVo`000?l00008ok;4
i`03o`000?nc`nKo/l?V00[o/l?V00?o0000ok?2i?nc`^@02Onc`^@00ol0003oooooooooo`0Uoooo
o`009Oooool3o`0004kooooo0ol0000Jooooo`;o00002OnF]^d00ol0003oUkO^oiNgkP08oiNgkP03
o`000?nI^>koVKS^00OoVKS^00?o0000oibjkOnL^^d02?nL^^d00ol0003oX;c/oj2lk004oj2lk0?o
000000?oX;g]o`000?nT_nd02onT_nd00ol0003oZ<7[ojS1j`09ojS1j`03o`000?n/`^[o[<;Z00Wo
[<;Z00?o0000ojo3jOn_`nT00ol00006ojk4jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionc
a>L02_nca>L2o`0000_o//CW00?o0000ok?3i_nc`nH02_nc`nH00ol0003o/l;Tok?2i008ok?2i0;o
00009_ooool002Gooooo00?o0000ooooooooool0Boooool3o`0001kooooo0_l00009oiJfk@03o`00
0?nG]nkoUkO^00SoUkO^00?o0000oiVhk_nI^>h01onI^>h00ol0003oW;[]oibjk@08oibjk@03o`00
0?nP_>coX;c/00?o00001OnP_Nd00ol0003oY;o]ojBok@0:ojBok@03o`000?nX`N_oZ<7[00WoZ<7[
00?o0000ojc2j_n/`^X02?n/`^X3o`0000[o[/CZ00?o0000ok74j?naa>P02_naa>P00ol0003o/lCW
ok?4i`06ok?4i`?o000000?o/LGXo`000?nba>L02onba>L00ol0003o/l?Vok?3iP0:ok?3iP03o`00
0?nc`^Co/l;T00Co/l;T0ol000000ona`NKo0000o`00000Uooooo`002Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01oooool00ol0003o
ooooooooo`18ooooo`?o00008_ooool2o`0000WoU[K]00?o0000oiNgk_nG]nh02?nG]nh00ol0003o
VKS^oiVhkP07oiVhkP03o`000?nL^^goW;[]00KoW;[]1?l00009oj2mk@03o`000?nT_ngoY;o]00[o
Y;o]00?o0000ojS1jonX`N/02OnX`N/00ol0003o[<;Zojc2jP04ojc2jP?o00000_n[`n/00ol0003o
[/CZojk4jP09ojk4jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4ionca>L00onca>L2o`0000Go
/LGX00?o0000ok;4ionba>L02_nba>L00ol0003o/l?Vok?3iP0:ok?3iP03o`000?nc`^Co/l;T00?o
00001Ona`NH2o`0002Cooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03o`000?oooooooooo04Gooooo0ol0000Voooo
o`;o00002OnF]^d00ol0003oUkO^oiNgkP08oiNgkP03o`000?nI^>koVKS^00OoVKS^00?o0000oibj
kOnL^^d01Ol00003oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000ojBokOnT_nd02_nT_nd00ol0
003oZ<7[ojS1j`09ojS1j`03o`000?n/`^[o[<;Z00?o00001_n[`n/00ol0003o[/CZojk4jP09ojk4
jP03o`000?naa>So/LCX00[o/LCX00?o0000ok?4iol000000_l00008ok75j003o`000?nba>Oo//CW
00Wo//CW00?o0000ok?3i_nc`nH02_nc`nH3o`0000Wo/L7V00?o0000ooooooooool08_ooool000Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`12ooooo`?o0000:_ooool2o`0000WoU[K]00?o0000oiNgk_nG]nh02?nG]nh0
0ol0003oVKS^oiVhkP03oiVhkPKo00002OnM^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngo
Y;o]00[oY;o]00?o0000ojS1jonX`N/02?nX`N/3o`0000[oZl?[00?o0000ojk4j_n^a>X02On^a>X0
0ol0003o/LCXok74j009ok74j0;o00003?naaNP00ol0003o//CWok;4i`09ok;4i`03o`000?nc`nKo
/l?V00Ko/l?V0ol000000ona`^Oo0000ok71iP0:ok71iP03o`000?oooooooooo027ooooo0009oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o
0000ooooooooool0?oooool3o`0002kooooo0_l00009oiJfk@03o`000?nG]nkoUkO^00KoUkO^1ol0
0005oiZjkP03o`000?nM^nkoWK_^00SoWK_^00?o0000oj2mkOnP_Nd02?nP_Nd00ol0003oY;o]ojBo
k@0:ojBok@03o`000?nX`N_oZ<7[00CoZ<7[0ol000000onX`^co0000oj_3j`0;oj_3j`03o`000?n^
a>[o[/CZ00Wo[/CZ00?o0000ok74j?naa>P01_naa>P2o`000003ojo5j_l0003o/LGX00co/LGX00?o
0000ok;4ionba>L02Onba>L00ol0003o/l?Vok?3iP03ok?3iP;o00001Ona`^L00ol0003o/L7Vok71
iP08ok71iP;o00008_ooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o0000<_ooool2o`0000WoU[K]
00?o0000oiNgk_nG]nh01Ol00002oiVhkP03o`000?nJ^^koV[[^00SoV[[^00?o0000oifkk_nM^nh0
2?nM^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngoY;o]00[oY;o]00?o0000ojS1jonX`N/0
0ol00005ojS2k003o`000?n[`n_oZl?[00[oZl?[00?o0000ojk4j_n^a>X02On^a>X00ol0003o/LCX
ok74j002ok74j0?o00001?n_aNX00ol0003o/LGXok75j00;ok75j003o`000?nba>Oo//CW00Wo//CW
00?o0000ok?3i_l000000_l00008ok72i`03o`000?na`NKo/L7V00So/L7V0_l0000Qooooo`002Ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4007ooooo`03
o`000?oooooooooo03Wooooo0ol0000fooooo`;o00001OnF]^d6o`0000SoVKS^00?o0000oiZjk_nJ
^^h02?nJ^^h00ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000ojBokOnT
_nd02?nT_nd4o`0000WoZ<;/00?o0000oj_3jon[`n/02_n[`n/00ol0003o[/CZojk4jP09ojk4jP04
o`000?naa>So0000o`0000So[lGZ00?o0000ok75j?naaNP02_naaNP00ol0003o//CWok;4i`09ok;4
i`;o00003?na`^L00ol0003o/L7Vok71iP08ok71iP03o`000?oooooooooo01oooooo0009ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000
ooooooooool0=oooool3o`0003[ooooo1_l00004oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000
oiZjk_nJ^^h02?nJ^^h00ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00SoX;g]00?o0000
ojBokOnT_nd01?nT_nd3o`0000;oYL7]00?o0000ojS2k?nX`^`02OnX`^`00ol0003oZl?[oj_3j`0:
oj_3j`03o`000?n^a>[o[/CZ00So[/CZ0_l0000;ojo5jP03o`000?naaNSo/LGX00[o/LGX00?o0000
ok;4ionba>L01_nba>L2o`000003ok34j?l0003o/L;W00_o/L;W00?o0000ok71i_na`NH02?na`NH2
o`00023ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool0=?ooool3o`0003kooooo00?o0000oiRgkOnH]nd01onH
]nd00ol0003oVKS^oiVhkP08oiVhkP03o`000?nJ^^koV[[^00SoV[[^00?o0000oifkk_nM^nh02?nM
^nh00ol0003oX;g]oj2mk@08oj2mk@03o`000?nT_ngoY;o]00?o00001_nU`Nd00ol0003oZ<;/ojS2
k009ojS2k003o`000?n[`n_oZl?[00[oZl?[00?o0000ojk4j_n^a>X01?n^a>X3o`0000;o[LG[00?o
0000ojo5j_n_aNX02On_aNX00ol0003o/LGXok75j00:ok75j003o`000?nba>Oo//CW00;o//CW0ol0
0004ok34j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok71i_na`NH02?na`NH2o`0001oooooo000T
ooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?nH]ngoV;O]00OoV;O]00?o0000
oiVhk_nI^>h02?nI^>h00ol0003oV[[^oiZjkP08oiZjkP03o`000?nM^nkoWK_^00SoWK_^00?o0000
oj2mkOnP_Nd01_nP_Nd4o`0000[oYL7]00?o0000ojS2k?nX`^`02OnX`^`00ol0003oZl?[oj_3j`0:
oj_3j`03o`000?n^a>[o[/CZ00?o00001_n]aN/00ol0003o[lGZojo5jP09ojo5jP03o`000?naaNSo
/LGX00[o/LGX00Co0000ok;4iol0003o00002?n`a>P00ol0003o/L;Wok72i`0:ok72i`03o`000?na
`NKo/L7V00So/L7V0_l0000Nooooo`009?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool0
0ol0003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZjk_nJ^^h02?nJ^^h0
0ol0003oWK_^oifkkP08oifkkP03o`000?nP_NgoX;g]00Go00000onR_nh00ol0003oYL7]ojG1k@09
ojG1k@03o`000?nX`^coZ<;/00WoZ<;/00?o0000oj_3jon[`n/02?n[`n/4o`0000[o[LG[00?o0000
ojo5j_n_aNX02On_aNX00ol0003o/LGXok75j008ok75j0?o00002on`a>P00ol0003o/L;Wok72i`09
ok72i`03o`000?na`NKo/L7V00So/L7V0_l0000Nooooo`009?ooool00ol0003oooooooooo`0/oooo
o`?o0000BOooool00ol0003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZj
k_nJ^^h02?nJ^^h00ol0003oWK_^oifkkP06oifkkPCo00002OnR_nh00ol0003oYL7]ojG1k@09ojG1
k@03o`000?nX`^coZ<;/00WoZ<;/00?o0000oj_3jon[`n/01?n[`n/3o`0000;oZlC/00?o0000ojg5
jon]aN/02_n]aN/00ol0003o[lGZojo5jP09ojo5jP03o`000?naaNSo/LGX00Co/LGX0ol00002ojo5
jP03o`000?n`a>So/<CX00[o/<CX00?o0000ok72iona`^L02Ona`^L00ol0003o/L7Vok71iP04ok71
iP?o000000?o[/3Wo`000?l000007Oooool002Cooooo00?o0000ooooooooool0:Oooool3o`0004go
oooo00?o0000oiRgkOnH]nd01onH]nd00ol0003oVKS^oiVhkP08oiVhkP03o`000?nJ^^koV[[^00So
V[[^00?o0000oifkk_nM^nh01Ol00003oinmkP03o`000?nR_nkoX[o^00SoX[o^00?o0000ojG1kOnU
`Nd02OnU`Nd00ol0003oZ<;/ojS2k009ojS2k003o`000?n[`n_oZl?[00?o00001_n[a>`00ol0003o
[LG[ojg5j`0:ojg5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok75j?naaNP00ol00006ojo5jP03
o`000?n`a>So/<CX00[o/<CX00?o0000ok72iona`^L02Ona`^L00ol0003o/L7Vok71iP03o`0000Go
[/3W0_l0000Looooo`009?ooool00ol0003oooooooooo`0Vooooo`?o0000DOooool00ol0003oV;O]
oiRgk@07oiRgk@03o`000?nI^>koVKS^00SoVKS^00?o0000oiZjk_nJ^^h01_nJ^^h4o`0000WoWkg^
00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@09ojG1k@03o`000?nX`^coZ<;/00SoZ<;/
0ol0000:oj_4k003o`000?n]aN_o[LG[00[o[LG[00?o0000ojo5j_n_aNX02?n_aNX3o`0000[o[lGZ
00?o0000ok34j?n`a>P02_n`a>P00ol0003o/L;Wok72i`08ok72i`?o00002On^`>L2o`0001_ooooo
000Sooooo`;o00009Oooool3o`0005Gooooo00?o0000oiRgkOnH]nd01onH]nd00ol0003oVKS^oiVh
kP08oiVhkP03o`000?nJ^^koV[[^00Go00000onM^nh00ol0003oWkg^oinmkP08oinmkP03o`000?nR
_nkoX[o^00SoX[o^00?o0000ojG1kOnU`Nd02?nU`Nd2o`0000KoZ<;/0ol00002ojS3k@03o`000?n[
a>coZlC/00WoZlC/00?o0000ojg5jon]aN/02_n]aN/00ol0003o[lGZojo5jP04ojo5jP?o000000?o
[/G[o`000?n_aNX02on_aNX00ol0003o/<CXok34j00:ok34j003o`000?na`^Oo/L;W00Co/L;W0ol0
00000on]`^Wo0000ojk0i`0:ojk0i`03o`000?oooooooooo01Wooooo000Tooooo`03o`000?oooooo
oooo023ooooo0ol0001Iooooo`03o`000?nH]ngoV;O]00OoV;O]00?o0000oiVhk_nI^>h01_nI^>h4
o`0000WoWK_^00?o0000oinmk_nO_Nh02?nO_Nh00ol0003oX[o^oj:okP08oj:okP03o`000?nU`Ngo
YL7]00SoYL7]0_l00002ojS2k0?o00001_nX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o
[LG[00[o[LG[00?o0000ojo5j_n_aNX00ol00005ojk5j`03o`000?n_aN[o[lGZ00[o[lGZ00?o0000
ok34j?n`a>P02_n`a>P00ol0003o/L;Wok72i`03o`0000Go[L;Y00?o0000ojk0ion^`>L02On^`>L0
0ol0003oooooooooo`0Hooooo`008oooool00ol0003oooooooooo`0Nooooo`?o0000GOooool00ol0
003oV;O]oiRgk@07oiRgk@03o`000?nI^>koVKS^00Go00000onK^Nd00ol0003oWK_^oifkkP08oifk
kP03o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@08ojG1
k@?o00002_nX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o[LG[00Wo[LG[0ol00009ojk5
j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`a>P02_n`a>P3o`0000Wo[L;Y00?o0000ojk0
ion^`>L02On^`>L00ol0003oooooooooo`0Gooooo`008oooool00ol0003oooooooooo`0Kooooo`?o
0000HOooool00ol0003oV;O]oiRgk@03oiRgk@Ko00002OnK^Nd00ol0003oWK_^oifkkP08oifkkP03
o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh02?nR_nh00ol0003oYL7]ojG1k@04ojG1k@?o
000000?oYL;^o`000?l000002onX`nd00ol0003oZlC/oj_4k009oj_4k003o`000?n]aN_o[LG[00Ko
[LG[0_l000000on/aNco0000ojk5j`0:ojk5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`
a>P01_n`a>P3o`000003ojg3j_l0003o[L;Y00[o[L;Y00?o0000ojk0ion^`>L02?n^`>L2o`0001So
oooo000Sooooo`03o`000?oooooooooo01Sooooo0ol0001Uooooo`Go00001OnK^>`00ol0003oVkW]
oi^ik@08oi^ik@03o`000?nM^nkoWK_^00SoWK_^00?o0000oinmk_nO_Nh02?nO_Nh00ol0003oX[o^
oj:okP08oj:okP03o`000?nU`NgoYL7]00?o00001OnU`^h2o`0000_oZ<?]00?o0000oj_4k?n[a>`0
2On[a>`00ol0003o[LG[ojg5j`02ojg5j`?o00001?n/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`00
0?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?n`a>P00on`a>P2o`0000Go[L?Z00?o0000ojg2jOn]`^T0
2On]`^T00ol0003o[/3Wojk0i`08ojk0i`03o`000?oooooooooo01Kooooo000Sooooo`03o`000?oo
oooooooo01Gooooo0ol0001Xooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK
^Nd00ol0003oWK_^oifkkP08oifkkP03o`000?nO_NkoWkg^00SoWkg^00?o0000oj:ok_nR_nh01_nR
_nh4o`0000WoYL;^0_l0000;ojS3k@03o`000?n[a>coZlC/00WoZlC/00Co0000ojg5jol0003o0000
2?n/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_aN[o[lGZ00Wo[lGZ00?o0000ok34j?l00000
0_l00008ojg3jP03o`000?n]`^Wo[L;Y00So[L;Y00?o0000ojk0ion^`>L02On^`>L00ol0003ooooo
ooooo`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oVkS/oi^h
k008oi^hk003o`000?nK^NgoVkW]00SoVkW]00?o0000oifkk_nM^nh02?nM^nh00ol0003oWkg^oinm
kP08oinmkP03o`000?nR_nkoX[o^00Go00000onS`>h00ol0003oYL;^ojG2kP08ojG2kP;o00002onX
`nd00ol0003oZlC/oj_4k008oj_4k0;o00002on/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_
aN[o[lGZ00So[lGZ0_l0000<ojg3jP03o`000?n]`^Wo[L;Y00So[L;Y00?o0000ojk0ion^`>L02On^
`>L00ol0003oooooooooo`0Dooooo`008_ooool3o`00013ooooo0ol0001`ooooo`03o`000?nK^>co
VkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003oWK_^oifkkP08oifkkP03o`000?nO_Nko
Wkg^00KoWkg^1?l00009oj?0kP03o`000?nU`^koYL;^00SoYL;^0_l0000;ojS3k@03o`000?n[a>co
ZlC/00CoZlC/0ol00002oj[5k@03o`000?n/aNco[<G/00Wo[<G/00?o0000ojk5jon^aN/02On^aN/0
0ol0003o[lGZojo5jP04ojo5jP?o00000_n/a>/00ol0003o[L?Zojg3jP0:ojg3jP03o`000?n]`^Wo
[L;Y00So[L;Y00?o0000ojk0ion^`>L01on^`>L3o`0001Gooooo000Sooooo`03o`000?oooooooooo
00cooooo0ol0001dooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0
003oWK_^oifkkP08oifkkP03o`000?nO_NkoWkg^00Go00000onQ_^h00ol0003oXl3^oj?0kP08oj?0
kP03o`000?nU`^koYL;^00OoYL;^00?o0000ojG2k_l000002onX`nd00ol0003oZlC/oj_4k003o`00
00KoZ/G]00?o0000ojc5k?n/aN`02On/aN`00ol0003o[/G[ojk5j`09ojk5j`03o`000?n_aN[o[lGZ
00?o00001_n/a>/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n]`^Wo[L;Y00Wo[L;Y00Co0000ojk0
ion^`>Oo[/3W1Ol00002ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo
00Wooooo0ol0001hooooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0
003oWK_^oifkkP06oifkkPCo00002OnQ_^h00ol0003oXl3^oj?0kP08oj?0kP03o`000?nU`^koYL;^
00OoYL;^00?o0000ojG2k_l000002OnX`nd4o`0000[oZ/G]00?o0000ojc5k?n/aN`02On/aN`00ol0
003o[/G[ojk5j`08ojk5j`?o00002_n/a>/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n]`^Wo[L;Y
00So[L;Y1_l00005ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo00Ko
oooo0ol0001looooo`03o`000?nK^>coVkS/00SoVkS/00?o0000oi^ikOnK^Nd02?nK^Nd00ol0003o
WK_^oifkkP05o`0000;oWkc]00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003oXl3^oj?0kP08oj?0kP03
o`000?nU`^koYL;^00OoYL;^00?o0000ojG2k_l000000onX`nd5o`0000;oZ<C^00?o0000oj[5kOnZ
aNd02_nZaNd00ol0003o[<G/ojc5k009ojc5k003o`000?n^aN_o[/G[00Co[/G[0ol000000on/aNco
0000ojc4j`0;ojc4j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000ojg2jOn]`^T01?n]`^T6o`0000So
oooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool01?ooool3o`00083ooooo
00?o0000oi^hk?nK^>`02?nK^>`00ol0003oVkW]oi^ik@06oi^ik@Co00002?nO_>d00ol0003oXKk^
oj6nkP09oj6nkP03o`000?nS`>koXl3^00SoXl3^00?o0000ojG2k_nU`^h01onU`^h5o`0000SoZ<C^
00?o0000oj[5kOnZaNd02_nZaNd00ol0003o[<G/ojc5k009ojc5k003o`000?n^aN_o[/G[00?o0000
1On/aN`00ol0003o[<C[ojc4j`0:ojc4j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000ojg2jOn]`^T0
1Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?ooooooooooooooo`?o0000
Q?ooool00ol0003oVkS/oi^hk008oi^hk003o`000?nK^NgoVkW]00Go00000onN^n`00ol0003oWkc]
oinlk@07oinlk@03o`000?nQ_^koXKk^00WoXKk^00?o0000oj?0k_nS`>h02?nS`>h00ol0003oYL;^
ojG2kP04ojG2kPCo000000?oYl?^o`000?nXa>h02OnXa>h00ol0003oZ/G]oj[5k@0:oj[5k@03o`00
0?n/aNco[<G/00So[<G/0ol00009ojc5k003o`000?n/a>_o[<C[00[o[<C[00?o0000ojg3j_n]`nX0
2?n]`nX5o`0000oooooo00?o0000ooooooooool04oooool002;ooooo1?l00028ooooo`03o`000?nK
^>coVkS/00KoVkS/1?l00009oijkk003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02OnQ
_^h00ol0003oXl3^oj?0kP08oj?0kP03o`000?nU`^koYL;^00?o00001?nW`nh00ol0003oYl?^o`00
000:ojS4kP03o`000?nZaNgoZ/G]00[oZ/G]00?o0000ojc5k?n/aN`01?n/aN`3o`000003oj_6kOl0
003o[<G/00[o[<G/00?o0000ojc4jon/a>/02_n/a>/00ol0003o[L?Zojg3jP04ojg3jPGo00004_oo
ool00ol0003oooooooooo`0Cooooo`008_ooool3o`0008[ooooo00?o0000oi^hk?nK^>`01Ol00003
oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO_>d00ol0003oXKk^oj6nkP09
oj6nkP03o`000?nS`>koXl3^00KoXl3^1?l00008ojO3kP03o`000?nW`nko000000[oZ<C^00?o0000
oj[5kOnZaNd02_nZaNd00ol0003o[<G/ojc5k003o`0000GoZlK]00?o0000ojc5k?n/aN`02On/aN`0
0ol0003o[<C[ojc4j`0:ojc4j`03o`000?n]`n[o[L?Z00Co00005oooool00ol0003oooooooooo`0B
ooooo`009?ooool00ol0003oooooooooo`29ooooo`;o00002OnN^N/00ol0003oW[_/oijkk008oijk
k003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02OnQ_^h00ol0003oXl3^oj?0kP05o`00
00?oYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l0000:ojS4kP03o`000?nZaNgo
Z/G]00SoZ/G]1?l00009oj_6k@03o`000?n/aNco[<G/00Wo[<G/00?o0000ojc4jon/a>/02?n/a>/5
o`0001[ooooo00?o0000ooooooooool04_ooool001Kooooo00?ok^k^o`000?l000000_l000000ol@
413oooooooooo`07ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN^N/00ol0
003oW[_/oijkk008oijkk003o`000?nO_>goWkc]00OoWkc]00?o0000oj6nk_nQ_^h02?nQ_^h3o`00
00WoYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l0000:ojS4kP03o`000?nZaNgo
Z/G]00CoZ/G]0ol00003oj[5kP03o`000?n[a^goZlK]00SoZlK]00?o0000ojc5k?n/aN`02On/aN`0
0ol0003o[<C[ojc4j`04ojc4j`Go00007Oooool00ol0003oooooooooo`0Booooo`005_ooool01Omg
MgOoV9RHooooool0003oMgMg00_ooooo00?o0000ooooooooool0ROooool00ol0003oW[W[oijij`08
oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO_>d00ol0003oXKk^oj6nkP04
oj6nkP?o00000_nT`>d00ol0003oYL;^ojG2kP08ojG2kP03o`000?nW`nkoYl?^00KoYl?^00Co0000
ojO3k_nW`nko00002_nXa>h00ol0003oZ/G]oj[5k@03o`0000OoZ/G^00?o0000oj_6kOn[a^d02?n[
a^d00ol0003o[<G/ojc5k009ojc5k003o`000?n/a>_o[<C[00Co00008Oooool00ol0003ooooooooo
o`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00cooooo00?o0000ooooooooool0ROoo
ool00ol0003oW[W[oijij`08oijij`03o`000?nN^ncoW[_/00SoW[_/00?o0000oinlkOnO_>d01onO
_>d00ol0003oXKk^oj6nkP03o`0000KoY<3]00?o0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3
kP06ojO3kP04o`000?nW`nkoYl?^o`0000SoZ<C^1?l0000;oj[5kP03o`000?n[a^goZlK]00SoZlK]
00?o0000ojc5k?n/aN`02?n/aN`4o`0002Cooooo00?o0000ooooooooool04_ooool001Kooooo00?o
0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN
^N/00ol0003oW[_/oijkk008oijkk003o`000?nO_>goWkc]00GoWkc]1?l0000:ojC0k@03o`000?nU
`^koYL;^00SoYL;^00?o0000ojO3k_nW`nh01_nW`nh01?l0003oYl?^ojO3k_l00002ojS4kPGo0000
1?nYaNh00ol0003oZ/G^oj[5kP09oj[5kP03o`000?n[a^goZlK]00SoZlK]00?o0000ojc5k?n/aN`0
1?n/aN`4o`0002Oooooo00?o0000ooooooooool04_ooool001Kooooo00?o0000ooooooooool00_l0
000>ooooo`03o`000?oooooooooo08Wooooo00?o0000oijijonN^N/02?nN^N/00ol0003oW[_/oijk
k008oijkk003o`000?nO_>goWkc]00Co00001?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`000?nU
`^koYL;^00SoYL;^00?o0000ojO3k_nW`nh01_nW`nh00ol0003oYl?^o`000002o`0000[oZLG^00?o
0000oj[5k_nZaNh02OnZaNh00ol0003oZlK]oj_6k@08oj_6k@03o`000?n/aNco[<G/00Co0000:_oo
ool00ol0003oooooooooo`0Booooo`005_ooool01Ol@413oooooooooool0003o410@00oooooo00?o
0000ooooooooool0ROooool00ol0003oW[W[oijij`08oijij`03o`000?nN^ncoW[_/00KoW[_/1?l0
0009oj>nk003o`000?nT`>goY<3]00SoY<3]00?o0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3
kP04ojO3kP?o00000_nXa>h00ol0003oZLG^ojW5kP09ojW5kP03o`000?nZaNkoZ/G^00WoZ/G^00?o
0000oj_6kOn[a^d01_n[a^d4o`0002kooooo00?o0000ooooooooool04_ooool001Kooooo00GoMgMg
oiRHV?oooooo0000ogMgM`0@ooooo`;o0000R_ooool00ol0003oW[W[oijij`08oijij`03o`000?nN
^ncoW[_/00Go00000onR_>/00ol0003oXkk/oj>nk008oj>nk003o`000?nT`>goY<3]00SoY<3]00?o
0000ojG2k_nU`^h02?nU`^h00ol0003oYl?^ojO3kP03o`0000?oZ<C^00Co0000ojS4k_nXa>ko0000
2onYaNh00ol0003oZ/G^oj[5kP09oj[5kP03o`000?n[a^goZlK]00Ko0000<Oooool00ol0003ooooo
ooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`000?l0003ok^k^01;ooooo00?o0000ooooooooool0
R?ooool00ol0003oW[W[oijij`06oijij`Co00002OnR_>/00ol0003oXkk/oj>nk008oj>nk003o`00
0?nT`>goY<3]00SoY<3]00?o0000ojG2k_nU`^h01onU`^h3o`0000KoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000;ojW5kP03o`000?nZaNkoZ/G^00SoZ/G^1_l0000dooooo`03o`000?oooooooooo01;o
oooo000/ooooo`03o`000?oooooo000008[ooooo00?o0000oijijonN^N/01Ol00002oj:jjP03o`00
0?nR_>_oX[c[00WoX[c[00?o0000oj>nk?nS_^`02?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`00
0?nU`^koYL;^00?oYL;^0ol00002ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000;ojW5kP03o`000?nZaNkoZ/G^00CoZ/G^1Ol0000hooooo`03o`000?oooooooooo01;o
oooo000_ooooo`03o`000?oooooooooo08Sooooo0_l00008oj:jjP03o`000?nR_>_oX[c[00WoX[c[
00?o0000oj>nk?nS_^`02?nS_^`00ol0003oY<3]ojC0k@08ojC0k@03o`000?nU`^ko000000;o0000
1_nW`nd00ol0003oZ<C^ojS4kP05ojS4kP05o`000?nXa>koZ<C^ojS4k_l000002onYaNh00ol0003o
Z/G^oj[5kP05o`0003cooooo00?o0000ooooooooool04Oooool0033ooooo00?o0000ooooooooool0
Qoooool2o`0000WoX[[Z00?o0000oj:ljonR_>/02OnR_>/00ol0003oXkk/oj>nk008oj>nk003o`00
0?nT`>goY<3]00KoY<3]0ol0000:ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00Go0000ojS4k_nXa>ko
Z<C^o`00000:ojW5kPGo0000?oooool00ol0003oooooooooo`0Aooooo`00<Oooool00ol0003ooooo
ooooo`27ooooo`;o00002OnR^^X00ol0003oX[c[oj:lj`09oj:lj`03o`000?nS_^coXkk/00SoXkk/
00?o0000ojC0kOnT`>d01Ol00003ojO1k003o`000?nW`ngoYl?]00SoYl?]00?o0000ojS4k_nXa>h0
1OnXa>h01Ol0003oZ<C^ojS4k_nXa>ko000000KoZLG^1?l00013ooooo`03o`000?oooooooooo017o
oooo000booooo`03o`000?oooooooooo08Oooooo0_l00009oj:jjP03o`000?nR_>_oX[c[00WoX[c[
00?o0000oj>nk?nS_^`01_nS_^`4o`0000WoYl7/00?o0000ojO3kOnW`nd02?nW`nd00ol0003oZ<C^
ojS4kP05ojS4kP05o`000?nXa>koZ<C^ojS4k_l000000_nYaNh4o`0004Kooooo00?o0000oooooooo
ool04Oooool003?ooooo00?o0000ooooooooool0Qoooool2o`0000WoX[[Z00?o0000oj:ljonR_>/0
2OnR_>/00ol0003oXkk/oj>nk005o`0000?oY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003oYl?]
ojO3k@08ojO3k@03o`000?nXa>koZ<C^00GoZ<C^00?o0000ojS4k_nXa>h01?l00019ooooo`03o`00
0?oooooooooo017ooooo000dooooo`;o0000R?ooool2o`0000WoX[[Z00?o0000oj:ljonR_>/02?nR
_>/3o`0000WoY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003oYl?]ojO3k@08ojO3k@03o`000?nX
a>koZ<C^00CoZ<C^0ol0001=ooooo`03o`000?oooooooooo017ooooo000fooooo`03o`000?oooooo
oooo08Kooooo0_l00009oj:jjP03o`000?nR_>_oX[c[00CoX[c[0ol000000onV_N[o0000ojJoj`0:
ojJoj`03o`000?nW`NcoYl7/00SoYl7/00?o0000ojO3kOnW`nd02?nW`nd00ol0003oZ<C^ojS4kP03
o`000003ooooool0003ooooo04gooooo00?o0000ooooooooool04Oooool003Oooooo0_l00027oooo
o`;o00002OnR^^X00ol0003oX[c[oj:lj`03o`0000GoY[gZ00?o0000ojJojonV_n/02OnV_n/00ol0
003oYl7/ojO1k008ojO1k003o`000?nW`ngoYl?]00KoYl?]1?l00005ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool003Kooooo00?o0000ooooool00000R?ooool2o`0000Oo
X[[Z1?l00009ojJmjP03o`000?nV_n_oY[o[00WoY[o[00?o0000ojO1k?nW`N`02?nW`N`00ol0003o
Yl?]ojO3k@05o`0000[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`00
>Oooool00ol0003oooooooooo`26ooooo`;o00000_nR^^X4o`0000?oY[_X00?o0000ojJmj_nV_NX0
2?nV_NX00ol0003oY[o[ojJoj`09ojJoj`03o`000?nW`NcoYl7/00OoYl7/1Ol0000>ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool04Oooool003[ooooo00?o0000ooooooooool0Q_oo
ool3o`0000SoY[_X00?o0000ojJmj_nV_NX02?nV_NX00ol0003oY[o[ojJoj`09ojJoj`03o`000?nW
`NcoYl7/00?oYl7/1Ol0000Booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04Ooo
ool003_ooooo00?o0000ooooooooool0Q_ooool00ol0003oY[_XojJkj008ojJkj003o`000?nV_N[o
Y[gZ00SoY[gZ00?o0000ojJojonV_n/02OnV_n/00ol0003oYl7/o`000003o`0001Oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0@ooooo`00??ooool00ol0003oooooooooo`26oooo
o`03o`000?nV^nSoY[_X00SoY[_X00?o0000ojJmj_nV_NX02?nV_NX00ol0003oY[o[ojJoj`08ojJo
j`?o00006oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo013ooooo000mooooo`;o
0000Qoooool00ol0003oY[_XojJkj008ojJkj003o`000?nV_N[oY[gZ00SoY[gZ00?o0000ojJojonV
_n/01?nV_n/3o`0001oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0@ooooo`00
?oooool00ol0003oooooooooo`25ooooo`03o`000?nV^nSoY[_X00SoY[_X00?o0000ojJmj_nV_NX0
2?nV_NX00ol0003oY[o[ojJoj`03o`0002;ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0@ooooo`00@?ooool00ol0003oooooooooo`25ooooo`03o`000?nV^nSoY[_X00SoY[_X00?o
0000ojJmj_nV_NX01_nV_NX4o`0002Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`0@ooooo`00@Oooool2o`0008Kooooo00?o0000ojJkj?nV^nP02?nV^nP00ol0003oY[gZojJmjP05
o`0002_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`00@?ooool00ol0
003oooooo`000027ooooo`03o`000?nV^nSoY[_X00OoY[_X1Ol0000_ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0QOooool00ol0003o
Y[_XojJkj003ojJkj0Co0000=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo013o
oooo0014ooooo`03o`000?oooooooooo08Gooooo00?o0000ojJkj?l000000ol0000hooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool04?ooool004Gooooo00?o0000ooooooooool0QOoo
ool2o`0003cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`00A_ooool2
o`0008Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo013ooooo0018ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo0019ooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oo
oooo001:ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00oooooo001:ooooo`;o0000POooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03oooool004cooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool03oooool004gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03oooool004kooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool03oooool004oooooo0_l0001looooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0?ooooo`00DOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`00D_ooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0?ooooo`00Doooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0?ooooo`00E?ooool3o`0007Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oo
oooo001Dooooo`;o0000Moooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool03_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`08ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00kooooo000hooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`08ooooo`;o0000Loooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool003Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool003Sooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0>oooo
o`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0>ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`;o0000K_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03_ooool005oooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool0063ooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03_ooool0067ooooo0_l0001Zooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`00Hoooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=
ooooo`00I?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0=ooooo`00IOooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`00
I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0=ooooo`00I_ooool3o`0006Cooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo001Xooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00gooooo001Yooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo001Zooooo`;o0000HOooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool006cooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03Oooool006gooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool006kooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03?ooool006oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03?ooool006oooooo0ol0001Kooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`00
LOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0<ooooo`00L_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`00Loooool2
o`0005Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00cooooo001eooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo001fooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00co
oooo001gooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00cooooo001hooooo`;o0000Doooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool007Sooooo0_l0001C
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<
ooooo`00N_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0<ooooo`00Noooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`00
O?ooool2o`0004oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00_ooooo001nooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo001oooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo0020ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo0021ooooo`?o0000BOooool00ol0003o
ooooooooo`1Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool007Kooooo
1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo001hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0;ooooo`00N?ooool00ol0003oooooooooo`0:ooooo`;o0000A_ooool00ol0
003oooooooooo`1/ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool005co
oooo0ol000000ol@413oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02oooool005kooooo00?o410@okZj^_ooool05oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo001Nooooo`03oiRHV?lb<S;ooooo01Oooooo00?o0000ooooooooool03_oo
ool2o`0004;ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo001Nooooo`03omgMgOl0003o^[Zj01Gooooo00?oEEEEofIVI_l000004?ooool2
o`0004;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00[ooooo001Nooooo`03oeEEEOmgMgOoA4A402[ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool005go
oooo00GogMgMoa0@4?oooooo8B4QomgMg@0Zooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo001Mooooo`05
ofIVI_n7QhOooooooiRHV?mEEED0:oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00G?ooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo02[ooooo0_l0000mooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00G?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo02_ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool0097ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool0097ooooo0_l0000jooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00Toooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`00U?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`00UOooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00
U_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`00Uoooool2o`0003Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo002Iooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo002Iooooo`?o0000<Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool009_ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool009cooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool009gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool009kooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool009oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00:3ooooo0_l0000[ooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`00
XOooool2o`0002[ooooo00?o0000ooooooooool0P_ooool01Ol0003ooooooooooooooooo000000[o
oooo002Sooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Poooool01?l0003ooooo
ooooool0000:ooooo`00Y?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooool000002_ooool00:Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`25ooooo`;o00002_ooool00:Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`24
ooooo`?o00002_ooool00:Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`20oooo
o`Co00003Oooool00:Sooooo00Co0000ooooool0003o00008Oooool00ol0003oooooooooo`1loooo
o`Co00004Oooool008kooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Kooooo0_l0000Rooooo`03o`000?oooooooooo07Sooooo1?l0000Eoooo
o`00T?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0M?ooool4o`0001Wooooo002@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo073ooooo1?l0000Mooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1]ooooo`?o00008Ooo
ool0093ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Yooooo`Co00009?ooool0093ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0IOooool4o`0002Sooooo002@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool3o`0001[ooooo00?o0000ooooooooool0HOooool4o`0002cooooo002>ooooo`03
oeEEEOmVIVKo000000gooooo1?l0000>ooooo`;o00006oooool00ol0003oooooooooo`1Mooooo`Co
0000<?ooool00;;ooooo0_l0000Iooooo`03o`000?oooooooooo05Wooooo1?l0000dooooo`00]?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05Gooooo1?l0000hooooo`00]Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo057ooooo1?l0000looooo`00]_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04gooooo1?l00010ooooo`00]oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo1?l00014ooooo`00^?ooool2o`0001?ooooo
00?o0000ooooooooool0AOooool4o`0004Sooooo002iooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0@Oooool4o`0004cooooo002jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0?_ooool3o`00053ooooo002kooooo`;o00004?ooool00ol0003oooooooooo`0joooo
o`Co0000Doooool00;gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`Co
0000Eoooool00;kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`Co0000
Foooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02kooooo1?l0001Oooooo`00_oooool2
o`0000cooooo00?o0000ooooooooool0:_ooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09_ooool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08_ooool4o`0006_ooooo0033ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07_ooool4o`0006oooooo0034ooooo`;o00001oooool00ol0003ooooooooo
o`0Jooooo`Co0000Loooool00<Kooooo0ol00004ooooo`03o`000?oooooooooo01Kooooo1?l0001g
ooooo`00a_ooool2o`0000Gooooo00?o0000ooooooooool04oooool3o`0007_ooooo0038ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool4o`0007kooooo0039ooooo`05o`00
0?ooooooooooooooool000003Oooool4o`0008;ooooo003:ooooo`04o`000?ooooooooooo`0000Wo
oooo1?l00026ooooo`00boooool00ol0003oooooo`000005ooooo`Co0000R_ooool00<cooooo1ol0
002>ooooo`00`_ooool5o`0000Kooooo0_l0002Booooo`00`_ooool01OnHV9So8B4Qonk^k_oooooo
A4A409[ooooo0033ooooo`03oiRHV?lQ8B7ok^k^09_ooooo0034ooooo`03oiRHV?lQ8B7ok^k^09[o
oooo0035ooooo`03ogMgMomVIVKooooo09Wooooo0036ooooo`03o`000?oooooooooo09Sooooo0032
ooooo`05o`000?nj^[[ooooooiRHV?l@4100V_ooool00<;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c02Jooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00oooo
oomRooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00YOooool3o`000003oa0@
4?oooooooooo0;Kooooo002Cooooo`;o00002oooool00ol0003o^[Zjooooo`04ooooo`03oa0@4?nj
^[[ooooo00Gooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0VOoo
ool009?ooooo00?o0000ooooooooool02_ooool2oc8b<PGooooo00?oV9RHoc8b<_ooool01Oooool2
oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Y[ooooo0028ooooo`05oa0@4?l0003o0000
o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00Co410@o`000?m4A4Coc<c<L_ooool008[ooooo00?o0000ooooooooool01_ooool02_l0
003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Co
oooo00?oEEEEogMgMom4A4@01Oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Ko410@okZj
^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00onHV9So410@omgMg@1aooooo`00R_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03ohN7QomEEEGooooo073ooooo002:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:oooo
o`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?lQ8B7o0000oeEEEOl00000LOooool008[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01OlQ8B7o
QhN7oooooonHV9So0000077ooooo0027ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01_ooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05o`000?ooooooooooooooool00000LOooool008Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0LOooool008Oooooo1ol00005oooo
o`;o00008Oooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^077ooooo003o
ooooof;ooooo003oooooof;ooooo003oooooof;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11253 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.066106 1.21212 -1.11022e-16 1.21212 [
[.5 1.12503 -41 0 ]
[.5 1.12503 41 24.5 ]
[.03831 .17557 -5.85635 -9 ]
[.03831 .17557 .14365 0 ]
[.12814 .13981 -17.2021 -9 ]
[.12814 .13981 .79789 0 ]
[.22015 .10319 -16.8352 -9 ]
[.22015 .10319 1.16484 0 ]
[.31441 .06568 -16.4682 -9 ]
[.31441 .06568 1.53178 0 ]
[.411 .02725 -16.1013 -9 ]
[.411 .02725 1.89873 0 ]
[.51 -0.01213 -5.24477 -9 ]
[.51 -0.01213 .75523 0 ]
[.21792 .02683 -9.25094 -12 ]
[.21792 .02683 .74906 0 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[.1484 .76875 -18 -3.08128 ]
[.1484 .76875 0 5.91872 ]
[.29382 .89692 -6 -3.18183 ]
[.29382 .89692 0 5.81817 ]
[.42456 1.01215 -18 -3.26907 ]
[.42456 1.01215 0 5.73093 ]
[.54272 1.11629 -6 -3.34548 ]
[.54272 1.11629 0 5.65452 ]
[.22112 .91822 -10 -4.24244 ]
[.22112 .91822 0 7.75756 ]
[.03467 .19213 -6 -2.71522 ]
[.03467 .19213 0 6.28478 ]
[.02559 .27239 -18 -2.7611 ]
[.02559 .27239 0 6.2389 ]
[.01617 .35567 -18 -2.80881 ]
[.01617 .35567 0 6.19119 ]
[.00638 .44212 -18 -2.85847 ]
[.00638 .44212 0 6.14153 ]
[-0.00378 .53194 -18 -2.9102 ]
[-0.00378 .53194 0 6.0898 ]
[-0.01434 .62532 -6 -2.96413 ]
[-0.01434 .62532 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 1.11253 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.12503 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
.04875 .18654 m
.0558 .18375 L
s
[(0)] .03467 .19213 1 -0.39662 Mshowa
.03972 .26693 m
.04679 .2642 L
s
[(0.2)] .02559 .27239 1 -0.38642 Mshowa
.03035 .35034 m
.03744 .34767 L
s
[(0.4)] .01617 .35567 1 -0.37582 Mshowa
.02062 .43693 m
.02774 .43433 L
s
[(0.6)] .00638 .44212 1 -0.36478 Mshowa
.01051 .52689 m
.01765 .52437 L
s
[(0.8)] -0.00378 .53194 1 -0.35329 Mshowa
0 .62042 m
.00717 .61797 L
s
[(1)] -0.01434 .62532 1 -0.3413 Mshowa
.125 Mabswid
.04653 .20636 m
.05076 .2047 L
s
.04428 .22637 m
.04851 .22471 L
s
.04201 .24656 m
.04625 .24491 L
s
.03741 .28749 m
.04165 .28587 L
s
.03508 .30825 m
.03933 .30663 L
s
.03272 .32919 m
.03698 .32759 L
s
.02795 .37168 m
.03221 .37009 L
s
.02553 .39322 m
.02979 .39164 L
s
.02309 .41497 m
.02735 .4134 L
s
.01813 .45909 m
.0224 .45755 L
s
.01561 .48147 m
.01989 .47994 L
s
.01307 .50407 m
.01736 .50255 L
s
.00792 .54993 m
.01221 .54843 L
s
.00531 .5732 m
.0096 .5717 L
s
.00267 .59669 m
.00696 .59521 L
s
.25 Mabswid
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
.5561 .7194 m
.04875 .18654 L
s
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.5561 .7194 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.5574 1.11253 L
s
.5574 1.11253 m
.5561 .7194 L
s
0 0 m
1 0 L
1 1.11253 L
0 1.11253 L
closepath
clip
newpath
.5 Mabswid
.654 .735 .909 r
.52593 .68772 .5561 .7194 .58394 .7109 .55403 .67985 Metetra
.655 .741 .913 r
.55403 .67985 .58394 .7109 .61197 .70234 .58232 .67187 Metetra
.655 .746 .917 r
.58232 .67187 .61197 .70234 .64019 .69372 .61083 .66376 Metetra
.657 .751 .92 r
.61083 .66376 .64019 .69372 .66861 .68504 .63955 .65546 Metetra
.658 .756 .922 r
.63955 .65546 .66861 .68504 .69723 .6763 .66847 .64695 Metetra
.661 .76 .923 r
.66847 .64695 .69723 .6763 .72605 .6675 .6976 .63821 Metetra
.663 .762 .924 r
.6976 .63821 .72605 .6675 .75507 .65863 .72693 .62921 Metetra
.666 .764 .923 r
.72693 .62921 .75507 .65863 .7843 .6497 .75646 .61996 Metetra
.668 .764 .922 r
.75646 .61996 .7843 .6497 .81374 .64071 .7862 .61044 Metetra
.671 .763 .92 r
.7862 .61044 .81374 .64071 .84339 .63166 .81614 .60069 Metetra
.673 .76 .916 r
.81614 .60069 .84339 .63166 .87325 .62254 .84628 .59071 Metetra
.674 .757 .913 r
.84628 .59071 .87325 .62254 .90333 .61335 .87663 .58054 Metetra
.675 .753 .909 r
.87663 .58054 .90333 .61335 .93362 .6041 .90718 .57022 Metetra
.676 .748 .905 r
.90718 .57022 .93362 .6041 .96413 .59478 .93794 .55978 Metetra
.643 .732 .913 r
.49498 .6552 .52593 .68772 .55403 .67985 .52332 .64792 Metetra
.644 .737 .917 r
.52332 .64792 .55403 .67985 .58232 .67187 .55188 .64049 Metetra
.646 .742 .92 r
.55188 .64049 .58232 .67187 .61083 .66376 .58067 .63285 Metetra
.648 .748 .922 r
.58067 .63285 .61083 .66376 .63955 .65546 .60967 .62491 Metetra
.652 .753 .923 r
.60967 .62491 .63955 .65546 .66847 .64695 .63889 .6166 Metetra
.657 .757 .924 r
.63889 .6166 .66847 .64695 .6976 .63821 .66833 .6079 Metetra
.662 .761 .923 r
.66833 .6079 .6976 .63821 .72693 .62921 .69798 .59876 Metetra
.667 .763 .922 r
.69798 .59876 .72693 .62921 .75646 .61996 .72782 .58916 Metetra
.672 .764 .919 r
.72782 .58916 .75646 .61996 .7862 .61044 .75787 .57913 Metetra
.676 .763 .916 r
.75787 .57913 .7862 .61044 .81614 .60069 .78811 .56868 Metetra
.68 .762 .913 r
.78811 .56868 .81614 .60069 .84628 .59071 .81855 .55786 Metetra
.683 .759 .909 r
.81855 .55786 .84628 .59071 .87663 .58054 .84918 .54673 Metetra
.685 .755 .905 r
.84918 .54673 .87663 .58054 .90718 .57022 .88 .53535 Metetra
.686 .751 .901 r
.88 .53535 .90718 .57022 .93794 .55978 .91103 .52381 Metetra
.632 .728 .917 r
.4632 .62183 .49498 .6552 .52332 .64792 .49179 .61505 Metetra
.634 .733 .92 r
.49179 .61505 .52332 .64792 .55188 .64049 .52061 .6081 Metetra
.637 .739 .922 r
.52061 .6081 .55188 .64049 .58067 .63285 .54967 .60085 Metetra
.641 .744 .923 r
.54967 .60085 .58067 .63285 .60967 .62491 .57896 .5932 Metetra
.647 .749 .924 r
.57896 .5932 .60967 .62491 .63889 .6166 .60848 .58505 Metetra
.654 .754 .923 r
.60848 .58505 .63889 .6166 .66833 .6079 .63822 .57635 Metetra
.661 .758 .922 r
.63822 .57635 .66833 .6079 .69798 .59876 .66818 .56705 Metetra
.668 .761 .92 r
.66818 .56705 .69798 .59876 .72782 .58916 .69834 .55712 Metetra
.675 .762 .916 r
.69834 .55712 .72782 .58916 .75787 .57913 .72871 .54657 Metetra
.681 .763 .913 r
.72871 .54657 .75787 .57913 .78811 .56868 .75926 .53546 Metetra
.687 .762 .909 r
.75926 .53546 .78811 .56868 .81855 .55786 .79001 .52384 Metetra
.69 .76 .905 r
.79001 .52384 .81855 .55786 .84918 .54673 .82094 .51179 Metetra
.693 .757 .901 r
.82094 .51179 .84918 .54673 .88 .53535 .85206 .49942 Metetra
.694 .753 .897 r
.85206 .49942 .88 .53535 .91103 .52381 .88337 .48685 Metetra
.623 .725 .92 r
.43058 .58756 .4632 .62183 .49179 .61505 .4594 .58117 Metetra
.625 .73 .922 r
.4594 .58117 .49179 .61505 .52061 .6081 .48847 .57456 Metetra
.629 .735 .923 r
.48847 .57456 .52061 .6081 .54967 .60085 .5178 .5676 Metetra
.635 .74 .924 r
.5178 .5676 .54967 .60085 .57896 .5932 .54737 .56015 Metetra
.642 .745 .923 r
.54737 .56015 .57896 .5932 .60848 .58505 .57719 .5521 Metetra
.651 .75 .922 r
.57719 .5521 .60848 .58505 .63822 .57635 .60723 .54335 Metetra
.66 .754 .92 r
.60723 .54335 .63822 .57635 .66818 .56705 .63751 .53386 Metetra
.669 .758 .917 r
.63751 .53386 .66818 .56705 .69834 .55712 .66799 .52359 Metetra
.678 .76 .913 r
.66799 .52359 .69834 .55712 .72871 .54657 .69868 .51257 Metetra
.685 .761 .909 r
.69868 .51257 .72871 .54657 .75926 .53546 .72956 .50084 Metetra
.692 .761 .905 r
.72956 .50084 .75926 .53546 .79001 .52384 .76062 .48848 Metetra
.696 .76 .901 r
.76062 .48848 .79001 .52384 .82094 .51179 .79187 .47561 Metetra
.699 .757 .897 r
.79187 .47561 .82094 .51179 .85206 .49942 .82331 .46234 Metetra
.7 .754 .894 r
.82331 .46234 .85206 .49942 .88337 .48685 .85493 .44884 Metetra
.616 .723 .922 r
.39706 .55236 .43058 .58756 .4594 .58117 .42612 .5462 Metetra
.618 .726 .923 r
.42612 .5462 .4594 .58117 .48847 .57456 .45545 .53979 Metetra
.623 .731 .924 r
.45545 .53979 .48847 .57456 .5178 .5676 .48503 .53299 Metetra
.63 .736 .923 r
.48503 .53299 .5178 .5676 .54737 .56015 .51488 .52562 Metetra
.639 .741 .922 r
.51488 .52562 .54737 .56015 .57719 .5521 .54499 .51756 Metetra
.649 .745 .92 r
.54499 .51756 .57719 .5521 .60723 .54335 .57534 .50871 Metetra
.66 .75 .917 r
.57534 .50871 .60723 .54335 .63751 .53386 .60593 .499 Metetra
.67 .753 .913 r
.60593 .499 .63751 .53386 .66799 .52359 .63674 .4884 Metetra
.68 .756 .909 r
.63674 .4884 .66799 .52359 .69868 .51257 .66775 .47693 Metetra
.688 .758 .905 r
.66775 .47693 .69868 .51257 .72956 .50084 .69897 .46465 Metetra
.695 .759 .901 r
.69897 .46465 .72956 .50084 .76062 .48848 .73037 .45166 Metetra
.7 .758 .897 r
.73037 .45166 .76062 .48848 .79187 .47561 .76195 .43807 Metetra
.704 .757 .894 r
.76195 .43807 .79187 .47561 .82331 .46234 .79372 .42404 Metetra
.705 .755 .891 r
.79372 .42404 .82331 .46234 .85493 .44884 .82567 .40974 Metetra
.611 .721 .923 r
.36263 .5162 .39706 .55236 .42612 .5462 .39192 .51007 Metetra
.614 .724 .924 r
.39192 .51007 .42612 .5462 .45545 .53979 .4215 .50369 Metetra
.62 .727 .923 r
.4215 .50369 .45545 .53979 .48503 .53299 .45135 .49688 Metetra
.628 .732 .922 r
.45135 .49688 .48503 .53299 .51488 .52562 .48147 .48947 Metetra
.637 .736 .92 r
.48147 .48947 .51488 .52562 .54499 .51756 .51186 .48129 Metetra
.648 .741 .917 r
.51186 .48129 .54499 .51756 .57534 .50871 .54252 .47226 Metetra
.659 .745 .913 r
.54252 .47226 .57534 .50871 .60593 .499 .57342 .4623 Metetra
.67 .749 .909 r
.57342 .4623 .60593 .499 .63674 .4884 .60455 .45138 Metetra
.681 .752 .905 r
.60455 .45138 .63674 .4884 .66775 .47693 .6359 .43951 Metetra
.69 .754 .901 r
.6359 .43951 .66775 .47693 .69897 .46465 .66746 .42677 Metetra
.697 .756 .897 r
.66746 .42677 .69897 .46465 .73037 .45166 .69921 .41324 Metetra
.703 .756 .894 r
.69921 .41324 .73037 .45166 .76195 .43807 .73114 .39907 Metetra
.706 .756 .891 r
.73114 .39907 .76195 .43807 .79372 .42404 .76326 .38444 Metetra
.708 .755 .889 r
.76326 .38444 .79372 .42404 .82567 .40974 .79557 .36951 Metetra
.61 .721 .924 r
.32723 .47902 .36263 .5162 .39192 .51007 .35677 .47274 Metetra
.613 .722 .923 r
.35677 .47274 .39192 .51007 .4215 .50369 .38659 .46619 Metetra
.619 .725 .922 r
.38659 .46619 .4215 .50369 .45135 .49688 .4167 .4592 Metetra
.627 .728 .92 r
.4167 .4592 .45135 .49688 .48147 .48947 .4471 .45158 Metetra
.637 .732 .917 r
.4471 .45158 .48147 .48947 .51186 .48129 .47779 .44318 Metetra
.648 .736 .914 r
.47779 .44318 .51186 .48129 .54252 .47226 .50874 .4339 Metetra
.659 .74 .91 r
.50874 .4339 .54252 .47226 .57342 .4623 .53995 .42365 Metetra
.67 .744 .905 r
.53995 .42365 .57342 .4623 .60455 .45138 .57141 .4124 Metetra
.681 .747 .901 r
.57141 .4124 .60455 .45138 .6359 .43951 .6031 .40019 Metetra
.69 .75 .897 r
.6031 .40019 .6359 .43951 .66746 .42677 .635 .38707 Metetra
.697 .752 .894 r
.635 .38707 .66746 .42677 .69921 .41324 .6671 .37314 Metetra
.703 .753 .891 r
.6671 .37314 .69921 .41324 .73114 .39907 .6994 .35854 Metetra
.707 .754 .889 r
.6994 .35854 .73114 .39907 .76326 .38444 .73189 .34347 Metetra
.709 .754 .888 r
.73189 .34347 .76326 .38444 .79557 .36951 .76458 .32809 Metetra
.611 .721 .923 r
.29083 .44079 .32723 .47902 .35677 .47274 .32062 .43413 Metetra
.615 .722 .922 r
.32062 .43413 .35677 .47274 .38659 .46619 .35071 .42722 Metetra
.62 .723 .92 r
.35071 .42722 .38659 .46619 .4167 .4592 .38108 .41986 Metetra
.628 .725 .917 r
.38108 .41986 .4167 .4592 .4471 .45158 .41176 .41188 Metetra
.638 .728 .914 r
.41176 .41188 .4471 .45158 .47779 .44318 .44273 .40313 Metetra
.648 .732 .91 r
.44273 .40313 .47779 .44318 .50874 .4339 .47399 .39351 Metetra
.659 .735 .906 r
.47399 .39351 .50874 .4339 .53995 .42365 .50551 .38294 Metetra
.67 .739 .902 r
.50551 .38294 .53995 .42365 .57141 .4124 .53729 .37138 Metetra
.68 .742 .898 r
.53729 .37138 .57141 .4124 .6031 .40019 .56932 .35887 Metetra
.689 .745 .894 r
.56932 .35887 .6031 .40019 .635 .38707 .60157 .34546 Metetra
.696 .748 .891 r
.60157 .34546 .635 .38707 .6671 .37314 .63404 .33126 Metetra
.702 .75 .889 r
.63404 .33126 .6671 .37314 .6994 .35854 .66671 .3164 Metetra
.706 .752 .888 r
.66671 .3164 .6994 .35854 .73189 .34347 .69958 .30107 Metetra
.708 .753 .887 r
.69958 .30107 .73189 .34347 .76458 .32809 .73265 .28543 Metetra
.616 .723 .922 r
.25338 .40146 .29083 .44079 .32062 .43413 .28344 .39422 Metetra
.619 .722 .92 r
.28344 .39422 .32062 .43413 .35071 .42722 .3138 .38674 Metetra
.624 .722 .917 r
.3138 .38674 .35071 .42722 .38108 .41986 .34445 .37883 Metetra
.632 .724 .914 r
.34445 .37883 .38108 .41986 .41176 .41188 .37541 .37033 Metetra
.64 .725 .91 r
.37541 .37033 .41176 .41188 .44273 .40313 .40668 .36111 Metetra
.65 .728 .906 r
.40668 .36111 .44273 .40313 .47399 .39351 .43823 .35107 Metetra
.66 .731 .902 r
.43823 .35107 .47399 .39351 .50551 .38294 .47007 .34013 Metetra
.669 .734 .898 r
.47007 .34013 .50551 .38294 .53729 .37138 .50218 .32828 Metetra
.678 .737 .895 r
.50218 .32828 .53729 .37138 .56932 .35887 .53454 .31552 Metetra
.686 .74 .892 r
.53454 .31552 .56932 .35887 .60157 .34546 .56714 .30192 Metetra
.693 .743 .89 r
.56714 .30192 .60157 .34546 .63404 .33126 .59997 .28757 Metetra
.699 .746 .888 r
.59997 .28757 .63404 .33126 .66671 .3164 .63302 .27261 Metetra
.702 .749 .888 r
.63302 .27261 .66671 .3164 .69958 .30107 .66628 .25719 Metetra
.705 .751 .888 r
.66628 .25719 .69958 .30107 .73265 .28543 .69976 .24147 Metetra
.623 .725 .92 r
.21484 .36098 .25338 .40146 .28344 .39422 .24519 .35297 Metetra
.626 .723 .917 r
.24519 .35297 .28344 .39422 .3138 .38674 .27584 .34472 Metetra
.63 .722 .914 r
.27584 .34472 .3138 .38674 .34445 .37883 .30678 .33608 Metetra
.636 .722 .91 r
.30678 .33608 .34445 .37883 .37541 .37033 .33803 .32692 Metetra
.644 .723 .906 r
.33803 .32692 .37541 .37033 .40668 .36111 .36959 .31711 Metetra
.652 .725 .902 r
.36959 .31711 .40668 .36111 .43823 .35107 .40145 .30657 Metetra
.66 .727 .899 r
.40145 .30657 .43823 .35107 .47007 .34013 .4336 .29524 Metetra
.668 .729 .895 r
.4336 .29524 .47007 .34013 .50218 .32828 .46603 .28309 Metetra
.676 .732 .892 r
.46603 .28309 .50218 .32828 .53454 .31552 .49873 .27013 Metetra
.683 .735 .89 r
.49873 .27013 .53454 .31552 .56714 .30192 .53168 .25643 Metetra
.689 .739 .889 r
.53168 .25643 .56714 .30192 .59997 .28757 .56487 .24205 Metetra
.694 .742 .888 r
.56487 .24205 .59997 .28757 .63302 .27261 .5983 .22712 Metetra
.698 .745 .888 r
.5983 .22712 .63302 .27261 .66628 .25719 .63197 .21178 Metetra
.7 .748 .889 r
.63197 .21178 .66628 .25719 .69976 .24147 .66586 .19616 Metetra
.632 .728 .917 r
.17516 .3193 .21484 .36098 .24519 .35297 .20582 .31033 Metetra
.634 .725 .914 r
.20582 .31033 .24519 .35297 .27584 .34472 .23678 .30115 Metetra
.638 .723 .91 r
.23678 .30115 .27584 .34472 .30678 .33608 .26803 .29163 Metetra
.642 .722 .906 r
.26803 .29163 .30678 .33608 .33803 .32692 .29959 .28167 Metetra
.648 .722 .902 r
.29959 .28167 .33803 .32692 .36959 .31711 .33145 .27117 Metetra
.654 .722 .899 r
.33145 .27117 .36959 .31711 .40145 .30657 .36362 .26006 Metetra
.661 .723 .896 r
.36362 .26006 .40145 .30657 .4336 .29524 .39608 .24829 Metetra
.667 .725 .893 r
.39608 .24829 .4336 .29524 .46603 .28309 .42883 .23584 Metetra
.673 .728 .891 r
.42883 .23584 .46603 .28309 .49873 .27013 .46186 .22273 Metetra
.679 .731 .889 r
.46186 .22273 .49873 .27013 .53168 .25643 .49515 .20899 Metetra
.684 .734 .889 r
.49515 .20899 .53168 .25643 .56487 .24205 .52871 .19469 Metetra
.688 .738 .889 r
.52871 .19469 .56487 .24205 .5983 .22712 .56252 .17992 Metetra
.691 .742 .89 r
.56252 .17992 .5983 .22712 .63197 .21178 .59658 .16479 Metetra
.693 .745 .891 r
.59658 .16479 .63197 .21178 .66586 .19616 .63089 .14942 Metetra
.643 .732 .913 r
.13429 .27638 .17516 .3193 .20582 .31033 .16529 .2663 Metetra
.644 .728 .91 r
.16529 .2663 .20582 .31033 .23678 .30115 .19658 .25604 Metetra
.646 .725 .906 r
.19658 .25604 .23678 .30115 .26803 .29163 .22815 .24551 Metetra
.649 .723 .902 r
.22815 .24551 .26803 .29163 .29959 .28167 .26003 .23464 Metetra
.653 .721 .899 r
.26003 .23464 .29959 .28167 .33145 .27117 .29221 .22336 Metetra
.657 .721 .896 r
.29221 .22336 .33145 .27117 .36362 .26006 .32469 .21161 Metetra
.661 .721 .893 r
.32469 .21161 .36362 .26006 .39608 .24829 .35747 .19938 Metetra
.666 .722 .891 r
.35747 .19938 .39608 .24829 .42883 .23584 .39054 .18663 Metetra
.67 .724 .89 r
.39054 .18663 .42883 .23584 .46186 .22273 .4239 .17338 Metetra
.674 .727 .889 r
.4239 .17338 .46186 .22273 .49515 .20899 .45753 .15967 Metetra
.678 .73 .889 r
.45753 .15967 .49515 .20899 .52871 .19469 .49145 .14552 Metetra
.681 .734 .89 r
.49145 .14552 .52871 .19469 .56252 .17992 .52563 .13101 Metetra
.683 .738 .892 r
.52563 .13101 .56252 .17992 .59658 .16479 .56008 .11621 Metetra
.685 .742 .894 r
.56008 .11621 .59658 .16479 .63089 .14942 .59481 .1012 Metetra
.654 .735 .909 r
.09217 .23214 .13429 .27638 .16529 .2663 .12354 .22084 Metetra
.655 .731 .905 r
.12354 .22084 .16529 .2663 .19658 .25604 .15518 .2094 Metetra
.655 .727 .902 r
.15518 .2094 .19658 .25604 .22815 .24551 .18711 .19776 Metetra
.657 .724 .899 r
.18711 .19776 .22815 .24551 .26003 .23464 .21932 .18589 Metetra
.658 .722 .896 r
.21932 .18589 .26003 .23464 .29221 .22336 .25183 .17376 Metetra
.66 .72 .893 r
.25183 .17376 .29221 .22336 .32469 .21161 .28463 .16134 Metetra
.662 .719 .891 r
.28463 .16134 .32469 .21161 .35747 .19938 .31773 .1486 Metetra
.665 .72 .89 r
.31773 .1486 .35747 .19938 .39054 .18663 .35112 .13555 Metetra
.667 .721 .89 r
.35112 .13555 .39054 .18663 .4239 .17338 .3848 .12219 Metetra
.669 .723 .89 r
.3848 .12219 .4239 .17338 .45753 .15967 .41877 .10852 Metetra
.671 .726 .891 r
.41877 .10852 .45753 .15967 .49145 .14552 .45303 .09458 Metetra
.673 .73 .892 r
.45303 .09458 .49145 .14552 .52563 .13101 .48759 .08039 Metetra
.674 .734 .895 r
.48759 .08039 .52563 .13101 .56008 .11621 .52243 .06599 Metetra
.675 .738 .897 r
.52243 .06599 .56008 .11621 .59481 .1012 .55756 .05142 Metetra
.666 .738 .904 r
.04875 .18654 .09217 .23214 .12354 .22084 .08051 .17394 Metetra
.665 .734 .901 r
.08051 .17394 .12354 .22084 .15518 .2094 .11254 .16124 Metetra
.665 .73 .898 r
.11254 .16124 .15518 .2094 .18711 .19776 .14483 .14843 Metetra
.664 .726 .895 r
.14483 .14843 .18711 .19776 .21932 .18589 .1774 .13551 Metetra
.664 .723 .893 r
.1774 .13551 .21932 .18589 .25183 .17376 .21025 .12249 Metetra
.664 .72 .891 r
.21025 .12249 .25183 .17376 .28463 .16134 .24339 .10934 Metetra
.663 .719 .89 r
.24339 .10934 .28463 .16134 .31773 .1486 .27681 .09609 Metetra
.663 .718 .89 r
.27681 .09609 .31773 .1486 .35112 .13555 .31052 .08272 Metetra
.663 .719 .89 r
.31052 .08272 .35112 .13555 .3848 .12219 .34452 .06923 Metetra
.664 .72 .891 r
.34452 .06923 .3848 .12219 .41877 .10852 .37882 .05563 Metetra
.664 .723 .893 r
.37882 .05563 .41877 .10852 .45303 .09458 .41342 .04191 Metetra
.664 .726 .895 r
.41342 .04191 .45303 .09458 .48759 .08039 .44833 .02806 Metetra
.665 .73 .898 r
.44833 .02806 .48759 .08039 .52243 .06599 .48355 .01409 Metetra
.665 .734 .901 r
.48355 .01409 .52243 .06599 .55756 .05142 .51908 0 Metetra
0 g
.25 Mabswid
.51908 0 m
.96413 .59478 L
s
.96413 .59478 m
1 .99897 L
s
1 .99897 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.04875 .18654 m
0 .62042 L
s
0 .62042 m
.51687 .44401 L
s
.51687 .44401 m
.51908 0 L
s
.51908 0 m
.04875 .18654 L
s
.04875 .18654 m
.51908 0 L
s
.04875 .18654 m
.05398 .19203 L
s
[(0)] .03831 .17557 .95212 1 Mshowa
.13835 .151 m
.14345 .1566 L
s
[(0.2)] .12814 .13981 .91135 1 Mshowa
.2301 .11461 m
.23508 .12033 L
s
[(0.4)] .22015 .10319 .87057 1 Mshowa
.32408 .07734 m
.32892 .08317 L
s
[(0.6)] .31441 .06568 .8298 1 Mshowa
.42038 .03915 m
.42507 .04509 L
s
[(0.8)] .411 .02725 .78903 1 Mshowa
.51908 0 m
.52362 .00607 L
s
[(1)] .51 -0.01213 .74826 1 Mshowa
.125 Mabswid
.07096 .17773 m
.07407 .18104 L
s
.09329 .16888 m
.09639 .1722 L
s
.11575 .15997 m
.11883 .16331 L
s
.16108 .14199 m
.16413 .14536 L
s
.18395 .13292 m
.18698 .13631 L
s
.20696 .12379 m
.20996 .1272 L
s
.25338 .10538 m
.25635 .10883 L
s
.27681 .09609 m
.27975 .09955 L
s
.30037 .08674 m
.3033 .09022 L
s
.34794 .06788 m
.35082 .07139 L
s
.37194 .05836 m
.3748 .06189 L
s
.39609 .04878 m
.39892 .05233 L
s
.44483 .02945 m
.44762 .03304 L
s
.46943 .01969 m
.4722 .0233 L
s
.49418 .00988 m
.49692 .0135 L
s
gsave
.21792 .02683 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
0 .62042 m
.5574 1.11253 L
s
0 .62042 m
.00717 .61797 L
s
[(0)] -0.01434 .62532 1 -0.3413 Mshowa
.16285 .76419 m
.17007 .76191 L
s
[(0.5)] .1484 .76875 1 -0.31527 Mshowa
.30836 .89266 m
.31563 .89053 L
s
[(1)] .29382 .89692 1 -0.29293 Mshowa
.43917 1.00815 m
.44648 1.00615 L
s
[(1.5)] .42456 1.01215 1 -0.27354 Mshowa
.5574 1.11253 m
.56474 1.11064 L
s
[(2)] .54272 1.11629 1 -0.25656 Mshowa
.125 Mabswid
.0341 .65053 m
.03841 .64908 L
s
.06741 .67994 m
.07173 .67851 L
s
.09995 .70867 m
.10428 .70726 L
s
.13176 .73675 m
.13609 .73536 L
s
.19324 .79103 m
.19758 .78968 L
s
.22297 .81728 m
.22732 .81595 L
s
.25205 .84295 m
.25641 .84164 L
s
.28051 .86807 m
.28487 .86678 L
s
.33562 .91673 m
.33999 .91547 L
s
.36232 .9403 m
.36669 .93906 L
s
.38847 .96338 m
.39284 .96215 L
s
.41408 .98599 m
.41846 .98478 L
s
.46376 1.02986 m
.46815 1.02868 L
s
.48787 1.05114 m
.49226 1.04997 L
s
.5115 1.072 m
.51589 1.07085 L
s
.53467 1.09246 m
.53907 1.09132 L
s
gsave
.22112 .91822 -71 -8.24244 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{282.75, 314.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001RB000`400?l00000o`00003ooooooomR
ooooo`00oooooomRooooo`00oooooomRooooo`00^_ooool4o`000003oa0@4?oooooooooo0:3ooooo
002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002loooo
o`03o`000?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002looooo`03o`00
0?oooooooooo0:;ooooo002looooo`03o`000?oooooooooo0:;ooooo002jooooo`03oeEEEOmVIVKo
00000:Cooooo003oooooof;ooooo003oooooof;ooooo001Mooooo`;o00000_ooool2o`000?kooooo
001Mooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMo_ooool005kooooo00CogMgMo`000?l@413o
c<c<:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07oooool2o`0009oooooo001Nooooo`04onk^k_lQ8B7o410@onk^kR[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01cooooo
0ol000000onZ^nKo0000o`00002Nooooo`00G_ooool01?lQ8B7oMgMgogMgMolb<S8Zooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001[ooooo0ol00003ojZk
iP?o0000WOooool005gooooo0_l00002ooooo`;o0000:Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`?o00001_nZ^nH00ol0003oZ[_Vo`00002M
ooooo`00S?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00Eooooo`?o00000_nZ^nH00ol0003oZ[_VojZkiP03ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo
002<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;o
oooo1?l0000:ojZkiP04o`000?nZ^nKoZ[_Vo`0009cooooo002<ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013ooooo1?l000000onZ^^Go0000ojZkiP09
ojZkiP05o`000?nZ^nKoZ[_VojZki_l00000Voooool008cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool4o`000003ojZjiOl0003oZ[[U00;oZ[[U
00?o0000ojZki_nZ^nH01onZ^nH00ol0003oZ[_VojZkiP02ojZkiP03o`000?oooooooooo09Sooooo
002/ooooo`Co00002?nZ^^D00ol0003oZ[_VojZkiP06ojZkiP03o`000?nZ^nKoZ[_V00?oZ[_V00?o
0000ooooooooool0Uoooool00:Wooooo1?l0000<ojZji@03o`000?nZ^nKoZ[_V00GoZ[_V00?o0000
ojZki_nZ^nH00onZ^nH00ol0003oooooooooo`2Gooooo`00Yoooool6o`0000coZ[[U00?o0000ojZk
i_nZ^nH01OnZ^nH00ol0003oZ[_VojZkiP04ojZkiP03o`000?oooooooooo09Kooooo002Tooooo`Co
00001OnY^ND00ol0003oZ[[UojZji@0:ojZji@03o`000?nZ^nKoZ[_V00CoZ[_V00?o0000ojZki_nZ
^nH01OnZ^nH00ol0003oooooooooo`2Eooooo`00KOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`08?ooool3o`0000WoZKWU00?o0000ojZj
iOnZ^^D02_nZ^^D00ol0003oZ[_VojZkiP03ojZkiP03o`000?nZ^nKoZ[_V00KoZ[_V00?o0000oooo
ooooool0U?ooool006gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q01gooooo0ol000000onY^NGo0000ojVii@0:ojVii@03o`000?nZ^^Go
Z[[U00[oZ[[U00?o0000ojZki_nZ^nH00_nZ^nH00ol0003oZ[_VojZkiP06ojZkiP03o`000?oooooo
oooo09Cooooo001]ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000001_ooooo0ol000001OnY^NCo0000ojViiOnY^NGo000000[oZKWU00?o0000ojZjiOnZ^^D0
2_nZ^^D00ol0003oZ[_VojZkiP02ojZkiP03o`000?nZ^nKoZ[_V00OoZ[_V00?o0000ooooooooool0
Toooool006gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B406?ooool3o`0000GoZKWT00?o0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@05
o`000?nZ^nKoZ[_VojZki_l000002_nZ^nH00ol0003oooooooooo`2Booooo`00KOooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co000000?oZKWT
o`000?nY^N@01OnY^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ^^GoZ[[U00[oZ[[U00Co0000
ojZki_nZ^nKo00002_nZ^nH2o`0009?ooooo001]ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`0Eooooo`?o00003?nY^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ
^^GoZ[[U00[oZ[[U00?o0000ojZki_l000002?nZ^nH2o`000003ojbliOl0003ooooo09;ooooo001]
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Cooooo`Co00003OnY
^N@00ol0003oZKWUojVii@0;ojVii@03o`000?nZ^^GoZ[[U00[oZ[[U00?o0000ojZki_l000001OnZ
^nH3o`0000Co[;cU00?o0000ooooooooool0T?ooool006gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40oooooo0_l00002ojVhi003o`000?nY^>Co000000goZKWT
00?o0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@;o00000onZ^nH2o`0000So[;cU
00?o0000ooooooooool0Soooool008kooooo0ol00007ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o
0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@0:ojZji@04o`000?nZ^nKo0000o`0000_o[;cU
00?o0000ooooooooool0S_ooool008cooooo0ol0000:ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o
0000ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@09ojZji@;o00003On/_>D2o`0008oooooo0029
ooooo`Co000000?oZKSTo`000?nY^>@02OnY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGo
ZKWU00_oZKWU00?o0000ojZjiOnZ^^D01_nZ^^D5o`0000ko[;cU00?o0000ooooooooool0SOooool0
053ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooo
oooo023ooooo1?l000000onY^>?o0000ojVhi00<ojVhi003o`000?nY^NCoZKWT00_oZKWT00?o0000
ojViiOnY^ND02onY^ND00ol0003oZ[[UojZji@03ojZji@;o00000on/^nD00ol0003o[;_Uo`00000>
ojbli@03o`000?oooooooooo08cooooo001@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Oooooo00?o0000ooooooooool07_ooool4o`0000GoZKSS00?o0000ojVhi?nY^>@02onY^>@0
0ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00_oZKWU00?o0000ojZjiOl000000_l00005
ojbki@04o`000?n/^nGo[;_Uo`0000ko[;cU00?o0000ooooooooool0Roooool0053ooooo00Go410@
oooooooooooooooooa0@400;ooooo`Go00007Oooool3o`000003ojVhhol0003oZKSS00KoZKSS00?o
0000ojVhi?nY^>@02onY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00[oZKWU0_l0
0008ojbki@05o`000?n/^nGo[;_UojbkiOl000003On/_>D2o`0008cooooo001@ooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool0000Kooooo`?o00001OnY^><00ol0003o
ZKSSojVhh`05ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY^N@02_nY^N@00ol0003o
ZKWUojVii@07ojVii@?o000000?o[;[To`000?n/^nD01on/^nD00ol0003o[;_Uojbki@02ojbki@03
o`000?n/_>Go[;cU00_o[;cU0_l0002;ooooo`00D?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00006Oooool3o`000003ojVghol0003oZKSS00coZKSS00?o0000ojVh
i?nY^>@02onY^>@00ol0003oZKWTojVii00;ojVii003o`000?nY^NGoZKWU00?oZKWU0ol00005ojbj
i003o`000?n/^nGo[;_U00Go[;_U00?o0000ojbkiOn/^nD00_n/^nD00ol0003o[;cUojbli@0<ojbl
i@03o`000?oooooooooo08Wooooo001@ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omg
MgOoc<c<o`00000Fooooo`?o00000_nY]n<01?l0003oZKOSojVghol0000=ojVhh`03o`000?nY^>Co
ZKST00_oZKST00?o0000ojVii?nY^N@02onY^N@00ol0003oZKWUo`000002o`0000Wo[;[T00?o0000
ojbkiOn/^nD01?n/^nD00ol0003o[;_Uojbki@03ojbki@03o`000?n/_>Go[;cU00co[;cU00?o0000
ooooooooool0R?ooool0053ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000001Cooooo0ol00008ojVgh`03o`000?nY^>?oZKSS00_oZKSS00?o0000ojVhi?nY^>@02onY^>@0
0ol0003oZKWTojVii00:ojVii0;o00003?n/^^@00ol0003o[;_Uojbki@04ojbki@03o`000?n/^nGo
[;_U00Co[;_U00?o0000ojbliOn/_>D02on/_>D2o`0008Wooooo001@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0@ooooo`?o00003?nY]n<00ol0003oZKSSojVhh`0;
ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY^N@01onY^N@2o`000003oj^ii?l0003o
[;[T00co[;[T00?o0000ojbkiOn/^nD00on/^nD00ol0003o[;_Uojbki@05ojbki@03o`000?n/_>Go
[;cU00_o[;cU0_l00028ooooo`00Loooool3o`000003ojVhhol0003o000000coZKOS00?o0000ojVh
honY^><02_nY^><00ol0003oZKSTojVhi00;ojVhi003o`000?nY^NCoZKWT00GoZKWT0_l00004oj^i
i003o`000?n/^^Co[;[T00_o[;[T00?o0000ojbkiOn/^nD00_n/^nD00ol0003o[;_Uojbki@06ojbk
i@03o`000?n/_>Go[;cU00_o[;cU0_l00027ooooo`00L?ooool3o`0000GoZKSS00?o0000ojVghonY
]n<02_nY]n<00ol0003oZKSSojVhh`0;ojVhh`03o`000?nY^>CoZKST00_oZKST00?o0000ojVii?nY
^N@00_nY^N@2o`0000OoZkWT00?o0000ojbji?n/^^@02_n/^^@00ol0003o[;_Uojbki@02ojbki@03
o`000?n/^nGo[;_U00Ko[;_U00?o0000ojbliOn/_>D02On/_>D2o`000003ojnmi?l0003ooooo08Ko
oooo001^ooooo`?o00002?nY^><00ol0003oZKOSojVgh`0:ojVgh`03o`000?nY^>?oZKSS00_oZKSS
00?o0000ojVhi?nY^>@02onY^>@01?l0003oZKWTo`000?l0000:oj^ii003o`000?n/^^Co[;[T00[o
[;[T00Go0000ojbkiOn/^nGo[;_Uo`000009ojbki@03o`000?n/_>Go[;cU00Go[;cU0ol00003ojnm
i0;o0000Q_ooool003?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
02?ooooo0ol00002ojVhh`03o`000?nY^>?oZKSS00OoZKSS00?o0000ojVghonY]n<02_nY]n<00ol0
003oZKSSojVhh`0;ojVhh`03o`000?nY^>CoZKST00[oZKST0_l0000<oj^ii003o`000?n/^^Co[;[T
00_o[;[T00Co0000ojbkiOn/^nGo00002_n/^nD00ol0003o[;cUojbli@02ojbli@;o00001on__N@2
o`0008Gooooo000cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Qooooo`?o000000?oZKSTo`000?nY^><02onY^><00ol0003oZKOSojVg
h`0;ojVgh`03o`000?nY^>?oZKSS00[oZKSS00?o0000ojVhi?nY^>@01onY^>@3o`000003oj^ihol0
003oZkWT00coZkWT00?o0000ojbji?n/^^@02on/^^@00ol0003o[;_Uo`00000;ojbki@04o`000?n/
_>Go0000o`0000[o[kgT0_l00024ooooo`00<oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h07oooool4o`0000CoZKST00?o0000ojVhhonY^><02_nY^><00ol0003oZKOS
ojVgh`0;ojVgh`03o`000?nY^>?oZKSS00[oZKSS00?o0000ojVhi?nY^>@00onY^>@3o`0000GoZkWS
00?o0000oj^ii?n[^N@02on[^N@00ol0003o[;[Tojbji00:ojbji003o`000?n/^nGo000000_o[;_U
0_l0000=ojnmi003o`000?oooooooooo08;ooooo000cooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP0Kooooo`?o00001?nY^>@00ol0003oZKSTojVhi002ojVhi003o`00
0?nY^>?oZKSS00[oZKSS00?o0000ojVghonY]n<02onY]n<00ol0003oZKSSojVhh`0:ojVhh`03o`00
0?nY^>Co000000;o00002On[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00[o[;[T
0_l00009ojbki@;o000000?o[[cTo`000?n__N@03?n__N@2o`0008?ooooo000cooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Hooooo`?o00003?nY^>@00ol0003oZKSS
ojVhh`0:ojVhh`03o`000?nY]n?oZKOS00[oZKOS00?o0000ojVhhonY^><02_nY^><2o`0000goZkWS
00?o0000oj^ii?n[^N@02_n[^N@00ol0003o[;[Tojbji00;ojbji003o`000?n/^nGo[;_U00Co[;_U
0ol00004ojjli003o`000?n__NCo[kgT00_o[kgT0_l00022ooooo`00<oooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool05?ooool3o`000003ojVii?l0003oZKST00coZKST
00?o0000ojVhhonY^><02_nY^><00ol0003oZKOSojVgh`0;ojVgh`03o`000?nY^>?oZKSS00KoZKSS
0ol000000onZ^>?o0000oj^ih`0<oj^ih`03o`000?n[^NCoZkWT00_oZkWT00?o0000ojbji?n/^^@0
2_n/^^@00ol0003o[;_Uojbki@02ojbki@;o00002?n^_>@00ol0003o[kgTojnmi00;ojnmi0;o0000
POooool003?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41005?ooool3o`0000CoZKWT00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKSSojVhh`0:ojVhh`03
o`000?nY]n?oZKOS00_oZKOS00?o0000ojVhhonY^><00onY^><2o`0000GoZ[SS00?o0000oj^ihon[
^N<02on[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00Wo[;[T0_l000000on/^nGo
0000o`00000;ojjli003o`000?n__NCo[kgT00_o[kgT00?o0000ooooooooool0Ooooool003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool3o`00
00SoZKWT00?o0000ojVhi?nY^>@02onY^>@00ol0003oZKSSojVhh`0:ojVhh`03o`000?nY]n?oZKOS
00_oZKOS00?o0000ojVhhol000000_l00008ojZhh`03o`000?n[^N?oZkWS00_oZkWS00?o0000oj^i
i?n[^N@02on[^N@00ol0003o[;[Tojbji008ojbji0?o00003On^_>@00ol0003o[kgTojnmi00;ojnm
i0;o0000P?ooool005Oooooo0ol000000onY^NCo0000ojVii008ojVii003o`000?nY^>CoZKST00_o
ZKST00?o0000ojVhhonY^><02_nY^><00ol0003oZKOSojVgh`0:ojVgh`;o00003?nZ^><00ol0003o
ZkWSoj^ih`0;oj^ih`03o`000?n[^NCoZkWT00[oZkWT00?o0000ojbji?n/^^@01_n/^^@3o`000003
ojjkhol0003o[[cT00go[[cT00?o0000ojnmi?n__N@02on__N@2o`0007oooooo001Dooooo`?o0000
00?oZKWUo`000?nY^N@03?nY^N@00ol0003oZKSTojVhi00:ojVhi003o`000?nY^>?oZKSS00[oZKSS
00?o0000ojVghonY]n<01onY]n<3o`000003ojZhhol0003oZ[SS00_oZ[SS00?o0000oj^ihon[^N<0
2on[^N<00ol0003oZkWToj^ii00;oj^ii003o`000?n/^^Co[;[T00?o[;[T0_l00002ojjkh`04o`00
0?n^^n?o[[_So`0000ko[[cT00?o0000ojnmi?n__N@02on__N@00ol0003oooooooooo`1mooooo`00
D_ooool3o`0000CoZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003o`00
0?nY^>?oZKSS00[oZKSS00?o0000ojVghonY]n<00onY]n<3o`0000GoZ[SS00?o0000ojZhhonZ^><0
2_nZ^><00ol0003oZkWSoj^ih`0;oj^ih`03o`000?n[^NCoZkWT00_oZkWT00?o0000ojbji?l00000
0_l00004ojjkh`05o`000?n^^n?o[[_Sojjkhol000003_n^_>@00ol0003o[kgTojnmi00;ojnmi003
o`000?oooooooooo07cooooo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool4o`000003
ojViiOl0003oZKWU00CoZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003
o`000?nY^>?oZKSS00[oZKSS00?o0000ojVghol000000_l00009ojZhh`03o`000?nZ^>?oZ[SS00[o
Z[SS00?o0000oj^ihon[^N<02on[^N<00ol0003oZkWToj^ii00:oj^ii0;o00001on^^n<00ol0003o
[[_Sojjkh`02ojjkh`03o`000?n^_>Co[[cT00_o[[cT00?o0000ojnmi?n__N@02on__N@2o`0007go
oooo000Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL08Oooool3o`0000_oZKWU00?o0000ojVii?nY
^N@02_nY^N@00ol0003oZKSTojVhi00;ojVhi003o`000?nY^>?oZKSS00WoZKSS0_l0000=ojZhh`03
o`000?nZ^>?oZ[SS00[oZ[SS00?o0000oj^ihon[^N<02_n[^N<00ol0003oZkWToj^ii007oj^ii0?o
000000?o[K[So`000?n^^n<01_n^^n<00ol0003o[[_Sojjkh`03ojjkh`03o`000?n^_>Co[[cT00_o
[[cT00?o0000ojnmi?n__N@02on__N@2o`0007cooooo000Wooooo`05oa0@4?ooooooooooooooool@
41007_ooool5o`0000goZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi00:ojVhi003
o`000?nY^>?oZKSS00KoZKSS0ol000000onY^>Co0000ojZhh`0<ojZhh`03o`000?nZ^>?oZ[SS00[o
Z[SS00?o0000oj^ihon[^N<02on[^N<00ol0003oZkWToj^ii003oj^ii0?o00001On]^^<00ol0003o
[[_Sojjkh`04ojjkh`03o`000?n^^n?o[[_S00?o[[_S00?o0000ojjli?n^_>@03?n^_>@00ol0003o
[kgTojnmi008ojnmi0;o000000?o/KkTo`000?ooool0Noooool002Oooooo00Go0000oooooooooooo
ooooo`00000Looooo`?o00000_nZ^^D00ol0003oZ[[Uo`00000<ojVii@03o`000?nY^NCoZKWT00_o
ZKWT00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZKSSojVhh`03ojVhh`;o00001OnY^>@00ol0003o
Z[SSojZhh`0;ojZhh`03o`000?nZ^>?oZ[SS00[oZ[SS00?o0000oj^ihon[^N<02on[^N<00ol0003o
ZkWTo`000002o`0000Wo[K[S00?o0000ojjkhon^^n<00on^^n<00ol0003o[[_Sojjkh`04ojjkh`03
o`000?n^_>Co[[cT00_o[[cT00?o0000ojnmi?n__N@01On__N@3o`0000Co/KkT00?o0000oooooooo
ool0NOooool002Oooooo00Go0000ooooooooooooooooo`00000Iooooo`Co00001OnZ^^D00ol0003o
Z[[Uo`00000<ojVii@03o`000?nY^NCoZKWT00_oZKWT00?o0000ojVhi?nY^>@02_nY^>@00ol0003o
ZKSSo`000002o`0000SoZKST00?o0000ojZhhonZ^><02onZ^><00ol0003oZ[SSojZhh`0:ojZhh`03
o`000?n[^N?oZkWS00[oZkWS0_l0000=ojfjh`03o`000?n^^n?o[[_S00;o[[_S00?o0000ojjkhon^
^n<01On^^n<00ol0003o[[cTojjli00;ojjli003o`000?n__NCo[kgT00;o[kgT0_l00007ok6ni0;o
0000N_ooool002Oooooo00Go410@oooooooooooooooooa0@400Gooooo`?o00002onZ^^D00ol0003o
ZKWUojVii@0:ojVii@03o`000?nY^NCoZKWT00[oZKWT00?o0000ojVhi?nY^>@02_nY^>@2o`0000co
ZKST00?o0000ojZhhonZ^><02onZ^><00ol0003oZ[SSojZhh`0:ojZhh`03o`000?n[^N?oZkWS00Oo
ZkWS0_l000000on/^^?o0000ojfjh`0<ojfjh`03o`000?n^^n?o[[_S00;o[[_S00?o0000ojjkhon^
^n<01_n^^n<00ol0003o[[cTojjli00;ojjli004o`000?n__NCo0000o`0000[o/KkT0_l0001ioooo
o`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo1Ol000000onZ^^Go0000ojZji@0:ojZj
i@03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVii?nY^N@02_nY^N@00ol0003oZKSTojVhi006ojVh
i0?o000000?oZ;STo`000?nY^>@03?nY^>@00ol0003oZ[SSojZhh`0:ojZhh`03o`000?nZ^>?oZ[SS
00[oZ[SS00?o0000oj^ihon[^N<01On[^N<2o`0000Co[;[S00?o0000ojfjhon]^^<02on]^^<01Ol0
003o[[_Sojjkhon^^n?o000000Wo[[_S00?o0000ojjli?n^_>@02_n^_>@2o`0000go/KkT00?o0000
ooooooooool0Moooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Booooo`?o00001?nZ^nH0
0ol0003oZ[[UojZji@0;ojZji@03o`000?nY^NGoZKWU00[oZKWU00?o0000ojVii?nY^N@02_nY^N@0
0ol0003oZKSTojVhi003ojVhi0;o00001OnX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o
Z[SS00_oZ[SS00?o0000ojZhhonZ^><02_nZ^><00ol0003oZkWSoj^ih`02oj^ih`;o00001on/^^<0
0ol0003o[K[Sojfjh`0;ojfjh`04o`000?n^^n?o[[_So`0000Wo[[_S00?o0000ojjli?n^_>@02?n^
_>@2o`000003ok2mhol0003o/KkT00go/KkT00?o0000ooooooooool0M_ooool003_ooooo1Ol00006
ojZkiP03o`000?nZ^^GoZ[[U00_oZ[[U00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKWTojVii00:
ojVii003o`000?nY^>Co000000;o00002?nX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o
Z[SS00_oZ[SS00?o0000ojZhhonZ^><02_nZ^><01?l0003oZkWSo`000?l0000:ojbjh`03o`000?n]
^^?o[K[S00_o[K[S00?o0000ojjkhol000002_n^^n<00ol0003o[[cTojjli005ojjli0;o00001?n`
_N<00ol0003o/KkTok6ni00;ok6ni0;o0000Moooool003Wooooo0ol0000;ojZkiP03o`000?nZ^^Go
Z[[U00_oZ[[U00?o0000ojViiOnY^ND02OnY^ND00ol0003oZKWTojVii00:ojVii0;o00003?nX^>@0
0ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00_oZ[SS00?o0000ojZhhonZ^><02OnZ^><2
o`0000co[;[S00?o0000ojfjhon]^^<02on]^^<00ol0003o[[_So`00000;ojjkh`03o`000?n^_>Co
[[cT00;o[[cT0_l00007ok2mh`03o`000?na_^Co/KkT00_o/KkT0_l0001fooooo`00=oooool3o`00
0003ojZliol0003oZ[_V00_oZ[_V00?o0000ojZjiOnZ^^D02_nZ^^D00ol0003oZKWUojVii@0:ojVi
i@03o`000?nY^NCoZKWT00KoZKWT0ol000000onX^>Go0000ojRhi00<ojRhi003o`000?nY^>CoZKST
00[oZKST00?o0000ojZhhonZ^><02_nZ^><00ol0003oZ[SSojZhh`06ojZhh`?o000000?oZkWSo`00
0?n/^^<03?n/^^<00ol0003o[K[Sojfjh`0;ojfjh`;o00003?n^^n<01?l0003o[[cTo`000?l0000:
ok2mh`03o`000?na_^Co/KkT00_o/KkT00?o0000ooooooooool0M?ooool003Cooooo0ol000000onZ
_>Oo0000ojZli`02ojZli`03o`000?nZ^nKoZ[_V00[oZ[_V00?o0000ojZjiOnZ^^D02_nZ^^D00ol0
003oZKWUojVii@0:ojVii@03o`000?nY^NCoZKWT00?oZKWT0_l00005ojRhi@03o`000?nX^>CoZ;ST
00_oZ;ST00?o0000ojVhi?nY^>@02_nY^>@00ol0003oZ[SSojZhh`0:ojZhh`03o`000?nZ^>?oZ[SS
00?oZ[SS0_l00005oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02on]^^<00ol0
003o[[_Sojjkh`0:ojjkh`;o00003?n`_N<00ol0003o/KkTok6ni00<ok6ni003o`000?oooooooooo
07?ooooo000booooo`?o00002?nZ_>L00ol0003oZ[_VojZkiP0:ojZkiP03o`000?nZ^^GoZ[[U00[o
Z[[U00?o0000ojViiOnY^ND02_nY^ND00ol0003oZKWTo`000002o`0000SoZ;SU00?o0000ojRhi?nX
^>@02onX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00[oZ[SS00?o0000ojZhhol0
00000_l00008oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02_n]^^<00ol0003o
[[_Sojjkh`07ojjkh`?o000000?o/;cSo`000?n`_N<03?n`_N<00ol0003o/KkTok6ni00;ok6ni0;o
0000M?ooool0037ooooo00?o0000ojZlionZ_>L02_nZ_>L00ol0003oZ[_VojZkiP0:ojZkiP03o`00
0?nZ^^GoZ[[U00[oZ[[U00?o0000ojViiOnY^ND02?nY^ND3o`0000coZ;SU00?o0000ojRhi?nX^>@0
2onX^>@00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>?oZ[SS00[oZ[SS0_l0000<oj^ih`03o`00
0?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<02_n]^^<2o`0000Go[[_S0ol00005ok2lh`03o`00
0?n`_N?o/;gS00_o/;gS00?o0000ok6ni?na_^@02ona_^@00ol0003oooooooooo`1booooo`00<Ooo
ool2o`0000coZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@0;ojZji@03o`000?nY
^NGoZKWU00CoZKWU0ol00002ojRiiP03o`000?nX^>GoZ;SU00_oZ;SU00?o0000ojRhi?nX^>@02_nX
^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?oZ[SS00KoZ[SS0ol000000onZ^>Co0000oj^i
h`0<oj^ih`03o`000?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<02On]^^<01?l0003o[K[So`00
0?n^^n<3o`0000Wo/;cS00?o0000ok2mhon`_N<02on`_N<00ol0003o/KkTok6ni00;ok6ni003o`00
0?oooooooooo077ooooo000Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool2o`0000goZ[cW
00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@0;ojZji@03o`000?nY^NGoZKWU00?o0000
1_nX^NH00ol0003oZ;SUojRhi@0;ojRhi@03o`000?nX^>CoZ;ST00[oZ;ST00?o0000ojVhi?nY^>@0
2_nY^>@00ol0003oZ[SSojZhh`03ojZhh`;o00001OnZ^>@00ol0003oZkWSoj^ih`0:oj^ih`03o`00
0?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]^^<02?n]^^<01?l0003o[K[So`000?l0000=ok2lh`03
o`000?n`_N?o/;gS00[o/;gS00?o0000ok6ni?na_^@03?na_^@00ol0003oooooooooo`1`ooooo`00
9Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?o0000ooooool000003OnZ_>L00ol0003o
Z[_VojZkiP09ojZkiP03o`000?nZ^^GoZ[[U00[oZ[[U0ol0000:ojRiiP03o`000?nX^>GoZ;SU00_o
Z;SU00?o0000ojRhi?nX^>@02_nX^>@00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>?o000000;o
00002?nZ^>@00ol0003oZkWSoj^ih`0:oj^ih`03o`000?n/^^?o[;[S00_o[;[S00?o0000ojfjhon]
^^<01on]^^<2o`000003ojnkhol0003o/;cS00go/;cS00?o0000ok2mhon`_N<02_n`_N<00ol0003o
/KkTok6ni00;ok6ni0;o0000LOooool002Gooooo00Go410@oooooooooooooooooa0@4007ooooo`04
o`000?ooooooooooo`0000goZ[cW00?o0000ojZki_nZ^nH02OnZ^nH00ol0003oZ[[UojZji@06ojZj
i@?o000000?oYk[Vo`000?nX^NH02onX^NH00ol0003oZ;SUojRhi@0;ojRhi@03o`000?nX^>CoZ;ST
00[oZ;ST00?o0000ojVhi?nY^>@02?nY^>@3o`0000coZ[ST00?o0000oj^ihon[^N<02_n[^N<00ol0
003o[;[Sojbjh`0:ojbjh`03o`000?n]^^?o[K[S00Go[K[S0ol00003ojnkh`03o`000?n`_>?o/;cS
00_o/;cS00?o0000ok2mhon`_N<02on`_N<00ol0003o/KkTok6ni008ok6ni0;o000000?o/koSo`00
0?ooool0L?ooool002Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000oooool00ol0
003oZ[cWojZli`0;ojZli`03o`000?nZ^nKoZ[_V00WoZ[_V00?o0000ojZjiOnZ^^D00onZ^^D2o`00
00GoYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nX^>CoZ;ST
00_oZ;ST00?o0000ojVhi?nY^>@01?nY^>@3o`0000;oZKST00?o0000ojZhi?nZ^>@02onZ^>@00ol0
003oZkWSoj^ih`0:oj^ih`03o`000?n/^^?o[;[S00[o[;[S00?o0000ojfjhon]^^<00_n]^^<2o`00
00;o[k_S00?o0000ojnkhon_^n<00_n_^n<00ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o/;gS
00[o/;gS00?o0000ok6ni?na_^@01Ona_^@3o`0000Co/koS00?o0000ooooooooool0K_ooool002Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZl
ionZ_>L02onZ_>L00ol0003oZ[_VojZkiP09ojZkiP03o`000?nZ^^Go000000;o00002?nW^^H00ol0
003oZ;WVojRiiP0:ojRiiP03o`000?nX^>GoZ;SU00[oZ;SU00?o0000ojRhi?nX^>@02onX^>@00ol0
003oZKSTojVhi003o`0000KoZKST00?o0000ojZhi?nZ^>@02_nZ^>@00ol0003oZkWSoj^ih`0;oj^i
h`03o`000?n/^^?o[;[S00[o[;[S00Co0000ojfjhol0003o00001?n_^n<00ol0003o[k_Sojnkh`03
ojnkh`03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<02_n`_N<00ol0003o/KkTok6ni002
ok6ni0;o00002?nc_n<00ol0003oooooooooo`1]ooooo`009Oooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool01?ooool00ol0003oZ[cWojZli`0;ojZli`03o`000?nZ^nKo
Z[_V00SoZ[_V0_l0000<ojNjiP03o`000?nX^NKoZ;WV00[oZ;WV00?o0000ojRhiOnX^>D02_nX^>D0
0ol0003oZ;STojRhi00:ojRhi0?o00002_nY^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?o
ZkWS00[oZkWS00?o0000ojbjhon/^^<02_n/^^<2o`0000Ko[k_S00?o0000ojnkhon_^n<01?n_^n<0
0ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o/;gS00[o/;gS00Co0000ok6ni?l0003o00002_nc
_n<2o`0006kooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?nZ_>OoZ[cW00_oZ[cW00?o0000ojZki_nZ^nH01?nZ^nH3o`000003ojNkiol0
003oYk[V00coYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nX
^>CoZ;ST00KoZ;ST0ol000000onX^>Go0000ojVhi00;ojVhi003o`000?nZ^>CoZ[ST00[oZ[ST00?o
0000oj^ihon[^N<02_n[^N<00ol0003o[;[Sojbjh`06ojbjh`?o000000?o[K_So`000?n_^n<01On_
^n<00ol0003o[k_Sojnkh`04ojnkh`03o`000?n`_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<02_n`
_N<2o`0000go/koS00?o0000ooooooooool0K?ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ojZlionZ_>L02onZ_>L00ol0003oZ[_VojZk
iP03o`0000GoYk_W00?o0000ojNji_nW^^H02onW^^H00ol0003oZ;WVojRiiP09ojRiiP03o`000?nX
^>GoZ;SU00_oZ;SU00?o0000ojRhi?nX^>@00onX^>@2o`0000GoZ;SU00?o0000ojVhi?nY^>@02_nY
^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00[oZkWS00?o0000ojbjhon/^^<00on/
^^<2o`0000Go[K_S00?o0000ojnkhon_^n<00on_^n<00ol0003o[k_Sojnkh`05ojnkh`03o`000?n`
_>?o/;cS00_o/;cS00?o0000ok2mhon`_N<01_n`_N<3o`000003ok:nhol0003o/koS00go/koS00?o
0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool01oooool00ol0003oZ[cWojZli`0:
ojZli`?o00002OnW^nL00ol0003oYk[VojNjiP0;ojNjiP03o`000?nX^NKoZ;WV00WoZ;WV00?o0000
ojRhiOnX^>D02onX^>D00ol0003oZ;STo`000002o`0000SoZ;SU00?o0000ojVhi?nY^>@02OnY^>@0
0ol0003oZ[STojZhi00;ojZhi003o`000?n[^N?oZkWS00[oZkWS00?o0000ojbjhol000000_l00008
ojfkh`03o`000?n_^n?o[k_S00;o[k_S00?o0000ojnkhon_^n<01_n_^n<00ol0003o/;cSok2lh`0;
ok2lh`03o`000?n`_N?o/;gS00?o/;gS0_l00005ok:nh`03o`000?nc_n?o/koS00co/koS00?o0000
ooooooooool0J_ooool0033ooooo00?o0000ooooooooool02?ooool00ol0003oZ[cWojZli`06ojZl
i`?o000000?oYkcXo`000?nW^nL02_nW^nL00ol0003oYk[VojNjiP0;ojNjiP03o`000?nX^NKoZ;WV
00WoZ;WV00?o0000ojRhiOnX^>D02_nX^>D2o`0000coZ;SU00?o0000ojVhi?nY^>@02OnY^>@00ol0
003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00[oZkWS0_l0000<ojfkh`05o`000?n_^n?o[k_S
ojnkhol000002On_^n<00ol0003o/;cSok2lh`0;ok2lh`03o`000?n`_N?o000000;o00002?nb_^<0
0ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06[ooooo000_ooooo`;o00002oooool00ol0
003oZ[cWojZli`03ojZli`;o00001OnW_>P00ol0003oYk_WojNki`09ojNki`03o`000?nW^^KoYk[V
00[oYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0003oZ;SUojRhi@06ojRhi@?o000000?oYkSVo`00
0?nX^>D03?nX^>D00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>CoZ[ST00[oZ[ST00?o0000oj^i
hon[^N<01_n[^N<3o`000003ojbji?l0003o[K_S00co[K_S00Co0000ojnkhon_^n?o00002_n_^n<0
0ol0003o/;cSok2lh`0:ok2lh`;o00003?nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooo
oooo06Wooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ojZliol000000_l00008ojNl
j003o`000?nW^nOoYk_W00WoYk_W00?o0000ojNji_nW^^H02_nW^^H00ol0003oZ;WVojRiiP0:ojRi
iP03o`000?nX^>GoZ;SU00?oZ;SU0_l00005ojNhiP03o`000?nX^>GoZ;SU00[oZ;SU00?o0000ojVh
i?nY^>@02_nY^>@00ol0003oZ[STojZhi00:ojZhi003o`000?n[^N?oZkWS00?oZkWS0_l00005ojbj
i003o`000?n]^n?o[K_S00[o[K_S00Co0000ojnkhon_^n?o00002_n_^n<00ol0003o/;cSok2lh`08
ok2lh`;o000000?o/KgSo`000?nb_^<03?nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooo
oooo06Sooooo000_ooooo`03o`000?oooooooooo00cooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0
003oYk_WojNki`09ojNki`03o`000?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH02_nX^NH00ol0
003oZ;SUo`000002o`0000SoYkSV00?o0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi00:ojVh
i003o`000?nZ^>CoZ[ST00[oZ[ST00?o0000oj^ihol000000_l00008ojbji003o`000?n]^n?o[K_S
00[o[K_S00?o0000ojnkhol000002on_^n<00ol0003o/;cSok2lh`05ok2lh`;o00001?na_N<00ol0
003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00co/koS00?o0000ooooooooool0Ioooool002oo
oooo00?o0000ooooooooool03Oooool00ol0003oYkcXojNlj00:ojNlj003o`000?nW^nOoYk_W00Wo
Yk_W00?o0000ojNji_nW^^H02_nW^^H00ol0003oZ;WVojRiiP08ojRiiP?o00003?nW^>H00ol0003o
Z;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00WoZKST00?o0000ojZhi?nZ^>@02_nZ^>@2o`0000co
[;[T00?o0000ojfkhon]^n<02_n]^n<2o`0000co[k_S00?o0000ok2lhon`_><00_n`_><2o`0000Oo
/KgS00?o0000ok:nhonb_^<02_nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06Oo
oooo000_ooooo`03o`000?oooooooooo00kooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0003oYk_W
ojNki`09ojNki`03o`000?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH01?nX^NH3o`0000;oY[WV
00?o0000ojNhi_nW^>H02onW^>H00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00WoZKST
00?o0000ojZhi?nZ^>@01_nZ^>@3o`000003ojZii?l0003o[;[T00_o[;[T00?o0000ojfkhon]^n<0
2on]^n<00ol0003o[k_Sojnkh`0;ojnkh`04o`000?n`_>?o0000o`0000[o/KgS00?o0000ok:nhonb
_^<02_nb_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?oooooooooo06Kooooo000_ooooo`03o`00
0?oooooooooo00oooooo00?o0000ojNlj?nW_>P02_nW_>P00ol0003oYk_WojNki`09ojNki`03o`00
0?nW^^KoYk[V00[oYk[V00?o0000ojRii_nX^NH00ol00006ojJiiP03o`000?nW^>KoYkSV00[oYkSV
00?o0000ojRhiOnX^>D02onX^>D00ol0003oZKSTojVhi009ojVhi003o`000?nZ^>CoZ[ST00?oZ[ST
0_l00005ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfkhon]^n<02_n]^n<00ol0003o[k_S
ojnkh`0;ojnkh`;o00003Ona_N<00ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00[o/koS
0_l0001Wooooo`00;_ooool3o`00017ooooo00?o0000ojNlj?nW_>P02OnW_>P00ol0003oYk_WojNk
i`0:ojNki`03o`000?nW^^KoYk[V00SoYk[V1?l0000:ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o
0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi00:ojVhi003o`000?nZ^>Co000000;o00002?nZ
^N@00ol0003o[;[Tojbji00:ojbji003o`000?n]^n?o[K_S00Wo[K_S0_l00009ojnkh`?o000000?o
/;gSo`000?na_N<03?na_N<00ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00So/koS0_l0
00000ond`>?o0000o`00001Vooooo`00;oooool00ol0003oooooooooo`0Aooooo`03o`000?nW_>So
YkcX00WoYkcX00?o0000ojNkionW^nL02_nW^nL00ol0003oYk[VojNjiP04ojNjiP?o00000_nU^NL0
0ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX^>D02_nX^>D0
0ol0003oZKSTojVhi008ojVhi0?o00003?nZ^N@00ol0003o[;[Tojbji00:ojbji003o`000?n]^n?o
[K_S00So[K_S00?o0000ojfkhol000001On_^n<3o`0000Go/;gS00?o0000ok6mhona_N<02ona_N<0
0ol0003o/[kSok:nh`0:ok:nh`03o`000?nc_n?o/koS00Go/koS0_l00004okC0h`03o`000?oooooo
oooo06Cooooo000_ooooo`03o`000?oooooooooo01;ooooo00?o0000ojNlj?nW_>P02OnW_>P00ol0
003oYk_WojNki`0:ojNki`03o`000?nW^^KoYk[V00?o00001_nU^NL00ol0003oY[WVojJiiP0:ojJi
iP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX^>D02_nX^>D00ol0003oZKSTojVhi004ojVh
i0?o00000_nY^ND00ol0003oZ[WTojZii00:ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfk
hon]^n<02?n]^n<01Ol0003o[K_Sojfkhol0003o[k_S00?o00002On`_N<00ol0003o/KgSok6mh`0;
ok6mh`03o`000?nb_^?o/[kS00[o/[kS00?o0000ok>ohonc_n<00_nc_n<2o`0000Oo]<3S00?o0000
ooooooooool0Hoooool002oooooo00?o0000ooooooooool04oooool00ol0003oYkcXojNlj009ojNl
j003o`000?nW^nOoYk_W00SoYk_W1?l0000:ojFii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNh
i_nW^>H02_nW^>H00ol0003oZ;SUojRhi@0:ojRhi@03o`000?nY^>CoZKST00?o00001_nY^ND00ol0
003oZ[WTojZii00:ojZii003o`000?n/^^Co[;[T00[o[;[T00?o0000ojfkhon]^n<01on]^n<00ol0
003o[K_Sojfkh`02o`0000go/;gS00?o0000ok6mhona_N<02ona_N<00ol0003o/[kSok:nh`0:ok:n
h`04o`000?nc_n?o0000o`0000[o]<3S00?o0000ooooooooool0H_ooool002oooooo00?o0000oooo
ooooool04oooool2o`0000_oYkcX00?o0000ojNkionW^nL01?nW^nL3o`0000;oY;[X00?o0000ojFi
ionU^NL02_nU^NL00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00WoYkSV00?o0000ojRh
iOnX^>D02_nX^>D3o`0000[oZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[Tojbji00:ojbj
i003o`000?n]^n?o[K_S00Ko[K_S0ol000000on^_>?o0000ok2mh`0<ok2mh`03o`000?na_N?o/KgS
00_o/KgS00?o0000ok:nhonb_^<02_nb_^<2o`0000co]<3S0_l0001Sooooo`00;_ooool00ol0003o
ooooooooo`0Eooooo`;o00002onW_>P00ol0003oYk_WojNki`03o`0000KoY;[X00?o0000ojFiionU
^NL02_nU^NL00ol0003oY[WVojJiiP09ojJiiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojRhiOnX
^>D01_nX^>D3o`000003ojNhi_l0003oZKWU00_oZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o
[;[Tojbji009ojbji003o`000?n]^n?o[K_S00Go[K_S0_l00004ojjlh`03o`000?n`_N?o/;gS00_o
/;gS00?o0000ok6mhona_N<02ona_N<00ol0003o/[kSok:nh`06ok:nh`?o000000?o/koSo`000?nd
`><03?nd`><00ol0003oooooooooo`1Qooooo`00;_ooool3o`0001Kooooo0_l0000:ojNlj0?o0000
2_nT^^P00ol0003oYKWWojFii`0:ojFii`03o`000?nV^NKoY[WV00WoY[WV00?o0000ojNhi_nW^>H0
2_nW^>H00ol0003oZ;SUojRhi@03ojRhi@;o00001OnW^>H00ol0003oZKWUojVii@0:ojVii@03o`00
0?nZ^NCoZ[WT00WoZ[WT00?o0000ojbji?n/^^@02_n/^^@00ol0003o[K_Sojfkh`02ojfkh`;o0000
00?o[[cSo`000?n^_><01?n^_><00ol0003o/;gSok2mh`0;ok2mh`03o`000?na_N?o/KgS00_o/KgS
00?o0000ok:nhonb_^<00onb_^<2o`0000Go/koS00?o0000okC0hond`><02ond`><00ol0003ooooo
ooooo`1Pooooo`00;_ooool00ol0003oooooooooo`0Gooooo`;o00001_nW_>P3o`000003ojBkjOl0
003oY;[X00_oY;[X00?o0000ojFiionU^NL02_nU^NL00ol0003oY[WVojJiiP09ojJiiP03o`000?nW
^>KoYkSV00[oYkSV00?o0000ojRhiOl000000_l00008ojNhiP03o`000?nY^NGoZKWU00WoZKWU00?o
0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[Tojbji00:ojbji004o`000?n]^n?o0000o`0000?o[[cS
00?o0000ojjlhon^_><01?n^_><00ol0003o/;gSok2mh`0:ok2mh`03o`000?na_N?o/KgS00co/KgS
00?o0000ok:nhol000000_l00008ok>oh`03o`000?nd`>?o]<3S00_o]<3S00?o0000ooooooooool0
Goooool001;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Oooooo
00?o0000ooooooooool06?ooool2o`0000;oYkcX0ol00005ojBkj@03o`000?nT^^SoY;[X00[oY;[X
00?o0000ojFiionU^NL02OnU^NL00ol0003oY[WVojJiiP0:ojJiiP03o`000?nW^>KoYkSV00SoYkSV
0ol0000<ojNhiP03o`000?nY^NGoZKWU00WoZKWU00?o0000ojZii?nZ^N@02_nZ^N@00ol0003o[;[T
ojbji009ojbji0;o00001On^_><00ol0003o[[cSojjlh`05ojjlh`03o`000?n`_N?o/;gS00[o/;gS
00?o0000ok6mhona_N<02ona_N<2o`0000co/koS00?o0000okC0hond`><02ond`><00ol0003ooooo
ooooo`1Nooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`0Iooooo`?o00002OnT^nT00ol0003o
Y;[XojBjj00:ojBjj003o`000?nU^NOoYKWW00WoYKWW00?o0000ojJii_nV^NH02_nV^NH00ol0003o
YkSVojNhiP04ojNhiP?o00000_nU^>H00ol0003oYkSVojNhiP0:ojNhiP03o`000?nY^NGoZKWU00[o
ZKWU00?o0000ojZii?nZ^N@02OnZ^N@00ol0003o[;[Tojbji006ojbji0?o000000?o[K_To`000?n^
_><01?n^_><00ol0003o[[cSojjlh`05ojjlh`03o`000?n`_N?o/;gS00_o/;gS00?o0000ok6mhona
_N<02?na_N<2o`000003ok:nhol0003o/koS00_o/koS00?o0000okC0hond`><02ond`><00ol0003o
ooooooooo`1Nooooo`004_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02?ooool00ol0003oooooooooo`0Jooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojBjj?nT
^^P02_nT^^P00ol0003oYKWWojFii`09ojFii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojNhi_nW
^>H00ol00006ojFhiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOnY^ND02_nY^ND00ol0003o
Z[WTojZii009ojZii003o`000?n/^^Co[;[T00?o[;[T0_l00005ojfki003o`000?n^_>?o[[cS00;o
[[cS00?o0000ojjlhon^_><01_n^_><00ol0003o/;gSok2mh`0;ok2mh`03o`000?na_N?o/KgS00Co
/KgS0ol00004ok:nh`03o`000?nc_n?o/koS00[o/koS00?o0000okC0hond`><02ond`><00ol0003o
ooooooooo`1Mooooo`004_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00ol0003oooooooooo`0Kooooo`03o`000?nT^nWoY;_Y00WoY;_Y00?o0000ojBjj?nT
^^P02OnT^^P00ol0003oYKWWojFii`0:ojFii`03o`000?nV^NKoY[WV00SoY[WV1?l0000:ojFhiP03
o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOnY^ND02OnY^ND00ol0003oZ[WTojZii00:ojZii003
o`000?n/^^Co000000;o00002?n]^n@01Ol0003o[[cSojjlhon^_>?o000000Wo[[cS00?o0000ok2m
hon`_N<02_n`_N<00ol0003o/KgSok6mh`02ok6mh`;o00002?nb_^<00ol0003o/koSok>oh`0:ok>o
h`03o`000?nd`>?o]<3S00_o]<3S00?o0000ooooooooool0G?ooool001;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool07?ooool00ol0
003oY;_YojBkj@09ojBkj@03o`000?nT^^SoY;[X00WoY;[X00?o0000ojFiionU^NL02_nU^NL00ol0
003oY[WVojJiiP04ojJiiP?o00000_nT^>L00ol0003oYKSVojFhiP0:ojFhiP03o`000?nW^>KoYkSV
00[oYkSV00?o0000ojViiOnY^ND02OnY^ND00ol0003oZ[WTojZii008ojZii0?o00003?n]^n@01?l0
003o[[cSojjlhol0000:ojjlh`03o`000?n`_N?o/;gS00[o/;gS00Co0000ok6mhol0003o00002onb
_^<00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00[o]<3S0_l0001Mooooo`004_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool2o`0001oooooo00?o
0000ojBkjOnT^nT02OnT^nT00ol0003oY;[XojBjj009ojBjj003o`000?nU^NOoYKWW00[oYKWW00?o
0000ojJii_nV^NH00ol00006ojBhi`03o`000?nU^>KoYKSV00[oYKSV00?o0000ojNhi_nW^>H02OnW
^>H00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^NCoZ[WT00CoZ[WT0ol00002oj^ji@03o`000?n]
^nCo[K_T00_o[K_T00?o0000ojjlhol000002_n^_><00ol0003o/;gSok2mh`0:ok2mh`;o00003Onb
_^<00ol0003o/koSok>oh`0;ok>oh`03o`000?nd`>?o]<3S00Oo]<3S0_l000000one`>?o0000oooo
o`1Looooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4006ooooo`03o`000?oooooooooo01oooooo00?o0000ojBkjOnT^nT02OnT^nT00ol0003oY;[X
ojBjj009ojBjj003o`000?nU^NOoYKWW00SoYKWW1?l0000:ojBhi`03o`000?nU^>KoYKSV00WoYKSV
00?o0000ojNhi_nW^>H02_nW^>H00ol0003oZKWUojVii@0:ojVii@03o`000?nZ^NCoZ[WT00?o0000
1_n[^^D00ol0003o[K_Tojfki00;ojfki0;o00002on^_><00ol0003o/;gSok2mh`06ok2mh`?o0000
00?o/KkSo`000?nb_^<03Onb_^<00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00Go]<3S
0_l00004okG0h`03o`000?oooooooooo05[ooooo000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool08?ooool00ol0003o
Y;_YojBkj@09ojBkj@03o`000?nT^^SoY;[X00WoY;[X00?o0000ojFiionU^NL01?nU^NL3o`0000;o
XkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`000?nW^>KoYkSV00[o
YkSV00?o0000ojViiOnY^ND02OnY^ND3o`0000[oZk[U00?o0000ojfki?n]^n@02on]^n@00ol0003o
[[cSojjlh`0:ojjlh`03o`000?n`_N?o/;gS00?o/;gS0_l00005ok6nh`03o`000?nb_^?o/[kS00co
/[kS00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`02okC0h`;o00001one`><00ol0003o
ooooooooo`1Iooooo`00;Oooool00ol0003oooooooooo`0Qooooo`03o`000?nT^nWoY;_Y00WoY;_Y
00?o0000ojBjj?nT^^P02OnT^^P00ol0003oYKWWojFii`03o`0000KoXkWX00?o0000ojBhionT^>L0
2_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`000?nW^>KoYkSV00WoYkSV00?o0000ojViiOnY^ND0
1_nY^ND3o`000003ojRji_l0003oZk[U00_oZk[U00?o0000ojfki?n]^n@02_n]^n@00ol0003o[[cS
ojjlh`0;ojjlh`03o`000?n`_N?o000000;o00002?na_^<00ol0003o/[kSok:nh`0;ok:nh`03o`00
0?nc_n?o/koS00_o/koS00Co0000okC0hol0003o00002_ne`><00ol0003oooooooooo`1Hooooo`00
;Oooool00ol0003oooooooooo`0Qooooo`03o`000?nT^nWoY;_Y00[oY;_Y00?o0000ojBjj?nT^^P0
2?nT^^P3o`0000[oXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFhiP09ojFhiP03o`00
0?nW^>KoYkSV00WoYkSV00?o0000ojViiOnY^ND00onY^ND2o`0000GoZ;[V00?o0000oj^jiOn[^^D0
2_n[^^D00ol0003o[K_Tojfki009ojfki0;o00003?n^_><2o`0000co/KkS00?o0000ok:nhonb_^<0
2onb_^<00ol0003o/koSok>oh`0:ok>oh`;o00003?ne`><00ol0003oooooooooo`1Hooooo`00;Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?nT^nWoY;_Y00[oY;_Y00?o0000ojBjj?nT^^P01?nT
^^P3o`000003oj:ijOl0003oXkWX00_oXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFh
iP08ojFhiP03o`000?nW^>KoYkSV00[oYkSV00?o0000ojViiOl000000_l00008ojRjiP03o`000?n[
^^GoZk[U00[oZk[U00?o0000ojfki?n]^n@02?n]^n@00ol0003o[K_To`000008ojjlh`?o000000?o
[kgTo`000?na_^<03?na_^<00ol0003o/[kSok:nh`0;ok:nh`03o`000?nc_n?o/koS00Oo/koS0_l0
00000ond`>?o0000okG0h`0<okG0h`03o`000?oooooooooo05Oooooo000/ooooo`?o00009?ooool0
0ol0003oY;_YojBkj@0:ojBkj@03o`000?nT^^SoY;[X00?o00001OnR^NT00ol0003oXkWXoj>ij00:
oj>ij003o`000?nT^>OoY;SW00WoY;SW00?o0000ojFhi_nU^>H02OnU^>H00ol0003oYkSVojNhiP08
ojNhiP?o00003?nX^^H00ol0003oZk[Uoj^ji@0:oj^ji@03o`000?n]^nCo[K_T00Oo[K_T00Co0000
ojfki?n]^nCo00001On^_><2o`0000Go[kgT00?o0000ok6nhona_^<02ona_^<00ol0003o/[kSok:n
h`0;ok:nh`03o`000?nc_n?o/koS00Co/koS0_l00004okC0h`03o`000?ne`>?o]L3S00_o]L3S00?o
0000ooooooooool0E_ooool002gooooo00?o0000ooooooooool09?ooool00ol0003oY;_YojBkj@08
ojBkj@Co00002OnR^NT00ol0003oXkWXoj>ij00:oj>ij003o`000?nT^>OoY;SW00WoY;SW00?o0000
ojFhi_nU^>H02OnU^>H00ol0003oYkSVojNhiP04ojNhiP?o00000_nV^NH00ol0003oZ;[VojRjiP0;
ojRjiP03o`000?n[^^GoZk[U00WoZk[U00?o0000ojfki?n]^n@01on]^n@01_l0003o[K_Tojfki?n]
^nCo0000ojjlh`?o00002?n__N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00[o/[kS
00?o0000ok>ohonc_n<00_nc_n<2o`0000Oo]<3S00?o0000okG0hone`><02one`><00ol0003ooooo
ooooo`1Eooooo`00;Oooool00ol0003oooooooooo`0Uooooo`03o`000?nT^nWoY;_Y00CoY;_Y0ol0
0002oj6jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000oj>ij?nS^NP02_nS^NP00ol0003oY;SWojBh
i`09ojBhi`03o`000?nU^>KoYKSV00WoYKSV00?o0000ojNhi_nW^>H00ol00006ojJiiP03o`000?nX
^^KoZ;[V00[oZ;[V00?o0000oj^jiOn[^^D02_n[^^D00ol0003o[K_Tojfki006ojfki004o`000?n]
^nCo[K_Tojfki0;o00003?n__N@00ol0003o/KkSok6nh`0:ok6nh`03o`000?nb_^?o/[kS00_o/[kS
00Co0000ok>ohol0003o00002_nd`><00ol0003o]L3SokG0h`0:okG0h`;o0000E_ooool002gooooo
00?o0000ooooooooool09_ooool00ol0003oY;_YojBkj@03o`0000KoXK[Z00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00[oY;SW00?o0000ojFhi_nU^>H0
2?nU^>H3o`0000[oY[WV00?o0000ojRji_nX^^H02_nX^^H00ol0003oZk[Uoj^ji@0:oj^ji@03o`00
0?n]^nCo[K_T00Go[K_T1?l000000on]_>Go0000ojnmi00<ojnmi003o`000?na_^?o/KkS00[o/KkS
00?o0000ok:nhonb_^<02_nb_^<2o`0000co]<3S00?o0000okG0hone`><02one`><00ol0003ooooo
ooooo`1Dooooo`00;?ooool00ol0003oooooooooo`0Xooooo`;o00002_nQ^^X00ol0003oX[WYoj:i
j@09oj:ij@03o`000?nS^NSoXkWX00WoXkWX00?o0000ojBhionT^>L02_nT^>L00ol0003oYKSVojFh
iP04ojFhiP?o000000?oY;WWo`000?nV^NH02onV^NH00ol0003oZ;[VojRjiP0:ojRjiP03o`000?n[
^^GoZk[U00[oZk[U00?o0000ojfki?n]^n@00on]^n@2o`0000Go[KcU00?o0000ojnmi?n__N@02_n_
_N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00Ko/[kS0ol000000onc_n?o0000okC0
h`0<okC0h`03o`000?ne`>?o]L3S00_o]L3S00?o0000ooooooooool0Doooool002cooooo00?o0000
ooooooooool0:Oooool00ol0003oXK[Zoj6jjP09oj6jjP03o`000?nR^NWoX[WY00WoX[WY00?o0000
oj>ij?nS^NP02OnS^NP00ol0003oY;SWojBhi`0:ojBhi`03o`000?nU^>KoYKSV00?o00001OnT^NL0
0ol0003oY[WVojJiiP0:ojJiiP03o`000?nX^^KoZ;[V00[oZ;[V00?o0000oj^jiOn[^^D02_n[^^D0
0ol0003o[K_To`000002o`000003ojfliOl0003o[KcU00Go[KcU00?o0000ojnmi?n__N@02_n__N@0
0ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o/[kS00?o/[kS0_l00005ok>oh`03o`000?nd`>?o
]<3S00_o]<3S00?o0000okG0hone`><02one`><00ol0003oooooooooo`1Booooo`00;?ooool2o`00
02_ooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@09oj:ij@03o`000?nS^NSoXkWX
00WoXkWX00?o0000ojBhionT^>L02?nT^>L4o`0000WoY;WW00?o0000ojJii_nV^NH02_nV^NH00ol0
003oZ;[VojRjiP09ojRjiP03o`000?n[^^GoZk[U00[oZk[U0_l00004ojfli@03o`000?n]_>Go[KcU
00Go[KcU00?o0000ojnmi?n__N@02_n__N@00ol0003o/KkSok6nh`0;ok6nh`03o`000?nb_^?o0000
00;o00002?nc_n<00ol0003o]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00[o]L3S0_l0001Coooo
o`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?nQ^^[oXK[Z00WoXK[Z00?o0000oj:ijOnR
^NT02OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00CoY;SW0ol00002oj:hj003
o`000?nT^NOoY;WW00WoY;WW00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP09ojRjiP03
o`000?n[^^GoZk[U00KoZk[U0ol000000on[^nGo0000ojfli@03ojfli@03o`000?n]_>Go[KcU00Ko
[KcU00?o0000ojnmi?n__N@02_n__N@00ol0003o/KkSok6nh`0:ok6nh`;o00003?nc_n<00ol0003o
]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00Oo]L3S0_l000000one`N?o0000ooooo`1Booooo`00
;?ooool00ol0003oooooooooo`0/ooooo`03o`000?nQ^^[oXK[Z00WoXK[Z00?o0000oj:ijOnR^NT0
2OnR^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nT^>OoY;SW00?o00001_nR^>P00ol0003oY;WW
ojBii`09ojBii`03o`000?nV^NKoY[WV00[oY[WV00?o0000ojRji_nX^^H02OnX^^H00ol0003oZk[U
oj^ji@03oj^ji@;o00001On[^nD01Ol0003o[KcUojfliOn]_>Go000000So[KcU00?o0000ojnmi?n_
_N@02_n__N@00ol0003o/KkSok6nh`08ok6nh`;o000000?o/[oTo`000?nc_n<02onc_n<00ol0003o
]<3SokC0h`0;okC0h`03o`000?ne`>?o]L3S00Go]L3S0_l00004okG1h`03o`000?oooooooooo053o
oooo000/ooooo`03o`000?oooooooooo02gooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WY
oj:ij@09oj:ij@03o`000?nS^NSoXkWX00OoXkWX1?l0000:oj:hj003o`000?nT^NOoY;WW00WoY;WW
00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP09ojRjiP03o`000?n[^^Go000000;o0000
2?n[^nD01?l0003o[KcUojfliOl00009ojfli@03o`000?n__NCo[kgT00[o[kgT00?o0000ok6nhona
_^<01Ona_^<2o`0000Co/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`0;okC0h`03
o`000?ne`>?o]L3S00;o]L3S0_l00007okG1h`03o`000?oooooooooo04oooooo000/ooooo`03o`00
0?oooooooooo02kooooo00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@09oj:ij@04o`00
0?nS^NSoXkWXoj>ij0Go00000_nQ^>T00ol0003oX[SXoj:hj00:oj:hj003o`000?nT^NOoY;WW00Wo
Y;WW00?o0000ojJii_nV^NH02_nV^NH00ol0003oZ;[VojRjiP08ojRjiP;o00003?n[^nD00ol0003o
[KcUo`00000:ojfli@03o`000?n__NCo[kgT00[o[kgT00?o0000ok6nhona_^<00_na_^<2o`0000Oo
/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`0;okC0h`04o`000?ne`>?o0000o`00
00Wo]L7S0_l0001@ooooo`00;?ooool00ol0003oooooooooo`0_ooooo`03o`000?nQ^^[oXK[Z00Wo
XK[Z00?o0000oj:ijOnR^NT02?nR^NT4o`0000SoXKSY00?o0000oj:hj?nR^>P02_nR^>P00ol0003o
Y;WWojBii`08ojBii`03o`000?nV^NKoY[WV00_oY[WV00?o0000ojRji_nX^^H01?nX^^H3o`000003
ojRki_l0003oZk_U00coZk_U0_l0000;ojfli@03o`000?n__NCo[kgT00[o[kgT00Co0000ok6nhol0
003o00002_nb_n@00ol0003o/koSok>oh`0:ok>oh`03o`000?nd`>?o]<3S00[o]<3S0_l0000<okG1
h`03o`000?oooooooooo04kooooo000/ooooo`;o0000<Oooool00ol0003oXK[Zoj6jjP09oj6jjP03
o`000?nR^NWoX[WY00CoX[WY0ol000000onP^N[o0000oj6hj@0:oj6hj@03o`000?nR^>SoX[SX00[o
X[SX00?o0000ojBiionT^NL02?nT^NL00ol0003oY[WVojJiiP0;ojJiiP03o`000?nX^^KoZ;[V00?o
00001OnX^nH00ol0003oZk_Uoj^ki@0:oj^ki@;o00002on]_>D00ol0003o[kgTojnmi00:ojnmi0;o
00003?nb_n@00ol0003o/koSok>oh`0;ok>oh`03o`000?nd`>?o]<3S00Oo]<3S0_l000000ond`N?o
0000okG1h`0<okG1h`03o`000?oooooooooo04gooooo000[ooooo`03o`000?oooooooooo03;ooooo
00?o0000oj6jj_nQ^^X02OnQ^^X00ol0003oX[WYoj:ij@03o`0000GoX;WZ00?o0000oj6hjOnQ^>T0
2OnQ^>T00ol0003oX[SXoj:hj00:oj:hj003o`000?nT^NOoY;WW00SoY;WW00?o0000ojJii_nV^NH0
2_nV^NH3o`0000WoZ;_V00?o0000oj^kiOn[^nD02_n[^nD00ol0003o[KcUojfli@0:ojfli@03o`00
0?n__NCo[kgT00Ko[kgT0ol000000on`_^Co0000ok:oi00<ok:oi003o`000?nc_n?o/koS00[o/koS
00?o0000okC0hond`><01Ond`><2o`0000Co]<7S00?o0000okG1hone`N<02one`N<00ol0003ooooo
ooooo`1<ooooo`00:oooool00ol0003oooooooooo`0cooooo`03o`000?nQ^^[oXK[Z00SoXK[Z0ol0
0009oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P02OnR^>P00ol0003oY;WWojBi
i`09ojBii`03o`000?nV^NKoY[WV00KoY[WV0ol000000onV^^Oo0000ojRkiP0:ojRkiP03o`000?n[
^nGoZk_U00WoZk_U0_l0000<ojfli@03o`000?n__NCo[kgT00?o[kgT0_l00005ok2ni003o`000?nb
_nCo/[oT00_o/[oT00?o0000ok>ohonc_n<02_nc_n<00ol0003o]<3SokC0h`02okC0h`;o00001ond
`N<00ol0003o]L7SokG1h`0:okG1h`;o0000COooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?oo
ool00ol0003oXK[Zoj6jjP04oj6jjP?o000000?oWkW[o`000?nP^NX02_nP^NX00ol0003oXKSYoj6h
j@09oj6hj@03o`000?nR^>SoX[SX00WoX[SX00?o0000ojBiionT^NL02OnT^NL00ol0003oY[WVojJi
iP03ojJiiP;o00001OnV^^L00ol0003oZ;_VojRkiP09ojRkiP03o`000?n[^nGoZk_U00SoZk_U00?o
0000oj^kiOl000003?n]_>D00ol0003o[kgTo`000002o`0000So/;kT00?o0000ok:oi?nb_n@02onb
_n@00ol0003o/koSok>oh`0:ok>oh`04o`000?nd`>?o0000o`0000[o]<7S00?o0000okG1hone`N<0
2_ne`N<2o`0004cooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?nQ^^[oXK[Z00?o0000
1OnO^N/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P0
2OnR^>P00ol0003oY;WWojBii`09ojBii`03o`000?nV^NKo000000;o00002?nV^^L00ol0003oZ;_V
ojRkiP09ojRkiP03o`000?n[^nGoZk_U00OoZk_U00?o0000oj^kiOl000003?n]_>D2o`0000co/;kT
00?o0000ok:oi?nb_n@02onb_n@00ol0003o/koSok>oh`09ok>oh`;o00003?nd`N<00ol0003o]L7S
okG1h`0;okG1h`03o`000?oooooooooo04[ooooo000@ooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Kooooo00?o0000ooooooooool0=_ooool2o`0000WoWkW[00?o0000oj2ij_nP^NX0
2OnP^NX00ol0003oXKSYoj6hj@09oj6hj@03o`000?nR^>SoX[SX00WoX[SX00?o0000ojBiionT^NL0
1onT^NL3o`0000coY[[W00?o0000ojRki_nX^nH02OnX^nH00ol0003oZk_Uoj^ki@06oj^ki@04o`00
0?n[^nGoZk_Uo`0000So[KcU0ol000000on^_NGo0000ok2ni00;ok2ni003o`000?nb_nCo/[oT00_o
/[oT00?o0000ok>ohonc_n<01_nc_n<3o`000003ok?0i?l0003o]<7S00co]<7S00?o0000okG1hone
`N<02one`N<00ol0003oooooooooo`19ooooo`004?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0gooooo`03o`000?nO^N_oWkW[
00SoWkW[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXKSYoj6hj@09oj6hj@03o`000?nR^>SoX[SX
00WoX[SX00Co0000ojBiionT^NOoY;WW1Ol00002oj>ij003o`000?nV^^OoY[[W00_oY[[W00?o0000
ojRki_nX^nH02?nX^nH00ol0003oZk_Uoj^ki@06oj^ki@05o`000?n[^nGoZk_Uoj^kiOl000001On]
_>D2o`0000Go[[gU00?o0000ok2ni?n`_^@02_n`_^@00ol0003o/[oTok:oi00;ok:oi003o`000?nc
_n?o/koS00?o/koS0_l00005ok?0i003o`000?nd`N?o]<7S00_o]<7S00?o0000okG1hone`N<02_ne
`N<2o`0004[ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00007ooooo`03o`000?oooooooooo03Sooooo00?o0000oinijonO^N/02?nO^N/00ol0003oX;WZ
oj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P02?nR^>P4o`0000SoXkWX
00?o0000ojJjionV^^L02_nV^^L00ol0003oZ;_VojRkiP09ojRkiP03o`000?n[^nGoZk_U00GoZk_U
00?o0000oj^kiOn[^nD00_n[^nD00ol0003o[KcUo`000002o`0000So[[gU00?o0000ok2ni?n`_^@0
2_n`_^@00ol0003o/[oTok:oi00;ok:oi003o`000?nc_n?o000000;o00002?nc`>@00ol0003o]<7S
okC1h`0;okC1h`03o`000?ne`N?o]L7S00[o]L7S0_l00019ooooo`004?ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool2o`0003_ooooo00?o0000oinijonO^N/0
2?nO^N/00ol0003oX;WZoj2ijP09oj2ijP03o`000?nQ^>WoXKSY00WoXKSY00?o0000oj:hj?nR^>P0
1?nR^>P3o`000003oj6ijOl0003oXkWX00[oXkWX00?o0000ojJjionV^^L02_nV^^L00ol0003oZ;_V
ojRkiP09ojRkiP03o`000?n[^nGoZk_U00CoZk_U00Co0000oj^kiOn[^nGoZk_U0ol0000<ojjmi@03
o`000?n`_^Co/;kT00[o/;kT00?o0000ok:oi?nb_n@02_nb_n@2o`0000co/l3T00?o0000okC1hond
`N<02ond`N<00ol0003o]L7SokG1h`07okG1h`;o000000?o]L7So`000?ooool0B?ooool0013ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooooooo
ool0>_ooool00ol0003oWkW[oinij`08oinij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj6hjOnQ
^>T02OnQ^>T00ol0003oX[SXoj:hj003o`0000GoXKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003o
Y[[WojJji`0:ojJji`03o`000?nX^nKoZ;_V00WoZ;_V00?o0000oj^kiOn[^nD00on[^nD4o`0000;o
ZkgV00?o0000ojjmiOn^_ND02_n^_ND00ol0003o/;kTok2ni00;ok2ni003o`000?nb_nCo/[oT00Oo
/[oT0_l000000onb`>Co0000ok?0i00<ok?0i003o`000?nd`N?o]<7S00[o]<7S00?o0000okG1hone
`N<01One`N<2o`0000Co]L7S00?o0000ooooooooool0A_ooool0013ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0??ooool00ol0003o
WkW[oinij`08oinij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj6hjOnQ^>T01onQ^>T4o`0000Wo
XKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003oY[[WojJji`0:ojJji`03o`000?nX^nKoZ;_V00Wo
Z;_V00?o0000oj^kiOn[^nD00ol00006oj^miP03o`000?n^_NGo[[gU00[o[[gU00?o0000ok2ni?n`
_^@02_n`_^@00ol0003o/[oTok:oi005ok:oi0;o00001?nb`>@00ol0003o/l3Tok?0i00;ok?0i003
o`000?nd`N?o]<7S00[o]<7S00?o0000okG1hone`N<00_ne`N<2o`0000Ko]L7S0_l00017ooooo`00
:_ooool00ol0003oooooooooo`0mooooo`03o`000?nO^N_oWkW[00SoWkW[00?o0000oj2ij_nP^NX0
2OnP^NX01?l0003oXKSYoj6hjOnQ^>T5o`0000;oWkSZ00?o0000oj6ijOnQ^NT02OnQ^NT00ol0003o
XkWXoj>ij009oj>ij003o`000?nV^^OoY[[W00WoY[[W00?o0000ojRki_nX^nH02OnX^nH3o`0000;o
ZkgV00?o0000oj^mi_n[_NH01On[_NH00ol0003o[[gUojjmi@0:ojjmi@03o`000?n`_^Co/;kT00[o
/;kT00?o0000ok:oi?nb_n@00_nb_n@2o`0000Oo//3T00?o0000ok?0i?nc`>@02_nc`>@00ol0003o
]<7SokC1h`0;okC1h`04o`000?ne`N?o0000o`0000Wo]L7S00?o0000ooooooooool0AOooool002[o
oooo00?o0000ooooooooool0?_ooool00ol0003oWkW[oinij`08oinij`03o`000?nP^N[oX;WZ00So
X;WZ1?l00008oinhjP03o`000?nQ^NWoXKWY00WoXKWY00?o0000oj>ij?nS^NP02OnS^NP00ol0003o
Y[[WojJji`09ojJji`03o`000?nX^nKoZ;_V00KoZ;_V0_l000000onX_>Oo0000oj^miP02oj^miP03
o`000?n[_NKoZkgV00KoZkgV00?o0000ojjmiOn^_ND02_n^_ND00ol0003o/;kTok2ni00:ok2ni004
o`000?nb_nCo0000o`0000[o//3T00?o0000ok?0i?nc`>@02_nc`>@00ol0003o]<7SokC1h`0:okC1
h`;o00003?ne`N<00ol0003oooooooooo`14ooooo`00:_ooool00ol0003oooooooooo`0oooooo`03
o`000?nO^N_oWkW[00SoWkW[00?o0000oj2ij_nP^NX01?nP^NX3o`000003oijhjol0003oWkSZ00[o
WkSZ00?o0000oj6ijOnQ^NT02OnQ^NT00ol0003oXkWXoj>ij009oj>ij003o`000?nV^^OoY[[W00Wo
Y[[W00?o0000ojRki_nX^nH00_nX^nH3o`0000CoZ;cW00Co0000oj^mi_n[_NKo00002On[_NH00ol0
003o[[gUojjmi@0:ojjmi@03o`000?n`_^Co/;kT00Wo/;kT0_l0000<ok;0i003o`000?nc`>Co/l3T
00_o/l3T00?o0000okC1hond`N<01_nd`N<3o`000003okC1i?l0003o]L7S00co]L7S00?o0000oooo
ooooool0@oooool002Wooooo0ol00010ooooo`;o00002_nO^N/00ol0003oX;WZoj2ijP03o`0000Go
W[S[00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@09oj6ij@03o`000?nS^NSoXkWX00Wo
XkWX00?o0000ojJjionV^^L02OnV^^L01?l0003oZ;_Vo`000?l00008ojRli`03o`000?n[_NKo0000
00[oZkgV00?o0000ojjmiOn^_ND02On^_ND00ol0003o/;kTok2ni006ok2ni0?o000000?o/;oUo`00
0?nb`>@03?nb`>@00ol0003o/l3Tok?0i00;ok?0i003o`000?nd`N?o]<7S00?o]<7S0_l00005okC1
i003o`000?ne`N?o]L7S00[o]L7S0_l00014ooooo`00:_ooool00ol0003oooooooooo`10ooooo`;o
00002?nO^N/4o`0000WoW[S[00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@08oj6ij@03
o`000?nS^NSoXkWX00[oXkWX00?o0000ojJjionV^^L01onV^^L3o`0000_oZ;cW0_l0000;oj^miP03
o`000?n^_NGo[[gU00Wo[[gU00?o0000ok2ni?n`_^@00on`_^@2o`0000Go/;oU00?o0000ok;0i?nb
`>@02onb`>@00ol0003o/l3Tok?0i00;ok?0i003o`000?nd`N?o000000;o00002?nd`N@00ol0003o
]L7SokG1h`0:okG1h`03o`000?oooooooooo04;ooooo000Zooooo`03o`000?oooooooooo047ooooo
0_l00002oinij`Go00000_nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00WoWkSZ
00?o0000oj6ijOnQ^NT02?nQ^NT00ol0003oXkWXoj>ij00:oj>ij004o`000?nV^^OoY[[WojJji`Go
00000_nU^nP00ol0003oZ;cWojRli`0:ojRli`03o`000?n[_NKoZkgV00[oZkgV00?o0000ojjmiOn^
_ND02On^_ND00ol0003o/;kTo`000002o`0000So/;oU00?o0000ok;0i?nb`>@02onb`>@00ol0003o
/l3Tok?0i00:ok?0i0;o00003?nd`N@00ol0003o]L7SokG1h`0:okG1h`03o`000?oooooooooo047o
oooo000Zooooo`03o`000?oooooooooo04;ooooo0ol00008oifik003o`000?nN^>_oW[S[00WoW[S[
00?o0000oinhj_nO^>X02OnO^>X00ol0003oXKWYoj6ij@08oj6ij@03o`000?nS^NSoXkWX00SoXkWX
1Ol00008ojFkj003o`000?nX_>OoZ;cW00WoZ;cW0_l0000<oj^miP03o`000?n^_NGo[[gU00So[[gU
0_l0000<ok2oi@03o`000?nb`>Co//3T00_o//3T00?o0000ok?0i?nc`>@01onc`>@2o`000003ok?1
i?l0003o]<7T00_o]<7T00?o0000okG1hone`N<02one`N<00ol0003oooooooooo`10ooooo`00:Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/02OnN
^>/00ol0003oWkSZoinhjP08oinhjP03o`000?nQ^NWoXKWY00WoXKWY00?o0000oj>ij?nS^NP01?nS
^NP3o`0000;oXk[Y00?o0000ojFkj?nU^nP02OnU^nP00ol0003oZ;cWojRli`08ojRli`03o`000?nX
_>Oo000000coZkgV00?o0000ojjmiOn^_ND01?n^_ND3o`000003ojjoi_l0003o/;oU00co/;oU00?o
0000ok;0i?nb`>@02_nb`>@00ol0003o/l3Tok?0i005ok?0i0;o00001?nc`N@00ol0003o]<7TokC1
i00:okC1i003o`000?ne`N?o]L7S00[o]L7S00?o0000ooooooooool0@?ooool002Wooooo00?o0000
ooooooooool0AOooool00ol0003oWKW/oifik008oifik003o`000?nN^>_oW[S[00WoW[S[00?o0000
oinhj_nO^>X02?nO^>X00ol0003oXKWYoj6ij@09oj6ij@03o`000?nS^NSoXkWX00?o00001_nS^^T0
0ol0003oYK_XojFkj009ojFkj003o`000?nX_>OoZ;cW00OoZ;cW00?o0000ojRliol000003On[_NH0
0ol0003o[[gUojjmi@03o`0000Go[[oV00?o0000ok2oiOn`_nD02on`_nD00ol0003o//3Tok;0i00:
ok;0i003o`000?nc`>Co/l3T00;o/l3T0_l00007ok?1i003o`000?nd`NCo]<7T00[o]<7T00?o0000
okG1hone`N<02_ne`N<00ol0003oooooooooo`0oooooo`00:Oooool00ol0003oooooooooo`16oooo
o`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/02OnN^>/00ol0003oWkSZoinhjP08oinh
jP03o`000?nQ^NWoXKWY00SoXKWY0ol0000:oj>jj@03o`000?nU^nSoYK_X00WoYK_X00?o0000ojRl
ionX_>L01_nX_>L01?l0003oZ;cWojRliol0000<oj^miP?o00002On^_nH00ol0003o/;oUok2oi@0:
ok2oi@03o`000?nb`>Co//3T00_o//3T00Co0000ok?0i?l0003o00002_nc`N@00ol0003o]<7TokC1
i00:okC1i003o`000?ne`N?o]L7S00Wo]L7S0_l00010ooooo`00:Oooool2o`0004Sooooo00?o0000
oifik?nM^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00SoWkSZ00?o0000
oj6ijOnQ^NT01?nQ^NT3o`000003oj2ij_l0003oXk[Y00_oXk[Y00?o0000ojFkj?nU^nP02OnU^nP0
0ol0003oZ;cWojRli`05ojRli`05o`000?nX_>OoZ;cWojRliol000002?n[_NH3o`000003oj^niol0
003o[[oV00[o[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i00:ok;0i0;o00003?nc
`N@00ol0003o]<7TokC1i00:okC1i003o`000?ne`N?o]L7S00Ko]L7S0ol000000ond`NCo0000o`00
000oooooo`00:Oooool00ol0003oooooooooo`18ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000
oijhjonN^>/02OnN^>/00ol0003oWkSZoinhjP08oinhjP03o`000?nQ^NWoXKWY00?o00001OnP^NX0
0ol0003oXk[Yoj>jj@0:oj>jj@03o`000?nU^nSoYK_X00SoYK_X00?o0000ojRlionX_>L01OnX_>L0
0ol0003oZ;cWojRli`02ojRli`03o`000?n[_NKoZkgV00?oZkgV0_l00005oj^ni`03o`000?n^_nKo
[[oV00Wo[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i006ok;0i0?o000000?o//7U
o`000?nc`N@03?nc`N@00ol0003o]<7TokC1i00:okC1i003o`000?ne`N?o]L7S00?o]L7S0_l00005
okC1i003o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo04Wooooo00?o0000oifi
k?nM^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00KoWkSZ1?l00009oj2i
jP03o`000?nS^^WoXk[Y00[oXk[Y00?o0000ojFkj?nU^nP02?nU^nP00ol0003oZ;cWojRli`04ojRl
i`03o`000?nX_>OoZ;cW00?oZ;cW00?o0000oj^mi_l000000_l00008oj^ni`03o`000?n^_nKo[[oV
00Wo[[oV00?o0000ok2oiOn`_nD02_n`_nD00ol0003o//3Tok;0i003ok;0i0;o00001Onb`ND00ol0
003o/l7Tok?1i00;ok?1i003o`000?nd`NCo]<7T00[o]<7T00?o0000okG1hol000000_l00008okC1
i003o`000?oooooooooo03cooooo000Yooooo`03o`000?oooooooooo04[ooooo00?o0000oifik?nM
^N`02?nM^N`00ol0003oW[S[oijhj`09oijhj`03o`000?nO^>[oWkSZ00Go00000_nN^N/00ol0003o
X;WZoj2ijP09oj2ijP03o`000?nS^^WoXk[Y00[oXk[Y00?o0000ojFkj?nU^nP02?nU^nP00ol0003o
Z;cWojRli`03ojRli`03o`000?nX_>OoZ;cW00;oZ;cW0ol0000<oj^ni`03o`000?n^_nKo[[oV00So
[[oV00?o0000ok2oiOn`_nD02on`_nD00ol0003o//3To`000002o`0000So//7U00?o0000ok?1i?nc
`N@02onc`N@00ol0003o]<7TokC1i009okC1i0;o00003?nd`N@00ol0003oooooooooo`0kooooo`00
:Oooool00ol0003oooooooooo`1;ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000oijhjonN^>/0
1onN^>/4o`0000SoW[W[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>jj@09oj>jj@03o`00
0?nU^nSoYK_X00WoYK_X00?o0000ojRlionX_>L00_nX_>L00ol0003oZ;cWo`000002o`0000;oZ;gX
00?o0000oj^nion[_^L02on[_^L00ol0003o[[oVojjoiP08ojjoiP03o`000?n`_nGo/;oU00[o/;oU
0_l0000<ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000okC1i?nd`N@01_nd`N@3o`000003okC1
i?l0003o]<7T00_o]<7T0_l0000looooo`00:Oooool00ol0003oooooooooo`1<ooooo`03o`000?nM
^NcoWKW/00SoWKW/00Co0000oijhjonN^>_oW[S[1Ol00002oifhk003o`000?nN^N_oW[W[00SoW[W[
00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>jj@09oj>jj@03o`000?nU^nSoYK_X00WoYK_X
00?o0000ojRlionX_>L00ol00006ojRmj003o`000?n[_^OoZkkW00_oZkkW00?o0000ojjoi_n^_nH0
2?n^_nH00ol0003o/;oUok2oi@06ok2oi@?o000000?o/<7Vo`000?nb`ND03?nb`ND00ol0003o/l7T
ok?1i00:ok?1i003o`000?nd`NCo]<7T00?o]<7T0_l00005okC1i003o`000?nd`NCo]<7T00[o]<7T
00?o0000ooooooooool0>_ooool002Sooooo0ol0001>ooooo`03o`000?nM^NcoWKW/00KoWKW/1Ol0
0008oifhk003o`000?nN^N_oW[W[00SoW[W[00?o0000oj2ij_nP^NX02OnP^NX00ol0003oXk[Yoj>j
j@09oj>jj@03o`000?nU^nSoYK_X00SoYK_X0ol000000onX_NSo0000ojRmj007ojRmj003o`000?n[
_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH02On^_nH00ol0003o/;oUok2oi@03ok2oi@;o00001On`
`NH00ol0003o//7Uok;1i@0;ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000okC1i?l000000_l0
0008okC1i003o`000?nd`NCo]<7T00[o]<7T00?o0000ooooooooool0>Oooool002Sooooo00?o0000
ooooooooool0Coooool00ol0003oWKW/oifik005o`0000;oW;S/00?o0000oifhk?nM^>`02OnM^>`0
0ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj>jjOnS^^T02OnS^^T0
0ol0003oYK_XojFkj004ojFkj0?o000000GoYKcYo`000?nX_NSoZ;gXo`000009ojRmj003o`000?n[
_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH02On^_nH00ol0003o/;oUo`000002o`0000So/<7V00?o
0000ok;1iOnb`ND02onb`ND00ol0003o/l7Tok?1i009ok?1i0;o00003?nd`N@00ol0003o]<7TokC1
i00:okC1i003o`000?oooooooooo03Sooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c007ooooo`03o`000?oooooooooo053ooooo
0_l00008oibhk003o`000?nM^>coWKS/00WoWKS/00?o0000oijijonN^N/02?nN^N/00ol0003oX;WZ
oj2ijP09oj2ijP03o`000?nS^^WoXk[Y00WoXk[Y00?o0000ojFkj?nU^nP00ol00005ojFlj@03o`00
0?nX_NSo000000[oZ;gX00?o0000oj^nion[_^L02_n[_^L00ol0003o[[oVojjoiP08ojjoiP;o0000
3?n``NH00ol0003o//7Uok;1i@0;ok;1i@03o`000?nc`NCo/l7T00Ko/l7T0_l000000onc`^Go0000
okC1i00;okC1i003o`000?nd`NCo]<7T00[o]<7T0_l0000iooooo`003?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00ol0003o
ooooooooo`1@ooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifhk?nM^>`02OnM^>`00ol0003o
W[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00?o0000oj>jjOnS^^T01onS^^T4o`0000Wo
YKcY0_l0000;ojRmj003o`000?n[_^OoZkkW00[oZkkW00?o0000ojjoi_n^_nH01?n^_nH3o`000003
ojk0iol0003o/<7V00co/<7V00?o0000ok;1iOnb`ND02onb`ND00ol0003o/l7Tok?1i002ok?1i0?o
00001?nc`^D00ol0003o]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00[o]<7T00?o0000oooooooo
ool0=oooool000cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`1Aooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifh
k?nM^>`02OnM^>`00ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00WoX;WZ00Co0000oj>j
jOnS^^WoXk[Y1Ol00002oj>kjP03o`000?nU_>WoYKcY00GoYKcY0ol000000onU_>Wo0000ojRmj00:
ojRmj003o`000?n[_^OoZkkW00_oZkkW00?o0000ojjoi_n^_nH00ol00005ojk0i`03o`000?n``NKo
/<7V00_o/<7V00?o0000ok;1iOnb`ND02onb`ND01?l0003o/l7To`000?l00008ok?2i@03o`000?nd
`NCo]<7T00[o]<7T00?o0000okC1i?nd`N@02_nd`N@00ol0003oooooooooo`0fooooo`003?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03o`00
0?oooooooooo05;ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oWKS/oifhk009oifhk003o`00
0?nN^N_oW[W[00SoW[W[00?o0000oj2ij_nP^NX02?nP^NX4o`0000SoXk_Z00Co0000ojFljOnU_>Wo
YKcY0ol00005ojFlj@03o`000?nX_NSoZ;gX00WoZ;gX00?o0000oj^nion[_^L02_n[_^L3o`0000Wo
[/3W00?o0000ok31i_n``NH02on``NH00ol0003o//7Uok;1i@0:ok;1i@;o00002onc`^D00ol0003o
]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00Wo]<7T0_l0000gooooo`003?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c007ooooo`03o`000?oooooooooo
05?ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oWKS/oifhk009oifhk003o`000?nN^N_oW[W[
00SoW[W[00?o0000oj2ij_nP^NX01?nP^NX3o`000003oj2jjol0003oXk_Z00[oXk_Z0ol00009ojFl
j@03o`000?nX_NSoZ;gX00WoZ;gX00?o0000oj^nion[_^L01_n[_^L3o`000003oj^oj?l0003o[/3W
00[o[/3W00?o0000ok31i_n``NH02on``NH00ol0003o//7Uok;1i@06ok;1i@?o000000?o/L;Vo`00
0?nc`^D02_nc`^D00ol0003o]<7TokC1i00:okC1i003o`000?nd`NCo]<7T00Ko]<7T0ol000000onc
`NCo0000o`00000fooooo`003?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifh
k?nM^>`02OnM^>`00ol0003oW[W[oijij`08oijij`03o`000?nP^N[oX;WZ00?o00001OnP^^/00ol0
003oXk_Zoj>kjP05oj>kjP?o000000?oXk_Zo`000?nU_>T02_nU_>T00ol0003oZ;gXojRmj009ojRm
j003o`000?n[_^OoZkkW00?oZkkW0_l00005oj^oj003o`000?n^`>Oo[/3W00Wo[/3W00?o0000ok31
i_n``NH02on``NH00ol0003o//7Uok;1i@03ok;1i@;o00001Ona`^H00ol0003o/l;Uok?2i@09ok?2
i@03o`000?nd`NCo]<7T00[o]<7T00?o0000okC1i?nd`N@00ond`N@2o`0000Go/l7T00?o0000oooo
ooooool0=?ooool000cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Sooooo0_l0001Gooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oifhk?nM^>`02OnM^>`00ol0
003oW[W[oijij`06oijij`Co00002OnP^^/01?l0003oXk_Zoj>kj_nS^nX3o`0000GoXk_Z00?o0000
ojFljOnU_>T02OnU_>T00ol0003oZ;gXojRmj009ojRmj003o`000?n[_^Oo000000;o00002?n[_nP0
0ol0003o[/3Wojk0i`09ojk0i`03o`000?n``NKo/<7V00_o/<7V00?o0000ok;1iOl000000_l00008
ok72iP03o`000?nc`^Go/l;U00Wo/l;U00?o0000okC1i?nd`N@02_nd`N@00ol0003o]<7To`000002
o`0000So/l7T00?o0000ooooooooool0<oooool000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0Eoooool00ol0003oW;S/oibh
k008oibhk003o`000?nM^>coWKS/00WoWKS/00?o0000oijijonN^N/01Ol00003oijik003o`000?nP
^^_oX;[[00SoX;[[0ol00009oj>kjP03o`000?nU_>WoYKcY00WoYKcY00?o0000ojRmj?nX_NP02?nX
_NP2o`0000coZkoX00?o0000ojk0ion^`>L02On^`>L00ol0003o/<7Vok31iP0:ok31iP;o00003?na
`^H00ol0003o/l;Uok?2i@09ok?2i@03o`000?nd`NCo]<7T00Wo]<7T0_l0000<ok?1i003o`000?oo
oooooooo03;ooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o0000oibhk?nL^>`02?nL^>`0
0ol0003oWKS/oifhk007oifhk0Co00002OnN^N`00ol0003oX;[[oj2jj`04oj2jj`?o000000?oX;[[
o`000?nS^nX02OnS^nX00ol0003oYKcYojFlj@0:ojFlj@03o`000?nX_NSoZ;gX00CoZ;gX0ol00000
0onX_^Wo0000oj^oj00<oj^oj003o`000?n^`>Oo[/3W00Wo[/3W00?o0000ok31i_n``NH01_n``NH3
o`000003ok32iol0003o/L;V00_o/L;V00?o0000ok?2iOnc`^D02Onc`^D00ol0003o]<7TokC1i006
okC1i0?o000000?o//7Uo`000?nc`N@03?nc`N@00ol0003oooooooooo`0aooooo`009oooool00ol0
003oooooooooo`1Iooooo`03o`000?nL^>coW;S/00SoW;S/00Co0000oifhk?nM^>coWKS/1Ol00002
oibhk003o`000?nN^NcoW[W/00WoW[W/00?o0000oj2jjonP^^/00ol00005oj2jj`03o`000?nS^n[o
Xk_Z00SoXk_Z00?o0000ojFljOnU_>T02_nU_>T00ol0003oZ;gXojRmj003o`0000GoZ;kY00?o0000
oj^oj?n[_nP02on[_nP00ol0003o[/3Wojk0i`09ojk0i`03o`000?n``NKo/<7V00?o/<7V0_l00005
ok32i`03o`000?na`^Ko/L;V00[o/L;V00?o0000ok?2iOnc`^D02Onc`^D00ol0003o]<7TokC1i003
okC1i0;o00001Onb`ND00ol0003o/l7Tok?1i00:ok?1i0;o0000<_ooool002Oooooo00?o0000oooo
ooooool0F_ooool00ol0003oW;S/oibhk006oibhk0Go00002?nL^>`00ol0003oW[W/oijik008oiji
k0?o00002OnP^^/00ol0003oXk_Zoj>kjP08oj>kjP03o`000?nU_>WoYKcY00SoYKcY1?l00009ojRn
j@03o`000?n[_nSoZkoX00[oZkoX00?o0000ojk0ion^`>L02_n^`>L00ol0003o/<7Vo`000002o`00
00So/<;W00?o0000ok72i_na`^H02_na`^H00ol0003o/l;Uok?2i@09ok?2i@03o`000?nd`NCo0000
00;o00002?nb`ND00ol0003o/l7Tok?1i00:ok?1i003o`000?oooooooooo033ooooo000Wooooo`03
o`000?oooooooooo05_ooooo00?o0000oibhk?nL^>`01Ol00003oibhk003o`000?nL^>coW;S/00So
W;S/00?o0000oijik?nN^N`01?nN^N`3o`0000;oW[W/00?o0000oj2jjonP^^/02?nP^^/00ol0003o
Xk_Zoj>kjP08oj>kjP03o`000?nU_>WoYKcY00CoYKcY0ol00002ojFmjP03o`000?nX_^WoZ;kY00Wo
Z;kY00?o0000oj^oj?n[_nP02_n[_nP00ol0003o[/3Wojk0i`09ojk0i`;o00003?n``^L00ol0003o
/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00So/l;U0_l0000<ok;1i@03o`000?nc`NCo/l7T00[o
/l7T00?o0000ooooooooool0;oooool002Oooooo0_l0001Mooooo`;o00002OnL^>`00ol0003oW;S/
oibhk008oibhk003o`000?nN^NcoW[W/00?o00001_nN^N`00ol0003oX;[[oj2jj`08oj2jj`03o`00
0?nS^n[oXk_Z00SoXk_Z00?o0000ojFljOnU_>T00ol00006ojFmjP03o`000?nX_^WoZ;kY00WoZ;kY
00?o0000oj^oj?n[_nP02_n[_nP00ol0003o[/3Wojk0i`06ojk0i`;o000000?o[/7Xo`000?n``^L0
2on``^L00ol0003o/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00Ko/l;U0_l000000onb`^Ko0000
ok;1i@0<ok;1i@03o`000?nc`NCo/l7T00[o/l7T00?o0000ooooooooool0;_ooool002Kooooo0_l0
001Oooooo`03o`000?nL^>coW;S/00SoW;S/00?o0000oibhk?nL^>`01onL^>`3o`0000[oW[W/00?o
0000oj2jjonP^^/02?nP^^/00ol0003oXk_Zoj>kjP06oj>kjPCo00002_nU_NX00ol0003oZ;kYojRn
j@09ojRnj@03o`000?n[_nSoZkoX00[oZkoX00?o0000ojk0ion^`>L00_n^`>L3o`0000Co[/7X00?o
0000ok32ion``^L02_n``^L00ol0003o/L;Vok72iP0:ok72iP03o`000?nc`^Go/l;U00;o/l;U0ol0
0004ok;2iP03o`000?nb`NGo//7U00_o//7U00?o0000ok?1i?nc`N@02Onc`N@2o`0002oooooo000W
ooooo`03o`000?oooooooooo05kooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oW;S/oibhk003
oibhk0?o00000_nL^>`00ol0003oW[W/oijik009oijik003o`000?nP^^_oX;[[00SoX;[[00?o0000
oj>kj_nS^nX01Ol00002oj>lj`03o`000?nU_N[oYKgZ00[oYKgZ00?o0000ojRnjOnX_^T02OnX_^T0
0ol0003oZkoXoj^oj00:oj^oj004o`000?n^`>Oo0000o`0000So[/7X00?o0000ok32ion``^L02_n`
`^L00ol0003o/L;Vok72iP0:ok72iP04o`000?nc`^Go0000o`0000So//;V00?o0000ok;1iOnb`ND0
2_nb`ND00ol0003o/l7Tok?1i00:ok?1i0;o0000;_ooool002Oooooo00?o0000ooooooooool0Gooo
ool00ol0003oW;S/oibhk008oibhk003o`000?nL^>co000000;o00001_nL^>`00ol0003oW[W/oiji
k009oijik003o`000?nP^^_oX;[[00KoX;[[1?l00008oj>lj`03o`000?nU_N[oYKgZ00[oYKgZ00?o
0000ojRnjOnX_^T02OnX_^T00ol0003oZkoXoj^oj008oj^oj0?o00002on^`NP00ol0003o/<;Wok32
i`0:ok32i`03o`000?na`^Ko/L;V00Wo/L;V0_l0000;ok;2iP03o`000?nb`NGo//7U00[o//7U00?o
0000ok?1i?nc`N@01_nc`N@3o`000003ok70iOl0003ooooo02gooooo000Vooooo`03o`000?oooooo
oooo067ooooo00?o0000oibhk?nL^>`01_nL^>`3o`0000[oW;S/00?o0000oijik?nN^N`02OnN^N`0
0ol0003oX;[[oj2jj`05o`0000;oX;_/00?o0000oj>ljonS_>/02?nS_>/00ol0003oYKgZojFmjP0:
ojFmjP03o`000?nX_^WoZ;kY00WoZ;kY00?o0000oj^oj?n[_nP01?n[_nP3o`0000;oZl3Y00?o0000
ojk1j?n^`NP02_n^`NP00ol0003o/<;Wok32i`09ok32i`03o`000?na`^Ko/L;V00Ko/L;V0ol00000
0ona`^Oo0000ok;2iP0;ok;2iP03o`000?nb`NGo//7U00[o//7U00?o0000ok?1i?nc`N@00onc`N@2
o`0000Go/L3U00?o0000ooooooooool0:oooool002Kooooo00?o0000ooooooooool0H_ooool00ol0
003oW;S/oibhk002oibhk0?o00000onL^>`00ol0003oW;S/oibhk008oibhk003o`000?nN^NcoW[W/
00OoW[W/1?l00008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX02_nU_NX00ol0
003oZ;kYojRnj@09ojRnj@03o`000?n[_nSoZkoX00?o00001_n[`>T00ol0003o[/7Xojk1j00:ojk1
j003o`000?n``^Oo/<;W00Wo/<;W00?o0000ok72i_na`^H00ona`^H2o`0000Go/L;W00?o0000ok;2
i_nb`^H02_nb`^H00ol0003o//7Uok;1i@0:ok;1i@03o`000?nc`NCo000000;o00001ona`>D2o`00
02cooooo000Vooooo`03o`000?oooooooooo06?ooooo1?l00007oibhk003o`000?nL^>coW;S/00So
W;S/00Co0000oijik?nN^NcoW[W/1Ol00002oijjk003o`000?nP^ncoX;_/00SoX;_/00?o0000oj>l
jonS_>/02?nS_>/00ol0003oYKgZojFmjP09ojFmjP;o00002_nX_^T3o`0000[oZl3Y00?o0000ojk1
j?n^`NP02_n^`NP00ol0003o/<;Wok32i`09ok32i`03o`000?na`^Ko000000;o00002?na`^L00ol0
003o//;Vok;2iP09ok;2iP03o`000?nb`NGo//7U00[o//7U0_l0000;ok70i@03o`000?oooooooooo
02[ooooo000Vooooo`;o0000Hoooool3o`0000[oW;S/00?o0000oibhk?nL^>`01_nL^>`5o`0000So
W[[/00?o0000oj2kk?nP^n`02?nP^n`00ol0003oXkc[oj>lj`08oj>lj`03o`000?nU_N[oYKgZ00Wo
YKgZ0_l00006ojRnj@?o000000?oZ;oZo`000?n[`>T02on[`>T00ol0003o[/7Xojk1j00:ojk1j003
o`000?n``^Oo/<;W00So/<;W0_l0000<ok72i`03o`000?nb`^Ko//;V00Wo//;V00?o0000ok;1iOnb
`ND01_nb`ND3o`000003ok71i_l0003o/L3U00_o/L3U00?o0000ooooooooool0:Oooool002Kooooo
00?o0000ooooooooool0Goooool3o`0000?ooooo00?o0000oibhk?nL^>`02?nL^>`00ol0003oW;S/
oibhk005o`0000;oWKW/00?o0000oijjk?nN^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`00
0?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX02OnU_NX2o`0000;oZ;kY0ol00005ojRojP03o`00
0?n[`>WoZl3Y00[oZl3Y00?o0000ojk1j?n^`NP02_n^`NP00ol0003o/<;Wok32i`04ok32i`?o0000
00?o[l;Xo`000?na`^L03?na`^L00ol0003o//;Vok;2iP09ok;2iP03o`000?nb`NGo//7U00?o//7U
0_l00005ok71iP03o`000?na`>Go/L3U00[o/L3U00?o0000ooooooooool0:?ooool002Kooooo00?o
0000ooooooooool0G?ooool3o`0000Oooooo00?o0000oibhk?nL^>`01_nL^>`4o`0000SoWKW/00?o
0000oijjk?nN^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o
0000ojFmj_nU_NX02?nU_NX4o`0000WoZ;oZ00?o0000oj_0jOn[`>T02_n[`>T00ol0003o[/7Xojk1
j00:ojk1j003o`000?n``^Oo/<;W00?o00001On_`^P00ol0003o/L;Wok72i`0;ok72i`03o`000?nb
`^Ko//;V00Wo//;V00?o0000ok;1iOl000000_l00008ok71iP03o`000?na`>Go/L3U00Wo/L3U00?o
0000ooooooooool0:?ooool002Kooooo00?o0000ooooooooool0FOooool3o`0000_ooooo00?o0000
oibhk?nL^>`01Ol00002oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`02OnN^^`0
0ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00SoXkc[00?o0000ojFmj_nU_NX01?nU_NX3
o`0000;oY[k[00?o0000ojRoj_nX_nX02OnX_nX00ol0003oZl3Yoj_0j@09oj_0j@03o`000?n^`NSo
[/7X00[o[/7X0ol00009ojo2j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok;2i_nb`^H02Onb`^H2
o`0000co/L7V00?o0000ok70iOna`>D02Ona`>D00ol0003oooooooooo`0Wooooo`009_ooool00ol0
003oooooooooo`1Fooooo`?o00003oooool2o`0000SoW;S/00?o0000oifik?nM^N`02?nM^N`00ol0
003oW[[/oijjk009oijjk003o`000?nP^ncoX;_/00SoX;_/00?o0000oj>ljonS_>/02?nS_>/00ol0
003oYKgZojFmjP03o`0000KoY[k[00?o0000ojRoj_nX_nX02OnX_nX00ol0003oZl3Yoj_0j@09oj_0
j@03o`000?n^`NSo[/7X00Ko[/7X0ol000000on]`^Wo0000ojo2j00:ojo2j003o`000?na`^Oo/L;W
00[o/L;W00?o0000ok;2i_nb`^H01_nb`^H2o`000003ok32iol0003o/L7V00co/L7V00?o0000ok70
iOna`>D02Ona`>D00ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`1Cooooo`?o
00004oooool00ol0003oW;S/oibhk007oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN
^^`02OnN^^`00ol0003oX;_/oj2kk008oj2kk003o`000?nS_>_oXkc[00KoXkc[1?l0000:ojJnj`03
o`000?nX_n[oZ;oZ00WoZ;oZ00?o0000oj_0jOn[`>T02On[`>T00ol0003o[/7Xojk1j003ojk1j0;o
00001On]`^T00ol0003o[l;Xojo2j009ojo2j003o`000?na`^Oo/L;W00[o/L;W00?o0000ok;2i_nb
`^H00_nb`^H3o`0000Co/<;W00?o0000ok71i_na`NH02ona`NH00ol0003o/L3Uok70i@08ok70i@;o
00009oooool002Gooooo00?o0000ooooooooool0DOooool3o`0001Oooooo00?o0000oibhk?nL^>`0
1onL^>`00ol0003oWKW/oifik008oifik003o`000?nN^^coW[[/00WoW[[/00?o0000oj2kk?nP^n`0
2?nP^n`00ol0003oXkc[oj>lj`05o`0000?oXkg/00?o0000ojJnjonV_^/02?nV_^/2o`0000_oZ;oZ
00?o0000oj_0jOn[`>T02On[`>T00ol0003o[/7Xo`000002o`0000So[L;Y00?o0000ojo2j?n_`^P0
2On_`^P00ol0003o/L;Wok72i`0:ok72i`04o`000?nb`^Ko0000o`0000So/<;W00?o0000ok71i_na
`NH02_na`NH00ol0003o/L3Uok70i@09ok70i@03o`000?oooooooooo02Gooooo000Uooooo`?o0000
C_ooool3o`0001[ooooo0_l00009oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`0
2OnN^^`00ol0003oX;_/oj2kk006oj2kk0Co00002OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o0000
2onX_nX00ol0003oZl3Yoj_0j@08oj_0j@;o00003?n]`^T00ol0003o[l;Xojo2j009ojo2j003o`00
0?na`^Oo/L;W00So/L;W0ol0000;ok32i`03o`000?na`NKo/L7V00[o/L7V00?o0000ok70iOna`>D0
2?na`>D2o`0002Kooooo000Uooooo`03o`000?oooooooooo04_ooooo0ol0000Nooooo`;o00002OnL
^>`00ol0003oWKW/oifik008oifik003o`000?nN^^coW[[/00WoW[[/00?o0000oj2kk?nP^n`01Ol0
0002oj6lk003o`000?nS_NcoXkg/00WoXkg/00?o0000ojJnjonV_^/02?nV_^/2o`0000_oZ;oZ00?o
0000oj_0jOn[`>T01?n[`>T3o`0000;oZl;Z00?o0000ojg2jOn]`^T02_n]`^T00ol0003o[l;Xojo2
j009ojo2j003o`000?na`^Oo/L;W00Co/L;W0ol00002ojo3j003o`000?n``^Oo/<;W00[o/<;W00?o
0000ok71i_na`NH02_na`NH00ol0003o/L3Uok70i@04ok70i@?o000000?o[l3Vo`000?l000009Ooo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0B?ooool3o`0002;ooooo0_l00009oibhk003o`00
0?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`02?nN^^`3o`0000SoXKc/00?o0000oj>mk?nS_N`0
2OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o00002onX_nX00ol0003oZl3Yoj_0j@03o`0000KoZl;Z
00?o0000ojg2jOn]`^T02_n]`^T00ol0003o[l;Xojo2j009ojo2j003o`000?na`^Oo/L;W00?o0000
1_n_`nP00ol0003o/<;Wok32i`0:ok32i`03o`000?na`NKo/L7V00[o/L7V00?o0000ok70iOna`>D0
0ol00005ojo0iP;o00009?ooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0000ooooooooool0AOooool3o`0002Ko
oooo0_l00009oibhk003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`01?nN^^`3o`000003
oinkk?l0003oXKc/00WoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o
00002_nX_nX3o`0000[oZl;Z00?o0000ojg2jOn]`^T02On]`^T00ol0003o[l;Xojo2j009ojo2j0?o
00002_n_`nP00ol0003o/<;Wok32i`09ok32i`03o`000?na`NKo/L7V00[o/L7V0ol00009ojo0iP03
o`000?oooooooooo02;ooooo0009ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0@_ooool3o`0002[ooooo0_l00009oibh
k003o`000?nM^NcoWKW/00SoWKW/00?o0000oijjk?nN^^`00ol00005oinkk003o`000?nQ_>coXKc/
00SoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08ojJnj`;o00001_nX_nX3o`00
0003ojS1jol0003oZl;Z00_oZl;Z00?o0000ojg2jOn]`^T02On]`^T00ol0003o[l;Xojo2j006ojo2
j0;o000000?o[/?Yo`000?n_`nP02on_`nP00ol0003o/<;Wok32i`09ok32i`03o`000?na`NKo/L7V
00Ko/L7V0ol000000on_`NOo0000ojo0iP0:ojo0iP03o`000?oooooooooo027ooooo0009ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?o0000
ooooooooool0?oooool3o`0002kooooo0_l00009oibhk003o`000?nM^NcoWKW/00KoWKW/1?l00009
oinkk003o`000?nQ_>coXKc/00SoXKc/00?o0000oj>mk?nS_N`02OnS_N`00ol0003oY[k[ojJnj`08
ojJnj`;o00000_nX_nX3o`0000GoZ<7[00?o0000oj_2j_n[`^X02_n[`^X00ol0003o[L;Yojg2j@09
ojg2j@03o`000?n_`^So[l;X00;o[l;X0ol00004ojk3j@03o`000?n_`nSo[l?X00[o[l?X00?o0000
ok32ion``^L02On``^L00ol0003o/L7Vok71iP03ok71iP;o00001On_`NL00ol0003o[l3Vojo0iP08
ojo0iP;o00008_ooool000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01oooool00ol0003oooooooooo`0looooo`?o0000<_ooool2o`0000WoW;S/00?o
0000oifik?nM^N`01Ol00003oijik003o`000?nO^ncoWk_/00SoWk_/00?o0000oj6lk?nQ_>`02?nQ
_>`00ol0003oXkg/oj>mk009oj>mk003o`000?nV_^_oY[k[00OoY[k[1?l00009ojS1j`03o`000?n[
`^[oZl;Z00[oZl;Z00?o0000ojg2jOn]`^T02On]`^T01?l0003o[l;Xo`000?l00008ojk3j@03o`00
0?n_`nSo[l?X00[o[l?X00?o0000ok32ion``^L02On``^L00ol0003o/L7Vo`000002o`0000So[l7W
00?o0000ojo0i_n_`>H02?n_`>H2o`00027ooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Oooooo00?o0000ooooooooool0>Oooool3o`0003Ko
oooo0_l00005oibhk0Ko00002OnN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>coXKc/00So
XKc/00?o0000oj>mk?nS_N`02OnS_N`01?l0003oY[k[ojJnjonV_^/5o`000003ojJok?l0003o0000
00_oZ<7[00?o0000oj_2j_n[`^X02_n[`^X00ol0003o[L;Yojg2j@08ojg2j@;o00002on^`nT00ol0
003o[l?Xojo3j00:ojo3j003o`000?n``^Oo/<;W00So/<;W0_l0000<ojo1i`03o`000?n_`>Ko[l3V
00So[l3V00?o0000ooooooooool07oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0gooooo`?o0000>_ooool6
o`0000GoWKW/00?o0000oijik?nN^N`02?nN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>co
XKc/00SoXKc/00?o0000oj>mk?nS_N`02?nS_N`4o`0000OoY[o/0_l0000;ojS1j`03o`000?n[`^[o
Zl;Z00[oZl;Z00?o0000ojg2jOn]`^T01?n]`^T3o`000003ojc3j_l0003o[/?Y00_o[/?Y00?o0000
ojo3j?n_`nP02_n_`nP00ol0003o/<;Wok32i`04ok32i`?o000000?o[/;Xo`000?n_`NL02on_`NL0
0ol0003o[l3Vojo0iP08ojo0iP;o00008?ooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0dooooo`?o0000?_oo
ool00ol0003oWKW/oifik008oifik003o`000?nN^NcoW[W/00SoW[W/00?o0000oinkk?nO^n`02?nO
^n`00ol0003oXKc/oj6lk008oj6lk003o`000?nS_NcoXkg/00CoXkg/0ol000000onT_^co0000ojJo
k009ojJok0;o00002onX`N/00ol0003oZl;Zoj_2jP0:oj_2jP03o`000?n]`^Wo[L;Y00?o00001On/
`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n_`nSo[l?X00[o[l?X00?o0000ok32ion``^L00ol0
0005ojk2j003o`000?n_`NOo[l7W00[o[l7W00?o0000ojo0i_n_`>H02?n_`>H2o`0001oooooo000T
ooooo`03o`000?oooooooooo037ooooo0ol00012ooooo`03o`000?nM^NcoWKW/00SoWKW/00?o0000
oijik?nN^N`02?nN^N`00ol0003oWk_/oinkk008oinkk003o`000?nQ_>coXKc/00SoXKc/00?o0000
oj>mk?nS_N`00ol00005ojBnk003o`000?nV_ncoY[o/00SoY[o/0_l0000;ojS1j`03o`000?n[`^[o
Zl;Z00SoZl;Z1?l00009ojc3jP03o`000?n^`nWo[/?Y00[o[/?Y00?o0000ojo3j?n_`nP02?n_`nP4
o`0000Wo[/;X00?o0000ojo1ion_`NL02_n_`NL00ol0003o[l3Vojo0iP08ojo0iP;o00007_ooool0
02Cooooo00?o0000ooooooooool0;oooool2o`0004Kooooo00?o0000oifik?nM^N`02?nM^N`00ol0
003oW[W/oijik008oijik003o`000?nO^ncoWk_/00SoWk_/00?o0000oj6lk?nQ_>`01_nQ_>`4o`00
00WoY;k/00?o0000ojJok?nV_n`02?nV_n`2o`0000_oZ<7[00?o0000oj_2j_n[`^X01?n[`^X3o`00
00;oZl;[00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n_`nSo[l?X
00Co[l?X0ol00002ojk3j@03o`000?n^`^So[/;X00Wo[/;X00?o0000ojo1ion_`NL02On_`NL00ol0
003o[l3Vojo0iP08ojo0iP;o00007_ooool002Cooooo00?o0000ooooooooool0;?ooool3o`0004Wo
oooo00?o0000oifik?nM^N`02?nM^N`00ol0003oW[W/oijik008oijik003o`000?nO^ncoWk_/00So
Wk_/00?o0000oj6lk?nQ_>`01Ol00003oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV
_n`02?nV_n`2o`0000_oZ<7[00?o0000oj_2j_n[`^X00ol00006oj_2j`03o`000?n/`n[o[<?Z00Wo
[<?Z00?o0000ojk3jOn^`nT02_n^`nT00ol0003o[l?Xojo3j003o`0000Ko[/?Y00?o0000ojk2j?n^
`^P02On^`^P00ol0003o[l7Wojo1i`09ojo1i`03o`000?n_`>Ko[l3V00Co[l3V0ol000000on]_nOo
0000o`00000Mooooo`009?ooool00ol0003oooooooooo`0Yooooo`?o0000COooool00ol0003oWKW/
oifik008oifik003o`000?nN^NcoW[W/00SoW[W/00?o0000oinkk?nO^n`01_nO^n`4o`0000WoX[g/
00?o0000ojBnk?nT_^`02?nT_^`00ol0003oY[o/ojJok008ojJok0;o00002_nX`N/3o`0000[oZl;[
00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3j@09ojk3j@?o00002_n^`nT00ol0003o[/;X
ojk2j009ojk2j003o`000?n_`NOo[l7W00Wo[l7W00?o0000ojo0i_n_`>H00ol00005ojfoi`;o0000
7?ooool002Cooooo00?o0000ooooooooool09_ooool3o`00057ooooo00?o0000oifik?nM^N`02?nM
^N`00ol0003oW[W/oijik008oijik003o`000?nO^ncoWk_/00Go00000onQ_>`00ol0003oX[g/oj:m
k008oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV_n`02?nV_n`2o`0000KoZ<7[0ol0
0002ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3j_n/`nX02On/`nX00ol0003o[/?Yojk3
j@06ojk3j@;o000000?o[L?Zo`000?n^`nT02on^`nT00ol0003o[/;Xojk2j009ojk2j003o`000?n_
`NOo[l7W00So[l7W0ol00009ojfoi`;o00006oooool002?ooooo0_l0000Uooooo`?o0000EOooool0
0ol0003oWKW/oifik008oifik003o`000?nN^NcoW[W/00KoW[W/1?l00009oj6lk003o`000?nR_Nco
X[g/00SoX[g/00?o0000ojBnk?nT_^`02?nT_^`00ol0003oY[o/ojJok007ojJok003o`000?nV_nco
000000;oZ<7[0ol00006ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3j_n/`nX02On/`nX0
0ol0003o[/?Yojk3j@02ojk3j@?o00001?n]`nX00ol0003o[/?Yojk3j@0:ojk3j@03o`000?n^`^So
[/;X00Wo[/;X00?o0000ojo1ion_`NL01?n_`NL3o`000003ojc0j?l0003o[KoW00[o[KoW00?o0000
ooooooooool06Oooool002Cooooo00?o0000ooooooooool08?ooool3o`0005Wooooo00?o0000oifi
k?nM^N`02?nM^N`00ol0003oW[W/oijik005o`0000;oWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0
003oX[g/oj:mk008oj:mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojJok?nV_n`01onV_n`4o`00
00[oZL;/00?o0000oj_2jon[`^/02On[`^/00ol0003o[<?Zojc3jP09ojc3jP04o`000?n^`nWo0000
o`0000So[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/;Xojk2j00:ojk2j003o`000?n_`NOo
[l7W00?o00001On/`>P00ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Sooooo000Soooo
o`03o`000?oooooooooo01kooooo0ol0001Mooooo`03o`000?nM^NcoWKW/00KoWKW/1?l00008oinj
k003o`000?nQ_>coXKc/00WoXKc/00?o0000oj:mk?nR_N`02?nR_N`00ol0003oY;k/ojBnk008ojBn
k003o`000?nV_ncoY[o/00CoY[o/1Ol0000<ojW2k003o`000?n[`^_oZl;[00WoZl;[00?o0000ojc3
j_n/`nX02?n/`nX2o`0000_o[L?Z00?o0000ojk3jOn^`nT02On^`nT00ol0003o[/;Xojk2j008ojk2
j0Co00002On/`>P00ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Oooooo000Sooooo`03
o`000?oooooooooo01_ooooo0ol0001Qooooo`03o`000?nM^NcoWKW/00Go00000_nO^N/00ol0003o
Wk[/oinjk008oinjk003o`000?nQ_>coXKc/00WoXKc/00?o0000oj:mk?nR_N`02?nR_N`00ol0003o
Y;k/ojBnk008ojBnk003o`000?nV_ncoY[o/00?o00001?nW`N`2o`0000coZL;/00?o0000oj_2jon[
`^/02On[`^/00ol0003o[<?Zojc3jP04ojc3jP?o00000_n/`n/00ol0003o[L?Zojg3jP09ojg3jP03
o`000?n^`nWo[/?Y00Wo[/?Y00?o0000ojk2j?n^`^P01?n^`^P3o`0000;o[<7Y00?o0000ojc0j?n/
`>P02On/`>P00ol0003o[KoWojfoi`08ojfoi`;o00006?ooool002?ooooo00?o0000ooooooooool0
6?ooool3o`0006Gooooo0_l00008oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`0
2OnQ_>`00ol0003oX[g/oj:mk008oj:mk003o`000?nT_^coY;k/00KoY;k/1?l00008ojO1k0;o0000
3?nY`^`00ol0003oZl;[oj_2j`09oj_2j`03o`000?n/`n[o[<?Z00?o00001_n/`n/00ol0003o[L?Z
ojg3jP09ojg3jP03o`000?n^`nWo[/?Y00Wo[/?Y00?o0000ojk2j?n^`^P00ol00006ojc1j@03o`00
0?n/`>So[<3X00Wo[<3X00?o0000ojfoion]_nL02?n]_nL00ol0003oooooooooo`0Fooooo`008ooo
ool00ol0003oooooooooo`0Eooooo`?o0000J?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO
^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0003oX[g/oj:mk008oj:mk003o`000?nT
_^coY;k/00Go00000onU_n`00ol0003oYl7/ojO1k007ojO1k0;o00003?nY`^`00ol0003oZl;[oj_2
j`08oj_2j`?o00002_n/`n/00ol0003o[L?Zojg3jP09ojg3jP03o`000?n^`nWo[/?Y00So[/?Y0ol0
000:ojc1j@03o`000?n/`>So[<3X00So[<3X00?o0000ojfoion]_nL02On]_nL00ol0003ooooooooo
o`0Eooooo`008oooool00ol0003oooooooooo`0Booooo`?o0000K?ooool00ol0003oWkW[oinij`08
oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02OnQ_>`00ol0003oX[g/oj:mk006
oj:mk0Co00002OnU_n`00ol0003oYl7/ojO1k007ojO1k0;o00003?nY`^`00ol0003oZl;[oj_2j`04
oj_2j`?o00000_nZ`n`00ol0003o[<?[ojc3j`09ojc3j`03o`000?n]`n[o[L?Z00Wo[L?Z00?o0000
ojk3jOn^`nT01?n^`nT3o`000003ojc2j_l0003o[<7Y00_o[<7Y00?o0000ojc0j?n/`>P02?n/`>P0
0ol0003o[KoWojfoi`09ojfoi`03o`000?oooooooooo01Cooooo000Rooooo`?o00004?ooool3o`00
073ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWk[/oinjk008oinjk003o`000?nQ_>coXKc/
00WoXKc/00?o0000oj:mk?nR_N`01Ol00002ojBnk003o`000?nU_ncoYKo/00WoYKo/00?o0000ojO1
k?nW`N`01onW`N`2o`0000coZL;/00?o0000oj_2jon[`^/00ol00006oj[3k003o`000?n/`n_o[<?[
00Wo[<?[00?o0000ojg3j_n]`nX02On]`nX00ol0003o[/?Yojk3j@03o`0000Go[<;Z00?o0000ojc1
jOn/`NT02_n/`NT00ol0003o[<3Xojc0j008ojc0j003o`000?n]_nOo[KoW00Oo[KoW0ol0000Eoooo
o`008oooool00ol0003oooooooooo`0<ooooo`?o0000M?ooool00ol0003oWkW[oinij`08oinij`03
o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`02?nQ_>`3o`0000SoY;k/00?o0000ojFok?nU
_n`02OnU_n`00ol0003oYl7/ojO1k006ojO1k003o`000?nW`Nco000000[oZL;/1?l0000:oj[3k003
o`000?n/`n_o[<?[00Wo[<?[00?o0000ojg3j_n]`nX02?n]`nX3o`0000Wo[<;Z00?o0000ojc1jOn/
`NT02On/`NT00ol0003o[<3Xojc0j009ojc0j004o`000?n]_nOo[KoWojfoi`Go00000_ooool00ol0
003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`09ooooo`?o0000N?ooool00ol0003o
WkW[oinij`08oinij`03o`000?nO^^coWk[/00SoWk[/00?o0000oj6lk?nQ_>`01?nQ_>`3o`000003
oj>mk?l0003oY;k/00WoY;k/00?o0000ojFok?nU_n`02OnU_n`00ol0003oYl7/ojO1k006ojO1k003
o`000?nW`Nco000000KoZL;/0ol00002ojW2k003o`000?nZ`ncoZ/?/00[oZ/?/00?o0000ojc3jon/
`n/02On/`n/00ol0003o[L?Zojg3jP04ojg3jP?o000000?oZl?[o`000?n/`^X02_n/`^X00ol0003o
[<7Yojc1j@09ojc1j@03o`000?n/`>So[<3X00So[<3X1_l00005ooooo`03o`000?oooooooooo01?o
oooo000Sooooo`03o`000?oooooooooo00Kooooo0ol0001looooo`03o`000?nO^N_oWkW[00SoWkW[
00?o0000oinjk?nO^^`02?nO^^`00ol0003oXKc/oj6lk003o`0000GoXkg/00?o0000ojBnk?nT_^`0
2?nT_^`00ol0003oYKo/ojFok009ojFok003o`000?nW`NcoYl7/00KoYl7/00?o0000ojO1k?l00000
0_nY`^`3o`0000KoZL;/00?o0000oj[3k?nZ`n`02_nZ`n`00ol0003o[<?[ojc3j`09ojc3j`03o`00
0?n]`n[o[L?Z00?o00001On[`n/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n/`NWo[<7Y00Wo[<7Y
00?o0000ojc0j?n/`>P01?n/`>P6o`0000Sooooo00?o0000ooooooooool04oooool002;ooooo00?o
0000ooooooooool01?ooool3o`00083ooooo00?o0000oinijonO^N/02?nO^N/00ol0003oWk[/oinj
k006oinjk0Co00002OnS_N`00ol0003oY;k/ojBnk008ojBnk003o`000?nU_ncoYKo/00WoYKo/00?o
0000ojO1k?nW`N`01_nW`N`4o`0000[oZL;/00?o0000oj[3k?nZ`n`02_nZ`n`00ol0003o[<?[ojc3
j`08ojc3j`?o00002On[`n/00ol0003o[<;Zojc2jP09ojc2jP03o`000?n/`NWo[<7Y00Wo[<7Y00?o
0000ojc0j?n/`>P01Ol0000<ooooo`03o`000?oooooooooo01?ooooo000Rooooo`04o`000?oooooo
ooooooooo`?o0000Q?ooool00ol0003oWkW[oinij`08oinij`03o`000?nO^^coWk[/00Go00000onR
^n/00ol0003oXkg/oj>mk008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFok?nU_n`02OnU
_n`00ol0003oYl7/ojO1k005o`000004ojS1k?l0003oZ<7/o`0000_oZL;/00?o0000oj[3k?nZ`n`0
2_nZ`n`00ol0003o[<?[ojc3j`04ojc3j`?o000000?oZl?/o`000?n[`n/02_n[`n/00ol0003o[<;Z
ojc2jP09ojc2jP03o`000?n/`NWo[<7Y00So[<7Y1Ol0000?ooooo`03o`000?oooooooooo01?ooooo
000Rooooo`Co0000R?ooool00ol0003oWkW[oinij`06oinij`Co00002OnR^n/00ol0003oXkg/oj>m
k008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFok?nU_n`02?nU_n`3o`0000OoZ<7/00?o
0000ojS1k?l000002onY`^`00ol0003oZ/?/oj[3k00:oj[3k003o`000?n/`n_o[<?[00?o00001On[
`n`00ol0003oZl?[oj_3j`09oj_3j`03o`000?n/`^[o[<;Z00Wo[<;Z00?o0000ojc1jOn/`NT01?n/
`NT5o`0001;ooooo00?o0000ooooooooool04oooool002;ooooo0ol0002:ooooo`03o`000?nO^N_o
WkW[00Go00000onQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_NcoXkg/00SoXkg/00?o0000
ojBnk?nT_^`02?nT_^`00ol0003oYKo/ojFok004ojFok0?o000000?oY/3/o`000?nX`N`02?nX`N`0
0ol0003oZ<7/o`00000;ojW2k003o`000?nZ`ncoZ/?/00SoZ/?/1?l00009oj_3k003o`000?n[`n_o
Zl?[00SoZl?[00?o0000ojc2j_n/`^X02_n/`^X00ol0003o[<7Yojc1j@04o`0001Oooooo00?o0000
ooooooooool04_ooool002Cooooo00?o0000ooooooooool0ROooool2o`0000WoXK[Z00?o0000oj:k
jonR^n/02?nR^n/00ol0003oXkg/oj>mk008oj>mk003o`000?nT_^coY;k/00SoY;k/00?o0000ojFo
k?nU_n`00ol00005ojK0k003o`000?nX`NcoZ<7/00KoZ<7/00Co0000ojS1k?nX`Nco00002onY`^`0
0ol0003oZ/?/oj[3k004oj[3k0?o00000_nZ`n`00ol0003oZl?/oj_3k009oj_3k003o`000?n[`n_o
Zl?[00SoZl?[00?o0000ojc2j_n/`^X02?n/`^X5o`0001[ooooo00?o0000ooooooooool04_ooool0
01Kooooo00?ok^k^o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo
08Wooooo00?o0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_NcoXkg/
00SoXkg/00?o0000ojBnk?nT_^`01_nT_^`4o`0000WoY/3/00?o0000ojS1k?nX`N`01_nX`N`01?l0
003oZ<7/ojS1k?l0000;ojW2k003o`000?nZ`ncoZ/?/00?o00001_nZ`n`00ol0003oZl?/oj_3k009
oj_3k003o`000?n[`n_oZl?[00SoZl?[00?o0000ojc2j_n/`^X01?n/`^X5o`0001gooooo00?o0000
ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0;ooooo`03o`000?oooooo
oooo08Wooooo00?o0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_Nco
Xkg/00SoXkg/00?o0000ojBnk?nT_^`01Ol00004ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000
ojS1k?nX`N`01_nX`N`01?l0003oZ<7/ojS1k?l0000:ojW2k0?o00002_nZ`n`00ol0003oZl?/oj_3
k008oj_3k003o`000?n[`n_oZl?[00WoZl?[00?o0000ojc2j_n/`^X01?l0000Qooooo`03o`000?oo
oooooooo01;ooooo000Fooooo`05oa0@4?ooooooooooo`000?l@41003?ooool00ol0003ooooooooo
o`29ooooo`03o`000?nQ^^[oXK[Z00SoXK[Z00?o0000oj:kjonR^n/02?nR^n/00ol0003oXkg/oj>m
k007oj>mk0?o00002_nU_n`00ol0003oY/3/ojK0k007ojK0k003o`000?nX`NcoZ<7/00KoZ<7/00Co
0000ojS1k?nX`Nco00001_nY`^`3o`0000;oZL?/00?o0000oj[3k?nZ`n`02OnZ`n`00ol0003oZl?/
oj_3k008oj_3k003o`000?n[`n_oZl?[00SoZl?[1?l0000Tooooo`03o`000?oooooooooo01;ooooo
000Fooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`29ooooo`03o`000?nQ
^^[oXK[Z00SoXK[Z00?o0000oj:kjonR^n/02?nR^n/00ol0003oXkg/oj>mk003oj>mk0?o00000_nU
_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000ojS1k?nX`N`01_nX
`N`01?l0003oZ<7/ojS1k?l00002ojW2k0?o00001_nY`n`00ol0003oZ/?/oj[3k009oj[3k003o`00
0?n[`ncoZl?/00SoZl?/00?o0000oj_3jon[`n/01?n[`n/4o`0002Oooooo00?o0000ooooooooool0
4_ooool001Kooooo00?o0000ooooooooool00_l0000>ooooo`03o`000?oooooooooo08Wooooo00?o
0000oj6jj_nQ^^X02?nQ^^X00ol0003oX[_[oj:kj`08oj:kj`03o`000?nS_Nco000000;o00001_nU
_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00OoY/3/00?o0000ojS1k?nX`N`01_nX
`N`00ol0003oZ<7/o`000002o`0000[oZL?/00?o0000oj[3k?nZ`n`02OnZ`n`00ol0003oZl?/oj_3
k008oj_3k003o`000?n[`n_oZl?[00Co0000:_ooool00ol0003oooooooooo`0Booooo`005_ooool0
1Ol@413oooooooooool0003o410@00oooooo00?o0000ooooooooool0ROooool00ol0003oXK[Zoj6j
jP08oj6jjP03o`000?nR^n_oX[_[00KoX[_[0ol0000:ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o
0000ojK0k?nV`>`01onV`>`00ol0003oZ<7/ojS1k004ojS1k0?o00000_nY`^`00ol0003oZL?/ojW3
k009ojW3k003o`000?nZ`ncoZ/?/00WoZ/?/00?o0000oj_3k?n[`n`01_n[`n`4o`0002kooooo00?o
0000ooooooooool04_ooool001Kooooo00GoMgMgoiRHV?oooooo0000ogMgM`0@ooooo`;o0000R_oo
ool00ol0003oXK[Zoj6jjP08oj6jjP03o`000?nR^n_oX[_[00Go00000onT_>X00ol0003oYKg[ojFm
j`08ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o0000ojK0k?nV`>`01onV`>`00ol0003oZ<7/ojS1
k003o`0000?oZL;/00Co0000ojW2k?nY`^co00002onY`n`00ol0003oZ/?/oj[3k009oj[3k003o`00
0?n[`ncoZl?/00Ko0000<Oooool00ol0003oooooooooo`0Booooo`005_ooool01Oo^k^ko0`<3o`00
0?l0003ok^k^01;ooooo00?o0000ooooooooool0R?ooool00ol0003oXK[Zoj6jjP06oj6jjPCo0000
2OnT_>X00ol0003oYKg[ojFmj`08ojFmj`03o`000?nU_ncoYKo/00WoYKo/00?o0000ojK0k?nV`>`0
1OnV`>`4o`0000KoZL;/00Go0000ojW2k?nY`^coZL;/o`00000;ojW3k003o`000?nZ`ncoZ/?/00So
Z/?/1_l0000dooooo`03o`000?oooooooooo01;ooooo000/ooooo`03o`000?oooooo000008[ooooo
00?o0000oj6jj_nQ^^X01Ol00002ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/0
2?nU_N/00ol0003oYKo/ojFok009ojFok003o`000?nV`>coY/3/00Co00000onX`N`00ol0003oZL;/
ojW2k005ojW2k005o`000?nY`^coZL;/ojW2k?l000002onY`n`00ol0003oZ/?/oj[3k004oj[3k0Go
0000>?ooool00ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`28ooooo`;o0000
2?nT^nT00ol0003oY;cZojBljP09ojBljP03o`000?nU_N_oYKg[00SoYKg[00?o0000ojFok?nU_n`0
2?nU_n`3o`0000SoZ<7/00?o0000ojW2k?nY`^`01OnY`^`01Ol0003oZL;/ojW2k?nY`^co000000_o
ZL?/00?o0000oj[3k?nZ`n`01Ol0000looooo`03o`000?oooooooooo017ooooo000`ooooo`03o`00
0?oooooooooo08Oooooo0_l00009ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/0
2?nU_N/00ol0003oYKo/ojFok004ojFok0?o000000?oZ<3[o`000?nX`N`02OnX`N`00ol0003oZL;/
ojW2k005ojW2k005o`000?nY`^coZL;/ojW2k?l000002_nY`n`5o`0003oooooo00?o0000oooooooo
ool04Oooool0037ooooo00?o0000ooooooooool0Qoooool2o`0000WoY;_Y00?o0000ojBlj_nT_>X0
2OnT_>X00ol0003oYKg[ojFmj`08ojFmj`03o`000?nU_ncoYKo/00?o00001OnX`>/00ol0003oZ<7/
ojS1k008ojS1k003o`000?nY`^coZL;/00GoZL;/00Go0000ojW2k?nY`^coZL;/o`000006ojW3k0Co
0000@oooool00ol0003oooooooooo`0Aooooo`00<_ooool00ol0003oooooooooo`27ooooo`;o0000
2OnT^nT00ol0003oY;cZojBljP09ojBljP03o`000?nU_N_oYKg[00KoYKg[1?l00009ojS0j`03o`00
0?nX`NcoZ<7/00SoZ<7/00?o0000ojW2k?nY`^`01OnY`^`01Ol0003oZL;/ojW2k?nY`^co000000;o
ZL?/1?l00016ooooo`03o`000?oooooooooo017ooooo000cooooo`03o`000?oooooooooo08Oooooo
0_l00009ojBkj@03o`000?nT_>[oY;cZ00WoY;cZ00?o0000ojFmjonU_N/01Ol00003ojNnjP03o`00
0?nX`>_oZ<3[00SoZ<3[00?o0000ojS1k?nX`N`02?nX`N`00ol0003oZL;/ojW2k005ojW2k003o`00
0?nY`^coZL;/00Co0000BOooool00ol0003oooooooooo`0Aooooo`00=?ooool2o`0008Sooooo0_l0
0009ojBkj@03o`000?nT_>[oY;cZ00SoY;cZ0ol00009ojNnjP03o`000?nX`>_oZ<3[00SoZ<3[00?o
0000ojS1k?nX`N`02?nX`N`00ol0003oZL;/ojW2k004ojW2k0?o0000COooool00ol0003ooooooooo
o`0Aooooo`00=_ooool00ol0003oooooooooo`26ooooo`;o00002OnT^nT00ol0003oY;cZojBljP04
ojBljP?o000000?oYkgYo`000?nW_^X02_nW_^X00ol0003oZ<3[ojS0j`08ojS0j`03o`000?nX`Nco
Z<7/00SoZ<7/00?o0000ojW2k?nY`^`00ol000000ooooooo0000ooooo`1=ooooo`03o`000?oooooo
oooo017ooooo000gooooo`;o0000Qoooool2o`0000WoY;_Y00?o0000ojBlj_nT_>X00ol00005ojNm
j@03o`000?nW_^[oYkkZ00WoYkkZ00?o0000ojS0jonX`>/02?nX`>/00ol0003oZ<7/ojS1k006ojS1
k0Co00001Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo000fooooo`03
o`000?oooooo000008Sooooo0_l00007ojBkj@Co00002OnW_NT00ol0003oYkkZojNnjP09ojNnjP03
o`000?nX`>_oZ<3[00SoZ<3[00?o0000ojS1k?nX`N`01Ol0000:ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool04Oooool003Wooooo00?o0000ooooooooool0Q_ooool2o`0000;oY;_Y
1?l00003ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o0000ojNnj_nW_^X02OnW_^X00ol0003oZ<3[
ojS0j`07ojS0j`Go00003_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo017ooooo
000jooooo`03o`000?oooooooooo08Kooooo0ol00008ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o
0000ojNnj_nW_^X02OnW_^X00ol0003oZ<3[ojS0j`03ojS0j`Go00004_ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo017ooooo000kooooo`03o`000?oooooooooo08Kooooo00?o0000
ojNlj?nW_>P02?nW_>P00ol0003oYkgYojNmj@08ojNmj@03o`000?nW_^[oYkkZ00WoYkkZ00?o0000
ojS0jol000000ol0000Gooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool04?ooool0
03cooooo00?o0000ooooooooool0Q_ooool00ol0003oYkcXojNlj008ojNlj003o`000?nW_NWoYkgY
00SoYkgY00?o0000ojNnj_nW_^X02?nW_^X3o`0001_ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0@ooooo`00?Oooool2o`0008Oooooo00?o0000ojNlj?nW_>P02?nW_>P00ol0003o
YkgYojNmj@08ojNmj@03o`000?nW_^[oYkkZ00CoYkkZ0ol0000Oooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool04?ooool003oooooo00?o0000ooooooooool0QOooool00ol0003oYkcX
ojNlj008ojNlj003o`000?nW_NWoYkgY00SoYkgY00?o0000ojNnj_nW_^X00ol0000Rooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool04?ooool0043ooooo00?o0000ooooooooool0QOoo
ool00ol0003oYkcXojNlj008ojNlj003o`000?nW_NWoYkgY00KoYkgY1?l0000Vooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool04?ooool0047ooooo0_l00026ooooo`03o`000?nW_>So
YkcX00SoYkcX00?o0000ojNmjOnW_NT01Ol0000[ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool0043ooooo00?o0000ooooool00000Qoooool00ol0003oYkcXojNlj007ojNl
j0Go0000;oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo013ooooo0013ooooo`03
o`000?oooooooooo08Gooooo00?o0000ojNlj?nW_>P00onW_>P4o`0003Cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0@ooooo`00A?ooool00ol0003oooooooooo`25ooooo`03o`00
0?nW_>So000000?o0000>?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo013ooooo
0015ooooo`03o`000?oooooooooo08Gooooo0_l0000looooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool04?ooool004Kooooo0_l00025ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0@ooooo`00B?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?oooo
o`00BOooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0?ooooo`00B_oo
ool2o`00087ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00oooooo001<ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo001=ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00oooooo001>ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00oooooo001?ooooo`;o0000O?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03oooool0057ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool03oooool005;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03oooool005?ooooo00?o0000oooo
ooooool0Moooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool03oooool005Cooooo0ol0001fooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0?ooooo`00E?ooool2o`0007Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool02?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0>ooooo`00>?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool02?ooool2o`0007?ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000hooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00ko
oooo000hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03_ooool003Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool03_ooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03_ooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004?ooool2o`0006kooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00kooooo001Oooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00kooooo001Pooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo001Qooooo`;o0000J_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool03Ooo
ool006?ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool03Oooool006Cooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool006Go
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03Oooool006Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool006Kooooo0ol0
001Tooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`00J?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`00JOooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=oooo
o`00J_ooool2o`00067ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00gooooo001/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo001]ooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00gooooo001^ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo001_ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00cooooo001_ooooo`?o0000Foooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool03?ooool0077ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool007;ooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool03?ooool007?ooooo0_l0001Hooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`00MOooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<oooo
o`00M_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0<ooooo`00Moooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`00N?oo
ool2o`0005?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00cooooo001hooooo`;o0000Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03?ooool007[ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool007_o
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool02oooool007cooooo0_l0001?ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`00O_ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0;ooooo`00Ooooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`00P?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;oooo
o`00POooool3o`0004Wooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00_ooooo001fooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0;ooooo`00N?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo001h
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool007Sooooo00?o0000oooo
ooooool02_ooool2o`0004Kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00_ooooo001Looooo`?o000000?o410@ooooooooool05_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo001Nooooo`03oa0@4?nj^[[ooooo01Oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`00G_ooool00onHV9So<S8boooo
o`0Gooooo`03o`000?oooooooooo00kooooo0_l00012ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00G_ooool00ooMgMgo0000okZj^P0E
ooooo`03oeEEEOmVIVKo0000013ooooo0_l00012ooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`00G_ooool00omEEEGoMgMgodA4A00Zoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00[ooooo001Mooooo`05omgMgOl@413oooooob4Q8OoMgMd0:_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`00GOooool01OmVIVKoQhN7oooooonHV9SoEEEE02_ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02_ooool005cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Zooooo`;o
0000?Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02_ooool005cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0[ooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo002Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo002Aooooo`;o0000>_oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool009?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool009Cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool009Go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool009Kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool009Oooooo0_l0
000dooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`00VOooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`09ooooo`00VOooool3o`00037ooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo002Kooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Wooooo002Looooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo002Mooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo002Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo002Oooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo002Pooooo`;o0000:oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00:7ooooo0_l0000Zooooo`03o`000?oooooooooo08;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`00Xoooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo08?ooooo00Co0000oooooooooooo00002_ooool00:Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooo000000[ooooo002Uooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0QOooool2o`0000[ooooo002Vooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Q?ooool3o`0000[ooooo002Wooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0P?ooool4o`0000gooooo002Xooooo`04o`000?oooooo0000o`00
027ooooo00?o0000ooooooooool0O?ooool4o`00017ooooo002>ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`;o00008_ooool00ol0
003oooooooooo`1hooooo`Co00005Oooool0093ooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Co
oooo1?l0000Iooooo`00T?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1`ooooo`Co00007Oooool0093ooooo00?o
0000ooooooooool03_ooool00omgMgOo<S8booooo`09ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0KOooool3o`00027ooooo002@ooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0JOoo
ool4o`0002Cooooo002@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Gooooo1?l0000Xooooo`00T?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo0ol0000Jooooo`03o`000?oooooooooo
067ooooo1?l0000/ooooo`00S_ooool00omEEEGoIVIVo`00000=ooooo`Co00003_ooool2o`0001_o
oooo00?o0000ooooooooool0GOooool4o`00033ooooo002booooo`;o00006Oooool00ol0003ooooo
ooooo`1Iooooo`Co0000=?ooool00;Cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1Eooooo`Co0000>?ooool00;Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1A
ooooo`Co0000??ooool00;Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=oooo
o`Co0000@?ooool00;Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`Co
0000A?ooool00;Sooooo0_l0000Cooooo`03o`000?oooooooooo04Gooooo1?l00018ooooo`00^Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo047ooooo1?l0001<ooooo`00^_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo0ol0001@ooooo`00^oooool2o`00
013ooooo00?o0000ooooooooool0>_ooool4o`0005?ooooo002mooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0=_ooool4o`0005Oooooo002nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<_ooool4o`0005_ooooo002oooooo`;o00003?ooool00ol0003ooooooooo
o`0^ooooo`Co0000Goooool00;oooooo0_l0000<ooooo`03o`000?oooooooooo02[ooooo1?l0001S
ooooo`00`Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Kooooo1?l0001Woooo
o`00`_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo1?l0001[ooooo`00
`oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo1?l0001_ooooo`00a?oo
ool2o`0000Oooooo00?o0000ooooooooool06_ooool4o`0007?ooooo0036ooooo`?o00001?ooool0
0ol0003oooooooooo`0Fooooo`Co0000Moooool00<Kooooo0_l00005ooooo`03o`000?oooooooooo
01?ooooo0ol0001kooooo`00b?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oo
oooo1?l0001nooooo`00bOooool01Ol0003ooooooooooooooooo000000gooooo1?l00022ooooo`00
b_ooool01?l0003oooooooooool00009ooooo`Co0000Q_ooool00<_ooooo00?o0000ooooool00000
1Oooool4o`0008[ooooo003<ooooo`Oo0000S_ooool00<;ooooo1Ol00006ooooo`;o0000T_ooool0
0<;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A02Jooooo`00`oooool00onHV9So8B4Qonk^kP2Koooo
o`00a?ooool00onHV9So8B4Qonk^kP2Jooooo`00aOooool00omgMgOoIVIVooooo`2Iooooo`00a_oo
ool00ol0003oooooooooo`2Hooooo`00`_ooool01Ol0003o^[ZjoooooonHV9So410@09[ooooo0032
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0V_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?ooooooH_ooool00?oo
ooooH_ooool00:Wooooo0ol000000ol@413oooooooooo`2booooo`00U_ooool2o`0000_ooooo00?o
0000okZj^_ooool01Oooool00ol@413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo0_l0
0006ooooo`03o`000?nj^[[ooooo09Gooooo002Fooooo`03o`000?oooooooooo00[ooooo0_lb<S86
ooooo`03oiRHV?lb<S;ooooo00Cooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:F
ooooo`00S?ooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00?ogMgMo`000?nj^[X01?ooool0
0on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003ooooooooo
o`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8GOooooo002>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@
41001Oooool00omEEEGoMgMgodA4A004ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^
k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B5g
ooooo`00S_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`00
0?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0OOoo
ool008kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o
410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0003ooooo
ooooo`1mooooo`00S_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co
8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0OOooool008_ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`000?l000000ol00004ooooo`03
o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo07go
oooo002;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07gooooo002;ooooo`Oo00001?ooool2o`0002;ooooo
00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIV
o`00001oooooo`00oooooomRooooo`00oooooomRooooo`00oooooomRooooo`00\
\>"],
  ImageRangeCache->{{{0, 352.438}, {392.188, 0}} -> {-0.0365789, -0.0401404, \
0.00334761, 0.00334761}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.85",
    ButtonData:>"Cell 6.85",
    ButtonStyle->"Hyperlink"],
  ", we compare the Crank-Nicolson solution with the exact solution, Eq. ",
  ButtonBox["(6.2.32)",
    ButtonData:>"(6.2.32)",
    ButtonStyle->"Hyperlink"],
  ", along a cut at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(CrankNicolson = 
        Table[Plot[Tsol[1/2, y, t], {y, 0, L\_y}, PlotRange \[Rule] {0, 1}, 
            AxesLabel \[Rule] {"\<y\>", "\<\>"}, 
            DisplayFunction \[Rule] Identity, 
            PlotLabel \[Rule] \*"\"\<T[\!\(1\/2\),y,t],t=\>\"" <> 
                ToString[t]], {t, 0, 1,  .1}];\)\), "\n", 
    \(\(exact\  = 
        Table[Plot[
            Evaluate[\(\[ExponentialE]\^\(\(-\[Pi]\^\(\(2\)\(\ \)\)\) \[Chi]\ \
t\ \((1\ /L\_x\^2 + 1\ /L\_y\^2)\)\)\) Sin[Pi\ 5\ \[CapitalDelta]x/L\_x] 
                Sin[Pi\ y/L\_y]], {y, 0, L\_y}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {RGBColor[1, 0, 0], 
                Dashing[{0.05, 0.05}]}], {t, 0, 
            1,  .1}];\)\ \[IndentingNewLine]\), "\n", 
    \(\(Table[
        Show[CrankNicolson[\([n]\)], exact[\([n]\)], 
          DisplayFunction \[Rule] $DisplayFunction], {n, 1, 
          Length[exact]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.85"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -41.0938 0 ]
[.5 .63053 41.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
141.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .07865 L
.10458 .16276 L
.14415 .2389 L
.18221 .30837 L
.22272 .37701 L
.26171 .43664 L
.30316 .49224 L
.34309 .53696 L
.3815 .57132 L
.40095 .58532 L
.42237 .5978 L
.44268 .60689 L
.45178 .61009 L
.46172 .61298 L
.4671 .61427 L
.4721 .61531 L
.47727 .6162 L
.48196 .61686 L
.48658 .61737 L
.49093 .61771 L
.49332 .61785 L
.49552 .61794 L
.49667 .61798 L
.49794 .61801 L
.49926 .61803 L
.50049 .61803 L
.50175 .61801 L
.50239 .618 L
.50309 .61799 L
.50433 .61795 L
.50549 .6179 L
.50811 .61777 L
.51094 .61758 L
.5161 .61709 L
.52084 .61648 L
.52988 .61492 L
.5394 .61269 L
.55914 .60618 L
.57751 .59787 L
.61655 .57283 L
.65805 .53582 L
.69803 .49077 L
.7365 .43922 L
.77742 .37679 L
.81682 .31009 L
.85471 .24105 L
.89505 .16349 L
.93387 .0861 L
.97515 .00214 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .07855 L
.10458 .16272 L
.14415 .23895 L
.18221 .30843 L
.22272 .37703 L
.26171 .43673 L
.30316 .49226 L
.34309 .53707 L
.3815 .57141 L
.40095 .58533 L
.42237 .59788 L
.44268 .60702 L
.45178 .61023 L
.46172 .61311 L
.4671 .6144 L
.4721 .61542 L
.47727 .6163 L
.48196 .61694 L
.48658 .61743 L
.4887 .6176 L
.49093 .61776 L
.49332 .61788 L
.49438 .61793 L
.49552 .61797 L
.49675 .618 L
.49789 .61802 L
.49859 .61803 L
.49925 .61803 L
.50049 .61803 L
.50163 .61803 L
.50286 .61801 L
.50401 .61798 L
.50508 .61795 L
.50754 .61784 L
.51014 .61769 L
.51268 .61749 L
.51504 .61727 L
.5204 .61664 L
.5293 .61515 L
.53882 .61297 L
.54906 .60996 L
.56016 .6059 L
.58032 .59647 L
.62123 .56927 L
.66064 .53328 L
.69852 .49018 L
.73886 .43591 L
.77769 .37638 L
.81897 .30636 L
Mistroke
.85873 .23353 L
.89697 .15967 L
.93767 .07832 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Toooooooo00006?l0
00000ooo003o0000o`000005o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool03_oo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`;o0000@oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@?ooool0
0ooo003o0000ooooo`0?ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool04ooo
ool002[ooooo0_l0003oooooo`oooooo00?oo`00ooooooooool0:oooool002[ooooo00?o0000oooo
ool00000ooooool=ooooo`03ool00?l0003ooooo02cooooo000Zooooo`03o`000?oooooo00000?oo
oooo3Oooool00ol0003oooooooooo`0/ooooo`00:_ooool01?l0003oooooooooool0003oooooo`co
oooo00?o0000ooooooooool0;?ooool002[ooooo00Go0000oooooooooooo0000ool0003oooooo`[o
oooo00?o0000ooooooooool0;Oooool002[ooooo00Go0000ooooooooooooooooool0003oooooo`[o
oooo00?o0000ooooooooool0;Oooool002[ooooo0_l00002ooooo`03o`000?oo003ooooo0?oooooo
1oooool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo0?oooooo1_ooool00ol0003oooooooooo`0^ooooo`00:_ooool00ol0003oooooooooo`02
ooooo`03o`000?oo003ooooo0?oooooo1Oooool00ol0003oooooooooo`0_ooooo`00:_ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0_oooo
o`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo0?oooooo0oooool00ol0003o
ooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo0?oooooo
0_ooool00ol0003oooooooooo`0`ooooo`00:_ooool00ol0003oooooooooo`04ooooo`03ool00?oo
oooooooo0?oooooo0Oooool00ol0003oooooooooo`0aooooo`00:_ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo0?oooooo00?o0000ooooooooool0<Oooool002[ooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`3nooooo`03ool00?oooooooooo03;ooooo000Zooooo`;o
00001oooool00ooo003oooooooooo`3mooooo`03ool00?oooooooooo03;ooooo000Zooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0o?ooool00ooo003oooooooooo`0cooooo`00:_oo
ool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo0?[ooooo00?oo`00o`000?ooool0=?oo
ool002[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3jooooo`03ool00?oooooo
oooo03Cooooo000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0n?ooool00ooo
003o0000ooooo`0eooooo`00:_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?So
oooo00?oo`00ooooooooool0=Oooool002[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3fooooo`03ool00?l0003ooooo03Kooooo000Zooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0m_ooool00ooo003oooooooooo`0fooooo`00:_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0?Cooooo00?oo`00o`000?ooool0=oooool002[ooooo0_l0000;oooo
o`03o`000?oooooooooo0?Cooooo00?oo`00ooooooooool0=oooool002[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3booooo`03ool00?l0003ooooo03Sooooo000Zooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0l_ooool00ooo003oooooooooo`0hooooo`00:_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?3ooooo00?oo`00o`000?ooool0>Ooo
ool002[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooo
oooo03Wooooo000Zooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0koooool00ol0
003oooooooooo`0iooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo0>kooooo00?o0000oooo
ooooool0>_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`3]
ooooo`03o`000?oooooooooo03[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP06ooooo`?o00003_ooool00ol0003oo`00ooooo`3/ooooo`03o`000?oooooo
oooo03_ooooo000@ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05
ooooo`03o`000?oooooooooo00kooooo00?o0000ool00?ooool0k?ooool00ol0003oooooooooo`0k
ooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo0>[ooooo00?o0000ooooooooool0??ooool0
013ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03oooool00ol0003oo`00ooooo`3Zooooo`03o`000?oooooooooo03cooooo000@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o
0000ooooooooool04?ooool00ol0003oo`00ooooo`3Xooooo`03o`000?oooooooooo03gooooo000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`3Xooooo`03o`000?oooooooooo03gooooo
000Zooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0i_ooool00ol0003ooooooooo
o`0nooooo`00:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo0>Kooooo00?o0000
ooooooooool0?_ooool002[ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`3Toooo
o`03ool00?oooooooooo03oooooo000Zooooo`;o00004oooool00ol0003oo`00ooooo`3Tooooo`03
ool00?oooooooooo03oooooo000Zooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0
h_ooool00ooo003oooooooooo`10ooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
003ooooo0>;ooooo00?oo`00ooooooooool0@?ooool002[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`3Pooooo`03o`000?oo003ooooo047ooooo000Zooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0h?ooool00ooo003oooooooooo`11ooooo`00:_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo0=kooooo00?oo`00ooooooooool0@_ooool002[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Nooooo`03ool00?oooooooooo04;ooooo
000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0g?ooool00ooo003ooooooooo
o`13ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0=[ooooo00?oo`00
o`000?ooool0A?ooool002[ooooo0_l0000Hooooo`03o`000?oooooooooo0=[ooooo00?oo`00oooo
ooooool0A?ooool002[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3Hooooo`03
ool00?oooooooooo04Gooooo000Zooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
eoooool00ooo003o0000ooooo`16ooooo`00:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo0=Kooooo00?o0000ooooooooool0A_ooool002[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`3Fooooo`03o`000?oooooooooo04Kooooo000Zooooo`03o`000?oooooooooo
01[ooooo00?o0000ool00?ooool0e?ooool00ol0003oooooooooo`17ooooo`00:_ooool00ol0003o
ooooooooo`0Kooooo`03ool00?oooooooooo0=?ooooo00?o0000ooooooooool0Aoooool002[ooooo
00?o0000ooooooooool06oooool00ol0003oo`00ooooo`3Booooo`03o`000?oooooooooo04Sooooo
000Zooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0dOooool00ol0003ooooooooo
o`18ooooo`00:_ooool2o`0001gooooo00?o0000ool00?ooool0d?ooool00ol0003oooooooooo`19
ooooo`00:_ooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo0<oooooo00?o0000oooo
ooooool0BOooool002[ooooo00?o0000ooooooooool07Oooool00ol0003oo`00ooooo`3>ooooo`03
o`000?oooooooooo04[ooooo000Zooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0
c?ooool00ol0003oooooooooo`1;ooooo`00:_ooool00ol0003oooooooooo`0Oooooo`03ool00?oo
oooooooo0<_ooooo00?o0000ooooooooool0Boooool002[ooooo00?o0000ooooooooool07oooool0
0ooo003oooooooooo`3:ooooo`03o`000?oooooooooo04cooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooo
oooo023ooooo00?oo`00ooooooooool0bOooool00ooo003oooooooooo`1<ooooo`004?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08?ooool00ooo003oooooooooo`38ooooo`03o`000?oo003ooooo04gooooo000@oooo
o`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`37ooooo`03ool00?oooooooooo04gooooo000@ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`?o00008Oooool00ooo003ooooooooo
o`36ooooo`03o`000?oo003ooooo04kooooo000@ooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
aOooool00ooo003oooooooooo`1>ooooo`004?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0<Cooooo
00?o0000ool00?ooool0Coooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^
k_m4A4Co000000Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`33ooooo`03ool0
0?oooooooooo04oooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0`Oooool00ooo003ooooo
ooooo`1@ooooo`00:_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0<7ooooo00?o
o`00ooooooooool0D?ooool002[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2o
ooooo`03ool00?oooooooooo057ooooo000Zooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0_oooool00ooo003oooooooooo`1Aooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo0;gooooo00?oo`00ooooooooool0D_ooool002[ooooo0_l0000Wooooo`03o`00
0?oooooooooo0;gooooo00?oo`00ooooooooool0D_ooool002[ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`2kooooo`03ool00?oooooooooo05?ooooo000Zooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`1Cooooo`00:_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0E?ooool002[o
oooo00?o0000ooooooooool0:?ooool00ooo003o0000ooooo`2iooooo`03o`000?oooooooooo05Co
oooo000Zooooo`03o`000?oooooooooo02Sooooo00?oo`00o`000?ooool0^?ooool00ol0003ooooo
ooooo`1Eooooo`00:_ooool00ol0003oooooooooo`0Yooooo`03ool00?l0003ooooo0;Oooooo00?o
0000ooooooooool0EOooool002[ooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`2e
ooooo`03o`000?oooooooooo05Kooooo000Zooooo`03o`000?oooooooooo02_ooooo00?oo`00oooo
ooooool0/oooool00ooo003o0000ooooo`1Gooooo`00:_ooool2o`0002cooooo00?oo`00oooooooo
ool0/oooool00ooo003oooooooooo`1Gooooo`00:_ooool00ol0003oooooooooo`0/ooooo`03ool0
0?oooooooooo0;7ooooo00?oo`00o`000?ooool0F?ooool002[ooooo00?o0000ooooooooool0;?oo
ool00ooo003oooooooooo`2aooooo`03ool00?oooooooooo05Sooooo000Zooooo`03o`000?oooooo
oooo02gooooo00?oo`00ooooooooool0[oooool00ooo003oooooooooo`1Iooooo`00:_ooool00ol0
003oooooooooo`0]ooooo`03ool00?oooooooooo0:oooooo00?oo`00ooooooooool0FOooool002[o
oooo00?o0000ooooooooool0;_ooool00ooo003oooooooooo`2]ooooo`03ool00?oooooooooo05[o
oooo000Zooooo`03o`000?oooooooooo02kooooo00?oo`00o`000?ooool0[?ooool00ooo003o0000
ooooo`1Kooooo`00:_ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooooooo0:_ooooo00?o
o`00ooooooooool0Foooool002[ooooo0_l0000aooooo`03o`000?oooooooooo0:Wooooo00?oo`00
ooooooooool0G?ooool002[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Yoooo
o`03ool00?oooooooooo05cooooo000Zooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0Yoooool00ooo003oooooooooo`1Mooooo`00:_ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooooooool0G_ooool002[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo05kooooo000Zooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Oooooo`00:_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0H?ooool0013o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooo
oooo063ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`1Qooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000005ooooo`?o0000=Oooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo067ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo06;ooooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0=_ooool00ol0003oo`00ooooo`2Loooo
o`03o`000?oooooooooo06?ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`07ooooo`03o`000?oooooooooo03Kooooo00?o0000ool00?ooool0W?ooool00ol0
003oooooooooo`1Sooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P01oooool00ol0003oooooooooo`0gooooo`03o`000?oo003ooooo09[ooooo00?o0000oooo
ooooool0I?ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Gooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`2Hooooo`03ool00?oooooo
oooo06Gooooo000Zooooo`03o`000?oooooooooo03Sooooo00?o0000ool00?ooool0V?ooool00ooo
003oooooooooo`1Uooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?oo003ooooo09Ko
oooo00?oo`00ooooooooool0I_ooool002[ooooo00?o0000ooooooooool0>_ooool00ooo003ooooo
ooooo`2Dooooo`03ool00?l0003ooooo06Oooooo000Zooooo`;o0000??ooool00ooo003ooooooooo
o`2Cooooo`03ool00?oooooooooo06Oooooo000Zooooo`03o`000?oooooooooo03_ooooo00?oo`00
ooooooooool0T_ooool00ooo003oooooooooo`1Xooooo`00:_ooool00ol0003oooooooooo`0loooo
o`03ool00?oooooooooo093ooooo00?oo`00o`000?ooool0JOooool002[ooooo00?o0000oooooooo
ool0?Oooool00ooo003oooooooooo`2?ooooo`03ool00?oooooooooo06Wooooo000Zooooo`03o`00
0?oooooooooo03gooooo00?oo`00ooooooooool0S_ooool00ooo003o0000ooooo`1Zooooo`00:_oo
ool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo08cooooo00?oo`00o`000?ooool0Jooo
ool002[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2;ooooo`03ool00?oooooo
oooo06_ooooo000Zooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0ROooool00ooo
003o0000ooooo`1/ooooo`00:_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo08So
oooo00?oo`00o`000?ooool0KOooool002[ooooo0_l00012ooooo`03o`000?oooooooooo08Sooooo
00?o0000ooooooooool0K?ooool002[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo06gooooo000Zooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`1^ooooo`00:_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0K_ooool002[ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo06oooooo000Zooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1`ooooo`00:_oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0LOoo
ool002[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo077ooooo000Zooooo`03o`000?oooooooooo04Kooooo00?o0000ool00?ooool0OOooool00ol0
003oooooooooo`1booooo`00:_ooool2o`0004Sooooo00?oo`00ooooooooool0Noooool00ol0003o
ooooooooo`1cooooo`00:_ooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo07Wooooo
00?o0000ooooooooool0M?ooool002[ooooo00?o0000ooooooooool0BOooool00ooo003ooooooooo
o`1gooooo`03ool00?l0003ooooo07Gooooo000Zooooo`03o`000?oooooooooo04Wooooo00?oo`00
ooooooooool0Moooool00ooo003oooooooooo`1eooooo`00:_ooool00ol0003oooooooooo`1:oooo
o`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0M_ooool002[ooooo00?o0000oooooooo
ool0Boooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo07Oooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005oooo
o`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`1hoooo
o`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo073ooooo00?oo`00
o`000?ooool0NOooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo06oooooo00?o
o`00ooooooooool0NOooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801Oooool3o`0004gooooo00?o0000ool00?ooool0K_ooool00ooo003ooooo
ooooo`1jooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c005ooooo`03o`000?oooooooooo04kooooo00?o0000ool00?ooool0K?ooool00ooo003o
ooooooooo`1kooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4005ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0J_ooool00ooo
003oooooooooo`1looooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0J?ooool0
0ooo003oooooooooo`1mooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0I_oo
ool00ooo003oooooooooo`1nooooo`00:_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0Ooooool002[ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo083ooooo000Zooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`21ooooo`00:_ooool2o`0005Kooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`22ooooo`00:_ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Poooool002[ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Cooooo000Zoooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Eoooool2o`0008Oooooo000Zooooo`03
o`000?oooooooooo05Wooooo0_oo001Fooooo`03o`000?oooooooooo08Oooooo000Zooooo`03o`00
0?oooooooooo05_ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`28ooooo`00:_oo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo053ooooo00?o0000ool00?ooool0ROoo
ool002[ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`1>ooooo`03o`000?oo003o
oooo08[ooooo000Zooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0C?ooool00ol0
003oo`00ooooo`2;ooooo`00:_ooool2o`00063ooooo00?oo`00ooooooooool0B_ooool00ol0003o
o`00ooooo`2<ooooo`00:_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo04Sooooo
00?o0000ool00?ooool0SOooool002[ooooo00?o0000ooooooooool0HOooool00ooo003ooooooooo
o`16ooooo`03o`000?oo003ooooo08kooooo000Zooooo`03o`000?oooooooooo06;ooooo00?oo`00
ooooooooool0A?ooool00ol0003oo`00ooooo`2?ooooo`00:_ooool00ol0003oooooooooo`1Soooo
o`03ool00?oooooooooo04;ooooo0_oo002Aooooo`00:_ooool00ol0003oooooooooo`1Tooooo`03
ool00?l0003ooooo03oooooo0_oo002Cooooo`00:_ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo03cooooo00?oo`00ooooooooool0Toooool002[ooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`0iooooo`;o0000U_ooool002[ooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooooooo`0fooooo`;o0000V?ooool002[ooooo0_l0001Zooooo`;o0000=Oooool00ol0
003oooooooooo`2Hooooo`00:_ooool00ol0003oooooooooo`1[ooooo`?o0000<?ooool2o`0009_o
oooo000Zooooo`03o`000?oooooooooo06kooooo0_l0000]ooooo`03o`000?oooooooooo09_ooooo
000Zooooo`03o`000?oooooooooo073ooooo0_oo000Yooooo`;o0000W_ooool002[ooooo00?o0000
ooooooooool0L_ooool2ool002Gooooo0_l0002Pooooo`00:_ooool00ol0003oooooooooo`1doooo
o`03ool00?oooooooooo027ooooo0_oo002Qooooo`00:_ooool00ol0003oooooooooo`1eooooo`?o
o`007_ooool2ool00:?ooooo000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`1hooooo`?oo`006?ooool3ool00:Gooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Noooool3ool00003o`000?oooooooooo00cooooo1_oo002Xooooo`008oooool0
0ol0003oooooooooo`04ooooo`?o0000Ooooool<o`0000;oo`00[_ooool002?ooooo00?o0000oooo
ooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`00
0?oooooooooo0?oooooo@oooool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008Oooool0
0omEEEGoIVIVo`00003oooooodGooooo002Fooooo`Go0000cOooool009Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A03=ooooo`00Uoooool00onHV9So8B4Qonk^kP3>ooooo`00V?ooool00onHV9So8B4Q
onk^kP3=ooooo`00VOooool00omgMgOoIVIVooooo`3<ooooo`00V_ooool00ol0003oooooooooo`0;
ooooo`?o000000?o410@ooooooooool0^_ooool008gooooo0_l00007ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00Cooooo00?o0000
okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0WOooool008gooooo00?o0000oooo
ooooool01_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo0_lb<S86ooooo`03oiRHV?lb<S;o
oooo00Cooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:Nooooo`00Poooool01Ol@
413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool04_ooool00on7QhOo0000okZj^P05
ooooo`03omgMgOl0003o^[Zj00Cooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4
A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo0025ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00oo<c<co0000oa0@4005ooooo`03oeEE
EOmgMgOoA4A400Cooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000_ooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMgQ_ooool008Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`_o00002oooool01OoMgMgo410@oooooolQ
8B7ogMgM00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@4026ooooo`00QOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Ko0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool00000Q_ooool008;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`06ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003o
ooooooooo`09ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@
08Kooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool008;ooooo1ol00004oooo
o`;o00002?ooool4o`000003oa0@4?oooooooooo01_ooooo00?o0000ooooooooool01?ooool2o`00
00gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Ioooo
o`03o`000?oooooooooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Iooooo`03o`00
0?oooooooooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Iooooo`03o`000?oooooo
oooo0<cooooo002Iooooo`03o`000?oooooooooo0<cooooo002Gooooo`03oeEEEOmVIVKo00000<ko
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -47.0938 0 ]
[.5 .63053 47.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
153.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01701 L
.10458 .03521 L
.14415 .05168 L
.18221 .0667 L
.22272 .08155 L
.26171 .09445 L
.30316 .10648 L
.34309 .11615 L
.3815 .12358 L
.40095 .12661 L
.42237 .12931 L
.44268 .13128 L
.45178 .13197 L
.46172 .13259 L
.4671 .13287 L
.4721 .1331 L
.47727 .13329 L
.48196 .13343 L
.48658 .13354 L
.49093 .13362 L
.49332 .13365 L
.49552 .13367 L
.49667 .13368 L
.49794 .13368 L
.49926 .13369 L
.50049 .13369 L
.50175 .13368 L
.50239 .13368 L
.50309 .13368 L
.50433 .13367 L
.50549 .13366 L
.50811 .13363 L
.51094 .13359 L
.5161 .13348 L
.52084 .13335 L
.52988 .13301 L
.5394 .13253 L
.55914 .13112 L
.57751 .12932 L
.61655 .12391 L
.65805 .1159 L
.69803 .10616 L
.7365 .09501 L
.77742 .0815 L
.81682 .06708 L
.85471 .05214 L
.89505 .03537 L
.93387 .01862 L
.97515 .00046 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .0168 L
.10458 .03481 L
.14415 .05112 L
.18221 .06598 L
.22272 .08066 L
.26171 .09343 L
.30316 .10531 L
.34309 .11489 L
.3815 .12224 L
.40095 .12522 L
.42237 .1279 L
.44268 .12986 L
.45178 .13054 L
.46172 .13116 L
.4671 .13144 L
.4721 .13165 L
.47727 .13184 L
.48196 .13198 L
.48658 .13208 L
.4887 .13212 L
.49093 .13215 L
.49332 .13218 L
.49438 .13219 L
.49552 .1322 L
.49675 .13221 L
.49789 .13221 L
.49859 .13221 L
.49925 .13221 L
.50049 .13221 L
.50163 .13221 L
.50286 .13221 L
.50401 .1322 L
.50508 .13219 L
.50754 .13217 L
.51014 .13214 L
.51268 .1321 L
.51504 .13205 L
.5204 .13191 L
.5293 .1316 L
.53882 .13113 L
.54906 .13049 L
.56016 .12962 L
.58032 .1276 L
.62123 .12178 L
.66064 .11408 L
.69852 .10486 L
.73886 .09325 L
.77769 .08052 L
.81897 .06554 L
Mistroke
.85873 .04996 L
.89697 .03416 L
.93767 .01676 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Ko00000_oo
003oo`0001So00002_ooool01OmVIVKoQhN7oooooonHV9SoEEEE01Kooooo000Zooooo`03o`000?oo
ooooo`0000;oo`002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?ooool03ooo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`05o`000?oooooo
ooooooooool000000_oo000nooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0kooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00?o0000ooooooooool01?oo
ool00ooo003o0000ooooo`3oooooo`;o0000<oooool002[ooooo00?o0000ooooooooool01_ooool2
o`000?_ooooo0ol0000eooooo`00:_ooool00ol0003oooooooooo`08ooooo`;o0000moooool2ool0
03Sooooo000Zooooo`03o`000?oooooooooo00[ooooo0ol0003booooo`;oo`00>_ooool002[ooooo
00?o0000ooooooooool03Oooool2o`000>gooooo00?o0000ool00?oo0000??ooool002[ooooo00?o
0000ooooooooool03oooool2o`0000;oo`00ioooool00ol0003oo`00ool0000nooooo`00:_ooool2
o`0001;ooooo0_l000000ooo003oooooooooo`3Rooooo`03o`000?oo003oo`00043ooooo000Zoooo
o`03o`000?oooooooooo01Cooooo0_oo003Pooooo`03o`000?oo003oo`0004;ooooo000Zooooo`03
o`000?oooooooooo01Kooooo0ooo003Jooooo`;o00000_oo0014ooooo`00:_ooool00ol0003ooooo
ooooo`0Iooooo`;oo`00e_ooool2o`0004Sooooo000Zooooo`03o`000?oooooooooo01_ooooo0ooo
003Aooooo`;o0000B_ooool002[ooooo00?o0000ooooooooool07Oooool00ol0003oo`00o`00003<
ooooo`?o0000C?ooool002[ooooo00?o0000ooooooooool08?ooool2o`000<Sooooo0_l0001?oooo
o`00:_ooool00ol0003oooooooooo`0Rooooo`?o0000`_ooool2ool00003o`000?oooooooooo04oo
oooo000Zooooo`03o`000?oooooooooo02Gooooo0ol0002looooo`?oo`00E?ooool002[ooooo0_l0
000Yooooo`?o0000]oooool2ool00003o`000?oooooooooo05Cooooo000Zooooo`03o`000?oooooo
oooo02_ooooo0_oo002cooooo`;oo`00FOooool002[ooooo00?o0000ooooooooool0;Oooool3ool0
0:gooooo0ooo001Kooooo`00:_ooool00ol0003oooooooooo`0`ooooo`?oo`00Yoooool3ool005ko
oooo000Zooooo`03o`000?oooooooooo03?ooooo0ooo002Qooooo`?oo`00HOooool002[ooooo00?o
0000ooooooooool0=_ooool3ool009_ooooo0ooo001Tooooo`00:_ooool00ol0003oooooooooo`0i
ooooo`03ool00?l0003o000009Gooooo0_l000000ooo003oooooooooo`1Uooooo`00:_ooool00ol0
003oooooooooo`0looooo`?o0000Soooool3o`0006[ooooo000Zooooo`03o`000?oooooooooo03oo
oooo0ol00029ooooo`?o0000KOooool002[ooooo0_l00013ooooo`?o0000Poooool3o`00073ooooo
000Zooooo`03o`000?oooooooooo04Gooooo0_l00003ool007[ooooo0ooo00000ol0003ooooooooo
o`1aooooo`00:_ooool00ol0003oooooooooo`19ooooo`04o`000?oo003oo`00ool007Cooooo0ooo
001gooooo`00:_ooool00ol0003oooooooooo`1<ooooo`04o`000?oo003oo`00ool006gooooo1?oo
001jooooo`00:_ooool00ol0003oooooooooo`1@ooooo`?oo`0000?o0000ooooooooool0Hoooool0
1?l0003oo`00ool00?oo001nooooo`00:_ooool00ol0003oooooooooo`1Cooooo`;oo`000ol0001M
ooooo`?o00000_oo0021ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001Oooool00ol0003oooooooooo`1Hooooo`Go0000Doooool5o`0008Kooooo000@oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo05gooooo1Ol00018ooooo`Ko0000Roooool0013ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0001Rooooo`Koo`00??oo
ool2o`0000Goo`00T?ooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?o0000ooooooooool0J?ooool6ool0037ooooo00?o0000ool00?oo00001?oo
002Eooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?oo
ool00ol0003oooooooooo`1^ooooo`Coo`000_l0000Vooooo`;o00001?oo002Kooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1dooooo`_o00003ooo000<o`000:7ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooollooooo`004?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0003ooooooccooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?oo
oooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Ko
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooo
ooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0
oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooo
oooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003ooooooooo
o`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oo
oooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0ooooooll
ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool0
0ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo
?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05o`000?oo
ooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooocco
oooo000@ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?oooooo??ooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Qooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooccooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooollooooo`008oooool00ol0003oooooooooo`04ooooo`?o0000oooooollooooo`008oooool0
0ol0003oooooooooo`3ooooood?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool002?o
oooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooood?ooooo
000Qooooo`03oeEEEOmVIVKo00000?ooooooAOooool008kooooo1Ol0003Eooooo`00S_ooool01OnH
V9So8B4Qonk^k_ooooooA4A40=Gooooo002?ooooo`03oiRHV?lQ8B7ok^k^0=Kooooo002@ooooo`03
oiRHV?lQ8B7ok^k^0=Gooooo002Aooooo`03ogMgMomVIVKooooo0=Cooooo002Booooo`03o`000?oo
oooooooo00_ooooo0ol000000ol@413oooooooooo`32ooooo`00Q_ooool2o`0000Kooooo00Go0000
okZj^_ooooooV9RHoa0@4008ooooo`03o`000?nj^[[ooooo00Cooooo00?o410@okZj^_ooool01Ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2Uooooo`00Q_ooool0
0ol0003oooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool2oc8b<PGooooo00?o
V9RHoc8b<_ooool01Oooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<ZKooooo001k
ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool00ol0003oooooooooo`0Booooo`03ohN7Qol0
003o^[Zj00Cooooo00?ogMgMo`000?nj^[X01Oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@1looooo`00OOooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A005oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko0000
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo07_o
oooo001mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool:o`0000_ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`1jooooo`00OOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01So
oooo00GoIVIVohN7QoooooooV9RHoeEEE@0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool0Noooool007gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Gooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01looooo`00N_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05ooo
ool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1nooooo`00N_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0O_ooool007[ooooo1ol00005ooooo`;o
00001oooool4o`000003oa0@4?oooooooooo01_ooooo00?o0000ooooooooool01Oooool2o`0000go
oooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001moooo
o`00TOooool00ol0003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00TOoo
ool00ol0003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00TOooool00ol0
003oooooooooo`3Dooooo`00TOooool00ol0003oooooooooo`3Dooooo`00Soooool00omEEEGoIVIV
o`00003Fooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0 0.618034 [
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -44.0938 0 ]
[.5 .63053 44.0938 20.6875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.6875 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 17.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 17.438 moveto
(@) show
78.062 11.500 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
76.750 17.438 moveto
(\\200\\200) show
81.000 17.438 moveto
(\\200) show
83.062 17.438 moveto
(\\200) show
78.062 23.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
99.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.188 17.438 moveto
(D) show
117.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
123.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
129.188 17.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
135.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
147.188 17.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .00368 L
.10458 .00762 L
.14415 .01118 L
.18221 .01443 L
.22272 .01764 L
.26171 .02043 L
.30316 .02303 L
.34309 .02512 L
.3815 .02673 L
.40095 .02739 L
.42237 .02797 L
.44268 .0284 L
.45178 .02855 L
.46172 .02868 L
.4671 .02874 L
.4721 .02879 L
.47727 .02883 L
.48196 .02886 L
.48658 .02889 L
.49093 .0289 L
.49332 .02891 L
.49552 .02891 L
.49667 .02892 L
.49794 .02892 L
.49926 .02892 L
.50049 .02892 L
.50175 .02892 L
.50239 .02892 L
.50309 .02892 L
.50433 .02891 L
.50549 .02891 L
.50811 .02891 L
.51094 .0289 L
.5161 .02887 L
.52084 .02885 L
.52988 .02877 L
.5394 .02867 L
.55914 .02836 L
.57751 .02797 L
.61655 .0268 L
.65805 .02507 L
.69803 .02296 L
.7365 .02055 L
.77742 .01763 L
.81682 .01451 L
.85471 .01128 L
.89505 .00765 L
.93387 .00403 L
.97515 .0001 L
Mistroke
.97619 0 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 0 m
.06244 .00359 L
.10458 .00745 L
.14415 .01094 L
.18221 .01412 L
.22272 .01725 L
.26171 .01999 L
.30316 .02253 L
.34309 .02458 L
.3815 .02615 L
.40095 .02679 L
.42237 .02736 L
.44268 .02778 L
.45178 .02793 L
.46172 .02806 L
.4671 .02812 L
.4721 .02816 L
.47727 .0282 L
.48196 .02823 L
.48658 .02826 L
.4887 .02826 L
.49093 .02827 L
.49332 .02828 L
.49438 .02828 L
.49552 .02828 L
.49675 .02828 L
.49789 .02828 L
.49859 .02828 L
.49925 .02828 L
.50049 .02828 L
.50163 .02828 L
.50286 .02828 L
.50401 .02828 L
.50508 .02828 L
.50754 .02828 L
.51014 .02827 L
.51268 .02826 L
.51504 .02825 L
.5204 .02822 L
.5293 .02815 L
.53882 .02805 L
.54906 .02791 L
.56016 .02773 L
.58032 .0273 L
.62123 .02605 L
.66064 .02441 L
.69852 .02243 L
.73886 .01995 L
.77769 .01722 L
.81897 .01402 L
Mistroke
.85873 .01069 L
.89697 .00731 L
.93767 .00358 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0=oooool4o`000003oa0@4?oooooooooo03Gooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03Kooooo1Ol0
000[ooooo`00I?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0eooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:oooool006Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo00?oV9RHob4Q8Oo^k^h0
;?ooool006Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03Sooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Oooooo
00?oV9RHob4Q8Oo^k^h0:oooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`03ogMgMomVIVKooooo02[ooooo001Tooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
02Wooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0hoooo
o`05o`000?nj^[[ooooooiRHV?l@4100:oooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000>?ooool00omEEEGoIVIVo`00000iooooo`03oeEEEOmVIVKo000000gooooo1?l0000g
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool3o`000003oa0@4?oooooooooo01Kooooo003o
ooooodoooooo00?o410@okZj^_ooool05oooool00?ooooooCoooool00onHV9So<S8booooo`0Goooo
o`00oooooom?ooooo`03omgMgOl0003o^[Zj01Oooooo003oooooodoooooo00?oEEEEogMgMom4A4@0
5oooool00?ooooooC_ooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo000Tooooo`Oo00001_oo
003oo`0000Go00001_oo0008o`0000[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00:_oo
ool00ol0003oooooooooo`04ooooo`[oo`0000?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo0_l00009ool000Kooooo00?o0000ooooooooool03_oo
ool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo000Zooooo`03o`000?oooooo
oooo00oooooo3?l0000Wooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Tooooo`co00004Oooool00ol0003oooooooooo`0>ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool04oooool002[ooooo00?o0000ooooooooool06oooool;
ool00003o`000?oooooooooo0;gooooo0_l00009ool004[ooooo000Zooooo`03o`000?oooooooooo
02Kooooo1?oo0008o`000:Wooooo1ol00006ool005?ooooo000Zooooo`03o`000?oooooooooo03;o
oooo1Ol00007ool009;ooooo1_oo0005o`00063ooooo000Zooooo`03o`000?oooooooooo03gooooo
00?o0000ool00?oo00001ooo0002o`0007cooooo0_l00009ool006_ooooo000Zooooo`03o`000?oo
oooooooo04Wooooo2ol0000?ool004Oooooo3ooo000<o`0007Kooooo000Zooooo`03o`000?oooooo
oooo063ooooo4Ol0000?ool000go00004?oo000@o`0008kooooo000Zooooo`;o0000oooooolmoooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool2o`000?oooooo?Oooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?oooooo
??ooool0013ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?o0000ooooooooool0oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
0oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo
000@ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o0000ooooooooool0
oooooollooooo`004?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001_ooool3o`000?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3ooooo
occooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006oooo
o`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003o
ooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o
0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zoooo
o`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`00
0?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool0
0ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[o
oooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo000Zoooo
o`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00
:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??oo
ool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooo
occooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003oooooocgooooo
000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0ooooooll
ooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oo
oooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooooooo
o`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
k^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?oooooo??ooool0013ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Go
oooo00?o0000ooooooooool0oooooollooooo`004?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooollooooo`004?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oooooo??oo
ool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o
0000ooooooooool0oooooollooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Co
c<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
02[ooooo0_l0003oooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Z
ooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooolloooo
o`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool0
02[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo0?oooooo??ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooollooooo`004?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo0?oooooo??ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oooooo??ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3o
oooooccooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj
^[[o410@00Gooooo00?o0000ooooooooool0oooooollooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?oooooo
??ooool0013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT01Oooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo
??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3o
oooooccooooo000Zooooo`;o0000oooooolmooooo`00:_ooool00ol0003oooooooooo`3oooooocco
oooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooo
oollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo
0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0003ooooo
ooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo0_l0003o
ooooocgooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000oooooooo
ool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oo
oooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_ooool00ol0
003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool002[ooooo
00?o0000ooooooooool0oooooollooooo`00:_ooool2o`000?oooooo?Oooool002[ooooo00?o0000
ooooooooool0oooooollooooo`00:_ooool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03
o`000?oooooooooo0?oooooo??ooool002[ooooo00?o0000ooooooooool0oooooollooooo`00:_oo
ool00ol0003oooooooooo`3ooooooccooooo000Zooooo`03o`000?oooooooooo0?oooooo??ooool0
027ooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo??ooool002?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooccooooo000Sooooo`03o`00
0?oooooooooo00Cooooo0ol0003ooooooccooooo000Sooooo`03o`000?oooooooooo0?oooooo@ooo
ool002?ooooo00?o0000ooooooooool0oooooom3ooooo`008oooool00ol0003oooooooooo`3ooooo
od?ooooo000Sooooo`03o`000?oooooooooo0?oooooo@oooool0027ooooo00?oEEEEofIVI_l00000
oooooom5ooooo`00T_ooool5o`000=7ooooo002Booooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0dOoo
ool009?ooooo00?oV9RHob4Q8Oo^k^h0d_ooool009Cooooo00?oV9RHob4Q8Oo^k^h0dOooool009Go
oooo00?oMgMgofIVI_ooool0d?ooool009Kooooo00?o0000ooooooooool02oooool3o`000003oa0@
4?oooooooooo0;kooooo002:ooooo`;o00001_ooool01Ol0003o^[ZjoooooonHV9So410@00Oooooo
00?o0000okZj^_ooool01Oooool00ol@413o^[Zjooooo`04ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0:7ooooo002:ooooo`03o`000?oooooooooo00Gooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c007ooooo`;o<S8b1_ooool00onHV9So<S8booooo`04ooooo`;o<S8b
3_ooool00ol0003oooooooooo`04ooooo`;o<S8bX_ooool007oooooo00Go410@o`000?l0003o0000
oa0@4006ooooo`03o`000?oooooooooo017ooooo00?oQhN7o`000?nj^[X01Oooool00ooMgMgo0000
okZj^P04ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QPoooool0087ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03olc<c?l0003o410@00Gooooo00?oEEEEogMgMom4
A4@01?ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4QPoooool0087ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`_o00002oooool01OoMgMgo410@oooooolQ8B7o
gMgM00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0ROooool0087ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Hooooo`05ofIVI_n7QhOooooooiRHV?mEEED02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000
ooooooooool0ROooool0087ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Goooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`29oooo
o`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Kooooo00?o410@
o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=
ooooo`03o`000?oooooooooo08Wooooo001nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Wooooo001noooo
o`Oo00001Oooool2o`0000Oooooo1?l000000ol@413oooooooooo`0Kooooo`03o`000?oooooooooo
00Cooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000Roooool009Go
oooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o
0000ooooooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009Gooooo00?o0000oooo
ooooool0d?ooool009Gooooo00?o0000ooooooooool0d?ooool009?ooooo00?oEEEEofIVI_l00000
d_ooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.313969, -0.0837537, \
0.00916054, 0.00705812}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The numerical solution (solid line) is so close to the exact \
solution (dashed line) that the two curves cannot be distinguished. \
\>", \
"Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2.2 Boundary-Value Problems", "Subsubtitle",
  CellTags->{"i:29", "c:22"}],

Cell[CellGroupData[{

Cell["Direct Solution", "Section",
  CellTags->{"i:30", "c:23"}],

Cell["\<\
We now turn to the solution of time-independent boundary-value \
problems using grid techniques. The canonical example of such a problem is \
Poisson's equation in 2 dimensions,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2)\) \(\[Phi](x, y)\) = \[Rho](x, y)\)]],
  ","
}], "NE2",
  CellTags->"(6.2.33)"],

Cell[TextData[{
  "\tWe first consider the problem in a rectangular box with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " specified on the boundaries (Dirichlet boundary conditions). As before, \
we construct a grid on which we will determine \[Phi], at positions"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\_x\)]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tOne way to solve this problem is to centered-difference the spatial \
derivatives, defining a spatial grid that turns Eq. ",
  ButtonBox["(6.2.33)",
    ButtonData:>"(6.2.33)",
    ButtonStyle->"Hyperlink"],
  " into a system of coupled linear equations:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j + 1\ k\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j - 1\ k\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "+", 
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j\ k + 1\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j\ k - 1\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]]}], 
          "=", \(\[Rho]\_\(j\ k\)\)}], TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, \(\(...\)\(\ \)\(M\_x\)\) - 1, \ \ k = 1, 
      2,  ... , M\_y\  - 1. \)]]
}], "NE2",
  CellTags->"(6.2.34)"],

Cell[TextData[{
  "These equations for the potential in the interior of the box are \
supplemented by the boundary conditions on the box edges, which directly \
determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = M\_x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k = 0\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k = M\_y\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We can solve this problem directly using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This  involves the solution of ",
  Cell[BoxData[
      \(TraditionalForm\`\((M\_x - 1)\) \((M\_y - 1)\)\)]],
  " simultaneous equations for the potential at the interior points. This is \
a daunting task, but let's try it anyway to see if ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "can handle it",
  StyleBox[".  ",
    FontSlant->"Italic"],
  "First, we specify the dimensions of the box and the number of grid \
points:"
}], "Text"],

Cell[BoxData[{
    \(M\_x = 10; M\_y = 10;\), "\n", 
    \(\(\(L\_x = \(L\_y = 1. \);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = 
      L\_y/M\_y;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.86"],

Cell["\<\
Next, we specify the boundary conditions. We take homogeneous \
Dirichlet conditions:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Phi][0, k_]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][M\_x, k_]\  = \ 0;\)\ \), "\n", 
    \(\(\[Phi][j_, 0]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][j_, M\_y]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.87"],

Cell[TextData[{
  "For the source, we choose uniform charge density, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho][j_, k_]\  = \ 1;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.88"],

Cell[TextData[{
  "We are now ready to create the list of equations using Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  " for the interior points:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eqns", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{
                RowBox[{
                  FractionBox[
                    FormBox[
                      RowBox[{
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], "+", "1"}], ",", 
                            StyleBox["k",
                              FontSlant->"Plain"]}], "]"}], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{"\[Phi]", "[", 
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], ",", 
                              StyleBox["k",
                                FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], "-", "1"}], ",", 
                            StyleBox["k",
                              FontSlant->"Plain"]}], "]"}]}],
                      "TraditionalForm"], \(\[CapitalDelta]x\^2\)], "+", 
                  FractionBox[
                    FormBox[
                      RowBox[{
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            StyleBox["j",
                              FontSlant->"Plain"], ",", 
                            RowBox[{
                              StyleBox["k",
                                FontSlant->"Plain"], "+", "1"}]}], "]"}], "-",
                         
                        RowBox[{"2", " ", 
                          RowBox[{"\[Phi]", "[", 
                            RowBox[{
                              StyleBox["j",
                                FontSlant->"Plain"], ",", 
                              StyleBox["k",
                                FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                        RowBox[{"\[Phi]", "[", 
                          RowBox[{
                            StyleBox["j",
                              FontSlant->"Plain"], ",", 
                            RowBox[{
                              StyleBox["k",
                                FontSlant->"Plain"], "-", "1"}]}], "]"}]}],
                      "TraditionalForm"], \(\[CapitalDelta]y\^2\)]}], 
                "\[Equal]", \(\[Rho][j, k]\)}], ",", \({j, 1, M\_x - 1}\), 
              ",", \({k, 1, M\_y - 1}\)}], "]"}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.89"],

Cell["\<\
The list of variables for which we are solving is given by the \
following command:\
\>", "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[\[Phi][j, k], {j, 1, M\_x - 1}, {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.90"],

Cell["Finally, we solve the equations:", "Text"],

Cell[BoxData[
    \(\(sol\  = \ \(Solve[eqns, vars]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.91"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is able to solve this problem quite quickly.  We can construct an \
interpolation function of the solution in the usual way:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{j\ \[CapitalDelta]x, 
                k\ \[CapitalDelta]y, \[Phi][j, k]}, {j, 0, M\_x}, {k, 0, 
                M\_y}] /. sol, 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.92"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}, {0.`, 1.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.93",
    ButtonData:>"Cell 6.93",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y], {x, 0, 1}, {y, 0, 1}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<Potential inside a charge-filled square box\>"];\
\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.93"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -18 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -18 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -18 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -18 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -5 ]
[-0.01875 .5 -18 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -131 0 ]
[.5 1.0125 131 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.2)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.4)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.6)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.8)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -192 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
177.000 13.000 moveto
(charge) show
213.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
261.000 13.000 moveto
(square) show
303.000 13.000 moveto
(box) show
321.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.9 g
.08791 .06242 m
.15659 .04527 L
.22527 .03978 L
.29396 .03716 L
.36264 .03576 L
.43132 .03506 L
.5 .03484 L
.56868 .03506 L
.63736 .03576 L
.70604 .03716 L
.77473 .03978 L
.84341 .04527 L
.91209 .06242 L
.93758 .08791 L
.95473 .15659 L
.96022 .22527 L
.96284 .29396 L
.96424 .36264 L
.96494 .43132 L
.96516 .5 L
.96494 .56868 L
.96424 .63736 L
.96284 .70604 L
.96022 .77473 L
.95473 .84341 L
.93758 .91209 L
.91209 .93758 L
.84341 .95473 L
.77473 .96022 L
.70604 .96284 L
.63736 .96424 L
.56868 .96494 L
.5 .96516 L
.43132 .96494 L
.36264 .96424 L
.29396 .96284 L
.22527 .96022 L
.15659 .95473 L
.08791 .93758 L
.06242 .91209 L
.04527 .84341 L
.03978 .77473 L
.03716 .70604 L
.03576 .63736 L
.03506 .56868 L
.03484 .5 L
.03506 .43132 L
.03576 .36264 L
.03716 .29396 L
.03978 .22527 L
.04527 .15659 L
.06242 .08791 L
F
0 g
.08791 .06242 m
.15659 .04527 L
.22527 .03978 L
.29396 .03716 L
.36264 .03576 L
.43132 .03506 L
.5 .03484 L
.56868 .03506 L
.63736 .03576 L
.70604 .03716 L
.77473 .03978 L
.84341 .04527 L
.91209 .06242 L
.93758 .08791 L
.95473 .15659 L
.96022 .22527 L
.96284 .29396 L
.96424 .36264 L
.96494 .43132 L
.96516 .5 L
.96494 .56868 L
.96424 .63736 L
.96284 .70604 L
.96022 .77473 L
.95473 .84341 L
.93758 .91209 L
.91209 .93758 L
.84341 .95473 L
.77473 .96022 L
.70604 .96284 L
.63736 .96424 L
.56868 .96494 L
.5 .96516 L
.43132 .96494 L
.36264 .96424 L
.29396 .96284 L
.22527 .96022 L
.15659 .95473 L
.08791 .93758 L
.06242 .91209 L
.04527 .84341 L
.03978 .77473 L
.03716 .70604 L
.03576 .63736 L
.03506 .56868 L
.03484 .5 L
.03506 .43132 L
.03576 .36264 L
.03716 .29396 L
.03978 .22527 L
Mistroke
.04527 .15659 L
.06242 .08791 L
.08791 .06242 L
Mfstroke
.8 g
.15659 .08415 m
.22527 .06905 L
.29396 .06233 L
.36264 .05883 L
.43132 .05709 L
.5 .05655 L
.56868 .05709 L
.63736 .05883 L
.70604 .06233 L
.77473 .06905 L
.84341 .08415 L
.85334 .08791 L
.91209 .14666 L
.91585 .15659 L
.93095 .22527 L
.93767 .29396 L
.94117 .36264 L
.94291 .43132 L
.94345 .5 L
.94291 .56868 L
.94117 .63736 L
.93767 .70604 L
.93095 .77473 L
.91585 .84341 L
.91209 .85334 L
.85334 .91209 L
.84341 .91585 L
.77473 .93095 L
.70604 .93767 L
.63736 .94117 L
.56868 .94291 L
.5 .94345 L
.43132 .94291 L
.36264 .94117 L
.29396 .93767 L
.22527 .93095 L
.15659 .91585 L
.14666 .91209 L
.08791 .85334 L
.08415 .84341 L
.06905 .77473 L
.06233 .70604 L
.05883 .63736 L
.05709 .56868 L
.05655 .5 L
.05709 .43132 L
.05883 .36264 L
.06233 .29396 L
.06905 .22527 L
.08415 .15659 L
.08791 .14666 L
.14666 .08791 L
F
0 g
.15659 .08415 m
.22527 .06905 L
.29396 .06233 L
.36264 .05883 L
.43132 .05709 L
.5 .05655 L
.56868 .05709 L
.63736 .05883 L
.70604 .06233 L
.77473 .06905 L
.84341 .08415 L
.85334 .08791 L
.91209 .14666 L
.91585 .15659 L
.93095 .22527 L
.93767 .29396 L
.94117 .36264 L
.94291 .43132 L
.94345 .5 L
.94291 .56868 L
.94117 .63736 L
.93767 .70604 L
.93095 .77473 L
.91585 .84341 L
.91209 .85334 L
.85334 .91209 L
.84341 .91585 L
.77473 .93095 L
.70604 .93767 L
.63736 .94117 L
.56868 .94291 L
.5 .94345 L
.43132 .94291 L
.36264 .94117 L
.29396 .93767 L
.22527 .93095 L
.15659 .91585 L
.14666 .91209 L
.08791 .85334 L
.08415 .84341 L
.06905 .77473 L
.06233 .70604 L
.05883 .63736 L
.05709 .56868 L
.05655 .5 L
.05709 .43132 L
.05883 .36264 L
.06233 .29396 L
.06905 .22527 L
.08415 .15659 L
Mistroke
.08791 .14666 L
.14666 .08791 L
.15659 .08415 L
Mfstroke
.7 g
.36264 .08353 m
.43132 .0805 L
.5 .07958 L
.56868 .0805 L
.63736 .08353 L
.69188 .08791 L
.70604 .08972 L
.77473 .10216 L
.84341 .13305 L
.86695 .15659 L
.89784 .22527 L
.91028 .29396 L
.91209 .30812 L
.91647 .36264 L
.9195 .43132 L
.92042 .5 L
.9195 .56868 L
.91647 .63736 L
.91209 .69188 L
.91028 .70604 L
.89784 .77473 L
.86695 .84341 L
.84341 .86695 L
.77473 .89784 L
.70604 .91028 L
.69188 .91209 L
.63736 .91647 L
.56868 .9195 L
.5 .92042 L
.43132 .9195 L
.36264 .91647 L
.30812 .91209 L
.29396 .91028 L
.22527 .89784 L
.15659 .86695 L
.13305 .84341 L
.10216 .77473 L
.08972 .70604 L
.08791 .69188 L
.08353 .63736 L
.0805 .56868 L
.07958 .5 L
.0805 .43132 L
.08353 .36264 L
.08791 .30812 L
.08972 .29396 L
.10216 .22527 L
.13305 .15659 L
.15659 .13305 L
.22527 .10216 L
.29396 .08972 L
.30812 .08791 L
F
0 g
.36264 .08353 m
.43132 .0805 L
.5 .07958 L
.56868 .0805 L
.63736 .08353 L
.69188 .08791 L
.70604 .08972 L
.77473 .10216 L
.84341 .13305 L
.86695 .15659 L
.89784 .22527 L
.91028 .29396 L
.91209 .30812 L
.91647 .36264 L
.9195 .43132 L
.92042 .5 L
.9195 .56868 L
.91647 .63736 L
.91209 .69188 L
.91028 .70604 L
.89784 .77473 L
.86695 .84341 L
.84341 .86695 L
.77473 .89784 L
.70604 .91028 L
.69188 .91209 L
.63736 .91647 L
.56868 .9195 L
.5 .92042 L
.43132 .9195 L
.36264 .91647 L
.30812 .91209 L
.29396 .91028 L
.22527 .89784 L
.15659 .86695 L
.13305 .84341 L
.10216 .77473 L
.08972 .70604 L
.08791 .69188 L
.08353 .63736 L
.0805 .56868 L
.07958 .5 L
.0805 .43132 L
.08353 .36264 L
.08791 .30812 L
.08972 .29396 L
.10216 .22527 L
.13305 .15659 L
.15659 .13305 L
.22527 .10216 L
Mistroke
.29396 .08972 L
.30812 .08791 L
.36264 .08353 L
Mfstroke
.6 g
.22527 .1415 m
.29396 .12067 L
.36264 .11079 L
.43132 .10605 L
.5 .10463 L
.56868 .10605 L
.63736 .11079 L
.70604 .12067 L
.77473 .1415 L
.80248 .15659 L
.84341 .19752 L
.8585 .22527 L
.87933 .29396 L
.88921 .36264 L
.89395 .43132 L
.89537 .5 L
.89395 .56868 L
.88921 .63736 L
.87933 .70604 L
.8585 .77473 L
.84341 .80248 L
.80248 .84341 L
.77473 .8585 L
.70604 .87933 L
.63736 .88921 L
.56868 .89395 L
.5 .89537 L
.43132 .89395 L
.36264 .88921 L
.29396 .87933 L
.22527 .8585 L
.19752 .84341 L
.15659 .80248 L
.1415 .77473 L
.12067 .70604 L
.11079 .63736 L
.10605 .56868 L
.10463 .5 L
.10605 .43132 L
.11079 .36264 L
.12067 .29396 L
.1415 .22527 L
.15659 .19752 L
.19752 .15659 L
F
0 g
.22527 .1415 m
.29396 .12067 L
.36264 .11079 L
.43132 .10605 L
.5 .10463 L
.56868 .10605 L
.63736 .11079 L
.70604 .12067 L
.77473 .1415 L
.80248 .15659 L
.84341 .19752 L
.8585 .22527 L
.87933 .29396 L
.88921 .36264 L
.89395 .43132 L
.89537 .5 L
.89395 .56868 L
.88921 .63736 L
.87933 .70604 L
.8585 .77473 L
.84341 .80248 L
.80248 .84341 L
.77473 .8585 L
.70604 .87933 L
.63736 .88921 L
.56868 .89395 L
.5 .89537 L
.43132 .89395 L
.36264 .88921 L
.29396 .87933 L
.22527 .8585 L
.19752 .84341 L
.15659 .80248 L
.1415 .77473 L
.12067 .70604 L
.11079 .63736 L
.10605 .56868 L
.10463 .5 L
.10605 .43132 L
.11079 .36264 L
.12067 .29396 L
.1415 .22527 L
.15659 .19752 L
.19752 .15659 L
.22527 .1415 L
s
.5 g
.29396 .1565 m
.36264 .14152 L
.43132 .13451 L
.5 .13242 L
.56868 .13451 L
.63736 .14152 L
.70604 .1565 L
.70636 .15659 L
.77473 .18864 L
.81136 .22527 L
.84341 .29364 L
.8435 .29396 L
.85848 .36264 L
.86549 .43132 L
.86758 .5 L
.86549 .56868 L
.85848 .63736 L
.8435 .70604 L
.84341 .70636 L
.81136 .77473 L
.77473 .81136 L
.70636 .84341 L
.70604 .8435 L
.63736 .85848 L
.56868 .86549 L
.5 .86758 L
.43132 .86549 L
.36264 .85848 L
.29396 .8435 L
.29364 .84341 L
.22527 .81136 L
.18864 .77473 L
.15659 .70636 L
.1565 .70604 L
.14152 .63736 L
.13451 .56868 L
.13242 .5 L
.13451 .43132 L
.14152 .36264 L
.1565 .29396 L
.15659 .29364 L
.18864 .22527 L
.22527 .18864 L
.29364 .15659 L
F
0 g
.29396 .1565 m
.36264 .14152 L
.43132 .13451 L
.5 .13242 L
.56868 .13451 L
.63736 .14152 L
.70604 .1565 L
.70636 .15659 L
.77473 .18864 L
.81136 .22527 L
.84341 .29364 L
.8435 .29396 L
.85848 .36264 L
.86549 .43132 L
.86758 .5 L
.86549 .56868 L
.85848 .63736 L
.8435 .70604 L
.84341 .70636 L
.81136 .77473 L
.77473 .81136 L
.70636 .84341 L
.70604 .8435 L
.63736 .85848 L
.56868 .86549 L
.5 .86758 L
.43132 .86549 L
.36264 .85848 L
.29396 .8435 L
.29364 .84341 L
.22527 .81136 L
.18864 .77473 L
.15659 .70636 L
.1565 .70604 L
.14152 .63736 L
.13451 .56868 L
.13242 .5 L
.13451 .43132 L
.14152 .36264 L
.1565 .29396 L
.15659 .29364 L
.18864 .22527 L
.22527 .18864 L
.29364 .15659 L
.29396 .1565 L
s
.4 g
.29396 .19777 m
.36264 .17608 L
.43132 .16632 L
.5 .16345 L
.56868 .16632 L
.63736 .17608 L
.70604 .19777 L
.75105 .22527 L
.77473 .24895 L
.80223 .29396 L
.82392 .36264 L
.83368 .43132 L
.83655 .5 L
.83368 .56868 L
.82392 .63736 L
.80223 .70604 L
.77473 .75105 L
.75105 .77473 L
.70604 .80223 L
.63736 .82392 L
.56868 .83368 L
.5 .83655 L
.43132 .83368 L
.36264 .82392 L
.29396 .80223 L
.24895 .77473 L
.22527 .75105 L
.19777 .70604 L
.17608 .63736 L
.16632 .56868 L
.16345 .5 L
.16632 .43132 L
.17608 .36264 L
.19777 .29396 L
.22527 .24895 L
.24895 .22527 L
F
0 g
.29396 .19777 m
.36264 .17608 L
.43132 .16632 L
.5 .16345 L
.56868 .16632 L
.63736 .17608 L
.70604 .19777 L
.75105 .22527 L
.77473 .24895 L
.80223 .29396 L
.82392 .36264 L
.83368 .43132 L
.83655 .5 L
.83368 .56868 L
.82392 .63736 L
.80223 .70604 L
.77473 .75105 L
.75105 .77473 L
.70604 .80223 L
.63736 .82392 L
.56868 .83368 L
.5 .83655 L
.43132 .83368 L
.36264 .82392 L
.29396 .80223 L
.24895 .77473 L
.22527 .75105 L
.19777 .70604 L
.17608 .63736 L
.16632 .56868 L
.16345 .5 L
.16632 .43132 L
.17608 .36264 L
.19777 .29396 L
.22527 .24895 L
.24895 .22527 L
.29396 .19777 L
s
.3 g
.36264 .21678 m
.43132 .20253 L
.5 .19841 L
.56868 .20253 L
.63736 .21678 L
.66301 .22527 L
.70604 .2485 L
.7515 .29396 L
.77473 .33699 L
.78322 .36264 L
.79747 .43132 L
.80159 .5 L
.79747 .56868 L
.78322 .63736 L
.77473 .66301 L
.7515 .70604 L
.70604 .7515 L
.66301 .77473 L
.63736 .78322 L
.56868 .79747 L
.5 .80159 L
.43132 .79747 L
.36264 .78322 L
.33699 .77473 L
.29396 .7515 L
.2485 .70604 L
.22527 .66301 L
.21678 .63736 L
.20253 .56868 L
.19841 .5 L
.20253 .43132 L
.21678 .36264 L
.22527 .33699 L
.2485 .29396 L
.29396 .2485 L
.33699 .22527 L
F
0 g
.36264 .21678 m
.43132 .20253 L
.5 .19841 L
.56868 .20253 L
.63736 .21678 L
.66301 .22527 L
.70604 .2485 L
.7515 .29396 L
.77473 .33699 L
.78322 .36264 L
.79747 .43132 L
.80159 .5 L
.79747 .56868 L
.78322 .63736 L
.77473 .66301 L
.7515 .70604 L
.70604 .7515 L
.66301 .77473 L
.63736 .78322 L
.56868 .79747 L
.5 .80159 L
.43132 .79747 L
.36264 .78322 L
.33699 .77473 L
.29396 .7515 L
.2485 .70604 L
.22527 .66301 L
.21678 .63736 L
.20253 .56868 L
.19841 .5 L
.20253 .43132 L
.21678 .36264 L
.22527 .33699 L
.2485 .29396 L
.29396 .2485 L
.33699 .22527 L
.36264 .21678 L
s
.2 g
.36264 .26566 m
.43132 .24514 L
.5 .23945 L
.56868 .24514 L
.63736 .26566 L
.68402 .29396 L
.70604 .31598 L
.73434 .36264 L
.75486 .43132 L
.76055 .5 L
.75486 .56868 L
.73434 .63736 L
.70604 .68402 L
.68402 .70604 L
.63736 .73434 L
.56868 .75486 L
.5 .76055 L
.43132 .75486 L
.36264 .73434 L
.31598 .70604 L
.29396 .68402 L
.26566 .63736 L
.24514 .56868 L
.23945 .5 L
.24514 .43132 L
.26566 .36264 L
.29396 .31598 L
.31598 .29396 L
F
0 g
.36264 .26566 m
.43132 .24514 L
.5 .23945 L
.56868 .24514 L
.63736 .26566 L
.68402 .29396 L
.70604 .31598 L
.73434 .36264 L
.75486 .43132 L
.76055 .5 L
.75486 .56868 L
.73434 .63736 L
.70604 .68402 L
.68402 .70604 L
.63736 .73434 L
.56868 .75486 L
.5 .76055 L
.43132 .75486 L
.36264 .73434 L
.31598 .70604 L
.29396 .68402 L
.26566 .63736 L
.24514 .56868 L
.23945 .5 L
.24514 .43132 L
.26566 .36264 L
.29396 .31598 L
.31598 .29396 L
.36264 .26566 L
s
.1 g
.5 .29086 m
.54084 .29396 L
.56868 .29909 L
.63736 .33086 L
.66914 .36264 L
.70091 .43132 L
.70604 .45916 L
.70914 .5 L
.70604 .54084 L
.70091 .56868 L
.66914 .63736 L
.63736 .66914 L
.56868 .70091 L
.54084 .70604 L
.5 .70914 L
.45916 .70604 L
.43132 .70091 L
.36264 .66914 L
.33086 .63736 L
.29909 .56868 L
.29396 .54084 L
.29086 .5 L
.29396 .45916 L
.29909 .43132 L
.33086 .36264 L
.36264 .33086 L
.43132 .29909 L
.45916 .29396 L
F
0 g
.5 .29086 m
.54084 .29396 L
.56868 .29909 L
.63736 .33086 L
.66914 .36264 L
.70091 .43132 L
.70604 .45916 L
.70914 .5 L
.70604 .54084 L
.70091 .56868 L
.66914 .63736 L
.63736 .66914 L
.56868 .70091 L
.54084 .70604 L
.5 .70914 L
.45916 .70604 L
.43132 .70091 L
.36264 .66914 L
.33086 .63736 L
.29909 .56868 L
.29396 .54084 L
.29086 .5 L
.29396 .45916 L
.29909 .43132 L
.33086 .36264 L
.36264 .33086 L
.43132 .29909 L
.45916 .29396 L
.5 .29086 L
s
.5 .36246 m
.50737 .36264 L
.56868 .37907 L
.62093 .43132 L
.63736 .49263 L
.63754 .5 L
.63736 .50737 L
.62093 .56868 L
.56868 .62093 L
.50737 .63736 L
.5 .63754 L
.49263 .63736 L
.43132 .62093 L
.37907 .56868 L
.36264 .50737 L
.36246 .5 L
.36264 .49263 L
.37907 .43132 L
.43132 .37907 L
.49263 .36264 L
F
.5 .36246 m
.50737 .36264 L
.56868 .37907 L
.62093 .43132 L
.63736 .49263 L
.63754 .5 L
.63736 .50737 L
.62093 .56868 L
.56868 .62093 L
.50737 .63736 L
.5 .63754 L
.49263 .63736 L
.43132 .62093 L
.37907 .56868 L
.36264 .50737 L
.36246 .5 L
.36264 .49263 L
.37907 .43132 L
.43132 .37907 L
.49263 .36264 L
.5 .36246 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`?ooool2o`0000;ooooo0_l0002Rooooo`00`?oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ;ooooo0031ooooo`04omgMgOl0003o410@olc<c:?o
oooo0031ooooo`04onk^k_lQ8B7o410@onk^kZ?ooooo0031ooooo`04ob4Q8OmgMgOoMgMgoc8b<Z?o
oooo0030ooooo`;o00000_ooool2o`000:;ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000^oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00009_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;oooool4o`000003oa0@4?oooooooooo00kooooo000^
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@09_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02Gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q037ooooo00?o0000oooooooo
ool04?ooool002kooooo00Go410@oooooooooooooooooa0@400]ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP0Wooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0002Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
9Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000aoooo
o`03o`000?oooooooooo013ooooo000^ooooo`05o`000?ooooooooooooooool00000;Oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h09_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CoA4A4omgMgOoooooo00009_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b037ooooo00?o0000ooooooooool04?ooool002kooooo00Go0000
ooooooooooooooooo`00000]ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`0Uooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Voooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<02Gooooo00Go
0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0<Oooool00ol0003o
ooooooooo`0@ooooo`00;_ooool01Ol@413ooooooooooooooooo410@02gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000002Kooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo02Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
4100<Oooool00ol0003oooooooooo`0@ooooo`00;_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41009_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000009_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P09oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`00000aooooo`03o`000?oooooooooo013ooooo000^ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0;Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`0Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Uoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY02oooooo00?o
EEEEofIVI_l000004_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool002_oooooool0000bo`0000cooooo000[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool0023ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`00
8?ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0003oooooobcooooo0ol0000<ooooo`00
8?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool0023ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`00
8?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo00[ooooo000Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`1QooooofWo0000Hoooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`1<oooooaGo0000JOoVi^HEo`0004kooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool0=ooooolEo`0009?oi^KV5Ol0000iooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo02[ooooo3Ol0002monKViPco0000;Oooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`0Wooooo`?o0000e_oVi^H3o`0002[ooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool08oooool4o`000=coi^KV1?l0000Vooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo023ooooo0ol0003TonKViP?o0000
8oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0Looooo`Co0000A_oV
i^IOo`0004Goi^KV1?l0000Oooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo01Wooooo0ol0000oonKViP_o0000Goo<c<`:o`0003ooi^KV0ol0000Looooo`03o`000?oooooo
oooo00[ooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0000honKViP[o0000M?o<c<`:o`00
03Soi^KV0ol0000Iooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00005oooool00ol0003o
i^KVonKViP0]onKViP_o0000R?o<c<`;o`00033oi^KV00?o0000ooooooooool05Oooool2o`0000co
oooo000[ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H09_oVi^H8o`0009koc<c<
2?l0000YonKViP03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool05?ooool00ol0003oi^KVonKViP0RonKViPGo0000[_o<c<`5o`0002Goi^KV00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0C
ooooo`03o`000?oVi^Koi^KV01koi^KV1Ol0002holc<c0Go00008OoVi^H00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000onKV
i_oVi^H06_oVi^H5o`0004;oc<c<@?l00010olc<c0Go00007OoVi^H00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo017ooooo00?o0000onKVi_oV
i^H05ooVi^H4o`0003Coc<c<4ol00010ok>c/a;o0000<oo<c<`5o`0001Woi^KV00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oVi^Koi^KV01Koi^KV0_l0000]olc<c0_o0000IOnc/k<:o`0002koc<c<00?o0000onKVi_oVi^H0
5ooVi^H00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo013ooooo00?o0000onKVi_oVi^H05OoVi^H00ol0003oc<c<olc<c00Xolc<c0Go0000N_nc
/k<5o`0002[oc<c<00?o0000onKVi_oVi^H05_oVi^H00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000onKVi_oVi^H05?oVi^H0
0ol0003oc<c<olc<c00Tolc<c0Go0000Q?nc/k<5o`0002Koc<c<00?o0000onKVi_oVi^H05OoVi^H0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00oooooo00?o0000onKVi_oVi^H05?oVi^H00ol0003oc<c<olc<c00Polc<c0Go0000S_nc/k<5o`00
02;oc<c<00?o0000onKVi_oVi^H05OoVi^H00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00oooooo00?o0000onKVi_oVi^H04ooVi^H00ol0003o
c<c<olc<c00Lolc<c0Go0000V?nc/k<5o`0001koc<c<00?o0000onKVi_oVi^H05?oVi^H00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00oooooo
00?o0000onKVi_oVi^H04_oVi^H00ol0003oc<c<olc<c00Iolc<c0Co0000Aonc/k<Fo`0004Go/k>c
1?l0000Kolc<c003o`000?oVi^Koi^KV01?oi^KV00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV01;oi^KV00?o
0000olc<c?o<c<`05oo<c<`3o`0003Ko/k>c5Ol0000FoiVIVAGo0000=?nc/k<3o`0001Woc<c<00?o
0000onKVi_oVi^H04_oVi^H00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00kooooo00?o0000onKVi_oVi^H04OoVi^H00ol0003oc<c<olc<c00F
olc<c0;o0000:onc/k<>o`00043oVIVI3Ol0000Zok>c/`;o00006?o<c<`00ol0003oi^KVonKViP0B
onKViP03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool03_ooool00ol0003oi^KVonKViP0@onKViP03o`000?o<c<coc<c<01Goc<c<0_l0000Vok>c
/`Oo0000FonIVIT7o`0002Go/k>c0_l0000Golc<c003o`000?oVi^Koi^KV017oi^KV00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0:ooooo`00:oooool2o`0000oooooo00?o0000onKVi_oV
i^H03ooVi^H00ol0003oc<c<olc<c00Colc<c0?o00008Onc/k<7o`0006WoVIVI1ol0000Pok>c/`?o
00005Oo<c<`00ol0003oi^KVonKViP0@onKViP03o`000?oooooooooo00gooooo0_l0000<ooooo`00
:oooool00ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00ooi^KV00?o0000olc<c?o<c<`0
4_o<c<`2o`0001oo/k>c1Ol0001goiVIV@Go00007_nc/k<2o`0001Coc<c<00?o0000onKVi_oVi^H0
3ooVi^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo00gooooo00?o0000onKVi_oVi^H03_oVi^H00ol0003oc<c<olc<c00Aolc<c0;o00007_nc
/k<3o`00087oVIVI0ol0000Mok>c/`;o00004oo<c<`00ol0003oi^KVonKViP0?onKViP03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03Oooool0
0ol0003oi^KVonKViP0=onKViP03o`000?o<c<coc<c<00ooc<c<0ol0000Mok>c/`?o0000QonIVIT3
o`0001co/k>c0ol0000Aolc<c003o`000?oVi^Koi^KV00koi^KV00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oVi^Koi^KV
00goi^KV00?o0000olc<c?o<c<`03_o<c<`2o`0001go/k>c0ol0002=oiVIV@?o00007?nc/k<2o`00
013oc<c<00?o0000onKVi_oVi^H03OoVi^H00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00cooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003o
c<c<olc<c00>olc<c003o`000?nc/k?o/k>c01[o/k>c0ol0000aoiVIVC;o0000<?nIVIT3o`0001_o
/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0<onKViP03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03?ooool00ol0003oi^KV
onKViP0;onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<06?nc/k<3o`0002goVIVI
1ol0000bogmoO`Oo0000;?nIVIT3o`0001Wo/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KV
onKViP0;onKViP03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool03?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00koc<c<00?o
0000ok>c/onc/k<05_nc/k<3o`0002WoVIVI1ol00010ogmoO`Oo0000:?nIVIT3o`0001Oo/k>c00?o
0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0;onKViP03o`000?oooooooooo00cooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0:
onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<05?nc/k<3o`0002GoVIVI1ol0001>
ogmoO`Ko00009OnIVIT2o`0001Ko/k>c00?o0000olc<c?o<c<`03_o<c<`00ol0003oi^KVonKViP0:
onKViP03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c
/onc/k<04onc/k<2o`0002?oVIVI1Ol0001KogmoO`Go00008_nIVIT2o`0001Go/k>c00?o0000olc<
c?o<c<`03_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP09onKViP03
o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<04_nc/k<2o`00023oVIVI1Ol0001UogmoO`Go
00007onIVIT3o`0001?o/k>c00?o0000olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP09onKViP03
o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<0
4Onc/k<2o`0001goVIVI1Ol0001_ogmoO`Go00007OnIVIT2o`0001;o/k>c00?o0000olc<c?o<c<`0
3Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<
c<coc<c<00coc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@0IoiVIV@Co0000NOmo
Ogl4o`0001_oVIVI00?o0000ok>c/onc/k<04?nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oV
i^Koi^KV00Woi^KV00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`03?o<c<`0
0ol0003o/k>cok>c/`0@ok>c/`03o`000?nIVIWoVIVI01SoVIVI0_l00021ogmoO`;o00006OnIVIT0
0ol0003o/k>cok>c/`0@ok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oVi^H02OoVi^H0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00002oooool00ol0
003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<04?nc/k<00ol0
003oVIVIoiVIV@0GoiVIV@;o0000>?moOglFo`0003OoOgmo0_l0000HoiVIV@03o`000?nc/k?o/k>c
013o/k>c00?o0000olc<c?o<c<`02oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo
00[ooooo0_l0000<ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Wo
i^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0?ok>c/`03o`000?nIVIWoVIVI01Ko
VIVI0_l0000/ogmoO`ko00005_mVIVH>o`0002_oOgmo0_l0000GoiVIV@03o`000?nc/k?o/k>c00oo
/k>c00?o0000olc<c?o<c<`03?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<03onc/k<00ol0003oVIVI
oiVIV@0EoiVIV@;o00009omoOgl7o`0003;oIVIV1ol0000VogmoO`;o00005_nIVIT00ol0003o/k>c
ok>c/`0?ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00[ooooo00?o
0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00;olc<c003o`000?nc/k?o/k>c00ko/k>c00?o
0000oiVIVOnIVIT04onIVIT3o`0002;oOgmo1ol00010ofIVIPOo00008OmoOgl2o`0001GoVIVI00?o
0000ok>c/onc/k<03_nc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV00Soi^KV00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0=
ok>c/`03o`000?nIVIWoVIVI01;oVIVI0_l0000PogmoO`Go0000C_mVIVH4o`0001ooOgmo0_l0000D
oiVIV@03o`000?nc/k?o/k>c00ko/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP09
onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02_ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c
/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0AoiVIV@;o00007omoOgl3o`0005OoIVIV0ol0000Nogmo
O`;o00004onIVIT00ol0003o/k>cok>c/`0=ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKV
i_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00:olc<c003
o`000?nc/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT04?nIVIT2o`0001koOgmo0ol0001MofIVIP?o
00007OmoOgl2o`0001;oVIVI00?o0000ok>c/onc/k<03Onc/k<00ol0003oc<c<olc<c00:olc<c003
o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`0
2_o<c<`00ol0003o/k>cok>c/`0<ok>c/`03o`000?nIVIWoVIVI00ooVIVI0_l0000MogmoO`?o0000
HomVIVH3o`0001coOgmo0_l0000AoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<c?o<c<`0
2_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<
c<coc<c<00[oc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?mo
OgooOgmo01[oOgmo0ol0001YofIVIP?o00006omoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc
/k?o/k>c00co/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool0
0ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<0
0ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo01SoOgmo0ol0001_ofIVIP?o00006OmoOgl0
0ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`02_o<c<`0
0ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<
00Woc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo
01KoOgmo0ol0001eofIVIP?o00005omoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c
00[o/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003o
i^KVonKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003o
VIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo01CoOgmo0ol0000cofIVIQKo0000<_mVIVH2o`0001Ko
Ogmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Wo
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03
o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c009olc<c003
o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0CogmoO`;o
0000:?mVIVH>o`0001KoC4a<3Ol0000WofIVIP;o00005OmoOgl00ol0003oVIVIoiVIV@0>oiVIV@03
o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0013ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIV
I_mVIVH08omVIVH5o`00037oC4a<1Ol0000TofIVIP03o`000?moOgooOgmo01?oOgmo00?o0000oiVI
VOnIVIT03_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000@ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
00Wooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c
00[o/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0BogmoO`;o00008OmVIVH5o`00
03_oC4a<1Ol0000PofIVIP;o00005?moOgl00ol0003oVIVIoiVIV@0>oiVIV@03o`000?nc/k?o/k>c
00Wo/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool0013ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol00009ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmo
OomoOgl04OmoOgl2o`0001koIVIV1Ol00015oda<C0Go00007OmVIVH2o`0001?oOgmo00?o0000oiVI
VOnIVIT03OnIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`07ooooo`?o00003?ooool0013ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo013oOgmo0_l0000LofIVIPCo0000Com<C4`4o`00
01_oIVIV0_l0000BogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0
003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<
c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl04?moOgl00ol0003oIVIVofIVIP0IofIVIP?o0000Eom<C4`3o`0001[oIVIV00?o0000ogmo
OomoOgl04?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl03omoOgl2o`0001WoIVIV0ol0001Moda<C0;o00006OmVIVH2o`00017oOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000
onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000@oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Ooc<c<00?o
0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00ooOgmo00?o
0000ofIVI_mVIVH05omVIVH2o`0006;oC4a<0_l0000IofIVIP03o`000?moOgooOgmo00ooOgmo00?o
0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o
0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0>
ogmoO`03o`000?mVIVKoIVIV01KoIVIV0_l0001Voda<C0;o00006?mVIVH00ol0003oOgmoogmoO`0>
ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c007
olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl03_moOgl00ol0003oIVIVofIVIP0EofIVIP;o0000J_m<C4`2o`0001OoIVIV00?o0000ogmo
OomoOgl03_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH05?mVIVH2o`0006koC4a<0_l0000FofIVIP03
o`000?moOgooOgmo00goOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV01CoIVIV00?o0000oda<C?m<C4`0
<_m<C4`;o`0003?oC4a<00?o0000ofIVI_mVIVH05?mVIVH00ol0003oOgmoogmoO`0=ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03?mo
Ogl00ol0003oIVIVofIVIP0CofIVIP;o0000:_m<C4`;o`0000_o<c<c2ol0000Yoda<C0;o00005OmV
IVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02Onc
/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0BofIVIP;o00009Om<C4`7
o`00027o<c<c1ol0000Toda<C0;o00005?mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Ko
i^KV00Goi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0
003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0
003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<02;oC4a<0ol0000_oc<c<`?o00008om<C4`00ol0
003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo00_oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wo
oooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV017o
IVIV00?o0000oda<C?m<C4`07om<C4`4o`0003Go<c<c1?l0000Poda<C003o`000?mVIVKoIVIV017o
IVIV00?o0000ogmoOomoOgl03?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So
/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<
oda<C00Moda<C0?o0000?Olc<c<3o`0001koC4a<00?o0000ofIVI_mVIVH04OmVIVH00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<
olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01[oC4a<1?l0
0013oc<c<`Co00006om<C4`00ol0003oIVIVofIVIP0AofIVIP03o`000?moOgooOgmo00_oOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`;o00002Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Hoda<C0?o0000Bolc<c<3o`0001WoC4a<00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000
ooooooooool02?ooool2o`0000cooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<
C?m<C4`05_m<C4`3o`00057o<c<c0ol0000Goda<C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmo
OomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03
o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?lc<c?o<c<c05Go<c<c00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP0@ofIVIP03
o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0
5Om<C4`2o`0005Wo<c<c0_l0000Foda<C003o`000?mVIVKoIVIV00ooIVIV00?o0000ogmoOomoOgl0
2_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?mo
OgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?lc
<c?o<c<c05_o<c<c00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP0?ofIVIP03o`000?mo
OgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT0
0ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`05?m<C4`2
o`0005oo<c<c0_l0000Eoda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02_moOgl0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Coda<C0;o0000Holc<c<2o`00
01CoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003o
IVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<0IOlc<c<00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo
00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo
00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Boda<C0;o0000JOlc<c<2o`0001?oC4a<
00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<0;_lc<c<=o`00033o<c<c00?o
0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:
ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0V
oc<c<`Wo00003OlI6AT8o`0002Wo<c<c00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`07
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<
C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Soc<c<`Co00007_lI6AT5o`0002Co<c<c00?o0000oda<
C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02?nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Qoc<c<`?o
00009olI6AT3o`0002;o<c<c00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
4?m<C4`00ol0003o<c<coc<c<`0Ooc<c<`?o0000;OlI6AT3o`00023o<c<c00?o0000oda<C?m<C4`0
4?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
1onIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00002Ooo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc
/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c01ko<c<c0_l0000coaTI6@;o00007olc
<c<00ol0003oC4a<oda<C00@oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo0_l0000<ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<07Olc<c<2
o`0003Oo6ATI0_l0000Noc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01_nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
00ooC4a<00?o0000oc<c<olc<c<06olc<c<3o`0003_o6ATI0ol0000Loc<c<`03o`000?m<C4coC4a<
00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<06_lc<c<2o`00047o
6ATI0_l0000Koc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00ooC4a<
00?o0000oc<c<olc<c<06?lc<c<2o`0004Go6ATI0_l0000Ioc<c<`03o`000?m<C4coC4a<00ooC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<05_lc<c<3o`0004Wo6ATI0ol0
000Goc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000
oc<c<olc<c<05Olc<c<2o`0004oo6ATI0_l0000Foc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<05?lc<c<00ol0003o6ATIoaTI6@1AoaTI
6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oV
i^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<
C4`03_m<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI6AWo6ATI05;o6ATI00?o0000oc<c<olc
<c<05?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c01Co<c<c00?o0000oaTI6OlI6AT0E?lI6AT00ol0003o<c<coc<c<`0Doc<c<`03o`00
0?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<04olc
<c<00ol0003o6ATIoaTI6@1FoaTI6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onI
VIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oV
i^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Ko/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0Coc<c<`03o`000?lI6AWo
6ATI05So6ATI00?o0000oc<c<olc<c<04olc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o
/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0
003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c01;o<c<c00?o0000oaTI6OlI6AT0F_lI6AT00ol0
003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00go
C4a<00?o0000oc<c<olc<c<04_lc<c<00ol0003o6ATIoaTI6@1LoaTI6@03o`000?lc<c?o<c<c01;o
<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<c
oc<c<`0Boc<c<`03o`000?lI6AWo6ATI05ko6ATI00?o0000oc<c<olc<c<04_lc<c<00ol0003oC4a<
oda<C00=oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo0_l0
0009ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI
6@1PoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIV
IP09ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`07ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00<
oda<C003o`000?lc<c?o<c<c017o<c<c00?o0000oaTI6OlI6AT0H_lI6AT00ol0003o<c<coc<c<`0A
oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005
olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c
<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0]oaTI6@Wo0000;_lI6AT00ol0003o<c<coc<c<`0Aoc<c
<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc
<c<04Olc<c<00ol0003o6ATIoaTI6@0YoaTI6A7o0000:_lI6AT00ol0003o<c<coc<c<`0Aoc<c<`03
o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl0
1omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
4?lc<c<00ol0003o6ATIoaTI6@0VoaTI6AWo00009olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`00
0?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc
<c<00ol0003o6ATIoaTI6@0SoaTI6Aoo00009?lI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<
C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<0
0ol0003o6ATIoaTI6@0PoaTI6BOo00008OlI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4co
C4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0
003o6ATIoaTI6@0NoaTI6B_o00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<
00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o
6ATIoaTI6@0MoaTI6Bgo00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_o
C4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATI
oaTI6@0MoaTI6Boo00007_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_oC4a<
00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI
6@0LoaTI6C7o00007_lI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0L
oaTI6C?o00007OlI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0K
oaTI6CGo00007OlI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06olI6ATg
o`0001co6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go410@oooooooooooooooooa0@400;
ooooo`Go00001_ooool3o`0000Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`06
ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0?
oc<c<`03o`000?lI6AWo6ATI01[o6ATI>Ol0000KoaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000
oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000
oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
onKVi_oVi^H01?oVi^H00ol0003oooooooooo`06ooooo`?o00003?ooool0013ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c013o<c<c00?o0000oaTI6OlI6AT06OlI
6ATko`0001_o6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06OlI6ATmo`0001[o6ATI
00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool0013ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06?lI6AToo`0001[o6ATI00?o0000oc<c<olc<c<0
3_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00ko<c<c
00?o0000oaTI6OlI6AT06?lI6AU1o`0001Wo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<
oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0013ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT0
5olI6AU3o`0001Wo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05olI
6AU5o`0001So6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05_lI6AU7
o`0001So6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT05OlI6AU9o`00
01Oo6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT05OlI6AU;o`0001Oo6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Ko6ATI00?o0000
oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000
ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Ko6ATI00?o0000oc<c
<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05OlI6AU=o`0001Oo6ATI00?o0000oc<c<olc
<c<03?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo0_l00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
1_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0DoaTI6Doo00005_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oo
oooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI
6AWo6ATI01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oV
i^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo
6ATI01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI
01Go6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go
/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00So
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI01Co
6ATIDOl0000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003o
IVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATI
DOl0000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATIDOl0
000EoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIV
IP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATIDOl0000E
oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01?o6ATIDol0000DoaTI
6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000;ooooo`?o000000?o410@ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o
6ATIoaTI6@0DoaTI6E?o00005OlI6AT00ol0003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00[o
C4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?o
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003Oooool00ol@413o^[Zj
ooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<c
oc<c<`0<oc<c<`03o`000?lI6AWo6ATI01Co6ATIDol0000EoaTI6@03o`000?lc<c?o<c<c00co<c<c
00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
000=ooooo`03oiRHV?lb<S;ooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI6AUEo`0001Co6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool000gooooo00?ogMgMo`000?nj^[X06oooool00ol0003oooooooooo`07
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0C
oaTI6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003Oooool00omEEEGoMgMgodA4A00Koooo
o`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0<oc<c
<`03o`000?lI6AWo6ATI01?o6ATIEOl0000DoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01OnIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKV
i_oVi^H00ooVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000<ooooo`05
omgMgOl@413oooooob4Q8OoMgMd06_ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Koi^KV
00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI
00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<
00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI6EGo00005?lI6AT00ol0
003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`003?ooool01OmVIVKoQhN7oooooonHV9SoEEEE01[ooooo0_l00008oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI
6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000oooo
ooooool01oooool2o`0000cooooo000;ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0CoaTI6EGo00005?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03
o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00
2oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Oooooo00?o0000oooooooo
ool01oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mV
IVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT04olI6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
1oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
4olI6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI
6AUEo`0001Co6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mV
IVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUC
o`0001Go6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUCo`00
01Go6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c
00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT04olI6AUCo`0001Co
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT04olI6AUCo`0001Co6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00:oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o
0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o0000
oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000
ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05?lI6AUAo`0001Go6ATI00?o0000oc<c
<olc<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05OlI6AU?o`0001Ko6ATI00?o0000oc<c<olc
<c<03Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool002_ooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT05OlI6AU?o`0001Ko6ATI00?o0000oc<c<olc<c<0
3Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool002_ooooo0_l00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<03?lc
<c<00ol0003o6ATIoaTI6@0EoaTI6Doo00005_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<
C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oooooo
oooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo
6ATI01Co6ATICol0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI
01Go6ATICOl0000GoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oo
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go
/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00So
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go
6ATICOl0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003o
IVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go6ATI
COl0000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Go6ATICOl0
000FoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIV
IP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000
oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Go6ATIBol0000G
oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Go6ATIBol0000GoaTI
6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oV
i^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnI
VIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<
C4`02_m<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01Oo6ATIAol0000IoaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03
o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
2_m<C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01Oo6ATIAOl0000IoaTI6@03o`00
0?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nI
VIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01So6ATI@ol0000JoaTI6@03o`000?lc
<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?mo
OgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<C4`0
0ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01So6ATI@Ol0000JoaTI6@03o`000?lc<c?o
<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nI
VIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI01Wo6ATI?ol0000KoaTI6@03o`000?lc
<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Oooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI01[o6ATI?Ol0000KoaTI6@03o`00
0?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI6AT06_lI6ATko`0001co6ATI00?o0000oc<c<olc
<c<03_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool0013ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRH
V?lQ8B401_ooool3o`0000Oooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0?oc<c
<`03o`000?lI6AWo6ATI01_o6ATI>Ol0000LoaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000oda<
C?m<C4`02_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`06ooooo`?o00003?ooool0013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0K
oaTI6COo00007OlI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4co
C4a<00_oC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0LoaTI6CGo00007OlI6AT0
0ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000
oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0LoaTI6C?o00007_lI6AT00ol0003o<c<coc<c<`0?
oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04?lc
<c<00ol0003o6ATIoaTI6@0MoaTI6C7o00007_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<
C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl0
0ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<0
0ol0003o6ATIoaTI6@0MoaTI6Boo00007olI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4co
C4a<00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0
003o6ATIoaTI6@0NoaTI6Bgo00007olI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<
00_oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV
00Coi^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o
6ATIoaTI6@0NoaTI6B_o00008?lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00_o
C4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATI
oaTI6@0QoaTI6BGo00008_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<
00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`08ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI
6@0UoaTI6Ago00009_lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0X
oaTI6AGo0000:OlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o6ATIoaTI6@0[oaTI
6@oo0000;?lI6AT00ol0003o<c<coc<c<`0@oc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIV
I_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0^oaTI6@Oo
0000;olI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<04_lc<c<00ol0003o6ATIoaTI6@1SoaTI6@03o`00
0?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo000[ooooo`;o00002Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc
<c?o<c<c01;o<c<c00?o0000oaTI6OlI6AT0HOlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<
C4coC4a<00coC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Coi^KV00?o0000ooooooooool01oooool2o`0000cooooo000[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0Boc<c<`03o`000?lI6AWo
6ATI05oo6ATI00?o0000oc<c<olc<c<04Olc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mVIVKo
IVIV00WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0
003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c01?o<c<c00?o0000oaTI6OlI6AT0GOlI6AT00ol0
003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00goC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00go
C4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATIoaTI6@1KoaTI6@03o`000?lc<c?o<c<c01;o
<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0Doc<c<`03o`000?lI6AWo6ATI05Wo6ATI00?o0000oc<c<olc<c<04olc<c<00ol0003oC4a<
oda<C00=oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c01Co<c<c00?o
0000oaTI6OlI6AT0EolI6AT00ol0003o<c<coc<c<`0Coc<c<`03o`000?m<C4coC4a<00koC4a<00?o
0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<05?lc<c<00ol0003o6ATIoaTI6@1E
oaTI6@03o`000?lc<c?o<c<c01?o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`06
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<
C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0Eoc<c<`03o`000?lI6AWo6ATI05?o6ATI00?o0000oc<c
<olc<c<05?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003
o`000?lc<c?o<c<c01Go<c<c0_l0001AoaTI6@;o00005_lc<c<00ol0003oC4a<oda<C00>oda<C003
o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c01Oo<c<c0_l0001=oaTI6@;o0000
6?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc
<c?o<c<c01So<c<c0_l00019oaTI6@;o00006Olc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool0
0ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c01Wo<c<c0_l00015oaTI6@;o00006_lc<c<0
0ol0003oC4a<oda<C00?oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
02_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c
01_o<c<c0_l00011oaTI6@;o00007?lc<c<00ol0003oC4a<oda<C00>oda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c
00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003o
VIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00>oda<C0;o00007Olc<c<3o`0003_o6ATI0ol0000Moc<c<`03o`000?m<C4coC4a<00ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<013oC4a<00?o0000oc<c<olc<c<07Olc<c<2o`0003Oo6ATI
0_l0000Ooc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool2o`0000Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`0:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`04?m<C4`00ol0003o<c<coc<c
<`0Noc<c<`;o0000<olI6AT2o`00023o<c<c00?o0000oda<C?m<C4`03om<C4`00ol0003oIVIVofIV
IP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c
/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`08ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00A
oda<C003o`000?lc<c?o<c<c01oo<c<c0_l0000_oaTI6@;o00008Olc<c<00ol0003oC4a<oda<C00@
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07
oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04
onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c023o<c<c0_l0000[oaTI
6@;o00008_lc<c<00ol0003oC4a<oda<C00@oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03
o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?lc<c?o<c<c027o<c<c1Ol0000QoaTI6@Go00008olc<c<00ol0003oC4a<oda<C00Aoda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool0
2?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Boda<C0;o00009_lc<c<;o`0000_o6ATI2ol0000Voc<c<`;o0000
4om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oo
oooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mV
IVKoIVIV00goIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0^oc<c<`_o0000<?lc
<c<00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool002_ooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgoo
Ogmo00[oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00Coda<C0;o0000Iolc<c<2
o`0001CoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<0Holc<c<00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00koIVIV00?o0000ogmoOomoOgl02_moOgl00ol0
003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003oi^KVonKViP04onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_o
oooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00[o
Ogmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Doda<C0;o0000HOlc<c<2o`0001Go
C4a<00?o0000ofIVI_mVIVH03omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Wo
VIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<01GoC4a<0_l0001Moc<c<`;o00005_m<C4`00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>c
ok>c/`07ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o
0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o
0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003o<c<coc<c<`1Ioc<c<`03o`000?m<C4coC4a<01GoC4a<00?o
0000ofIVI_mVIVH03omVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08
ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07
ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0001Goc<c<`;o00005om<C4`00ol0003oIVIVofIVIP0@
ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`08
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVI
VOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003o<c<coc<c<`1Coc<c<`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH04?mVIVH00ol0003oOgmoogmoO`0:ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<02?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`08ooooo`03
o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`07ok>c/`03
o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0@ofIVIP03
o`000?m<C4coC4a<01OoC4a<0ol0001?oc<c<`?o00006?m<C4`00ol0003oIVIVofIVIP0AofIVIP03
o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
6Om<C4`3o`0004Wo<c<c0ol0000Joda<C003o`000?mVIVKoIVIV017oIVIV00?o0000ogmoOomoOgl0
2_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool002_ooooo0_l0000:ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omo
Ogl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01_oC4a<1?l00011oc<c<`Co00007?m<
C4`00ol0003oIVIVofIVIP0AofIVIP03o`000?moOgooOgmo00_oOgmo00?o0000oiVIVOnIVIT02_nI
VIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoV
i^H00ol0003oooooooooo`08ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02Oooool0
0ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc/k<0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH04OmVIVH0
0ol0003oC4a<oda<C00Noda<C0?o0000>olc<c<3o`0001ooC4a<00?o0000ofIVI_mVIVH04_mVIVH0
0ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<02?nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<
023oC4a<1?l0000coc<c<`Co00008Om<C4`00ol0003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo
00_oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c007olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003o
OgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV01;oIVIV0_l0000Toda<C0?o0000;Olc<c<3o`0002?o
C4a<0_l0000DofIVIP03o`000?moOgooOgmo00coOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo
00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00So/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV01?oIVIV
0_l0000Uoda<C0Oo00007olc<c<7o`0002CoC4a<0_l0000EofIVIP03o`000?moOgooOgmo00coOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`0=ogmoO`03o`000?mVIVKoIVIV01CoIVIV0_l0000Zoda<C0_o00002Olc<c<;o`0002WoC4a<0_l0
000FofIVIP03o`000?moOgooOgmo00goOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`08ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000
onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV01GoIVIV0_l0000c
oda<C0Wo0000<_m<C4`2o`0001OoIVIV00?o0000ogmoOomoOgl03OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP06
onKViP03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00koOgmo00?o0000ofIV
I_mVIVH05_mVIVH00ol0003oC4a<oda<C01Zoda<C003o`000?mVIVKoIVIV01KoIVIV00?o0000ogmo
OomoOgl03_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00koOgmo00?o0000ofIVI_mVIVH05_mVIVH2o`0006SoC4a<0_l0000HofIVIP03
o`000?moOgooOgmo00koOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV01OoIVIV0_l0001Toda<C0;o0000
6OmVIVH00ol0003oOgmoogmoO`0?ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
2Onc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`09ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03omoOgl2o`0001WoIVIV0_l0001Poda<C0;o00006OmV
IVH2o`00017oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV01SoIVIV0ol0001Joda<C0?o00006_mVIVH0
0ol0003oOgmoogmoO`0@ogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc/k<02Onc/k<0
0ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`09ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl04?moOgl2o`0001_oIVIV0ol0001Eoda<C0;o00006omV
IVH2o`0001;oOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<
c<coc<c<00Soc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
3OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV01_oIVIV1?l0001=oda<C0Co0000
7?mVIVH00ol0003oOgmoogmoO`0AogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<0
2Onc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00002Oooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03
o`000?moOgooOgmo017oOgmo0_l0000OofIVIPGo0000@om<C4`5o`0001koIVIV0_l0000CogmoO`03
o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c008olc<c003
o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool01oooool3o`0000cooooo000@ooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo01;oOgmo0_l0000RofIV
IPGo0000>Om<C4`5o`00027oIVIV0_l0000DogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c
/onc/k<02_nc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00Wooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000
oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV02CoIVIV1Ol0000_
oda<C0Go00009OmVIVH00ol0003oOgmoogmoO`0CogmoO`03o`000?nIVIWoVIVI00ooVIVI00?o0000
ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`004?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o
0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o
0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0CogmoO`;o0000:OmVIVH>o`0001CoC4a<3Ol0
000XofIVIP;o00005OmoOgl00ol0003oVIVIoiVIV@0?oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o
0000olc<c?o<c<`02?o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oVi^Koi^KV00Ooi^KV
00?o0000olc<c?o<c<`02Oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI013oVIVI
00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0dofIVIQCo0000=?mVIVH00ol0003oOgmo
ogmoO`0DogmoO`03o`000?nIVIWoVIVI013oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<
olc<c009olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@06ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003o
c<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c0_l0000AoiVIV@03o`000?moOgooOgmo01Co
Ogmo0ol0001hofIVIP?o00005_moOgl00ol0003oVIVIoiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o
/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02Oooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVI
oiVIV@0?oiVIV@03o`000?moOgooOgmo01KoOgmo0ol0001bofIVIP?o00006?moOgl00ol0003oVIVI
oiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KV
onKViP07onKViP03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o
0000ooooooooool02_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00[oc<c<00?o
0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0?oiVIV@;o00006OmoOgl4o`0006_oIVIV0ol0
000IogmoO`;o00004_nIVIT00ol0003o/k>cok>c/`0;ok>c/`03o`000?o<c<coc<c<00Woc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo000[
ooooo`03o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c00:
olc<c003o`000?nc/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT04?nIVIT2o`0001_oOgmo0ol0001T
ofIVIPCo00006_moOgl2o`0001?oVIVI00?o0000ok>c/onc/k<03?nc/k<00ol0003oc<c<olc<c009
olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`02_o<c<`00ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI017oVIVI0_l0000Logmo
O`Co0000GOmVIVH3o`0001coOgmo0_l0000DoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<
c?o<c<`02_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP08onKViP03
o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0BoiVIV@;o
00007_moOgl3o`0005OoIVIV0ol0000MogmoO`;o00005OnIVIT00ol0003o/k>cok>c/`0=ok>c/`03
o`000?o<c<coc<c<00[oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00[ooooo00?o0000onKVi_oVi^H0
2?oVi^H00ol0003oc<c<olc<c00:olc<c003o`000?nc/k?o/k>c00ko/k>c00?o0000oiVIVOnIVIT0
4onIVIT2o`0001ooOgmo1_l0001<ofIVIPGo00007_moOgl2o`0001KoVIVI00?o0000ok>c/onc/k<0
3Onc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oV
i^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0>ok>c/`03o`000?nI
VIWoVIVI01CoVIVI0ol0000RogmoO`Oo0000?_mVIVH7o`00027oOgmo0_l0000GoiVIV@03o`000?nc
/k?o/k>c00ko/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool0
0ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<03onc/k<0
0ol0003oVIVIoiVIV@0FoiVIV@;o00009omoOgl7o`00033oIVIV1ol0000VogmoO`;o00006?nIVIT0
0ol0003o/k>cok>c/`0>ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo
00[ooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c00<olc<c003o`000?nc/k?o/k>c
00oo/k>c00?o0000oiVIVOnIVIT05onIVIT2o`0002coOgmo3_l0000DofIVIPko0000:omoOgl2o`00
01WoVIVI00?o0000ok>c/onc/k<03onc/k<00ol0003oc<c<olc<c00;olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool2o`0000_o
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c00;olc<c003o`000?nc/k?o/k>c013o
/k>c00?o0000oiVIVOnIVIT06?nIVIT2o`0003SoOgmo5?l0000gogmoO`;o00006_nIVIT00ol0003o
/k>cok>c/`0?ok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0:ooooo`;o00003?ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KV
onKViP09onKViP03o`000?o<c<coc<c<00_oc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVI
oiVIV@0IoiVIV@;o0000OomoOgl2o`0001_oVIVI00?o0000ok>c/onc/k<04?nc/k<00ol0003oc<c<
olc<c00;olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o
0000olc<c?o<c<`03?o<c<`00ol0003o/k>cok>c/`0Aok>c/`;o00006onIVIT3o`0007SoOgmo1?l0
000KoiVIV@;o00004_nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oVi^Koi^KV00Woi^KV00?o
0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0:
ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`03Oo<c<`00ol0003o/k>cok>c/`0B
ok>c/`03o`000?nIVIWoVIVI01_oVIVI1?l0001`ogmoO`Co00007OnIVIT2o`0001?o/k>c00?o0000
olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP0:onKV
iP03o`000?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<04_nc/k<2o`0001ooVIVI1Ol0001Wogmo
O`Co00007onIVIT2o`0001Co/k>c00?o0000olc<c?o<c<`03Oo<c<`00ol0003oi^KVonKViP0:onKV
iP03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooooooo
ool02oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc
/k<04onc/k<2o`0002;oVIVI1?l0001OogmoO`Co00008_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?o<c<coc<c<00koc<c<00?o0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00_ooooo00?o0000onKVi_oVi^H0
2_oVi^H00ol0003oc<c<olc<c00>olc<c003o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT0
8onIVIT4o`0005OoOgmo1?l0000ToiVIV@;o00005Onc/k<00ol0003oc<c<olc<c00>olc<c003o`00
0?oVi^Koi^KV00[oi^KV00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`03_o<
c<`00ol0003o/k>cok>c/`0Dok>c/`?o00009_nIVIT7o`0004WoOgmo1ol0000UoiVIV@?o00005_nc
/k<00ol0003oc<c<olc<c00>olc<c003o`000?oVi^Koi^KV00_oi^KV00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0<ooooo`03o`000?oVi^Ko
i^KV00_oi^KV00?o0000olc<c?o<c<`03_o<c<`00ol0003o/k>cok>c/`0Fok>c/`?o0000:_nIVIT;
o`0003?oOgmo2ol0000YoiVIV@?o00006?nc/k<00ol0003oc<c<olc<c00>olc<c003o`000?oVi^Ko
i^KV00coi^KV00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0
003oooooooooo`0<ooooo`03o`000?oVi^Koi^KV00coi^KV00?o0000olc<c?o<c<`03_o<c<`2o`00
01Wo/k>c1?l0000aoiVIVC?o0000<?nIVIT4o`0001Wo/k>c0_l0000@olc<c003o`000?oVi^Koi^KV
00coi^KV00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oVi^Koi^KV00goi^KV00?o0000olc<c?o<c<`03oo<c<`2o`0001_o
/k>c0ol0002>oiVIV@?o00006onc/k<2o`00017oc<c<00?o0000onKVi_oVi^H03OoVi^H00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00cooooo
00?o0000onKVi_oVi^H03_oVi^H00ol0003oc<c<olc<c00@olc<c0;o00007?nc/k<4o`0008KoVIVI
1?l0000Lok>c/`;o00004_o<c<`00ol0003oi^KVonKViP0>onKViP03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool03Oooool00ol0003oi^KVonKV
iP0>onKViP03o`000?o<c<coc<c<017oc<c<0_l0000Nok>c/`?o0000P?nIVIT3o`0001ko/k>c0_l0
000Colc<c003o`000?oVi^Koi^KV00ooi^KV00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00ooi^KV00?o0000
olc<c?o<c<`04_o<c<`2o`0001oo/k>c1_l0001eoiVIV@Go00007onc/k<2o`0001Coc<c<00?o0000
onKVi_oVi^H03ooVi^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[oooo
o`03o`000?oooooooooo00gooooo00?o0000onKVi_oVi^H04?oVi^H00ol0003oc<c<olc<c00Colc<
c0?o00008_nc/k<7o`0006OoVIVI1ol0000Qok>c/`?o00005Oo<c<`00ol0003oi^KVonKViP0@onKV
iP03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool002_ooooo0_l0000?ooooo`03
o`000?oVi^Koi^KV013oi^KV00?o0000olc<c?o<c<`05Oo<c<`2o`0002Oo/k>c1ol0001IoiVIV@Oo
00009_nc/k<2o`0001Ooc<c<00?o0000onKVi_oVi^H04OoVi^H00ol0003oooooooooo`0=ooooo`;o
00003?ooool002_ooooo00?o0000ooooooooool03_ooool00ol0003oi^KVonKViP0AonKViP03o`00
0?o<c<coc<c<01Koc<c<0_l0000/ok>c/`ko0000?_nIVIT=o`0002_o/k>c0_l0000Holc<c003o`00
0?oVi^Koi^KV01;oi^KV00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00:ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV01;oi^KV00?o0000olc<c?o<c<`05oo<
c<`2o`0003So/k>c5Ol0000DoiVIVAGo0000=_nc/k<2o`0001Woc<c<00?o0000onKVi_oVi^H04ooV
i^H00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooo
oooo00kooooo00?o0000onKVi_oVi^H04ooVi^H00ol0003oc<c<olc<c00Holc<c0;o0000Bonc/k<D
o`0004Wo/k>c0_l0000Jolc<c003o`000?oVi^Koi^KV01?oi^KV00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oVi^Koi^KV
01?oi^KV00?o0000olc<c?o<c<`06Oo<c<`5o`0009oo/k>c1?l0000Kolc<c003o`000?oVi^Koi^KV
01Coi^KV00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oVi^Koi^KV01Coi^KV00?o0000olc<c?o<c<`07Oo<c<`7o`00097o
/k>c1ol0000Nolc<c003o`000?oVi^Koi^KV01Goi^KV00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?oVi^Koi^KV01Goi^KV
00?o0000olc<c?o<c<`08oo<c<`7o`0008?o/k>c1ol0000Tolc<c003o`000?oVi^Koi^KV01Koi^KV
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oVi^Koi^KV01Goi^KV00?o0000olc<c?o<c<`0:Oo<c<`5o`0007So/k>c1_l0
000Zolc<c003o`000?oVi^Koi^KV01Koi^KV00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0:ooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`000?oVi^Koi^KV01Koi^KV0ol0000]
olc<c0_o0000Honc/k<:o`0002koc<c<0_l0000IonKViP03o`000?oooooooooo013ooooo00?o0000
ooooooooool02_ooool002_ooooo00?o0000ooooooooool04?ooool00ol0003oi^KVonKViP0IonKV
iP?o0000=Oo<c<`Co`0003ko/k>c4_l0000dolc<c0Co00006_oVi^H00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo017ooooo00?o0000onKVi_oV
i^H06ooVi^H4o`0004Coc<c<?_l00012olc<c0Co00007OoVi^H00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo01;ooooo00?o0000onKVi_oVi^H0
7_oVi^H5o`000;[oc<c<1Ol0000PonKViP03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool04oooool00ol0003oi^KVonKViP0RonKViPCo0000/_o<
c<`4o`0002Coi^KV00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oVi^Koi^KV02Goi^KV1?l0002Zolc<c0Co00009ooVi^H0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo000[ooooo`;o00005_ooool00ol0
003oi^KVonKViP0XonKViPOo0000W?o<c<`7o`0002[oi^KV00?o0000ooooooooool05Oooool2o`00
00cooooo000[ooooo`03o`000?oooooooooo01Kooooo00?o0000onKVi_oVi^H0;_oVi^H;o`0008Ko
c<c<2ol0000`onKViP03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool002_ooooo
00?o0000ooooooooool05oooool3o`0003Soi^KV4?l0001Wolc<c0oo0000>?oVi^H3o`0001[ooooo
00?o0000ooooooooool02_ooool002_ooooo00?o0000ooooooooool06_ooool4o`0004Coi^KVIol0
0013onKViPCo00007Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0N
ooooo`Go0000i?oVi^H5o`00027ooooo00?o0000ooooooooool02_ooool002_ooooo00?o0000oooo
ooooool08oooool4o`000=coi^KV1?l0000Vooooo`03o`000?oooooooooo00[ooooo000[ooooo`03
o`000?oooooooooo02Oooooo1?l0003DonKViPCo0000:_ooool00ol0003oooooooooo`0:ooooo`00
:oooool00ol0003oooooooooo`0[ooooo`Oo0000a_oVi^H7o`0002kooooo00?o0000ooooooooool0
2_ooool002_ooooo00?o0000ooooooooool0<_ooool;o`000;3oi^KV2ol0000eooooo`03o`000?oo
oooooooo00[ooooo000[ooooo`03o`000?oooooooooo03gooooo9Ol0001WonKViRCo0000@?ooool0
0ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`1RooooofOo0000I?ooool00ol0
003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`3oooooobkooooo00?o0000oooooooo
ool02_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`05ooooo`?o0000ooooool/ooooo`?o00003?ooool002?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooobkooooo00?o
0000ooooooooool02_ooool0027ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo000[ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool002_oooooool0000bo`0000cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003Booooo`05ob4Q8Ol0003o0000odA4A?oMgMd0C_ooool3o`00
0003oa0@4?oooooooooo03gooooo003Eooooo`03ogMgMolb<S;ooooo04oooooo00?o0000oooooooo
ool0?_ooool00=Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0nooooo`008ooo
ool3o`000003oa0@4?oooooooooo00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413ooooooooooonHV9P2o`000003odA4A?nj^[[ooooo00;o
oooo1Ol00002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool5o`0000Oooooo1Ol00002
ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooool@413o<S8b0_l000000ol@413oZJVY
ooooo`02ooooo`Go00000_ooool02_o^k^koEEEEo`000?l0003oV9RHo`000?l@413oooooonk^k_mE
EED2o`000003odA4A?nj^[[ooooo00Gooooo00KoV9RHo`000?l0003oMgMgoa0@4?l0000:ooooo`05
ofIVI_l0003o0000odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooo
V9RH00;o000000GoMgMgoa0@4?l0003ooooooa0@4005o`0000?ooooo00Kok^k^oeEEEOl0003o410@
olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1oooool00ol@413o0000o`000002
o`000004oa0@4?ooooooooooooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001Oooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000ogMgMol00003oooo
o`08oiRHV?l0003o0000ogMgMol0003o410@oooooonHV9P2o`000005ogMgMol@413o0000ooooool@
41001Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1oooool00ol@413o0000ohN7Q`02
o`000005ofIVI_o^k^koooooonk^k_mEEED00_l000001?mEEEGok^k^ooooooooool2o`0000;ooooo
0_l00003ooooo`009?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOooooooooooomgMgOo
EEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oZJVYoooooooooooo^[Zjo`0000Gooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMg
ooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4106ooooo`05o`000?o<
c<cok^k^ohN7Qol000002_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003ooooooooo
o`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00006ooooo`06o`000?nYZJWooooooooooonj^[[o00000_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002oooo
o`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@2?ooool02Ol0003oEEEEonk^k_ooooooMgMgofIVI_ooooooEEEEogMgM`02
ooooo`0:ogMgMomEEEGoooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo000Tooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`05oa0@4?n7QhOoooooonk^k_l000001Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05okZj^_n7QhOoIVIVofIVI_l@41001Oooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`09ooooo`05oa0@4?n7QhOo
ooooonk^k_l000002_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooooooooook^k^o`0000;ooooo00?o0000ooooooooool00_ooool6o`0000Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`06o`000?ooooooooooooooooo^k^ko0000
1oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00Ko0000ooooooooooooooooonk^k_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooool000001?ooool02?l0003ooooooooooooooooogMgMo`000?l@413oc<c<1?ooool0
02Cooooo0ol000001OlQ8B7oc<c<oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o00001Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^1Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooooooooo^k^ko00000_ooool6o`0000Kooooo00?o^[Zjoa0@4?l000000_l0000:ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj^_l@413o000000;o
00001?ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6
o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Ko0000ooooooooooooooooonk^
k_l00006ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool01_l0003ooooooooooooooooo
k^k^o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj^_l@413o000000;o0000
1?ooool00ol0003oooooooooo`04ooooo`Ko00002?ooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooo000000Cooooo00So0000ooooooooooooooooonk^k_lQ8B7o410@onk^kPCooooo000Toooo
o`05o`000?ooooooooooohN7Qol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo
00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7
QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
1Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005ooooo`03
o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b2Oooool00oo<c<co0000ooooo`09ooooo`06ofIVI_mgMgOooooooooooon7
QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?oc<c<o`000?ooool00oooool0
0ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<PWooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<P;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00006ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01?ooool01_mEEEGo
QhN7onk^k_ooooooQhN7oc8b<PSooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGooooooeEEEOmg
MgL00_ooool00omgMgOoEEEEooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PCooooo000Tooooo`05
o`000?ooooooooooooooool000000_ooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@
1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooo410@00Go00001?ooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o0000
oiRHV0Gooooo00?o0000ooooooooool01oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooooZJVYob4Q8@02o`000003oc8b<_l0003ooooo00;ooooo00?o
410@o`000?l000001?ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0
003o0000odA4A?o^k^h7ooooo`04oc8b<_l0003o0000oiRHV0[ooooo00Kok^k^ofIVI_l0003o0000
odA4A?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00oooool01?lb<S;o0000o`000?nHV9P3
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02_o^k^koEEEEo`000?lQ8B7oZJVYo`000?l@
413oooooonk^k_mEEED2o`000003odA4A?o^k^kooooo00Kooooo00?o410@o`000?l000000ol00003
ooooo`03oa0@4?l0003o000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`00
00Kooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`0:onk^k_mEEEGo0000o`000?mgMgOo
0000oa0@4?oooooo410@o`0000;ooooo0_l00003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^2?ooool02Ol0
003oc<c<oa0@4?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`000004oeEEEOo^k^koooooooooo`;o
00000_ooool2o`0000?ooooo000Tooooo`05o`000?ooooooooooohN7Qol@41002oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Eooooo`008oooool4o`000003ob4Q8Oo<c<cooooo00[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0[ooooo`03oa0@4?nj^[[ooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Eooooo`00E_ooool00ol@413oooooooooo`0:ooooo`03oa0@4?l0
003o000000_ooooo00?o410@ooooooooool05Oooool00ol@413oooooooooo`06ooooo`;o00009Ooo
ool00ol@413o0000ooooo`0/ooooo`04okZj^_l@413o0000oa0@40Gooooo00?o410@ooooooooool0
0_ooool00ol@413o0000o`000005ooooo`03oa0@4?l0003o0000017ooooo0_l0000kooooo`03oa0@
4?l0003ooooo01Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.167753, -0.133128, \
0.00427501, 0.00427501}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonrectangular Boundaries", "Section",
  CellTags->{"i:31", "c:24"}],

Cell["\<\
The same direct method of solution can be used for Poisson's \
equation in domains with nonrectangular boundaries. We will assume for now \
that the boundary can be matched to some rectangular grid, so that grid \
points fall on the boundary. The grid is chosen as\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{\(x\_o\), "+", " ", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = f(k), f(k) + 1,  ... , g(k)\)]],
  ",\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{\(y\_o\), "+", 
            RowBox[{"k", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "NE2",
  CellTags->"(6.2.35)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}], 
        TraditionalForm]]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`f(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " are two integer functions that determine the left and right edges of the \
domain respectively; and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  " are the dimensions of a rectangular box that is sufficiently large to \
contain the domain of interest. ( This procedure does not work very well for \
smoothly curved boundaries, as we will see. )"
}], "Text"],

Cell[TextData[{
  "\tThe equations for the interior points are the same as Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j + 1\ k\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j - 1\ k\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "+", 
            FractionBox[
              
              FormBox[\(\[Phi]\_\(j\ k + 1\) - 
                  2\ \[Phi]\_\(j\ k\) + \ \[Phi]\_\(j\ k - 1\)\),
                "TraditionalForm"], 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "2"]]}], 
          "=", \(\[Rho]\_\(j\ k\)\)}], TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`j = f(k) + 1, \(\(...\)\(\ \)\(g(k)\)\) - 
        1, \[IndentingNewLine]k = 1, 2,  ... , M\_y\  - 1. \)]]
}], "NE2",
  CellTags->"(6.2.36)"],

Cell[TextData[{
  "These equations for the potential in the interior of the box are \
supplemented by the boundary conditions on the box edges, which directly \
determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " on the boundary points."
}], "Text"],

Cell[TextData[{
  "\tWe again solve this problem directly using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This time we choose a Laplace equation problem, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ", with boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "=", 
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " on the domain boundary."
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 30; \ M\_y = 30;\), "\n", 
    \(L\_x = \ 2; \ L\_y = \ 2;\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = L\_y/M\_y;\), "\n", 
    \(x0\  = \ \(-1\); \ y0 = \(-1\);\), "\n", 
    \(\(x[j_]\  = \ x0\  + \ j\ \[CapitalDelta]x;\)\), "\n", 
    \(\(y[k_]\  = y0\  + \ k\ \[CapitalDelta]y;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.94"],

Cell["\<\
The boundary conditions are specified by the following statements: \
\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ boundary\ conditions\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      " ", \(\(\[Phi][j_, k_]\  := \ \ V0[j, k] /; \ 
            j \[LessEqual] \ f[k];\)\[IndentingNewLine]
      \(\[Phi][j_, k_]\  := \ 
          V0[j, k]\  /; \ j \[GreaterEqual] \ g[k];\)\[IndentingNewLine]
      \(\[Phi][j_, 0]\  := \ V0[j, 0];\)\[IndentingNewLine]
      \(\[Phi][j_, M\_y]\  := \ V0[j, M\_y];\)\)}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.95"],

Cell[TextData[{
  "\tLet's choose the following equations for the boundaries : ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2 = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \(-\(\(|\)\(y\)\(|\)\)\)\)]],
  ". This boundary, shown in Cell ",
  ButtonBox["6.99",
    ButtonData:>"Cell 6.99",
    ButtonStyle->"Hyperlink"],
  ",  is the same as that chosen in Example 3 of Sec. ",
  ButtonBox["6.1",
    ButtonData:>"c:8",
    ButtonStyle->"Hyperlink"],
  ", except that it is rotated by 90 degrees. "
}], "Text"],

Cell[TextData[{
  "We choose boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[\(1\  - \ r\^2\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " on the cusp surfaces, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " on the circular part of the boundary:"
}], "Text"],

Cell[BoxData[{
    \(\(V0[j_, k_]\  := \ 
        0\  /; \ \ Abs[y[k]] \[GreaterEqual] \ 1/Sqrt[2]\  || \ 
            x[j] > \ 0;\)\), "\n", 
    \(V0[j_, k_]\  := \ 
      1\  - \ x[j]^2\  - \ y[j]^2\  /; \ 
        Abs[\ y[k]]\  < \ 1/Sqrt[2]\  && \ x[j] \[LessEqual] \ 0\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.96"],

Cell[TextData[{
  "\tTo determine the integer functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(k)\)\ and\ \(g(k)\)\)]],
  " that best fit this boundary, we will first break the boundary up into \
left and right boundaries, ",
  Cell[BoxData[
      \(TraditionalForm\`x(y)\  = \ \(x\_R\)(y)\)]],
  " on the right and ",
  Cell[BoxData[
      \(TraditionalForm\`x(y) = \(x\_L\)(y)\)]],
  " on the left. For our example, equations for the left and right boundaries \
are of the following form:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_R\)(
          y)\  = \@\(1 - y\^2\)\)\(\ \)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(
          y)\  = \ \(-\@\(1 - y\^2\)\), \ \(\(|\)\(y\)\(|\)\(\(>\)\(1/\@\(\(2\
\)\(,\)\)\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(
          y) = \(-\(\(|\)\(y\)\(|\)\)\), \ \(\(|\)\(y\)\(|\)\(\(<\)\(\ \
\)\(\(1/\@2. \)\(\ \)\)\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "Then the integer functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " are determined by the values of ",
  Cell[BoxData[
      \(TraditionalForm\`j(k)\)]],
  " corresponding to these boundary equations. Using ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(j)\), " ", "=", " ", 
          RowBox[{
            RowBox[{\(x\_o\), " ", "+", " ", 
              RowBox[{"j", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]}], 
            "=", \(\(x\_R\)(y(k))\)}]}], TraditionalForm]]],
  "on the right boundary yields ",
  Cell[BoxData[
      FormBox[
        RowBox[{"j", "=", " ", 
          RowBox[{\((\(x\_R\)(y(k)) - x\_o)\), "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". Rounding down to the nearest integer we obtain the value of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " corresponding to the right boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`y = y(k)\)]],
  ". This is our function ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(k)\), "=", 
          RowBox[{"Floor", "(", 
            FractionBox[\(\(x\_R\)(y(k)) - x\_o\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]], ")"}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.37)"],

Cell[" Similarly, on the left boundary,   ", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(k)\), "=", 
          RowBox[{
            RowBox[{"Floor", "(", 
              FractionBox[\(\(x\_L\)(y(k)) - x\_o\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], ")"}], "."}]}], 
        TraditionalForm]]]
}], "NE2",
  CellTags->"(6.2.38)"],

Cell[TextData[{
  " These integer functions are defined below using the above definitions of \
",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_L\)(y)\)]],
  ":\t"
}], "Text"],

Cell[BoxData[{
    \(\(g[k_]\  := 
        Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  + \ 
                Sqrt[1\  - \ y[k]^2])\)\ ];\)\), "\n", 
    \(\(f[k_]\  := \ 
        Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  - \ 
                  Sqrt[1\  - \ y[k]^2]\ )\)] /; \ 
          Abs[y[k]\ ] > \ 1/Sqrt[2];\)\), "\n", 
    \(f[k_]\  := 
      Floor[\(1\/\[CapitalDelta]x\) \((\(-x0\)\  - 
                Abs[y[k]])\)]\  /; \ \ Abs[\ y[k]]\  \[LessEqual] \ \ 1/
            Sqrt[2]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.97"],

Cell[TextData[{
  "The shape of this domain is shown in Cell ",
  ButtonBox["6.98",
    ButtonData:>"Cell 6.98",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
        Join[Table[{x[f[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[g[k]], \ y[k]}, {k, 0, 
              M\_y}]], \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(-1.2\), \(-1.2\)}, 
        PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.98"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -12 -9 ]
[.29167 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -9 -9 ]
[.70833 -0.0125 9 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .29167 -24 -4.5 ]
[-0.0125 .29167 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .70833 -18 -4.5 ]
[-0.0125 .70833 0 4.5 ]
[-0.0125 .91667 -6 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-1)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-0.5)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(0.5)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(-1)] -0.0125 .08333 1 0 Mshowa
0 .29167 m
.00625 .29167 L
s
[(-0.5)] -0.0125 .29167 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .70833 m
.00625 .70833 L
s
[(0.5)] -0.0125 .70833 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(1)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .125 m
.00375 .125 L
s
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .33333 m
.00375 .33333 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .54167 m
.00375 .54167 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .75 m
.00375 .75 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .04167 m
.00375 .04167 L
s
0 .95833 m
.00375 .95833 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.5 .08333 Mdot
.33333 .11111 Mdot
.27778 .13889 Mdot
.25 .16667 Mdot
.19444 .19444 Mdot
.22222 .22222 Mdot
.25 .25 Mdot
.27778 .27778 Mdot
.30556 .30556 Mdot
.33333 .33333 Mdot
.36111 .36111 Mdot
.38889 .38889 Mdot
.41667 .41667 Mdot
.44444 .44444 Mdot
.47222 .47222 Mdot
.5 .5 Mdot
.47222 .52778 Mdot
.44444 .55556 Mdot
.41667 .58333 Mdot
.38889 .61111 Mdot
.36111 .63889 Mdot
.33333 .66667 Mdot
.30556 .69444 Mdot
.27778 .72222 Mdot
.25 .75 Mdot
.22222 .77778 Mdot
.19444 .80556 Mdot
.25 .83333 Mdot
.27778 .86111 Mdot
.33333 .88889 Mdot
.5 .91667 Mdot
.5 .08333 Mdot
.63889 .11111 Mdot
.69444 .13889 Mdot
.75 .16667 Mdot
.77778 .19444 Mdot
.80556 .22222 Mdot
.83333 .25 Mdot
.83333 .27778 Mdot
.86111 .30556 Mdot
.86111 .33333 Mdot
.88889 .36111 Mdot
.88889 .38889 Mdot
.88889 .41667 Mdot
.88889 .44444 Mdot
.88889 .47222 Mdot
.91667 .5 Mdot
.88889 .52778 Mdot
.88889 .55556 Mdot
.88889 .58333 Mdot
.88889 .61111 Mdot
.88889 .63889 Mdot
.86111 .66667 Mdot
.86111 .69444 Mdot
.83333 .72222 Mdot
.83333 .75 Mdot
.80556 .77778 Mdot
.77778 .80556 Mdot
.75 .83333 Mdot
.69444 .86111 Mdot
.63889 .88889 Mdot
.5 .91667 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00?oooool4o`000003oa0@4?oooooooooo03?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0fooooo`Co000000?o410@ooooooooool06?ooool0047ooooo
00?o0000ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo037ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0gooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0=oooool00ol0003oooooooooo`0J
ooooo`00=_ooool6o`0000Gooooo00?o0000ooooooooool0;Oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo033ooooo00Go410@oooooooooooooooooa0@
400gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01[ooooo0011ooooo`03o`000?oooooooooo03Gooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo037ooooo00Go0000ooooooooooooooooo`00000gooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0gooooo`03o`000?oooooooooo
01[ooooo0011ooooo`03o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0<_ooool01Ol0003ooooooooooooooooo000003Oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0>?ooool00ol0003o
ooooooooo`0Jooooo`00@Oooool00ol0003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0dooooo`05oa0@4?ooooooooooooooool@4100=oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0J
ooooo`00@Oooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0dooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Jooooo`00?ooo
ool00omEEEGoIVIVo`00000gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
03Oooooo00?oEEEEofIVI_l000007?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool002;oooooool00017o`0000008_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool002;ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01[ooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`00
0?ooooooAOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`006?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom4ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?ooooooA?ooool000oooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0
002Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2N
ooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
odCooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4ooooo`00
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo06Sooooo0_l0001Qooooo`;o0000
M_ooool002;ooooo00?o0000ooooooooool0J?ooool2o`00067ooooo0_l0001fooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`000?ooooooAOooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Roooo
o`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0E_ooool2o`0008Go
oooo0_l0001Tooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000QOooool2o`0006Cooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oo
ooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0001>oooo
o`;o0000XOooool2o`00057ooooo000Rooooo`03o`000?oooooooooo04gooooo0_l0002Qooooo`;o
0000DOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooo
ooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`0kooooo`;o0000_?ooool2o`0004Sooooo000Rooooo`03o`000?oooooooooo
03_ooooo0_l0002looooo`;o0000B?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`00
8_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?oo
ool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo04Cooooo0_l0002looooo`;o0000?oooool002;ooooo00?o0000
ooooooooool0A?ooool2o`000;cooooo0_l0000oooooo`008_ooool00ol0003oooooooooo`3ooooo
odCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0
oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`;o0000C_ooool2o`000;cooooo0_l0000fooooo`008_oo
ool00ol0003oooooooooo`1=ooooo`;o0000_?ooool2o`0003Kooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Roooo
o`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0E_ooool2o`000;?o
oooo0_l0000fooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000/oooool2o`0003Kooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0?ooooooA?ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0?oo
ooooA?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooom4ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0?ooooooA?ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooom4ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0Goooool2o`00
0;?ooooo0_l0000]ooooo`008_ooool00ol0003oooooooooo`1Oooooo`;o0000/oooool2o`0002go
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0001Y
ooooo`;o0000Z_ooool2o`0002gooooo000Rooooo`03o`000?oooooooooo06Sooooo0_l0002Zoooo
o`;o0000;Oooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`1aooooo`;o0000Z_ooool2o`0002Cooooo000Rooooo`03o`000?oooooo
oooo077ooooo0_l0002Zooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo07[ooooo0_l0002Qooooo`;o00009?ooool002;ooooo00?o
0000ooooooooool0N_ooool2o`000:7ooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo08?ooooo0_l0002Hooooo`;o
00009?ooool002;ooooo0_l00024ooooo`;o0000V?ooool2o`0002Cooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0S?ooool2o`00
08oooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`2<ooooo`;o0000Soooool2o`0002Co
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`;o0000oooooom5oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`2E
ooooo`;o0000Q_ooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo09Gooooo0_l00026oooo
o`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodCooooo000Gooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2Nooooo`;o0000Q_ooool2o`00
01_ooooo000Gooooo`05o`000?ooooooooooooooool000001_ooool3o`0009kooooo0_l00026oooo
o`;o00006oooool001Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
0?ooooooA?ooool001Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0UOooool2o`0008Kooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`2Eoooo
o`;o0000Q_ooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`;o0000oooooom5ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`2<ooooo`;o0000Soooool2o`0002Cooooo000Rooooo`03o`000?oooooo
oooo08cooooo0_l0002?ooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`23ooooo`;o0000V?ooool2o`0002Cooooo
000Rooooo`;o0000Q?ooool2o`0009Sooooo0_l0000Tooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0N_ooool2o`000:7ooooo0_l0000Tooooo`008_ooool00ol0003ooooooooo
o`1jooooo`;o0000XOooool2o`0002Cooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`000?ooooooAOooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`1aooooo`;o0000Z_ooool2o`0002Cooooo000Rooooo`03o`00
0?oooooooooo077ooooo0_l0002Zooooo`;o00009?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool2o`0006Wooooo0_l0002Zooooo`;o0000;Oooool002;o
oooo00?o0000ooooooooool0J?ooool2o`000:[ooooo0_l0000]ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo05oooooo0_l0002c
ooooo`;o0000;Oooool002;ooooo00?o0000ooooooooool0Goooool2o`000;?ooooo0_l0000]oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3o
ooooodCooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`?o0000oooooom4ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooo
oom4ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3oooooodCooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?ooooooA?ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Fooooo`;o0000/ooo
ool2o`0003Kooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l0002cooooo`;o0000=_ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooo
oom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool2o`0004kooooo
0_l0002looooo`;o0000=_ooool002;ooooo00?o0000ooooooooool0COooool2o`000;cooooo0_l0
000fooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000
ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03
o`000?oooooooooo04Cooooo0_l0002looooo`;o0000?oooool002;ooooo00?o0000ooooooooool0
A?ooool2o`000;cooooo0_l0000oooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0003oooooodGooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_oo
ool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool0
02;ooooo00?o0000ooooooooool0>oooool2o`000;cooooo0_l00018ooooo`008_ooool00ol0003o
ooooooooo`0kooooo`;o0000_?ooool2o`0004Sooooo000Rooooo`03o`000?oooooooooo0?oooooo
A?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo0_l0001>ooooo`;o0000XOooool2o`00057ooooo000Roooo
o`03o`000?oooooooooo04gooooo0_l0002Qooooo`;o0000DOooool002;ooooo00?o0000oooooooo
ool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oo
oooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0
003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo
00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`1Fooooo`;o0000QOoo
ool2o`0006Cooooo000Rooooo`03o`000?oooooooooo05Kooooo0_l00025ooooo`;o0000I?ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCo
oooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0003oooooodGooooo000R
ooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4oooo
o`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo06Sooooo
0_l0001Qooooo`;o0000M_ooool002;ooooo00?o0000ooooooooool0J?ooool2o`00067ooooo0_l0
001fooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo
0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooo
ooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3oooooodCooooo000Jooooo`03o`000?oooooooooo00Go
oooo0ol0002Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Nooooo`;o0000Xoooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooodCooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4
ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001So
oooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool2o`000?ooooooAOooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`00
8_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?oo
ool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3ooooo
odCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0
oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o
0000ooooooooool0oooooom4ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.45159, -1.38235, 0.00923261, \
0.00923261}}]
}, Open  ]],

Cell[TextData[{
  "The irregularities in the boundary reflect the difficulty of fitting a \
rectangular grid to a curved boundary. They can be reduced by using a finer \
grid, but this increases the number of coupled equations that we need to \
solve.  They can also be reduced by employing an averaging technique, \
determining the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the boundary as a weighted average of surrounding grid points. (See \
the exercises for an implementation of this technique.)  Alternatively, a \
nonrectangular grid can be chosen that better matches the edge(s). However, \
this is rather nontrivial, and will not be pursued further here.  An \
excellent introduction to irregular grids, finite element analysis, and the \
like, can be found on the ",
  ButtonBox["web",
    ButtonData:>{
      URL[ "http://www.esc.auckland.ac.nz/Academic/Texts/FEM-BEM-notes.html"],
       None},
    ButtonStyle->"Hyperlink"],
  " in a set of  course notes by Peter Hunter and  Andrew Pullan (2002). A \
recent textbook on the subject is also listed in the references."
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tHere we will make do with the coarse fit obtained above.  Since we may \
be off by as much as a grid spacing ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in the boundary location, we can only expect our solution to be \
first-order accurate in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". However, for distances from the boundary much greater than ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ",  the effect of the irregularities in the boundary often average out, and \
the solution can be more accurate than this estimate suggests. "
}], "Text"],

Cell[TextData[{
  "\tContinuing with our example, we take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  " for the source, "
}], "Text"],

Cell[BoxData[
    \(\(\[Rho][j_, k_]\  = \ 0. ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.99"],

Cell[TextData[{
  "Then the  list of equations, using Eq. ",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  " for the interior points, is given by"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"eqns", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{"Table", "[", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      FractionBox[
                        FormBox[
                          RowBox[{
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], "+", "1"}], ",", 
                                StyleBox["k",
                                  FontSlant->"Plain"]}], "]"}], "-", 
                            RowBox[{"2", " ", 
                              RowBox[{"\[Phi]", "[", 
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], ",", 
                                  StyleBox["k",
                                    FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                            
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], "-", "1"}], ",", 
                                StyleBox["k",
                                  FontSlant->"Plain"]}], "]"}]}],
                          "TraditionalForm"], \(\[CapitalDelta]x\^2\)], "+", 
                      FractionBox[
                        FormBox[
                          RowBox[{
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                StyleBox["j",
                                  FontSlant->"Plain"], ",", 
                                RowBox[{
                                  StyleBox["k",
                                    FontSlant->"Plain"], "+", "1"}]}], "]"}], 
                            "-", 
                            RowBox[{"2", " ", 
                              RowBox[{"\[Phi]", "[", 
                                RowBox[{
                                  StyleBox["j",
                                    FontSlant->"Plain"], ",", 
                                  StyleBox["k",
                                    FontSlant->"Plain"]}], "]"}]}], "+", " ", 
                            
                            RowBox[{"\[Phi]", "[", 
                              RowBox[{
                                StyleBox["j",
                                  FontSlant->"Plain"], ",", 
                                RowBox[{
                                  StyleBox["k",
                                    FontSlant->"Plain"], "-", "1"}]}], 
                              "]"}]}],
                          "TraditionalForm"], \(\[CapitalDelta]y\^2\)]}], 
                    "\[Equal]", \(\[Rho][j, k]\)}], 
                  ",", \({j, f[k] + 1, g[k] - 1}\)}], "]"}], 
              ",", \({k, 1, M\_y - 1}\)}], "]"}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.100"],

Cell["and the list of variables is", "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[
            Table[\[Phi][j, k], {j, f[k] + 1, g[k] - 1}], {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.101"],

Cell["Finally, we solve the equations:", "Text"],

Cell[BoxData[
    \(\(sol\  = \ \(Solve[eqns, vars]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.102"],

Cell["\<\
We can again construct an interpolation function of the solution:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{x[j], y[k], \[Phi][j, k]}, {j, 0, M\_x}, {k, 0, 
                M\_y}] /. sol, 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.103"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-1.`\), 1.`}, {\(-1.`\), 1.`}}, 
        "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.105",
    ButtonData:>"Cell 6.105",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(<< Calculus`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.104"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y] 
          Boole[1\  - \ x^2\  - \ y^2\  \[GreaterEqual] \ 0\  && \ 
              x\  \[GreaterEqual] \ \(-Abs[y]\)], {x, \(-1\), 
          1. }, {y, \(-1\), 1}, FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<\[Phi](x,y)\>", 
        PlotPoints \[Rule] 60];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.105"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -36 -5 ]
[-0.01875 .5 -24 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -20 0 ]
[.5 1.0125 20 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(-1)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.5)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -96 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.36147 .06578 m
.37777 .06307 L
.39407 .06126 L
.41037 .06028 L
.42666 .05986 L
.44296 .05988 L
.45926 .06027 L
.47555 .06098 L
.49185 .06202 L
.50815 .06337 L
.52445 .0651 L
.54074 .06725 L
.54644 .06812 L
.55704 .06994 L
.57334 .0733 L
.58963 .07755 L
.60593 .08286 L
.61016 .08442 L
.62223 .08929 L
.63853 .09674 L
.64659 .10072 L
.65482 .10485 L
.67112 .11337 L
.6777 .11701 L
.68742 .12267 L
.70372 .13292 L
.7043 .13331 L
.72001 .14398 L
.72786 .14961 L
.73631 .15601 L
.74833 .16591 L
.75261 .16967 L
.7659 .1822 L
.7689 .18521 L
.78148 .1985 L
.7852 .20267 L
.79543 .2148 L
.8015 .22256 L
.80777 .2311 L
.8178 .24605 L
.81866 .24739 L
.82865 .26369 L
.83409 .27324 L
.8378 .27999 L
.84612 .29628 L
.85039 .30529 L
.85372 .31258 L
.86079 .32888 L
.86669 .34384 L
.86718 .34518 L
.87275 .36147 L
.8774 .37777 L
.88113 .39407 L
.88299 .40385 L
.88407 .41037 L
.88638 .42666 L
.88817 .44296 L
.88955 .45926 L
.8906 .47555 L
.89127 .49185 L
.89127 .50815 L
.8906 .52445 L
.88955 .54074 L
.88817 .55704 L
.88638 .57334 L
.88407 .58963 L
.88299 .59615 L
.88113 .60593 L
.8774 .62223 L
.87275 .63853 L
.86718 .65482 L
.86669 .65616 L
.86079 .67112 L
.85372 .68742 L
.85039 .69471 L
.84612 .70372 L
.8378 .72001 L
.83409 .72676 L
.82865 .73631 L
.81866 .75261 L
.8178 .75395 L
.80777 .7689 L
.8015 .77744 L
.79543 .7852 L
.7852 .79733 L
.78148 .8015 L
.7689 .81479 L
.7659 .8178 L
.75261 .83033 L
.74833 .83409 L
.73631 .84399 L
.72786 .85039 L
.72001 .85602 L
.7043 .86669 L
.70372 .86708 L
.68742 .87733 L
.6777 .88299 L
.67112 .88663 L
.65482 .89515 L
.64659 .89928 L
.63853 .90326 L
.62223 .91071 L
.61016 .91558 L
.60593 .91714 L
.58963 .92245 L
.57334 .9267 L
.55704 .93006 L
.54644 .93188 L
.54074 .93275 L
.52445 .9349 L
.50815 .93663 L
.49185 .93798 L
.47555 .93902 L
.45926 .93973 L
.44296 .94012 L
.42666 .94014 L
.41037 .93972 L
.39407 .93874 L
.37777 .93693 L
.36147 .93422 L
.35231 .93188 L
.34518 .92967 L
.32888 .92317 L
.31258 .91739 L
.30663 .91558 L
.29628 .91207 L
.27999 .90522 L
.27083 .89928 L
.26369 .89454 L
.24739 .88462 L
.24514 .88299 L
.2311 .87205 L
.22402 .86669 L
.2148 .86222 L
.1985 .85596 L
.18484 .85039 L
.1822 .84847 L
.17263 .83409 L
.17473 .8178 L
.1822 .80978 L
.18778 .8015 L
.1985 .79046 L
.20238 .7852 L
.2148 .77264 L
.21799 .7689 L
.2311 .75569 L
.23371 .75261 L
.24739 .73886 L
.24971 .73631 L
.26369 .72228 L
.26572 .72001 L
.27999 .70572 L
.28186 .70372 L
.29628 .68926 L
.29799 .68742 L
.31258 .67281 L
.31419 .67112 L
.32888 .65642 L
.33039 .65482 L
.34518 .64002 L
.34662 .63853 L
.36147 .62366 L
.36285 .62223 L
.37777 .6073 L
.3791 .60593 L
.39407 .59096 L
.39536 .58963 L
.41037 .57462 L
.41163 .57334 L
.42666 .5583 L
.4279 .55704 L
.44296 .54197 L
.44418 .54074 L
.45926 .52566 L
.46046 .52445 L
.47555 .50935 L
.47674 .50815 L
.47674 .49185 L
.47555 .49065 L
.46046 .47555 L
.45926 .47434 L
.44418 .45926 L
.44296 .45803 L
.4279 .44296 L
.42666 .4417 L
.41163 .42666 L
.41037 .42538 L
.39536 .41037 L
.39407 .40904 L
.3791 .39407 L
.37777 .3927 L
.36285 .37777 L
.36147 .37634 L
.34662 .36147 L
.34518 .35998 L
.33039 .34518 L
.32888 .34358 L
.31419 .32888 L
.31258 .32719 L
.29799 .31258 L
.29628 .31074 L
.28186 .29628 L
.27999 .29428 L
.26572 .27999 L
.26369 .27772 L
.24971 .26369 L
.24739 .26114 L
.23371 .24739 L
.2311 .24431 L
.21799 .2311 L
.2148 .22736 L
.20238 .2148 L
.1985 .20954 L
.18778 .1985 L
.1822 .19022 L
.17473 .1822 L
.17263 .16591 L
.1822 .15153 L
.18484 .14961 L
.1985 .14404 L
.2148 .13778 L
.22402 .13331 L
.2311 .12795 L
.24514 .11701 L
.24739 .11538 L
.26369 .10546 L
.27083 .10072 L
.27999 .09478 L
.29628 .08793 L
.30663 .08442 L
.31258 .08261 L
.32888 .07683 L
.34518 .07033 L
.35231 .06812 L
F
0 g
.36147 .06578 m
.37777 .06307 L
.39407 .06126 L
.41037 .06028 L
.42666 .05986 L
.44296 .05988 L
.45926 .06027 L
.47555 .06098 L
.49185 .06202 L
.50815 .06337 L
.52445 .0651 L
.54074 .06725 L
.54644 .06812 L
.55704 .06994 L
.57334 .0733 L
.58963 .07755 L
.60593 .08286 L
.61016 .08442 L
.62223 .08929 L
.63853 .09674 L
.64659 .10072 L
.65482 .10485 L
.67112 .11337 L
.6777 .11701 L
.68742 .12267 L
.70372 .13292 L
.7043 .13331 L
.72001 .14398 L
.72786 .14961 L
.73631 .15601 L
.74833 .16591 L
.75261 .16967 L
.7659 .1822 L
.7689 .18521 L
.78148 .1985 L
.7852 .20267 L
.79543 .2148 L
.8015 .22256 L
.80777 .2311 L
.8178 .24605 L
.81866 .24739 L
.82865 .26369 L
.83409 .27324 L
.8378 .27999 L
.84612 .29628 L
.85039 .30529 L
.85372 .31258 L
.86079 .32888 L
.86669 .34384 L
.86718 .34518 L
Mistroke
.87275 .36147 L
.8774 .37777 L
.88113 .39407 L
.88299 .40385 L
.88407 .41037 L
.88638 .42666 L
.88817 .44296 L
.88955 .45926 L
.8906 .47555 L
.89127 .49185 L
.89127 .50815 L
.8906 .52445 L
.88955 .54074 L
.88817 .55704 L
.88638 .57334 L
.88407 .58963 L
.88299 .59615 L
.88113 .60593 L
.8774 .62223 L
.87275 .63853 L
.86718 .65482 L
.86669 .65616 L
.86079 .67112 L
.85372 .68742 L
.85039 .69471 L
.84612 .70372 L
.8378 .72001 L
.83409 .72676 L
.82865 .73631 L
.81866 .75261 L
.8178 .75395 L
.80777 .7689 L
.8015 .77744 L
.79543 .7852 L
.7852 .79733 L
.78148 .8015 L
.7689 .81479 L
.7659 .8178 L
.75261 .83033 L
.74833 .83409 L
.73631 .84399 L
.72786 .85039 L
.72001 .85602 L
.7043 .86669 L
.70372 .86708 L
.68742 .87733 L
.6777 .88299 L
.67112 .88663 L
.65482 .89515 L
.64659 .89928 L
Mistroke
.63853 .90326 L
.62223 .91071 L
.61016 .91558 L
.60593 .91714 L
.58963 .92245 L
.57334 .9267 L
.55704 .93006 L
.54644 .93188 L
.54074 .93275 L
.52445 .9349 L
.50815 .93663 L
.49185 .93798 L
.47555 .93902 L
.45926 .93973 L
.44296 .94012 L
.42666 .94014 L
.41037 .93972 L
.39407 .93874 L
.37777 .93693 L
.36147 .93422 L
.35231 .93188 L
.34518 .92967 L
.32888 .92317 L
.31258 .91739 L
.30663 .91558 L
.29628 .91207 L
.27999 .90522 L
.27083 .89928 L
.26369 .89454 L
.24739 .88462 L
.24514 .88299 L
.2311 .87205 L
.22402 .86669 L
.2148 .86222 L
.1985 .85596 L
.18484 .85039 L
.1822 .84847 L
.17263 .83409 L
.17473 .8178 L
.1822 .80978 L
.18778 .8015 L
.1985 .79046 L
.20238 .7852 L
.2148 .77264 L
.21799 .7689 L
.2311 .75569 L
.23371 .75261 L
.24739 .73886 L
.24971 .73631 L
.26369 .72228 L
Mistroke
.26572 .72001 L
.27999 .70572 L
.28186 .70372 L
.29628 .68926 L
.29799 .68742 L
.31258 .67281 L
.31419 .67112 L
.32888 .65642 L
.33039 .65482 L
.34518 .64002 L
.34662 .63853 L
.36147 .62366 L
.36285 .62223 L
.37777 .6073 L
.3791 .60593 L
.39407 .59096 L
.39536 .58963 L
.41037 .57462 L
.41163 .57334 L
.42666 .5583 L
.4279 .55704 L
.44296 .54197 L
.44418 .54074 L
.45926 .52566 L
.46046 .52445 L
.47555 .50935 L
.47674 .50815 L
.47674 .49185 L
.47555 .49065 L
.46046 .47555 L
.45926 .47434 L
.44418 .45926 L
.44296 .45803 L
.4279 .44296 L
.42666 .4417 L
.41163 .42666 L
.41037 .42538 L
.39536 .41037 L
.39407 .40904 L
.3791 .39407 L
.37777 .3927 L
.36285 .37777 L
.36147 .37634 L
.34662 .36147 L
.34518 .35998 L
.33039 .34518 L
.32888 .34358 L
.31419 .32888 L
.31258 .32719 L
.29799 .31258 L
Mistroke
.29628 .31074 L
.28186 .29628 L
.27999 .29428 L
.26572 .27999 L
.26369 .27772 L
.24971 .26369 L
.24739 .26114 L
.23371 .24739 L
.2311 .24431 L
.21799 .2311 L
.2148 .22736 L
.20238 .2148 L
.1985 .20954 L
.18778 .1985 L
.1822 .19022 L
.17473 .1822 L
.17263 .16591 L
.1822 .15153 L
.18484 .14961 L
.1985 .14404 L
.2148 .13778 L
.22402 .13331 L
.2311 .12795 L
.24514 .11701 L
.24739 .11538 L
.26369 .10546 L
.27083 .10072 L
.27999 .09478 L
.29628 .08793 L
.30663 .08442 L
.31258 .08261 L
.32888 .07683 L
.34518 .07033 L
.35231 .06812 L
.36147 .06578 L
Mfstroke
.2 g
.39407 .11629 m
.41037 .1158 L
.42666 .11599 L
.44296 .11682 L
.44581 .11701 L
.45926 .11825 L
.47555 .12028 L
.49185 .12289 L
.50815 .12612 L
.52445 .13001 L
.53644 .13331 L
.54074 .1346 L
.55704 .13995 L
.57334 .14612 L
.58164 .14961 L
.58963 .15319 L
.60593 .16119 L
.61471 .16591 L
.62223 .17018 L
.63853 .18023 L
.64152 .1822 L
.65482 .19144 L
.66426 .1985 L
.67112 .20393 L
.68395 .2148 L
.68742 .21791 L
.7012 .2311 L
.70372 .23366 L
.71642 .24739 L
.72001 .25154 L
.72993 .26369 L
.73631 .27211 L
.74195 .27999 L
.75261 .29618 L
.75267 .29628 L
.76224 .31258 L
.7689 .32516 L
.77076 .32888 L
.77832 .34518 L
.78496 .36147 L
.7852 .3621 L
.79075 .37777 L
.79571 .39407 L
.79988 .41037 L
.8015 .41762 L
.80329 .42666 L
.80599 .44296 L
.80798 .45926 L
.80931 .47555 L
.80997 .49185 L
.80997 .50815 L
.80931 .52445 L
.80798 .54074 L
.80599 .55704 L
.80329 .57334 L
.8015 .58238 L
.79988 .58963 L
.79571 .60593 L
.79075 .62223 L
.7852 .6379 L
.78496 .63853 L
.77832 .65482 L
.77076 .67112 L
.7689 .67484 L
.76224 .68742 L
.75267 .70372 L
.75261 .70382 L
.74195 .72001 L
.73631 .72789 L
.72993 .73631 L
.72001 .74846 L
.71642 .75261 L
.70372 .76634 L
.7012 .7689 L
.68742 .78209 L
.68395 .7852 L
.67112 .79607 L
.66426 .8015 L
.65482 .80856 L
.64152 .8178 L
.63853 .81977 L
.62223 .82982 L
.61471 .83409 L
.60593 .83881 L
.58963 .84681 L
.58164 .85039 L
.57334 .85388 L
.55704 .86005 L
.54074 .8654 L
.53644 .86669 L
.52445 .86999 L
.50815 .87388 L
.49185 .87711 L
.47555 .87972 L
.45926 .88175 L
.44581 .88299 L
.44296 .88318 L
.42666 .88401 L
.41037 .8842 L
.39407 .88371 L
.38099 .88299 L
.37777 .88249 L
.36147 .88049 L
.34518 .87768 L
.32888 .87406 L
.31258 .86969 L
.30262 .86669 L
.29628 .8646 L
.27999 .8587 L
.26369 .852 L
.25999 .85039 L
.24739 .84468 L
.2311 .83667 L
.22628 .83409 L
.2148 .82821 L
.1985 .81971 L
.1962 .8178 L
.19511 .8015 L
.1985 .79777 L
.20745 .7852 L
.2148 .77762 L
.22216 .7689 L
.2311 .75978 L
.23717 .75261 L
.24739 .74227 L
.2528 .73631 L
.26369 .72532 L
.26846 .72001 L
.27999 .70842 L
.28439 .70372 L
.29628 .69176 L
.30031 .68742 L
.31258 .67511 L
.31639 .67112 L
.32888 .65859 L
.33245 .65482 L
.34518 .64207 L
.3486 .63853 L
.36147 .62563 L
.36474 .62223 L
.37777 .60918 L
.38094 .60593 L
.39407 .59279 L
.39713 .58963 L
.41037 .5764 L
.41337 .57334 L
.42666 .56004 L
.4296 .55704 L
.44296 .54368 L
.44587 .54074 L
.45926 .52735 L
.46213 .52445 L
.47555 .51102 L
.47839 .50815 L
.47839 .49185 L
.47555 .48898 L
.46213 .47555 L
.45926 .47265 L
.44587 .45926 L
.44296 .45632 L
.4296 .44296 L
.42666 .43996 L
.41337 .42666 L
.41037 .4236 L
.39713 .41037 L
.39407 .40721 L
.38094 .39407 L
.37777 .39082 L
.36474 .37777 L
.36147 .37437 L
.3486 .36147 L
.34518 .35793 L
.33245 .34518 L
.32888 .34141 L
.31639 .32888 L
.31258 .32489 L
.30031 .31258 L
.29628 .30824 L
.28439 .29628 L
.27999 .29158 L
.26846 .27999 L
.26369 .27468 L
.2528 .26369 L
.24739 .25773 L
.23717 .24739 L
.2311 .24022 L
.22216 .2311 L
.2148 .22238 L
.20745 .2148 L
.1985 .20223 L
.19511 .1985 L
.1962 .1822 L
.1985 .18029 L
.2148 .17179 L
.22628 .16591 L
.2311 .16333 L
.24739 .15532 L
.25999 .14961 L
.26369 .148 L
.27999 .1413 L
.29628 .1354 L
.30262 .13331 L
.31258 .13031 L
.32888 .12594 L
.34518 .12232 L
.36147 .11951 L
.37777 .11751 L
.38099 .11701 L
F
0 g
.39407 .11629 m
.41037 .1158 L
.42666 .11599 L
.44296 .11682 L
.44581 .11701 L
.45926 .11825 L
.47555 .12028 L
.49185 .12289 L
.50815 .12612 L
.52445 .13001 L
.53644 .13331 L
.54074 .1346 L
.55704 .13995 L
.57334 .14612 L
.58164 .14961 L
.58963 .15319 L
.60593 .16119 L
.61471 .16591 L
.62223 .17018 L
.63853 .18023 L
.64152 .1822 L
.65482 .19144 L
.66426 .1985 L
.67112 .20393 L
.68395 .2148 L
.68742 .21791 L
.7012 .2311 L
.70372 .23366 L
.71642 .24739 L
.72001 .25154 L
.72993 .26369 L
.73631 .27211 L
.74195 .27999 L
.75261 .29618 L
.75267 .29628 L
.76224 .31258 L
.7689 .32516 L
.77076 .32888 L
.77832 .34518 L
.78496 .36147 L
.7852 .3621 L
.79075 .37777 L
.79571 .39407 L
.79988 .41037 L
.8015 .41762 L
.80329 .42666 L
.80599 .44296 L
.80798 .45926 L
.80931 .47555 L
.80997 .49185 L
Mistroke
.80997 .50815 L
.80931 .52445 L
.80798 .54074 L
.80599 .55704 L
.80329 .57334 L
.8015 .58238 L
.79988 .58963 L
.79571 .60593 L
.79075 .62223 L
.7852 .6379 L
.78496 .63853 L
.77832 .65482 L
.77076 .67112 L
.7689 .67484 L
.76224 .68742 L
.75267 .70372 L
.75261 .70382 L
.74195 .72001 L
.73631 .72789 L
.72993 .73631 L
.72001 .74846 L
.71642 .75261 L
.70372 .76634 L
.7012 .7689 L
.68742 .78209 L
.68395 .7852 L
.67112 .79607 L
.66426 .8015 L
.65482 .80856 L
.64152 .8178 L
.63853 .81977 L
.62223 .82982 L
.61471 .83409 L
.60593 .83881 L
.58963 .84681 L
.58164 .85039 L
.57334 .85388 L
.55704 .86005 L
.54074 .8654 L
.53644 .86669 L
.52445 .86999 L
.50815 .87388 L
.49185 .87711 L
.47555 .87972 L
.45926 .88175 L
.44581 .88299 L
.44296 .88318 L
.42666 .88401 L
.41037 .8842 L
.39407 .88371 L
Mistroke
.38099 .88299 L
.37777 .88249 L
.36147 .88049 L
.34518 .87768 L
.32888 .87406 L
.31258 .86969 L
.30262 .86669 L
.29628 .8646 L
.27999 .8587 L
.26369 .852 L
.25999 .85039 L
.24739 .84468 L
.2311 .83667 L
.22628 .83409 L
.2148 .82821 L
.1985 .81971 L
.1962 .8178 L
.19511 .8015 L
.1985 .79777 L
.20745 .7852 L
.2148 .77762 L
.22216 .7689 L
.2311 .75978 L
.23717 .75261 L
.24739 .74227 L
.2528 .73631 L
.26369 .72532 L
.26846 .72001 L
.27999 .70842 L
.28439 .70372 L
.29628 .69176 L
.30031 .68742 L
.31258 .67511 L
.31639 .67112 L
.32888 .65859 L
.33245 .65482 L
.34518 .64207 L
.3486 .63853 L
.36147 .62563 L
.36474 .62223 L
.37777 .60918 L
.38094 .60593 L
.39407 .59279 L
.39713 .58963 L
.41037 .5764 L
.41337 .57334 L
.42666 .56004 L
.4296 .55704 L
.44296 .54368 L
.44587 .54074 L
Mistroke
.45926 .52735 L
.46213 .52445 L
.47555 .51102 L
.47839 .50815 L
.47839 .49185 L
.47555 .48898 L
.46213 .47555 L
.45926 .47265 L
.44587 .45926 L
.44296 .45632 L
.4296 .44296 L
.42666 .43996 L
.41337 .42666 L
.41037 .4236 L
.39713 .41037 L
.39407 .40721 L
.38094 .39407 L
.37777 .39082 L
.36474 .37777 L
.36147 .37437 L
.3486 .36147 L
.34518 .35793 L
.33245 .34518 L
.32888 .34141 L
.31639 .32888 L
.31258 .32489 L
.30031 .31258 L
.29628 .30824 L
.28439 .29628 L
.27999 .29158 L
.26846 .27999 L
.26369 .27468 L
.2528 .26369 L
.24739 .25773 L
.23717 .24739 L
.2311 .24022 L
.22216 .2311 L
.2148 .22238 L
.20745 .2148 L
.1985 .20223 L
.19511 .1985 L
.1962 .1822 L
.1985 .18029 L
.2148 .17179 L
.22628 .16591 L
.2311 .16333 L
.24739 .15532 L
.25999 .14961 L
.26369 .148 L
.27999 .1413 L
Mistroke
.29628 .1354 L
.30262 .13331 L
.31258 .13031 L
.32888 .12594 L
.34518 .12232 L
.36147 .11951 L
.37777 .11751 L
.38099 .11701 L
.39407 .11629 L
Mfstroke
.3 g
.36147 .16452 m
.37777 .16375 L
.39407 .1637 L
.41037 .16436 L
.42666 .16574 L
.42824 .16591 L
.44296 .16782 L
.45926 .17062 L
.47555 .17414 L
.49185 .17841 L
.50433 .1822 L
.50815 .18346 L
.52445 .18935 L
.54074 .19613 L
.54595 .1985 L
.55704 .20388 L
.57334 .21269 L
.57696 .2148 L
.58963 .22264 L
.60206 .2311 L
.60593 .23389 L
.62223 .24661 L
.62317 .24739 L
.63853 .26103 L
.64131 .26369 L
.65482 .2775 L
.65709 .27999 L
.67093 .29628 L
.67112 .29653 L
.68309 .31258 L
.68742 .31892 L
.69379 .32888 L
.70318 .34518 L
.70372 .34617 L
.71139 .36147 L
.71851 .37777 L
.72001 .38155 L
.7246 .39407 L
.72973 .41037 L
.73394 .42666 L
.73631 .43773 L
.73727 .44296 L
.73974 .45926 L
.74138 .47555 L
.7422 .49185 L
.7422 .50815 L
.74138 .52445 L
.73974 .54074 L
.73727 .55704 L
.73631 .56227 L
.73394 .57334 L
.72973 .58963 L
.7246 .60593 L
.72001 .61845 L
.71851 .62223 L
.71139 .63853 L
.70372 .65383 L
.70318 .65482 L
.69379 .67112 L
.68742 .68108 L
.68309 .68742 L
.67112 .70347 L
.67093 .70372 L
.65709 .72001 L
.65482 .7225 L
.64131 .73631 L
.63853 .73897 L
.62317 .75261 L
.62223 .75339 L
.60593 .76611 L
.60206 .7689 L
.58963 .77736 L
.57696 .7852 L
.57334 .78731 L
.55704 .79612 L
.54595 .8015 L
.54074 .80387 L
.52445 .81065 L
.50815 .81654 L
.50433 .8178 L
.49185 .82159 L
.47555 .82586 L
.45926 .82938 L
.44296 .83218 L
.42824 .83409 L
.42666 .83426 L
.41037 .83564 L
.39407 .8363 L
.37777 .83625 L
.36147 .83548 L
.34588 .83409 L
.34518 .83398 L
.32888 .83176 L
.31258 .82882 L
.29628 .82518 L
.27999 .82085 L
.26985 .8178 L
.26369 .81578 L
.24739 .81006 L
.2311 .80561 L
.21847 .8015 L
.2148 .80053 L
.21259 .7852 L
.2148 .78284 L
.22619 .7689 L
.2311 .7638 L
.24045 .75261 L
.24739 .74552 L
.2557 .73631 L
.26369 .72819 L
.27101 .72001 L
.27999 .71095 L
.28675 .70372 L
.29628 .6941 L
.30248 .68742 L
.31258 .67726 L
.31844 .67112 L
.32888 .66062 L
.33437 .65482 L
.34518 .64398 L
.35045 .63853 L
.36147 .62746 L
.36651 .62223 L
.37777 .61094 L
.38266 .60593 L
.39407 .5945 L
.3988 .58963 L
.41037 .57806 L
.415 .57334 L
.42666 .56166 L
.4312 .55704 L
.44296 .54528 L
.44745 .54074 L
.45926 .52893 L
.46369 .52445 L
.47555 .51259 L
.47994 .50815 L
.47994 .49185 L
.47555 .48741 L
.46369 .47555 L
.45926 .47107 L
.44745 .45926 L
.44296 .45472 L
.4312 .44296 L
.42666 .43834 L
.415 .42666 L
.41037 .42194 L
.3988 .41037 L
.39407 .4055 L
.38266 .39407 L
.37777 .38906 L
.36651 .37777 L
.36147 .37254 L
.35045 .36147 L
.34518 .35602 L
.33437 .34518 L
.32888 .33938 L
.31844 .32888 L
.31258 .32274 L
.30248 .31258 L
.29628 .3059 L
.28675 .29628 L
.27999 .28905 L
.27101 .27999 L
.26369 .27181 L
.2557 .26369 L
.24739 .25448 L
.24045 .24739 L
.2311 .2362 L
.22619 .2311 L
.2148 .21716 L
.21259 .2148 L
.2148 .19947 L
.21847 .1985 L
.2311 .19439 L
.24739 .18994 L
.26369 .18422 L
.26985 .1822 L
.27999 .17915 L
.29628 .17482 L
.31258 .17118 L
.32888 .16824 L
.34518 .16602 L
.34588 .16591 L
F
0 g
.36147 .16452 m
.37777 .16375 L
.39407 .1637 L
.41037 .16436 L
.42666 .16574 L
.42824 .16591 L
.44296 .16782 L
.45926 .17062 L
.47555 .17414 L
.49185 .17841 L
.50433 .1822 L
.50815 .18346 L
.52445 .18935 L
.54074 .19613 L
.54595 .1985 L
.55704 .20388 L
.57334 .21269 L
.57696 .2148 L
.58963 .22264 L
.60206 .2311 L
.60593 .23389 L
.62223 .24661 L
.62317 .24739 L
.63853 .26103 L
.64131 .26369 L
.65482 .2775 L
.65709 .27999 L
.67093 .29628 L
.67112 .29653 L
.68309 .31258 L
.68742 .31892 L
.69379 .32888 L
.70318 .34518 L
.70372 .34617 L
.71139 .36147 L
.71851 .37777 L
.72001 .38155 L
.7246 .39407 L
.72973 .41037 L
.73394 .42666 L
.73631 .43773 L
.73727 .44296 L
.73974 .45926 L
.74138 .47555 L
.7422 .49185 L
.7422 .50815 L
.74138 .52445 L
.73974 .54074 L
.73727 .55704 L
.73631 .56227 L
Mistroke
.73394 .57334 L
.72973 .58963 L
.7246 .60593 L
.72001 .61845 L
.71851 .62223 L
.71139 .63853 L
.70372 .65383 L
.70318 .65482 L
.69379 .67112 L
.68742 .68108 L
.68309 .68742 L
.67112 .70347 L
.67093 .70372 L
.65709 .72001 L
.65482 .7225 L
.64131 .73631 L
.63853 .73897 L
.62317 .75261 L
.62223 .75339 L
.60593 .76611 L
.60206 .7689 L
.58963 .77736 L
.57696 .7852 L
.57334 .78731 L
.55704 .79612 L
.54595 .8015 L
.54074 .80387 L
.52445 .81065 L
.50815 .81654 L
.50433 .8178 L
.49185 .82159 L
.47555 .82586 L
.45926 .82938 L
.44296 .83218 L
.42824 .83409 L
.42666 .83426 L
.41037 .83564 L
.39407 .8363 L
.37777 .83625 L
.36147 .83548 L
.34588 .83409 L
.34518 .83398 L
.32888 .83176 L
.31258 .82882 L
.29628 .82518 L
.27999 .82085 L
.26985 .8178 L
.26369 .81578 L
.24739 .81006 L
.2311 .80561 L
Mistroke
.21847 .8015 L
.2148 .80053 L
.21259 .7852 L
.2148 .78284 L
.22619 .7689 L
.2311 .7638 L
.24045 .75261 L
.24739 .74552 L
.2557 .73631 L
.26369 .72819 L
.27101 .72001 L
.27999 .71095 L
.28675 .70372 L
.29628 .6941 L
.30248 .68742 L
.31258 .67726 L
.31844 .67112 L
.32888 .66062 L
.33437 .65482 L
.34518 .64398 L
.35045 .63853 L
.36147 .62746 L
.36651 .62223 L
.37777 .61094 L
.38266 .60593 L
.39407 .5945 L
.3988 .58963 L
.41037 .57806 L
.415 .57334 L
.42666 .56166 L
.4312 .55704 L
.44296 .54528 L
.44745 .54074 L
.45926 .52893 L
.46369 .52445 L
.47555 .51259 L
.47994 .50815 L
.47994 .49185 L
.47555 .48741 L
.46369 .47555 L
.45926 .47107 L
.44745 .45926 L
.44296 .45472 L
.4312 .44296 L
.42666 .43834 L
.415 .42666 L
.41037 .42194 L
.3988 .41037 L
.39407 .4055 L
.38266 .39407 L
Mistroke
.37777 .38906 L
.36651 .37777 L
.36147 .37254 L
.35045 .36147 L
.34518 .35602 L
.33437 .34518 L
.32888 .33938 L
.31844 .32888 L
.31258 .32274 L
.30248 .31258 L
.29628 .3059 L
.28675 .29628 L
.27999 .28905 L
.27101 .27999 L
.26369 .27181 L
.2557 .26369 L
.24739 .25448 L
.24045 .24739 L
.2311 .2362 L
.22619 .2311 L
.2148 .21716 L
.21259 .2148 L
.2148 .19947 L
.21847 .1985 L
.2311 .19439 L
.24739 .18994 L
.26369 .18422 L
.26985 .1822 L
.27999 .17915 L
.29628 .17482 L
.31258 .17118 L
.32888 .16824 L
.34518 .16602 L
.34588 .16591 L
.36147 .16452 L
Mfstroke
.4 g
.27999 .21228 m
.29628 .20933 L
.31258 .207 L
.32888 .20537 L
.34518 .20442 L
.36147 .20417 L
.37777 .20464 L
.39407 .20582 L
.41037 .20775 L
.42666 .21043 L
.44296 .21389 L
.44674 .2148 L
.45926 .21815 L
.47555 .22325 L
.49185 .22926 L
.49638 .2311 L
.50815 .23623 L
.52445 .24424 L
.53029 .24739 L
.54074 .25342 L
.55675 .26369 L
.55704 .26389 L
.57334 .27584 L
.57851 .27999 L
.58963 .28953 L
.5969 .29628 L
.60593 .30533 L
.61266 .31258 L
.62223 .32379 L
.62627 .32888 L
.63806 .34518 L
.63853 .34587 L
.64826 .36147 L
.65482 .37342 L
.65703 .37777 L
.66451 .39407 L
.67078 .41037 L
.67112 .41134 L
.67592 .42666 L
.67997 .44296 L
.68299 .45926 L
.68498 .47555 L
.68598 .49185 L
.68598 .50815 L
.68498 .52445 L
.68299 .54074 L
.67997 .55704 L
.67592 .57334 L
.67112 .58866 L
.67078 .58963 L
.66451 .60593 L
.65703 .62223 L
.65482 .62658 L
.64826 .63853 L
.63853 .65413 L
.63806 .65482 L
.62627 .67112 L
.62223 .67621 L
.61266 .68742 L
.60593 .69467 L
.5969 .70372 L
.58963 .71047 L
.57851 .72001 L
.57334 .72416 L
.55704 .73611 L
.55675 .73631 L
.54074 .74658 L
.53029 .75261 L
.52445 .75576 L
.50815 .76377 L
.49638 .7689 L
.49185 .77074 L
.47555 .77675 L
.45926 .78185 L
.44674 .7852 L
.44296 .78611 L
.42666 .78957 L
.41037 .79225 L
.39407 .79418 L
.37777 .79536 L
.36147 .79583 L
.34518 .79558 L
.32888 .79463 L
.31258 .793 L
.29628 .79067 L
.27999 .78772 L
.2668 .7852 L
.26369 .78463 L
.24739 .78144 L
.2311 .78049 L
.23058 .7689 L
.2311 .76835 L
.2438 .75261 L
.24739 .7489 L
.25859 .73631 L
.26369 .73108 L
.27352 .72001 L
.27999 .71346 L
.28906 .70372 L
.29628 .69639 L
.30458 .68742 L
.31258 .67935 L
.32042 .67112 L
.32888 .66259 L
.33623 .65482 L
.34518 .64583 L
.35223 .63853 L
.36147 .62924 L
.36821 .62223 L
.37777 .61264 L
.38431 .60593 L
.39407 .59614 L
.4004 .58963 L
.41037 .57965 L
.41657 .57334 L
.42666 .56323 L
.43274 .55704 L
.44296 .54681 L
.44897 .54074 L
.45926 .53044 L
.4652 .52445 L
.47555 .51409 L
.48142 .50815 L
.48142 .49185 L
.47555 .48591 L
.4652 .47555 L
.45926 .46956 L
.44897 .45926 L
.44296 .45319 L
.43274 .44296 L
.42666 .43677 L
.41657 .42666 L
.41037 .42035 L
.4004 .41037 L
.39407 .40386 L
.38431 .39407 L
.37777 .38736 L
.36821 .37777 L
.36147 .37076 L
.35223 .36147 L
.34518 .35417 L
.33623 .34518 L
.32888 .33741 L
.32042 .32888 L
.31258 .32065 L
.30458 .31258 L
.29628 .30361 L
.28906 .29628 L
.27999 .28654 L
.27352 .27999 L
.26369 .26892 L
.25859 .26369 L
.24739 .2511 L
.2438 .24739 L
.2311 .23165 L
.23058 .2311 L
.2311 .21951 L
.24739 .21856 L
.26369 .21537 L
.2668 .2148 L
F
0 g
.27999 .21228 m
.29628 .20933 L
.31258 .207 L
.32888 .20537 L
.34518 .20442 L
.36147 .20417 L
.37777 .20464 L
.39407 .20582 L
.41037 .20775 L
.42666 .21043 L
.44296 .21389 L
.44674 .2148 L
.45926 .21815 L
.47555 .22325 L
.49185 .22926 L
.49638 .2311 L
.50815 .23623 L
.52445 .24424 L
.53029 .24739 L
.54074 .25342 L
.55675 .26369 L
.55704 .26389 L
.57334 .27584 L
.57851 .27999 L
.58963 .28953 L
.5969 .29628 L
.60593 .30533 L
.61266 .31258 L
.62223 .32379 L
.62627 .32888 L
.63806 .34518 L
.63853 .34587 L
.64826 .36147 L
.65482 .37342 L
.65703 .37777 L
.66451 .39407 L
.67078 .41037 L
.67112 .41134 L
.67592 .42666 L
.67997 .44296 L
.68299 .45926 L
.68498 .47555 L
.68598 .49185 L
.68598 .50815 L
.68498 .52445 L
.68299 .54074 L
.67997 .55704 L
.67592 .57334 L
.67112 .58866 L
.67078 .58963 L
Mistroke
.66451 .60593 L
.65703 .62223 L
.65482 .62658 L
.64826 .63853 L
.63853 .65413 L
.63806 .65482 L
.62627 .67112 L
.62223 .67621 L
.61266 .68742 L
.60593 .69467 L
.5969 .70372 L
.58963 .71047 L
.57851 .72001 L
.57334 .72416 L
.55704 .73611 L
.55675 .73631 L
.54074 .74658 L
.53029 .75261 L
.52445 .75576 L
.50815 .76377 L
.49638 .7689 L
.49185 .77074 L
.47555 .77675 L
.45926 .78185 L
.44674 .7852 L
.44296 .78611 L
.42666 .78957 L
.41037 .79225 L
.39407 .79418 L
.37777 .79536 L
.36147 .79583 L
.34518 .79558 L
.32888 .79463 L
.31258 .793 L
.29628 .79067 L
.27999 .78772 L
.2668 .7852 L
.26369 .78463 L
.24739 .78144 L
.2311 .78049 L
.23058 .7689 L
.2311 .76835 L
.2438 .75261 L
.24739 .7489 L
.25859 .73631 L
.26369 .73108 L
.27352 .72001 L
.27999 .71346 L
.28906 .70372 L
.29628 .69639 L
Mistroke
.30458 .68742 L
.31258 .67935 L
.32042 .67112 L
.32888 .66259 L
.33623 .65482 L
.34518 .64583 L
.35223 .63853 L
.36147 .62924 L
.36821 .62223 L
.37777 .61264 L
.38431 .60593 L
.39407 .59614 L
.4004 .58963 L
.41037 .57965 L
.41657 .57334 L
.42666 .56323 L
.43274 .55704 L
.44296 .54681 L
.44897 .54074 L
.45926 .53044 L
.4652 .52445 L
.47555 .51409 L
.48142 .50815 L
.48142 .49185 L
.47555 .48591 L
.4652 .47555 L
.45926 .46956 L
.44897 .45926 L
.44296 .45319 L
.43274 .44296 L
.42666 .43677 L
.41657 .42666 L
.41037 .42035 L
.4004 .41037 L
.39407 .40386 L
.38431 .39407 L
.37777 .38736 L
.36821 .37777 L
.36147 .37076 L
.35223 .36147 L
.34518 .35417 L
.33623 .34518 L
.32888 .33741 L
.32042 .32888 L
.31258 .32065 L
.30458 .31258 L
.29628 .30361 L
.28906 .29628 L
.27999 .28654 L
.27352 .27999 L
Mistroke
.26369 .26892 L
.25859 .26369 L
.24739 .2511 L
.2438 .24739 L
.2311 .23165 L
.23058 .2311 L
.2311 .21951 L
.24739 .21856 L
.26369 .21537 L
.2668 .2148 L
.27999 .21228 L
Mfstroke
.5 g
.26369 .24242 m
.27999 .24175 L
.29628 .24029 L
.31258 .23931 L
.32888 .23887 L
.34518 .23909 L
.36147 .24002 L
.37777 .24168 L
.39407 .24408 L
.41037 .24726 L
.41099 .24739 L
.42666 .25125 L
.44296 .2561 L
.45926 .26187 L
.4639 .26369 L
.47555 .26863 L
.49185 .27646 L
.49848 .27999 L
.50815 .28551 L
.52445 .29591 L
.52499 .29628 L
.54074 .30791 L
.5465 .31258 L
.55704 .3218 L
.56446 .32888 L
.57334 .33808 L
.57964 .34518 L
.58963 .35754 L
.59257 .36147 L
.60356 .37777 L
.60593 .38166 L
.61286 .39407 L
.62061 .41037 L
.62223 .41418 L
.62696 .42666 L
.63196 .44296 L
.63568 .45926 L
.63815 .47555 L
.63853 .47916 L
.63939 .49185 L
.63939 .50815 L
.63853 .52084 L
.63815 .52445 L
.63568 .54074 L
.63196 .55704 L
.62696 .57334 L
.62223 .58582 L
.62061 .58963 L
.61286 .60593 L
.60593 .61834 L
.60356 .62223 L
.59257 .63853 L
.58963 .64246 L
.57964 .65482 L
.57334 .66192 L
.56446 .67112 L
.55704 .6782 L
.5465 .68742 L
.54074 .69209 L
.52499 .70372 L
.52445 .70409 L
.50815 .71449 L
.49848 .72001 L
.49185 .72354 L
.47555 .73137 L
.4639 .73631 L
.45926 .73813 L
.44296 .7439 L
.42666 .74875 L
.41099 .75261 L
.41037 .75274 L
.39407 .75592 L
.37777 .75832 L
.36147 .75998 L
.34518 .76091 L
.32888 .76113 L
.31258 .76069 L
.29628 .75971 L
.27999 .75825 L
.26369 .75758 L
.24784 .75261 L
.26167 .73631 L
.26369 .7342 L
.27611 .72001 L
.27999 .71606 L
.29139 .70372 L
.29628 .69873 L
.30668 .68742 L
.31258 .68145 L
.32239 .67112 L
.32888 .66456 L
.33806 .65482 L
.34518 .64767 L
.35399 .63853 L
.36147 .63099 L
.36988 .62223 L
.37777 .61431 L
.38593 .60593 L
.39407 .59776 L
.40196 .58963 L
.41037 .58122 L
.41811 .57334 L
.42666 .56476 L
.43424 .55704 L
.44296 .54832 L
.45045 .54074 L
.45926 .53192 L
.46666 .52445 L
.47555 .51556 L
.48288 .50815 L
.48288 .49185 L
.47555 .48444 L
.46666 .47555 L
.45926 .46808 L
.45045 .45926 L
.44296 .45168 L
.43424 .44296 L
.42666 .43524 L
.41811 .42666 L
.41037 .41878 L
.40196 .41037 L
.39407 .40224 L
.38593 .39407 L
.37777 .38569 L
.36988 .37777 L
.36147 .36901 L
.35399 .36147 L
.34518 .35233 L
.33806 .34518 L
.32888 .33544 L
.32239 .32888 L
.31258 .31855 L
.30668 .31258 L
.29628 .30127 L
.29139 .29628 L
.27999 .28394 L
.27611 .27999 L
.26369 .2658 L
.26167 .26369 L
.24784 .24739 L
F
0 g
.26369 .24242 m
.27999 .24175 L
.29628 .24029 L
.31258 .23931 L
.32888 .23887 L
.34518 .23909 L
.36147 .24002 L
.37777 .24168 L
.39407 .24408 L
.41037 .24726 L
.41099 .24739 L
.42666 .25125 L
.44296 .2561 L
.45926 .26187 L
.4639 .26369 L
.47555 .26863 L
.49185 .27646 L
.49848 .27999 L
.50815 .28551 L
.52445 .29591 L
.52499 .29628 L
.54074 .30791 L
.5465 .31258 L
.55704 .3218 L
.56446 .32888 L
.57334 .33808 L
.57964 .34518 L
.58963 .35754 L
.59257 .36147 L
.60356 .37777 L
.60593 .38166 L
.61286 .39407 L
.62061 .41037 L
.62223 .41418 L
.62696 .42666 L
.63196 .44296 L
.63568 .45926 L
.63815 .47555 L
.63853 .47916 L
.63939 .49185 L
.63939 .50815 L
.63853 .52084 L
.63815 .52445 L
.63568 .54074 L
.63196 .55704 L
.62696 .57334 L
.62223 .58582 L
.62061 .58963 L
.61286 .60593 L
.60593 .61834 L
Mistroke
.60356 .62223 L
.59257 .63853 L
.58963 .64246 L
.57964 .65482 L
.57334 .66192 L
.56446 .67112 L
.55704 .6782 L
.5465 .68742 L
.54074 .69209 L
.52499 .70372 L
.52445 .70409 L
.50815 .71449 L
.49848 .72001 L
.49185 .72354 L
.47555 .73137 L
.4639 .73631 L
.45926 .73813 L
.44296 .7439 L
.42666 .74875 L
.41099 .75261 L
.41037 .75274 L
.39407 .75592 L
.37777 .75832 L
.36147 .75998 L
.34518 .76091 L
.32888 .76113 L
.31258 .76069 L
.29628 .75971 L
.27999 .75825 L
.26369 .75758 L
.24784 .75261 L
.26167 .73631 L
.26369 .7342 L
.27611 .72001 L
.27999 .71606 L
.29139 .70372 L
.29628 .69873 L
.30668 .68742 L
.31258 .68145 L
.32239 .67112 L
.32888 .66456 L
.33806 .65482 L
.34518 .64767 L
.35399 .63853 L
.36147 .63099 L
.36988 .62223 L
.37777 .61431 L
.38593 .60593 L
.39407 .59776 L
.40196 .58963 L
Mistroke
.41037 .58122 L
.41811 .57334 L
.42666 .56476 L
.43424 .55704 L
.44296 .54832 L
.45045 .54074 L
.45926 .53192 L
.46666 .52445 L
.47555 .51556 L
.48288 .50815 L
.48288 .49185 L
.47555 .48444 L
.46666 .47555 L
.45926 .46808 L
.45045 .45926 L
.44296 .45168 L
.43424 .44296 L
.42666 .43524 L
.41811 .42666 L
.41037 .41878 L
.40196 .41037 L
.39407 .40224 L
.38593 .39407 L
.37777 .38569 L
.36988 .37777 L
.36147 .36901 L
.35399 .36147 L
.34518 .35233 L
.33806 .34518 L
.32888 .33544 L
.32239 .32888 L
.31258 .31855 L
.30668 .31258 L
.29628 .30127 L
.29139 .29628 L
.27999 .28394 L
.27611 .27999 L
.26369 .2658 L
.26167 .26369 L
.24784 .24739 L
.26369 .24242 L
Mfstroke
.6 g
.27999 .26492 m
.29628 .26689 L
.31258 .26893 L
.32888 .26966 L
.34518 .27102 L
.36147 .27306 L
.37777 .27582 L
.39407 .27938 L
.39651 .27999 L
.41037 .28378 L
.42666 .28906 L
.44296 .29529 L
.44533 .29628 L
.45926 .30258 L
.47555 .31103 L
.4783 .31258 L
.49185 .32082 L
.50368 .32888 L
.50815 .33216 L
.5242 .34518 L
.52445 .34539 L
.54074 .36101 L
.54118 .36147 L
.55536 .37777 L
.55704 .37991 L
.5672 .39407 L
.57334 .40386 L
.57703 .41037 L
.58503 .42666 L
.58963 .43803 L
.59136 .44296 L
.59609 .45926 L
.59925 .47555 L
.60087 .49185 L
.60087 .50815 L
.59925 .52445 L
.59609 .54074 L
.59136 .55704 L
.58963 .56197 L
.58503 .57334 L
.57703 .58963 L
.57334 .59614 L
.5672 .60593 L
.55704 .62009 L
.55536 .62223 L
.54118 .63853 L
.54074 .63899 L
.52445 .65461 L
.5242 .65482 L
.50815 .66784 L
.50368 .67112 L
.49185 .67918 L
.4783 .68742 L
.47555 .68897 L
.45926 .69742 L
.44533 .70372 L
.44296 .70471 L
.42666 .71094 L
.41037 .71622 L
.39651 .72001 L
.39407 .72062 L
.37777 .72418 L
.36147 .72694 L
.34518 .72898 L
.32888 .73034 L
.31258 .73107 L
.29628 .73311 L
.27999 .73508 L
.27893 .72001 L
.27999 .71892 L
.29385 .70372 L
.29628 .70122 L
.30886 .68742 L
.31258 .68364 L
.3244 .67112 L
.32888 .66658 L
.33992 .65482 L
.34518 .64953 L
.35576 .63853 L
.36147 .63276 L
.37156 .62223 L
.37777 .61598 L
.38755 .60593 L
.39407 .59938 L
.40353 .58963 L
.41037 .58278 L
.41964 .57334 L
.42666 .56629 L
.43574 .55704 L
.44296 .54981 L
.45193 .54074 L
.45926 .5334 L
.46812 .52445 L
.47555 .51702 L
.48432 .50815 L
.48432 .49185 L
.47555 .48298 L
.46812 .47555 L
.45926 .4666 L
.45193 .45926 L
.44296 .45019 L
.43574 .44296 L
.42666 .43371 L
.41964 .42666 L
.41037 .41722 L
.40353 .41037 L
.39407 .40062 L
.38755 .39407 L
.37777 .38402 L
.37156 .37777 L
.36147 .36724 L
.35576 .36147 L
.34518 .35047 L
.33992 .34518 L
.32888 .33342 L
.3244 .32888 L
.31258 .31636 L
.30886 .31258 L
.29628 .29878 L
.29385 .29628 L
.27999 .28108 L
.27893 .27999 L
F
0 g
.27999 .26492 m
.29628 .26689 L
.31258 .26893 L
.32888 .26966 L
.34518 .27102 L
.36147 .27306 L
.37777 .27582 L
.39407 .27938 L
.39651 .27999 L
.41037 .28378 L
.42666 .28906 L
.44296 .29529 L
.44533 .29628 L
.45926 .30258 L
.47555 .31103 L
.4783 .31258 L
.49185 .32082 L
.50368 .32888 L
.50815 .33216 L
.5242 .34518 L
.52445 .34539 L
.54074 .36101 L
.54118 .36147 L
.55536 .37777 L
.55704 .37991 L
.5672 .39407 L
.57334 .40386 L
.57703 .41037 L
.58503 .42666 L
.58963 .43803 L
.59136 .44296 L
.59609 .45926 L
.59925 .47555 L
.60087 .49185 L
.60087 .50815 L
.59925 .52445 L
.59609 .54074 L
.59136 .55704 L
.58963 .56197 L
.58503 .57334 L
.57703 .58963 L
.57334 .59614 L
.5672 .60593 L
.55704 .62009 L
.55536 .62223 L
.54118 .63853 L
.54074 .63899 L
.52445 .65461 L
.5242 .65482 L
.50815 .66784 L
Mistroke
.50368 .67112 L
.49185 .67918 L
.4783 .68742 L
.47555 .68897 L
.45926 .69742 L
.44533 .70372 L
.44296 .70471 L
.42666 .71094 L
.41037 .71622 L
.39651 .72001 L
.39407 .72062 L
.37777 .72418 L
.36147 .72694 L
.34518 .72898 L
.32888 .73034 L
.31258 .73107 L
.29628 .73311 L
.27999 .73508 L
.27893 .72001 L
.27999 .71892 L
.29385 .70372 L
.29628 .70122 L
.30886 .68742 L
.31258 .68364 L
.3244 .67112 L
.32888 .66658 L
.33992 .65482 L
.34518 .64953 L
.35576 .63853 L
.36147 .63276 L
.37156 .62223 L
.37777 .61598 L
.38755 .60593 L
.39407 .59938 L
.40353 .58963 L
.41037 .58278 L
.41964 .57334 L
.42666 .56629 L
.43574 .55704 L
.44296 .54981 L
.45193 .54074 L
.45926 .5334 L
.46812 .52445 L
.47555 .51702 L
.48432 .50815 L
.48432 .49185 L
.47555 .48298 L
.46812 .47555 L
.45926 .4666 L
.45193 .45926 L
Mistroke
.44296 .45019 L
.43574 .44296 L
.42666 .43371 L
.41964 .42666 L
.41037 .41722 L
.40353 .41037 L
.39407 .40062 L
.38755 .39407 L
.37777 .38402 L
.37156 .37777 L
.36147 .36724 L
.35576 .36147 L
.34518 .35047 L
.33992 .34518 L
.32888 .33342 L
.3244 .32888 L
.31258 .31636 L
.30886 .31258 L
.29628 .29878 L
.29385 .29628 L
.27999 .28108 L
.27893 .27999 L
.27999 .26492 L
Mfstroke
.7 g
.31258 .29395 m
.32778 .29628 L
.32888 .29656 L
.34518 .30073 L
.36147 .30379 L
.37777 .30774 L
.39407 .31241 L
.39461 .31258 L
.41037 .31791 L
.42666 .32442 L
.43654 .32888 L
.44296 .332 L
.45926 .34079 L
.46659 .34518 L
.47555 .35096 L
.49013 .36147 L
.49185 .36281 L
.50815 .37676 L
.50923 .37777 L
.52445 .39356 L
.52488 .39407 L
.53775 .41037 L
.54074 .41469 L
.54819 .42666 L
.55648 .44296 L
.55704 .4442 L
.56274 .45926 L
.56697 .47555 L
.56926 .49185 L
.56926 .50815 L
.56697 .52445 L
.56274 .54074 L
.55704 .5558 L
.55648 .55704 L
.54819 .57334 L
.54074 .58531 L
.53775 .58963 L
.52488 .60593 L
.52445 .60644 L
.50923 .62223 L
.50815 .62324 L
.49185 .63719 L
.49013 .63853 L
.47555 .64904 L
.46659 .65482 L
.45926 .65921 L
.44296 .668 L
.43654 .67112 L
.42666 .67558 L
.41037 .68209 L
.39461 .68742 L
.39407 .68759 L
.37777 .69226 L
.36147 .69621 L
.34518 .69927 L
.32888 .70344 L
.32778 .70372 L
.31258 .70605 L
.29711 .70372 L
.31121 .68742 L
.31258 .68601 L
.32653 .67112 L
.32888 .66873 L
.34186 .65482 L
.34518 .65147 L
.35758 .63853 L
.36147 .63459 L
.37327 .62223 L
.37777 .61771 L
.38921 .60593 L
.39407 .60104 L
.40512 .58963 L
.41037 .58437 L
.42119 .57334 L
.42666 .56784 L
.43725 .55704 L
.44296 .55132 L
.45342 .54074 L
.45926 .53489 L
.4696 .52445 L
.47555 .51849 L
.48577 .50815 L
.48577 .49185 L
.47555 .48151 L
.4696 .47555 L
.45926 .46511 L
.45342 .45926 L
.44296 .44868 L
.43725 .44296 L
.42666 .43216 L
.42119 .42666 L
.41037 .41563 L
.40512 .41037 L
.39407 .39896 L
.38921 .39407 L
.37777 .38229 L
.37327 .37777 L
.36147 .36541 L
.35758 .36147 L
.34518 .34853 L
.34186 .34518 L
.32888 .33127 L
.32653 .32888 L
.31258 .31399 L
.31121 .31258 L
.29711 .29628 L
F
0 g
.31258 .29395 m
.32778 .29628 L
.32888 .29656 L
.34518 .30073 L
.36147 .30379 L
.37777 .30774 L
.39407 .31241 L
.39461 .31258 L
.41037 .31791 L
.42666 .32442 L
.43654 .32888 L
.44296 .332 L
.45926 .34079 L
.46659 .34518 L
.47555 .35096 L
.49013 .36147 L
.49185 .36281 L
.50815 .37676 L
.50923 .37777 L
.52445 .39356 L
.52488 .39407 L
.53775 .41037 L
.54074 .41469 L
.54819 .42666 L
.55648 .44296 L
.55704 .4442 L
.56274 .45926 L
.56697 .47555 L
.56926 .49185 L
.56926 .50815 L
.56697 .52445 L
.56274 .54074 L
.55704 .5558 L
.55648 .55704 L
.54819 .57334 L
.54074 .58531 L
.53775 .58963 L
.52488 .60593 L
.52445 .60644 L
.50923 .62223 L
.50815 .62324 L
.49185 .63719 L
.49013 .63853 L
.47555 .64904 L
.46659 .65482 L
.45926 .65921 L
.44296 .668 L
.43654 .67112 L
.42666 .67558 L
.41037 .68209 L
Mistroke
.39461 .68742 L
.39407 .68759 L
.37777 .69226 L
.36147 .69621 L
.34518 .69927 L
.32888 .70344 L
.32778 .70372 L
.31258 .70605 L
.29711 .70372 L
.31121 .68742 L
.31258 .68601 L
.32653 .67112 L
.32888 .66873 L
.34186 .65482 L
.34518 .65147 L
.35758 .63853 L
.36147 .63459 L
.37327 .62223 L
.37777 .61771 L
.38921 .60593 L
.39407 .60104 L
.40512 .58963 L
.41037 .58437 L
.42119 .57334 L
.42666 .56784 L
.43725 .55704 L
.44296 .55132 L
.45342 .54074 L
.45926 .53489 L
.4696 .52445 L
.47555 .51849 L
.48577 .50815 L
.48577 .49185 L
.47555 .48151 L
.4696 .47555 L
.45926 .46511 L
.45342 .45926 L
.44296 .44868 L
.43725 .44296 L
.42666 .43216 L
.42119 .42666 L
.41037 .41563 L
.40512 .41037 L
.39407 .39896 L
.38921 .39407 L
.37777 .38229 L
.37327 .37777 L
.36147 .36541 L
.35758 .36147 L
.34518 .34853 L
Mistroke
.34186 .34518 L
.32888 .33127 L
.32653 .32888 L
.31258 .31399 L
.31121 .31258 L
.29711 .29628 L
.31258 .29395 L
Mfstroke
.8 g
.34518 .32601 m
.35579 .32888 L
.36147 .33103 L
.37777 .33741 L
.39407 .34302 L
.39943 .34518 L
.41037 .35018 L
.42666 .35784 L
.43377 .36147 L
.44296 .36656 L
.45926 .37679 L
.46071 .37777 L
.47555 .38858 L
.48232 .39407 L
.49185 .40255 L
.49982 .41037 L
.50815 .4194 L
.51411 .42666 L
.52445 .44148 L
.52536 .44296 L
.53406 .45926 L
.5402 .47555 L
.54074 .47746 L
.54361 .49185 L
.54361 .50815 L
.54074 .52254 L
.5402 .52445 L
.53406 .54074 L
.52536 .55704 L
.52445 .55852 L
.51411 .57334 L
.50815 .5806 L
.49982 .58963 L
.49185 .59745 L
.48232 .60593 L
.47555 .61142 L
.46071 .62223 L
.45926 .62321 L
.44296 .63344 L
.43377 .63853 L
.42666 .64216 L
.41037 .64982 L
.39943 .65482 L
.39407 .65698 L
.37777 .66259 L
.36147 .66897 L
.35579 .67112 L
.34518 .67399 L
.3289 .67112 L
.34396 .65482 L
.34518 .65358 L
.35952 .63853 L
.36147 .63654 L
.37508 .62223 L
.37777 .61952 L
.39093 .60593 L
.39407 .60276 L
.40676 .58963 L
.41037 .58602 L
.42279 .57334 L
.42666 .56944 L
.43881 .55704 L
.44296 .55288 L
.45495 .54074 L
.45926 .53642 L
.47111 .52445 L
.47555 .52 L
.48727 .50815 L
.48727 .49185 L
.47555 .48 L
.47111 .47555 L
.45926 .46358 L
.45495 .45926 L
.44296 .44712 L
.43881 .44296 L
.42666 .43056 L
.42279 .42666 L
.41037 .41398 L
.40676 .41037 L
.39407 .39724 L
.39093 .39407 L
.37777 .38048 L
.37508 .37777 L
.36147 .36346 L
.35952 .36147 L
.34518 .34642 L
.34396 .34518 L
.3289 .32888 L
F
0 g
.34518 .32601 m
.35579 .32888 L
.36147 .33103 L
.37777 .33741 L
.39407 .34302 L
.39943 .34518 L
.41037 .35018 L
.42666 .35784 L
.43377 .36147 L
.44296 .36656 L
.45926 .37679 L
.46071 .37777 L
.47555 .38858 L
.48232 .39407 L
.49185 .40255 L
.49982 .41037 L
.50815 .4194 L
.51411 .42666 L
.52445 .44148 L
.52536 .44296 L
.53406 .45926 L
.5402 .47555 L
.54074 .47746 L
.54361 .49185 L
.54361 .50815 L
.54074 .52254 L
.5402 .52445 L
.53406 .54074 L
.52536 .55704 L
.52445 .55852 L
.51411 .57334 L
.50815 .5806 L
.49982 .58963 L
.49185 .59745 L
.48232 .60593 L
.47555 .61142 L
.46071 .62223 L
.45926 .62321 L
.44296 .63344 L
.43377 .63853 L
.42666 .64216 L
.41037 .64982 L
.39943 .65482 L
.39407 .65698 L
.37777 .66259 L
.36147 .66897 L
.35579 .67112 L
.34518 .67399 L
.3289 .67112 L
.34396 .65482 L
Mistroke
.34518 .65358 L
.35952 .63853 L
.36147 .63654 L
.37508 .62223 L
.37777 .61952 L
.39093 .60593 L
.39407 .60276 L
.40676 .58963 L
.41037 .58602 L
.42279 .57334 L
.42666 .56944 L
.43881 .55704 L
.44296 .55288 L
.45495 .54074 L
.45926 .53642 L
.47111 .52445 L
.47555 .52 L
.48727 .50815 L
.48727 .49185 L
.47555 .48 L
.47111 .47555 L
.45926 .46358 L
.45495 .45926 L
.44296 .44712 L
.43881 .44296 L
.42666 .43056 L
.42279 .42666 L
.41037 .41398 L
.40676 .41037 L
.39407 .39724 L
.39093 .39407 L
.37777 .38048 L
.37508 .37777 L
.36147 .36346 L
.35952 .36147 L
.34518 .34642 L
.34396 .34518 L
.3289 .32888 L
.34518 .32601 L
Mfstroke
.9 g
.37777 .36205 m
.39407 .3711 L
.40801 .37777 L
.41037 .37901 L
.42666 .38775 L
.43603 .39407 L
.44296 .39886 L
.45926 .40984 L
.45995 .41037 L
.47555 .42383 L
.47868 .42666 L
.49185 .43894 L
.49556 .44296 L
.50804 .45926 L
.50815 .45941 L
.51929 .47555 L
.52445 .48757 L
.52549 .49185 L
.52549 .50815 L
.52445 .51243 L
.51929 .52445 L
.50815 .54059 L
.50804 .54074 L
.49556 .55704 L
.49185 .56106 L
.47868 .57334 L
.47555 .57617 L
.45995 .58963 L
.45926 .59016 L
.44296 .60114 L
.43603 .60593 L
.42666 .61225 L
.41037 .62099 L
.40801 .62223 L
.39407 .6289 L
.37777 .63795 L
.37704 .62223 L
.37777 .62149 L
.39278 .60593 L
.39407 .60462 L
.40851 .58963 L
.41037 .58777 L
.42447 .57334 L
.42666 .57113 L
.44044 .55704 L
.44296 .55452 L
.45655 .54074 L
.45926 .53803 L
.47269 .52445 L
.47555 .52158 L
.48883 .50815 L
.48883 .49185 L
.47555 .47842 L
.47269 .47555 L
.45926 .46197 L
.45655 .45926 L
.44296 .44548 L
.44044 .44296 L
.42666 .42887 L
.42447 .42666 L
.41037 .41223 L
.40851 .41037 L
.39407 .39538 L
.39278 .39407 L
.37777 .37851 L
.37704 .37777 L
F
0 g
.37777 .36205 m
.39407 .3711 L
.40801 .37777 L
.41037 .37901 L
.42666 .38775 L
.43603 .39407 L
.44296 .39886 L
.45926 .40984 L
.45995 .41037 L
.47555 .42383 L
.47868 .42666 L
.49185 .43894 L
.49556 .44296 L
.50804 .45926 L
.50815 .45941 L
.51929 .47555 L
.52445 .48757 L
.52549 .49185 L
.52549 .50815 L
.52445 .51243 L
.51929 .52445 L
.50815 .54059 L
.50804 .54074 L
.49556 .55704 L
.49185 .56106 L
.47868 .57334 L
.47555 .57617 L
.45995 .58963 L
.45926 .59016 L
.44296 .60114 L
.43603 .60593 L
.42666 .61225 L
.41037 .62099 L
.40801 .62223 L
.39407 .6289 L
.37777 .63795 L
.37704 .62223 L
.37777 .62149 L
.39278 .60593 L
.39407 .60462 L
.40851 .58963 L
.41037 .58777 L
.42447 .57334 L
.42666 .57113 L
.44044 .55704 L
.44296 .55452 L
.45655 .54074 L
.45926 .53803 L
.47269 .52445 L
.47555 .52158 L
Mistroke
.48883 .50815 L
.48883 .49185 L
.47555 .47842 L
.47269 .47555 L
.45926 .46197 L
.45655 .45926 L
.44296 .44548 L
.44044 .44296 L
.42666 .42887 L
.42447 .42666 L
.41037 .41223 L
.40851 .41037 L
.39407 .39538 L
.39278 .39407 L
.37777 .37851 L
.37704 .37777 L
.37777 .36205 L
Mfstroke
1 g
.42666 .41228 m
.44296 .42652 L
.44326 .42666 L
.45926 .44013 L
.4629 .44296 L
.47555 .45233 L
.48375 .45926 L
.49185 .46922 L
.4984 .47555 L
.50815 .4869 L
.51099 .49185 L
.51099 .50815 L
.50815 .5131 L
.4984 .52445 L
.49185 .53078 L
.48375 .54074 L
.47555 .54767 L
.4629 .55704 L
.45926 .55987 L
.44326 .57334 L
.44296 .57348 L
.42666 .58772 L
.42632 .57334 L
.42666 .57299 L
.44222 .55704 L
.44296 .55629 L
.45828 .54074 L
.45926 .53976 L
.47439 .52445 L
.47555 .52328 L
.4905 .50815 L
.4905 .49185 L
.47555 .47672 L
.47439 .47555 L
.45926 .46024 L
.45828 .45926 L
.44296 .44371 L
.44222 .44296 L
.42666 .42701 L
.42632 .42666 L
F
0 g
.42666 .41228 m
.44296 .42652 L
.44326 .42666 L
.45926 .44013 L
.4629 .44296 L
.47555 .45233 L
.48375 .45926 L
.49185 .46922 L
.4984 .47555 L
.50815 .4869 L
.51099 .49185 L
.51099 .50815 L
.50815 .5131 L
.4984 .52445 L
.49185 .53078 L
.48375 .54074 L
.47555 .54767 L
.4629 .55704 L
.45926 .55987 L
.44326 .57334 L
.44296 .57348 L
.42666 .58772 L
.42632 .57334 L
.42666 .57299 L
.44222 .55704 L
.44296 .55629 L
.45828 .54074 L
.45926 .53976 L
.47439 .52445 L
.47555 .52328 L
.4905 .50815 L
.4905 .49185 L
.47555 .47672 L
.47439 .47555 L
.45926 .46024 L
.45828 .45926 L
.44296 .44371 L
.44222 .44296 L
.42666 .42701 L
.42632 .42666 L
.42666 .41228 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{332.375, 332.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006O0001Wb000`400?l00000o`00003ooooooonP
ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00oooooonP
ooooo`00i_ooool2o`0000;ooooo0_l0002cooooo`00i_ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMgK?ooooo003Wooooo`04omgMgOl0003o410@olc<c;Cooooo003Wooooo`04onk^k_lQ8B7o410@
onk^k[Cooooo003Wooooo`04ob4Q8OmgMgOoMgMgoc8b<[Cooooo003Vooooo`;o00000_ooool2o`00
0;?ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooooj3ooooo003ooooo
oj3ooooo003ooooooj3ooooo000looooo`Co000000?o410@ooooooooool0Aoooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0A_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^04[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM04[ooooo1?l000000ol@413oooooooooo`03ooooo`00?_oo
ool00ol0003oooooooooo`19ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0AOooool01OmgMgOoV9RHoooooonHV9SoMgMg04[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`1;ooooo`03o`000?oooooooooo
00Gooooo000cooooo`Ko00001Oooool00ol0003oooooooooo`11ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool0A?ooool01Ol@413ooooooooooooooooo
410@04[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool01Oooool003kooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool0AOooool01Ol0003ooooooooooooooooo000004[ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo04_ooooo00?o0000oooooooo
ool01Oooool003kooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c016ooooo`05o`000?ooooooooooooooool00000B_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01<ooooo`03o`00
0?oooooooooo00Gooooo000nooooo`03o`000?oooooooooo04Wooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo04Sooooo00Go410@oooooooooooooooooa0@401:ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
00Gooooo000nooooo`03o`000?oooooooooo04Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo04Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo000l
ooooo`03oeEEEOmVIVKo000004_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000Aooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^04[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
0000Boooool00omEEEGoIVIVo`000007ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonP
ooooo`00oooooonPooooo`00oooooonPooooo`00oooooonPooooo`00<oooooooo`0006go0000000c
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Cooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Cooooo0Ol0000003?ooooo00?o0000oooooooo
ool0oooooomYooooo`7o0000000Yooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3oooooofWooooo0Ol0000002_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooofWooooo0Ol00000023ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooomYooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo1?l0003ooooo
ofKooooo0ol0000002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooooooo
0000G_l00007ooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooooooo`0005ko00001oooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Coooooool0001No`0000Oooooo0Ol0000002Wooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?ooooooo`0005ko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oo
oooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooo
oooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonAo`00
00go6ATI_ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooQOl0000[oaTI6Jgo
00001oooool1o`000000<oooool3o`0000CoooooOol0000loaTI6J;o00001Oooool3o`000000<ooo
ool00ol0003oooooooooo`04ooooogSo0000B_lI6AVKo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomeo`0005;o6ATIU_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooLol0001IoaTI6I7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooog;o
0000GOlI6AV>o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom`o`0006;o6ATI
Rol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooKOl0001XoaTI6HSo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooofOo0000LOlI6AV5o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomVo`0007Go6ATIP_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooI?l0001ioaTI6H3o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooof7o0000O_lI6AUno`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomNo`0008?o6ATIO?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooG?l00028
oaTI6GWo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooe_o0000RolI6AUgo`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomJo`0008go6ATIM_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooF?l0002AoaTI6GCo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooooeKo0000UOlI6AUbo`0000Oooooo0Ol0000003?ooooo0ol00004
oooooeCo0000VOlI6AU`o`0000Gooooo0ol0000003?ooooo00?o0000ooooooooool01?oooomCo`00
02co6ATI8?l0001@oaTI6Fko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooe7o
0000:?lI6AT6o`00023o<c<c2ol00017oaTI6Fco00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooe3o00009?lI6AT5o`00037o<c<c1_l00012oaTI6F_o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooodoo00008OlI6AT4o`0003co<c<c1?l00010oaTI6FWo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooodko00007olI6AT3o`0004Co<c<c0ol0000n
oaTI6FSo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodgo00007?lI6AT4o`00
04[o<c<c1?l0000loaTI6FKo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodco
00006_lI6AT3o`0005;o<c<c1Ol0000hoaTI6FGo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooood[o00006_lI6AT2o`0005[o<c<c0ol0000hoaTI6F;o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooodSo00006OlI6AT3o`0005oo<c<c0_l0000goaTI6F7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooodKo00006?lI6AT3o`0006Co<c<c0_l0000f
oaTI6F3o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooood?o00006?lI6AT3o`00
06Wo<c<c0_l0000eoaTI6Eoo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooood3o
00006OlI6AT2o`0006ko<c<c0ol0000doaTI6Ego00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooocgo00006_lI6AT2o`0007?o<c<c0ol0000boaTI6Eco00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooocco00006?lI6AT3o`0007So<c<c0_l0000boaTI6E[o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooocco00005_lI6AT2o`0007go<c<c0_l0000a
oaTI6EWo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooc_o00005OlI6AT2o`00
087o<c<c0_l0000aoaTI6EOo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooc[o
00005?lI6AT2o`0008Go<c<c0_l0000`oaTI6EKo00001oooool1o`000000<oooool3o`0000Cooooo
>_l0000BoaTI6@;o0000;?lc<c<Ho`0004Go<c<c00?o0000oaTI6OlI6AT0;_lI6AUEo`0000Gooooo
0ol0000003?ooooo00?o0000ooooooooool01?oooolio`00017o6ATI0_l0000Xoc<c<`Ko00006?m<
C4`;o`0003_o<c<c0ol0000^oaTI6ECo00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooocWo00003olI6AT2o`0002Co<c<c1_l0000Yoda<C0?o0000>olc<c<2o`0002go6ATIDol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>Ol0000=oaTI6@;o00008?lc<c<6o`00
03;oC4a<1?l0000ioc<c<`03o`000?lI6AWo6ATI02_o6ATID_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>Ol0000;oaTI6@;o00007_lc<c<4o`0003coC4a<1_l0000doc<c<`;o
0000;?lI6AUAo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooljo`0000So6ATI
0_l0000Moc<c<`?o0000A_m<C4`4o`0003;o<c<c00?o0000oaTI6OlI6AT0:_lI6AU@o`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?ooooljo`0000Oo6ATI00?o0000oc<c<olc<c<06Olc
<c<4o`0004goC4a<0_l0000aoc<c<`03o`000?lI6AWo6ATI02[o6ATICol00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01Go<c<c1Ol0001C
oda<C0Co0000;_lc<c<2o`0002_o6ATIC_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01?o<c<c0_l0001Loda<C0?o0000;Olc<c<2o`00
02[o6ATICOl00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>ol00005oaTI6@03
o`000?lc<c?o<c<c017o<c<c0_l0001Qoda<C0;o0000;Olc<c<00ol0003o6ATIoaTI6@0XoaTI6Dco
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocco00001?lI6AT00ol0003o<c<c
oc<c<`0=oc<c<`Co0000IOm<C4`2o`0002co<c<c00?o0000oaTI6OlI6AT0:?lI6AU;o`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooollo`0000Co6ATI00?o0000oc<c<olc<c<02Olc
<c<4o`0006_oC4a<0_l0000[oc<c<`03o`000?lI6AWo6ATI02So6ATIB_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo?Ol00003oaTI6@03o`000?lc<c?o<c<c00Ko<c<c0ol0001a
oda<C0;o0000:_lc<c<00ol0003o6ATIoaTI6@0XoaTI6DWo00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooocko00000_lI6AT00ol0003o<c<coc<c<`04oc<c<`;o0000M_m<C4`2o`00
02Wo<c<c0_l0000YoaTI6DSo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocoo
00000_lI6AT00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<07OoC4a<0_l0000Yoc<c<`03
o`000?lI6AWo6ATI02Oo6ATIAol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
@?l000000olI6AWo0000oc<c<`04oc<c<`03o`000?m<C4coC4a<02CoC4a<7_l0000goda<C0;o0000
:?lc<c<00ol0003o6ATIoaTI6@0VoaTI6DOo00001oooool1o`000000<oooool00ol0003ooooooooo
o`04oooood7o000000?o6ATIo`000?lc<c<00olc<c<00ol0003oC4a<oda<C00Noda<C0Ko00007_mV
IVH6o`0003?oC4a<0_l0000Woc<c<`03o`000?lI6AWo6ATI02Ko6ATIA_l00007ooooo`7o0000000c
ooooo`?o00001?oooom2o`000005oaTI6Ol0003o<c<coc<c<ol000006om<C4`6o`0002[oIVIV1_l0
000_oda<C0;o00009_lc<c<00ol0003o6ATIoaTI6@0VoaTI6DGo00001Oooool3o`000000<oooool0
0ol0003oooooooooo`04ooooodCo00000_lc<c<00ol0003oC4a<oda<C00Doda<C0Go0000=_mVIVH3
o`0002koC4a<00?o0000oc<c<olc<c<09?lc<c<00ol0003o6ATIoaTI6@0VoaTI6DCo00001oooool1
o`000000<oooool00ol0003oooooooooo`04ooooodSo00003_m<C4`7o`0003koIVIV1?l0000[oda<
C0;o00009Olc<c<00ol0003o6ATIoaTI6@0VoaTI6D?o00001oooool1o`000000<oooool00ol0003o
ooooooooo`04ooooodGo000000?o6ATIo`000?l000001Om<C4`9o`0004WoIVIV1?l0000Yoda<C0?o
00008olc<c<2o`0002Oo6ATI@_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
A_l000000olI6AWo0000o`000004oda<C003o`000?mVIVKoIVIV05?oIVIV0ol0000Yoda<C0;o0000
8olc<c<00ol0003o6ATIoaTI6@0UoaTI6D7o00001oooool1o`000000<oooool00ol0003ooooooooo
o`04ooooodOo000000?o6ATIo`000?l000000om<C4`00ol0003oIVIVofIVIP1FofIVIP?o0000:?m<
C4`2o`0002;o<c<c00?o0000oaTI6OlI6AT09?lI6AU1o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooom8o`000003oaTI6Ol0003o000000;oC4a<00?o0000ofIVI_mVIVH0FOmVIVH3
o`0002OoC4a<00?o0000oc<c<olc<c<08?lc<c<00ol0003o6ATIoaTI6@0ToaTI6D3o00001oooool1
o`000000<oooool00ol0003oooooooooo`04ooooodWo000000Go6ATIo`000?l0003oC4a<o`00001N
ofIVIP?o00009Om<C4`00ol0003o<c<coc<c<`0Poc<c<`03o`000?lI6AWo6ATI02Co6ATI?ol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol000000olc<c?o0000o`00001QofIV
IP;o00009?m<C4`2o`00027o<c<c00?o0000oaTI6OlI6AT08olI6AToo`0000Oooooo0Ol0000003?o
oooo00?o0000ooooooooool01?oooom<o`000003oc<c<ol0003o000006;oIVIV0_l0000Toda<C003
o`000?lc<c?o<c<c01oo<c<c00?o0000oaTI6OlI6AT08olI6ATno`0000Oooooo0Ol0000003?ooooo
00?o0000ooooooooool01?oooom>o`000003oda<C?l0003oIVIV01OoIVIV4_l0000iofIVIP;o0000
8om<C4`00ol0003o<c<coc<c<`0Ooc<c<`03o`000?lI6AWo6ATI02?o6ATI?Ol00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00CoooooCol000000om<C4co0000ofIVIP0:ofIVIPco00004_mo
Ogl<o`0002ooIVIV0_l0000Roda<C003o`000?lc<c?o<c<c01oo<c<c00?o0000oaTI6OlI6AT08_lI
6ATmo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom@o`000003oda<C?l0003o
IVIV00?oIVIV1_l0000ZogmoO`Ko0000:omVIVH3o`00023oC4a<00?o0000oc<c<olc<c<07olc<c<0
0ol0003o6ATIoaTI6@0RoaTI6Cco00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oe7o000000?oC4a<o`000?l000000_l0000fogmoO`Go0000:OmVIVH00ol0003oC4a<oda<C00Noda<
C0;o00008?lc<c<00ol0003o6ATIoaTI6@0RoaTI6C_o00001oooool1o`000000<oooool00ol0003o
ooooooooo`04oooooeCo0000?OmoOgl3o`0002OoIVIV00?o0000oda<C?m<C4`07om<C4`00ol0003o
<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI02;o6ATI>ol00007ooooo`7o0000000Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00CoooooEOl0000oogmoO`Co00009?mVIVH00ol0003oC4a<oda<C00Ooda<
C003o`000?lc<c?o<c<c01go<c<c00?o0000oaTI6OlI6AT08_lI6ATjo`0000Oooooo0Ol0000001So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00CoooooE_l00012ogmoO`Co00008OmVIVH2o`00023oC4a<00?o0000oc<c
<olc<c<07Olc<c<00ol0003o6ATIoaTI6@0RoaTI6CWo00001oooool1o`0000004?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?oooomGo`0004GoOgmo0_l0000QofIVIP;o00007om<C4`00ol0003o<c<coc<c<`0Moc<c
<`03o`000?lI6AWo6ATI027o6ATI>Ol00007ooooo`7o0000000Hooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`Co00000ooooomHo`0004KoOgmo0_l0000QofIV
IP;o00007_m<C4`00ol0003o<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI027o6ATI>?l00005oooo
o`?o0000000Hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool01?oooomIo`0004OoOgmo0ol0000PofIVIP;o00007Om<C4`0
0ol0003o<c<coc<c<`0Moc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00CoooooF_l00005ogmoO`[o0000>_moOgl3o`0001ooIVIV00?o0000oda<C?m<C4`06om<C4`0
0ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00CoooooF_l00005ogmoO`03o`000?nIVIWoVIVI00OoVIVI3?l0000aogmoO`;o00007_mVIVH0
0ol0003oC4a<oda<C00Koda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08OlI6ATf
o`0000Oooooo0Ol0000001Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`04oooooe_o00001?moOgl00ol0003oVIVIoiVIV@0CoiVIV@Go0000;_moOgl2
o`0001goIVIV00?o0000oda<C?m<C4`06om<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo
6ATI023o6ATI=_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooG?l00002ogmo
O`03o`000?nIVIWoVIVI01WoVIVI1_l0000ZogmoO`;o00007?mVIVH00ol0003oC4a<oda<C00Koda<
C003o`000?lc<c?o<c<c01_o<c<c00?o0000oaTI6OlI6AT08OlI6ATeo`0000Oooooo0Ol0000003?o
oooo00?o0000ooooooooool01?oooomMo`000003ogmoOol0003oVIVI023oVIVI1_l0000VogmoO`;o
00006omVIVH2o`0001coC4a<00?o0000oc<c<olc<c<06olc<c<00ol0003o6ATIoaTI6@0PoaTI6CGo
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooeoo00009onIVIT5o`0002?oOgmo
0_l0000KofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATI
oaTI6@0PoaTI6CCo00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooof3o0000:onI
VIT3o`0002;oOgmo00?o0000ofIVI_mVIVH06OmVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc
<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATdo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomQo`0002goVIVI1?l0000OogmoO`;o00006_mVIVH00ol0003oC4a<oda<C00H
oda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATco`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomRo`00033oVIVI1?l0000MogmoO`03o`000?mVIVKoIVIV
01SoIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI
01oo6ATI<ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooHol0000coiVIV@;o
00007?moOgl2o`0001WoIVIV0_l0000Ioda<C003o`000?lc<c?o<c<c01_o<c<c00?o0000oaTI6OlI
6AT08?lI6ATbo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomTo`0000CoVIVI
1ol0000YoiVIV@;o00007?moOgl00ol0003oIVIVofIVIP0HofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000oc<c<olc<c<06olc<c<00ol0003o6ATIoaTI6@0OoaTI6C;o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooofSo00001onc/k<4o`0002OoVIVI0ol0000JogmoO`?o00006?mV
IVH00ol0003oC4a<oda<C00Goda<C0;o00007?lc<c<00ol0003o6ATIoaTI6@0OoaTI6C7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooofKo00003Onc/k<3o`0002OoVIVI0ol0000J
ogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0J
oc<c<`03o`000?lI6AWo6ATI01oo6ATI<Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooIol0000?ok>c/`Co00009_nIVIT2o`0001WoOgmo00?o0000ofIVI_mVIVH05_mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT`o`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomXo`0001;o/k>c1_l0000RoiVIV@;o
00006?moOgl00ol0003oIVIVofIVIP0FofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000oc<c<olc
<c<06_lc<c<00ol0003o6ATIoaTI6@0OoaTI6Boo00001oooool1o`000000<oooool3o`0000Cooooo
JOl0000Gok>c/`Go00007onIVIT2o`0001OoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT_o`0000Gooooo
0ol0000003?ooooo00?o0000ooooooooool01?oooomZo`0001_o/k>c0ol0000NoiVIV@03o`000?mo
OgooOgmo01GoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?lc
<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07olI6AT^o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooom/o`0001co/k>c0ol0000LoiVIV@;o00005_moOgl2o`0001KoIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI6AWo6ATI01ko6ATI;_l00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooK?l0000Ook>c/`?o00006onIVIT2o`00
01KoOgmo00?o0000ofIVI_mVIVH05?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c
01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT^o`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooom]o`00027o/k>c0ol0000JoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mV
IVH05?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI
6AT07_lI6AT]o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom^o`0002?o/k>c
0ol0000HoiVIV@;o00005OmoOgl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000oc<c<olc<c<06_lc<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooofoo00009Onc/k<2o`0001SoVIVI00?o0000ogmoOomoOgl04omo
Ogl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000oc<c<olc<c<06Olc
<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooog3o00001?nc/k<5o`0001go/k>c0_l0000GoiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000
ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01Wo<c<c00?o0000
oaTI6OlI6AT07_lI6AT/o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomdo`00
00Goc<c<0ol0000Lok>c/`;o00005_nIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV
01?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI
01go6ATI;?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooL_l0000:olc<c0?o
00006onc/k<2o`0001GoVIVI0_l0000DogmoO`03o`000?mVIVKoIVIV01;oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI01go6ATI;?l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooLol0000<olc<c0?o00006_nc/k<2o`0001GoVIVI
00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooogCo00003_o<c<`3o`0001Wo/k>c0_l0000DoiVIV@03o`000?mo
OgooOgmo01;oOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?lc
<c?o<c<c01Wo<c<c00?o0000oaTI6OlI6AT07OlI6AT[o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomeo`00013oc<c<0ol0000Hok>c/`03o`000?nIVIWoVIVI01;oVIVI00?o0000
ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooogKo00004_o<c<`2o`0001Oo/k>c00?o0000oiVIVOnIVIT04_nIVIT00ol0
003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI01go6ATI:_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooMol0000Colc<c0;o00005_nc/k<2o`0001?oVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc
<c<06?lc<c<00ol0003o6ATIoaTI6@0NoaTI6BWo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooogSo00005?o<c<`2o`0001Ko/k>c0_l0000BoiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07_lI6ATYo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomio`0001Goc<c<0ol0000Eok>c/`;o00004OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mV
IVKoIVIV01;oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI
6AWo6ATI01ko6ATI:?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooN_l0000G
olc<c0?o00005?nc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo017oOgmo00?o0000
ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000
oaTI6OlI6AT07_lI6ATXo`0000Oooooo0Ol0000003?ooooo0ol00004ooooog_o00006Oo<c<`2o`00
01?o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV
017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI
01go6ATI:?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00CoooooO?l0000Jolc<c003
o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03
o`000?lI6AWo6ATI01ko6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
OOl00005olc<c0;o00004oo<c<`2o`0001;o/k>c0_l0000@oiVIV@03o`000?moOgooOgmo013oOgmo
00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07OlI6ATWo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oommo`0000Goc<c<00Co0000onKVi_l0003o00004oo<c<`00ol0003o/k>cok>c/`0Aok>c/`03o`00
0?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6BOo0000
1oooool1o`000000<oooool00ol0003oooooooooo`04ooooogko00001?o<c<`01?l0003oi^KVonKV
i_oVi^H2o`0001;oc<c<0_l0000Bok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl0
3omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<0
6?lc<c<00ol0003o6ATIoaTI6@0LoaTI6BOo00001oooool1o`000000<oooool00ol0003ooooooooo
o`04ooooogoo00000oo<c<`00ol0003oi^KVonKViP03onKViP;o00004_o<c<`2o`00017o/k>c00?o
0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI01co6ATI9ol0
0007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooP?l00002olc<c003o`000?oVi^Ko
i^KV00Goi^KV0_l0000Bolc<c0;o00004?nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgoo
Ogmo00koOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o
<c<c01Oo<c<c00?o0000oaTI6OlI6AT07OlI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000oooo
ooooool01?oooon1o`000003olc<c?l0003oi^KV00Soi^KV00?o0000olc<c?o<c<`04Oo<c<`00ol0
003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl03_moOgl00ol0
003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0
003o6ATIoaTI6@0LoaTI6BKo00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooh?o
00002_oVi^H3o`00013oc<c<0_l0000@ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomo
Ogl03_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc
<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BKo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooohCo00003?oVi^H2o`00013oc<c<00?o0000ok>c/onc/k<03_nc/k<00ol0003oVIVI
oiVIV@0=oiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATVo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon5o`0000goi^KV0_l0000?olc<c0;o00003onc
/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00koOgmo00?o0000ofIVI_mVIVH04?mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI
6ATUo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon6o`0000koi^KV00?o0000
olc<c?o<c<`03_o<c<`00ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000
ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooohOo00003_oVi^H00ol0003oc<c<olc<c00>olc<c003o`000?nc/k?o/k>c
00go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV
013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI
01co6ATI9Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooR?l0000>onKViP03
o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo0Ol0000003?ooooo
00?o0000ooooooooool01?oooon9o`0000koi^KV0ol0000>olc<c0;o00003_nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon:o`00013oi^KV0_l0000>olc<c003o`000?nc
/k?o/k>c00_o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mV
IVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI
6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooRol0000A
onKViP03o`000?o<c<coc<c<00coc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo0Ol00000
03?ooooo0ol00004ooooohco00004OoVi^H2o`0000goc<c<00?o0000ok>c/onc/k<02onc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT06olI6ATTo`00
00Gooooo0ol0000003?ooooo00?o0000ooooooooool01?oooon=o`0001;oi^KV00?o0000olc<c?o<
c<`02oo<c<`00ol0003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl03OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc
<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6BCo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooohko00004_oVi^H2o`0000coc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon?o`0000Goi^KV0_l0000<onKViP03o`000?o<
c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?lc
<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooon@o`0000Coi^KV00?o0000ooooool000003?oVi^H00ol0003oc<c<olc<c009
olc<c003o`000?nc/k?o/k>c00_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0G
oc<c<`03o`000?lI6AWo6ATI01_o6ATI8ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooTOl00003onKViP04o`000?ooooooooooo`0000coi^KV00?o0000olc<c?o<c<`02Oo<c<`0
0ol0003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl0
0ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05olc<c<0
0ol0003o6ATIoaTI6@0KoaTI6B?o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooo
oi;o00000_oVi^H01Ol0003ooooooooooooooooo000000coi^KV00?o0000olc<c?o<c<`02Oo<c<`2
o`0000_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKo
IVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo
6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooTol000000ooV
i^Ko0000ooooo`03ooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0
003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiGo
00001Oooool2o`0000_oi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0003o/k>cok>c/`09ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiKo00001_ooool00ol0003oi^KV
onKViP09onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonGo`0000Kooooo00?o0000onKVi_oVi^H02OoV
i^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooV?l00006ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooiWo00001_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<
00Soc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATRo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonJo`0000Kooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03
o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03
o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Vol00006ooooo`;o00002_oVi^H00ol0003oc<c<olc<c007olc<c0;o00002_nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?lc<c?o<c<c01Go<c<c00?o0000oaTI6OlI6AT06olI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonKo`0000Sooooo00?o0000onKVi_oVi^H01ooV
i^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003o<c<coc<c<`0Eoc<c<`03o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooW?l00008ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000
olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0KoaTI6B;o00001oooool1o`000000<oooool3o`00
00CoooooWOl00008ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0
003o/k>cok>c/`08ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0
003o6ATIoaTI6@0KoaTI6B;o00001Oooool3o`000000<oooool00ol0003oooooooooo`04oooooiko
00002?ooool2o`0000Ooi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`07ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03
o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooioo00002Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonQo`0000Sooooo00?o0000onKVi_oVi^H01OoV
i^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnI
VIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooXOl00008ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000
ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000
oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooj;o00002?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonSo`0000Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03
o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Y?l00008ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATI
oaTI6@0JoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooojGo00002?oo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc
/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI
6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonWo`0000Oooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000
oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000
oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooYol00007ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<
017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`00
0000<oooool00ol0003oooooooooo`04ooooojSo00001oooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03
o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003
o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol0000000_ooooo
0ol000000ol@413oooooooooo`0Rooooo`03o`000?oooooooooo00CoooooZOl00007ooooo`03o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o0000
1oooool1o`0000003Oooool00ol@413o^[Zjooooo`0Sooooo`03o`000?oooooooooo00CoooooZ_l0
0007ooooo`03o`000?oVi^Koi^KV00?oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIV
IP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI
6@0JoaTI6B7o00001oooool1o`0000003Oooool00onHV9So<S8booooo`0Sooooo`03o`000?oooooo
oooo00CoooooZol00007ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02omoOgl0
0ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<0
0ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`0000003Oooool00ooMgMgo0000okZj^P0Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojco00001oooool0
0ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01onc/k<0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH0
0ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQ
o`0000Oooooo0Ol0000000gooooo00?oEEEEogMgMom4A4@06?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool01?oooon/o`0000Oooooo00?o0000onKVi_oVi^H00_oVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT0
0ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`0
0ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000<oooo
o`05omgMgOl@413oooooob4Q8OoMgMd05oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool01?oooon/o`0000Oooooo00?o0000onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c
<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000<ooooo`05ofIVI_n7QhOo
oooooiRHV?mEEED05oooool01Ol0003ooooooooooooooooo000000Kooooo1?l00003ooooojco0000
1oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT0
6_lI6ATQo`0000Gooooo0ol0000000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`0Eooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooojco0000
1oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT0
6_lI6ATQo`0000Oooooo0Ol0000000_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`0Dooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooojco
00001oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<01onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI
6AT06_lI6ATQo`0000Oooooo0Ol0000002Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo[?l00007ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomo
Ogl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc
<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000:?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooon[o`0000Oooooo00?o0000onKVi_oV
i^H00_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<
C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooZ_l00007ooooo`03o`000?oVi^Koi^KV00?oi^KV
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<
00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooojWo00002?ooool00ol0003oi^KVonKViP03onKViP03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?mo
OgooOgmo00_oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc
<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooonXo`0000Sooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;
ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01[o6ATI8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooYol00008ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl02omoOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0JoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooojKo
00002?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI
6AT06_lI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooonUo`0000Sooooo
00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c
00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV
00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01[o6ATI
8Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooY?l00008ooooo`03o`000?oV
i^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nI
VIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<
C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0JoaTI6B7o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooj?o00002Oooool00ol0003oi^KVonKViP05
onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09
oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00A
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06_lI6ATQo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooonRo`0000Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0
003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0
003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01_o6ATI8Ol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooXOl00009ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomo
Ogl03?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc
<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooj3o00002?ooool2o`0000Ooi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0003o6ATI
oaTI6@0KoaTI6B7o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooioo00002?oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc
/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03_mV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT06olI
6ATQo`0000Oooooo0Ol0000003?ooooo0ol00004oooooiko00001oooool2o`0000Woi^KV00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000
oc<c<olc<c<05_lc<c<00ol0003o6ATIoaTI6@0KoaTI6B7o00001Oooool3o`000000<oooool00ol0
003oooooooooo`04oooooigo00001oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<
00Soc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c
01Ko<c<c00?o0000oaTI6OlI6AT06olI6ATQo`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooonLo`0000Oooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0<ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Eoc<c<`03
o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Vol00007ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>c
ok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATI
oaTI6@0KoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi_o00001_oo
ool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Ooc<c<0_l0000:ok>c/`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0KoaTI6B;o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooiWo00001_ooool2o`0000[oi^KV0_l0000:
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0<
ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01_o6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooV?l00006ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`02Oo<c<`00ol0
003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0
003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0KoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiOo
00001Oooool2o`0000_oi^KV00?o0000olc<c?o<c<`02Oo<c<`00ol0003o/k>cok>c/`09ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0?ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05Olc<c<00ol0003o6ATIoaTI6@0LoaTI6B;o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooiKo00001Oooool00ol0003oi^KV
onKViP0:onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00Aoda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATRo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooonEo`0000Gooooo00?o0000onKVi_oVi^H02_oV
i^H00ol0003oc<c<olc<c00:olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00CoooooUOl00004ooooo`;o00003?oVi^H00ol0003oc<c<olc<c009
olc<c003o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0F
oc<c<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooTol000000ooVi^Ko0000ooooo`02ooooo`03o`000?oVi^Koi^KV00[oi^KV0_l0000;olc<
c003o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0=ogmo
O`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0Foc<c
<`03o`000?lI6AWo6ATI01co6ATI8_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooT_l00002onKViP04o`000?ooooooooooo`0000coi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0
003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05_lc<c<00ol0
003o6ATIoaTI6@0LoaTI6B;o00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi7o
00000ooVi^H00ol0003oooooo`00000;onKViP;o00003?o<c<`00ol0003o/k>cok>c/`0;ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0>ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6B?o
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooi3o00001?oVi^H2o`0000_oi^KV
00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl03OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0KoaTI6B?o00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooohoo00001OoVi^H00ol0003oi^KVonKViP09onKViP03o`000?o<
c<coc<c<00_oc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH2o`0001CoC4a<00?o0000oc<c<olc<c<05_lc
<c<00ol0003o6ATIoaTI6@0LoaTI6B?o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooohko00004OoVi^H2o`0000goc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATSo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooon=o`00017oi^KV00?o0000olc<c?o<c<`03?o<c<`00ol0
003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl03OmoOgl00ol0
003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000oc<c<olc<c<05olc<c<00ol0
003o6ATIoaTI6@0KoaTI6BCo00001oooool1o`000000<oooool3o`0000CoooooS?l0000@onKViP;o
00003Oo<c<`2o`0000go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03
o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03
o`000?lI6AWo6ATI01_o6ATI9?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo
Rol0000@onKViP03o`000?o<c<coc<c<00coc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooon:o`0000ooi^KV0_l0000>olc<c003o`000?nc
/k?o/k>c00go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mV
IVKoIVIV00ooIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI
6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooROl0000>
onKViP;o00003oo<c<`00ol0003o/k>cok>c/`0<ok>c/`;o00003_nIVIT00ol0003oOgmoogmoO`0=
ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0G
oc<c<`03o`000?lI6AWo6ATI01co6ATI9?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooR?l0000>onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0
003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000oaTI6OlI6AT07?lI6ATTo`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon7o`0000koi^KV00?o0000olc<c?o<
c<`03Oo<c<`2o`0000oo/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0=ogmoO`03
o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o<c<coc<c<`0Goc<c<`03
o`000?lI6AWo6ATI01co6ATI9Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
Q_l0000=onKViP;o00003oo<c<`00ol0003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00goVIVI
00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooohGo00003?oVi^H2o`0000ooc<c<0_l0000@ok>c/`03o`000?nI
VIWoVIVI00goVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0LoaTI6BGo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooohCo00002ooVi^H2o`00013oc<c<00?o0000
ok>c/onc/k<03onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000
ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o0000
oaTI6OlI6AT07?lI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooon3o`00
00Woi^KV0ol0000Aolc<c003o`000?nc/k?o/k>c00oo/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0
003oOgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01co6ATI9_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooPOl000000oo<c<co0000onKViP06onKViP;o00004oo<c<`2o`00013o
/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01co
6ATI9_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooP?l00002olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`04Oo<c<`2o`00017o/k>c00?o0000oiVIVOnIVIT0
3_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
4om<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI01go6ATI9_l00007ooooo`7o0000
000cooooo`03o`000?oooooooooo00CoooooOol00003olc<c003o`000?oVi^Koi^KV00;oi^KV0_l0
000Bolc<c0;o00004_nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo00ooOgmo00?o
0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?lc<c?o<c<c01Oo<c<c00?o
0000oaTI6OlI6AT07OlI6ATVo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomn
o`0000Coc<c<00?o0000onKVi_oVi^H00_l0000Bolc<c0;o00004onc/k<00ol0003oVIVIoiVIV@0>
oiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07?lI6ATWo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooommo`0000Goc<c<0ol0000Colc<c003o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV
017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Goc<c<`03o`000?lI6AWo6ATI
01go6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooOOl00005olc<c003
o`000?o<c<coc<c<017oc<c<0_l0000Bok>c/`?o00004?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03
o`000?lI6AWo6ATI01go6ATI9ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
O?l0000Golc<c0?o00004onc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07OlI6ATWo`0000Oooooo0Ol0000003?ooooo0ol00004ooooog_o00005_o<
c<`2o`0001Go/k>c00?o0000oiVIVOnIVIT04?nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mV
IVKoIVIV017oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI
6AWo6ATI01go6ATI:?l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00CoooooN_l0000E
olc<c0;o00005_nc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo017oOgmo00?o0000
ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000
oaTI6OlI6AT07OlI6ATXo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomio`00
01Coc<c<0_l0000Fok>c/`;o00004_nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV
01;oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI
01ko6ATI:?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooN?l0000Colc<c0;o
00005_nc/k<2o`0001?oVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0CofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6BWo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooogOo00004_o<c<`2o`0001Oo/k>c
00?o0000oiVIVOnIVIT04OnIVIT2o`0001?oOgmo00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6ATYo`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?oooomgo`00013oc<c<0_l0000Hok>c/`03o`000?nI
VIWoVIVI017oVIVI00?o0000ogmoOomoOgl04omoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@0MoaTI6B[o00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooogKo00003_o<c<`3o`0001So/k>c0_l0000C
oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6ATZo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomeo`0000coc<c<0ol0000Iok>c/`;o00005?nIVIT00ol0
003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003o<c<coc<c<`0Hoc<c<`03o`000?lI6AWo6ATI01go6ATI:ol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooM?l0000:olc<c0?o00006_nc/k<2o`0001GoVIVI00?o0000ogmoOomo
Ogl04omoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000oc<c<olc
<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6B_o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooog?o00002?o<c<`3o`0001_o/k>c0_l0000FoiVIV@03o`000?moOgooOgmo01?oOgmo
00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c01So<c<c
00?o0000oaTI6OlI6AT07_lI6AT[o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomeo`0000?oc<c<0ol0000Lok>c/`;o00005_nIVIT2o`0001CoOgmo0_l0000EofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0MoaTI6Bco00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04ooooog3o00001Onc/k<3o`0001go/k>c0_l0000G
oiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?lc<c?o<c<c01So<c<c00?o0000oaTI6OlI6AT07_lI6AT/o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooom_o`0002Co/k>c0_l0000HoiVIV@03o`000?moOgooOgmo
01?oOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?lc<c?o<c<c
01Wo<c<c00?o0000oaTI6OlI6AT07OlI6AT]o`0000Oooooo0Ol0000003?ooooo00?o0000oooooooo
ool01?oooom^o`0002;o/k>c0ol0000HoiVIV@;o00005OmoOgl00ol0003oIVIVofIVIP0EofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003o6ATIoaTI6@0NoaTI6Bgo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofgo00008?nc/k<3o`0001WoVIVI
0_l0000FogmoO`03o`000?mVIVKoIVIV01GoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o<c<c
oc<c<`0Joc<c<`03o`000?lI6AWo6ATI01ko6ATI;Ol00007ooooo`7o0000000cooooo`03o`000?oo
oooooooo00CoooooK?l0000Nok>c/`?o00006onIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mV
IVKoIVIV01GoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI
6AWo6ATI01go6ATI;_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooJol0000L
ok>c/`?o00006onIVIT3o`0001OoOgmo00?o0000ofIVI_mVIVH05OmVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT^o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooom[o`0001Wo/k>c0ol0000LoiVIV@;o00006OmoOgl00ol0
003oIVIVofIVIP0EofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000oc<c<olc<c<06_lc<c<00ol0
003o6ATIoaTI6@0NoaTI6Bko00001oooool1o`000000<oooool3o`0000CoooooJ_l0000Eok>c/`Go
00007OnIVIT2o`0001WoOgmo0_l0000GofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000oc<c<olc
<c<06_lc<c<00ol0003o6ATIoaTI6@0NoaTI6Boo00001Oooool3o`000000<oooool00ol0003ooooo
ooooo`04ooooofWo00004?nc/k<6o`00023oVIVI0_l0000JogmoO`03o`000?mVIVKoIVIV01OoIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003o<c<coc<c<`0Joc<c<`03o`000?lI6AWo6ATI01oo6ATI
;ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooJ?l0000=ok>c/`Co00009?nI
VIT2o`0001_oOgmo00?o0000ofIVI_mVIVH05omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc
<c?o<c<c01[o<c<c00?o0000oaTI6OlI6AT07_lI6AT`o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomWo`0000_o/k>c0ol0000WoiVIV@03o`000?moOgooOgmo01[oOgmo00?o0000
ofIVI_mVIVH05omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?lc<c?o<c<c01[o<c<c00?o0000
oaTI6OlI6AT07olI6AT`o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomYo`00
00Go/k>c1?l0000WoiVIV@?o00006_moOgl3o`0001SoIVIV0_l0000Ioda<C0;o00007?lc<c<00ol0
003o6ATIoaTI6@0OoaTI6C7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofCo
00001OnIVIT5o`0002SoVIVI0ol0000LogmoO`03o`000?mVIVKoIVIV01SoIVIV00?o0000oda<C?m<
C4`06Om<C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lI6AWo6ATI01oo6ATI<Ol00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooHol0000`oiVIV@?o00007OmoOgl2o`0001[oIVIV
00?o0000oda<C?m<C4`06Om<C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lI6AWo6ATI01oo6ATI
<_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooH_l0000^oiVIV@?o00007omo
Ogl00ol0003oIVIVofIVIP0IofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000oc<c<olc<c<06olc
<c<00ol0003o6ATIoaTI6@0PoaTI6C;o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooof7o0000;?nIVIT3o`00023oOgmo0_l0000KofIVIP03o`000?m<C4coC4a<01WoC4a<00?o0000
oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0OoaTI6C?o00001oooool1o`000000<oooool00ol0
003oooooooooo`04ooooof3o0000:_nIVIT3o`0002;oOgmo00?o0000ofIVI_mVIVH06_mVIVH00ol0
003oC4a<oda<C00Ioda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oaTI6OlI6AT08?lI6ATco`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomOo`0002KoVIVI1Ol0000SogmoO`;o
00006omVIVH2o`0001_oC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0PoaTI6CCo
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooeoo00008?nIVIT6o`0002KoOgmo
0_l0000KofIVIP;o00007Om<C4`00ol0003o<c<coc<c<`0Loc<c<`03o`000?lI6AWo6ATI023o6ATI
=?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooGOl000000omoOgoo0000oiVI
V@0IoiVIV@Ko0000:_moOgl2o`0001coIVIV00?o0000oda<C?m<C4`07?m<C4`00ol0003o<c<coc<c
<`0Loc<c<`03o`000?lI6AWo6ATI023o6ATI=Ol00007ooooo`7o0000000cooooo`03o`000?oooooo
oooo00CoooooG?l00003ogmoO`03o`000?nIVIWoVIVI00coVIVI2ol0000^ogmoO`;o00007?mVIVH2
o`0001koC4a<00?o0000oc<c<olc<c<07?lc<c<00ol0003o6ATIoaTI6@0QoaTI6CGo00001oooool1
o`000000<oooool00ol0003oooooooooo`04oooooe_o00001?moOgl00ol0003oVIVIoiVIV@0<o`00
03OoOgmo0_l0000MofIVIP03o`000?m<C4coC4a<01goC4a<00?o0000oc<c<olc<c<07Olc<c<00ol0
003o6ATIoaTI6@0PoaTI6CKo00001oooool1o`0000006?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04
oooooe[o00001OmoOgl3o`00043oOgmo0ol0000NofIVIP03o`000?m<C4coC4a<01goC4a<00?o0000
oc<c<olc<c<07Olc<c<00ol0003o6ATIoaTI6@0QoaTI6CKo00001oooool1o`0000006?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool01?oooomIo`0004KoOgmo0ol0000PofIVIP;o00007_m<C4`00ol0003o<c<coc<c<`0M
oc<c<`03o`000?lI6AWo6ATI027o6ATI=ol00007ooooo`7o0000000Hooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`Co00000ooooomCo`000003oaTI6Ol0003o
000000;o0000A?moOgl3o`00027oIVIV0_l0000Noda<C0;o00007olc<c<00ol0003o6ATIoaTI6@0R
oaTI6COo00001Oooool3o`0000006?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`04oooooeOo0000@_moOgl3o`0002;oIVIV0_l0000O
oda<C003o`000?lc<c?o<c<c01ko<c<c00?o0000oaTI6OlI6AT08_lI6ATho`0000Oooooo0Ol00000
01Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`04oooooeKo0000@?moOgl3o`0002?oIVIV0_l0000Ooda<C0;o00008?lc
<c<00ol0003o6ATIoaTI6@0RoaTI6CWo00001oooool1o`0000006?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooooe;o000000?o
C4a<o`000?l00000??moOgl5o`0002GoIVIV00?o0000oda<C?m<C4`07_m<C4`00ol0003o<c<coc<c
<`0Ooc<c<`03o`000?lI6AWo6ATI02;o6ATI>_l00007ooooo`7o0000000Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00CoooooDOl0
00000om<C4co0000o`000002o`0003SoOgmo0ol0000XofIVIP;o00008?m<C4`00ol0003o<c<coc<c
<`0Ooc<c<`03o`000?lI6AWo6ATI02;o6ATI>ol00007ooooo`7o0000000Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool01?oooomAo`000003oda<C?l0
003oIVIV00;oIVIV0ol0000bogmoO`Co0000:OmVIVH00ol0003oC4a<oda<C00Ooda<C0;o00008?lc
<c<00ol0003o6ATIoaTI6@0SoaTI6C_o00001oooool1o`000000<oooool00ol0003oooooooooo`04
oooooe3o000000?oC4a<o`000?mVIVH01_mVIVH4o`0002SoOgmo1_l0000[ofIVIP;o00008Om<C4`0
0ol0003o<c<coc<c<`0Ooc<c<`03o`000?lI6AWo6ATI02Co6ATI>ol00007ooooo`7o0000000coooo
o`03o`000?oooooooooo00CoooooC?l000001OlI6AWo0000o`000?m<C4co000000coIVIV4_l00005
ogmoOa7o0000;omVIVH2o`00027oC4a<0_l0000Qoc<c<`03o`000?lI6AWo6ATI02Co6ATI??l00007
ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol000000olI6AWo0000oc<c<`02o`00
01ooIVIV1Ol0000nofIVIP;o00008_m<C4`00ol0003o<c<coc<c<`0Poc<c<`03o`000?lI6AWo6ATI
02Co6ATI?Ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooB_l000000olI6AWo
0000o`000002o`00063oIVIV0ol0000Soda<C003o`000?lc<c?o<c<c023o<c<c00?o0000oaTI6OlI
6AT09?lI6ATno`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom9o`000005oaTI
6Ol0003o0000oda<C?l00000GomVIVH2o`0002CoC4a<0_l0000Roc<c<`03o`000?lI6AWo6ATI02Co
6ATI?ol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBOl000001OlI6AWo0000
o`000?m<C4co000005goIVIV0_l0000Toda<C0;o00008olc<c<00ol0003o6ATIoaTI6@0UoaTI6Coo
00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooodSo000000?o6ATIo`000?l00000
0_m<C4`00ol0003oIVIVofIVIP1HofIVIP?o00009Om<C4`00ol0003o<c<coc<c<`0Roc<c<`03o`00
0?lI6AWo6ATI02Go6ATI@?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooAol0
00000olI6AWo0000o`000003oda<C003o`000?mVIVKoIVIV05GoIVIV0ol0000Voda<C0;o00009?lc
<c<00ol0003o6ATIoaTI6@0UoaTI6D7o00001oooool1o`000000<oooool00ol0003oooooooooo`04
ooooodWo00001?m<C4`00ol0003oIVIVofIVIP1BofIVIP?o00009om<C4`2o`0002Go<c<c00?o0000
oaTI6OlI6AT09_lI6AU1o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooom6o`00
0003oc<c<ol0003oC4a<00CoC4a<2_l00017ofIVIPCo0000:Om<C4`00ol0003o<c<coc<c<`0Toc<c
<`03o`000?lI6AWo6ATI02Ko6ATI@_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooAOl000000olc<c?o0000oda<C00?oda<C0Oo0000?OmVIVH3o`0002coC4a<00?o0000oc<c<olc
<c<09?lc<c<00ol0003o6ATIoaTI6@0VoaTI6D?o00001oooool1o`000000<oooool3o`0000Cooooo
@ol000001?lI6AWo0000oc<c<ol0000Goda<C0Go0000=?mVIVH4o`0002goC4a<0_l0000Voc<c<`03
o`000?lI6AWo6ATI02Oo6ATI@ol00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo
@_l000001OlI6AWo0000oc<c<olc<c?o000001coC4a<1_l0000XofIVIPKo0000;om<C4`2o`0002Oo
<c<c00?o0000oaTI6OlI6AT09olI6AU4o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool0
1?oooom1o`000003oaTI6Ol0003o<c<c00;o<c<c00?o0000oda<C?m<C4`08?m<C4`6o`0001coIVIV
1_l0000coda<C0;o0000:?lc<c<00ol0003o6ATIoaTI6@0WoaTI6DGo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04oooood3o00000_lI6AT00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<02GoC4a<7?l0000goda<C0;o0000:?lc<c<2o`0002Wo6ATIA_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Cooooo?ol00002oaTI6@03o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`0M_m<C4`2o`0002Wo<c<c00?o0000oaTI6OlI6AT0:?lI6AU7o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooolno`0000;o6ATI00?o0000oc<c<olc<c<01?lc<c<3o`00
07CoC4a<0_l0000Zoc<c<`03o`000?lI6AWo6ATI02So6ATIB?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo?_l00002oaTI6@03o`000?lc<c?o<c<c00Oo<c<c0ol0001_oda<C0;o
0000:olc<c<00ol0003o6ATIoaTI6@0XoaTI6DWo00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04ooooocgo00000olI6AT00ol0003o<c<coc<c<`0:oc<c<`Co0000JOm<C4`2o`0002co<c<c
00?o0000oaTI6OlI6AT0:?lI6AU:o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oollo`0000Co6ATI00?o0000oc<c<olc<c<03_lc<c<5o`0006;oC4a<0_l0000/oc<c<`;o0000:_lI
6AU;o`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooollo`0000Co6ATI00?o0000
oc<c<olc<c<04olc<c<3o`0005goC4a<0_l0000/oc<c<`;o0000:olI6AU<o`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooolko`0000Go6ATI00?o0000oc<c<olc<c<05_lc<c<2o`00
05SoC4a<0ol0000]oc<c<`03o`000?lI6AWo6ATI02[o6ATICOl00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>_l00006oaTI6@03o`000?lc<c?o<c<c01So<c<c0ol0001@oda<C0Go
0000;olc<c<00ol0003o6ATIoaTI6@0ZoaTI6Dko00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooc[o00001olI6AT2o`0001_o<c<c1?l00019oda<C0?o0000<_lc<c<2o`0002co6ATI
Col00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo>_l00009oaTI6@;o00007Olc
<c<3o`0004?oC4a<0ol0000coc<c<`;o0000;OlI6AU@o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?ooooljo`0000_o6ATI0_l0000Noc<c<`Co0000>_m<C4`5o`0003Co<c<c0_l0000^
oaTI6E7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooocWo00003_lI6AT2o`00
023o<c<c1_l0000^oda<C0Ko0000=olc<c<2o`0002oo6ATID_l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>Ol0000@oaTI6@;o00009?lc<c<6o`0002?oC4a<1Ol0000loc<c<`03
o`000?lI6AWo6ATI02ko6ATIDol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo
>Ol0000BoaTI6@;o0000:?lc<c<6o`0001KoC4a<1ol0000ooc<c<`;o0000;olI6AUEo`0000Oooooo
0Ol0000003?ooooo0ol00004ooooocWo00005?lI6AT2o`0002co<c<c5_l00015oc<c<`03o`000?lI
6AWo6ATI02ko6ATIE_l00005ooooo`?o0000000cooooo`03o`000?oooooooooo00Cooooo>_l0000E
oaTI6@;o0000Polc<c<2o`00033o6ATIEol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Cooooo>ol0000FoaTI6@;o0000Oolc<c<2o`00037o6ATIF?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00Cooooo>ol0000HoaTI6@;o0000Nolc<c<2o`00037o6ATIF_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00Cooooo??l0000IoaTI6@?o0000M_lc<c<2o`0003;o6ATI
Fol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo?_l0000JoaTI6@?o0000L?lc
<c<3o`0003;o6ATIGOl00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Cooooo@Ol0000J
oaTI6@;o0000Jolc<c<3o`0003Co6ATIG_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooA?l0000IoaTI6@;o0000I_lc<c<3o`0003Go6ATIH?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooAol0000HoaTI6@?o0000H?lc<c<3o`0003Oo6ATIHOl00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooBOl0000IoaTI6@?o0000F_lc<c<3o`0003Wo6ATI
H_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooBol0000JoaTI6@;o0000E_lc
<c<2o`0003_o6ATIHol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooC?l0000K
oaTI6@?o0000D?lc<c<3o`0003[o6ATII_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooCOl0000MoaTI6@Go0000AOlc<c<6o`0003co6ATIIol00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooCol0000PoaTI6@Co0000?Olc<c<4o`00043o6ATIJOl00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooD?l0000SoaTI6@?o0000=olc<c<3o`0004?o6ATI
J_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooDOl0000UoaTI6@Co0000;olc
<c<4o`0004Co6ATIK?l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooD_l0000X
oaTI6@Ko00007_lc<c<;o`0004Oo6ATIKOl00007ooooo`7o0000000cooooo`?o00001?oooomEo`00
02_o6ATI7_l0001@oaTI6Foo00001Oooool3o`000000<oooool00ol0003oooooooooo`04oooooeKo
0000U_lI6AUao`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomHo`0009;o6ATI
Lol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooFOl0002?oaTI6GGo00001ooo
ool1o`000000<oooool00ol0003oooooooooo`04oooooe[o0000S?lI6AUgo`0000Oooooo0Ol00000
03?ooooo00?o0000ooooooooool01?oooomKo`0008[o6ATIN?l00007ooooo`7o0000000cooooo`03
o`000?oooooooooo00CoooooGOl00026oaTI6G[o00001oooool1o`000000<oooool00ol0003ooooo
ooooo`04oooooeoo0000POlI6AUmo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oo
oomRo`0007co6ATIOol00007ooooo`7o0000000cooooo`03o`000?oooooooooo00CoooooIOl0001g
oaTI6H7o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooofOo0000LolI6AV3o`00
00Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomXo`0006oo6ATIQ_l00007ooooo`7o
0000000cooooo`03o`000?oooooooooo00CoooooK_l0001VoaTI6HWo00001oooool1o`000000<ooo
ool00ol0003oooooooooo`04ooooog7o0000H?lI6AV<o`0000Oooooo0Ol0000003?ooooo00?o0000
ooooooooool01?oooomco`0005_o6ATISol00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00CoooooMOl0001FoaTI6I;o00001oooool1o`000000<oooool00ol0003oooooooooo`04ooooogKo
0000D?lI6AVGo`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?oooomlo`0004;o6ATI
Wol00007ooooo`7o0000000cooooo`?o00001?oooon0o`0003[o6ATIXol00005ooooo`?o0000000c
ooooo`03o`000?oooooooooo00CoooooQ_l0000YoaTI6Jko00001oooool1o`000000<oooool00ol0
003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
ooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko0000
1oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000c
ooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000oooo
ooooool01?ooooooo`0005ko00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo
0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo00Coooooool0001No`0000Oooooo
0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko00001oooool1o`000000<oooool0
0ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000000cooooo`03o`000?oooooooooo
00Coooooool0001No`0000Oooooo0Ol0000003?ooooo00?o0000ooooooooool01?ooooooo`0005ko
00001oooool1o`000000<oooool00ol0003oooooooooo`04oooooooo0000G_l00007ooooo`7o0000
000Yooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`04oooooooo0000G_l0
0007ooooo`7o0000000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oooooo
o`0005ko00001oooool1o`000000:oooool00ol0003oooooooooo`05ooooo`Co00000oooooooo`00
05ko00001Oooool3o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
ooooJOooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
JOooool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooJOoo
ool1o`000000:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooJOooool1
o`000000:Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`04ooooo`7o0000000cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo0Ol0000003?oooooool0001]o`000000oooooonPooooo`00oooooonPooooo`00oooooonPoooo
o`00oooooonPooooo`00oooooonPooooo`00l?ooool3o`000003oa0@4?oooooooooo0:Wooooo003E
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02Oooool00ol0003o^[Zjooooo`04
ooooo`03oa0@4?nj^[[ooooo00Cooooo00?oIVIVogMgMoooool0Xoooool00=Gooooo00?o410@omgM
gOooool01_ooool00ooMgMgo410@onk^kP0:ooooo`;o<S8b1Oooool00onHV9So<S8booooo`04oooo
o`03onk^k_l@413ogMgM0:?ooooo003Cooooo`05olc<c?l@413o0000o`000?n7QhL01_ooool01?mE
EEGoV9RHooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00?ogMgM
o`000?nj^[X01Oooool00on7QhOoIVIVooooo`2Rooooo`00doooool01_lQ8B7oQhN7oc8b<_nYZJWo
A4A4ohN7Q`Gooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool0
0oo<c<co0000oa0@4004ooooo`03oeEEEOmgMgOoA4A400Gooooo00?ok^k^o`000?ooool0X_ooool0
0=?ooooo00Ko0000oooooomVIVKoQhN7omgMgOl@4105ooooo`03oc8b<_oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000oooooooo
ool0XOooool00=?ooooo00Ko410@omgMgOmgMgOoMgMgooooool00005ooooo`03oc8b<_oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o
0000ooooooooool0XOooool00=?ooooo00KoZJVYodA4A?nHV9SoA4A4oiRHV?l@4105ooooo`03o`00
0?o^k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo00;ooooo00?ok^k^o`000?ooool0X_ooool00=Cooooo00GoV9RHo`000?l0003o
410@olc<c005ooooo`04oeEEEOmgMgOoooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`00
0?l0003ooooo0_l000001_l@413oooooooooooooooooMgMgoeEEEJ?ooooo003Eooooo`03okZj^_lb
<S;ooooo00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00e_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool0
0?ooooooX?ooool00?ooooooX?ooool00?ooooooX?ooool00?ooooooX?ooool00001\
\>"],
  ImageRangeCache->{{{0, 414.438}, {414.438, 0}} -> {-1.33723, -1.22135, \
0.00717279, 0.00717279}}]
}, Open  ]],

Cell[TextData[{
  "\tSince this problem is analytically tractable, we can compare our \
numerical solution to the analytic solution. The analytic solution is given \
by Eq. ",
  ButtonBox["(6.1.14)",
    ButtonData:>"(6.1.14)",
    ButtonStyle->"Hyperlink"],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 5  \[Pi]/4\)]],
  ". In Fig. ",
  ButtonBox["6.7",
    ButtonData:>"Fig. 6.7",
    ButtonStyle->"Hyperlink"],
  " we compare the analytic solution (solid) to the grid solution along the \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " axis, for  ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = 30\)\)]],
  " (dashed) and ",
  Cell[BoxData[
      \(TraditionalForm\`60\)]],
  " (dotted):"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0149073 0.588412 [
[.21429 .00241 -9 -9 ]
[.21429 .00241 9 0 ]
[.40476 .00241 -9 -9 ]
[.40476 .00241 9 0 ]
[.59524 .00241 -9 -9 ]
[.59524 .00241 9 0 ]
[.78571 .00241 -9 -9 ]
[.78571 .00241 9 0 ]
[.97619 .00241 -3 -9 ]
[.97619 .00241 3 0 ]
[1.025 .01491 0 -6 ]
[1.025 .01491 10 6 ]
[.01131 .13259 -18 -4.5 ]
[.01131 .13259 0 4.5 ]
[.01131 .25027 -18 -4.5 ]
[.01131 .25027 0 4.5 ]
[.01131 .36795 -18 -4.5 ]
[.01131 .36795 0 4.5 ]
[.01131 .48564 -18 -4.5 ]
[.01131 .48564 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01491 m
.21429 .02116 L
s
[(0.2)] .21429 .00241 0 1 Mshowa
.40476 .01491 m
.40476 .02116 L
s
[(0.4)] .40476 .00241 0 1 Mshowa
.59524 .01491 m
.59524 .02116 L
s
[(0.6)] .59524 .00241 0 1 Mshowa
.78571 .01491 m
.78571 .02116 L
s
[(0.8)] .78571 .00241 0 1 Mshowa
.97619 .01491 m
.97619 .02116 L
s
[(1)] .97619 .00241 0 1 Mshowa
.125 Mabswid
.07143 .01491 m
.07143 .01866 L
s
.11905 .01491 m
.11905 .01866 L
s
.16667 .01491 m
.16667 .01866 L
s
.2619 .01491 m
.2619 .01866 L
s
.30952 .01491 m
.30952 .01866 L
s
.35714 .01491 m
.35714 .01866 L
s
.45238 .01491 m
.45238 .01866 L
s
.5 .01491 m
.5 .01866 L
s
.54762 .01491 m
.54762 .01866 L
s
.64286 .01491 m
.64286 .01866 L
s
.69048 .01491 m
.69048 .01866 L
s
.7381 .01491 m
.7381 .01866 L
s
.83333 .01491 m
.83333 .01866 L
s
.88095 .01491 m
.88095 .01866 L
s
.92857 .01491 m
.92857 .01866 L
s
.25 Mabswid
0 .01491 m
1 .01491 L
s
gsave
1.025 .01491 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13259 m
.03006 .13259 L
s
[(0.2)] .01131 .13259 1 0 Mshowa
.02381 .25027 m
.03006 .25027 L
s
[(0.4)] .01131 .25027 1 0 Mshowa
.02381 .36795 m
.03006 .36795 L
s
[(0.6)] .01131 .36795 1 0 Mshowa
.02381 .48564 m
.03006 .48564 L
s
[(0.8)] .01131 .48564 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04433 m
.02756 .04433 L
s
.02381 .07375 m
.02756 .07375 L
s
.02381 .10317 m
.02756 .10317 L
s
.02381 .16201 m
.02756 .16201 L
s
.02381 .19143 m
.02756 .19143 L
s
.02381 .22085 m
.02756 .22085 L
s
.02381 .27969 m
.02756 .27969 L
s
.02381 .30911 m
.02756 .30911 L
s
.02381 .33853 m
.02756 .33853 L
s
.02381 .39737 m
.02756 .39737 L
s
.02381 .4268 m
.02756 .4268 L
s
.02381 .45622 m
.02756 .45622 L
s
.02381 .51506 m
.02756 .51506 L
s
.02381 .54448 m
.02756 .54448 L
s
.02381 .5739 m
.02756 .5739 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02476 .59454 m
.0294 .57582 L
.03373 .56319 L
.04355 .54017 L
.06336 .50391 L
.10545 .44535 L
.14441 .40214 L
.18581 .363 L
.2257 .32995 L
.26408 .30143 L
.3049 .27392 L
.34421 .24971 L
.38201 .22821 L
.42226 .20697 L
.46099 .18794 L
.50217 .16904 L
.54184 .15199 L
.58 .13654 L
.6206 .12103 L
.65969 .10691 L
.70123 .0927 L
.74126 .07973 L
.77977 .06784 L
.82073 .0558 L
.86018 .04474 L
.89812 .03456 L
.9385 .02419 L
.97619 .01491 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 .60332 m
.06244 .53327 L
.08255 .49094 L
.10458 .45652 L
.14415 .40945 L
.18466 .36884 L
.22365 .33497 L
.2651 .30284 L
.30503 .27494 L
.34344 .2504 L
.38431 .22631 L
.42366 .20482 L
.4615 .18551 L
.50178 .16623 L
.54055 .14877 L
.58178 .13125 L
.62149 .11528 L
.65968 .10066 L
.70033 .08583 L
.73946 .07218 L
.78104 .05832 L
.8211 .04554 L
.85966 .03395 L
.8792 .02837 L
.90066 .02301 L
.92108 .01892 L
.93087 .01738 L
.94015 .01622 L
.94452 .01578 L
.94918 .01539 L
.9516 .01523 L
.95428 .01507 L
.95674 .01494 L
.959 .01486 L
.96108 .01479 L
.96212 .01477 L
.96327 .01475 L
.96442 .01473 L
.96565 .01472 L
.96681 .01472 L
.96787 .01472 L
.96894 .01472 L
.96992 .01473 L
.971 .01475 L
.97215 .01477 L
.97407 .01483 L
.97619 .01491 L
s
0 1 0 r
[ .01 .02 ] 0 setdash
.02381 .60332 m
.04262 .55997 L
.06244 .5124 L
.07286 .49478 L
.08255 .48011 L
.10458 .45011 L
.14357 .40537 L
.18502 .36522 L
.22495 .33144 L
.26336 .30235 L
.30423 .27432 L
.34358 .24965 L
.38141 .22775 L
.4217 .20611 L
.46047 .18671 L
.5017 .16741 L
.54141 .14999 L
.5796 .13418 L
.62025 .11829 L
.65938 .10379 L
.70096 .08918 L
.74102 .07579 L
.77957 .06348 L
.82058 .05094 L
.86007 .03935 L
.89804 .02868 L
.91918 .02306 L
.93846 .01851 L
.94774 .01683 L
.95264 .01612 L
.95784 .01552 L
.96237 .01514 L
.96361 .01506 L
.96495 .01498 L
.9661 .01493 L
.96737 .01488 L
.96853 .01485 L
.96961 .01483 L
.97075 .01482 L
.97197 .01482 L
.97311 .01483 L
.97418 .01485 L
.97515 .01487 L
.97619 .01491 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{303.188, 187.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005j0000jB000`400?l00000o`00003ooooooomk
ooooo`00oooooomkooooo`00E?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<Oooool4o`000003oa0@4?oooooooooo023ooooo001Dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Y
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool09ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<oooool00ol0003oooooooooo`0Rooooo`00E?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Xooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002Wo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`0Rooooo`00E?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Yoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03?ooooo00?o
0000ooooooooool08_ooool005Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00cooooo`03o`00
0?oooooooooo02;ooooo001Dooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Wooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Yooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0[ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03?ooooo00?o0000ooooooooool08_oo
ool005Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0:oooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000cooooo`03o`000?oooooooooo02;ooooo001D
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<Oooool00omEEEGoIVIVo`00000Tooooo`008_oo
ool00ol0003oooooooooo`3ooooooeKooooo000Rooooo`03o`000?oooooooooo0?ooooooE_ooool0
02;ooooo00?o0000ooooooooool0oooooom4ooooo`;o00000_ooool2o`0000cooooo000Rooooo`03
o`000?oooooooooo0?ooooooA?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo000Roooo
o`03o`000?oooooooooo0?ooooooAOooool01?oMgMgo0000oa0@4?o<c<`=ooooo`006_ooooooo`00
033o00001?oo0004o`3o00go00002oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`008_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`Ooo`001_ooool4o`0000;ooooo00?o0000ooooooooool04Oooool01?lQ
8B7oMgMgogMgMolb<S8=ooooo`008_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02Gooooo0_oo00000ooooooo0?l0o`3o0003o`3o00?ooooo1?l00006ooooo`03o`000?oooooooooo
013ooooo0_l00002ooooo`;o00003?ooool002;ooooo00?o0000ooooooooool0oooooolSooooo`Co
0000;oooool002;ooooo00?o0000ooooooooool0oooooolGooooo`?o0?l01?ooool5o`0003?ooooo
000Rooooo`03o`000?oooooooooo0?oooooo5_ooool01?l0o`3oooooooooooooool4o`0003Sooooo
000Rooooo`03o`000?oooooooooo0?oooooo2_ooool4ool000Sooooo1?l0000looooo`008_ooool0
0ol0003oooooooooo`3oooooo`Oooooo0ooo0003ooooo`Co0?l000?oooooo`000?l000000_l00010
ooooo`008_ooool00ol0003oooooooooo`3oooooo`Cooooo0ooo0007ooooo`Co0000A?ooool002;o
oooo0_l0003oooooo`;ooooo0ooo00001?oooooo0?l0o`3o0?l0o`02ooooo`Co0000B?ooool002;o
oooo00?o0000ooooooooool0o?ooool4ool000;ooooo0_l0o`02ooooo`?o0000C?ooool002;ooooo
00?o0000ooooooooool0ooooool4ooooo`?o0000Coooool002;ooooo00?o0000ooooooooool0nooo
ool2o`3o00?ooooo0ol0001Booooo`008_ooool00ol0003oooooooooo`3iooooo`;o0?l000?ooooo
o`000?l000000_l0001Eooooo`008_ooool00ol0003oooooooooo`3iooooo`?o0000FOooool002;o
oooo00?o0000ooooooooool0k?ooool2ool000Cooooo0_l0o`02ooooo`?o0000G?ooool002;ooooo
00?o0000ooooooooool0jOooool3ool000Cooooo0_l0o`001?oooooo0000o`000?l0001Oooooo`00
8_ooool00ol0003oooooooooo`3Vooooo`?oo`001_ooool4o`0006;ooooo000Rooooo`03o`000?oo
oooooooo0>?ooooo0ooo0003ooooo`;o0?l000Coooooo`000?l0003o0000I_ooool002;ooooo0_l0
003Qooooo`?oo`001?ooool2o`3o00?o0000JOooool002;ooooo00?o0000ooooooooool0g_ooool2
ool000Kooooo0ol0001/ooooo`008_ooool00ol0003oooooooooo`3Pooooo`;o0?l000Coooooo`00
0?l0003o0000Koooool002;ooooo00?o0000ooooooooool0g_ooool2o`3o00?o0000L_ooool002;o
oooo00?o0000ooooooooool0gOooool3o`0007Gooooo000Rooooo`03o`000?oooooooooo0=Kooooo
0_l0o`02ooooo`?o0000N?ooool002;ooooo00?o0000ooooooooool0e?ooool2o`3o0004ooooool0
003o0000o`0007_ooooo000Rooooo`03o`000?oooooooooo0<kooooo0_oo0004ooooo`?o0000O_oo
ool002;ooooo00?o0000ooooooooool0boooool2ool000;o0?l00_ooool3o`00087ooooo000Roooo
o`;o0000b_ooool2ool000;o0?l000Coooooo`000?l0003o0000Q?ooool002;ooooo00?o0000oooo
ooooool0a_ooool3ool000;ooooo0ol00027ooooo`008_ooool00ol0003oooooooooo`33ooooo`03
ool00?l0o`3o0?l000?ooooo0_l0002:ooooo`008_ooool00ol0003oooooooooo`30ooooo`;oo`00
0_l0o`02ooooo`?o0000S?ooool002;ooooo00?o0000ooooooooool0_oooool01?oo003ooooooooo
ooooool3o`0008oooooo000Rooooo`03o`000?oooooooooo0<3ooooo0ol0002Booooo`008_ooool0
0ol0003oooooooooo`2kooooo`;o0?l00ol0002Eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`2iooooo`;o0?l00_l0002H
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01_ooool00ol0003oooooooooo`2gooooo`?o0000Voooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0/_oo
ool2o`3o00?o0000W_ooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo0ol0002_ooooo`03ool00?l0o`3o0?l000;o0000XOooool000Oooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0[?oo
ool3ool000;o0000Y?ooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Z_ooool2ool000?o0000Y_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooo
ooooo`2Xooooo`04ool00?l0o`3o0?l0o`000:Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0YOooool2ool0
00;o0?l000?o0000ooooooooool0ZOooool002;ooooo00?o0000ooooooooool0Xoooool2ool000?o
0000[Oooool002;ooooo00?o0000ooooooooool0X_ooool00ooo003o0000o`00002`ooooo`008_oo
ool00ol0003oooooooooo`2Pooooo`;o0?l000?o0000ooooooooool0/?ooool002;ooooo00?o0000
ooooooooool0W_ooool2o`3o0003o`000?oooooooooo0;;ooooo000Rooooo`;o0000WOooool3o`00
0;Kooooo000Rooooo`03o`000?oooooooooo09[ooooo0_l0002iooooo`008_ooool00ol0003ooooo
ooooo`2Fooooo`?o0?l000?o0000ooooooooool0^Oooool002;ooooo00?o0000ooooooooool0UOoo
ool00ol0o`3o0000o`00002mooooo`008_ooool00ol0003oooooooooo`2Booooo`;oo`000_l0002o
ooooo`008_ooool00ol0003oooooooooo`2@ooooo`;oo`000_l00031ooooo`008_ooool00ol0003o
ooooooooo`2=ooooo`;oo`000_l0o`000ol0003oooooooooo`31ooooo`008_ooool00ol0003ooooo
ooooo`2;ooooo`;oo`000_l0o`36ooooo`008_ooool00ol0003oooooooooo`29ooooo`;oo`000_l0
0038ooooo`008_ooool00ol0003oooooooooo`27ooooo`;oo`000_l0003:ooooo`008_ooool2o`00
08Oooooo0_l0o`000ol0003oooooooooo`3:ooooo`008_ooool00ol0003oooooooooo`24ooooo`;o
0?l000?o0000ooooooooool0c?ooool002;ooooo00?o0000ooooooooool0Poooool2o`000=3ooooo
000Rooooo`03o`000?oooooooooo087ooooo0_l0003Booooo`008_ooool00ol0003oooooooooo`1n
ooooo`03o`3o0?l0003o00000=Cooooo000Rooooo`03o`000?oooooooooo07cooooo0_l0o`000ol0
003oooooooooo`3Dooooo`008_ooool00ol0003oooooooooo`1kooooo`03o`3o0?l0003ooooo0=Oo
oooo000Rooooo`03o`000?oooooooooo07Wooooo0_l0003Jooooo`008_ooool00ol0003ooooooooo
o`1eooooo`;oo`000_l0003Looooo`008_ooool2o`0007Cooooo0_oo0002o`3o0=kooooo000Roooo
o`03o`000?oooooooooo07;ooooo00Coo`00o`3o0?l0o`3o0000goooool002;ooooo00?o0000oooo
ooooool0L?ooool2ool000;o0000hOooool002;ooooo00?o0000ooooooooool0K_ooool2ool000;o
0000hoooool002;ooooo00?o0000ooooooooool0K?ooool2o`3o00;o0000iOooool002;ooooo00?o
0000ooooooooool0Joooool00ol0o`3o0000o`00003Wooooo`008_ooool00ol0003oooooooooo`1Y
ooooo`03ool00?l0o`3o00000>Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo00?oo`00
o`000?ooool0j_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo0_l0003/ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`03o`000?oooooooooo06Gooooo00?o0?l0
o`000?ooool0kOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Oooooo0ol0001Sooooo`;o0?l0l?ooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0HOooool00ol0003o0?l0
ooooo`3aooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
1oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0?;ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo05kooooo
0_l0003eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`1Looooo`;o0?l0moooool002;ooooo00?o0000ooooooooool0Fooo
ool00ol0o`3oooooooooo`3gooooo`008_ooool00ol0003oooooooooo`1Iooooo`03o`000?l0o`3o
o`000?Wooooo000Rooooo`03o`000?oooooooooo05Oooooo0_l000000ooo003oooooooooo`3ioooo
o`008_ooool00ol0003oooooooooo`1Fooooo`03o`000?oo003oo`000?cooooo000Rooooo`;o0000
EOooool2o`000003ool00?oooooooooo0?cooooo000Rooooo`03o`000?oooooooooo05?ooooo0_l0
o`000ooo003oooooooooo`3mooooo`008_ooool00ol0003oooooooooo`1Aooooo`03o`000?l0o`3o
o`000?oooooo0_ooool002;ooooo00?o0000ooooooooool0Coooool2o`000003ool00?oooooooooo
0?oooooo0_ooool002;ooooo00?o0000ooooooooool0C_ooool00ol0003oo`00ool0003oooooo`Go
oooo000Rooooo`03o`000?oooooooooo04cooooo0_l000000ooo003oooooooooo`3oooooo`Gooooo
000Rooooo`03o`000?oooooooooo04_ooooo00?o0000o`3o0?oo0000ooooool8ooooo`008_ooool0
0ol0003oooooooooo`19ooooo`;o000000?o0?l0ooooooooool0ooooool8ooooo`008_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooo0?l00?oooooo2oooool002;ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`3oooooo`cooooo000Rooooo`;o0000A_ooool2o`000?oooooo
3oooool002;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`3oooooo`oooooo000R
ooooo`03o`000?oooooooooo04?ooooo00?o0000o`3o0?l0o`00ooooool@ooooo`008_ooool00ol0
003oooooooooo`11ooooo`;o000000?o0?l0ooooooooool0ooooool@ooooo`008_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooo0?l00?oooooo4oooool002;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`3ooooooaCooooo000Rooooo`03o`000?oooooooooo03gooooo0_l0
0002ool00?oooooo5Oooool002;ooooo00?o0000ooooooooool0??ooool00ol0003oooooool0003o
oooooaOooooo000Rooooo`03o`000?oooooooooo03_ooooo00?o0000ool00?l0o`00oooooolHoooo
o`008_ooool2o`0003_ooooo00?o0000ool00?l0o`00oooooolIooooo`008_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oo003o0?l00?oooooo6_ooool002;ooooo00?o0000ooooooooool0=ooo
ool2o`000003ool00?oooooooooo0?oooooo6_ooool002;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooool0003ooooooagooooo000Rooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
oooo0000oooooolNooooo`008_ooool00ol0003oooooooooo`0dooooo`03o`000?l0o`3o0?l00?oo
oooo7oooool002;ooooo00?o0000ooooooooool0<oooool00ol0003o0?l0ool0003oooooob3ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo03;ooooo00?o0000o`3o0?oo0000oooooolQooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo8_ooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo8oooool000Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0002oooooo00?o
0000ooooooooool0oooooolTooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo02kooooo00?o0?l0ooooooooool0
oooooolUooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`0]ooooo`03o`000?l0o`3ooooo0?oooooo9_ooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
;?ooool00ol0003o0?l0ooooo`3oooooobOooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02_ooooo00?o0000o`3o0?oo
ool0oooooolXooooo`008_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo
:Oooool002;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooob[ooooo000R
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0ooooool[ooooo`008_ooool00ol0
003oooooooooo`0Wooooo`03o`3o0?ooooooo`000?oooooo;?ooool002;ooooo0_l0000Wooooo`03
o`3o0?ooooooo`000?oooooo;Oooool002;ooooo00?o0000ooooooooool09Oooool00ol0o`3ooooo
ool0003oooooobkooooo000Rooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo0000oooo
ool_ooooo`008_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo003ooooo0?oooooo;oooool0
02;ooooo00?o0000ooooooooool08oooool00ol0003oo`00ooooo`3ooooooc3ooooo000Rooooo`03
o`000?oooooooooo02;ooooo00?o0000oooooooo0000oooooolaooooo`008_ooool00ol0003ooooo
ooooo`0Qooooo`03o`3o0?ooooooo`000?oooooo<_ooool002;ooooo00?o0000ooooooooool08?oo
ool00ol0003o0?l0ool0003ooooooc?ooooo000Rooooo`03o`000?oooooooooo01oooooo00?o0000
o`3o0?oo0000ooooooldooooo`008_ooool00ol0003oooooooooo`0Nooooo`03o`000?l0o`3oo`00
0?oooooo=Oooool002;ooooo0_l0000Nooooo`03o`000?ooooooo`000?oooooo=_ooool002;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooool0003oooooocOooooo000Rooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0oooooolhooooo`008_ooool00ol0003oooooooooo`0J
ooooo`03o`3o0?oooooooooo0?oooooo>Oooool002;ooooo00?o0000ooooooooool06Oooool00ol0
003o0?l0ooooo`3ooooooc[ooooo000Rooooo`03o`000?oooooooooo01Sooooo00?o0000o`3o0?oo
ool0oooooolkooooo`008_ooool00ol0003oooooooooo`0Gooooo`03o`000?l0o`3ooooo0?oooooo
??ooool002;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3ooooooccooooo000R
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0oooooolmooooo`008_ooool2o`00
01Kooooo00?o0000ooooooooool0oooooolnooooo`008_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0?oooooo?_ooool002;ooooo00?o0000ooooooooool05?ooool00ol0o`3ooooo
ooooo`3oooooocoooooo000Rooooo`03o`000?oooooooooo01?ooooo00?o0000o`3o0?ooool0oooo
oom0ooooo`008_ooool00ol0003oooooooooo`0Cooooo`03o`3o0?oooooooooo0?oooooo@?ooool0
02;ooooo00?o0000ooooooooool04_ooool00ol0o`3oooooool0003ooooood7ooooo000Rooooo`03
o`000?oooooooooo017ooooo00Co0000ooooooooooooo`00oooooom1ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`0@ooooo`04o`000?ooooooooooool00?oooooo@_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool04?ooool00ol0003oooooool0003ooooood?ooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooo003ooooood?ooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0000>ooooo`04o`000?l0o`3o
ooooool00?ooooooA?ooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`0>ooooo`03o`3o0?ooooooo`000?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001_ooool00ol0003oooooooooo`0=ooooo`04o`3o0?ooooooooooool00?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooool00?ooooooA_ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooool00?ooooooA_ooool002;ooooo00?o0000ooooooooool0
2oooool01?l0003ooooooooooooo003oooooodOooooo000Rooooo`03o`000?oooooooooo00[ooooo
00Go0000ooooooooooooooooool0003oooooodOooooo000Rooooo`03o`000?oooooooooo00[ooooo
00Co0000ooooooooooooo`00oooooom8ooooo`008_ooool00ol0003oooooooooo`09ooooo`;o0?l0
0_ooool00ooo003oooooooooo`3oooooodKooooo000Rooooo`;o00002Oooool01Ol0003o0?l0oooo
ooooooooo`000?ooooooBOooool002;ooooo00?o0000ooooooooool02?ooool00ol0o`3ooooooooo
o`3ooooood_ooooo000Rooooo`03o`000?oooooooooo00Oooooo00?o0000o`3o0?ooool0oooooom<
ooooo`008_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooCOooool002;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodgooooo000Rooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooom>ooooo`008_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?ooooooC_ooool002;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodoooooo000Rooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo0?l0oooooom?ooooo`008_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`3o0?ooooooCoooool002;ooooo0_l00003ooooo`04o`000?ooooooooooo`3o0?ooooooD?ooool0
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0o`3ooooooe3ooooo000Roooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooomAooooo`008_ooool01Ol0003o
oooooooooooooooo00000?ooooooE?ooool002;ooooo00Go0000ooooooooooooooooo`00003ooooo
oeCooooo000Rooooo`05o`000?ooooooooooooooool000000oooool00ooo003oooooooooo`3ooooo
odkooooo000Rooooo`04o`000?ooooooooooo`0000Cooooo00?oo`00ooooooooool0oooooom>oooo
o`008_ooool02?l0003oooooooooool0003oooooo`3o0?ooooooo`00oooooomAooooo`008_ooool0
2?l0003oooooooooool0003oooooo`3o0?ooooooo`00oooooomAooooo`008_ooool3o`000004oooo
ool0o`3oooooool00?ooooooD_ooool002;ooooo00Ko0000ooooool0003oooooo`3o0?oo003ooooo
oe?ooooo000Rooooo`03o`000?oooooo000000;ooooo00?oo`00ooooooooool0oooooomAooooo`00
8_ooool2o`0000;ooooo00?oo`00ooooooooool0oooooomBooooo`008_ooool2o`0000;ooooo00?o
o`00ooooooooool0oooooomBooooo`008_ooool2o`000003oooooooo003ooooo0?ooooooE?ooool0
02;ooooo00Co0000ooooooooooooo`00oooooomEooooo`006?ooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000o`3o0?oo0000oooooomFooooo`006_ooool00ol0003oooooooooo`05ooooo`03
o`000?l0o`3ooooo0?ooooooE_ooool001[ooooo00?o0000ooooooooool01Oooool00ol0o`3oo`00
ooooo`3ooooooeKooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0?l0o`000?l00000oooo
oomFooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooE_ooool0
01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooeKooooo000Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooomFooooo`006?ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooNoooool00?ooooooNoooool0
0?ooooooNoooool00?ooooooNoooool00?ooooooNoooool00?ooooooNoooool00?ooooooNoooool0
0?ooooooNoooool00?ooooooNoooool00?ooooooNoooool000oooooo00?o0000ooooooooool01_oo
ool00omgMgOoIVIVooooo`09ooooo`03o`000?nj^[[ooooo00_ooooo00?oIVIVogMgMoooool0oooo
oom6ooooo`003oooool00ol@413ogMgMooooo`05ooooo`03omgMgOl@413ok^k^00[ooooo0_lb<S8<
ooooo`03onk^k_l@413ogMgM0?ooooooA_ooool000gooooo00Goc<c<oa0@4?l0003o0000ohN7Q`05
ooooo`03oeEEEOnHV9Sooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOoIVIVooooo`3oooooodGooooo000=
ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN71?ooool00ol0003oooooooooo`02ooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo^k^ko0000ooooo`3oooooodGooooo000=ooooo`06o`000?ooooooIVIV
ohN7QooMgMgo410@1?ooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0[ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo0?ooooooA?ooool000gooooo
00Ko410@omgMgOmgMgOoMgMgooooool00004ooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q
8Ol@413ok^k^2_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0oooo
oom4ooooo`003Oooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40Cooooo00?o0000onk^k_ooool0
0oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool000000oooool00oo^
k^ko0000ooooo`3oooooodGooooo000>ooooo`05oiRHV?l0003o0000oa0@4?o<c<`01?ooool00omE
EEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@4003
ooooo`03ogMgMomEEEGooooo0?ooooooAOooool000oooooo00?o^[Zjoc8b<_ooool01Oooool00ooM
gMgo410@onk^kP0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00oo^k^ko410@omgMg@3o
ooooodKooooo000@ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool04?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?oIVIVogMgMoooool0oooooom6ooooo`00oooooomkoooo
o`00oooooomkooooo`00oooooomkooooo`00\
\>"],
  ImageRangeCache->{{{0, 377.938}, {232.938, 0}} -> {-0.112202, -0.0805045, \
0.00406808, 0.00658444}}],

Cell["Fig. 6.7 ", "Caption",
  CellTags->"Fig. 6.7"],

Cell[TextData[{
  "The  solution is  more accurate than the corresponding Galerkin solution \
(see Fig. ",
  ButtonBox["6.2",
    ButtonData:>"Fig. 6.2",
    ButtonStyle->"Hyperlink"],
  ") near the singularity at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(y = 0\)\)]],
  ".  However, the Galerkin solution is superior near the circular boundary, \
because of the aforementioned difficulty of fitting a curved edge to a grid. \
"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relaxation Methods", "Section",
  CellTags->{"i:32", "c:25"}],

Cell[CellGroupData[{

Cell["Jacobi's Method", "Subsubsection",
  CellTags->"i:33"],

Cell[TextData[{
  "Although direct solution of the coupled equations for the potential is not \
difficult using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, it can be much more difficult to program an efficient direct \
solution in other computing environments  where access to sophisticated \
linear algebra packages may be limited. In these situations, relaxation \
methods are often useful. These methods have the advantage that they are \
relatively simple to code, needing no sophisticated external library \
routines.  On the other hand, they are typically not as fast as the direct \
methods. "
}], "Text"],

Cell[TextData[{
  "\t In the following relaxation method, one uses the following idea: \
solutions to Poisson's equation can be thought of as the equilibrium solution \
to the heat equation with a source, Eq. ",
  ButtonBox["(6.2.26)",
    ButtonData:>"(6.2.26)",
    ButtonStyle->"Hyperlink"],
  ".  Starting with any initial condition, the heat equation solution will \
eventually relax to a solution of Poisson's equation. "
}], "Text"],

Cell[TextData[{
  "\t For example, we can take the FTCS algorithm for the heat equation, ",
  ButtonBox["(6.2.28)",
    ButtonData:>"(6.2.28)",
    ButtonStyle->"Hyperlink"],
  ", replace ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`S/\[Chi]\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Rho]\)\)]],
  ", and take the largest possible time step size that is stable according to \
the Courant condition ",
  ButtonBox["(6.2.29)",
    ButtonData:>"(6.2.29)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(\[Phi]\_\(j\ k\)\%n\), "+", 
            RowBox[{\(1\/2\), 
              FractionBox[
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}], 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}]], 
              RowBox[{"(", 
                RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], 
                        "2"]], \((\[Phi]\_\(j + 1\ k\)\%n - 
                        2  \[Phi]\_\(j\ k\)\%n + \[Phi]\_\(j - 1\ k\)\%\(\(\ \
\)\(n\)\))\)}], "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["y",
                              FontSlant->"Italic"]}]], 
                        "2"]], \((\[Phi]\_\(j\ k + 1\)\%n - 
                        2  \[Phi]\_\(j\ k\)\%n + \[Phi]\_\(j\ k - 1\)\%\(\(\ \
\)\(n\)\)\ )\)}]}], ")"}]}]}]}], TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "If one expands out the expression, one finds that the terms involving ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%n\)]],
  " cancel, leaving"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{\(1\/2\), 
            FractionBox[
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"], 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "2"]}], 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"], "+", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}], ")"}]], 
            RowBox[{"(", 
              RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                RowBox[{
                  FractionBox["1", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], 
                      "2"]], \((\[Phi]\_\(j + 1\ k\)\%n + \[Phi]\_\(j - 1\ \
k\)\%\(\(\ \)\(n\)\))\)}], "+", 
                RowBox[{
                  FractionBox["1", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], 
                      "2"]], \((\[Phi]\_\(j\ k + 1\)\%n + \[Phi]\_\(j\ k - \
1\)\%\(\(\ \)\(n\)\)\ )\)}]}], ")"}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.39)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(6.2.39)",
    ButtonData:>"(6.2.39)",
    ButtonStyle->"Hyperlink"],
  " is called",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Jacobi's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jacobi.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" method",
    FontSlant->"Italic"],
  ". The equation provides us with a recursion relation for determining the \
solution to ",
  "Poisson's",
  " equation. Starting with any initial choice for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at time step ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  ", the solution eventually relaxes to a solution of the Poisson equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \[Rho]\)]],
  ".  We stop the recursion when the difference between ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at adjacent time steps is less than some tolerance."
}], "Text",
  CellTags->"i:61"],

Cell["\<\
\tThe following simple code implements the Jacobi method in a \
domain of arbitrary shape:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 20; \ M\_y = 20;\), "\n", 
    \(L\_x = 1.5\ ; \ L\_y = \ 2. ;\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \ \[CapitalDelta]y = 
      L\_y/M\_y;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.106"],

Cell["\<\
The homogeneous boundary conditions are specified by the following \
statements: \
\>", "Text"],

Cell[BoxData[{
    \(\[Phi][j_, k_, n_]\  := \ 0\  /; \ j \[LessEqual] \ f[k]\), "\n", 
    \(\[Phi][j_, k_, n_]\  := \ 0\  /; \ j \[GreaterEqual] \ g[k]\), "\n", 
    \(\(\[Phi][j_, 0, n_]\  = \ 0;\)\), "\n", 
    \(\(\[Phi][j_, M\_y, n_]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.107"],

Cell[TextData[{
  "The main body of the code is the Jacobi recursion relation, Eq. ",
  ButtonBox["(6.2.39)",
    ButtonData:>"(6.2.39)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Phi][j_, k_, 
        n_]\  := \ \(\[Phi][j, k, 
          n]\  = \ \(1\/2\) \(\(\(\[CapitalDelta]x\^2\) \[CapitalDelta]y\^2\)\
\/\((\[CapitalDelta]x\^2 + \[CapitalDelta]y\^2)\)\) \((\(-\[Rho][j, 
                  k]\) + \(1\/\[CapitalDelta]x\^2\) \((\[Phi][j + 1, k, 
                      n - 1] + \[Phi][j - 1, k, 
                      n - 1])\) + \(1\/\[CapitalDelta]y\^2\) \((\[Phi][j, 
                      k + 1, n - 1] + \[Phi][j, k - 1, 
                      n - 1]\ )\))\)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.108"],

Cell[TextData[{
  "We must start the recursion with an initial guess. Typically, the closer \
the guess to the exact solution, the better the method works. However, we \
will simply choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " inside the domain:"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi][j_, k_, 0]\  = \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.109"],

Cell[TextData[{
  "In order to determine how well the solution is converging to the correct \
answer, we take the difference between the solutions at the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th and ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  "st steps:"
}], "Text"],

Cell[BoxData[
    \(error[n_]\  := \ 
      Max[Table[
          Table[Abs[\[Phi][j, k, n] - \[Phi][j, k, n - 1]], {j, f[k] + 1, 
              g[k] - 1}], {k, 1, M\_y - 1}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.110"],

Cell["\<\
When this difference is sufficiently small, we can say that the \
solution has converged. \
\>", "Text"],

Cell[TextData[{
  "\tLet's now perform a solution of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 1\)]],
  " in the irregular domain specified below:"
}], "Text"],

Cell[BoxData[{
    \(\(\(\[Rho][j_, k_]\  = \ 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(g[k_]\  := M\_x; \ k \[LessEqual] \ 5;\), "\n", 
    \(\(g[k_]\  := \ M\_x - k + 5 /; 5 < k < 15;\)\), "\n", 
    \(\(g[k_]\  := \ M\_x - 10\  /; \ k \[GreaterEqual] \ 15;\)\), "\n", 
    \(\(f[k_]\ \  = \ Floor[12 \((k/M\_y - 1)\)^2];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.111"],

Cell[TextData[{
  "It requires many steps,  but eventually the error falls to an acceptable \
level, as shown in Cells ",
  ButtonBox["6.112",
    ButtonData:>"Cell 6.112",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["6.113",
    ButtonData:>"Cell 6.113",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(error[200]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.112"],

Cell[BoxData[
    \(4.741557711643307`*^-6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(LogLogListPlot[Table[{n, error[n]}, {n, 1, 200}], 
        AxesLabel \[Rule] {"\<n\>", "\<error[n]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.113"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.413893 1.22966 0.228198 [
[.02381 -0.0125 -5 -12 ]
[.02381 -0.0125 5 0 ]
[.1484 -0.0125 -5 -12 ]
[.1484 -0.0125 5 0 ]
[.31311 -0.0125 -5 -12 ]
[.31311 -0.0125 5 0 ]
[.4377 -0.0125 -8 -12 ]
[.4377 -0.0125 8 0 ]
[.5623 -0.0125 -8 -12 ]
[.5623 -0.0125 8 0 ]
[.727 -0.0125 -8 -12 ]
[.727 -0.0125 8 0 ]
[.8516 -0.0125 -11 -12 ]
[.8516 -0.0125 11 0 ]
[.97619 -0.0125 -11 -12 ]
[.97619 -0.0125 11 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .08867 -46 -6 ]
[-0.0125 .08867 0 6 ]
[-0.0125 .15736 -46 -6 ]
[-0.0125 .15736 0 6 ]
[-0.0125 .24817 -46 -6 ]
[-0.0125 .24817 0 6 ]
[-0.0125 .31687 -40 -6 ]
[-0.0125 .31687 0 6 ]
[-0.0125 .38556 -40 -6 ]
[-0.0125 .38556 0 6 ]
[-0.0125 .47637 -40 -6 ]
[-0.0125 .47637 0 6 ]
[-0.0125 .54507 -34 -6 ]
[-0.0125 .54507 0 6 ]
[-0.0125 .61376 -34 -6 ]
[-0.0125 .61376 0 6 ]
[0 .64303 -26 0 ]
[0 .64303 26 12 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.1484 0 m
.1484 .00625 L
s
gsave
.1484 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31311 0 m
.31311 .00625 L
s
gsave
.31311 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.4377 0 m
.4377 .00625 L
s
gsave
.4377 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5623 0 m
.5623 .00625 L
s
gsave
.5623 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.727 0 m
.727 .00625 L
s
gsave
.727 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8516 0 m
.8516 .00625 L
s
gsave
.8516 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.22129 0 m
.22129 .00375 L
s
.273 0 m
.273 .00375 L
s
.34588 0 m
.34588 .00375 L
s
.37359 0 m
.37359 .00375 L
s
.39759 0 m
.39759 .00375 L
s
.41876 0 m
.41876 .00375 L
s
.63518 0 m
.63518 .00375 L
s
.68689 0 m
.68689 .00375 L
s
.75977 0 m
.75977 .00375 L
s
.78748 0 m
.78748 .00375 L
s
.81149 0 m
.81149 .00375 L
s
.83266 0 m
.83266 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08867 m
.00625 .08867 L
s
gsave
-0.0125 .08867 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .15736 m
.00625 .15736 L
s
gsave
-0.0125 .15736 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00002) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .24817 m
.00625 .24817 L
s
gsave
-0.0125 .24817 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00005) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .31687 m
.00625 .31687 L
s
gsave
-0.0125 .31687 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .38556 m
.00625 .38556 L
s
gsave
-0.0125 .38556 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0002) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47637 m
.00625 .47637 L
s
gsave
-0.0125 .47637 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .54507 m
.00625 .54507 L
s
gsave
-0.0125 .54507 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61376 m
.00625 .61376 L
s
gsave
-0.0125 .61376 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.002) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .19755 m
.00375 .19755 L
s
0 .22606 m
.00375 .22606 L
s
0 .26624 m
.00375 .26624 L
s
0 .28152 m
.00375 .28152 L
s
0 .29475 m
.00375 .29475 L
s
0 .30643 m
.00375 .30643 L
s
0 .42575 m
.00375 .42575 L
s
0 .45426 m
.00375 .45426 L
s
0 .49444 m
.00375 .49444 L
s
0 .50972 m
.00375 .50972 L
s
0 .52295 m
.00375 .52295 L
s
0 .53462 m
.00375 .53462 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(error) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.1484 .60332 Mdot
.22129 .60332 Mdot
.273 .60332 Mdot
.31311 .60332 Mdot
.34588 .60332 Mdot
.37359 .60332 Mdot
.39759 .60175 Mdot
.41876 .60168 Mdot
.4377 .59889 Mdot
.45484 .59871 Mdot
.47048 .59513 Mdot
.48486 .59481 Mdot
.49818 .59072 Mdot
.51059 .59027 Mdot
.52219 .5859 Mdot
.53308 .58529 Mdot
.54336 .58083 Mdot
.55308 .58 Mdot
.5623 .57556 Mdot
.57107 .5747 Mdot
.57943 .57016 Mdot
.58742 .56926 Mdot
.59507 .56466 Mdot
.60241 .56372 Mdot
.60946 .55907 Mdot
.61624 .55809 Mdot
.62278 .55341 Mdot
.62909 .55239 Mdot
.63518 .54768 Mdot
.64107 .54663 Mdot
.64678 .5419 Mdot
.65231 .54082 Mdot
.65768 .53606 Mdot
.66289 .53496 Mdot
.66795 .53019 Mdot
.67288 .52906 Mdot
.67767 .52428 Mdot
.68234 .52313 Mdot
.68689 .51834 Mdot
.69133 .51717 Mdot
.69566 .51238 Mdot
.69989 .51118 Mdot
.70402 .50645 Mdot
.70806 .50516 Mdot
.71201 .50049 Mdot
.71588 .49912 Mdot
.71966 .49451 Mdot
.72337 .49305 Mdot
.727 .4885 Mdot
.73056 .48697 Mdot
.73405 .48247 Mdot
.73748 .48087 Mdot
.74084 .47641 Mdot
.74413 .47475 Mdot
.74737 .47034 Mdot
.75055 .46862 Mdot
.75368 .46425 Mdot
.75675 .46247 Mdot
.75977 .45813 Mdot
.76275 .4563 Mdot
.76567 .45201 Mdot
.76854 .45013 Mdot
.77138 .44586 Mdot
.77416 .44394 Mdot
.77691 .4397 Mdot
.77961 .43776 Mdot
.78227 .43353 Mdot
.7849 .43159 Mdot
.78748 .42734 Mdot
.79003 .4254 Mdot
.79255 .42114 Mdot
.79503 .4192 Mdot
.79747 .41493 Mdot
.79988 .41299 Mdot
.80227 .40871 Mdot
.80462 .40677 Mdot
.80693 .40248 Mdot
.80922 .40054 Mdot
.81149 .39624 Mdot
.81372 .39429 Mdot
.81592 .38999 Mdot
.8181 .38804 Mdot
.82026 .38373 Mdot
.82238 .38178 Mdot
.82449 .37747 Mdot
.82656 .37551 Mdot
.82862 .37119 Mdot
.83065 .36923 Mdot
.83266 .36491 Mdot
.83464 .36295 Mdot
.83661 .35862 Mdot
.83855 .35665 Mdot
.84047 .35233 Mdot
.84238 .35035 Mdot
.84426 .34603 Mdot
.84612 .34405 Mdot
.84796 .33972 Mdot
.84979 .33774 Mdot
.8516 .33341 Mdot
.85338 .33142 Mdot
.85516 .3271 Mdot
.85691 .3251 Mdot
.85865 .32078 Mdot
.86037 .31877 Mdot
.86207 .31445 Mdot
.86376 .31244 Mdot
.86543 .30812 Mdot
.86709 .3061 Mdot
.86873 .30179 Mdot
.87036 .29976 Mdot
.87197 .29545 Mdot
.87356 .29342 Mdot
.87515 .28911 Mdot
.87672 .28707 Mdot
.87827 .28276 Mdot
.87982 .28072 Mdot
.88135 .27642 Mdot
.88286 .27437 Mdot
.88437 .27007 Mdot
.88586 .26801 Mdot
.88734 .26371 Mdot
.88881 .26165 Mdot
.89026 .25736 Mdot
.89171 .25529 Mdot
.89314 .251 Mdot
.89456 .24892 Mdot
.89597 .24464 Mdot
.89737 .24256 Mdot
.89876 .23827 Mdot
.90013 .23619 Mdot
.9015 .23191 Mdot
.90286 .22981 Mdot
.9042 .22554 Mdot
.90554 .22344 Mdot
.90687 .21917 Mdot
.90818 .21706 Mdot
.90949 .2128 Mdot
.91079 .21069 Mdot
.91208 .20643 Mdot
.91336 .20432 Mdot
.91463 .20005 Mdot
.91589 .19795 Mdot
.91714 .19368 Mdot
.91839 .19158 Mdot
.91962 .1873 Mdot
.92085 .18521 Mdot
.92207 .18092 Mdot
.92328 .17884 Mdot
.92448 .17454 Mdot
.92567 .17247 Mdot
.92686 .16816 Mdot
.92804 .16609 Mdot
.92921 .16177 Mdot
.93037 .15972 Mdot
.93153 .15539 Mdot
.93268 .15334 Mdot
.93382 .149 Mdot
.93495 .14697 Mdot
.93608 .14261 Mdot
.9372 .14059 Mdot
.93831 .13623 Mdot
.93942 .13421 Mdot
.94052 .12984 Mdot
.94161 .12783 Mdot
.9427 .12345 Mdot
.94378 .12145 Mdot
.94485 .11706 Mdot
.94592 .11506 Mdot
.94698 .11067 Mdot
.94803 .10868 Mdot
.94908 .10427 Mdot
.95012 .1023 Mdot
.95116 .09788 Mdot
.95219 .09591 Mdot
.95321 .09149 Mdot
.95423 .08952 Mdot
.95524 .08509 Mdot
.95625 .08314 Mdot
.95725 .0787 Mdot
.95825 .07675 Mdot
.95924 .0723 Mdot
.96022 .07036 Mdot
.9612 .06591 Mdot
.96218 .06397 Mdot
.96315 .05951 Mdot
.96411 .05758 Mdot
.96507 .05311 Mdot
.96602 .05119 Mdot
.96697 .04671 Mdot
.96791 .0448 Mdot
.96885 .04031 Mdot
.96979 .03841 Mdot
.97072 .03392 Mdot
.97164 .03202 Mdot
.97256 .02752 Mdot
.97347 .02562 Mdot
.97438 .02112 Mdot
.97529 .01923 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@Oooool4o`000003oa0@4?oo
oooooooo01_ooooo1Ol0000Zooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hFooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^027ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h04oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03_ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04Oooool004?ooooo00?o0000ooooooooool07Oooool01OnHV9So
8B4Qonk^k_ooooooA4A402gooooo00?oMgMgoc8b<_ooool06oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Tooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9So
MgMg01Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`00@oooool00ol0
003oooooooooo`0Nooooo`03oiRHV?lQ8B7ok^k^02oooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41009Oooool01?l0003oooooooooool@4103ooooo`03oa0@
4?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004Oooool004?ooooo00?o0000
ooooooooool07oooool00onHV9So8B4Qonk^kP0]ooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Sooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000002Cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000@ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool004?ooooo00?o
0000ooooooooool08?ooool00omgMgOoIVIVooooo`0Yooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
7?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000006Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000008Oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
0000017ooooo0013ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400J
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Oooooo`03o`000?oo
oooooooo00Cooooo00Go410@oooooooooooooooooa0@400Eooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41004_ooool01Ol0
003ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00oooooo0013ooooo`03o`000?oooooooooo01gooooo00Go0000okZj^_ooooooV9RHoa0@
400Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01Kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL08Oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg017ooooo0011ooooo`03oeEEEOmVIVKo0000
01oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Zooooo`Co00006oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0>ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomOooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00Oooool00?ooooooH?ooool01Ol0003ooooooooooooooooo000000Cooooo003o
ooooof3ooooo00Go0000ooooooooooooooooo`000004ooooo`00??ooooooo`0001Wo00002oooool0
1Ol0003ooooooooooooooooo000000Cooooo000looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0@ooooo`05o`000?n7QhOoooooojVYZOl000001?oo
ool003cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00oooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02ooooo`00??ooool00ol0
003oooooooooo`3oooooob[ooooo000looooo`03o`000?oooooooooo0?oooooo3_ooool2o`0001[o
oooo000looooo`03o`000?oooooooooo0?oooooo3Oooool3o`0001[ooooo000looooo`03o`000?oo
oooooooo0?oooooo3Oooool3o`0001[ooooo000looooo`03o`000?oooooooooo0?oooooo3Oooool2
o`0001_ooooo000looooo`03o`000?oooooooooo0?oooooo3Oooool2o`0001_ooooo000looooo`03
o`000?oooooooooo0?oooooo3?ooool3o`0001_ooooo000looooo`03o`000?oooooooooo0?oooooo
3?ooool2o`0001cooooo000looooo`03o`000?oooooooooo0?oooooo3?ooool2o`0001cooooo000l
ooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0001cooooo000looooo`03o`000?oooooooooo
0?oooooo2oooool3o`0001cooooo000looooo`03o`000?oooooooooo0?oooooo2oooool2o`0001go
oooo000looooo`03o`000?oooooooooo0?oooooo2oooool2o`0001gooooo000looooo`03o`000?oo
oooooooo0?oooooo2_ooool2o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo2_ooool2
o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo2_ooool2o`0001kooooo000looooo`03
o`000?oooooooooo0?oooooo2Oooool3o`0001kooooo000looooo`03o`000?oooooooooo0?oooooo
2Oooool2o`0001oooooo000looooo`03o`000?oooooooooo0?oooooo2Oooool2o`0001oooooo0003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000Go410@ooooooooooooooooo`00
003oooooo`_ooooo0_l0000Oooooo`000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00023ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
o`Sooooo0_l0000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o
oooo0ol0003oooooo`Oooooo0ol0000Pooooo`000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0ooooool7ooooo`;o00008Oooool000?ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo1ooo
ool2o`00027ooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooo`Oooooo0_l0000Qooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`03oeEEEOmVIVKo000000Gooooo00?o0000ooooooooool0ooooool6ooooo`?o00008Oooool003co
oooo00?o0000ooooooooool0ooooool6ooooo`;o00008_ooool003cooooo00?o0000ooooooooool0
ooooool6ooooo`;o00008_ooool003cooooo00?o0000ooooooooool0ooooool5ooooo`;o00008ooo
ool003cooooo00?o0000ooooooooool0ooooool5ooooo`;o00008oooool003cooooo00?o0000oooo
ooooool0ooooool5ooooo`;o00008oooool003cooooo00?o0000ooooooooool0ooooool4ooooo`?o
00008oooool003cooooo00?o0000ooooooooool0ooooool4ooooo`;o00009?ooool003cooooo00?o
0000ooooooooool0ooooool4ooooo`;o00009?ooool003cooooo00?o0000ooooooooool0ooooool3
ooooo`?o00009?ooool003cooooo00?o0000ooooooooool0ooooool3ooooo`;o00009Oooool003co
oooo00?o0000ooooooooool0ooooool2ooooo`?o00009Oooool000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0002Kooooo
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1?ooool00ol0003oooooooooo`3oooooo`;ooooo0_l0000Vooooo`000oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0ooooool1ooooo`?o00009_oo
ool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP04ooooo`?o0000ooooool1
ooooo`;o00009oooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`03oooo
o`03o`000?oooooooooo0?oooooo0Oooool2o`0002Oooooo0003ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`?o00009oooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool0ooooool2o`0002Sooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`03o`000?oooooooooo0?kooooo0ol0000Xooooo`00??ooool00ol0003ooooo
ooooo`3nooooo`?o0000:?ooool003cooooo00?o0000ooooooooool0o_ooool2o`0002Wooooo000l
ooooo`03o`000?oooooooooo0?gooooo0ol0000Yooooo`00??ooool00ol0003oooooooooo`3moooo
o`;o0000:_ooool003cooooo00?o0000ooooooooool0oOooool2o`0002[ooooo000looooo`03o`00
0?oooooooooo0?cooooo0ol0000Zooooo`00??ooool3o`000?cooooo0_l0000[ooooo`00??ooool0
0ol0003oooooooooo`3kooooo`?o0000:oooool003cooooo00?o0000ooooooooool0noooool2o`00
02cooooo000looooo`03o`000?oooooooooo0?_ooooo0_l0000/ooooo`00??ooool00ol0003ooooo
ooooo`3jooooo`?o0000;?ooool003cooooo00?o0000ooooooooool0n_ooool2o`0002gooooo000l
ooooo`03o`000?oooooooooo0?[ooooo0_l0000]ooooo`00??ooool00ol0003oooooooooo`3ioooo
o`?o0000;Oooool003cooooo0ol0003iooooo`;o0000;_ooool003cooooo00?o0000ooooooooool0
n?ooool2o`0002oooooo000looooo`03o`000?oooooooooo0?Sooooo0_l0000_ooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o
0000ooooooooool0moooool3o`0002oooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07
ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool0moooool2o`00033ooooo0003oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Sooooo00Go0000ooooooooooooooooo`00003hooooo`?o0000<?ooool0
00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`02ooooo`?o0000m_ooool2o`00
037ooooo0003ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003oooo
o`03o`000?oooooooooo0?Kooooo0_l0000aooooo`000oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0mOooool2o`0003;ooooo0003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3eooooo`;o0000
<_ooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo00?o0000ooooooooool0m?oo
ool3o`0003;ooooo000looooo`?o0000m?ooool2o`0003?ooooo000looooo`03o`000?oooooooooo
0??ooooo0ol0000cooooo`00??ooool00ol0003oooooooooo`3cooooo`;o0000=?ooool003cooooo
00?o0000ooooooooool0l_ooool3o`0003Cooooo000looooo`?o0000l_ooool2o`0003Gooooo000l
ooooo`03o`000?oooooooooo0?;ooooo0_l0000eooooo`00??ooool00ol0003oooooooooo`3aoooo
o`;o0000=_ooool003cooooo00?o0000ooooooooool0l?ooool3o`0003Kooooo000looooo`?o0000
l?ooool2o`0003Oooooo000looooo`03o`000?oooooooooo0>oooooo0ol0000gooooo`00??ooool0
0ol0003oooooooooo`3_ooooo`;o0000>?ooool003cooooo0ol0003^ooooo`?o0000>?ooool000_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool4o`000005oa0@4?ooooooooooooooool00000l?ooool2o`0003Wooooo000;ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`?o0000>Oooool000_ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
00?ooooo0ol0003]ooooo`?o0000>Oooool000_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
k?ooool3o`0003[ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo0_l0000k
ooooo`002oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3[ooooo`?o0000>oooool000_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0j_ooool3o`0003cooooo000;ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00omEEEGoIVIVo`000005oooo
o`03o`000?oooooooooo0>[ooooo0ol0000looooo`00??ooool00ol0003oooooooooo`3Yooooo`?o
0000?Oooool003cooooo00?o0000ooooooooool0jOooool3o`0003gooooo000looooo`03o`000?oo
oooooooo0>Sooooo0ol0000nooooo`00??ooool00ol0003oooooooooo`3Xooooo`;o0000?oooool0
03cooooo00?o0000ooooooooool0ioooool3o`0003oooooo000looooo`03o`000?oooooooooo0>Ko
oooo0ol00010ooooo`00??ooool00ol0003oooooooooo`3Vooooo`?o0000@?ooool003cooooo00?o
0000ooooooooool0iOooool2o`0004;ooooo000looooo`03o`000?oooooooooo0>Cooooo0ol00012
ooooo`00??ooool00ol0003oooooooooo`3Tooooo`;o0000@oooool003cooooo00?o0000oooooooo
ool0hoooool3o`0004?ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`03o`000?oooooooooo0>?ooooo0_l0
0014ooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`3Q
ooooo`Co0000A?ooool000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0ol0003Qooooo`?o0000AOooool000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00?o0000ooooooooool0h?ooool3o`0004Kooooo000;ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`03oooo
o`03o`000?oooooooooo0>3ooooo0ol00016ooooo`002oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3Oooooo`?o0000Aoooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`3Nooooo`?o0000B?ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`3N
ooooo`;o0000BOooool003cooooo00?o0000ooooooooool0g?ooool4o`0004Wooooo000looooo`03
o`000?oooooooooo0=cooooo0ol0001:ooooo`00??ooool00ol0003oooooooooo`3Kooooo`?o0000
Boooool003cooooo00?o0000ooooooooool0f_ooool4o`0004_ooooo000looooo`03o`000?oooooo
oooo0=[ooooo0_l0001=ooooo`00??ooool00ol0003oooooooooo`3Iooooo`?o0000COooool003co
oooo0ol0003Hooooo`?o0000C_ooool003cooooo00?o0000ooooooooool0eoooool3o`0004oooooo
000looooo`03o`000?oooooooooo0=Kooooo1?l0001?ooooo`00??ooool00ol0003oooooooooo`3E
ooooo`?o0000DOooool003cooooo00?o0000ooooooooool0eOooool2o`0005;ooooo000looooo`03
o`000?oooooooooo0=Cooooo0ol0001Booooo`00??ooool00ol0003oooooooooo`3Booooo`Co0000
Doooool003cooooo00?o0000ooooooooool0d_ooool3o`0005Cooooo000looooo`?o0000dOooool2
o`0005Kooooo000looooo`03o`000?oooooooooo0=3ooooo0ol0001Fooooo`00??ooool00ol0003o
ooooooooo`3?ooooo`?o0000Eoooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo
00?o0000ooooooooool0c_ooool3o`0005Sooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool00_ooool0
0ol0003oooooooooo`3=ooooo`?o0000FOooool000_ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4008ooooo`05o`000?ooooooooooooooool00000cOooool4o`00
05[ooooo000;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1oooool00omgMgOo<S8booooo`02ooooo`?o0000boooool3o`0005_ooooo000;ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00?o0000ooooooooool0bOooool3o`0005gooooo000;ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0<Sooooo1?l0001Mooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`37ooooo`?o0000Goooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`Co00001?ooool00ol0003oooooooooo`35ooooo`Co0000H?ooool0
03cooooo0ol00035ooooo`?o0000HOooool003cooooo00?o0000ooooooooool0`oooool3o`0006?o
oooo000looooo`03o`000?oooooooooo0<;ooooo1?l0001Sooooo`00??ooool00ol0003ooooooooo
o`31ooooo`?o0000IOooool003cooooo0ol0002oooooo`Co0000I_ooool003cooooo00?o0000oooo
ooooool0_oooool3o`0006Oooooo000looooo`03o`000?oooooooooo0;cooooo0ol0001Zooooo`00
??ooool00ol0003oooooooooo`2kooooo`Co0000J_ooool003cooooo0ol0002jooooo`?o0000K?oo
ool003cooooo00?o0000ooooooooool0]oooool5o`0006gooooo000looooo`03o`000?oooooooooo
0;Oooooo0ol0001_ooooo`004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
00000ol@413oooooooooo`02ooooo`?o0000]?ooool4o`00077ooooo000Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;?o
oooo1Ol0001aooooo`004_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;7ooooo1?l0001dooooo`004_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`04ooooo`?o0000[_ooool5o`0007Kooooo000Booooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?ooool5o`00
07Sooooo000Booooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Z_ooool4o`0007_ooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Yoooool5o`0007gooooo000Booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0Yoooool4
o`0007kooooo000looooo`03o`000?oooooooooo0:?ooooo1?l00022ooooo`00??ooool00ol0003o
ooooooooo`2Nooooo`;o000000?oooooo`000?l000001?l00022ooooo`00??ooool00ol0003ooooo
ooooo`2Nooooo`;o000000?oooooo`000?l00000Q_ooool003cooooo00?o0000ooooooooool0V_oo
ool4o`0008_ooooo000looooo`03o`000?oooooooooo09Cooooo0_l000001?oooooo0000o`000?oo
ool4o`0008_ooooo000looooo`03o`000?oooooooooo09Cooooo0_l000000ooooooo0000o`00002@
ooooo`00??ooool00ol0003oooooooooo`2>ooooo`;o000000?oooooo`000?l00000U_ooool003co
oooo00?o0000ooooooooool0R?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`00
0?l00000U_ooool003cooooo00?o0000ooooooooool0P?ooool2o`0000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l00000W?ooool003cooooo00?o0000ooooooooool0Moooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`000:?ooooo000looooo`03o`000?oooooooooo06cooooo0_l0
0004ooooo`;o00000oooool2o`0000?ooooo0_l0002[ooooo`004_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0000Pooooo`;o
00004oooool2o`0000cooooo0_l00009ooooo`;o00001oooool2o`0000Kooooo0_l00005ooooo`;o
00001?ooool2o`000;Gooooo000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool01?ooool2o`00023ooooo0_l0
000Cooooo`;o00003?ooool2o`0000Wooooo0_l00007ooooo`;o00001_ooool2o`000<;ooooo000B
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0oooooolZooooo`004_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP05
ooooo`?o0000oooooolZooooo`004_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo0?oooooo:_ooool001;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00Oooooo00?o0000ooooooooool0ooooool`ooooo`004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01Ol0003o^[ZjoooooonHV9So410@0?oooooo<_ooool001;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03ooooooc;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0018ooooo`;o
00002oooool2o`000?oooooo4_ooool004Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3ooooooa3ooooo000Pooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`00
00;ooooo00?o410@o`000?l000000ol00003ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^oooo
ool@4105o`0000?ooooo00?o0000ooooooooool00_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooooooooo`000?oooooo4_ooool0023ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgoooooooo
ooooMgMgoeEEE@?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`3ooooooa3ooooo000Pooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oooooo4?ooool0023o
oooo1_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3ooooooa3ooooo000Poooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@05ooooo`03o`000?lb
<S;ogMgM00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o0000oooo
ooooool0ooooool@ooooo`008?ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l00000
1?nYZJWo8B4Qo`000?lQ8B42ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEE
o`000?l0003oEEEEonk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`03o`000?oooooo
oooo00;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Sooooooooooooooooo00000?oooooo4_oo
ool004Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooa3ooooo0018oooo
o`;o00002oooool2o`000?oooooo4_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.586479, -5.74836, \
0.0108422, 0.0196649}}]
}, Open  ]],

Cell["\<\
We can again construct an interpolation function of the solution, \
taken  from the 200th iteration:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Phi]sol\  = \ 
      Interpolation[
        Flatten[Table[{j\ \[CapitalDelta]x, 
              k\ \[CapitalDelta]y, \[Phi][j, k, 200]}, {j, 0, M\_x}, {k, 0, 
              M\_y}], 1]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.114"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.5`}, {0.`, 2.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "A contour plot of the solution is shown in Cell ",
  ButtonBox["6.115",
    ButtonData:>"Cell 6.115",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\[Phi]sol[x, y], {x, 0, 1.5}, {y, 0, 2}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotLabel \[Rule] "\<Potential inside a\ncharge-filled irregular \
box\>", AspectRatio \[Rule] 4/3, PlotPoints \[Rule] 30];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.115"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.641026 0.025641 0.641026 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.14744 -0.0125 -9 -9 ]
[.14744 -0.0125 9 0 ]
[.27564 -0.0125 -9 -9 ]
[.27564 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.53205 -0.0125 -9 -9 ]
[.53205 -0.0125 9 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.91667 -0.0125 -9 -9 ]
[.91667 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .02564 -6 -4.5 ]
[-0.0125 .02564 0 4.5 ]
[-0.0125 .34615 -18 -4.5 ]
[-0.0125 .34615 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .98718 -18 -4.5 ]
[-0.0125 .98718 0 4.5 ]
[-0.0125 1.30769 -6 -4.5 ]
[-0.0125 1.30769 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .66667 -30 -5 ]
[-0.01875 .66667 -18 5 ]
[ 0 1.33333 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.34583 -83 0 ]
[.5 1.34583 83 24.5 ]
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.14744 0 m
.14744 .00625 L
s
[(0.2)] .14744 -0.0125 0 1 Mshowa
.27564 0 m
.27564 .00625 L
s
[(0.4)] .27564 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.6)] .40385 -0.0125 0 1 Mshowa
.53205 0 m
.53205 .00625 L
s
[(0.8)] .53205 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(1)] .66026 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(1.2)] .78846 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(1.4)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.33974 0 m
.33974 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.5 0 m
.5 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02564 m
.00625 .02564 L
s
[(0)] -0.0125 .02564 1 0 Mshowa
0 .34615 m
.00625 .34615 L
s
[(0.5)] -0.0125 .34615 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(1)] -0.0125 .66667 1 0 Mshowa
0 .98718 m
.00625 .98718 L
s
[(1.5)] -0.0125 .98718 1 0 Mshowa
0 1.30769 m
.00625 1.30769 L
s
[(2)] -0.0125 1.30769 1 0 Mshowa
.125 Mabswid
0 .08974 m
.00375 .08974 L
s
0 .15385 m
.00375 .15385 L
s
0 .21795 m
.00375 .21795 L
s
0 .28205 m
.00375 .28205 L
s
0 .41026 m
.00375 .41026 L
s
0 .47436 m
.00375 .47436 L
s
0 .53846 m
.00375 .53846 L
s
0 .60256 m
.00375 .60256 L
s
0 .73077 m
.00375 .73077 L
s
0 .79487 m
.00375 .79487 L
s
0 .85897 m
.00375 .85897 L
s
0 .92308 m
.00375 .92308 L
s
0 1.05128 m
.00375 1.05128 L
s
0 1.11538 m
.00375 1.11538 L
s
0 1.17949 m
.00375 1.17949 L
s
0 1.24359 m
.00375 1.24359 L
s
.25 Mabswid
0 0 m
0 1.33333 L
s
gsave
-0.01875 .66667 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 1.32708 m
.01923 1.33333 L
s
.14744 1.32708 m
.14744 1.33333 L
s
.27564 1.32708 m
.27564 1.33333 L
s
.40385 1.32708 m
.40385 1.33333 L
s
.53205 1.32708 m
.53205 1.33333 L
s
.66026 1.32708 m
.66026 1.33333 L
s
.78846 1.32708 m
.78846 1.33333 L
s
.91667 1.32708 m
.91667 1.33333 L
s
.125 Mabswid
.05128 1.32958 m
.05128 1.33333 L
s
.08333 1.32958 m
.08333 1.33333 L
s
.11538 1.32958 m
.11538 1.33333 L
s
.17949 1.32958 m
.17949 1.33333 L
s
.21154 1.32958 m
.21154 1.33333 L
s
.24359 1.32958 m
.24359 1.33333 L
s
.30769 1.32958 m
.30769 1.33333 L
s
.33974 1.32958 m
.33974 1.33333 L
s
.37179 1.32958 m
.37179 1.33333 L
s
.4359 1.32958 m
.4359 1.33333 L
s
.46795 1.32958 m
.46795 1.33333 L
s
.5 1.32958 m
.5 1.33333 L
s
.5641 1.32958 m
.5641 1.33333 L
s
.59615 1.32958 m
.59615 1.33333 L
s
.62821 1.32958 m
.62821 1.33333 L
s
.69231 1.32958 m
.69231 1.33333 L
s
.72436 1.32958 m
.72436 1.33333 L
s
.75641 1.32958 m
.75641 1.33333 L
s
.82051 1.32958 m
.82051 1.33333 L
s
.85256 1.32958 m
.85256 1.33333 L
s
.88462 1.32958 m
.88462 1.33333 L
s
.94872 1.32958 m
.94872 1.33333 L
s
.98077 1.32958 m
.98077 1.33333 L
s
.25 Mabswid
0 1.33333 m
1 1.33333 L
s
.99375 .02564 m
1 .02564 L
s
.99375 .34615 m
1 .34615 L
s
.99375 .66667 m
1 .66667 L
s
.99375 .98718 m
1 .98718 L
s
.99375 1.30769 m
1 1.30769 L
s
.125 Mabswid
.99625 .08974 m
1 .08974 L
s
.99625 .15385 m
1 .15385 L
s
.99625 .21795 m
1 .21795 L
s
.99625 .28205 m
1 .28205 L
s
.99625 .41026 m
1 .41026 L
s
.99625 .47436 m
1 .47436 L
s
.99625 .53846 m
1 .53846 L
s
.99625 .60256 m
1 .60256 L
s
.99625 .73077 m
1 .73077 L
s
.99625 .79487 m
1 .79487 L
s
.99625 .85897 m
1 .85897 L
s
.99625 .92308 m
1 .92308 L
s
.99625 1.05128 m
1 1.05128 L
s
.99625 1.11538 m
1 1.11538 L
s
.99625 1.17949 m
1 1.17949 L
s
.99625 1.24359 m
1 1.24359 L
s
.25 Mabswid
1 0 m
1 1.33333 L
s
gsave
.5 1.34583 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
63.000 25.500 moveto
(charge) show
99.000 25.500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
105.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
147.000 25.500 moveto
(irregular) show
207.000 25.500 moveto
(box) show
225.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 g
.01923 1.30769 m
.98077 1.30769 L
.98077 .02564 L
.01923 .02564 L
F
0 g
.5 Mabswid
.9 g
.54973 .03111 m
.58289 .029 L
.61605 .02839 L
.6492 .02815 L
.68236 .02806 L
.71552 .02806 L
.74867 .02812 L
.78183 .02825 L
.81499 .02848 L
.84814 .02885 L
.8813 .0295 L
.91446 .03086 L
.94761 .03502 L
.97444 .06985 L
.97699 .11406 L
.97775 .15827 L
.97809 .20248 L
.97821 .24668 L
.97812 .29089 L
.97747 .3351 L
.95697 .37931 L
.94761 .38954 L
.92439 .42352 L
.91446 .44423 L
.88869 .46773 L
.8813 .47804 L
.86392 .51194 L
.84814 .52924 L
.82872 .55615 L
.81499 .5773 L
.78966 .60035 L
.78183 .61218 L
.76406 .64456 L
.74867 .66053 L
.73013 .68877 L
.71552 .70961 L
.6911 .73298 L
.68236 .7475 L
.66289 .77719 L
.6492 .79115 L
.63116 .8214 L
.61605 .84157 L
.59326 .86561 L
.58289 .88349 L
.56034 .90981 L
.54973 .92129 L
.5317 .95402 L
.51658 .97208 L
.49979 .99823 L
.50024 1.04244 L
.50134 1.08665 L
.50074 1.13086 L
.49984 1.17507 L
.49816 1.21927 L
.49332 1.26348 L
.48342 1.28666 L
.45027 1.30157 L
.41711 1.30351 L
.38395 1.30428 L
.3508 1.30467 L
.31764 1.30487 L
.28448 1.30495 L
.25133 1.30495 L
.21817 1.30487 L
.18501 1.30468 L
.15186 1.30433 L
.1187 1.30369 L
.08554 1.30232 L
.05239 1.29808 L
.02584 1.26348 L
.02318 1.21927 L
.02238 1.17507 L
.02202 1.13086 L
.02187 1.08665 L
.02192 1.04244 L
.02257 .99823 L
.04612 .95402 L
.05239 .94715 L
.072 .90981 L
.07124 .86561 L
.07105 .8214 L
.07441 .77719 L
.08554 .75614 L
.11696 .73298 L
.1187 .73015 L
.14092 .68877 L
.15186 .67742 L
.16585 .64456 L
.16439 .60035 L
.18501 .56213 L
.18961 .55615 L
.21817 .52377 L
.225 .51194 L
.25133 .48314 L
.26058 .46773 L
.26247 .42352 L
.26979 .37931 L
.28448 .36235 L
.31387 .3351 L
.31764 .32846 L
.34952 .29089 L
.3508 .28946 L
.37411 .24668 L
.38395 .23455 L
.41179 .20248 L
.41711 .19351 L
.45027 .15987 L
.4516 .15827 L
.47442 .11406 L
.48342 .10531 L
.51658 .0725 L
.51949 .06985 L
F
0 g
.54973 .03111 m
.58289 .029 L
.61605 .02839 L
.6492 .02815 L
.68236 .02806 L
.71552 .02806 L
.74867 .02812 L
.78183 .02825 L
.81499 .02848 L
.84814 .02885 L
.8813 .0295 L
.91446 .03086 L
.94761 .03502 L
.97444 .06985 L
.97699 .11406 L
.97775 .15827 L
.97809 .20248 L
.97821 .24668 L
.97812 .29089 L
.97747 .3351 L
.95697 .37931 L
.94761 .38954 L
.92439 .42352 L
.91446 .44423 L
.88869 .46773 L
.8813 .47804 L
.86392 .51194 L
.84814 .52924 L
.82872 .55615 L
.81499 .5773 L
.78966 .60035 L
.78183 .61218 L
.76406 .64456 L
.74867 .66053 L
.73013 .68877 L
.71552 .70961 L
.6911 .73298 L
.68236 .7475 L
.66289 .77719 L
.6492 .79115 L
.63116 .8214 L
.61605 .84157 L
.59326 .86561 L
.58289 .88349 L
.56034 .90981 L
.54973 .92129 L
.5317 .95402 L
.51658 .97208 L
.49979 .99823 L
.50024 1.04244 L
Mistroke
.50134 1.08665 L
.50074 1.13086 L
.49984 1.17507 L
.49816 1.21927 L
.49332 1.26348 L
.48342 1.28666 L
.45027 1.30157 L
.41711 1.30351 L
.38395 1.30428 L
.3508 1.30467 L
.31764 1.30487 L
.28448 1.30495 L
.25133 1.30495 L
.21817 1.30487 L
.18501 1.30468 L
.15186 1.30433 L
.1187 1.30369 L
.08554 1.30232 L
.05239 1.29808 L
.02584 1.26348 L
.02318 1.21927 L
.02238 1.17507 L
.02202 1.13086 L
.02187 1.08665 L
.02192 1.04244 L
.02257 .99823 L
.04612 .95402 L
.05239 .94715 L
.072 .90981 L
.07124 .86561 L
.07105 .8214 L
.07441 .77719 L
.08554 .75614 L
.11696 .73298 L
.1187 .73015 L
.14092 .68877 L
.15186 .67742 L
.16585 .64456 L
.16439 .60035 L
.18501 .56213 L
.18961 .55615 L
.21817 .52377 L
.225 .51194 L
.25133 .48314 L
.26058 .46773 L
.26247 .42352 L
.26979 .37931 L
.28448 .36235 L
.31387 .3351 L
.31764 .32846 L
Mistroke
.34952 .29089 L
.3508 .28946 L
.37411 .24668 L
.38395 .23455 L
.41179 .20248 L
.41711 .19351 L
.45027 .15987 L
.4516 .15827 L
.47442 .11406 L
.48342 .10531 L
.51658 .0725 L
.51949 .06985 L
.54973 .03111 L
Mfstroke
.8 g
.54973 .06713 m
.58289 .05373 L
.61605 .04889 L
.6492 .04683 L
.68236 .04599 L
.71552 .04588 L
.74867 .04633 L
.78183 .04734 L
.81499 .04908 L
.84814 .05197 L
.8813 .0571 L
.91446 .06803 L
.91773 .06985 L
.94732 .11406 L
.94761 .11509 L
.95467 .15827 L
.95779 .20248 L
.9589 .24668 L
.95816 .29089 L
.95356 .3351 L
.94761 .3602 L
.92572 .37931 L
.91446 .39425 L
.89686 .42352 L
.8813 .43007 L
.86418 .46773 L
.84814 .48998 L
.82942 .51194 L
.81499 .53401 L
.79975 .55615 L
.78183 .57933 L
.75577 .60035 L
.74867 .62256 L
.72922 .64456 L
.71552 .6692 L
.70144 .68877 L
.68236 .71254 L
.66012 .73298 L
.6492 .75203 L
.62665 .77719 L
.61605 .80206 L
.60154 .8214 L
.58289 .83504 L
.5637 .86561 L
.54973 .8796 L
.53415 .90981 L
.51658 .93555 L
.50167 .95402 L
.48342 .98768 L
.479 .99823 L
.47668 1.04244 L
.47503 1.08665 L
.47232 1.13086 L
.46851 1.17507 L
.46208 1.21927 L
.45027 1.25178 L
.43614 1.26348 L
.41711 1.27158 L
.38395 1.27866 L
.3508 1.2821 L
.31764 1.2839 L
.28448 1.2847 L
.25133 1.28476 L
.21817 1.28412 L
.18501 1.28264 L
.15186 1.2799 L
.1187 1.27478 L
.08554 1.26349 L
.08554 1.26348 L
.05401 1.21927 L
.05239 1.21325 L
.04634 1.17507 L
.04302 1.13086 L
.04164 1.08665 L
.04201 1.04244 L
.04615 .99823 L
.05239 .98566 L
.07259 .95402 L
.08554 .92292 L
.08886 .90981 L
.09028 .86561 L
.09308 .8214 L
.10912 .77719 L
.1187 .76348 L
.13882 .73298 L
.15186 .71565 L
.16883 .68877 L
.18501 .6475 L
.18576 .64456 L
.19243 .60035 L
.21817 .56459 L
.22625 .55615 L
.25133 .51318 L
.25237 .51194 L
.2785 .46773 L
.2843 .42352 L
.28448 .42266 L
.31056 .37931 L
.31764 .36607 L
.34776 .3351 L
.3508 .3186 L
.37296 .29089 L
.38395 .27818 L
.40858 .24668 L
.41711 .23211 L
.44411 .20248 L
.45027 .18803 L
.47465 .15827 L
.48342 .14748 L
.51237 .11406 L
.51658 .10792 L
.54725 .06985 L
F
0 g
.54973 .06713 m
.58289 .05373 L
.61605 .04889 L
.6492 .04683 L
.68236 .04599 L
.71552 .04588 L
.74867 .04633 L
.78183 .04734 L
.81499 .04908 L
.84814 .05197 L
.8813 .0571 L
.91446 .06803 L
.91773 .06985 L
.94732 .11406 L
.94761 .11509 L
.95467 .15827 L
.95779 .20248 L
.9589 .24668 L
.95816 .29089 L
.95356 .3351 L
.94761 .3602 L
.92572 .37931 L
.91446 .39425 L
.89686 .42352 L
.8813 .43007 L
.86418 .46773 L
.84814 .48998 L
.82942 .51194 L
.81499 .53401 L
.79975 .55615 L
.78183 .57933 L
.75577 .60035 L
.74867 .62256 L
.72922 .64456 L
.71552 .6692 L
.70144 .68877 L
.68236 .71254 L
.66012 .73298 L
.6492 .75203 L
.62665 .77719 L
.61605 .80206 L
.60154 .8214 L
.58289 .83504 L
.5637 .86561 L
.54973 .8796 L
.53415 .90981 L
.51658 .93555 L
.50167 .95402 L
.48342 .98768 L
.479 .99823 L
Mistroke
.47668 1.04244 L
.47503 1.08665 L
.47232 1.13086 L
.46851 1.17507 L
.46208 1.21927 L
.45027 1.25178 L
.43614 1.26348 L
.41711 1.27158 L
.38395 1.27866 L
.3508 1.2821 L
.31764 1.2839 L
.28448 1.2847 L
.25133 1.28476 L
.21817 1.28412 L
.18501 1.28264 L
.15186 1.2799 L
.1187 1.27478 L
.08554 1.26349 L
.08554 1.26348 L
.05401 1.21927 L
.05239 1.21325 L
.04634 1.17507 L
.04302 1.13086 L
.04164 1.08665 L
.04201 1.04244 L
.04615 .99823 L
.05239 .98566 L
.07259 .95402 L
.08554 .92292 L
.08886 .90981 L
.09028 .86561 L
.09308 .8214 L
.10912 .77719 L
.1187 .76348 L
.13882 .73298 L
.15186 .71565 L
.16883 .68877 L
.18501 .6475 L
.18576 .64456 L
.19243 .60035 L
.21817 .56459 L
.22625 .55615 L
.25133 .51318 L
.25237 .51194 L
.2785 .46773 L
.2843 .42352 L
.28448 .42266 L
.31056 .37931 L
.31764 .36607 L
.34776 .3351 L
Mistroke
.3508 .3186 L
.37296 .29089 L
.38395 .27818 L
.40858 .24668 L
.41711 .23211 L
.44411 .20248 L
.45027 .18803 L
.47465 .15827 L
.48342 .14748 L
.51237 .11406 L
.51658 .10792 L
.54725 .06985 L
.54973 .06713 L
Mfstroke
.7 g
.6492 .06696 m
.68236 .06525 L
.71552 .06498 L
.74867 .06585 L
.78183 .06791 L
.80231 .06985 L
.81499 .07153 L
.84814 .07784 L
.8813 .09013 L
.90897 .11406 L
.91446 .12221 L
.92775 .15827 L
.93498 .20248 L
.93756 .24668 L
.93643 .29089 L
.92917 .3351 L
.91446 .37127 L
.90394 .37931 L
.8813 .41837 L
.87711 .42352 L
.84814 .46559 L
.84671 .46773 L
.81499 .50954 L
.8132 .51194 L
.78234 .55615 L
.78183 .55692 L
.74883 .60035 L
.74867 .60238 L
.71557 .64456 L
.71552 .6447 L
.68315 .68877 L
.68236 .6899 L
.65009 .73298 L
.6492 .7349 L
.61607 .77719 L
.61605 .77727 L
.58289 .82117 L
.58271 .8214 L
.55086 .86561 L
.54973 .86649 L
.51709 .90981 L
.51658 .9105 L
.48473 .95402 L
.48342 .95679 L
.46497 .99823 L
.46143 1.04244 L
.45854 1.08665 L
.45479 1.13086 L
.45027 1.16451 L
.44769 1.17507 L
.42736 1.21927 L
.41711 1.22994 L
.38395 1.24833 L
.3508 1.25647 L
.31764 1.26055 L
.28448 1.26237 L
.25133 1.26256 L
.21817 1.26123 L
.18501 1.25804 L
.15186 1.25184 L
.1187 1.23907 L
.09522 1.21927 L
.08554 1.20453 L
.07477 1.17507 L
.06681 1.13086 L
.06356 1.08665 L
.0638 1.04244 L
.06949 .99823 L
.08554 .9672 L
.09138 .95402 L
.10324 .90981 L
.1063 .86561 L
.11113 .8214 L
.1187 .79134 L
.13057 .77719 L
.15186 .74002 L
.15635 .73298 L
.18501 .69165 L
.18643 .68877 L
.20108 .64456 L
.21176 .60035 L
.21817 .58848 L
.24426 .55615 L
.25133 .53934 L
.27178 .51194 L
.28448 .48836 L
.29295 .46773 L
.30198 .42352 L
.31764 .39266 L
.32856 .37931 L
.3508 .34329 L
.35699 .3351 L
.38395 .30123 L
.391 .29089 L
.41711 .25773 L
.42587 .24668 L
.45027 .21213 L
.4584 .20248 L
.48342 .17356 L
.49449 .15827 L
.51658 .13466 L
.53486 .11406 L
.54973 .09876 L
.58289 .07952 L
.61605 .07093 L
.62136 .06985 L
F
0 g
.6492 .06696 m
.68236 .06525 L
.71552 .06498 L
.74867 .06585 L
.78183 .06791 L
.80231 .06985 L
.81499 .07153 L
.84814 .07784 L
.8813 .09013 L
.90897 .11406 L
.91446 .12221 L
.92775 .15827 L
.93498 .20248 L
.93756 .24668 L
.93643 .29089 L
.92917 .3351 L
.91446 .37127 L
.90394 .37931 L
.8813 .41837 L
.87711 .42352 L
.84814 .46559 L
.84671 .46773 L
.81499 .50954 L
.8132 .51194 L
.78234 .55615 L
.78183 .55692 L
.74883 .60035 L
.74867 .60238 L
.71557 .64456 L
.71552 .6447 L
.68315 .68877 L
.68236 .6899 L
.65009 .73298 L
.6492 .7349 L
.61607 .77719 L
.61605 .77727 L
.58289 .82117 L
.58271 .8214 L
.55086 .86561 L
.54973 .86649 L
.51709 .90981 L
.51658 .9105 L
.48473 .95402 L
.48342 .95679 L
.46497 .99823 L
.46143 1.04244 L
.45854 1.08665 L
.45479 1.13086 L
.45027 1.16451 L
.44769 1.17507 L
Mistroke
.42736 1.21927 L
.41711 1.22994 L
.38395 1.24833 L
.3508 1.25647 L
.31764 1.26055 L
.28448 1.26237 L
.25133 1.26256 L
.21817 1.26123 L
.18501 1.25804 L
.15186 1.25184 L
.1187 1.23907 L
.09522 1.21927 L
.08554 1.20453 L
.07477 1.17507 L
.06681 1.13086 L
.06356 1.08665 L
.0638 1.04244 L
.06949 .99823 L
.08554 .9672 L
.09138 .95402 L
.10324 .90981 L
.1063 .86561 L
.11113 .8214 L
.1187 .79134 L
.13057 .77719 L
.15186 .74002 L
.15635 .73298 L
.18501 .69165 L
.18643 .68877 L
.20108 .64456 L
.21176 .60035 L
.21817 .58848 L
.24426 .55615 L
.25133 .53934 L
.27178 .51194 L
.28448 .48836 L
.29295 .46773 L
.30198 .42352 L
.31764 .39266 L
.32856 .37931 L
.3508 .34329 L
.35699 .3351 L
.38395 .30123 L
.391 .29089 L
.41711 .25773 L
.42587 .24668 L
.45027 .21213 L
.4584 .20248 L
.48342 .17356 L
.49449 .15827 L
Mistroke
.51658 .13466 L
.53486 .11406 L
.54973 .09876 L
.58289 .07952 L
.61605 .07093 L
.62136 .06985 L
.6492 .06696 L
Mfstroke
.6 g
.58289 .10666 m
.61605 .09491 L
.6492 .08908 L
.68236 .08653 L
.71552 .08621 L
.74867 .08778 L
.78183 .09143 L
.81499 .09807 L
.84814 .11033 L
.85495 .11406 L
.8813 .13593 L
.89494 .15827 L
.90859 .20248 L
.91353 .24668 L
.91253 .29089 L
.90397 .3351 L
.88357 .37931 L
.8813 .38418 L
.85607 .42352 L
.84814 .43604 L
.82762 .46773 L
.81499 .48493 L
.79556 .51194 L
.78183 .53269 L
.76373 .55615 L
.74867 .57775 L
.73276 .60035 L
.71552 .62149 L
.69855 .64456 L
.68236 .667 L
.66512 .68877 L
.6492 .71163 L
.63336 .73298 L
.61605 .75355 L
.59875 .77719 L
.58289 .79801 L
.56463 .8214 L
.54973 .84313 L
.53255 .86561 L
.51658 .88554 L
.49989 .90981 L
.48342 .93183 L
.46948 .95402 L
.45352 .99823 L
.45027 1.02408 L
.44746 1.04244 L
.44056 1.08665 L
.43125 1.13086 L
.41711 1.16931 L
.41419 1.17507 L
.38395 1.20934 L
.36688 1.21927 L
.3508 1.22529 L
.31764 1.23293 L
.28448 1.23626 L
.25133 1.23659 L
.21817 1.23412 L
.18501 1.22802 L
.15908 1.21927 L
.15186 1.21567 L
.1187 1.18769 L
.11079 1.17507 L
.09503 1.13086 L
.08871 1.08665 L
.08797 1.04244 L
.09339 .99823 L
.10874 .95402 L
.11785 .90981 L
.1187 .90229 L
.12298 .86561 L
.1311 .8214 L
.15083 .77719 L
.15186 .77499 L
.17489 .73298 L
.18501 .71842 L
.20152 .68877 L
.21478 .64456 L
.21817 .63039 L
.23062 .60035 L
.25133 .56616 L
.25778 .55615 L
.28448 .516 L
.28695 .51194 L
.30633 .46773 L
.31764 .42559 L
.31854 .42352 L
.34603 .37931 L
.3508 .37092 L
.3766 .3351 L
.38395 .32585 L
.40875 .29089 L
.41711 .28046 L
.44376 .24668 L
.45027 .23757 L
.48013 .20248 L
.48342 .19888 L
.51658 .1594 L
.51765 .15827 L
.54973 .12847 L
.56899 .11406 L
F
0 g
.58289 .10666 m
.61605 .09491 L
.6492 .08908 L
.68236 .08653 L
.71552 .08621 L
.74867 .08778 L
.78183 .09143 L
.81499 .09807 L
.84814 .11033 L
.85495 .11406 L
.8813 .13593 L
.89494 .15827 L
.90859 .20248 L
.91353 .24668 L
.91253 .29089 L
.90397 .3351 L
.88357 .37931 L
.8813 .38418 L
.85607 .42352 L
.84814 .43604 L
.82762 .46773 L
.81499 .48493 L
.79556 .51194 L
.78183 .53269 L
.76373 .55615 L
.74867 .57775 L
.73276 .60035 L
.71552 .62149 L
.69855 .64456 L
.68236 .667 L
.66512 .68877 L
.6492 .71163 L
.63336 .73298 L
.61605 .75355 L
.59875 .77719 L
.58289 .79801 L
.56463 .8214 L
.54973 .84313 L
.53255 .86561 L
.51658 .88554 L
.49989 .90981 L
.48342 .93183 L
.46948 .95402 L
.45352 .99823 L
.45027 1.02408 L
.44746 1.04244 L
.44056 1.08665 L
.43125 1.13086 L
.41711 1.16931 L
.41419 1.17507 L
Mistroke
.38395 1.20934 L
.36688 1.21927 L
.3508 1.22529 L
.31764 1.23293 L
.28448 1.23626 L
.25133 1.23659 L
.21817 1.23412 L
.18501 1.22802 L
.15908 1.21927 L
.15186 1.21567 L
.1187 1.18769 L
.11079 1.17507 L
.09503 1.13086 L
.08871 1.08665 L
.08797 1.04244 L
.09339 .99823 L
.10874 .95402 L
.11785 .90981 L
.1187 .90229 L
.12298 .86561 L
.1311 .8214 L
.15083 .77719 L
.15186 .77499 L
.17489 .73298 L
.18501 .71842 L
.20152 .68877 L
.21478 .64456 L
.21817 .63039 L
.23062 .60035 L
.25133 .56616 L
.25778 .55615 L
.28448 .516 L
.28695 .51194 L
.30633 .46773 L
.31764 .42559 L
.31854 .42352 L
.34603 .37931 L
.3508 .37092 L
.3766 .3351 L
.38395 .32585 L
.40875 .29089 L
.41711 .28046 L
.44376 .24668 L
.45027 .23757 L
.48013 .20248 L
.48342 .19888 L
.51658 .1594 L
.51765 .15827 L
.54973 .12847 L
.56899 .11406 L
Mistroke
.58289 .10666 L
Mfstroke
.5 g
.6492 .11376 m
.68236 .11051 L
.71552 .11042 L
.74867 .1132 L
.7558 .11406 L
.78183 .11921 L
.81499 .13035 L
.84814 .15297 L
.85305 .15827 L
.8774 .20248 L
.8813 .21649 L
.88612 .24668 L
.88609 .29089 L
.8813 .32123 L
.87755 .3351 L
.85932 .37931 L
.84814 .40074 L
.83397 .42352 L
.81499 .45518 L
.80645 .46773 L
.78183 .50426 L
.77652 .51194 L
.74867 .54999 L
.74425 .55615 L
.71552 .59682 L
.71286 .60035 L
.68236 .6417 L
.68024 .64456 L
.6492 .68467 L
.64616 .68877 L
.61605 .72887 L
.61284 .73298 L
.58289 .77276 L
.5795 .77719 L
.54973 .81545 L
.54532 .8214 L
.51658 .85896 L
.51159 .86561 L
.48342 .90605 L
.48087 .90981 L
.45314 .95402 L
.45027 .9585 L
.43632 .99823 L
.42592 1.04244 L
.41711 1.07867 L
.41504 1.08665 L
.39968 1.13086 L
.38395 1.15703 L
.36741 1.17507 L
.3508 1.18622 L
.31764 1.19937 L
.28448 1.20488 L
.25133 1.20534 L
.21817 1.20105 L
.18501 1.19017 L
.16098 1.17507 L
.15186 1.16646 L
.12991 1.13086 L
.1187 1.08917 L
.1183 1.08665 L
.11524 1.04244 L
.1187 .99954 L
.11891 .99823 L
.129 .95402 L
.13782 .90981 L
.14453 .86561 L
.15186 .83128 L
.15459 .8214 L
.1726 .77719 L
.18501 .75109 L
.19492 .73298 L
.21722 .68877 L
.21817 .68591 L
.23306 .64456 L
.25133 .60127 L
.25176 .60035 L
.27659 .55615 L
.28448 .54349 L
.30308 .51194 L
.31764 .47802 L
.32172 .46773 L
.33924 .42352 L
.3508 .40317 L
.36574 .37931 L
.38395 .35304 L
.39713 .3351 L
.41711 .30704 L
.42963 .29089 L
.45027 .26528 L
.46522 .24668 L
.48342 .22595 L
.50419 .20248 L
.51658 .18885 L
.54972 .15827 L
.54973 .15825 L
.58289 .13538 L
.61605 .12124 L
.64688 .11406 L
F
0 g
.6492 .11376 m
.68236 .11051 L
.71552 .11042 L
.74867 .1132 L
.7558 .11406 L
.78183 .11921 L
.81499 .13035 L
.84814 .15297 L
.85305 .15827 L
.8774 .20248 L
.8813 .21649 L
.88612 .24668 L
.88609 .29089 L
.8813 .32123 L
.87755 .3351 L
.85932 .37931 L
.84814 .40074 L
.83397 .42352 L
.81499 .45518 L
.80645 .46773 L
.78183 .50426 L
.77652 .51194 L
.74867 .54999 L
.74425 .55615 L
.71552 .59682 L
.71286 .60035 L
.68236 .6417 L
.68024 .64456 L
.6492 .68467 L
.64616 .68877 L
.61605 .72887 L
.61284 .73298 L
.58289 .77276 L
.5795 .77719 L
.54973 .81545 L
.54532 .8214 L
.51658 .85896 L
.51159 .86561 L
.48342 .90605 L
.48087 .90981 L
.45314 .95402 L
.45027 .9585 L
.43632 .99823 L
.42592 1.04244 L
.41711 1.07867 L
.41504 1.08665 L
.39968 1.13086 L
.38395 1.15703 L
.36741 1.17507 L
.3508 1.18622 L
Mistroke
.31764 1.19937 L
.28448 1.20488 L
.25133 1.20534 L
.21817 1.20105 L
.18501 1.19017 L
.16098 1.17507 L
.15186 1.16646 L
.12991 1.13086 L
.1187 1.08917 L
.1183 1.08665 L
.11524 1.04244 L
.1187 .99954 L
.11891 .99823 L
.129 .95402 L
.13782 .90981 L
.14453 .86561 L
.15186 .83128 L
.15459 .8214 L
.1726 .77719 L
.18501 .75109 L
.19492 .73298 L
.21722 .68877 L
.21817 .68591 L
.23306 .64456 L
.25133 .60127 L
.25176 .60035 L
.27659 .55615 L
.28448 .54349 L
.30308 .51194 L
.31764 .47802 L
.32172 .46773 L
.33924 .42352 L
.3508 .40317 L
.36574 .37931 L
.38395 .35304 L
.39713 .3351 L
.41711 .30704 L
.42963 .29089 L
.45027 .26528 L
.46522 .24668 L
.48342 .22595 L
.50419 .20248 L
.51658 .18885 L
.54972 .15827 L
.54973 .15825 L
.58289 .13538 L
.61605 .12124 L
.64688 .11406 L
.6492 .11376 L
Mfstroke
.4 g
.61605 .15036 m
.6492 .14145 L
.68236 .1377 L
.71552 .13815 L
.74867 .14281 L
.78183 .15306 L
.79304 .15827 L
.81499 .17215 L
.83918 .20248 L
.84814 .22261 L
.85439 .24668 L
.85677 .29089 L
.84929 .3351 L
.84814 .34064 L
.83258 .37931 L
.81499 .41477 L
.80955 .42352 L
.78243 .46773 L
.78183 .46867 L
.75332 .51194 L
.74867 .51855 L
.72231 .55615 L
.71552 .56593 L
.69026 .60035 L
.68236 .61117 L
.65755 .64456 L
.6492 .65531 L
.62397 .68877 L
.61605 .69924 L
.58985 .73298 L
.58289 .74215 L
.55574 .77719 L
.54973 .78478 L
.52176 .8214 L
.51658 .82807 L
.48829 .86561 L
.48342 .87249 L
.45785 .90981 L
.45027 .92092 L
.43206 .95402 L
.41711 .98714 L
.41338 .99823 L
.39959 1.04244 L
.38395 1.08398 L
.38287 1.08665 L
.35488 1.13086 L
.3508 1.13481 L
.31764 1.15682 L
.28448 1.16566 L
.25133 1.16609 L
.21817 1.15839 L
.18501 1.13756 L
.17851 1.13086 L
.15486 1.08665 L
.15186 1.07503 L
.14706 1.04244 L
.14772 .99823 L
.15186 .96946 L
.15437 .95402 L
.16166 .90981 L
.16894 .86561 L
.17998 .8214 L
.18501 .8059 L
.19678 .77719 L
.21746 .73298 L
.21817 .73153 L
.23759 .68877 L
.25133 .65345 L
.2548 .64456 L
.27412 .60035 L
.28448 .57997 L
.29755 .55615 L
.31764 .51927 L
.32126 .51194 L
.34171 .46773 L
.3508 .44684 L
.36185 .42352 L
.38395 .38636 L
.38861 .37931 L
.41711 .33908 L
.42004 .3351 L
.45027 .29613 L
.45449 .29089 L
.48342 .25612 L
.49177 .24668 L
.51658 .22038 L
.53489 .20248 L
.54973 .18972 L
.58289 .16609 L
.59651 .15827 L
F
0 g
.61605 .15036 m
.6492 .14145 L
.68236 .1377 L
.71552 .13815 L
.74867 .14281 L
.78183 .15306 L
.79304 .15827 L
.81499 .17215 L
.83918 .20248 L
.84814 .22261 L
.85439 .24668 L
.85677 .29089 L
.84929 .3351 L
.84814 .34064 L
.83258 .37931 L
.81499 .41477 L
.80955 .42352 L
.78243 .46773 L
.78183 .46867 L
.75332 .51194 L
.74867 .51855 L
.72231 .55615 L
.71552 .56593 L
.69026 .60035 L
.68236 .61117 L
.65755 .64456 L
.6492 .65531 L
.62397 .68877 L
.61605 .69924 L
.58985 .73298 L
.58289 .74215 L
.55574 .77719 L
.54973 .78478 L
.52176 .8214 L
.51658 .82807 L
.48829 .86561 L
.48342 .87249 L
.45785 .90981 L
.45027 .92092 L
.43206 .95402 L
.41711 .98714 L
.41338 .99823 L
.39959 1.04244 L
.38395 1.08398 L
.38287 1.08665 L
.35488 1.13086 L
.3508 1.13481 L
.31764 1.15682 L
.28448 1.16566 L
.25133 1.16609 L
Mistroke
.21817 1.15839 L
.18501 1.13756 L
.17851 1.13086 L
.15486 1.08665 L
.15186 1.07503 L
.14706 1.04244 L
.14772 .99823 L
.15186 .96946 L
.15437 .95402 L
.16166 .90981 L
.16894 .86561 L
.17998 .8214 L
.18501 .8059 L
.19678 .77719 L
.21746 .73298 L
.21817 .73153 L
.23759 .68877 L
.25133 .65345 L
.2548 .64456 L
.27412 .60035 L
.28448 .57997 L
.29755 .55615 L
.31764 .51927 L
.32126 .51194 L
.34171 .46773 L
.3508 .44684 L
.36185 .42352 L
.38395 .38636 L
.38861 .37931 L
.41711 .33908 L
.42004 .3351 L
.45027 .29613 L
.45449 .29089 L
.48342 .25612 L
.49177 .24668 L
.51658 .22038 L
.53489 .20248 L
.54973 .18972 L
.58289 .16609 L
.59651 .15827 L
.61605 .15036 L
Mfstroke
.3 g
.58289 .19949 m
.61605 .18268 L
.6492 .173 L
.68236 .16935 L
.71552 .17117 L
.74867 .17923 L
.78183 .19766 L
.7874 .20248 L
.81499 .24284 L
.81597 .24668 L
.82319 .29089 L
.8181 .3351 L
.81499 .34679 L
.80338 .37931 L
.78194 .42352 L
.78183 .42373 L
.7562 .46773 L
.74867 .48 L
.72766 .51194 L
.71552 .52996 L
.6972 .55615 L
.68236 .57674 L
.66509 .60035 L
.6492 .62186 L
.63205 .64456 L
.61605 .66564 L
.59823 .68877 L
.58289 .70828 L
.56358 .73298 L
.54973 .7505 L
.52871 .77719 L
.51658 .79265 L
.49417 .8214 L
.48342 .8352 L
.46088 .86561 L
.45027 .88028 L
.43064 .90981 L
.41711 .93107 L
.405 .95402 L
.38395 .99675 L
.38338 .99823 L
.36384 1.04244 L
.3508 1.06375 L
.33546 1.08665 L
.31764 1.09932 L
.28448 1.11328 L
.25133 1.1127 L
.21817 1.09557 L
.20879 1.08665 L
.18806 1.04244 L
.18501 1.02424 L
.18306 .99823 L
.18501 .95866 L
.18542 .95402 L
.19053 .90981 L
.19749 .86561 L
.2085 .8214 L
.21817 .79212 L
.22434 .77719 L
.24288 .73298 L
.25133 .71332 L
.26157 .68877 L
.27917 .64456 L
.28448 .63195 L
.29859 .60035 L
.31764 .56278 L
.32112 .55615 L
.34343 .51194 L
.3508 .49676 L
.36454 .46773 L
.38395 .42866 L
.38674 .42352 L
.41464 .37931 L
.41711 .37574 L
.44687 .3351 L
.45027 .33075 L
.48305 .29089 L
.48342 .29046 L
.51658 .25442 L
.52421 .24668 L
.54973 .22361 L
.57802 .20248 L
F
0 g
.58289 .19949 m
.61605 .18268 L
.6492 .173 L
.68236 .16935 L
.71552 .17117 L
.74867 .17923 L
.78183 .19766 L
.7874 .20248 L
.81499 .24284 L
.81597 .24668 L
.82319 .29089 L
.8181 .3351 L
.81499 .34679 L
.80338 .37931 L
.78194 .42352 L
.78183 .42373 L
.7562 .46773 L
.74867 .48 L
.72766 .51194 L
.71552 .52996 L
.6972 .55615 L
.68236 .57674 L
.66509 .60035 L
.6492 .62186 L
.63205 .64456 L
.61605 .66564 L
.59823 .68877 L
.58289 .70828 L
.56358 .73298 L
.54973 .7505 L
.52871 .77719 L
.51658 .79265 L
.49417 .8214 L
.48342 .8352 L
.46088 .86561 L
.45027 .88028 L
.43064 .90981 L
.41711 .93107 L
.405 .95402 L
.38395 .99675 L
.38338 .99823 L
.36384 1.04244 L
.3508 1.06375 L
.33546 1.08665 L
.31764 1.09932 L
.28448 1.11328 L
.25133 1.1127 L
.21817 1.09557 L
.20879 1.08665 L
.18806 1.04244 L
Mistroke
.18501 1.02424 L
.18306 .99823 L
.18501 .95866 L
.18542 .95402 L
.19053 .90981 L
.19749 .86561 L
.2085 .8214 L
.21817 .79212 L
.22434 .77719 L
.24288 .73298 L
.25133 .71332 L
.26157 .68877 L
.27917 .64456 L
.28448 .63195 L
.29859 .60035 L
.31764 .56278 L
.32112 .55615 L
.34343 .51194 L
.3508 .49676 L
.36454 .46773 L
.38395 .42866 L
.38674 .42352 L
.41464 .37931 L
.41711 .37574 L
.44687 .3351 L
.45027 .33075 L
.48305 .29089 L
.48342 .29046 L
.51658 .25442 L
.52421 .24668 L
.54973 .22361 L
.57802 .20248 L
.58289 .19949 L
Mfstroke
.2 g
.58289 .23705 m
.61605 .2198 L
.6492 .21015 L
.68236 .20773 L
.71552 .2128 L
.74867 .22917 L
.76492 .24668 L
.78183 .2872 L
.78246 .29089 L
.78202 .3351 L
.78183 .3363 L
.77031 .37931 L
.75087 .42352 L
.74867 .4281 L
.72648 .46773 L
.71552 .48604 L
.69863 .51194 L
.68236 .53624 L
.66834 .55615 L
.6492 .58281 L
.63623 .60035 L
.61605 .62711 L
.60266 .64456 L
.58289 .66984 L
.56794 .68877 L
.54973 .7114 L
.53235 .73298 L
.51658 .75219 L
.49629 .77719 L
.48342 .79278 L
.4605 .8214 L
.45027 .83405 L
.42625 .86561 L
.41711 .8775 L
.39474 .90981 L
.38395 .92472 L
.36646 .95402 L
.3508 .97503 L
.33381 .99823 L
.31764 1.01577 L
.28448 1.03304 L
.25133 1.02164 L
.23292 .99823 L
.22706 .95402 L
.22835 .90981 L
.23343 .86561 L
.24307 .8214 L
.25133 .79149 L
.2568 .77719 L
.2731 .73298 L
.28448 .70338 L
.29019 .68877 L
.30747 .64456 L
.31764 .62029 L
.32647 .60035 L
.34786 .55615 L
.3508 .55013 L
.36933 .51194 L
.38395 .4821 L
.39114 .46773 L
.41517 .42352 L
.41711 .42032 L
.44439 .37931 L
.45027 .37121 L
.47848 .3351 L
.48342 .32921 L
.51658 .29258 L
.51818 .29089 L
.54973 .26145 L
.56816 .24668 L
F
0 g
.58289 .23705 m
.61605 .2198 L
.6492 .21015 L
.68236 .20773 L
.71552 .2128 L
.74867 .22917 L
.76492 .24668 L
.78183 .2872 L
.78246 .29089 L
.78202 .3351 L
.78183 .3363 L
.77031 .37931 L
.75087 .42352 L
.74867 .4281 L
.72648 .46773 L
.71552 .48604 L
.69863 .51194 L
.68236 .53624 L
.66834 .55615 L
.6492 .58281 L
.63623 .60035 L
.61605 .62711 L
.60266 .64456 L
.58289 .66984 L
.56794 .68877 L
.54973 .7114 L
.53235 .73298 L
.51658 .75219 L
.49629 .77719 L
.48342 .79278 L
.4605 .8214 L
.45027 .83405 L
.42625 .86561 L
.41711 .8775 L
.39474 .90981 L
.38395 .92472 L
.36646 .95402 L
.3508 .97503 L
.33381 .99823 L
.31764 1.01577 L
.28448 1.03304 L
.25133 1.02164 L
.23292 .99823 L
.22706 .95402 L
.22835 .90981 L
.23343 .86561 L
.24307 .8214 L
.25133 .79149 L
.2568 .77719 L
.2731 .73298 L
Mistroke
.28448 .70338 L
.29019 .68877 L
.30747 .64456 L
.31764 .62029 L
.32647 .60035 L
.34786 .55615 L
.3508 .55013 L
.36933 .51194 L
.38395 .4821 L
.39114 .46773 L
.41517 .42352 L
.41711 .42032 L
.44439 .37931 L
.45027 .37121 L
.47848 .3351 L
.48342 .32921 L
.51658 .29258 L
.51818 .29089 L
.54973 .26145 L
.56816 .24668 L
.58289 .23705 L
Mfstroke
.1 g
.58289 .28186 m
.61605 .26498 L
.6492 .25688 L
.68236 .25835 L
.71552 .2755 L
.72571 .29089 L
.73679 .3351 L
.73017 .37931 L
.71552 .41929 L
.71369 .42352 L
.69102 .46773 L
.68236 .48312 L
.66401 .51194 L
.6492 .53435 L
.63379 .55615 L
.61605 .58054 L
.60108 .60035 L
.58289 .62368 L
.5663 .64456 L
.54973 .66461 L
.52965 .68877 L
.51658 .70379 L
.49127 .73298 L
.48342 .74156 L
.45127 .77719 L
.45027 .77824 L
.41711 .81423 L
.41015 .8214 L
.38395 .84874 L
.36586 .86561 L
.3508 .87837 L
.31764 .89404 L
.2959 .86561 L
.28936 .8214 L
.30047 .77719 L
.31326 .73298 L
.31764 .71728 L
.3269 .68877 L
.34278 .64456 L
.3508 .62341 L
.36032 .60035 L
.38037 .55615 L
.38395 .54837 L
.4011 .51194 L
.41711 .4802 L
.42369 .46773 L
.4497 .42352 L
.45027 .42265 L
.48124 .37931 L
.48342 .37654 L
.51658 .33808 L
.51929 .3351 L
.54973 .30622 L
.56856 .29089 L
F
0 g
.58289 .28186 m
.61605 .26498 L
.6492 .25688 L
.68236 .25835 L
.71552 .2755 L
.72571 .29089 L
.73679 .3351 L
.73017 .37931 L
.71552 .41929 L
.71369 .42352 L
.69102 .46773 L
.68236 .48312 L
.66401 .51194 L
.6492 .53435 L
.63379 .55615 L
.61605 .58054 L
.60108 .60035 L
.58289 .62368 L
.5663 .64456 L
.54973 .66461 L
.52965 .68877 L
.51658 .70379 L
.49127 .73298 L
.48342 .74156 L
.45127 .77719 L
.45027 .77824 L
.41711 .81423 L
.41015 .8214 L
.38395 .84874 L
.36586 .86561 L
.3508 .87837 L
.31764 .89404 L
.2959 .86561 L
.28936 .8214 L
.30047 .77719 L
.31326 .73298 L
.31764 .71728 L
.3269 .68877 L
.34278 .64456 L
.3508 .62341 L
.36032 .60035 L
.38037 .55615 L
.38395 .54837 L
.4011 .51194 L
.41711 .4802 L
.42369 .46773 L
.4497 .42352 L
.45027 .42265 L
.48124 .37931 L
.48342 .37654 L
Mistroke
.51658 .33808 L
.51929 .3351 L
.54973 .30622 L
.56856 .29089 L
.58289 .28186 L
Mfstroke
.61605 .33015 m
.6492 .33385 L
.65102 .3351 L
.67346 .37931 L
.66327 .42352 L
.6492 .45564 L
.64379 .46773 L
.61702 .51194 L
.61605 .51348 L
.58603 .55615 L
.58289 .56028 L
.55042 .60035 L
.54973 .60113 L
.51658 .63856 L
.51002 .64456 L
.48342 .67138 L
.46142 .68877 L
.45027 .69756 L
.41711 .71259 L
.39397 .68877 L
.3927 .64456 L
.40888 .60035 L
.41711 .57891 L
.42469 .55615 L
.44533 .51194 L
.45027 .50165 L
.46825 .46773 L
.48342 .44322 L
.49699 .42352 L
.51658 .39941 L
.53491 .37931 L
.54973 .3665 L
.58289 .34195 L
.60023 .3351 L
F
.61605 .33015 m
.6492 .33385 L
.65102 .3351 L
.67346 .37931 L
.66327 .42352 L
.6492 .45564 L
.64379 .46773 L
.61702 .51194 L
.61605 .51348 L
.58603 .55615 L
.58289 .56028 L
.55042 .60035 L
.54973 .60113 L
.51658 .63856 L
.51002 .64456 L
.48342 .67138 L
.46142 .68877 L
.45027 .69756 L
.41711 .71259 L
.39397 .68877 L
.3927 .64456 L
.40888 .60035 L
.41711 .57891 L
.42469 .55615 L
.44533 .51194 L
.45027 .50165 L
.46825 .46773 L
.48342 .44322 L
.49699 .42352 L
.51658 .39941 L
.53491 .37931 L
.54973 .3665 L
.58289 .34195 L
.60023 .3351 L
.61605 .33015 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{315.062, 420.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006900023B000`400?l00000o`00003ooooooon:
ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00eoooool2
o`0000;ooooo0_l0002/ooooo`00eoooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJcooooo003H
ooooo`04omgMgOl0003o410@olc<c:gooooo003Hooooo`04onk^k_lQ8B7o410@onk^kZgooooo003H
ooooo`04ob4Q8OmgMgOoMgMgoc8b<Zgooooo003Gooooo`;o00000_ooool2o`000:cooooo003ooooo
oh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooooh[ooooo003ooooo
oh[ooooo003ooooooh[ooooo000aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00005oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08?ooool4o`00
0003oa0@4?oooooooooo01gooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`00
01Sooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
01Cooooo000aooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@05oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A401[ooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00?o0000ooooooooool0
5Oooool0037ooooo00Go410@oooooooooooooooooa0@400Pooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP0Hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`00
01Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000005ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000Rooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP0Kooooo`03
o`000?oooooooooo00[ooooo1Ol0000Fooooo`00<Oooool01Ol0003ooooooooooooooooo0000023o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001Sooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B405oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Rooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool03?ooool00onHV9So8B4Qonk^kP0Jooooo`03o`000?oooooooooo00[ooooo00CoA4A4
omgMgOoooooo00005oooool0037ooooo00Go0000ooooooooooooooooo`00000Pooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Fooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool0000Hooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<01Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`08_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00go
oooo00?oMgMgofIVI_ooool06Oooool00ol0003oooooooooo`0:ooooo`04omgMgOmEEEGoooooo`00
01Oooooo000aooooo`05oa0@4?ooooooooooooooool@41008?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool05Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000006?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
6Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Roooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000005oooool0037ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000008_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400Jooooo`03o`000?oo
oooooooo00_ooooo00?ok^k^odA4A?l000005oooool0037ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Pooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<01Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT08?ooool00omEEEGoIVIVo`00000Qooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Hooooo`03oeEEEOmVIVKo0000
00kooooo00?oMgMgo`000?ooool05_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_oo
ool00?ooooooR_ooool00?ooooooR_ooool002koooooool0001Jo`0000;ooooo000^ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0?ooooooE_ooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool0oooooomFooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7o
oooo000Sooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooeKo
oooo0Ol00001ooooo`7ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool3o`000?oo
ooooE?ooool3o`0000;ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`30ooooog?o00008_ooool1o`00007ooooo0Oooool002?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0;[ooooo1_l0001conKViP_o00005oooool1o`00007o
oooo0Oooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;[o
oooo00?o0000onKVi_oVi^H0POoVi^H6o`00017ooooo0Ol00001ooooo`7ooooo000Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2iooooo`03o`000?oVi^Koi^KV08Oo
i^KV00?o0000ooooooooool03oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
^?ooool00ol0003oi^KVonKViP29onKViP03o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo0;Oooooo00?o0000onKVi_oVi^H0RooVi^H00ol0003ooooooooo
o`0=ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2gooooo`03o`000?oVi^Ko
i^KV01goi^KV>_l0000eonKViP03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo0;Kooooo00?o0000onKVi_oVi^H04_oVi^H<o`0003[oc<c<2ol0000ZonKV
iP03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;Go
oooo00?o0000onKVi_oVi^H03?oVi^H7o`00057oc<c<2Ol0000RonKViP03o`000?oooooooooo00_o
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;Cooooo00?o0000onKVi_oVi^H0
2ooVi^H2o`00067oc<c<1Ol0000NonKViP03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo0;?ooooo00?o0000onKVi_oVi^H02OoVi^H3o`0006Soc<c<1Ol0
000JonKViP03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo0;?ooooo00?o0000onKVi_oVi^H01ooVi^H2o`00073oc<c<1?l0000FonKViP03o`000?oooooo
oooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0;;ooooo00?o0000onKV
i_oVi^H01_oVi^H2o`0002Goc<c<6?l0000iolc<c0?o00005?oVi^H00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2aooooo`03o`000?oVi^Koi^KV00Ko
i^KV00?o0000olc<c?o<c<`06oo<c<`:o`0001So/k>c5Ol0000Wolc<c0;o00004ooVi^H00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2`ooooo`03o`00
0?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`04oo<c<`9o`0003Oo/k>c1Ol0000Tolc<c003o`00
0?oVi^Koi^KV017oi^KV00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0[_ooool2o`0000Woi^KV00?o0000olc<c?o<c<`03oo<c<`4o`0004Go/k>c1Ol0
000Oolc<c003o`000?oVi^Koi^KV017oi^KV00?o0000ooooooooool01_ooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0[Oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<co
c<c<00coc<c<1?l0001>ok>c/`Ko00006_o<c<`00ol0003oi^KVonKViP0@onKViP03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0:cooooo00?o0000onKV
i_oVi^H02?oVi^H00ol0003oc<c<olc<c00:olc<c0?o0000F?nc/k<4o`0001Ooc<c<00?o0000onKV
i_oVi^H03ooVi^H00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`2[ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`02_o<c<`00ol0003o
/k>cok>c/`1Mok>c/`?o00005Oo<c<`00ol0003oi^KVonKViP0>onKViP03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0:[ooooo00?o0000onKVi_oVi^H0
2OoVi^H00ol0003oc<c<olc<c008olc<c0;o0000Honc/k<3o`0001;oc<c<00?o0000onKVi_oVi^H0
3_oVi^H00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`2Yooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01oo<c<`2o`00027o/k>c8ol0
000Tok>c/`?o00004?o<c<`00ol0003oi^KVonKViP0=onKViP03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo000^ooooo`;o0000ZOooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<co
c<c<00Ooc<c<00?o0000ok>c/onc/k<06?nc/k<9o`0002?oVIVI2?l0000Ook>c/`;o00003oo<c<`0
0ol0003oi^KVonKViP0<onKViP03o`000?oooooooooo00Cooooo0ol00002ooooo`00;_ooool00ol0
003oooooooooo`2Wooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01_o<c<`2o`00
01Ko/k>c1Ol0000doiVIV@Co00007Onc/k<00ol0003oc<c<olc<c00=olc<c003o`000?oVi^Koi^KV
00coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool0Y_ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<04_nc/k<4o`0003goVIVI0ol0000Kok>c/`03o`000?o<c<coc<c<00coc<c<00?o0000onKVi_oV
i^H03?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`2Uooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`0@ok>c/`?o0000A?nIVIT4o`0001So/k>c00?o0000olc<c?o<c<`03?o<c<`00ol0003oi^KV
onKViP0;onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo0:Cooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00ko/k>c0ol0001;oiVIV@?o00005_nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oV
i^Koi^KV00[oi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0Xoooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<03?nc/k<3o`00057oVIVI0ol0000Dok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000
onKVi_oVi^H02_oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`0:ok>c/`?o0000EonIVIT3o`0001;o/k>c00?o0000olc<c?o<c<`02oo<c<`00ol0
003oi^KVonKViP09onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo0:7ooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Wo/k>c0_l0000NoiVIVASo00009onIVIT2o`00017o/k>c00?o0000olc<c?o<
c<`02oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo0:3ooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00So/k>c0_l0000GoiVIV@Wo00006?moOgl:o`0001ooVIVI
0_l0000@ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Pooooo`03o`000?oV
i^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nI
VIWoVIVI01CoVIVI0ol0000[ogmoO`Go00007?nIVIT00ol0003o/k>cok>c/`0=ok>c/`03o`000?o<
c<coc<c<00_oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`2Oooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`;o00005?nIVIT3o`0003?oOgmo0ol0000J
oiVIV@03o`000?nc/k?o/k>c00go/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP07
onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
09oooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00Ko/k>c00?o0000oiVIVOnIVIT04OnIVIT3o`0003WoOgmo0ol0000HoiVIV@03o`000?nc/k?o/k>c
00go/k>c00?o0000olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo09kooooo00?o0000onKVi_oV
i^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnI
VIT03onIVIT3o`0003ooOgmo0ol0000FoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<c?o<
c<`02Oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo09kooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c0_l0000@oiVIV@;o0000AOmoOgl3o`0001CoVIVI
00?o0000ok>c/onc/k<03?nc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0WOoo
ool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@0>oiVIV@;o0000B_moOgl2o`0001?oVIVI00?o0000ok>c/onc/k<02onc
/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool01Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0WOooool00ol0003oi^KVonKViP08
onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@0<
oiVIV@?o0000C_moOgl00ol0003oVIVIoiVIV@0AoiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000
olc<c?o<c<`02Oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo09cooooo00?o0000onKVi_oVi^H02?oVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02onIVIT2o`00
01ooOgmo2_l0000YogmoO`;o00004_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<
00Soc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`2Kooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl06OmoOgl6o`0000[oIVIV2ol0000PogmoO`03o`000?nIVIWoVIVI00ooVIVI00?o0000ok>c/onc
/k<02_nc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Voooool00ol0003oi^KV
onKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@;o00005omoOgl5o`0001_oIVIV1ol0000JogmoO`;o00004?nIVIT00ol0003o/k>c
ok>c/`0:ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Jooooo`03o`000?oV
i^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nI
VIWoVIVI00WoVIVI0_l0000EogmoO`Co00009omVIVH3o`0001WoOgmo00?o0000oiVIVOnIVIT03_nI
VIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`05
ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl04_moOgl3o`0002koIVIV0ol0000G
ogmoO`;o00003onIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000
onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00SoVIVI0_l0000AogmoO`Co0000=?mVIVH3o`00
01KoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool2o`0009[ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0>ogmoO`?o
0000>omVIVH3o`0001CoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`03ooooo`?o
00000_ooool002kooooo00?o0000ooooooooool0V?ooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?moOgooOgmo00coOgmo0ol00011ofIVIP?o00004_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo09Sooooo00?o
0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o
0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`0;ogmoO`;o0000AomVIVH00ol0003oOgmoogmo
O`0?ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0Uoooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgoo
Ogmo00_oOgmo00?o0000ofIVI_mVIVH0B?mVIVH2o`00013oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`2Foooo
o`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`06ok>c
/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02_moOgl2o`0004goIVIV00?o0000ogmo
OomoOgl03OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo09Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV01coIVIV3Ol0000UofIVIP03o`000?moOgooOgmo00go
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`2Dooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
2_moOgl00ol0003oIVIVofIVIP0FofIVIPOo00003Om<C4`7o`0001ooIVIV00?o0000ogmoOomoOgl0
3OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo09?ooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmo
O`09ogmoO`;o00005_mVIVH3o`0001_oC4a<1?l0000KofIVIP03o`000?moOgooOgmo00goOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`2Booooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0CofIVIP?o00008_m<C4`3o`0001WoIVIV00?o0000ogmoOomoOgl03OmoOgl0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo097ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00004omVIVH3o`0002SoC4a<0ol0000GofIVIP03o`000?moOgooOgmo00coOgmo00?o0000oiVI
VOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`2@ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0AofIVIP;o0000;_m<C4`2o`0001KoIVIV00?o0000ogmoOomoOgl03?moOgl00ol0003o
VIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo08oooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV013oIVIV0_l0000boda<C0;o00005?mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0S_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH03omVIVH2o`0003KoC4a<0_l0000CofIVIP03o`000?moOgooOgmo00coOgmo00?o
0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0>ofIVIP;o0000>_m<C4`2o`0001;oIVIV00?o0000ogmoOomoOgl02omoOgl0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo08cooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00goIVIV0_l0000noda<C0;o00004?mVIVH00ol0003oOgmoogmoO`0<ogmo
O`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool0S?ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;o
c<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH2o`0004;oC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
OgmoogmoO`0<ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0Roooool00ol0003oi^KVonKViP09onKViP05o`00
0?o<c<coc<c<olc<c?l000001onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C013oda<C003o`000?mVIVKoIVIV00ko
IVIV00?o0000ogmoOomoOgl02omoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08[ooooo00?o0000onKVi_oVi^H0
2OoVi^H01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l00017oda<C003o`000?mVIVKoIVIV00ko
IVIV00?o0000ogmoOomoOgl02omoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08[ooooo00?o0000onKVi_oVi^H0
2?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
7Om<C4`:o`00023oC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0ROooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH02_mVIVH2o`0001WoC4a<1ol0000:oc<c<`Go00007?m<C4`00ol0003oIVIVofIV
IP0>ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`28ooooo`03o`000?oVi^Ko
i^KV00Soi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4co
C4a<01KoC4a<0ol0000Foc<c<`Co00006Om<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgoo
Ogmo00_oOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`27ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<0ol0000Moc<c
<`;o00005om<C4`00ol0003oIVIVofIVIP0>ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool2o`0008Oo
oooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00Wo
IVIV0_l0000Doda<C0?o00008_lc<c<2o`0001KoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool00oooool3o`0000;o
oooo000^ooooo`03o`000?oooooooooo08Gooooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`04_m<C4`2o`0002Oo<c<c
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`25ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP08ofIVIP;o00004om<C4`2o`0002[o<c<c0_l0000Doda<C003o`000?mV
IVKoIVIV00koIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oo
oooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo08Cooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`04Om<C4`2o`0002ko<c<c0_l0000Coda<C003o`000?mVIVKoIVIV00goIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo08?ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`04?m<C4`2o`00
03;o<c<c00?o0000oda<C?m<C4`04?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`22ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00ooC4a<0_l0000eoc<c<`03
o`000?m<C4coC4a<013oC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?oVi^Koi^KV00?oi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0POooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00>oda<C0;o0000>?lc<c<00ol0003oC4a<
oda<C00@oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KV
onKViP03onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo087ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`2o`0003_o<c<c00?o0000oda<C?m<C4`03om<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onI
VIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooV
i^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`20
ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<00coC4a<0_l0000noc<c<`03o`000?m<C4coC4a<00ooC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Ooooool00ol0
003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c03oo<c<c00?o0000oda<C?m<C4`03om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0
003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1nooooo`03
o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<00_oC4a<0_l00013oc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0O_ooool00ol0003oi^KV
onKViP08onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00;oda<C003o`000?lc<c?o<c<c04?o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1mooooo`03o`000?oV
i^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<
C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0AOlc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03onKViP03o`000?oo
oooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo07cooooo00?o0000
onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0Koc<c<`Wo00008_lc<c<00ol0003oC4a<oda<C00>
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP03
onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
07cooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00SoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0Hoc<c<`Co00002OlI6AT7o`00
01co<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`1kooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<0_l0000Hoc<c<`?o
00005?lI6AT2o`0001[o<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1kooooo`03o`000?oVi^Koi^KV00Ooi^KV
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<
00?o0000oc<c<olc<c<05Olc<c<3o`0001Wo6ATI0_l0000Hoc<c<`03o`000?m<C4coC4a<00goC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00?oi^KV
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0N_oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c01Co<c<c0_l0000NoaTI6@03o`000?lc
<c?o<c<c01Ko<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`1iooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000
olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
oc<c<olc<c<04olc<c<2o`00027o6ATI0_l0000Foc<c<`03o`000?m<C4coC4a<00goC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0NOooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c01;o<c<c0_l0000UoaTI6@;o00005Olc<c<00ol0
003oC4a<oda<C00<oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo07Sooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Aoc<c<`;o
0000:OlI6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0N?ooool00ol0003oi^KV
onKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C009oda<C003o`000?lc<c?o<c<c013o<c<c0_l0000[oaTI6@03o`000?lc<c?o<c<c01?o<c<c
00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_oo
ool2o`0007Sooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0?oc<c<`;o0000;_lI
6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool00ooo
ool3o`0000;ooooo000^ooooo`03o`000?oooooooooo07Kooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`0
0ol0003o<c<coc<c<`0>oc<c<`;o0000<OlI6AT00ol0003o<c<coc<c<`0Aoc<c<`03o`000?m<C4co
C4a<00coC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Ko
i^KV00Coi^KV00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0M_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01omVIVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI
6OlI6AT0<OlI6AT00ol0003o<c<coc<c<`0Boc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000ofIV
I_mVIVH02OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0MOooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003o
C4a<oda<C009oda<C003o`000?lc<c?o<c<c00go<c<c0_l0000eoaTI6@03o`000?lc<c?o<c<c017o
<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00Oo
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`1eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0eoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`0
2om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`1dooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI
6@0foaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIV
IP09ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1cooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<00WoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0hoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`1booooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c
<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0ioaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<
C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`1aooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<02olc<c<2o`0003co
6ATI00?o0000oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00Wo
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo073ooooo00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`0
2?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI03co6ATI00?o0000oc<c<olc<c<0
4?lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo06oooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c
<`0;oc<c<`03o`000?lI6AWo6ATI03ko6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKV
iP04onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo06oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKo
IVIV00OoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo
6ATI03oo6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06kooooo00?o0000onKV
i_oVi^H01OoVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI043o6ATI00?o0000oc<c
<olc<c<03olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo06gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o
<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04;o6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003o
C4a<oda<C00:oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
i^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo06cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`00
0?lI6AWo6ATI04?o6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C00:oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06_ooooo00?o
0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04Co6ATI00?o
0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00WoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo06[ooooo00?o0000onKVi_oVi^H01ooVi^H0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`0
0ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI04Go6ATI00?o0000oc<c<olc<c<03_lc<c<0
0ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01omoOgl0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo06[ooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`0;oc<c
<`03o`000?lI6AWo6ATI01_o6ATI2_l0000RoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKV
i_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`1Yooooo`03o`000?oVi^Koi^KV00Soi^KV00Go0000olc<c?o<c<coc<c<o`000005ok>c
/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0HoaTI
6ACo00007?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0J?ooool00ol0003o
i^KVonKViP09onKViP04o`000?o<c<coc<c<o`0000Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0
003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI01Ko6ATI5_l0000LoaTI6@03o`000?lc<c?o<c<c
00go<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Wooooo`03o`000?oVi^Koi^KV00Woi^KV00Co0000
olc<c?o<c<co00001_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00co<c<c00?o
0000oaTI6OlI6AT05?lI6ATIo`0001_o6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<
C009oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKV
iP04onKViP03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo000Cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oVi^Koi^KV00Woi^KV00Co0000olc<c?o<c<co00001_nc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C007oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT04olI6ATKo`0001_o6ATI
00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00WoIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo00Kooooo
0Ol00001ooooo`7ooooo000Cooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`?o0000IOooool00ol0003oi^KVonKViP09onKViP05o`000?o<c<coc<c<olc<c?l0
00001_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI
6AT04olI6ATMo`0001[o6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03
o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP04onKViP03
o`000?oooooooooo00Gooooo0ol00002ooooo`004oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Tooooo`03o`000?oVi^Koi^KV00Wo
i^KV00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c
<olc<c<02olc<c<00ol0003o6ATIoaTI6@0CoaTI6Ako00006OlI6AT00ol0003o<c<coc<c<`0=oc<c
<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c007olc<
c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool01oooool1o`00007ooooo0Oooool001?o
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02olc<c<0
0ol0003o6ATIoaTI6@0BoaTI6B7o00006?lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Ko
i^KV00?oi^KV00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool001?ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H_ooool0
0ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT04_lI6ATR
o`0001So6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`02?o<c<`00ol0003oi^KVonKViP03onKViP03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo00?o0000onKVi_oVi^H02OoVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`02?m<C4`0
0ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI017o6ATI9Ol0000GoaTI6@03o`000?lc<c?o
<c<c00co<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00?o0000onKVi_oVi^H00ooVi^H00ol0003oooooooooo`09ooooo`7o00000Oooool1
ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooo
oooo063ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo
6ATI017o6ATI9_l0000GoaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l00005onKViP03o`000?oooooo
oooo00Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000onKV
i_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`01om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI017o6ATI9ol0000GoaTI
6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`09oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Nooooo`03o`000?oVi^Koi^KV00Wo
i^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00So
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0@oaTI6B[o00005_lI6AT00ol0003o
<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool02_ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0GOooool00ol0003oi^KVonKViP0:onKViP03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6AT[o`0001Go6ATI00?o0000oc<c<olc<c<0
3?lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
0oo<c<`2o`0000Soi^KV00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0G?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT04?lI6AT]o`0001Co6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<
C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c00Go/k>c0_l00005olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o
0000ooooooooool02oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Foooool0
0ol0003oi^KVonKViP0;onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6AT^
o`0001Co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKo
IVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooo
oooo00_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05[ooooo00?o0000onKV
i_oVi^H02ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<
C?m<C4`02?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI<?l0000CoaTI
6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0<oooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Jooooo`03o`000?oVi^Koi^KV00_o
i^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00So
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0@oaTI6C3o00004olI6AT00ol0003o
<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c004olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool03?ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0F_ooool00ol0003oi^KVonKViP0:onKViP03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI6ATao`0001;o6ATI00?o0000oc<c<olc<c<0
2olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo05[ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c
<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI<_l0000BoaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o
0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0?oaTI6C;o00004olI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Ko
i^KV00Ooi^KV00?o0000ooooooooool03oooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0FOooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI
6OlI6AT03olI6ATco`0001;o6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Wo
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00oo
6ATI=?l0000BoaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003o
IVIVofIVIP06ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0@ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Iooooo`03o`00
0?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CGo0000
4_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
4Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0FOooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATeo`00017o6ATI00?o
0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo017ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Sooooo00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`0
0ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00oo6ATI=Ol0000BoaTI6@03o`000?lc<c?o
<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0Booooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`1Hooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c
<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CKo00004_lI6AT00ol0003o<c<coc<c<`0:oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c003olc<
c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool04oooool1o`00007ooooo0Oooool002ko
oooo0_l0001Iooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o
/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o
6ATIoaTI6@0>oaTI6COo00004OlI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00So
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00So
i^KV00?o0000ooooooooool04Oooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo05Sooooo
00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI
>?l0000AoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIV
ofIVIP07ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0Dooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Hooooo`03o`000?oV
i^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6CSo00004OlI
6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool05Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKViP06
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007
oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATho`00017o6ATI00?o0000
oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000
ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo01Gooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI>Ol0000AoaTI6@03o`000?lc<c?o<c<c
00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0Fooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc
<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6C[o00004?lI6AT00ol0003o<c<coc<c<`0:oc<c<`03
o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c0;o
00002OoVi^H00ol0003oooooooooo`0Gooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATI
oaTI6@0=oaTI6C[o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<o`000002o`0000_oi^KV00?o0000ooooooooool0
5oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKV
iP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03OlI6ATjo`00013o6ATI00?o
0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?l000003OoVi^H00ol0003oooooooooo`0Hooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01?moOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0=oaTI6C_o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oo
oooooooo01Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04
ok>c/`04o`000?o<c<coc<c<o`0000goi^KV00?o0000ooooooooool06Oooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool0Eoooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<0
0ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Co/k>c00Co0000olc<c?o<c<co00003?oV
i^H00ol0003oooooooooo`0Jooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1G
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0;
oaTI6Cco00004?lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<01?nc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oooooooooo01[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Oooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c003olc<c005o`000?nc/k?o/k>cok>c/ol000001_nIVIT00ol0003oOgmoogmo
O`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c
<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o
0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`05o`000?o<c<coc<c<olc<c?l00000
2ooVi^H2o`0001gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo05Kooooo00?o
0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o
0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0
000?oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIV
IP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c
/`05ok>c/`04o`000?o<c<coc<c<o`0000_oi^KV00?o0000ooooooooool07Oooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00Go0000olc<c?o<c<coc<c<
o`00000:onKViP03o`000?oooooooooo01kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo05Kooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c005o`000?nc
/k?o/k>cok>c/ol000001_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0Oooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Fooooo`03o`000?oV
i^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`01Ol0003o/k>cok>c/onc/k?o000000GoVIVI
00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<
00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0;oaTI6Cgo00004?lI6AT00ol0003o<c<c
oc<c<`09oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool08?ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000005oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03?lI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<
oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP06onKViP03o`000?oooooooooo027ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo05Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`0Rooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1F
ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000GoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6Cgo00004?lI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool08ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0E_ooool00ol0003oi^KVonKViP04
onKViP03o`000?o<c<coc<c<00;oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP05onKViP03o`000?oooooooooo02Cooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo05Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002
olc<c005o`000?nc/k?o/k>cok>c/ol000001?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoV
i^H00ol0003oooooooooo`0Tooooo`7o00000Oooool1ooooo`00;_ooool2o`0005Kooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c005o`000?nc/k?o/k>cok>c/ol000001?nI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0000@oaTI6@03o`000?lc
<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`0Sooooo`?o00000_oo
ool002kooooo00?o0000ooooooooool0E?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00So<c<c00?o
0000oaTI6OlI6AT03OlI6ATlo`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP05onKViP03o`000?oooooooooo02Kooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo05Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?lI6AWo
6ATI00go6ATI?Ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01_m<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`0Vooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Coooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o
000000CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00004?lI6AT0
0ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool09oooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0Doooool00ol0003oi^KVonKViP04onKV
iP03o`000?o<c<coc<c<00?oc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Oo<c<c00?o0000oaTI6OlI6AT03OlI6ATmo`00013o6ATI00?o0000oc<c<olc<c<02?lc<c<0
0ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003oi^KVonKViP05onKViP03o`000?oooooooooo02Oooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo05;ooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<
c005o`000?nc/k?o/k>cok>c/ol000001OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo
6ATI00go6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01_m<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`0Xooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<00OoC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00004?lI6AT0
0ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0:?ooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0D?ooool00ol0003oi^KVonKViP05onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<
C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT03OlI6ATlo`00013o6ATI00?o0000oc<c
<olc<c<02?lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo02Wooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo04oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o
<c<coc<c<`07oc<c<`03o`000?lI6AWo6ATI00go6ATI??l0000@oaTI6@03o`000?lc<c?o<c<c00Wo
<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0Yooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<0
2?lc<c<00ol0003o6ATIoaTI6@0=oaTI6Cco00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03o`00
0?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`00
0?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0:_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0COooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So<c<c00?o
0000oaTI6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP08onKViP03o`000?oooooooooo02[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo04cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo
6ATI00go6ATI>ol0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`0
0ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H0
0ol0003oooooooooo`0[ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI
6Cco00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000oooo
ooooool0:oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0B_ooool00ol0003o
i^KVonKViP06onKViP;o00001Oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00Ko
C4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI6Cco00003olI6AT00ol0003o
<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Woi^KV00?o0000ooooooooool0;?ooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool0B_ooool00ol0003oi^KVonKViP06onKViP03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`00
0?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<0
2Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl0
1_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo02cooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo04Wooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c
<`08oc<c<`03o`000?lI6AWo6ATI00co6ATI?Ol0000>oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o
0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`0]ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`19ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<0
0ol0003o6ATIoaTI6@0<oaTI6Cco00003_lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Ko
i^KV00Woi^KV00?o0000ooooooooool0;_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool0B?ooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI
6OlI6AT03?lI6ATlo`0000oo6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<
C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo02oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04So
oooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00Go
IVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo6ATI00co
6ATI>ol0000?oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003o
IVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003o
ooooooooo`0`ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0<oaTI6C_o0000
4?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
<Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0A_ooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C005oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATko`0000oo6ATI00?o
0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo037ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04Gooooo00?o0000onKVi_oVi^H01ooVi^H0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`0
0ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00_o6ATI>ol0000?oaTI6@03o`000?lc<c?o
<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`0booooo`7o00000Oooool1
ooooo`00;_ooool2o`0004Gooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c
<`03o`000?lI6AWo6ATI00co6ATI>_l0000@oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<
C?m<C4`01_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`0aooooo`?o00000_ooool002kooooo00?o0000oooooooo
ool0@oooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI
6AT03?lI6ATio`00013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003
o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo03Cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo04;ooooo
00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
>_l0000?oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooo
ooooo`0eooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`11ooooo`03o`000?oV
i^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6CWo00003olI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0=Ooo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0@?ooool00ol0003oi^KVonKViP09
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006
oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATio`00013o6ATI00?o0000
oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo03Kooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo03oooooo00?o0000onKVi_oVi^H02_oVi^H00ol0
003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>?l0000@oaTI6@03o`000?lc<c?o<c<c
00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0gooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0nooooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<
c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o000000KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0
003o6ATIoaTI6@0<oaTI6CSo00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<
00OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Ooi^KV00?o0000ooooooooool0>?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool0?Oooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Coc<c<00Go0000ok>c/onc
/k?o/k>co`000006oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03?lI6ATho`00
013o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
03Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03cooooo00?o0000onKVi_oV
i^H02_oVi^H00ol0003oc<c<olc<c004olc<c005o`000?nc/k?o/k>cok>c/ol000001_nIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0
003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI>?l0000@oaTI6@03o`000?lc<c?o<c<c
00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`0iooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0looooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc
<c<02Olc<c<00ol0003o6ATIoaTI6@0<oaTI6CSo00003olI6AT00ol0003o<c<coc<c<`09oc<c<`03
o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003
o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0>_ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0>oooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03OlI6ATgo`00013o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<
oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP08onKViP03o`000?oooooooooo03[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo03_ooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00co6ATI=ol0000@oaTI6@03o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`02?m<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooV
i^H00ol0003oooooooooo`0kooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=
oaTI6CKo00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000
ooooooooool0>oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0>_ooool00ol0
003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03OlI6ATeo`00
017o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo
03cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Wooooo00?o0000onKVi_oV
i^H02OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00go6ATI=Ol0000AoaTI6@03
o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00;oc<c<0_l00009onKViP;o0000?oooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool0>?ooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT03OlI6ATdo`00017o6ATI00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<
oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03
o`000?oooooooooo03oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Sooooo
00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00co6ATI
=Ol0000AoaTI6@03o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIV
ofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`10ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0gooooo`03o`000?oVi^Koi^KV00Soi^KV
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00KoC4a<
00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6CCo00004OlI6AT00ol0003o<c<c
oc<c<`08oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c002o`0000Woi^KV0_l00013ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI
6@0<oaTI6CCo00004OlI6AT00ol0003o<c<coc<c<`08oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oooooooooo04?ooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H02?oV
i^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00go6ATI<ol0000AoaTI6@03o`000?lc
<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`04o`000?o<
c<coc<c<o`0000[oi^KV00?o0000ooooooooool0A?ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool0=_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT03OlI6ATbo`00017o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Co0000olc<c?o<c<co00002_oVi^H00ol0003ooooo
ooooo`15ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oV
i^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0=oaTI6C;o00004OlI
6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc
/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oooooooooo04Kooooo0Ol00001ooooo`7ooooo
000^ooooo`;o0000=_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o
0000oaTI6OlI6AT03OlI6ATbo`00017o6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<
C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Co0000olc<c?o<c<co00002_oVi^H00ol0003ooooo
ooooo`14ooooo`?o00000_ooool002kooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKV
iP07onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATbo`00013o6ATI00?o
0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?l000002_oVi^H00ol0003oooooooooo`17ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<02Olc<c<0
0ol0003o6ATIoaTI6@0=oaTI6C;o00004?lI6AT00ol0003o<c<coc<c<`09oc<c<`03o`000?m<C4co
C4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:onKViP03o`000?oo
oooooooo04Oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Gooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI<Ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03
ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`17ooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000
oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6C3o00004?lI6AT00ol0003o<c<coc<c<`0:
oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<
c<co000000[oi^KV00?o0000ooooooooool0B?ooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0=Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000
oaTI6OlI6AT03_lI6AT`o`00013o6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oo
oooooooo04Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo03Gooooo00?o0000
onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI;ol0000@
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`19
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0eooooo`03o`000?oVi^Koi^KV
00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
00KoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0?oaTI6Bko00004?lI6AT00ol0
003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0BOooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0=_ooool00ol0003oi^KVonKViP05onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003
o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6AT_o`00013o6ATI00?o0000oc<c<olc
<c<02_lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo04[ooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI;_l0000@oaTI6@03o`000?lc<c?o<c<c00[o<c<c
00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`1:ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02?lc
<c<00ol0003o6ATIoaTI6@0?oaTI6Bgo00004?lI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<
C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oV
i^Koi^KV00Soi^KV00?o0000ooooooooool0Boooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0=_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000
oaTI6OlI6AT03_lI6AT]o`00017o6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C006
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo04cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
03Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
00ko6ATI;?l0000AoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0
003oooooooooo`1<ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0fooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>oaTI6B_o00004_lI6AT00ol0
003o<c<coc<c<`09oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0COooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0=_ooool00ol0003oi^KVonKViP04onKViP03
o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C006oda<C003
o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03_lI6ATZo`0001?o6ATI00?o0000oc<c<olc
<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`00_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo04gooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo03Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI00ko6ATI:Ol0000CoaTI6@03o`000?lc<c?o<c<c00Wo<c<c
00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H02?oVi^H2o`00053ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo03Kooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI
6AWo6ATI00ko6ATI:?l0000DoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooV
i^H00ol0003oooooooooo`1@ooooo`7o00000Oooool1ooooo`003Oooool3o`000003oa0@4?oooooo
oooo01_ooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATWo`0001Co6ATI00?o0000oc<c<olc<c<02Olc<c<0
0ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01_moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003oi^KVonKViP07onKViP03o`000?oooooooooo057ooooo0Ol00001ooooo`7ooooo000?oooo
o`03oa0@4?nj^[[ooooo01cooooo00?o0000ooooooooool0=Oooool00ol0003oi^KVonKViP03onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C007oda<
C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATVo`0001Co6ATI00?o0000oc<c
<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmo
OomoOgl01_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo05;ooooo0Ol00001oooo
o`7ooooo000?ooooo`03oiRHV?lb<S;ooooo01cooooo00?o0000ooooooooool0=?ooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003o
VIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT03olI6ATUo`0001Co
6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00Ko
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo05?o
oooo0Ol00001ooooo`7ooooo000?ooooo`03omgMgOl0003o^[Zj01;ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI013o6ATI9?l0000DoaTI6@03o`000?lc<c?o<c<c00Wo<c<c
00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`1Dooooo`7o00000Oooool1ooooo`003ooo
ool00omEEEGoMgMgodA4A00Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04?lI
6ATSo`0001Co6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oo
oooooooo05Cooooo0Ol00001ooooo`7ooooo000>ooooo`05omgMgOl@413oooooob4Q8OoMgMd04ooo
ool00ol0003oooooooooo`05ooooo`?o0000<oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc
<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04OlI6ATRo`0001Co6ATI00?o0000oc<c<olc<c<02Olc
<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo05?ooooo0ol00002ooooo`003_ooool0
1OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIV
IP06ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI
6@0AoaTI6B7o00005OlI6AT00ol0003o<c<coc<c<`08oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o
0000ooooooooool0E_ooool1o`00007ooooo0Oooool000gooooo00?ok^k^o`000?o^k^h00_ooool0
0ol0003ogMgMooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04OlI6ATP
o`0001Go6ATI00?o0000oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKo
IVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooo
oooo05Kooooo0Ol00001ooooo`7ooooo000=ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo00?o0000
onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI01;o6ATI7_l0000F
oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`1G
ooooo`7o00000Oooool1ooooo`009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
037ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
01;o6ATI7Ol0000FoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0
003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`1Gooooo`7o00000Oooool1ooooo`009?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo033ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003
o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03
o`000?lI6AWo6ATI01?o6ATI7?l0000FoaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oV
i^H01ooVi^H00ol0003oooooooooo`1Hooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATI
oaTI6@0CoaTI6A_o00005_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool0FOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0;_oo
ool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT04olI
6ATJo`0001Ko6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo05Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo02gooooo00?o0000
onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000
oda<C?m<C4`01om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI01Co6ATI6Ol0000F
oaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1J
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oVi^Koi^KV
00Ooi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<
00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0EoaTI6AKo00006?lI6AT00ol0
003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0F_ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool0;?ooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003
o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT05_lI6ATDo`0001So6ATI00?o0000oc<c<olc
<c<02_lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo05_ooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo02cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`09oc<c<`03o`000?lI6AWo6ATI01So6ATI4_l0000HoaTI6@03o`000?lc<c?o<c<c00[o<c<c
00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1Looooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02Olc
<c<00ol0003o6ATIoaTI6@0IoaTI6@oo00006OlI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<
C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oV
i^Koi^KV00Ooi^KV00?o0000ooooooooool0GOooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool0:oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000
oaTI6OlI6AT06_lI6AT;o`0001_o6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP07
onKViP03o`000?oooooooooo05gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02[ooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI
01co6ATI2?l0000MoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`1Nooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0MoaTI6@Go
00007_lI6AT00ol0003o<c<coc<c<`0:oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0Goooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0:Oooool00ol0003oi^KV
onKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<
oda<C008oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT07_lI6AT00ol0003o6ATI
oaTI6@0NoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<0_l00009onKViP03o`000?oooooooooo063ooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo02Wooooo00?o0000onKVi_oVi^H01OoV
i^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`02?m<
C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI03oo6ATI00?o0000oc<c<olc<c<02olc
<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo067ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo02Sooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:
oc<c<`03o`000?lI6AWo6ATI03ko6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo06;ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI
03go6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oooooooooo06?ooooo0Ol00001
ooooo`7ooooo000^ooooo`03o`000?oooooooooo02Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0
003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI03co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0
003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:
onKViP03o`000?oooooooooo06Cooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
02Oooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI
03co6ATI00?o0000oc<c<olc<c<02olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`000?oooooooooo06Gooooo0Ol00001
ooooo`7ooooo000^ooooo`;o00009oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00[o<c<c00?o0000oaTI6OlI6AT0>olI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<
00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000
ooooooooool0I?ooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo02Cooooo0_l00007onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<
C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>_lI6AT00ol0003o<c<coc<c<`0;oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co
000000[oi^KV00?o0000ooooooooool0Ioooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool08oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI
6OlI6AT0>OlI6AT00ol0003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0Ioooool1
o`00007ooooo0Oooool002kooooo00?o0000ooooooooool08_ooool00ol0003oi^KVonKViP07onKV
iP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<
C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>OlI6AT00ol0003o<c<coc<c<`0<oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000:
onKViP03o`000?oooooooooo06Sooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
023ooooo0_l00009onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT0>?lI6AT00ol0
003o<c<coc<c<`0<oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0
003oc<c<olc<c?o<c<co000000Woi^KV00?o0000ooooooooool0JOooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool07oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00_o<c<c00?o0000oaTI6OlI6AT0>?lI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<
00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000
ooooooooool0JOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool07Oooool2o`00
00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<
00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0hoaTI6@03o`000?lc<c?o<c<c
00co<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<
olc<c?l000002_oVi^H00ol0003oooooooooo`1Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`0Looooo`03o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0
003o6ATIoaTI6@0goaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0
003oooooooooo`1Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0foaTI6@03
o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`05
o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`1[ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<02olc<c<00ol0003o6ATIoaTI6@0foaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0
003oooooooooo`1/ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0eoaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05
o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`1/ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0doaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0
003oooooooooo`1]ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oVi^Koi^KV00[oi^KV00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0doaTI6@03
o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`04
o`000?o<c<coc<c<o`0000_oi^KV00?o0000ooooooooool0K_ooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool06?ooool00ol0003oi^KVonKViP0:onKViP03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00Ko
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co
<c<c00?o0000oaTI6OlI6AT0<olI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00So
C4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000;onKViP03o`000?oooooooooo
06oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Oooooo00?o0000onKVi_oV
i^H02_oVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnI
VIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`02?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI03;o6ATI00?o0000oc<c<olc
<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Co0000olc<c?o<
c<co00003?oVi^H00ol0003oooooooooo`1_ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oVi^Koi^KV00Woi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o
6ATIoaTI6@0boaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003o
IVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`03ok>c/`04o`000?o<c<coc<c<o`0000coi^KV00?o0000ooooooooool0L?ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0003oi^KVonKViP09onKViP03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C008oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0<OlI6AT00ol0003o<c<coc<c<`0=oc<c<`03
o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000<onKV
iP03o`000?oooooooooo077ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Co
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI037o
6ATI00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00Ko
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00Co0000olc<c?o<c<co00002ooVi^H00ol0003oooooooooo`1booooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Fooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0`oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<
C4`02?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`04o`000?o<c<coc<c<o`0000_oi^KV00?o0000oooo
ooooool0Loooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0003o
i^KVonKViP08onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0<?lI6AT00ol0003o
<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003o
c<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0M?ooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool05_ooool00ol0003oi^KVonKViP08onKViP03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00Go
Ogmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co
<c<c00?o0000oaTI6OlI6AT0;olI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00Wo
C4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Oo
i^KV00?o0000ooooooooool0MOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
5_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
;_lI6AT00ol0003o<c<coc<c<`0=oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0
M_ooool1o`00007ooooo0Oooool002kooooo0_l0000Gooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o
0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0]oaTI6@03o`000?lc<c?o<c<c00go<c<c00?o
0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`1dooooo`?o00000_ooool002kooooo00?o0000
ooooooooool05_ooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000
ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000
oaTI6OlI6AT0;OlI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000
ooooooooool0Moooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0
003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0
003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0;?lI6AT00ol0
003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N?ooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP07onKViP03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:olI6AT00ol0003o<c<coc<c<`0>oc<c<`03
o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N?ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00co<c<c
00?o0000oaTI6OlI6AT0:olI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?oVi^Koi^KV00Goi^KV
00?o0000ooooooooool0NOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Ooo
ool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:_lI
6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0NOoo
ool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP06
onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008
oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0:OlI6AT00ol0003o<c<coc<c<`0>
oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0N_ooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00go<c<c00?o0000oaTI6OlI6AT0:?lI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<
00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV
00Koi^KV00?o0000ooooooooool0Noooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool05Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<01Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI
6AT0:?lI6AT00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0Noooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C008oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT09olI6AT00ol0003o<c<c
oc<c<`0>oc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c003olc<c0;o00002OoVi^H00ol0003oooooooooo`1looooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03Olc
<c<00ol0003o6ATIoaTI6@0WoaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H02OoV
i^H00ol0003oooooooooo`1looooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0V
oaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`04o`000?o<c<coc<c<olc<c0;o00002ooVi^H00ol0003oooooooooo`1mooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000
olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0UoaTI6@03o`000?lc<c?o<c<c00ko<c<c00?o0000
oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000003?oV
i^H00ol0003oooooooooo`1nooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0S
oaTI6@03o`000?lc<c?o<c<c00oo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03
ok>c/`04o`000?o<c<coc<c<o`0000coi^KV00?o0000ooooooooool0Ooooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o
<c<c00oo<c<c00?o0000oaTI6OlI6AT08_lI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4co
C4a<00SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<olc<c?l0000=onKViP03o`000?oo
oooooooo07oooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000
oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI027o6ATI00?o0000
oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C008oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00;o/k>c00Go0000
olc<c?o<c<coc<c<o`00000<onKViP03o`000?oooooooooo083ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002
olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0?
oc<c<`03o`000?lI6AWo6ATI023o6ATI00?o0000oc<c<olc<c<04?lc<c<00ol0003oC4a<oda<C008
oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Co0000olc<c?o<c<co00003?oVi^H00ol0003ooooooooo
o`21ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4co
C4a<00WoC4a<00?o0000oc<c<olc<c<03olc<c<00ol0003o6ATIoaTI6@0OoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<co
c<c<olc<c?l000003?oVi^H00ol0003oooooooooo`21ooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<04Olc<c<0
0ol0003o6ATIoaTI6@0MoaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<C?m<C4`02?m<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`02ok>c/`05o`000?o<c<coc<c<olc<c?l000003?oVi^H00ol0003ooooooooo
o`22ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4co
C4a<00SoC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0LoaTI6@03o`000?lc<c?o
<c<c013o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`23ooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c
<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0KoaTI6@03o`000?lc<c?o<c<c013o<c<c00?o0000oda<
C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H0
0ol0003oooooooooo`24ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0JoaTI
6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP07ofIV
IP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c
/`05o`000?o<c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`25ooooo`7o00000Oooool1
ooooo`00;_ooool2o`0001Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Aoc<c
<`03o`000?lI6AWo6ATI01Wo6ATI00?o0000oc<c<olc<c<04Olc<c<00ol0003oC4a<oda<C009oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08onKV
iP03o`000?oooooooooo08Cooooo0ol00002ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATIoaTI6@0GoaTI6@03
o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05
o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003oooooooooo`27ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc
<c<04olc<c<00ol0003o6ATIoaTI6@0FoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oV
i^H01ooVi^H00ol0003oooooooooo`28ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`03ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o6ATI
oaTI6@0DoaTI6@;o00004olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00OoIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo08Wooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000onKVi_oVi^H01?oV
i^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<
C4`00ol0003o<c<coc<c<`0Coc<c<`03o`000?lI6AWo6ATI01?o6ATI00?o0000oc<c<olc<c<04olc
<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<
o`00000:onKViP03o`000?oooooooooo08Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo01Gooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI
6AWo6ATI013o6ATI0_l0000Eoc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc
/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV00?o0000ooooooooool0R_ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool05Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<
c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?mo
OgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc
<c?o<c<c01Go<c<c00?o0000oaTI6OlI6AT03_lI6AT00ol0003o<c<coc<c<`0Doc<c<`03o`000?m<
C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<c?o<c<co000000[oi^KV
00?o0000ooooooooool0Roooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05Ooo
ool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01Ko<c<c00?o0000oaTI6OlI6AT02olI
6AT2o`0001Ko<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<
c<coc<c<olc<c?l000002ooVi^H00ol0003oooooooooo`2;ooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<06?lc
<c<00ol0003o6ATIoaTI6@08oaTI6@;o00006?lc<c<00ol0003oC4a<oda<C009oda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00Co0000olc<c?o<c<co00002ooVi^H00ol0003oooooooooo`2<ooooo`7o0000
0Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oVi^Koi^KV00Coi^KV00?o
0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o
0000oc<c<olc<c<06?lc<c<00ol0003o6ATIoaTI6@05oaTI6@?o00006Olc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Go0000olc<c?o<c<coc<c<o`00000:onKViP03o`00
0?oooooooooo08gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Gooooo00?o
0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?lI6AWo6ATI00;o6ATI0_l0
000Koc<c<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<00onc/k<01Ol0003oc<c<olc<
c?o<c<co000000_oi^KV00?o0000ooooooooool0SOooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool05_ooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01[o<c<c00Co
0000oaTI6Ol0003o00007Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00KoIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo08kooooo
0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo00?o0000onKVi_oVi^H00_oV
i^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`02_m<
C4`00ol0003o<c<coc<c<`0Koc<c<`03o`000?lc<c?o<c<c01co<c<c00?o0000oda<C?m<C4`02_m<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`05o`000?o<c<coc<c<olc<c?l000002_oVi^H00ol0003ooooo
ooooo`2?ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Fooooo`03o`000?oV
i^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0>Olc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo093ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo00?o0000
onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0ioc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000
ooooooooool0TOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_ooool00ol0
003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0
003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c03Wo<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0
003oooooooooo`2Aooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0>Olc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP07onKViP03
o`000?oooooooooo09;ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01Kooooo
00?o0000onKVi_oVi^H00_oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0hoc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Koi^KV
00?o0000ooooooooool0Toooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool05_oo
ool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<00_nc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01omV
IVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03Oo<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01_oV
i^H00ol0003oooooooooo`2Dooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oVi^Koi^KV00;oi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`02
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0=olc<c<00ol0003oC4a<oda<C009
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP05
onKViP03o`000?oooooooooo09Gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
01Gooooo00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00;o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00OoIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0foc<c<`03o`000?m<C4coC4a<
00WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Goi^KV00?o0000ooooooooool0U_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool05Oooool00ol0003oi^KVonKViP02onKViP03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<00_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mV
IVH01omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03Go<c<c00?o0000oda<C?m<
C4`02Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oV
i^H01OoVi^H00ol0003oooooooooo`2Gooooo`7o00000Oooool1ooooo`00;_ooool2o`0001Gooooo
00?o0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0doc<c<`03o`000?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Coi^KV
00?o0000ooooooooool0U_ooool3o`0000;ooooo000^ooooo`03o`000?oooooooooo01Cooooo00?o
0000onKVi_oVi^H00ooVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0coc<c<`03o`000?m<C4coC4a<00[oC4a<00?o
0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Goi^KV00?o
0000ooooooooool0V?ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool04oooool0
0ol0003oi^KVonKViP03onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c03?o<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01OoVi^H0
0ol0003oooooooooo`2Iooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`03ok>c
/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0<_lc<c<00ol0003oC4a<oda<C009oda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP05onKV
iP03o`000?oooooooooo09Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo01;o
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00;o
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00Oo
IVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0aoc<c<`03o`000?m<C4coC4a<00[o
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Go
i^KV00?o0000ooooooooool0V_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
4Oooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c037o<c<c00?o0000oda<C?m<C4`0
2Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oooooooooo`2Jooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP07ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0<?lc<c<00ol0003oC4a<oda<
C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKV
iP06onKViP03o`000?oooooooooo09_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo013ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKo
IVIV00OoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0`oc<c<`03o`000?m<C4co
C4a<00WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Ko
i^KV00Koi^KV00?o0000ooooooooool0W?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool04?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c02oo<c<c00?o0000oda<
C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKV
i_oVi^H01ooVi^H00ol0003oooooooooo`2Looooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0;_lc<c<00ol0003o
C4a<oda<C00:oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
i^KVonKViP07onKViP03o`000?oooooooooo09gooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00kooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0^oc<c<`03o`00
0?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0WOooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool03Oooool00ol0003oi^KVonKViP06onKViP03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00KoOgmo00?o
0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c02go<c<c00?o
0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Nooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0;Olc<c<0
0ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01OmoOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003oi^KVonKViP08onKViP03o`000?oooooooooo09kooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00cooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0/oc<c
<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<
c003o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0Woooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool03?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00Ko
Ogmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c02_o
<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Pooooo`7o00000Oooool1ooooo`00
;_ooool00ol0003oooooooooo`0;ooooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
1_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<0
:_lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo0:7ooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00_ooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmo
O`06ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c
<`0Xoc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c003olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0X_ooool1o`00007ooooo0Ooo
ool002kooooo00?o0000ooooooooool02_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o
<c<c02Oo<c<c00?o0000oda<C?m<C4`03?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Sooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl01_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c
<olc<c<09_lc<c<00ol0003oC4a<oda<C00=oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:?ooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo00Wooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o
<c<coc<c<`0Voc<c<`03o`000?m<C4coC4a<00coC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0Y?ooool1o`00007o
oooo0Oooool001Cooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP06onKViP03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00=oda<C003
o`000?lc<c?o<c<c02Go<c<c00?o0000oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Uooooo`7o
00000Oooool1ooooo`005_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0Toc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003
o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0YOooool1o`00007ooooo0Oooool001Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Co/k>c
00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00WoIVIV
00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0Toc<c<`03o`000?m<C4coC4a<00goC4a<
00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV
00?o0000ooooooooool0Y_ooool1o`00007ooooo0Oooool001Kooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`04ooooo`?o00001oooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?mo
OgooOgmo00KoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc
<c?o<c<c02;o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<
00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Uooooo`?o00000_ooool001Kooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c02;o<c<c00?o0000oda<C?m<C4`0
3Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003o
ooooooooo`2Wooooo`7o00000Oooool1ooooo`005_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c027o<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`00
0?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`05o`00
0?o<c<coc<c<olc<c?l000001ooVi^H00ol0003oooooooooo`2Xooooo`7o00000Oooool1ooooo`00
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c023o<c<c00?o0000oda<C?m<C4`0
3_m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
0onIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`2Yooooo`7o00000Oooool1ooooo`005?ooool00omEEEGoIVIVo`00000=ooooo`Co0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
1omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<0
7olc<c<00ol0003oC4a<oda<C00?oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@03oiVIV@05o`000?nc/k?o/k>cok>c/ol000001?o<c<`00ol0003o
i^KVonKViP04onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0Moc<c<`03o`00
0?m<C4coC4a<00ooC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003o`000?oVi^Koi^KV00Co
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
2OmVIVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c01_o<c<c00?o0000oda<C?m<C4`0
4?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003o
ooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`00
0?m<C4coC4a<017oC4a<00?o0000oc<c<olc<c<06Olc<c<00ol0003oC4a<oda<C00@oda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000001?o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo0:Wo
oooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H0
1?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`0
4Om<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Coi^KV00?o0000ooooooooool0
ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Oooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<
C00Boda<C003o`000?lc<c?o<c<c01Go<c<c0_l0000Doda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKViP04onKViP03o`000?oooooooooo0:Wooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01?oVi^H0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`04om<C4`0
0ol0003o<c<coc<c<`0Boc<c<`;o00005Om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<0ol0000?oc<c
<`;o00005om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKV
i_oVi^H01?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<0ol0000;oc<c<`03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00Go0000ok>c/onc/k?o/k>co`000004olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003o
i^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00Joda<C0?o00001_lc<c<2o`0001WoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00Go0000ok>c/onc/k?o/k>co`000004olc<
c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00Oo
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Moda<C0?o000000?o<c<co`000?l0
00006_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01OnIVIT01Ol0003o/k>cok>c/onc/k?o000000Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0
003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03
o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01ooC4a<00?o0000oda<C?m<C4`06_m<C4`00ol0003oIVIVofIVIP08ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Coc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<03coC4a<00?o0000ofIVI_mV
IVH02?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00koda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KV
onKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oo
oooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00coIVIV00?o0000oda<C?m<C4`0>_m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?mo
OgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Ooo
ool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<03WoC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000
ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0
003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00ioda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003oi^KVonKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0=om<C4`00ol0003oIVIVofIVIP09ofIVIP03
o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o
00000Oooool1ooooo`00;_ooool2o`0000Gooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0=_m<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003ooooo
ooooo`2Wooooo`?o00000_ooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVI
V@06oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<
C00doda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003oi^KVonKV
iP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00goIVIV00?o0000oda<C?m<C4`0=?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01OoVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1
ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<03;oC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000oooo
ooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003o
i^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003o
C4a<oda<C00aoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
i^KVonKViP05onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0<?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Yooooo`7o0000
0Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Coi^KV00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<02ooC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o
0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool0
0ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03_mVIVH0
0ol0003oC4a<oda<C00^oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl01omoOgl0
0ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0;Om<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003oooooooooo`2Yoooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Co
i^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00So
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<02co
C4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ko
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00[oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl0
1omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0:_m<C4`00ol0003oIVIVofIV
IP0=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooooooo
o`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4co
C4a<02OoC4a<0_l0000@ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04oooo
o`03o`000?oVi^Koi^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`05ok>c
/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0AofIV
IP03o`000?m<C4coC4a<02GoC4a<00?o0000ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<
c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002ko
oooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00[o
Ogmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00Roda<C0;o00004_mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0ZOooool1o`00007o
oooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP04onKViP03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH04_mVIVH2o`00027oC4a<00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Koi^KV00?o0000ooooooooool0
ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKV
iP04onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVI
V@08oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH04omVIVH2o`0001goC4a<0_l0
000DofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H01_oVi^H00ol0003ooooooooo
o`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Ko
i^KV00Coi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0EofIVIP;o00006Om<C4`2
o`0001GoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKViP03o`000?oooooo
oooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKV
i_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o0000oda<
C?m<C4`04om<C4`3o`0001KoIVIV00?o0000ogmoOomoOgl02_moOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP06onKV
iP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Co
oooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Ko
/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV01Oo
IVIV0_l0000Aoda<C0;o00006OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ko
i^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH0
6?mVIVH2o`0000goC4a<0_l0000JofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000onKVi_oVi^H0
1ooVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`06ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIV
IP0IofIVIPgo00006omVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o
0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo0_l00005ooooo`03o`000?oVi^Ko
i^KV00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`06ok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP11ofIVIP03o`000?moOgoo
Ogmo00[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Wooooo`?o00000_ooool0
02kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo
00coOgmo00?o0000ofIVI_mVIVH0?omVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI
00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?oVi^Koi^KV
00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mV
IVH0?_mVIVH00ol0003oOgmoogmoO`0;ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc
/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@08oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH0?OmVIVH00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?mo
OgooOgmo00coOgmo00?o0000ofIVI_mVIVH0??mVIVH00ol0003oOgmoogmoO`0<ogmoO`03o`000?nI
VIWoVIVI00OoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oV
i^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000
ofIVI_mVIVH0>OmVIVH2o`0000koOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`05
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Y
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0fofIVIP;o00004?moOgl00ol0
003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003oi^KVonKViP07onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03
o`000?oooooooooo00Cooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0>ogmoO`;o
0000=OmVIVH00ol0003oOgmoogmoO`0?ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc
/k<01_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000oooooooo
ool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01?ooool00ol0003oi^KV
onKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@09oiVIV@03o`000?moOgooOgmo013oOgmo0_l0000bofIVIP03o`000?moOgooOgmo013oOgmo
00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H01ooVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`07ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl04Omo
Ogl00ol0003oIVIVofIVIP0]ofIVIP;o00004_moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oo
oooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000
onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0AogmoO`;o0000;?mVIVH00ol0003oOgmoogmoO`0A
ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c003
olc<c003o`000?oVi^Koi^KV00Ooi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool01?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
01?oOgmo0_l0000XofIVIP;o00005?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c
00Oo/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo
0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Cooooo00?o0000onKVi_oV
i^H01OoVi^H00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV02CoIVIV00?o0000ogmoOomo
Ogl04omoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003oi^KVonKViP07onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7o
oooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`0EogmoO`;o00008omVIVH00ol0003oOgmoogmoO`0DogmoO`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV00Soi^KV
00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Ooo
ool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<02?nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo01KoOgmo0ol0000MofIVIP?o00005_mo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0H
ogmoO`Co00005OmVIVH4o`0001SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Y
ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV
00Goi^KV00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl07?moOgl3o`0000ooIVIV0ol0000KogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<02Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo01koOgmo3ol0000MogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c003olc<c003
o`000?oVi^Koi^KV00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool01Oooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<coc<c<00Ooc<c<
00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo04SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Yooooo`7o00000Oooool1ooooo`00;_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<
c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0A_mo
Ogl00ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT03_nIVIT2o`0004CoOgmo0_l0000?
oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP08
onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
00Gooooo00?o0000onKVi_oVi^H01OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c
00Wo/k>c00?o0000oiVIVOnIVIT04?nIVIT00ol0003oOgmoogmoO`10ogmoO`03o`000?nIVIWoVIVI
00ooVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV
00Soi^KV00?o0000ooooooooool0ZOooool1o`00007ooooo0Oooool002kooooo0_l00006ooooo`03
o`000?oVi^Koi^KV00Goi^KV00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`0:ok>c/`03
o`000?nIVIWoVIVI013oVIVI0_l0000nogmoO`;o00004OnIVIT00ol0003o/k>cok>c/`09ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H02?oVi^H00ol0003oooooooooo`2Wooooo`?o
00000_ooool002kooooo00?o0000ooooooooool01Oooool00ol0003oi^KVonKViP05onKViP03o`00
0?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<02_nc/k<00ol0003oVIVIoiVIV@0AoiVIV@;o0000
>omoOgl00ol0003oVIVIoiVIV@0@oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo
000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o/k>c00_o/k>c0_l0000CoiVIV@03o`000?moOgooOgmo03KoOgmo0_l0
000BoiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKV
iP08onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o
/k>c00go/k>c00?o0000oiVIVOnIVIT04OnIVIT3o`0003;oOgmo0ol0000CoiVIV@03o`000?nc/k?o
/k>c00_o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooo
oooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKV
i_oVi^H01_oVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc/k?o/k>c00go/k>c00?o0000oiVI
VOnIVIT04onIVIT3o`0002coOgmo0ol0000EoiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo0:Wooooo0Ol00001oooo
o`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003o
c<c<olc<c008olc<c003o`000?nc/k?o/k>c00ko/k>c00?o0000oiVIVOnIVIT05OnIVIT3o`0002Ko
Ogmo0ol0000HoiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
i^KVonKViP09onKViP03o`000?oooooooooo0:Wooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c008olc<c003o`00
0?nc/k?o/k>c00oo/k>c00?o0000oiVIVOnIVIT05onIVIT3o`0001ooOgmo1?l0000JoiVIV@03o`00
0?nc/k?o/k>c00_o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP08onKViP03o`00
0?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o
0000onKVi_oVi^H01_oVi^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00oo/k>c00?o
0000oiVIVOnIVIT06OnIVIT4o`0001KoOgmo1Ol0000MoiVIV@03o`000?nc/k?o/k>c00co/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:[ooooo0Ol0
0001ooooo`7ooooo000^ooooo`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01_oVi^H0
0ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c013o/k>c00?o0000oiVIVOnIVIT07?nIVIT5
o`0000SoOgmo2Ol0000QoiVIV@03o`000?nc/k?o/k>c00go/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003oi^KVonKViP08onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^oooo
o`03o`000?oooooooooo00Gooooo00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<olc<c008olc<
c003o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT08?nIVIT8o`0002WoVIVI00?o0000ok>c
/onc/k<03Onc/k<00ol0003oc<c<olc<c008olc<c003o`000?oVi^Koi^KV00Soi^KV00?o0000oooo
ooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01Oooool00ol0003o
i^KVonKViP07onKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@1>oiVIV@;o00004?nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oVi^Koi^KV00Wo
i^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool0
1Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00[oc<c<00?o0000ok>c/onc/k<0
4Onc/k<00ol0003oVIVIoiVIV@1;oiVIV@;o00004Onc/k<00ol0003oc<c<olc<c008olc<c003o`00
0?oVi^Koi^KV00Woi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool01Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00_oc<c<00?o
0000ok>c/onc/k<04Onc/k<3o`0004SoVIVI0_l0000Cok>c/`03o`000?o<c<coc<c<00Soc<c<00?o
0000onKVi_oVi^H02OoVi^H00ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`03?o<c<`2
o`0001Co/k>c0_l00014oiVIV@;o00005?nc/k<00ol0003oc<c<olc<c009olc<c003o`000?oVi^Ko
i^KV00Woi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool01Oooool00ol0003oi^KVonKViP07onKViP03o`000?o<c<coc<c<00koc<c<00?o0000ok>c
/onc/k<04onc/k<3o`0003koVIVI0ol0000Eok>c/`03o`000?o<c<coc<c<00[oc<c<00?o0000onKV
i_oVi^H02OoVi^H00ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oVi^Koi^KV00Soi^KV00?o0000olc<c?o<c<`03_o<c<`00ol0003o
/k>cok>c/`0Eok>c/`?o0000=onIVIT4o`0001Oo/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003o
i^KVonKViP0:onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H02OoVi^H00ol0003oc<c<olc<c00>olc<c003o`00
0?nc/k?o/k>c01Oo/k>c1?l0000_oiVIV@Co00006_nc/k<00ol0003oc<c<olc<c00;olc<c003o`00
0?oVi^Koi^KV00[oi^KV00?o0000ooooooooool0Z_ooool1o`00007ooooo0Oooool002kooooo00?o
0000ooooooooool01Oooool00ol0003oi^KVonKViP09onKViP03o`000?o<c<coc<c<00ooc<c<00?o
0000ok>c/onc/k<06_nc/k<6o`0002KoVIVI0ol0000Lok>c/`;o00003_o<c<`00ol0003oi^KVonKV
iP0:onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00Gooooo00?o0000onKVi_oVi^H02_oVi^H00ol0003oc<c<olc<c00?olc<c003o`000?nc/k?o
/k>c01oo/k>c2Ol0000FoiVIV@Oo00007Onc/k<2o`0000ooc<c<00?o0000onKVi_oVi^H02ooVi^H0
0ol0003oooooooooo`2Zooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05oooo
o`03o`000?oVi^Koi^KV00_oi^KV00?o0000olc<c?o<c<`03oo<c<`00ol0003o/k>cok>c/`0Wok>c
/aKo00008_nc/k<2o`00017oc<c<00?o0000onKVi_oVi^H02ooVi^H00ol0003oooooooooo`2Zoooo
o`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`05ooooo`03o`000?oVi^Koi^KV00_o
i^KV00?o0000olc<c?o<c<`04?o<c<`2o`0005ko/k>c00?o0000olc<c?o<c<`04Oo<c<`00ol0003o
i^KVonKViP0;onKViP03o`000?oooooooooo0:[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`00
0?oooooooooo00Gooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003oc<c<olc<c00Aolc<c0;o0000
F_nc/k<2o`0001?oc<c<00?o0000onKVi_oVi^H03?oVi^H00ol0003oooooooooo`2Zooooo`7o0000
0Oooool1ooooo`00;_ooool2o`0000Oooooo00?o0000onKVi_oVi^H03?oVi^H00ol0003oc<c<olc<
c00Bolc<c0?o0000EOnc/k<2o`0001Goc<c<00?o0000onKVi_oVi^H02ooVi^H00ol0003ooooooooo
o`2Yooooo`?o00000_ooool002kooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP0=
onKViP03o`000?o<c<coc<c<01Coc<c<0_l0001@ok>c/`?o00005oo<c<`00ol0003oi^KVonKViP0;
onKViP03o`000?oooooooooo0:_ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo
00Kooooo00?o0000onKVi_oVi^H03OoVi^H00ol0003oc<c<olc<c00Folc<c0;o0000B_nc/k<4o`00
01Woc<c<00?o0000onKVi_oVi^H03?oVi^H00ol0003oooooooooo`2[ooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`06ooooo`03o`000?oVi^Koi^KV00koi^KV00?o0000olc<c?o<
c<`05oo<c<`4o`0004;o/k>c1?l0000Lolc<c0;o00003_oVi^H00ol0003oooooooooo`2[ooooo`7o
00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`06ooooo`03o`000?oVi^Koi^KV00ooi^KV
00?o0000olc<c?o<c<`06_o<c<`5o`0003So/k>c1Ol0000Oolc<c003o`000?oVi^Koi^KV00koi^KV
00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01_oo
ool00ol0003oi^KVonKViP0?onKViP03o`000?o<c<coc<c<01ooc<c<2Ol0000Zok>c/`Go00008oo<
c<`00ol0003oi^KVonKViP0?onKViP03o`000?oooooooooo0:_ooooo0Ol00001ooooo`7ooooo000^
ooooo`03o`000?oooooooooo00Kooooo00?o0000onKVi_oVi^H04?oVi^H2o`0002Soc<c<:_l0000W
olc<c003o`000?oVi^Koi^KV013oi^KV00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool0
02kooooo00?o0000ooooooooool01_ooool00ol0003oi^KVonKViP0AonKViP?o0000M?o<c<`3o`00
01?oi^KV00?o0000ooooooooool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000oooooooo
ool01_ooool00ol0003oi^KVonKViP0DonKViPCo0000KOo<c<`3o`0001Koi^KV00?o0000oooooooo
ool0Zoooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool01oooool00ol0003oi^KV
onKViP0GonKViPCo0000IOo<c<`4o`0001Soi^KV00?o0000ooooooooool0[?ooool1o`00007ooooo
0Oooool002kooooo00?o0000ooooooooool02?ooool00ol0003oi^KVonKViP0JonKViPGo0000G?o<
c<`4o`0001coi^KV00?o0000ooooooooool0[?ooool1o`00007ooooo0Oooool002kooooo00?o0000
ooooooooool02Oooool00ol0003oi^KVonKViP0NonKViPGo0000E?o<c<`3o`0001ooi^KV00?o0000
ooooooooool0[Oooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool02_ooool00ol0
003oi^KVonKViP0RonKViPWo0000@oo<c<`8o`0002;oi^KV00?o0000ooooooooool0[Oooool1o`00
007ooooo0Oooool002kooooo00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0ZonKViP_o
0000;Oo<c<`;o`0002Woi^KV00?o0000ooooooooool0[_ooool1o`00007ooooo0Oooool002kooooo
00?o0000ooooooooool02oooool00ol0003oi^KVonKViP0eonKViRgo0000=?oVi^H00ol0003ooooo
ooooo`2^ooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0<ooooo`03o`000?oV
i^Koi^KV09?oi^KV0_l0002aooooo`7o00000Oooool1ooooo`00;_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oVi^Koi^KV093oi^KV0_l0002cooooo`7o00000Oooool1ooooo`00;_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oVi^Koi^KV08coi^KV0ol0002eooooo`7o00000Oooool1oooo
o`00;_ooool00ol0003oooooooooo`0?ooooo`Co0000R?oVi^H2o`000;Sooooo0Ol00001ooooo`7o
oooo000Sooooo`Go00001_ooool00ol0003oooooooooo`0Cooooo`Go0000POoVi^H2o`000;[ooooo
0Ol00001ooooo`7ooooo000Sooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`0HoooooaGo0000F_oVi^HBo`000;cooooo0Ol00001ooooo`7ooooo000Tooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0;OoooomJo`000<kooooo0Ol00001ooooo`7ooooo000U
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooooeCooooo0ol00002ooooo`009_ooool00omg
MgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooE_ooool1o`00007ooooo0Oooool002Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooeKooooo0Ol00001ooooo`7o
oooo000Sooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3ooooooeKo
oooo0Ol00001ooooo`7ooooo000Sooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003o
ooooooooo`3ooooooeKooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooooooo0?oooooo
E_ooool1o`00007ooooo0Oooool002kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01[ooooo0Ol00001ooooo`7ooooo000^ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00;_ooooooo`0005[o
00000_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_ooool00?ooooooR_ooool00?oo
ooooR_ooool009Oooooo00Go8B4Qo`000?l0003oA4A4omgMg@1Tooooo`05ob4Q8Ol0003o0000odA4
A?oMgMd0Q?ooool009[ooooo00?oMgMgoc8b<_ooool0I_ooool00omgMgOo<S8booooo`23ooooo`00
Voooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo08;ooooo001gooooo`05ofIVI_l0
003o0000odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?ooooooV9RH00;o
000000GoMgMgoa0@4?l0003ooooooa0@4005o`0000?ooooo00Kok^k^oeEEEOl0003o410@olc<c?l0
0002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj1_ooool00ol@413o0000o`000002o`000004
oa0@4?ooooooooooooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj0_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001oooool5o`000003
ooooool@413o000000Co00000_ooool00ol@413o0000o`000003o`0000?ooooo00Kok^k^oeEEEOl0
003o0000odA4A?nj^[X2ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool01onHV9So0000
o`000?mgMgOo0000oa0@4?ooool01Ol00003ooooo`08oiRHV?l0003o0000ogMgMol@413o0000oooo
ool@4105o`0000Kooooo00?o410@o`000?n7QhL00_l000001OmVIVKok^k^ooooooo^k^koEEEE00;o
000000CoEEEEonk^k_oooooooooo0_l00002ooooo`;o0000BOooool007Kooooo00KoIVIVogMgMooo
ooooooooohN7Qol@4103ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003oc<c<onk^
k_n7QhOo000000Cooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`00
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4108ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Ko
EEEEogMgMoooooook^k^ogMgMol@4102ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003oooo
o`05o`000?nYZJWoooooohN7Qol000001?ooool00ol0003oooooooooo`03ooooo`05o`000?o<c<co
k^k^ohN7Qol000001?ooool00ol0003oooooooooo`08ooooo`09o`000?mEEEGok^k^oooooomgMgOo
IVIVoooooomEEEGoMgMg00;ooooo00[oMgMgoeEEEOooooooooooonk^k_lQ8B7oQhN7okZj^_l0003o
gMgMBOooool007Kooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooo
ooooooooooooonk^k_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Go410@ohN7Qoooooook^k^
o`000004ooooo`03o`000?oooooooooo00Sooooo00?o0000onk^k_ooool00_ooool00ol0003ooooo
o`000004ooooo`08o`000?oooooooooooooooooMgMgo0000oa0@4?o<c<a:ooooo`00M_ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00onj^[[o410@o`000002
o`0000Cooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo
1_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`06o`000?ooooooooooooooooo^
k^ko00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool6o`0000;ooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03okZj^_l@413o000000;o0000
1?ooool00ol0003oooooooooo`08ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool00000
1?ooool02?l0003oooooooooooooooook^k^ob4Q8Ol@413ok^k^B_ooool007Kooooo00KoIVIVogMg
MoooooooooooohN7Qol00003ooooo`05o`000?mgMgOoooooojVYZOl000001Oooool00oo<c<co0000
ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002oooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000[ooooo00?o0000
ooooooooool00oooool00ol0003o<S8bomgMg@05ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S82ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00oo<c<co0000ooooo`03
ooooo`03o`000?lb<S;ogMgM00Sooooo00Wo0000oeEEEOo^k^koooooogMgMomEEEGooooooeEEEOmg
MgL00_ooool00omgMgOoEEEEooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<T[ooooo001fooooo`06
onk^k_mVIVKo0000o`000?m4A4Co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00?ooooo00Co
<S8bo`000?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00[ok^k^oeEEEOl0
003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l000000om4A4Cok^k^ooooo`05ooooo`03oa0@
4?l0003o000000?o00000oooool00ol@413o0000o`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^oeEE
EOl0003o410@olc<c?l00008ooooo`03oa0@4?l0003o000000Cooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B42ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooool@413o00000_ooool2o`00
00Cooooo00?o0000ooooooooool01?ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVY
ob4Q8Ol0003o8B4Q1_ooool02Ol0003oc<c<oa0@4?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`00
0004oeEEEOo^k^koooooooooo`;o00000_ooool2o`0004Wooooo001oooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
05_ooooo001oooooo`03o`000?oooooooooo02[ooooo00?o410@okZj^_ooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Kooooo`00O_ooool00ol@413o0000ooooo`0[ooooo`04okZj^_l@413o0000oa0@40Go
oooo00?o410@ooooooooool00_ooool00ol@413o0000o`000005ooooo`03oa0@4?l0003o0000017o
oooo0_l0000:ooooo`03oa0@4?oooooooooo02[ooooo00?o410@o`000?l000006?ooool00ol@413o
0000ooooo`1Looooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:ooooo`00oooooon:oooo
o`00oooooon:ooooo`00oooooon:ooooo`00M_ooool3o`000003oa0@4?oooooooooo00;ooooo00Ko
k^k^oeEEEOl0003o0000oeEEEOo^k^h3ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_o^
k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooo
oooooonHV9P2o`000003odA4A?nj^[[ooooo00;ooooo1Ol00002ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool5o`0000Oooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co
410@ooooool@413o<S8b0_l000000ol@413oZJVYooooo`02ooooo`Go00000_ooool02_o^k^koEEEE
o`000?l0003oV9RHo`000?l@413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00Gooooo00Ko
V9RHo`000?l0003oMgMgoa0@4?l0002>ooooo`00Moooool00ol0003oooooooooo`04ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4103ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool01Ol0003oc<c<onk^k_n7QhOo
000000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Gooooo00?o0000oooooooo
ool00_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMg
Mol@4106ooooo`05o`000?o<c<cok^k^ohN7Qol00000Soooool007Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Go410@ohN7Qoooooook^k^o`000005ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
^[ZjohN7QomVIVKoIVIVoa0@4005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo
ooooonk^k_l00002ooooo`03o`000?oooooooooo00Wooooo00Go410@ohN7Qoooooook^k^o`00002?
ooooo`00Moooool3o`000005ob4Q8Oo<c<coooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo1_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoa0@4?l000000_l00005ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h5ooooo`03o`000?oooooooooo00;ooooo00Ko0000
ooooooooooooooooonk^k_l00002ooooo`Ko00001_ooool00onj^[[o410@o`000002o`0008oooooo
001gooooo`05o`000?ooooooooooohN7Qol@41000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go
0000ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005
ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06oeEE
EOn7QhOok^k^oooooon7QhOo<S8b2Oooool00oo<c<co0000ooooo`2>ooooo`00Moooool01Ol0003o
oooooooooooooooo000000;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^kooooooa0@40Go0000
0oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000000onH
V9Sooooooa0@4005o`0000Cooooo00?o410@o`000?l000001Oooool01?lb<S;o0000o`000?nHV9P5
ooooo`03o`000?oooooooooo00Oooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02
o`000005oiRHV?ooooooooooojVYZOlQ8B400_l000000olb<S;o0000ooooo`02ooooo`03oa0@4?l0
003o000000Cooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^1oooool01?lb<S;o0000o`000?nHV9R?ooooo`00Moooool01Ol0003ooooooooooon7
QhOo410@00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0X?ooool007Kooooo1?l000000olQ8B7oc<c<ooooo`0:
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:3ooooo002Yooooo`03oa0@4?oooooooooo00[ooooo00?o410@o`00
0?l000002oooool00ol@413oooooooooo`0Eooooo`03oa0@4?oooooooooo00Kooooo0_l0002Roooo
o`00oooooon:ooooo`00oooooon:ooooo`00\
\>"],
  ImageRangeCache->{{{0, 392.812}, {524.062, 0}} -> {-0.240152, -0.178572, \
0.0056696, 0.0056696}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simultaneous Overrelaxation", "Subsubsection",
  CellTags->"i:34"],

Cell[TextData[{
  "The convergence of the Jacobi method is quite slow, rendering it \
impractical in most applications.  Furthermore, the larger the system, the \
slower the convergence. This is simply because we are solving a heat equation \
problem, and we know that for a system of size ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " the solution to the heat equation decays  toward equilibrium at a rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]/L\^2\)]],
  " [the order of magnitude of the lowest eigenvalue: see Eq. ",
  ButtonBox["(3.1.60)",
    ButtonData:>{"Chapter3.nb", "(3.1.60)"},
    ButtonStyle->"Hyperlink"],
  "]. Multiplying this rate  by our time step size ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", and using the Courant condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "~", " ", 
          FormBox[
            RowBox[{
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], "/", "\[Chi]"}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the grid spacing, we obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"1", "/", 
          RowBox[{"(", 
            RowBox[{"\[Nu]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], " ", ")"}]}], "=", " ", 
        RowBox[{"number", " ", "of", " ", "time", " ", 
          RowBox[{"steps", " ", "~", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"L", "/", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}], "2"]}]}]}], 
      TraditionalForm]]]], "UNNEQ"],

Cell["\<\
The number of time steps required to get a converged solution \
scales like the square of the number of grid points across the system. \
\>", \
"Text"],

Cell[TextData[{
  "\tIn order to improve on this poor scaling, various recipes have been put \
forward. One of the most successful is the method of ",
  StyleBox["simultaneous overrelaxation",
    FontSlant->"Italic"],
  ". In this algorithm, the Jacobi method is modified in two ways, shown in \
red in Eq. ",
  ButtonBox["(6.2.40)",
    ButtonData:>"(6.2.40)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j\ k\)\%\(n + 1\)\), "=", 
          RowBox[{
            StyleBox[\(\((1 - \[Omega])\) \[Phi]\_\(j\ k\)\%n\),
              FontColor->RGBColor[1, 0, 0]], "+", 
            RowBox[{
              FractionBox[
                StyleBox["\[Omega]",
                  FontColor->RGBColor[1, 0, 0]], "2"], 
              RowBox[{
                FractionBox[
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], "2"]}], 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]], "2"], "+", 
                    SuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["y",
                            FontSlant->"Italic"]}]], "2"]}]], "[", 
                RowBox[{\(-\[Rho]\_\(j\ k\)\), "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["x",
                              FontSlant->"Italic"]}]], "2"]], 
                    RowBox[{"(", 
                      RowBox[{\(\[Phi]\_\(j + 1\ k\)\%n\), "+", 
                        SubsuperscriptBox["\[Phi]", \(j - 1\ k\), 
                          RowBox[{" ", 
                            StyleBox[\(n + 1\),
                              FontColor->RGBColor[1, 0, 0]]}]]}], ")"}]}], 
                  "+", 
                  RowBox[{
                    FractionBox["1", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["y",
                              FontSlant->"Italic"]}]], "2"]], 
                    RowBox[{"(", 
                      RowBox[{\(\[Phi]\_\(j\ k + 1\)\%n\), "+", 
                        SubsuperscriptBox["\[Phi]", \(j\ k - 1\), 
                          RowBox[{" ", 
                            StyleBox[\(n + 1\),
                              FontColor->RGBColor[1, 0, 0]]}]]}], " ", 
                      ")"}]}]}], "]"}]}]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.40)"],

Cell[TextData[{
  "First, we use improved values for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the right-hand side as soon as they become available, in order to help \
improve the guess we are making for the next step.  This looks like an \
implicit method with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%\(n + 1\)\)]],
  " appearing on both sides, but it is not: assuming that we are stepping \
through the equations  from smaller to larger values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox["j",
              "TraditionalForm"], "and", 
            FormBox["k",
              "TraditionalForm"]}]}], TraditionalForm]]],
  ",  by the time we evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\%\(n + 1\)\)]],
  " we have already evaluated ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j - 1\ k\)\%\(n + 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k - 1\)\%\(n + 1\)\)]],
  ", so we can use these values on the ",
  "right-hand",
  " side. (Stepping through the grid is performed when we evaluate the error \
in the solution,  creating a table of the error at each grid point, just as \
in the Jacobi method. The steps in the table are performed from smaller to \
larger values of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tAlso, we have added terms involving a ",
  StyleBox["relaxation parameter ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". It has been proven that this parameter must take on a value in the range \
",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Omega] < 2\)]],
  " for the method to work.  This parameter is added in order to take \
advantage of the fact that the Jacobi method converges exponentially toward \
equilibrium  (it is a solution to the heat equation), and tries to overshoot \
the exponential decay and go directly to the final result in one step.  \
However, the rate of convergence of the SOR method depends sensitively on the \
choice of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", and there is no way to know the correct choice beforehand (without doing \
considerable extra work). This is the main weakness of the method. Typically, \
one must simply make a guess for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ".  However, even if the guess is not close to the optimum value, the SOR \
method usually works better than the Jacobi method, and is just as easy to \
program. We provide a module below, and use it to solve the same problem as \
we did previously :"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(SOR[\[Omega]_, Nstep_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[Phi]}\), ",", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              choose\ grid\ parameters\ and\ shape\ of\ region*) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(M\_x = 20\), ";", "\[IndentingNewLine]", \(M\_y = 20\), 
            ";", "\[IndentingNewLine]", \(L\_x = 1.5\), ";", 
            "\[IndentingNewLine]", \(L\_y = \ 2. \), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]x = L\_x/M\_x\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]y = L\_y/M\_y\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", \(g[k_]\  := M\_x\),
             ";", " ", \(k \[LessEqual] \ 5\), ";", 
            "\[IndentingNewLine]", \(g[k_]\  := \ 
              M\_x - k + 5 /; 5 < k < 15\), ";", 
            "\[IndentingNewLine]", \(g[k_]\  := \ 
              M\_x - 10\  /; \ k \[GreaterEqual] \ 15\), ";", 
            "\[IndentingNewLine]", \(f[k_]\ \  = \ 
              Floor[12 \((k/M\_y - 1)\)^2]\), ";", "\[IndentingNewLine]", 
            StyleBox[\( (*\ boundary\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, n_]\  := \ 
              0\  /; \ j \[LessEqual] \ f[k]\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, n_]\  := \ 
              0\  /; \ j \[GreaterEqual] \ g[k]\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, 0, n_]\  = \ 0\), ";", 
            "\[IndentingNewLine]", \(\[Phi][j_, M\_y, n_]\  = \ 0\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ charge\ density\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho][j_, k_] = \ 1\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ SOR\ recursion\ relation\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, 
                n_]\  := \ \(\[Phi][j, k, 
                  n]\  = \((1 - \[Omega])\) \[Phi][j, k, 
                      n - 1]\  + \ \[Omega]\ \(1\/2\) \
\(\(\(\[CapitalDelta]x\^2\) \[CapitalDelta]y\^2\)\/\((\[CapitalDelta]x\^2 + \
\[CapitalDelta]y\^2)\)\) \((\(-\[Rho][j, 
                            k]\) + \(1\/\[CapitalDelta]x\^2\) \((\[Phi][
                                j + 1, k, n - 1] + \[Phi][j - 1, k, 
                                n])\) + \(1\/\[CapitalDelta]y\^2\) \((\[Phi][
                                j, k + 1, n - 1] + \[Phi][j, k - 1, 
                                n]\ )\))\)\)\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                initial\ choice\ for\ \[Phi]\ to\ start\ the\ iteration\ *) \
\),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi][j_, k_, 0]\  = \ 0\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ define\ error\ at\ the\ nth\ step\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(error[n_]\  := \ 
              Max[Table[
                  Table[Abs[\[Phi][j, k, n] - \[Phi][j, k, n - 1]], {j, 
                      f[k] + 1, g[k] - 1}], {k, 1, M\_y - 1}]]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*evaluate\ error\ at\ step\ NStep*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Print["\<error at step NStep = \>", 
              error[Nstep]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                create\ interpolation\ function\ of\ solution\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi]sol\  = \ 
              Interpolation[
                Flatten[
                  Table[{j\ \[CapitalDelta]x, 
                      k\ \[CapitalDelta]y, \[Phi][j, k, Nstep]}, {j, 0, 
                      M\_x}, {k, 0, M\_y}], 1]]\)}]}], "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.116"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SOR[1.6, 30]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.117"],

Cell[BoxData[
    InterpretationBox[\("error at step NStep = \
"\[InvisibleSpace]4.1582873067103066`*^-7\),
      SequenceForm[ "error at step NStep = ", 4.1582873067103066*^-07],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.5`}, {0.`, 2.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "With the guess \[Omega]=1.6, the result has already converged within 30 \
steps, as compared to the 200 steps needed in the Jacobi method. The error is \
plotted in Cell ",
  ButtonBox["6.118",
    ButtonData:>"Cell 6.118",
    ButtonStyle->"Hyperlink"],
  ", showing faster convergence than the Jacobi method."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(LogLogListPlot[Table[{n, error[n]}, {n, 1, 30}], 
        AxesLabel \[Rule] {"\<n\>", "\<error[n]\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.118"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.644755 0.846729 0.130387 [
[.02381 -0.0125 -5 -12 ]
[.02381 -0.0125 5 0 ]
[.2179 -0.0125 -5 -12 ]
[.2179 -0.0125 5 0 ]
[.47447 -0.0125 -5 -12 ]
[.47447 -0.0125 5 0 ]
[.66856 -0.0125 -8 -12 ]
[.66856 -0.0125 8 0 ]
[.86265 -0.0125 -8 -12 ]
[.86265 -0.0125 8 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .0644 -47.0625 -6.40625 ]
[-0.0125 .0644 0 6.40625 ]
[-0.0125 .19479 -46 -6 ]
[-0.0125 .19479 0 6 ]
[-0.0125 .32518 -40 -6 ]
[-0.0125 .32518 0 6 ]
[-0.0125 .45557 -34 -6 ]
[-0.0125 .45557 0 6 ]
[-0.0125 .58595 -28 -6 ]
[-0.0125 .58595 0 6 ]
[0 .64303 -26 0 ]
[0 .64303 26 12 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.2179 0 m
.2179 .00625 L
s
gsave
.2179 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.47447 0 m
.47447 .00625 L
s
gsave
.47447 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.66856 0 m
.66856 .00625 L
s
gsave
.66856 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.86265 0 m
.86265 .00625 L
s
gsave
.86265 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.33144 0 m
.33144 .00375 L
s
.41199 0 m
.41199 .00375 L
s
.52553 0 m
.52553 .00375 L
s
.56869 0 m
.56869 .00375 L
s
.60608 0 m
.60608 .00375 L
s
.63906 0 m
.63906 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0644 m
.00625 .0644 L
s
gsave
-0.0125 .0644 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.8125 translate 1 -1 scale
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.812 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
100.812 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
105.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .19479 m
.00625 .19479 L
s
gsave
-0.0125 .19479 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .32518 m
.00625 .32518 L
s
gsave
-0.0125 .32518 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .45557 m
.00625 .45557 L
s
gsave
-0.0125 .45557 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .58595 m
.00625 .58595 L
s
gsave
-0.0125 .58595 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .10365 m
.00375 .10365 L
s
0 .12661 m
.00375 .12661 L
s
0 .1429 m
.00375 .1429 L
s
0 .15554 m
.00375 .15554 L
s
0 .16587 m
.00375 .16587 L
s
0 .17459 m
.00375 .17459 L
s
0 .18216 m
.00375 .18216 L
s
0 .18883 m
.00375 .18883 L
s
0 .23404 m
.00375 .23404 L
s
0 .257 m
.00375 .257 L
s
0 .27329 m
.00375 .27329 L
s
0 .28593 m
.00375 .28593 L
s
0 .29625 m
.00375 .29625 L
s
0 .30498 m
.00375 .30498 L
s
0 .31254 m
.00375 .31254 L
s
0 .31921 m
.00375 .31921 L
s
0 .36443 m
.00375 .36443 L
s
0 .38739 m
.00375 .38739 L
s
0 .40368 m
.00375 .40368 L
s
0 .41632 m
.00375 .41632 L
s
0 .42664 m
.00375 .42664 L
s
0 .43537 m
.00375 .43537 L
s
0 .44293 m
.00375 .44293 L
s
0 .4496 m
.00375 .4496 L
s
0 .49482 m
.00375 .49482 L
s
0 .51778 m
.00375 .51778 L
s
0 .53407 m
.00375 .53407 L
s
0 .5467 m
.00375 .5467 L
s
0 .55703 m
.00375 .55703 L
s
0 .56576 m
.00375 .56576 L
s
0 .57332 m
.00375 .57332 L
s
0 .57999 m
.00375 .57999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(error) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.2179 .60011 Mdot
.33144 .59603 Mdot
.41199 .591 Mdot
.47447 .58505 Mdot
.52553 .57787 Mdot
.56869 .56965 Mdot
.60608 .55983 Mdot
.63906 .5482 Mdot
.66856 .53415 Mdot
.69525 .51612 Mdot
.71962 .49177 Mdot
.74203 .45054 Mdot
.76278 .43002 Mdot
.7821 .40959 Mdot
.80017 .38977 Mdot
.81715 .36763 Mdot
.83315 .34376 Mdot
.84829 .31598 Mdot
.86265 .28737 Mdot
.87632 .25676 Mdot
.88934 .22582 Mdot
.90179 .20237 Mdot
.91371 .18123 Mdot
.92514 .15746 Mdot
.93612 .13133 Mdot
.94669 .10363 Mdot
.95687 .07027 Mdot
.9667 .04513 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@oooool4
o`000003oa0@4?oooooooooo02gooooo1Ol00014ooooo`05odA4A?l0003o0000oc8b<_oMgMd0;Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hXooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Gooooo0015ooooo`03o`000?oooooooooo02oooooo00GoV9RHob4Q
8Oo^k^koooooodA4A017ooooo`03ogMgMolb<S;ooooo02kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0=Oooool004Gooooo00?o0000ooooooooool0<?ooool00onHV9So8B4Q
onk^kP19ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@02Wooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
03Gooooo0015ooooo`03o`000?oooooooooo037ooooo00?oV9RHob4Q8Oo^k^h0Aoooool00omgMgOo
<S8booooo`0^ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zoooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000eooooo`00AOooool00ol0
003oooooooooo`0booooo`03ogMgMomVIVKooooo04?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00_
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000[ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000eooooo`00AOooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100;?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool0<oooool004Gooooo00?o0000ooooooooool0;oooool01Ol0003o^[Zj
oooooonHV9So410@04Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0:?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0eooooo`00@oooool00omEEEGoIVIVo`00000aooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`0A?ooool4o`0002kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h0=Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooGoooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo007ooooo003oooooof3ooooo00Go0000
ooooooooooooooooo`000004ooooo`00?_ooooooo`0001Oo00002oooool01Ol0003ooooooooooooo
oooo000000Cooooo000nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00
0004ooooo`00?_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0;oooool01Ol0003oQhN7oooooonYZJWo000000Cooooo000nooooo`03o`000?oooooo
oooo0?oooooo7_ooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00;ooooo000noooo
o`03o`000?oooooooooo0?oooooo3?ooool2o`0001[ooooo000nooooo`03o`000?oooooooooo0?oo
oooo3?ooool2o`0001[ooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o
0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00
?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo2Ooo
ool2o`0001gooooo000nooooo`03o`000?oooooooooo0?oooooo2Oooool2o`0001gooooo000Coooo
o`;ok^k^0oooool2onk^kRCooooo00?o0000ooooooooool0oooooolXooooo`001?ooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00?o0000oooooooo
ool0oooooolXooooo`001_ooool00ol0003oooooooooo`04ooooo`;o8B4Q1Oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01?ooooo00?o0000ooooooooool0oooooolXooooo`001_ooool00ol0003oooooooooo`0<ooooo`03
omgMgOl0003ogMgM00Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
01?ooooo00?o0000ooooooooool0oooooolXooooo`001_ooool00ol0003oooooooooo`0;ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h02?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004oooool3o`000?oooooo:?ooool000Kooooo00?o0000ooooooooool02_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000004oooool00ol0003oooooooooo`3oooooo`Oooooo0_l0000Oooooo`001_oo
ool00ol0003oooooooooo`0:ooooo`;ok^k^0oooool2onk^kPOooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Oooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
1oooool2o`0001oooooo0006ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`3oooooobSooooo0004ooooo`03oeEEEOmVIVKo000001Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1Ol00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolXooooo`00<Oooool3o`0000[ooooo00?o0000ooooooooool0
oooooolXooooo`00<_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo:?oo
ool003?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3oooooobSooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00
?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000ooooool5ooooo`;o00008_oo
ool003kooooo00?o0000ooooooooool0ooooool4ooooo`;o00008_ooool003kooooo00?o0000oooo
ooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`00
0?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool0
0ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000ooooool2ooooo`;o00009Oooool003ko
oooo00?o0000ooooooooool0ooooool1ooooo`;o00009Oooool003kooooo00?o0000ooooooooool0
oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolY
ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oo
oooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool2o`000?kooooo0_l0
000Xooooo`00?_ooool00ol0003oooooooooo`3mooooo`;o0000:?ooool003kooooo0_l0003ooooo
obWooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0
oooooolXooooo`00?_ooool2o`000?oooooo:Oooool003kooooo00?o0000ooooooooool0n_ooool2
o`0002_ooooo000nooooo`;o0000noooool2o`0002_ooooo0004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooobSo
oooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
0_l0003oooooobWooooo0004ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ool3o`000?oooooo:?ooool000Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo:?ooool000Cooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?Kooooo0_l0000_ooooo`001?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m_ooool2o`0002oo
oooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooobSooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool0
03kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSo
oooo000nooooo`03o`000?oooooooooo0??ooooo0_l0000booooo`00?_ooool00ol0003ooooooooo
o`3cooooo`;o0000<_ooool003kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo
0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003ooooo
ooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000
ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3_ooooo`;o0000=_ooool003ko
oooo0_l0003`ooooo`;o0000=_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool0
03kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo
00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`;o0000k?ooool2o`0003[ooooo000nooooo`03o`000?oooooooooo0>_ooooo0_l0000joooo
o`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`00?_oo
ool00ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`;o0000oooooolYooooo`003?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3Wooooo`;o0000?_ooool000cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`04ooooo`;o0000j?ooool2o`0003kooooo000<ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo:?ooool000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooobSooooo000<oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo:?ooool000cooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooolXooooo`003?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
obSooooo000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0>?ooooo0_l00012ooooo`00?_oo
ool00ol0003oooooooooo`3Sooooo`;o0000@_ooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oo
oooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool2o`000?oooooo:Ooo
ool003kooooo00?o0000ooooooooool0goooool2o`0004Kooooo000nooooo`03o`000?oooooooooo
0=oooooo0_l00016ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`00
0?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool0
0ol0003oooooooooo`3oooooobSooooo000nooooo`;o0000foooool2o`0004_ooooo000nooooo`03
o`000?oooooooooo0=[ooooo0_l0001;ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo
000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo0_l0003oooooobWooooo000noooo
o`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0eOooool2o`00053o
oooo000nooooo`03o`000?oooooooooo0=Gooooo0_l0001@ooooo`00?_ooool2o`000?oooooo:Ooo
ool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3ooooo
obSooooo000nooooo`;o0000dOooool2o`0005Gooooo000nooooo`03o`000?oooooooooo0=3ooooo
0_l0001Eooooo`00?_ooool2o`000?oooooo:Oooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00?_ooool2o`000?oooooo:Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo000C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ooooo`;o
0000boooool2o`0005_ooooo000Cooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0b_ooool2o`0005_ooooo000Cooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Gooooo0ol0003oooooobSooooo000Cooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolXoooo
o`004oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo:?ooool001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooobSooooo000Cooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo
00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`03o`000?oooooooooo0<Cooooo0_l0001Qooooo`00?_ooool00ol0003oooooooooo`34oooo
o`;o0000HOooool003kooooo0_l0003oooooobWooooo000nooooo`03o`000?oooooooooo0?oooooo
:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3o
ooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000oooooooo
ool0_Oooool2o`0006Sooooo000nooooo`;o0000__ooool2o`0006Sooooo000nooooo`03o`000?oo
oooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`;o0000]oooool2o`0006oooooo000nooooo`03o`00
0?oooooooooo0;Kooooo0_l0001_ooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000n
ooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo0_l0002^ooooo`;o0000N?ooool003ko
oooo00?o0000ooooooooool0[Oooool2o`0007Sooooo000nooooo`03o`000?oooooooooo0?oooooo
:?ooool003kooooo0_l0002Uooooo`;o0000POooool003kooooo00?o0000ooooooooool0Y?ooool2
o`00087ooooo000nooooo`;o0000oooooolYooooo`00?_ooool00ol0003oooooooooo`2Jooooo`;o
0000Roooool003kooooo0_l0002Kooooo`;o0000Roooool001_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo08kooooo0_l0002Gooooo`006oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`05ooooo`;o0000Soooool2o`0009Oooooo000Kooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`20ooooo`;o0000YOooool001_ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`?o0000P?oo
ool2o`000:Gooooo000Kooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1^ooooo`;o0000
]oooool001_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo0_l0000Dooooo`;o
0000]oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo0_l0000Moooo
o`;o0000cOooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo00?ooooo0_l0000d
ooooo`;o0000k?ooool003kooooo00?o0000ooooooooool00oooool2o`000?oooooo8oooool003ko
oooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo
000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00BOooool2o`0000_ooooo0_l0
003ooooooa7ooooo0019ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool?
ooooo`008Oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00002ooooo`03oa0@
4?l0003o000000?o00000oooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413ooooooooo
ool0003ooooooa7ooooo000Qooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3oooooo`oooooo000Qooooo`Ko00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0ooooool?ooooo`008Oooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01Oooool00ol0003o<S8bomgMg@04oooo
o`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo0?oooooo
3oooool0027ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0
003o8B4Q0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool00ol0003oooooooooo`02ooooo`03
oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooooooooo`00003ooooooa7ooooo0019ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool?ooooo`00BOooool2o`0000_ooooo
0_l0003ooooooa7ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.385391, -7.13773, \
0.00699214, 0.0345757}}]
}, Open  ]],

Cell[TextData[{
  "A description of the theory behind SOR, and further references, can be \
found in ",
  ButtonBox["Press et al. (1992)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".  The reader is invited to vary the parameter \[Omega], the shape of the \
region and the boundary conditions in order to examine the convergence \
properties of the method."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT Method", "Section",
  CellTags->{"i:36", "c:26"}],

Cell[TextData[{
  "Solution of Poisson's equation within a rectangle (or a 3D box) can be \
efficiently performed using the analytic trigonometric Fourier series methods \
discussed in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ". However, for high-accuracy results, the number of terms kept in the \
series in each dimension must be large, and the total number of terms in the \
series is the square (in 2D) or cube (in 3D) of this large number. Evaluation \
of the enormous list of Fourier coefficients can be most rapidly accomplished \
using the FFT methods discussed in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  However, use of the FFT requires that we discretize the potential on a \
grid. "
}], "Text"],

Cell[TextData[{
  "\tAs an example, consider the Poisson equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \[Rho]\)]],
  " with periodic boundary conditions in a rectangular box with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_y\)]],
  ". The density and potential are discretized on  the usual rectangular \
grid, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\_x\ , \)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\), "=", 
          RowBox[{"k", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, 2,  ... , M\_y\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "=", \(L\_x/M\_x\)}],
              "TraditionalForm"], "and", 
            RowBox[{
              FormBox[
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "=", \(L\_y/M\_y\)}],
                "TraditionalForm"], "."}]}]}], TraditionalForm]]],
  " Then the density and potential at the grid point ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  " can be written in terms of a double discrete inverse Fourier transform in \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", using Eq. ",
  ButtonBox["(2.3.63)",
    ButtonData:>{"Chapter2.nb", "(2.3.63)"},
    ButtonStyle->"Hyperlink"],
  " (changed to use Fourier conventions for spatial transforms):"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Rho]\_\(j\ k\) = \[Sum]\+\(m = 0\)\%\(M\_x - 1\)\ \(\
\[Sum]\+\(n = 0\)\%\(M\_y - 1\)\ \(\[Rho]\&~\_\(m\ n\)\) \
\(\[ExponentialE]\^\(\(\ \ \)\(2\ \[Pi]\ \[ImaginaryI]\ m\ \ j/
                    M\_x\)\)\) \[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\ \
\[ImaginaryI]\ n\ \ k/M\_y\)\)\)\)]]], "NE2",
  CellTags->"(6.2.41)"],

Cell["and", "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\) = \[Sum]\+\(m = 0\)\%\(M\_x - 1\)\ \
\(\[Sum]\+\(n = 0\)\%\(M\_y - 1\)\ \(\[Phi]\&~\_\(m\ n\)\) \
\(\[ExponentialE]\^\(2\ \[Pi]\ \[ImaginaryI]\ m\ \ j/
                      M\_x\)\) \[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\
\ \ \[ImaginaryI]\ n\ \ k/M\_y\)\)\)\)], "NE2"], "NE2"],
  StyleBox[".", "NE2"]
}], "NE2",
  CellTags->"(6.2.42)"],

Cell[TextData[{
  "If we substitute these expressions into the discretized Poisson equation \
",
  ButtonBox["(6.2.34)",
    ButtonData:>"(6.2.34)",
    ButtonStyle->"Hyperlink"],
  ", and use orthogonality of the separate Fourier modes, we find that the \
Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&~\_\(m\ n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " are related according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Phi]\&~\_\(m\ n\)\), "(", 
            RowBox[{
              
              FractionBox[\(\[ExponentialE]\^\(\(\ \)\(2\ \[Pi]\ \
\[ImaginaryI]\ m\ /M\_x\)\) - 
                  2\  + \ \[ExponentialE]\^\(\(-2\)\ \[Pi]\ \[ImaginaryI]\ m\ \
/M\_x\)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], "+", 
              
              FractionBox[\(\[ExponentialE]\^\(2\ \[Pi]\ \[ImaginaryI]\ n\ /M\
\_y\) - 2\  + \ \[ExponentialE]\^\(\(-2\)\ \[Pi]\[ImaginaryI]\ n\ /M\_y\)\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "2"]]}], ")"}], 
          "=", \(\[Rho]\&~\_\(m\ n\)\)}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell["or in other words,", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi]\&~\_\(m\ n\)\  = \(-\(\[Rho]\&~\_\(m\ n\)\/\(\(\
\(\[Kappa]\^2\)(m, n)\)\(\ \)\)\)\)\)]]], "NE2",
  CellTags->"(6.2.43)"],

Cell["where", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Kappa]\^2\)(m, n)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ m/M\_x)\)}], " ", "+", 
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ n/M\_y)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "We can then use this expression in Eq. ",
  ButtonBox["(6.2.42)",
    ButtonData:>"(6.2.42)",
    ButtonStyle->"Hyperlink"],
  " to evaluate the potential at each grid point. Thus, our strategy will be \
to: "
}], "Text"],

Cell[TextData[{
  "(a) Compute the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " by a FFT."
}], "Text"],

Cell[TextData[{
  "(b) Determine the Fourier coefficients of the potential via Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  ""
}], "Text"],

Cell[TextData[{
  "(c) Perform an inverse FFT to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  ". We can then interpolate, if we wish, to determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " at any point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " in the rectangle."
}], "Text"],

Cell[TextData[{
  "\tBecause of the centered-difference method used, the error in this method \
scales roughly as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\^2\), 
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is the dominant wavenumber in the density and potential. One can see this \
directly in Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  ". For low wavenumbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\  \[TildeTilde] k\^2\)]],
  " and Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " correctly yields the Fourier transformed Poisson equation,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&~ = \(-\[Rho]\&~\)/k\^2\)]],
  ". However, if the density is dominated by wavenumbers on the order of the \
grid spacing, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " is not close to ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  "and the FFT method fails."
}], "Text"],

Cell[TextData[{
  "\tBefore we proceed, we note that Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " blows up for ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(m = 0\)\)]],
  ". This is because, for periodic boundary conditions, constant charge \
density (the ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[{
            Cell[BoxData[
                \(TraditionalForm\`m = \(n = 0\)\)]],
            " "
          }]]}], TraditionalForm]]],
  "term) creates an infinite potential :  the uniform charge density \
stretches to infinity in both ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions in the periodically replicated boxes, creating an infinite \
potential. Therefore, when using periodic boundary conditions, we require \
that this term in the charge density vanish, so that the net charge density \
in the box  is  zero. "
}], "Text"],

Cell[TextData[{
  "\tFirst, we set the parameters of the grid, taking a rather fine grid in \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " to illustrate the speed of the method:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(M\_x = \(M\_y = 50\);\)\), "\n", 
    \(\(\(L\_x = \(L\_y = 1\);\)\(\n\)
    \)\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y;\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.119"],

Cell[TextData[{
  "This corresponds to a discrete Fourier series with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2500\)\(\ \)\)\)]],
  " terms, which would be quite time-consuming to evaluate using a standard \
Fourier series expansion. For fine grids, the FFT method is also more \
efficient than the direct or relaxation methods discusssed previously."
}], "Text"],

Cell["\t  Next, we choose a charge density:", "Text"],

Cell[BoxData[
    \(\(\[Rho][x_, y_]\  = \ 
        x\ Sin[Pi\ x]\ Sin[Pi\ y] - 2\ /Pi^2\ ;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.120"],

Cell["\<\
As required by our periodic boundary conditions, this charge \
density has a zero average, as can be seen by evaluating the integral over \
the box:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[\ \[Rho][x, y], {x, 0, L\_x}, {y, 0, L\_y}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.121"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The charge density is plotted in Cell ",
  ButtonBox["6.122",
    ButtonData:>"Cell 6.122",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Rho][x, y], {x, 0, 1}, {y, 0, 1}, 
        PlotLabel \[Rule] "\<\[Rho][x,y]\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.122"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.2768e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02396 .26606 -24 -2.74312 ]
[.02396 .26606 0 6.25688 ]
[.01223 .33957 -6 -2.80532 ]
[.01223 .33957 0 6.19468 ]
[-7e-05 .41668 -18 -2.87087 ]
[-7e-05 .41668 0 6.12913 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03619 .26128 m
.0423 .2589 L
s
[(-0.2)] .02396 .26606 1 -0.39042 Mshowa
.02451 .33495 m
.03065 .33263 L
s
[(0)] .01223 .33957 1 -0.3766 Mshowa
.01227 .41221 m
.01844 .40998 L
s
[(0.2)] -7e-05 .41668 1 -0.36203 Mshowa
.125 Mabswid
.03332 .27938 m
.03699 .27795 L
s
.03042 .29768 m
.03409 .29627 L
s
.02748 .3162 m
.03116 .3148 L
s
.02151 .35391 m
.0252 .35254 L
s
.01846 .37311 m
.02216 .37175 L
s
.01539 .39254 m
.01908 .39119 L
s
.00911 .43212 m
.01282 .43079 L
s
.00592 .45228 m
.00963 .45097 L
s
.00268 .47269 m
.0064 .47139 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.651 .738 .913 r
.38313 .58323 .40512 .60371 .44189 .59268 .42017 .5731 Metetra
.624 .742 .931 r
.42017 .5731 .44189 .59268 .47916 .5815 .45772 .56506 Metetra
.585 .767 .966 r
.45772 .56506 .47916 .5815 .51695 .57017 .49585 .55881 Metetra
.509 .803 .999 r
.49585 .55881 .51695 .57017 .55526 .55867 .53465 .55383 Metetra
.343 .795 .95 r
.53465 .55383 .55526 .55867 .59412 .54701 .57418 .54941 Metetra
.57418 .54941 .59412 .54701 .63352 .53519 .61445 .54472 Metetra
.131 0 0 r
.61445 .54472 .63352 .53519 .67349 .5232 .65544 .53887 Metetra
.227 0 0 r
.65544 .53887 .67349 .5232 .71403 .51104 .6971 .53096 Metetra
.249 0 0 r
.6971 .53096 .71403 .51104 .75515 .4987 .73931 .52017 Metetra
.217 0 0 r
.73931 .52017 .75515 .4987 .79688 .48619 .78193 .50584 Metetra
.12 0 0 r
.78193 .50584 .79688 .48619 .83921 .47349 .82482 .48755 Metetra
.82482 .48755 .83921 .47349 .88217 .4606 .86781 .46517 Metetra
.513 .902 .752 r
.86781 .46517 .88217 .4606 .92578 .44752 .91077 .43888 Metetra
.788 .949 .926 r
.91077 .43888 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.639 .735 .918 r
.36056 .56222 .38313 .58323 .42017 .5731 .39788 .55293 Metetra
.581 .728 .944 r
.39788 .55293 .42017 .5731 .45772 .56506 .43566 .54791 Metetra
.495 .731 .978 r
.43566 .54791 .45772 .56506 .49585 .55881 .47408 .54658 Metetra
.349 .724 .986 r
.47408 .54658 .49585 .55881 .53465 .55383 .51329 .54794 Metetra
.115 .644 .871 r
.51329 .54794 .53465 .55383 .57418 .54941 .55339 .55064 Metetra
.125 0 0 r
.55339 .55064 .57418 .54941 .61445 .54472 .59445 .55304 Metetra
.252 0 0 r
.59445 .55304 .61445 .54472 .65544 .53887 .63641 .55334 Metetra
.281 0 0 r
.63641 .55334 .65544 .53887 .6971 .53096 .67914 .54972 Metetra
.245 0 0 r
.67914 .54972 .6971 .53096 .73931 .52017 .72244 .54049 Metetra
.149 0 0 r
.72244 .54049 .73931 .52017 .78193 .50584 .766 .52431 Metetra
.766 .52431 .78193 .50584 .82482 .48755 .8095 .50037 Metetra
.8095 .50037 .82482 .48755 .86781 .46517 .85263 .46846 Metetra
.754 .991 .787 r
.85263 .46846 .86781 .46517 .91077 .43888 .8951 .4291 Metetra
.887 .938 .843 r
.8951 .4291 .91077 .43888 .95362 .4092 .93675 .38345 Metetra
.628 .732 .922 r
.33741 .54067 .36056 .56222 .39788 .55293 .375 .5321 Metetra
.535 .71 .952 r
.375 .5321 .39788 .55293 .43566 .54791 .41298 .52981 Metetra
.397 .683 .976 r
.41298 .52981 .43566 .54791 .47408 .54658 .45162 .53295 Metetra
.187 .621 .944 r
.45162 .53295 .47408 .54658 .51329 .54794 .49114 .54014 Metetra
0 .497 .788 r
.49114 .54014 .51329 .54794 .55339 .55064 .53173 .54943 Metetra
.253 0 0 r
.53173 .54943 .55339 .55064 .59445 .55304 .57346 .55846 Metetra
.32 0 0 r
.57346 .55846 .59445 .55304 .63641 .55334 .61628 .56455 Metetra
.296 0 0 r
.61628 .56455 .63641 .55334 .67914 .54972 .66003 .56498 Metetra
.2 0 0 r
.66003 .56498 .67914 .54972 .72244 .54049 .70437 .55721 Metetra
.018 0 0 r
.70437 .55721 .72244 .54049 .766 .52431 .74888 .53924 Metetra
.74888 .53924 .766 .52431 .8095 .50037 .79306 .50987 Metetra
.648 .935 .675 r
.79306 .50987 .8095 .50037 .85263 .46846 .83645 .46892 Metetra
.883 .992 .782 r
.83645 .46892 .85263 .46846 .8951 .4291 .87864 .4173 Metetra
.93 .908 .778 r
.87864 .4173 .8951 .4291 .93675 .38345 .91939 .35695 Metetra
.618 .729 .926 r
.31365 .51855 .33741 .54067 .375 .5321 .3515 .51054 Metetra
.493 .692 .957 r
.3515 .51054 .375 .5321 .41298 .52981 .38966 .5105 Metetra
.306 .63 .962 r
.38966 .5105 .41298 .52981 .45162 .53295 .42847 .51741 Metetra
.06 .523 .894 r
.42847 .51741 .45162 .53295 .49114 .54014 .46823 .52956 Metetra
0 .389 .736 r
.46823 .52956 .49114 .54014 .53173 .54943 .50919 .54451 Metetra
.313 0 0 r
.50919 .54451 .53173 .54943 .57346 .55846 .55147 .55927 Metetra
.338 0 0 r
.55147 .55927 .57346 .55846 .61628 .56455 .59503 .57041 Metetra
.264 0 0 r
.59503 .57041 .61628 .56455 .66003 .56498 .63967 .57438 Metetra
.087 0 0 r
.63967 .57438 .66003 .56498 .70437 .55721 .68498 .56786 Metetra
.68498 .56786 .70437 .55721 .74888 .53924 .73041 .54823 Metetra
.572 .916 .707 r
.73041 .54823 .74888 .53924 .79306 .50987 .77534 .51399 Metetra
.834 .997 .773 r
.77534 .51399 .79306 .50987 .83645 .46892 .81913 .46502 Metetra
.935 .955 .764 r
.81913 .46502 .83645 .46892 .87864 .4173 .86129 .40269 Metetra
.947 .877 .734 r
.86129 .40269 .87864 .4173 .91939 .35695 .90152 .32967 Metetra
.61 .726 .928 r
.28926 .49583 .31365 .51855 .3515 .51054 .32736 .48817 Metetra
.458 .675 .958 r
.32736 .48817 .3515 .51054 .38966 .5105 .36569 .48978 Metetra
.239 .583 .945 r
.36569 .48978 .38966 .5105 .42847 .51741 .40464 .49953 Metetra
0 .452 .859 r
.40464 .49953 .42847 .51741 .46823 .52956 .44457 .51544 Metetra
0 .332 .727 r
.44457 .51544 .46823 .52956 .50919 .54451 .4858 .53474 Metetra
.309 0 0 r
.4858 .53474 .50919 .54451 .55147 .55927 .5285 .55393 Metetra
.292 0 0 r
.5285 .55393 .55147 .55927 .59503 .57041 .57266 .56899 Metetra
.155 0 0 r
.57266 .56899 .59503 .57041 .63967 .57438 .61805 .57568 Metetra
.126 .675 .75 r
.61805 .57568 .63967 .57438 .68498 .56786 .66422 .57006 Metetra
.498 .907 .856 r
.66422 .57006 .68498 .56786 .73041 .54823 .71053 .54902 Metetra
.781 .997 .859 r
.71053 .54902 .73041 .54823 .77534 .51399 .75623 .51079 Metetra
.908 .969 .803 r
.75623 .51079 .77534 .51399 .81913 .46502 .80058 .45536 Metetra
.948 .909 .747 r
.80058 .45536 .81913 .46502 .86129 .40269 .843 .38451 Metetra
.95 .851 .708 r
.843 .38451 .86129 .40269 .90152 .32967 .88312 .30158 Metetra
.605 .725 .93 r
.2642 .4725 .28926 .49583 .32736 .48817 .30258 .46493 Metetra
.436 .663 .957 r
.30258 .46493 .32736 .48817 .36569 .48978 .34108 .46748 Metetra
.204 .553 .932 r
.34108 .46748 .36569 .48978 .40464 .49953 .38015 .47893 Metetra
0 .418 .847 r
.38015 .47893 .40464 .49953 .44457 .51544 .42022 .49716 Metetra
0 .32 .754 r
.42022 .49716 .44457 .51544 .4858 .53474 .46164 .51917 Metetra
0 .303 .714 r
.46164 .51917 .4858 .53474 .5285 .55393 .50464 .54113 Metetra
0 .384 .752 r
.50464 .54113 .5285 .55393 .57266 .56899 .54924 .55863 Metetra
.043 .569 .864 r
.54924 .55863 .57266 .56899 .61805 .57568 .59522 .56699 Metetra
.374 .797 .973 r
.59522 .56699 .61805 .57568 .66422 .57006 .6421 .56182 Metetra
.678 .93 .97 r
.6421 .56182 .66422 .57006 .71053 .54902 .6892 .53967 Metetra
.845 .941 .885 r
.6892 .53967 .71053 .54902 .75623 .51079 .73569 .49864 Metetra
.915 .906 .799 r
.73569 .49864 .75623 .51079 .80058 .45536 .78075 .43877 Metetra
.941 .865 .736 r
.78075 .43877 .80058 .45536 .843 .38451 .8237 .36217 Metetra
.947 .828 .694 r
.8237 .36217 .843 .38451 .88312 .30158 .86416 .27265 Metetra
.603 .724 .93 r
.23846 .44853 .2642 .4725 .30258 .46493 .27712 .44078 Metetra
.431 .658 .955 r
.27712 .44078 .30258 .46493 .34108 .46748 .31582 .44347 Metetra
.206 .543 .928 r
.31582 .44347 .34108 .46748 .38015 .47893 .35503 .45535 Metetra
.003 .419 .858 r
.35503 .45535 .38015 .47893 .42022 .49716 .39522 .47427 Metetra
0 .346 .802 r
.39522 .47427 .42022 .49716 .46164 .51917 .43678 .49711 Metetra
0 .356 .805 r
.43678 .49711 .46164 .51917 .50464 .54113 .47999 .51994 Metetra
.014 .454 .87 r
.47999 .51994 .50464 .54113 .54924 .55863 .52489 .53817 Metetra
.246 .615 .956 r
.52489 .53817 .54924 .55863 .59522 .56699 .57129 .54693 Metetra
.515 .762 .986 r
.57129 .54693 .59522 .56699 .6421 .56182 .61874 .54167 Metetra
.718 .835 .937 r
.61874 .54167 .6421 .56182 .6892 .53967 .66652 .5188 Metetra
.834 .849 .857 r
.66652 .5188 .6892 .53967 .73569 .49864 .71377 .47635 Metetra
.893 .839 .785 r
.71377 .47635 .73569 .49864 .78075 .43877 .75964 .41441 Metetra
.923 .824 .73 r
.75964 .41441 .78075 .43877 .8237 .36217 .8034 .33523 Metetra
.938 .809 .69 r
.8034 .33523 .8237 .36217 .86416 .27265 .84462 .24283 Metetra
.605 .725 .93 r
.212 .42389 .23846 .44853 .27712 .44078 .25096 .41566 Metetra
.441 .66 .954 r
.25096 .41566 .27712 .44078 .31582 .44347 .28991 .41766 Metetra
.242 .553 .931 r
.28991 .41766 .31582 .44347 .35503 .45535 .32931 .42866 Metetra
.081 .448 .881 r
.32931 .42866 .35503 .45535 .39522 .47427 .36965 .44653 Metetra
.013 .395 .85 r
.36965 .44653 .39522 .47427 .43678 .49711 .41135 .46823 Metetra
.054 .414 .863 r
.41135 .46823 .43678 .49711 .47999 .51994 .45469 .48988 Metetra
.19 .494 .903 r
.45469 .48988 .47999 .51994 .52489 .53817 .49978 .507 Metetra
.381 .598 .932 r
.49978 .507 .52489 .53817 .57129 .54693 .54646 .51483 Metetra
.567 .685 .92 r
.54646 .51483 .57129 .54693 .61874 .54167 .59429 .50891 Metetra
.707 .739 .876 r
.59429 .50891 .61874 .54167 .66652 .5188 .64261 .48572 Metetra
.801 .767 .822 r
.64261 .48572 .66652 .5188 .71377 .47635 .69057 .44334 Metetra
.861 .78 .771 r
.69057 .44334 .71377 .47635 .75964 .41441 .73732 .38187 Metetra
.9 .787 .728 r
.73732 .38187 .75964 .41441 .8034 .33523 .78211 .30346 Metetra
.925 .792 .694 r
.78211 .30346 .8034 .33523 .84462 .24283 .82447 .21208 Metetra
.61 .726 .928 r
.18479 .39856 .212 .42389 .25096 .41566 .22409 .38956 Metetra
.466 .668 .951 r
.22409 .38956 .25096 .41566 .28991 .41766 .26335 .39004 Metetra
.305 .578 .937 r
.26335 .39004 .28991 .41766 .32931 .42866 .30302 .39884 Metetra
.188 .493 .903 r
.30302 .39884 .32931 .42866 .36965 .44653 .34358 .41395 Metetra
.156 .452 .882 r
.34358 .41395 .36965 .44653 .41135 .46823 .38544 .43254 Metetra
.21 .463 .881 r
.38544 .43254 .41135 .46823 .45469 .48988 .42891 .45102 Metetra
.324 .511 .886 r
.42891 .45102 .45469 .48988 .49978 .507 .47411 .46522 Metetra
.459 .57 .879 r
.47411 .46522 .49978 .507 .54646 .51483 .52092 .47079 Metetra
.585 .624 .857 r
.52092 .47079 .54646 .51483 .59429 .50891 .56898 .46363 Metetra
.686 .667 .826 r
.56898 .46363 .59429 .50891 .64261 .48572 .61769 .44053 Metetra
.764 .701 .792 r
.61769 .44053 .64261 .48572 .69057 .44334 .66626 .3997 Metetra
.824 .728 .759 r
.66626 .3997 .69057 .44334 .73732 .38187 .71389 .34117 Metetra
.871 .753 .73 r
.71389 .34117 .73732 .38187 .78211 .30346 .75986 .26687 Metetra
.907 .776 .704 r
.75986 .26687 .78211 .30346 .82447 .21208 .80369 .18035 Metetra
.618 .729 .926 r
.1568 .3725 .18479 .39856 .22409 .38956 .19648 .36245 Metetra
.502 .681 .946 r
.19648 .36245 .22409 .38956 .26335 .39004 .23613 .36063 Metetra
.383 .609 .939 r
.23613 .36063 .26335 .39004 .30302 .39884 .27618 .366 Metetra
.306 .542 .914 r
.27618 .366 .30302 .39884 .34358 .41395 .31707 .37678 Metetra
.294 .504 .89 r
.31707 .37678 .34358 .41395 .38544 .43254 .35917 .39046 Metetra
.341 .501 .872 r
.35917 .39046 .38544 .43254 .42891 .45102 .40279 .40391 Metetra
.42 .519 .853 r
.40279 .40391 .42891 .45102 .47411 .46522 .44806 .41356 Metetra
.509 .549 .833 r
.44806 .41356 .47411 .46522 .52092 .47079 .49492 .41568 Metetra
.592 .582 .811 r
.49492 .41568 .52092 .47079 .56898 .46363 .54307 .40678 Metetra
.666 .616 .789 r
.54307 .40678 .56898 .46363 .61769 .44053 .592 .38412 Metetra
.73 .649 .769 r
.592 .38412 .61769 .44053 .66626 .3997 .64105 .34616 Metetra
.786 .684 .751 r
.64105 .34616 .66626 .3997 .71389 .34117 .68951 .29283 Metetra
.837 .72 .735 r
.68951 .29283 .71389 .34117 .75986 .26687 .73673 .22568 Metetra
.883 .759 .721 r
.73673 .22568 .75986 .26687 .80369 .18035 .78223 .14761 Metetra
.628 .732 .922 r
.128 .34568 .1568 .3725 .19648 .36245 .16809 .33434 Metetra
.544 .696 .939 r
.16809 .33434 .19648 .36245 .23613 .36063 .20824 .32953 Metetra
.465 .641 .933 r
.20824 .32953 .23613 .36063 .27618 .366 .2488 .3304 Metetra
.418 .586 .911 r
.2488 .3304 .27618 .366 .31707 .37678 .29015 .33546 Metetra
.414 .548 .881 r
.29015 .33546 .31707 .37678 .35917 .39046 .33261 .34269 Metetra
.443 .529 .851 r
.33261 .34269 .35917 .39046 .40279 .40391 .37646 .3496 Metetra
.49 .528 .823 r
.37646 .3496 .40279 .40391 .44806 .41356 .42181 .35336 Metetra
.543 .537 .798 r
.42181 .35336 .44806 .41356 .49492 .41568 .46865 .35106 Metetra
.597 .555 .778 r
.46865 .35106 .49492 .41568 .54307 .40678 .51677 .34001 Metetra
.649 .579 .763 r
.51677 .34001 .54307 .40678 .592 .38412 .56577 .31809 Metetra
.698 .608 .752 r
.56577 .31809 .592 .38412 .64105 .34616 .61516 .28405 Metetra
.748 .644 .746 r
.61516 .28405 .64105 .34616 .68951 .29283 .66434 .23777 Metetra
.797 .687 .743 r
.66434 .23777 .68951 .29283 .73673 .22568 .71279 .18031 Metetra
.849 .74 .743 r
.71279 .18031 .73673 .22568 .78223 .14761 .76008 .1138 Metetra
.639 .735 .918 r
.09834 .31807 .128 .34568 .16809 .33434 .13889 .30523 Metetra
.587 .71 .928 r
.13889 .30523 .16809 .33434 .20824 .32953 .17965 .29687 Metetra
.541 .669 .92 r
.17965 .29687 .20824 .32953 .2488 .3304 .22087 .29236 Metetra
.514 .622 .896 r
.22087 .29236 .2488 .3304 .29015 .33546 .26284 .29064 Metetra
.51 .582 .863 r
.26284 .29064 .29015 .33546 .33261 .34269 .30581 .29026 Metetra
.522 .553 .829 r
.30581 .29026 .33261 .34269 .37646 .3496 .34999 .28949 Metetra
.544 .537 .798 r
.34999 .28949 .37646 .3496 .42181 .35336 .39548 .2864 Metetra
.571 .533 .774 r
.39548 .2864 .42181 .35336 .46865 .35106 .44229 .27901 Metetra
.601 .539 .756 r
.44229 .27901 .46865 .35106 .51677 .34001 .49029 .26554 Metetra
.634 .553 .746 r
.49029 .26554 .51677 .34001 .56577 .31809 .53924 .24454 Metetra
.669 .576 .742 r
.53924 .24454 .56577 .31809 .61516 .28405 .58879 .21517 Metetra
.707 .608 .744 r
.58879 .21517 .61516 .28405 .66434 .23777 .63854 .17724 Metetra
.751 .654 .753 r
.63854 .17724 .66434 .23777 .71279 .18031 .68812 .13137 Metetra
.802 .716 .77 r
.68812 .13137 .71279 .18031 .76008 .1138 .73719 .07886 Metetra
.651 .738 .913 r
.0678 .28963 .09834 .31807 .13889 .30523 .10886 .27514 Metetra
.627 .722 .915 r
.10886 .27514 .13889 .30523 .17965 .29687 .15032 .26282 Metetra
.606 .69 .902 r
.15032 .26282 .17965 .29687 .22087 .29236 .19236 .25233 Metetra
.592 .65 .876 r
.19236 .25233 .22087 .29236 .26284 .29064 .23513 .24309 Metetra
.585 .609 .842 r
.23513 .24309 .26284 .29064 .30581 .29026 .27877 .23437 Metetra
.584 .574 .808 r
.27877 .23437 .30581 .29026 .34999 .28949 .32341 .22525 Metetra
.588 .55 .779 r
.32341 .22525 .34999 .28949 .39548 .2864 .36913 .21477 Metetra
.596 .535 .757 r
.36913 .21477 .39548 .2864 .44229 .27901 .41593 .20195 Metetra
.607 .53 .742 r
.41593 .20195 .44229 .27901 .49029 .26554 .46378 .1859 Metetra
.622 .535 .735 r
.46378 .1859 .49029 .26554 .53924 .24454 .51256 .16593 Metetra
.641 .549 .736 r
.51256 .16593 .53924 .24454 .58879 .21517 .56212 .14158 Metetra
.665 .576 .745 r
.56212 .14158 .58879 .21517 .63854 .17724 .61226 .11272 Metetra
.696 .618 .765 r
.61226 .11272 .63854 .17724 .68812 .13137 .66278 .07959 Metetra
.737 .684 .8 r
.66278 .07959 .68812 .13137 .73719 .07886 .71353 .04274 Metetra
.664 .741 .908 r
.03634 .26033 .0678 .28963 .10886 .27514 .07793 .24409 Metetra
.663 .732 .901 r
.07793 .24409 .10886 .27514 .15032 .26282 .12022 .22757 Metetra
.659 .707 .882 r
.12022 .22757 .15032 .26282 .19236 .25233 .16322 .21077 Metetra
.653 .67 .854 r
.16322 .21077 .19236 .25233 .23513 .24309 .20695 .19369 Metetra
.644 .631 .822 r
.20695 .19369 .23513 .24309 .27877 .23437 .25144 .17632 Metetra
.634 .595 .792 r
.25144 .17632 .27877 .23437 .32341 .22525 .29669 .15864 Metetra
.625 .565 .766 r
.29669 .15864 .32341 .22525 .36913 .21477 .34274 .14065 Metetra
.618 .543 .747 r
.34274 .14065 .36913 .21477 .41593 .20195 .3896 .12235 Metetra
.613 .529 .735 r
.3896 .12235 .41593 .20195 .46378 .1859 .43729 .10372 Metetra
.612 .524 .731 r
.43729 .10372 .46378 .1859 .51256 .16593 .48583 .08476 Metetra
.613 .529 .735 r
.48583 .08476 .51256 .16593 .56212 .14158 .53526 .06546 Metetra
.619 .545 .749 r
.53526 .06546 .56212 .14158 .61226 .11272 .58558 .0458 Metetra
.629 .578 .778 r
.58558 .0458 .61226 .11272 .66278 .07959 .63684 .02578 Metetra
.646 .638 .828 r
.63684 .02578 .66278 .07959 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00l_ooool4o`000003oa0@4?oooooooooo06oooooo003dooooo`03o`00
0?oooooooooo077ooooo003dooooo`03o`000?oooooooooo077ooooo003dooooo`03o`000?oooooo
oooo077ooooo003dooooo`03o`000?oooooooooo077ooooo003dooooo`03o`000?oooooooooo077o
oooo003dooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Uooooo`00
l_ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0IOooool00?kooooo
00Go410@oooooooooooooooooa0@401Uooooo`00o_ooool01Ol0003ooooooooooooooooo000006Go
oooo003nooooo`05o`000?ooooooooooooooool00000IOooool00?kooooo00Go410@oooooooooooo
oooooa0@401Uooooo`00n?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Uooooo`00
mOooool3o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Uooooo`00
loooool2o`0000?ooooo0ol0001]ooooo`00l?ooool3o`0000;ooooo0ol000001?nUXm?o0000oooo
ool0001/ooooo`00k_ooool2o`0000;ooooo0ol00004ojFSd`?o0000K?ooool00>_ooooo1?l00000
0ooooooo0000o`000007ojFSd`04o`000?nUXm?o0000o`0006_ooooo002eooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o0000
0_ooool3o`0000WoYJ?C00Go0000ojFSdol0003oooooo`00001Zooooo`00]Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407?ooool2o`00
00;ooooo0ol0000<ojFSd`03o`000?nUXm?oYJ?C00;o0000J_ooool00;Gooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006Oooool3o`0000;ooooo0_l0000?
ojFSd`04o`000?nUXm?oYJ?CojFSd`;o0000JOooool00;Gooooo00Go0000ooooooooooooooooo`00
000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805oooool2o`0000;ooooo0ol000000onQTlOo0000
ojFSd`0?ojFSd`03o`000?nUXm?oYJ?C00?o0000J?ooool00;Gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`05?ooool3o`0000;ooooo0_l00005oj6Ca`03
o`000?nUXm?oYJ?C00goYJ?C00Co0000ojFSdonUXm?oYJ?C0_l0001Xooooo`00]Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`;o00000_ooool3
o`0000OoXI?700?o0000ojFSdonUXm<03OnUXm<00ol0003oYJ?CojFSd`02ojFSd`;o0000Ioooool0
0;Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000003ooo
ool3o`0000;ooooo0_l0000;oj6Ca`03o`000?nUXm?oYJ?C00coYJ?C00?o0000ojFSdonUXm<00_nU
Xm<00ol0003oooooo`00001Vooooo`00]Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@0=ooooo`;o00000oooool2o`0000goXI?700?o0000ojFSdonUXm<0
3?nUXm<00ol0003oYJ?CojFSd`03ojFSd`;o0000I_ooool007?ooooo0_l00002ooooo`;o0000Fooo
ool4o`000004ooooool0003o0000o`0000ooXI?700?o0000ojFSdonUXm<03?nUXm<00ol0003oYJ?C
ojFSd`03ojFSd`?o0000IOooool007?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeIooooo`;o
00000oooool2o`0001?oXI?700?o0000ojFSdonUXm<02onUXm<00ol0003oYJ?CojFSd`02ojFSd`04
o`000?nl[lco0000o`0006Gooooo001dooooo`04omgMgOl0003o410@olc<c5Oooooo0ol00002oooo
o`?o000000?oWX^oo`000?nQTlL04_nQTlL00ol0003oYJ?CojFSd`0;ojFSd`05o`000?nUXm?oYJ?C
ojFSdol000000onl[l`2o`0006Cooooo001dooooo`04onk^k_lQ8B7o410@onk^kUCooooo0ol00003
ooooo`;o00001OnNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00[oYJ?C00Co0000
ojFSdol0003o00001Onl[l`2o`0006?ooooo001dooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0ol0
0002ooooo`?o00001onNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00[oYJ?C0_l0
0008okb_c003o`000?oooooooooo067ooooo001cooooo`;o00000_ooool2o`0004kooooo0ol00002
ooooo`?o00002onNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00WoYJ?C00?o0000
okb_c?nl[l`01onl[l`2o`0006;ooooo0035ooooo`;o00000oooool4o`0000coWX^o00?o0000oj6C
aonQTlL04OnQTlL00ol0003oYJ?CojFSd`07ojFSd`?o00002_nl[l`2o`00067ooooo0032ooooo`?o
00000oooool2o`00013oWX^o00?o0000oj6CaonQTlL04_nQTlL00ol0003oYJ?CojFSd`05ojFSd`04
o`000?nl[lco_:o<o`0000_o_:o<00?o0000ooooooooool0Goooool00<3ooooo0_l00003ooooo`?o
000000?oW8Nlo`000?nNRkl04?nNRkl00ol0003oXI?7oj6Ca`0Aoj6Ca`03o`000?nUXm?oYJ?C00Co
YJ?C00Go0000okb_c?nl[lco_:o<o`00000;okb_c0;o0000H?ooool008Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01oooooo0ol00000
0ooooooo0000o`000002o`0000GoW8Nl00?o0000oij;_onNRkl03_nNRkl00ol0003oXI?7oj6Ca`0A
oj6Ca`03o`000?nUXm?oYJ?C00;oYJ?C0_l00004okb_c003o`000?nl[lco_:o<00[o_:o<0_l0001O
ooooo`00ROooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B407Oooool2o`0000?ooooo0_l00008oib7_003o`000?nNRkooWX^o00ooWX^o00?o
0000oj6CaonQTlL04OnQTlL01?l0003oYJ?CojFSdol00007okb_c003o`000?nl[lco_:o<00[o_:o<
00?o0000ooooooooool0GOooool008Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000006_ooool3o`0000;ooooo0ol0000:oib7_003o`000?nNRkooWX^o00oo
WX^o00?o0000oj6CaonQTlL04OnQTlL00ol0003oYJ?Co`000008okb_c003o`000?nl[lco_:o<00_o
_:o<00?o0000ooooooooool0G?ooool008Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?nHV9SooooooiRHV?lQ8B406?ooool2o`0000;ooooo0ol0000>oib7_003o`000?nNRkooWX^o
00ooWX^o00?o0000oj6CaonQTlL04?nQTlL2o`0000Wo_:o<00?o0000okb_c?nl[l`02onl[l`2o`00
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00043ooooo0029oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Gooooo1?l0
00000ooooooo0000o`00000Aoib7_003o`000?nNRkooWX^o00ooWX^o00?o0000oj6CaonQTlL03onQ
TlL00ol0003o/Yk3o`000009okb_c003o`000?nl[lco_:o<00[o_:o<00?o0000olfgaOl000002?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0@?ooool008Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01Go
oooo0_l00002ooooo`?o000000?oW8Jko`000?nLQk`04?nLQk`00ol0003oWX^ooij;_`0?oij;_`03
o`000?nQTlOoXI?700goXI?70_l00003ok:N``03o`000?nl[lco_:o<00Ko_:o<00?o0000okb_c?nl
[l`02Onl[l`01Ol0003ocKO5olfgaOo=]lGo000000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^047ooooo0029ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV00Booooo`?o000000Coooooo`000?l0003o00001?nLQ[/00ol0003oW8Nloib7
_00@oib7_003o`000?nNRkooWX^o00ooWX^o00?o0000oj6CaonQTlL02_nQTlL2o`0000Go/Yk300?o
0000okb_c?nl[l`01_nl[l`00ol0003o_:o<okb_c008okb_c003o`000?o=]lGocKO500;ocKO50_l0
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP10ooooo`00ROoo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3Oooool3o`0000;o
oooo0_l00008oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl03onNRkl00ol0003o
XI?7oj6Ca`09oj6Ca`03o`000?nbW/?o/Yk300Ko/Yk300?o0000okb_c?nl[l`01Onl[l`00ol0003o
_:o<okb_c007okb_c003o`000?o=]lGocKO500CocKO500?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0?oooool00:Wooooo0ol000001?oooooo
0000o`000?l0000:oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl04?nNRkl00ol0
003oXI?7oj6Ca`06oj6Ca`;o00002OnbW/<00ol0003o_:o<okb_c005okb_c003o`000?nl[lco_:o<
00Ko_:o<00?o0000olfgaOo=]lD01_o=]lD00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`0nooooo`00Y_ooool3o`000004ooooool0003o0000
o`0000goW8Jk00?o0000oib7_?nLQk`04?nLQk`00ol0003oWX^ooij;_`0?oij;_`03o`000?nQTlOo
XI?700GoXI?700?o0000ok:N`onbW/<02_nbW/<00ol0003o_:o<okb_c004okb_c003o`000?nl[lco
_:o<00Go_:o<00?o0000olfgaOo=]lD01oo=]lD2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100@?ooool00:Cooooo0_l00002ooooo`;o00004OnL
Q[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o013oWX^o00?o0000oj6CaonQTlL00_nQ
TlL2o`0000go/Yk300?o0000okb_c?nl[l`01?nl[l`00ol0003o_:o<okb_c004okb_c003o`000?o=
]lGocKO500WocKO500?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c010ooooo`00XOooool3o`000006ooooool0003o0000o`000?nL
Qkco00004OnLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o013oWX^o00?o0000oj6C
aonQTlL00_l0000@ok:N``03o`000?nl[lco_:o<00?o_:o<00?o0000okb_c?nl[l`00onl[l`00ol0
003ocKO5olfga@0:olfga@;o0000F?ooool009oooooo0_l00002ooooo`;o00001OnLQk`00ol0003o
W8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl03onNRkl00ol0003o
XI?7o`00000Bok:N``03o`000?nl[lco_:o<00?o_:o<00?o0000okb_c?nl[l`00_nl[l`00ol0003o
cKO5olfga@0<olfga@;o0000Eoooool009cooooo0ol000001?oooooo0000o`000?l00007oib7_003
o`000?nLQ[_oW8Jk00ooW8Jk00?o0000oib7_?nLQk`03onLQk`00ol0003oWX^ooij;_`0?oij;_`;o
00005?nbW/<00ol0003o_:o<okb_c002okb_c005o`000?nl[lco_:o<okb_c?l000004?o=]lD00ol0
003oooooooooo`1Eooooo`00V_ooool2o`0000;ooooo0_l00002oib7_003o`000?nLQkcoW8Nl00Go
W8Nl00?o0000oib6^onLQ[/03onLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nNRkooWX^o00go
WX^o0_l000000onZTkko0000ok:N``0Cok:N``03o`000?nl[lco_:o<00;o_:o<00Co0000okb_c?nl
[lco00004Oo=]lD2o`0005Kooooo002Gooooo`?o000000Coooooo`000?l0003o00003OnLQk`00ol0
003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl02onNRkl00ol0
003oZY>nojZC_P02ojZC_P03o`000?nbW/?o/Yk301;o/Yk300Oo0000okb_c?nl[lco_:o<o`000?nl
[lco0000017ocKO500Co0000omVm__l0003o0000EOooool005oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01oooooo0_l00002ooooo`;o0000
4?nLQk`00ol0003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl00ooW8Nl00?o0000oij;_onNRkl0
2OnNRkl2o`0000GoZY>n00?o0000ok:N`onbW/<04_nbW/<01?l0003o_:o<okb_c?nl[l`2o`00017o
cKO500Go0000omVm__oI_KkofKfno`00001Eooooo`00Goooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01gooooo0ol000001_oooooo0000o`000?l0003o
WX^oo`00013oW8Nl00?o0000oib6^onLQ[/03onLQ[/00ol0003oW8Nloib7_00?oib7_003o`000?nN
RkooWX^o00OoWX^o0_l00007ojZC_P03o`000?nbW/?o/Yk301?o/Yk300?o0000okb_c?nl[l`00_l0
000@olfga@03o`000?oI_KkofKfn00;ofKfn0_l0001Dooooo`00Goooool01Ol@413ooooooooooooo
oooo410@00_ooooo1Ol0000Kooooo`?o00000_ooool2o`0000GoWX^o00?o0000oib7_?nLQk`03_nL
Qk`00ol0003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onNRkl01?nN
Rkl2o`0000[oZY>n00?o0000ok:N`onbW/<04_nbW/<01Ol0003o_:o<o`000?o=]lGo0000013ocKO5
00?o0000omVm__oI_Kh00ooI_Kh2o`0005?ooooo001Oooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool0000Jooooo`;o00000_ooool3o`0000OoWX^o00?o0000oib7_?nL
Qk`03_nLQk`00ol0003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl013oW8Nl00?o0000oij;_onN
Rkl00_nNRkl2o`0000coZY>n00?o0000ok:N`onbW/<04_nbW/<2o`0000;ocKO500?o0000olfgaOo=
]lD03Oo=]lD00ol0003ofKfnomVm_P05omVm_P03o`000?oooooooooo057ooooo001Oooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0000Gooooo`?o00000_ooool2o`00
00[oWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl
00ooW8Nl00Go0000oij;_onNRkooWX^oo`00000>ojZC_P03o`000?nbW/?o/Yk3017o/Yk300?o0000
ol2W`?l000000_o=]lD00ol0003ocKO5olfga@0<olfga@03o`000?oI_KkofKfn00KofKfn0_l0001B
ooooo`00Goooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Oooool2
o`0000;ooooo0ol0000=oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6^onLQ[/03_nLQ[/0
0ol0003oW8Nloib7_00@oib7_0?o00004?nZTkh00ol0003o/Yk3ok:N``0?ok:N``07o`000?o0Yl3o
`:O0ol2W`?l0003ocKO5o`00000>olfga@03o`000?oI_KkofKfn00OofKfn00?o0000ooooooooool0
D?ooool005oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001;ooooo
0ol00002ooooo`;o00004?nNRkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00koW8Jk
00?o0000oib7_?nLQk`03onLQk`2o`0001;oZY>n00?o0000ok:N`onbW/<03_nbW/<00ol0003o`:O0
ol2W`002ol2W`003o`000?o=]lGo000000gocKO500?o0000omVm__oI_Kh02?oI_Kh2o`00057ooooo
001Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`;o0000
0_ooool3o`000003oin@a?l0003oWX^o00ooWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0003oW8Jk
oib6^`0?oib6^`03o`000?nLQkcoW8Nl00coW8Nl0_l000000onTS;co0000ojZC_P0BojZC_P03o`00
0?nbW/?o/Yk300co/Yk300?o0000ol2W`?o0Yl001?o0Yl02o`0000cocKO500?o0000omVm__oI_Kh0
2_oI_Kh2o`00053ooooo0020ooooo`?o00000_ooool2o`0000GoWi3400?o0000oij;_onNRkl03_nN
Rkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00koW8Jk00?o0000oib7_?nLQk`02_nL
Qk`2o`0000CoY8bl00?o0000ojZC__nZTkh04?nZTkh00ol0003o/Yk3ok:N``0;ok:N``03o`000?o0
Yl3o`:O000Go`:O00_l0000;olfga@03o`000?oI_KkofKfn00cofKfn00?o0000ooooooooool0C_oo
ool007kooooo0_l00002ooooo`?o00001onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkco
W8Nl00koW8Nl00?o0000oib6^onLQ[/03_nLQ[/00ol0003oW8Nloib7_008oib7_0;o00001_nTS;`0
0ol0003oZY>nojZC_P0@ojZC_P03o`000?nbW/?o/Yk300[o/Yk300?o0000ol2W`?o0Yl001oo0Yl00
0ol0003ocKO5olfga@09olfga@03o`000?oI_KkofKfn00cofKfn0_l0001?ooooo`00Noooool3o`00
00;ooooo0ol00009oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0
003oW8Jkoib6^`0?oib6^`03o`000?nLQkcoW8Nl00GoW8Nl0_l00008ojB<_003o`000?nZTkkoZY>n
017oZY>n00?o0000ok:N`onbW/<02?nbW/<00ol0003o`:O0ol2W`008ol2W`003o`000?o=]lGocKO5
00SocKO500?o0000omVm__oI_Kh03?oI_Kh01?l0003oh/:ho`000?l0001>ooooo`00NOooool2o`00
00?ooooo0_l0000=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03_nLQk`00ol0
003oW8Jkoib6^`0>oib6^`03o`000?nLQkcoW8Nl00?oW8Nl0_l0000;ojB<_003o`000?nZTkkoZY>n
013oZY>n00?o0000ok:N`onbW/<01onbW/<00ol0003o`:O0ol2W`009ol2W`0;o00002?o=]lD00ol0
003ofKfnomVm_P0<omVm_P05o`000?oR`[Soh/:hon;2^?l00000C_ooool007Kooooo0ol00003oooo
o`;o00003onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6
^onLQ[/03_nLQ[/01?l0003oW8Nloib7_?nLQk`2o`0000goY8bl00?o0000ojZC__nZTkh04OnZTkh0
0ol0003o/Yk3ok:N``05ok:N``03o`000?o0Yl3o`:O000[o`:O000?o0000ol2W`?l000001oo=]lD0
0ol0003ofKfnomVm_P0<omVm_P04o`000?oR`[Soh/:hon;2^0;o0000COooool007?ooooo0ol00002
ooooo`Co000000?oXYS:o`000?nOT<@03onOT<@00ol0003oWX^ooij;_`0>oij;_`03o`000?nLQkco
W8Nl00goW8Nl00?o0000oib6^onLQ[/03onLQ[/3o`0000ooY8bl00?o0000ojZC__nZTkh04OnZTkh0
0ol0003o/Yk3ok:N``04ok:N``03o`000?o0Yl3o`:O000_o`:O000?o0000ol2W`?l000001_o=]lD0
0ol0003ofKfnomVm_P0<omVm_P03o`000?oR`[Soh/:h00?oh/:h0_l0001<ooooo`00LOooool2o`00
00?ooooo1?l00004oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03_nNRkl00ol0
003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00goW8Jk0_l0000BojB<_003o`000?nZTkkoZY>n
013oZY>n00?o0000ok:N`onbW/<00onbW/<00ol0003o`:O0ol2W`00<ol2W`004o`000?o0Yl3o`:O0
o`0000CocKO500?o0000omVm__oI_Kh03OoI_Kh00ol0003oh/:hon;2^004on;2^003o`000?oooooo
oooo04[ooooo001^ooooo`?o00000_ooool3o`0000SoXYS:00?o0000oin@a?nOT<@03OnOT<@00ol0
003oWX^ooij;_`0>oij;_`03o`000?nLQkcoW8Nl00koW8Nl00?o0000oib6^onLQ[/02_nLQ[/3o`00
0003oin8_?l0003oY8bl017oY8bl00?o0000ojZC__nZTkh04OnZTkh01Ol0003o/Yk3ok:N`onbW/?o
000000oo`:O000Co0000ol2W`?o0Yl3o00000oo=]lD00ol0003ofKfnomVm_P0=omVm_P03o`000?oR
`[Soh/:h00Koh/:h00?o0000ooooooooool0BOooool003Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`00027ooooo0_l00002ooooo`?o00002onRV<X00ol0003oWi34oin@
a00>oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03OnLQk`00ol0003oW8Jkoib6
^`08oib6^`;o00001OnOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n013oZY>n00Co
0000ok:N`onbW/?o00004?o0Yl001Ol0003o`:O0ol2W`?o0Yl3o000000;ocKO500?o0000omVm__oI
_Kh03?oI_Kh00ol0003oh/:hon;2^007on;2^0;o0000B_ooool003Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0ol00002oooo
o`;o00003onRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7
_?nLQk`03_nLQk`00ol0003oW8Jkoib6^`04oib6^`?o00001onOR;`00ol0003oY8blojB<_00@ojB<
_003o`000?nZTkkoZY>n013oZY>n00?o0000ok:N`ol000004_o0Yl001_l0003o`:O0ol2W`?l0003o
cKO5o`0000oofKfn00?o0000on;2^?oR`[P02?oR`[P00ol0003oooooooooo`06ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`0[ooooo`00=_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h07Oooool2o`0000;ooooo
0ol000000onTXM;o0000oj:HbP0>oj:HbP03o`000?nOT<CoWi3400koWi3400?o0000oij;_onNRkl0
3OnNRkl00ol0003oW8Nloib7_00>oib7_003o`000?nLQ[_oW8Jk00;oW8Jk0_l0000:oin8_003o`00
0?nTS;coY8bl013oY8bl00?o0000ojZC__nZTkh04?nZTkh2o`0001?o`:O000Go0000ol2W`?o0Yl3o
`:O0o`00000?omVm_P03o`000?oR`[Soh/:h00[oh/:h00?o0000ooooooooool01Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02cooooo000fooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Iooooo`?o00000_ooool2o`00
00GoY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00>oin@a003o`000?nNRkooWX^o
00koWX^o00?o0000oib7_?nLQk`03OnLQk`00ol0003oW8Jko`000002o`0000goWhRl00?o0000ojB<
_?nTS;`04?nTS;`00ol0003oZY>nojZC_P0>ojZC_P03o`000?ndVkko000001?o`:O000Go0000ol2W
`?o0Yl3o`:O0o`00000?omVm_P03o`000?oR`[Soh/:h00[oh/:h0_l00006ooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0002gooooo000fooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`0Fooooo`;o00000_ooool3o`0000OoY:7B00?o0000oj:Hb_nRV<X03OnR
V<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00koWX^o00?o0000oib7_?nLQk`03OnL
Qk`2o`00013oWhRl00?o0000ojB<_?nTS;`04?nTS;`00ol0003oZY>nojZC_P0=ojZC_P05o`000?nd
Vkko]9^nokBK__l000004_o0Yl001_l0003o`:O0ol2W`?l0003oc:nno`0000gofKfn00?o0000on;2
^?oR`[P02_oR`[P00ol0003oj<Jdo`000006ooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000;ooooo`?o000000?o410@ooooooooool07Oooool003Kooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01;ooooo0ol00002ooooo`;o00002_nT
XM800ol0003oXYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400koWi3400?o0000oij;_onNRkl03OnN
Rkl00ol0003oW8Nloib7_00:oib7_0?o000000?oVhNmo`000?nOR;`03onOR;`00ol0003oY8blojB<
_00@ojB<_003o`000?nZTkkoZY>n00coZY>n00?o0000okBK__ndVkh00_ndVkh00ol0003o`:O0ol2W
`00@ol2W`003o`000?o0Yl3o000000;oc:nn00?o0000omVm__oI_Kh02_oI_Kh00ol0003oh/:hon;2
^00;on;2^004o`000?oXa[Co0000o`0000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04
omgMgOmEEEGoooooo`0000gooooo00?o410@okZj^_ooool07_ooool003Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004_ooool2o`0000;ooooo0ol0000=
ojBQdP03o`000?nRV<[oXYS:00goXYS:00?o0000oin@a?nOT<@03OnOT<@00ol0003oWX^ooij;_`0>
oij;_`03o`000?nLQkcoW8Nl00KoW8Nl0ol00004oi^7_@03o`000?nOR;coWhRl00ooWhRl00?o0000
ojB<_?nTS;`04?nTS;`00ol0003oZY>nojZC_P09ojZC_P;o00001OndVkh00ol0003o`:O0ol2W`00@
ol2W`0;o00001?o<[kh00ol0003ofKfnomVm_P09omVm_P03o`000?oR`[Soh/:h00[oh/:h00Co0000
onS6]?oXa[Coj<Jd0_l00004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000=ooooo`03oiRHV?lb<S;ooooo01kooooo000fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo0ol00002ooooo`;o00004?nTXM800ol0003o
XYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03_nNRkl00ol0003o
W8Nloib7_003oib7_0?o00002?nKQkd00ol0003oWhRloin8_00>oin8_003o`000?nTS;coY8bl013o
Y8bl00?o0000ojZC__nZTkh02?nZTkh00ol0003o]9^nokBK_P06okBK_P03o`000?o0Yl3o`:O000oo
`:O000?o0000olb___o<[kh00oo<[kh00ol0003ofKfnomVm_P08omVm_P03o`000?oR`[Soh/:h00_o
h/:h00Co0000onS6]?oXa[Coj<Jd0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000=ooooo`03omgMgOl0003o^[Zj01kooooo001Hooooo`?o000000Koooooo`00
0?l0003o0000ojN[f_l0000AojBQdP03o`000?nRV<[oXYS:00coXYS:00?o0000oin@a?nOT<@03_nO
T<@00ol0003oWX^ooij;_`0=oij;_`03o`000?nLQkcoW8Nl00?o00002onKQkd00ol0003oWhRloin8
_00>oin8_003o`000?nTS;coY8bl017oY8bl00?o0000ojZC__nZTkh01_nZTkh00ol0003o]9^nokBK
_P07okBK_P03o`000?o0Yl3o`:O000ko`:O00_l00006olb__P03o`000?oI_KkofKfn00OofKfn00?o
0000on;2^?oR`[P02_oR`[P00ol0003oj<JdonS6]003onS6]0;o00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool03?ooool00omEEEGoMgMgodA4A00Nooooo`00EOoo
ool3o`000004ooooool0003o0000o`0000GoYj_J00?o0000ojBQd_nTXM803_nTXM800ol0003oXYS:
oj:HbP0=oj:HbP03o`000?nOT<CoWi3400goWi3400?o0000oij;_onNRkl03?nNRkl4o`0000koVhNm
00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n00GoZY>n
00?o0000okBK__ndVkh02OndVkh00ol0003o`:O0ol2W`00=ol2W`0;o00001_o<[kh00ol0003ofKfn
omVm_P06omVm_P03o`000?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@01?oXa[@2o`0002;ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@0Mooooo`00D_ooool3o`0000;ooooo0_l00009ojN[fP03o`00
0?nTXM;oY:7B00koY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00>oin@a003o`00
0?nNRkooWX^o00OoWX^o1?l00002oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`0
3_nOR;`00ol0003oY8blojB<_00@ojB<_003o`000?nZTkkoZY>n00?oZY>n0_l0000<okBK_P03o`00
0?o0Yl3o`:O000co`:O000?o0000olb___l000001oo<[kh00ol0003ofKfnomVm_P04omVm_P03o`00
0?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@01OoXa[@2o`0002;ooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@0Mooooo`00D?ooool2o`0000;ooooo0ol0000;ojN[fP03o`000?nTXM;oY:7B00koY:7B
00?o0000oj:Hb_nRV<X03OnRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00CoWX^o
0ol00006oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8bl
ojB<_00@ojB<_005o`000?nZTkkoZY>nojZC__l000003ondVkh00ol0003o`:O0ol2W`00:ol2W`004
o`000?o<[kkoc:nno`0000Ooc:nn00?o0000omVm__oI_Kh01?oI_Kh00ol0003oh/:hon;2^00;on;2
^003o`000?oXa[Coj<Jd00Koj<Jd0_l0000Pooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool06oooool004gooooo1?l000000ooooooo0000o`00000?ojN[fP03o`000?nTXM;oY:7B00go
Y:7B00?o0000oj:Hb_nRV<X03OnRV<X00ol0003oWi34oin@a00=oin@a003o`000?nNRkooWX^o00Co
00002_nHR<400ol0003oVhNmoi^7_@0=oi^7_@03o`000?nOR;coWhRl00ooWhRl00?o0000ojB<_?nT
S;`04?nTS;`01?l0003oZY>nojZC__l0000@okBK_P03o`000?o0Yl3o`:O000Wo`:O000Go0000olb_
__o<[kkoc:nno`000007olb__P03o`000?oI_KkofKfn00?ofKfn00?o0000on;2^?oR`[P02ooR`[P0
0ol0003oj<JdonS6]007onS6]003o`000?oooooo000001oooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`0Jooooo`00Boooool2o`0000;ooooo0ol000000onX]>7o0000ojN[fP0>
ojN[fP03o`000?nTXM;oY:7B00koY:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a00<
oin@a0Co00003_nHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00koWhRl00?o0000
ojB<_?nTS;`04?nTS;`00ol0003oZY>no`00000AokBK_P03o`000?o0Yl3o`:O000So`:O000?o0000
olb___o<[kh00_o<[kh00ol0003oc:nnolb__P06olb__P03o`000?oI_KkofKfn00;ofKfn00?o0000
on;2^?oR`[P02ooR`[P00ol0003oj<JdonS6]008onS6]0;o0000@_ooool004Sooooo0ol000001?oo
oooo0000o`000?l00005ojRdh@03o`000?nWZm[oYj_J00goYj_J00?o0000ojBQd_nTXM803OnTXM80
0ol0003oXYS:oj:HbP0=oj:HbP03o`000?nOT<CoWi3400OoWi341?l00002oiJ<a`03o`000?nHR<7o
V8S100goV8S100?o0000oi^7_OnKQkd03_nKQkd00ol0003oWhRloin8_00?oin8_003o`000?nTS;co
Y8bl00ooY8bl0_l0000CokBK_P03o`000?o0Yl3o`:O000Ko`:O000?o0000olb___o<[kh00oo<[kh0
0ol0003oc:nnolb__P06olb__P05o`000?oI_KkofKfnomVm__l000003OoR`[P00ol0003oj<JdonS6
]009onS6]0?o0000@Oooool0027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Pooooo`;o000000Co
ooooo`000?l0003o00002OnX]>400ol0003oYj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00goY:7B
00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a004oin@a0?o00001onFS<L00ol0003oV8S1
oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8bl
ojB<_00=ojB<_0;o000000?oZi>mo`000?ndVkh04_ndVkh00ol0003o`:O0ol2W`005ol2W`003o`00
0?o<[kkoc:nn00Coc:nn00?o0000olb___o<[kh01oo<[kh00ol0003ofKfno`00000>on;2^003o`00
0?oXa[Coj<Jd00Soj<Jd00Co0000onc:/Ol0003o0000@Oooool0027ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Mooooo`Ko00003?nX]>400ol0003oYj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00go
Y:7B00?o0000oj:Hb_nRV<X03?nRV<X00ol0003oWi34oin@a004o`0000[oUXc700?o0000oiR8`OnH
R<403OnHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00koWhRl00?o0000ojB<_?nT
S;`03?nTS;`00ol0003oZi>moj^C_@02oj^C_@03o`000?ndVkko]9^n017o]9^n00?o0000ol2W`?o0
Yl001?o0Yl000ol0003oc:nnolb__P05olb__P03o`000?o<[kkoc:nn00Koc:nn00?o0000omVm__l0
00003OoR`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00;o0000@?ooool0027ooooo
00Go410@oooooooooooooooooa0@400Kooooo`;o000000?oooooo`000?l000004?nX]>400ol0003o
Yj_JojN[fP0=ojN[fP03o`000?nTXM;oY:7B00goY:7B00?o0000oj:Hb_nRV<X02_nRV<X4o`0000ko
UXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@0>oi^7_@03o`000?nOR;coWhRl00oo
WhRl00?o0000ojB<_?nTS;`02OnTS;`2o`0000GoZi>m00?o0000okBK__ndVkh04OndVkh00ol0003o
`:O0ol2W`003ol2W`003o`000?o<[kkoc:nn00Koc:nn00?o0000olb___o<[kh01oo<[kh00ol0003o
h/:hon;2^00<on;2^003o`000?oXa[Coj<Jd00Soj<Jd00?o0000onc:/Oo/b[400_o/b[42o`0003oo
oooo000Qooooo`05o`000?ooooooooooooooool000006?ooool3o`000005ooooool0003o0000ojVk
i_l000004OnX]>400ol0003oYj_JojN[fP0<ojN[fP03o`000?nTXM;oY:7B00goY:7B00?o0000oj:H
b_nRV<X01OnRV<X5o`0000;oUI;>00?o0000oiJ<aonFS<L03_nFS<L00ol0003oV8S1oiR8`@0=oiR8
`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_007ojB<
_0;o00001on[Tkd00ol0003o]9^nokBK_P0BokBK_P05o`000?o0Yl3o`:O0ol2W`?l000002Oo<[kh0
0ol0003oc:nnolb__P07olb__P03o`000?oR`[Soh/:h00_oh/:h00?o0000onS6]?oXa[@02OoXa[@0
0ol0003ok<Zaonc:/@03onc:/@03o`000?oooooooooo03gooooo000Qooooo`05o`000?oooooooooo
ooooool000005_ooool2o`0000;ooooo0_l00004ojVkiP03o`000?nX]>7oZ;CQ00ooZ;CQ00?o0000
ojN[f_nWZmX03?nWZmX00ol0003oY:7BojBQdP0<ojBQdP03o`000?nRV<[oXYS:00Go00002?nET/h0
0ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7_OnKQkd03OnKQkd0
0ol0003oWhRloin8_00?oin8_003o`000?nTS;coY8bl00GoY8bl0_l0000:oj^C_@03o`000?ndVkko
]9^n017o]9^n00Co0000ol2W`?o0Yl3o00002_o<[kh00ol0003oc:nnolb__P06olb__P03o`000?oF
^;co000000coh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@03onc:/@;o0000?_oo
ool0027ooooo00Go410@oooooooooooooooooa0@400Cooooo`?o000000Coooooo`000?l0003o0000
1onY^nH00ol0003oZ;CQojRdh@0>ojRdh@03o`000?nWZm[oYj_J00goYj_J00?o0000ojBQd_nTXM80
2OnTXM85o`0000goUI;>00?o0000oiJ<aonFS<L03OnFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`00
0?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03onOR;`00ol0003oY8blojB<_002ojB<_0;o0000
3?n[Tkd00ol0003o]9^nokBK_P0AokBK_P03o`000?o0Yl3o000000_oc:nn00?o0000olb___o<[kh0
1Oo<[kh01Ol0003oe[RlomJh_?oF^;co000000[oh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003o
k<Zaonc:/@05onc:/@;o0000?Oooool0027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o
00000_ooool2o`0000_oZK_V00?o0000ojRdhOnX]>403_nX]>400ol0003oYj_JojN[fP0<ojN[fP03
o`000?nTXM;oY:7B00;oY:7B1ol00003oiFKe`03o`000?nET/koUI;>00goUI;>00?o0000oiJ<aonF
S<L03OnFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00goVhNm00?o0000oin8_?nO
R;`03onOR;`01Ol0003oY8blojB<_?nTS;co000000koZi>m00?o0000okBK__ndVkh04OndVkh2o`00
00coc:nn00?o0000olb___o<[kh01?o<[kh00ol0003oe[RlomJh_002omJh_003o`000?oR`[Soh/:h
00Soh/:h00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@06onc:/@03o`000?oooooooooo
03_ooooo000Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`0000?ooooo0_l0000=ojVk
iP03o`000?nX]>7oZ;CQ00ooZ;CQ00?o0000ojN[f_nWZmX02_nWZmX6o`0000_oUI_G00?o0000oiFB
c_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7
_OnKQkd03OnKQkd00ol0003oWhRloin8_00?oin8_004o`000?nTS;co0000o`00013oZi>m00?o0000
okBK__ndVkh03ondVkh00ol0003o_jBno`00000<olb__P03o`000?o<[kkoc:nn00Coc:nn00?o0000
omJh_?oF^;`00ooF^;`00ol0003oh/:hon;2^006on;2^003o`000?oXa[Coj<Jd00Woj<Jd00?o0000
onc:/Oo/b[402?o/b[400ol0003oooooooooo`0jooooo`00<Oooool5o`000003ooooool0003o0000
013oZK_V00?o0000ojRdhOnX]>403_nX]>400ol0003oYj_JojN[fP05ojN[fPGo00000_nGY^000ol0
003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000oiJ<aonFS<L03OnFS<L00ol0
003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`03_nOR;`2o`00
01;oZi>m00?o0000okBK__ndVkh03_ndVkh01Ol0003o_jBnoknT__noY;ko000000[oc:nn0_l00005
olb__P03o`000?oF^;coe[Rl00Coe[Rl00?o0000on;2^?oR`[P01_oR`[P00ol0003oj<JdonS6]009
onS6]003o`000?o/b[7ok<Za00Sok<Za0_l0000kooooo`00;oooool2o`0000?ooooo0ol000000onY
_NSo0000ojVkiP0@ojVkiP03o`000?nX]>7oZ;CQ00koZ;CQ00?o0000ojN[f_nWZmX01?l00008oiNV
h003o`000?nEVmOoUI_G00coUI_G00?o0000oiFBc_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<
a`03o`000?nHR<7oV8S100goV8S100?o0000oi^7_OnKQkd03OnKQkd00ol0003oWhRloin8_00<oin8
_0;o000000?oXXfno`000?n[Tkd04_n[Tkd00ol0003o]9^nokBK_P0<okBK_P03o`000?noY;ko_jBn
00;o_jBn00?o0000olb___o<[kh01Oo<[kh3o`000003olb___l0003oc:nn00?oc:nn00?o0000omJh
_?oF^;`01_oF^;`00ol0003oh/:hon;2^004on;2^003o`000?oXa[Coj<Jd00Woj<Jd00?o0000onc:
/Oo/b[402?o/b[400ol0003ol<n`o`00000kooooo`00;?ooool3o`0000;ooooo0ol00005ojVmj003
o`000?nY^nKoZK_V00ooZK_V00?o0000ojRdhOnX]>403?nX]>44o`0000goUjKP00?o0000oiFKeonE
VmL02onEVmL00ol0003oUI;>oiFBcP0<oiFBcP03o`000?nFS<OoUXc700goUXc700?o0000oiR8`OnH
R<403OnHR<400ol0003oVhNmoi^7_@0=oi^7_@03o`000?nOR;coWhRl00WoWhRl0ol00004oj:=_P03
o`000?n[TkgoZi>m013oZi>m00?o0000okBK__ndVkh02ondVkh00ol0003o_jBnoknT_P04oknT_P04
o`000?o<[kkoc:nnolb__P?o00001Oo<[kh01Ol0003oc:nnolb___o<[kko000000Woe[Rl00?o0000
on;2^?oR`[P00ooR`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00Sok<Za00Co0000
oo3?/?o`ck3o0000>_ooool002_ooooo0_l000001?oooooo0000o`000?l00009ojVmj003o`000?nY
^nKoZK_V00koZK_V00?o0000ojRdhOnX]>402OnX]>43o`0000;oVk3V00?o0000oiNVh?nGY^003?nG
Y^000ol0003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000oiJ<aonFS<L03?nF
S<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm00?o0000oin8_?nOR;`01_nO
R;`2o`0000OoXXfn00?o0000oj^C_On[Tkd04?n[Tkd00ol0003o]9^nokBK_P0:okBK_P03o`000?no
Y;ko_jBn00Go_jBn1?l00009olb__P03o`000?o<[kko000000[oe[Rl00?o0000on;2^?oR`[P00_oR
`[P00ol0003oj<JdonS6]009onS6]003o`000?o/b[7ok<Za00Sok<Za00Co0000oo3?/?o`ck3ol<n`
0_l0000iooooo`00:oooool3o`0000goZKgX00?o0000ojVki_nY^nH03_nY^nH00ol0003oZ;CQojRd
h@04ojRdh@Co00001_nK/>H00ol0003oUjKPoiNVh00<oiNVh003o`000?nEVmOoUI_G00_oUI_G00?o
0000oiFBc_nET/h03?nET/h00ol0003oUXc7oiJ<a`0=oiJ<a`03o`000?nHR<7oV8S100goV8S100?o
0000oi^7_OnKQkd03OnKQkd00ol0003oWhRloin8_004oin8_0;o00002OnRSKh00ol0003oZi>moj^C
_@0Aoj^C_@03o`000?ndVkko]9^n00So]9^n00?o0000oknT__noY;h01?noY;h4o`0000coc:nn00?o
0000omJh_?oF^;`02_oF^;`01Ol0003oh/:hon;2^?oR`[So000000_oj<Jd00?o0000onc:/Oo/b[40
2?o/b[400ol0003ol<n`oo3?/002oo3?/0;o0000>?ooool002[ooooo0ol0000?ojVmj003o`000?nY
^nKoZK_V00koZK_V00?o0000ojRdhOnX]>400ol0000;oi^`iP03o`000?nGY^3oUjKP00_oUjKP00?o
0000oiFKeonEVmL03?nEVmL00ol0003oUI;>oiFBcP0<oiFBcP03o`000?nFS<OoUXc700coUXc700?o
0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@0=oi^7_@04o`000?nOR;coWhRloin8_0?o0000
3?nRSKh00ol0003oZi>moj^C_@0@oj^C_@03o`000?ndVkko]9^n00Oo]9^n00?o0000oknT__noY;h0
0_noY;h3o`0000?o_jBn00?o0000olb___o<[kh02Oo<[kh2o`0000coe[Rl00Co0000on;2^?oR`[So
00002ooXa[@00ol0003ok<Zaonc:/@09onc:/@03o`000?o`ck3ol<n`00;ol<n`0_l00008ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00K
ooooo`00:oooool2o`00013oZKgX00?o0000ojVki_nY^nH03?nY^nH4o`0000koVk3V00?o0000oiNV
h?nGY^003?nGY^000ol0003oUI_GoiFKe`0<oiFKe`03o`000?nET/koUI;>00_oUI;>00?o0000oiJ<
aonFS<L03?nFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00koVhNm0ol0000?oj:=
_P03o`000?n[TkgoZi>m017oZi>m00?o0000okBK__ndVkh01OndVkh00ol0003o_jBnoknT_P03o`00
00Oo_jBn00?o0000olb___o<[kh02?o<[kh00ol0003oe[Rlo`00000<omJh_003o`000?oR`[So0000
00_oj<Jd00?o0000onc:/Oo/b[402?o/b[400ol0003ol<n`oo3?/004oo3?/0;o00001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B406ooo
ool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00Co
0000oooooooooooo00004?nY_NP00ol0003oZK_VojVkiP08ojVkiP?o00000onP^>X00ol0003oVk3V
oi^`iP0=oi^`iP03o`000?nGY^3oUjKP00coUjKP00?o0000oiFKeonEVmL02onEVmL00ol0003oUI;>
oiFBcP0<oiFBcP03o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNm
oi^7_@0;oi^7_@?o00004OnRSKh00ol0003oZi>moj^C_@0Aoj^C_@03o`000?ndVkko]9^n00Co]9^n
00Co0000oknT__l0003o00002_noY;h00ol0003oc:nnolb__P07olb__P05o`000?oF^;coe[RlomJh
_?l000003?oF^;`00ol0003oj<JdonS6]00:onS6]003o`000?o/b[7ok<Za00Sok<Za00?o0000oo3?
/?o`ck001Oo`ck000ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000001_ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`05o`000?ooooooooooooooool0
00004?nY_NP00ol0003oZK_VojVkiP04ojVkiP?o00001onP^>X00ol0003oVk3Voi^`iP0=oi^`iP03
o`000?nGY^3oUjKP00_oUjKP00?o0000oiFKeonEVmL03?nEVmL00ol0003oUI;>oiFBcP0;oiFBcP03
o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNmoi^7_@07oi^7_@Co
00000_nIRL400ol0003oXXfnoj:=_P0@oj:=_P03o`000?n[TkgoZi>m013oZi>m00?o0000okBK__nd
Vkh00ondVkh3o`0000co_jBn00?o0000olb___o<[kh01_o<[kh00ol0003oe[RlomJh_002omJh_003
o`000?oF^;coe[Rl00[oe[Rl00?o0000onS6]?oXa[@02OoXa[@00ol0003ok<Zaonc:/@08onc:/@03
o`000?o`ck3ol<n`00Kol<n`0_l00006ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q01_ooooo0007ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?nY_NSo
ZKgX00koZKgX00?o0000ojVki_nY^nH00ol0000;oj2hjP03o`000?nK/>KoVk3V00goVk3V00?o0000
oiNVh?nGY^002onGY^000ol0003oUI_GoiFKe`0;oiFKe`03o`000?nET/koUI;>00coUI;>00?o0000
oiJ<aonFS<L02onFS<L00ol0003oV8S1oiR8`@0=oiR8`@03o`000?nKQkgoVhNm00CoVhNm0ol00007
oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[Tkd04On[Tkd00ol0003o]9^no`000002
o`00013o_jBn00?o0000olb___o<[kh01Oo<[kh00ol0003oe[RlomJh_003omJh_003o`000?oF^;co
e[Rl00Soe[Rl00?o0000omk0^_l000002_oXa[@00ol0003ok<Zaonc:/@08onc:/@03o`000?o`ck3o
l<n`00Ool<n`0_l00005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`00
0?l@413oc<c<01_ooooo000?ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`;o00001?ooool00ol0003oZKgXojVmj00<ojVmj0Co00003onP^>X00ol0003oVk3V
oi^`iP0<oi^`iP03o`000?nGY^3oUjKP00_oUjKP00?o0000oiFKeonEVmL03?nEVmL00ol0003oUI;>
oiFBcP0;oiFBcP03o`000?nFS<OoUXc700coUXc700?o0000oiR8`OnHR<403OnHR<400ol0003oVhNm
o`000003o`0000[oVHW100?o0000oj:=__nRSKh03onRSKh00ol0003oZi>moj^C_@0@oj^C_@?o0000
00?o]9^no`000?noY;h04?noY;h00ol0003oc:nnolb__P04olb__P03o`000?oF^;coe[Rl00Goe[Rl
00?o0000omJh_?oF^;`01_oF^;`01?l0003og/2jomk0^_l00009onS6]003o`000?o/b[7ok<Za00So
k<Za00?o0000oo3?/?o`ck002?o`ck02o`0000Gooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01gooooo000?ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`04ooooo`;o00001_ooool00ol0003oZKgXojVmj008ojVmj0?o00001?nV_>T00ol0
003oX;SZoj2hjP0=oj2hjP03o`000?nK/>KoVk3V00coVk3V00?o0000oiNVh?nGY^002onGY^000ol0
003oUI_GoiFKe`0;oiFKe`03o`000?nET/koUI;>00_oUI;>00?o0000oiJ<aonFS<L03?nFS<L00ol0
003oV8S1oiR8`@09oiR8`@Ko00003_nIRL400ol0003oXXfnoj:=_P0@oj:=_P03o`000?n[TkgoZi>m
00coZi>m0ol000001?n[Tkgo0000okBK__l0000CoknT_P03o`000?o<[kkoc:nn00;oc:nn00?o0000
omJh_?oF^;`01ooF^;`00ol0003oe[RlomJh_005omJh_005o`000?oN`;[og/2jomk0^_l000002?oX
a[@00ol0003ok<Zaonc:/@08onc:/@03o`000?o`ck3ol<n`00Ool<n`00Co0000oo;C/Ol0003o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P07Oooool000oooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oZKgXojVmj004ojVmj0?o00002?nV_>T00ol0003oX;SZoj2hjP0=oj2hjP03
o`000?nK/>KoVk3V00coVk3V00?o0000oiNVh?nGY^002onGY^000ol0003oUI_GoiFKe`0;oiFKe`03
o`000?nET/koUI;>00_oUI;>00?o0000oiJ<aonFS<L02onFS<L00ol0003oV8S1oiR8`@02oiR8`@Oo
00001?nBR<H00ol0003oVHW1oiV9`@0>oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[
Tkd02On[Tkd3o`0000CoZi>m0_l0000DoknT_P05o`000?o<[kkoc:nnolb___l000002_oF^;`00ol0
003oe[RlomJh_004omJh_003o`000?oN`;[og/2j00?og/2j00?o0000onS6]?oXa[@01?oXa[@00ol0
003ok<Zaonc:/@09onc:/@03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk400_l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Kooooo`003oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ojVmj?nY_NP00ol0000<ojJlj@03o`000?nP^>[oX;SZ00goX;SZ
00?o0000oi^`i_nK/>H02onK/>H00ol0003oUjKPoiNVh00;oiNVh003o`000?nEVmOoUI_G00_oUI_G
00?o0000oiFBc_nET/h02onET/h00ol0003oUXc7oiJ<a`05oiJ<a`_o00003?nBR<H00ol0003oVHW1
oiV9`@0=oiV9`@03o`000?nRSKkoXXfn00ooXXfn00?o0000oj^C_On[Tkd01_n[Tkd3o`0000KoZi>m
00?o0000ok:K`?l000005OnoY;h01?l0003oc:nnolb___l0000;omJh_003o`000?oF^;coe[Rl00;o
e[Rl00?o0000omk0^_oN`;X01?oN`;X00ol0003oj<JdonS6]004onS6]003o`000?o/b[7ok<Za00So
k<Za00?o0000oo3?/?o`ck001oo`ck001?l0003ol]>aoo;C/Oobdk42o`0003?ooooo000?ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000
ooooooooool02?ooool2o`00013oY[cY00?o0000oj2hj_nP^>X03OnP^>X00ol0003oVk3Voi^`iP0;
oi^`iP03o`000?nGY^3oUjKP00GoUjKP:Ol00007oh^9c003o`000?nBR<KoTXS600goTXS600?o0000
oiV9`OnIRL403_nIRL400ol0003oXXfnoj:=_P0?oj:=_P03o`000?n[TkgoZi>m00?oZi>m0_l00007
oj^C_@;o00000onbVl000ol0003o_jBnoknT_P0BoknT_P03o`000?o<[kko000000goe[Rl00Go0000
omJh_?oF^;coe[Rlo`000007omk0^P03o`000?oXa[Coj<Jd00;oj<Jd00?o0000onc:/Oo/b[402Oo/
b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00;ol]>a0_l0000booooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj2hj_nP^>X03OnP^>X0
0ol0003oVk3Voi^`iP05oi^`iPgo00001_n3WnD00ol0003oPYCLoh:Dg00;oh:Dg003o`000?n5SMCo
QHgD00_oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7o
VHW100koVHW100?o0000oj:=__nRSKh03onRSKh00ol0003oZi>moj^C_@03o`0000SoZi>m00?o0000
ok:K`?nbVl000onbVl000ol0003o_jBnoknT_P0CoknT_P03o`000?oF^;coe[Rl00coe[Rl00Co0000
omJh_?oF^;co00002?oN`;X00ol0003oj<JdonS6]002onS6]003o`000?o/b[7ok<Za00Sok<Za00?o
0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@04oo;C/@;o0000<Oooool002Wooooo0_l0000<
ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj2hj_nP^>X02onP^>X9o`0000KoRZ_[00?o0000
oh>OiOn3WnD02on3WnD00ol0003oPYCLoh:Dg00;oh:Dg003o`000?n5SMCoQHgD00_oQHgD00?o0000
oh^9c?n;RL`02on;RL`00ol0003oTXS6oi:8aP0=oi:8aP03o`000?nIRL7oVHW100goVHW100?o0000
oj:=__nRSKh03onRSKh3o`0000WoZi>m0_l00006ok:K`003o`000?noY;ko_jBn01?o_jBn00?o0000
omJh_?oF^;`03OoF^;`2o`0000[og/2j00Go0000onS6]?oXa[Coj<Jdo`00000:onc:/@03o`000?o`
ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk401?obdk42o`00037ooooo000Xooooo`;o00003_ooool0
0ol0003oY[cYojJlj@0>ojJlj@03o`000?nP^>[oX;SZ00GoX;SZ1Ol00002oiJek@03o`000?n:Zn_o
RZ_[00_oRZ_[00?o0000oh>OiOn3WnD02on3WnD00ol0003oPYCLoh:Dg00:oh:Dg003o`000?n5SMCo
QHgD00_oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7o
VHW100koVHW100?o0000oj:=__nRSKh02onRSKh3o`000003oj:=__l0003oZi>m00SoZi>m00?o0000
ok:K`?nbVl001onbVl000ol0003o_jBnoknT_P0AoknT_P03o`000?o9[l3o000000ooe[Rl00?o0000
omk0^_oN`;X02OoN`;X00ol0003oj<Jdo`00000:onc:/@03o`000?o`ck3ol<n`00Sol<n`00?o0000
oo;C/Oobdk401Oobdk42o`00033ooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ojJl
jOnV_>T03_nV_>T00ol0003oX;SZoj2hjP04o`0000SoU[G]00?o0000ohZ[jon:Zn/02on:Zn/00ol0
003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00_oPYCL00?o0000ohF=e?n5SM@02_n5SM@00ol0
003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL400ol0
003oXXfnoj:=_P08oj:=_P?o00001?nRSKh00ol0003oZi>moj^C_@06oj^C_@03o`000?nbVl3o/Y_0
00So/Y_000?o0000oknT__noY;h04?noY;h01?l0003obJo0olV_`?l0000>omJh_003o`000?oN`;[o
000000[og/2j00?o0000onS6]?l000002_o/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7o
l]>a00Ool]>a00?o0000ooooooooool0;_ooool002Wooooo00?o0000ooooooooool03_ooool00ol0
003oY[cYojJlj@0<ojJlj@Co00003OnF]Nd00ol0003oRZ_[ohZ[j`0;ohZ[j`03o`000?n3WnGoPioU
00[oPioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgDohF=e00;ohF=e003o`000?n;RLcoRhW<
00_oRhW<00?o0000oi:8a_nBR<H03OnBR<H00ol0003oVHW1oiV9`@0>oiV9`@03o`000?nRSKkoXXfn
00CoXXfn0ol00007oj:=_P03o`000?n[TkgoZi>m00CoZi>m0_l0000<ok:K`003o`000?noY;ko_jBn
00ko_jBn00?o0000olV_`?o9[l000_o9[l000ol0003oe[RlomJh_00:omJh_004o`000?oN`;[og/2j
o`0000_og/2j00?o0000onc:/Oo/b[402Oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7o
l]>a00Ool]>a0_l0000_ooooo`00:?ooool00ol0003oooooooooo`0@ooooo`03o`000?nV_>WoY[cY
00SoY[cY0ol00003oj>lj`03o`000?nF]NgoU[G]00coU[G]00?o0000ohZ[jon:Zn/02_n:Zn/00ol0
003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00_oPYCL00?o0000ohF=e?n5SM@02_n5SM@00ol0
003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL401?l0
003oXXfnoj:=__nRSKh3o`0000_oXXfn00?o0000oj^C_On[Tkd00_n[Tkd00ol0003o/Y_0ok:K`00<
ok:K`003o`000?noY;ko_jBn00go_jBn00?o0000olV_`?o9[l000oo9[l000ol0003oe[RlomJh_00:
omJh_005o`000?oN`;[og/2jomk0^_l000002_oN`;X00ol0003ok<Zaonc:/@08onc:/@03o`000?o`
ck3ol<n`00Ool<n`00?o0000oo;C/Oobdk401oobdk401?l0003olmVeo`000?l0000^ooooo`00:?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?nV_>WoY[cY00CoY[cY0ol00007oj>lj`03o`000?nF
]NgoU[G]00coU[G]00?o0000ohZ[jon:Zn/02_n:Zn/00ol0003oPioUoh>Oi@0:oh>Oi@03o`000?n2
U=coPYCL00[oPYCL00?o0000ohF=e?n5SM@02on5SM@00ol0003oRhW<oh^9c00;oh^9c003o`000?nB
R<KoTXS600coTXS600?o0000oiV9`OnIRL403_nIRL401?l0003oXXfno`000?l0000>oj:=_P03o`00
0?n[TkgoZi>m00;o00003onbVl000ol0003o_jBnoknT_P0<oknT_P03o`000?o9[l3obJo000GobJo0
00?o0000omJh_?oF^;`02?oF^;`00ol0003og/2jomk0^P03omk0^P03o`000?oN`;[og/2j00Kog/2j
00?o0000onK9^_l000002Oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00Ool]>a
00Co0000oo?I]OocfKGo0000;_ooool002Sooooo0_l0000Cooooo`03o`000?nV_>WoY[cY00?o0000
2onS_>/00ol0003oU[G]oiJek@0<oiJek@03o`000?n:Zn_oRZ_[00[oRZ_[00?o0000oh>OiOn3WnD0
2_n3WnD00ol0003oPYCLoh:Dg00:oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;RL`0
3?n;RL`00ol0003oTXS6oi:8aP0<oi:8aP03o`000?nIRL7oVHW100coVHW10ol0000@oj:=_P03o`00
0?n[Tkgo000001;o/Y_000?o0000oknT__noY;h02_noY;h00ol0003obJo0olV_`006olV_`003o`00
0?oF^;coe[Rl00Soe[Rl00?o0000omk0^_oN`;X01?oN`;X00ol0003og/2jomk0^P05omk0^P04o`00
0?oVbK[oi/Vjo`0000Ook<Za00?o0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@07oo;C/@04
o`000?ocfKGolmVeoo?I]@;o0000;Oooool002Sooooo00?o0000ooooooooool04oooool2o`0000oo
Xkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[ohZ[j`0;ohZ[j`03o`000?n3WnGoPioU00Wo
PioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgDohF=e00;ohF=e003o`000?n;RLcoRhW<00_o
RhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1oiV9`@09oiV9`@?o00000_nIRL400ol0003o
XXfnoj:=_P0>oj:=_P;o00004onbVl000ol0003o_jBnoknT_P09oknT_P03o`000?o9[l3obJo000So
bJo000?o0000omJh_?oF^;`01_oF^;`00ol0003og/2jomk0^P05omk0^P03o`000?oN`;[og/2j00Co
g/2j00Go0000onK9^_oVbK[oi/Vjo`000007onc:/@03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C
/Oobdk401oobdk400ol0003olmVeoo?I]@02oo?I]@;o0000;?ooool002Sooooo00?o0000oooooooo
ool05?ooool00ol0003oXkc[oj>lj`0>oj>lj`03o`000?nF]NgoU[G]00_oU[G]00?o0000ohZ[jon:
Zn/02_n:Zn/00ol0003oPioUoh>Oi@0:oh>Oi@03o`000?n2U=coPYCL00WoPYCL00?o0000ohF=e?n5
SM@02on5SM@00ol0003oRhW<oh^9c00<oh^9c003o`000?nBR<KoTXS600_oTXS600?o0000oiV9`OnI
RL401_nIRL43o`0000GoVHW100?o0000oj:=__nRSKh03?nRSKh2o`000003ojJD`ol0003o/Y_001?o
/Y_000?o0000oknT__noY;h01onoY;h00ol0003obJo0olV_`00:olV_`003o`000?oF^;coe[Rl00Co
e[Rl00?o0000omk0^_oN`;X01ooN`;X00ol0003og/2jomk0^P02omk0^P03o`000?oVbK[oi/Vj00?o
i/Vj00?o0000onc:/Oo/b[400oo/b[400ol0003ol<n`oo3?/007oo3?/003o`000?obdk7ol]>a00Oo
l]>a00?o0000oo?I]OocfKD01?ocfKD00ol0003oooooooooo`0Zooooo`00:?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?nS_>_oXkc[00koXkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[
ohZ[j`0:ohZ[j`03o`000?n3WnGoPioU00WoPioU00?o0000oh:Dg?n2U=`02_n2U=`00ol0003oQHgD
ohF=e00:ohF=e003o`000?n;RLcoRhW<00coRhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1
oiV9`@02oiV9`@?o00002OnIRL400ol0003oXXfnoj:=_P09oj:=_P;o00001?nVU<<00ol0003o/Y_0
ok:K`00Aok:K`003o`000?noY;ko_jBn00Oo_jBn00?o0000olV_`?o9[l002_o9[l000ol0003oe[Rl
omJh_004omJh_003o`000?oN`;[og/2j00Sog/2j00Go0000omk0^_oN`;[og/2jo`000006onK9^P03
o`000?o/b[7ok<Za00;ok<Za00?o0000oo3?/?o`ck001oo`ck000ol0003ol]>aoo;C/@07oo;C/@03
o`000?ocfKGolmVe00ColmVe0_l0000[ooooo`009oooool00ol0003oooooooooo`0Gooooo`03o`00
0?nS_>_oXkc[00koXkc[00?o0000oiJekOnF]Nd02onF]Nd00ol0003oRZ_[ohZ[j`0:ohZ[j`03o`00
0?n3WnGoPioU00WoPioU00?o0000oh:Dg?n2U=`02On2U=`00ol0003oQHgDohF=e00;ohF=e003o`00
0?n;RLcoRhW<00_oRhW<00?o0000oi:8a_nBR<H03?nBR<H00ol0003oVHW1o`000002o`0000coVHW1
00?o0000oj:=__nRSKh01_nRSKh3o`0000KoYYC300?o0000ok:K`?nbVl004OnbVl000ol0003o_jBn
oknT_P06oknT_P03o`000?o9[l3obJo000cobJo000?o0000omJh_?oF^;`00_oF^;`00ol0003og/2j
omk0^P09omk0^P04o`000?oN`;[og/2jo`0000Soi/Vj00Go0000onc:/Oo/b[7ok<Zao`000008oo3?
/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01_ocfKD2o`0002[ooooo000Wooooo`03
o`000?oooooooooo01Sooooo00?o0000oj>ljonS_>/03_nS_>/00ol0003oU[G]oiJek@05oiJekAOo
00002?n3WnD00ol0003oPYCLoh:Dg009oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;
RL`03?n;RL`00ol0003oTXS6oi:8aP0:oi:8aP?o00004?nIRL400ol0003oXXfnoj:=_P03oj:=_P;o
00002_nVU<<00ol0003o/Y_0ok:K`00Aok:K`003o`000?noY;ko_jBn00Co_jBn00?o0000olV_`?o9
[l003Oo9[l001Ol0003oe[RlomJh_?oF^;co000000gog/2j00?o0000omk0^_l000002?oVbKX01?l0
003ok<Zaonc:/Ol00009oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01oocfKD0
0ol0003oooooooooo`0Xooooo`009oooool3o`0001Wooooo00?o0000oj>ljonS_>/03?nS_>/9o`00
00KoRk;`00?o0000ogNTk_mgY>h02_mgY>h01?l0003oJiKYof^FjOm[U^T7o`000003oh>OiOl0003o
PYCL00[oPYCL00?o0000ohF=e?n5SM@02on5SM@00ol0003oRhW<oh^9c00;oh^9c003o`000?nBR<Ko
TXS600SoTXS60_l00002oi:8aP03o`000?nIRL7oVHW100koVHW100Co0000oj:=__nRSKkoXXfn0_l0
000<ojJD``03o`000?nbVl3o/Y_0017o/Y_000?o0000oknT__noY;h00onoY;h00ol0003obJo0olV_
`00?olV_`004o`000?oF^;coe[Rlo`0000kog/2j00?o0000onK9^_oVbKX02?oVbKX00ol0003ok<Za
o`000008oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD02?ocfKD2o`0002Wooooo
000Wooooo`03o`000?oooooooooo01[ooooo00?o0000oj>ljonS_>/02?nS_>/3o`0000?oX;_/00?o
0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP0:ogNTkP03o`000?m[U^WoJiKY00OoJiKY1_l0
0008oh:Dg003o`000?n5SMCoQHgD00[oQHgD00?o0000oh^9c?n;RL`03?n;RL`00ol0003oTXS6oi:8
aP04oi:8aP?o00001?nBR<H00ol0003oVHW1oiV9`@0>oiV9`@04o`000?nRSKko0000o`0000koYYC3
00?o0000ok:K`?nbVl004_nbVl001Ol0003o_jBnoknT__noY;ko000001;obJo000?o0000omJh_?l0
00003_oN`;X00ol0003oi/Vjo`00000:onK9^P03o`000?o`ck3ol<n`00Ool<n`00?o0000oo;C/Oob
dk401oobdk400ol0003olmVeoo?I]@07oo?I]@04o`000?obh;_o0000o`0002Sooooo000Looooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Kooooo`03o`000?nS_>_oXkc[
00CoXkc[0ol00007oj2kk003o`000?n;/_3oRk;`00[oRk;`00?o0000ogNTk_mgY>h02_mgY>h00ol0
003oJiKYof^Fj@08of^Fj@04o`000?mYS>7oJHcQofV<h@Oo000000?oPYCLo`000?n5SM@03?n5SM@0
0ol0003oRhW<oh^9c00;oh^9c004o`000?nBR<KoTXS6oi:8aP?o00001onBR<H00ol0003oVHW1oiV9
`@0=oiV9`@?o00004OnVU<<00ol0003o/Y_0ok:K`00Aok:K`004o`000?noY;ko_jBno`0001CobJo0
00?o0000omk0^_oN`;X03OoN`;X00ol0003oi/Vjo`00000:onK9^P03o`000?o`ck3ol<n`00Kol<n`
00?o0000oo;C/Oobdk401oobdk400ol0003olmVeoo?I]@08oo?I]@04o`000?obh;_ol^2ko`0000So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00_ooooo000Looooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0L
ooooo`03o`000?nS_>_oXkc[00?o00002onP^n`00ol0003oRk;`oh^bl00:oh^bl003o`000?mgY>ko
MjC^00[oMjC^00?o0000of^FjOm[U^T02?m[U^T00ol0003oJHcQofV<h@07ofV<h@Oo00002?n5SM@0
0ol0003oRhW<oh^9c00<oh^9c0?o00002onBR<H00ol0003oVHW1oiV9`@08oiV9`@Co00000_nHS/L0
0ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_0017o/Y_000?o0000oknT__l000005Oo9[l00
0ol0003og/2jomk0^P0<omk0^P05o`000?oVbK[oi/VjonK9^_l000002?oVbKX00ol0003ok=:jo`00
0007oo3?/003o`000?obdk7ol]>a00Ool]>a00?o0000oo?I]OocfKD01oocfKD01?l0003ol^2koo;P
^oobh;/2o`0000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00_ooooo000Looooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`0Nooooo`;o00003onP^n`00ol0003oRk;`oh^bl00:oh^bl003o`000?mgY>koMjC^
00WoMjC^00?o0000of^FjOm[U^T02Om[U^T00ol0003oJHcQofV<h@08ofV<h@03o`000?maQmWoLHOI
00;oLHOI1ol000000on5SMCo0000oh^9c00:oh^9c0Co00003OnBR<H00ol0003oVHW1oiV9`@04oiV9
`@Co00001onHS/L00ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_0013o/Y_00_l0000EolV_
`003o`000?oB^/;o000000gog/2j00?o0000onK9^_oVbKX00_oVbKX00ol0003oi/VjonK9^P05onK9
^P04o`000?o/d[[ok=:jo`0000Kol<n`00?o0000oo;C/Oobdk401_obdk400ol0003olmVeoo?I]@07
oo?I]@03o`000?obh;_ol^2k00?ol^2k0_l00006ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000_ooooo000Looooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?nP^ncoX;_/00goX;_/00?o0000oh^bl?n;/_00
2_n;/_000ol0003oMjC^ogNTkP09ogNTkP03o`000?m[U^WoJiKY00SoJiKY00?o0000ofV<hOmYS>40
2OmYS>400ol0003oLHOIog67f@08og67f@go00000on;RL`00ol0003oTXS6oi:8aP0;oi:8aP03o`00
0?nIRL7oVHW100Co00002onHS/L00ol0003oYYC3ojJD``0?ojJD``03o`000?nbVl3o/Y_000oo/Y_0
00?o0000okZVa?l000005?o9[l001Ol0003od[[2om:j`_oB^/;o000000_og/2j00?o0000onK9^_oV
bKX01?oVbKX00ol0003oi/VjonK9^P03onK9^P03o`000?o/d[[ok=:j00;ok=:j00?o0000oo3?/?o`
ck000_o`ck000ol0003ol]>aoo;C/@07oo;C/@03o`000?ocfKGolmVe00OolmVe00?o0000oo;P^oob
h;/00oobh;/2o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S802oooool001cooooo00Go0000ooooooooooooooooo`000005ooooo`;o00008_ooool0
0ol0003oX;_/oj2kk00=oj2kk003o`000?n;/_3oRk;`00[oRk;`00?o0000ogNTk_mgY>h02OmgY>h0
0ol0003oJiKYof^Fj@08of^Fj@03o`000?mYS>7oJHcQ00WoJHcQ00?o0000og67fOmaQmT02OmaQmT0
0ol0003oOHOBogf7dP02ogf7dP?o000000?oOHOBo`000?l000005?l0000?oiR>a`03o`000?nVU<?o
YYC3013oYYC300?o0000ok:K`?nbVl003OnbVl001Ol0003o^ZK4okZVa?njY/Co000001;obJo000?o
0000om:j`_oB^/800_oB^/800ol0003og/2jomk0^P09omk0^P03o`000?oVbK[oi/Vj00Coi/Vj00?o
0000onK9^_oVbKX00_oVbKX00ol0003ok=:joncB^P03oncB^P03o`000?o`ck3ol<n`00;ol<n`00?o
0000oo;C/Oobdk401_obdk400ol0003olmVeoo?I]@07oo?I]@03o`000?obh;_ol^2k00Gol^2k0_l0
0005ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00_o
oooo000Looooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Rooooo`03
o`000?nP^ncoX;_/00goX;_/00?o0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP08ogNTkP03
o`000?m[U^WoJiKY00SoJiKY00?o0000ofV<hOmYS>402OmYS>400ol0003oLHOIog67f@0:og67f@04
o`000?mmQm;o0000o`0000[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0?oiR>
a`03o`000?nVU<?oYYC300ooYYC300?o0000ok:K`?nbVl003?nbVl000ol0003o^ZK4okZVa002okZV
a003o`000?o9[l3obJo000oobJo000?o0000om:j`_oB^/801?oB^/800ol0003og/2jomk0^P07omk0
^P03o`000?oVbK[oi/Vj00Koi/Vj00Go0000onK9^_oVbK[oi/Vjo`000006oncB^P04o`000?o`ck3o
l<n`o`0000Wol]>a00?o0000oo?I]OocfKD01oocfKD00ol0003ol^2koo;P^`06oo;P^`;o00001?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400;ooooo`00
7?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool08oooool2o`0000ko
X;_/00?o0000oh^bl?n;/_002_n;/_000ol0003oMjC^ogNTkP08ogNTkP03o`000?m[U^WoJiKY00So
JiKY00?o0000ofV<hOmYS>402OmYS>400ol0003oLHOIog67f@08og67f@?o00003OmmQm800ol0003o
RhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700koV8k700?o0000ojJD`onVU<<03onVU<<00ol0003o
/Y_0ok:K`00:ok:K`0;o00001_njY/@00ol0003obJo0olV_`00>olV_`003o`000?oB^/;od[[200Co
d[[200?o0000omk0^_oN`;X01_oN`;X00ol0003oi/VjonK9^P08onK9^P03o`000?oVbK[o000000So
k=:j00?o0000oo3?/?l000002?obdk400ol0003olmVeoo?I]@07oo?I]@03o`000?obh;_ol^2k00Oo
l^2k0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000_ooooo000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0U
ooooo`03o`000?nP^ncoX;_/00[oX;_/5_l00004ogNTkP03o`000?m[U^WoJiKY00SoJiKY00?o0000
ofV<hOmYS>402?mYS>400ol0003oLHOIog67f@05og67f@?o00000_maQmT00ol0003oOHOBogf7dP0;
ogf7dP03o`000?n;RLcoRhW<00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003oYYC3ojJD``0@
ojJD``03o`000?nbVl3o/Y_000So/Y_000?o0000okZVa?njY/@01_njY/@00ol0003obJo0olV_`00=
olV_`003o`000?oB^/;od[[200Kod[[200?o0000omk0^_oN`;X01OoN`;X00ol0003oi/VjonK9^P08
onK9^P03o`000?oVbK[o000000Wok=:j00?o0000oo;C/Oobdk401oobdk400ol0003olmVeoo?I]@07
oo?I]@03o`000?obh;_ol^2k00Kol^2k00Co0000onkXaol0003o00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0;ooooo`009Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?nP^ncoX;_/00GoX;_/1?l00003oijjk@03o`000?n0[_;oP:kb00WoP:kb
00?o0000of:Kl?mRVo001?mRVo08o`0000OoJiKY00?o0000ofV<hOmYS>402OmYS>401?l0003oLHOI
og67fOmaQmT3o`0000GoLHOI00?o0000ogf7d_mmQm802ommQm800ol0003oRhW<oh^9c00<oh^9c003
o`000?nHS/OoV8k700koV8k700?o0000ojJD`onVU<<03onVU<<00ol0003o/Y_0ok:K`007ok:K`003
o`000?njY/Co^ZK400So^ZK400?o0000olV_`?o9[l002oo9[l000ol0003od[[2om:j`P08om:j`P03
o`000?oN`;[og/2j00?og/2j00?o0000onK9^_oVbKX02_oVbKX00ol0003ok=:joncB^P08oncB^P03
o`000?obdk7ol]>a00Kol]>a00?o0000oo?I]OocfKD01oocfKD00ol0003ol^2koo;P^`06oo;P^`04
o`000?o^j<Ook^S7onkXa`;o00008_ooool002Gooooo00?o0000ooooooooool0:?ooool00ol0003o
X;_/oj2kk004o`0000SoW[[]00?o0000oh2^l_n0[_802On0[_800ol0003oHY_`of:Kl008of:Kl003
o`000?m>R^WoCX[Y00?o00001Om[U^T00ol0003oJHcQofV<h@09ofV<h@?o00002OmaQmT00ol0003o
OHOBogf7dP0;ogf7dP03o`000?n;RLcoRhW<00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003o
YYC3ojJD``0@ojJD``03o`000?nbVl3o/Y_000Go/Y_000?o0000okZVa?njY/@02OnjY/@00ol0003o
bJo0olV_`00:olV_`003o`000?oB^/;od[[200Wod[[200?o0000omk0^_oN`;X00ooN`;X00ol0003o
i/VjonK9^P0:onK9^P;o00002?o/d[X00ol0003ol=flo`000007oo;C/@03o`000?ocfKGolmVe00Ko
lmVe00?o0000oo;P^oobh;/01oobh;/01?l0003ok^S7onkXaoo^j<L2o`0002;ooooo000Uooooo`;o
0000:_ooool2o`0000goW[[]00?o0000oh2^l_n0[_802On0[_800ol0003oHY_`of:Kl008of:Kl003
o`000?m>R^WoCX[Y00;oCX[Y0ol00002of^Fj@03o`000?mYS>7oJHcQ00KoJHcQ1?l0000;og67f@03
o`000?mmQm;oOHOB00_oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0?oiR>a`03
o`000?nVU<?oYYC300ooYYC300?o0000ok:K`?nbVl000onbVl02o`0000go^ZK400?o0000olV_`?o9
[l002?o9[l000ol0003od[[2om:j`P0;om:j`P05o`000?oN`;[og/2jomk0^_l000003?oVbKX01?l0
003ok=:joncB^_l00007oncB^P04o`000?o`gKcol=flo`0000Gol]>a00?o0000oo?I]OocfKD01ooc
fKD00ol0003ol^2koo;P^`06oo;P^`03o`000?o^j<Ook^S700?ok^S70_l0000Qooooo`009Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?nN^^goW[[]00goW[[]00?o0000oh2^l_n0[_802On0[_80
0ol0003oHY_`of:Kl008of:Kl003o`000?m>R^WoCX[Y00CoCX[Y1?l00004ofV<h@?o00001?mYS>40
0ol0003oLHOIog67f@09og67f@03o`000?mmQm;oOHOB00_oOHOB00?o0000oh^9c?n;RL`02on;RL`0
0ol0003oV8k7oiR>a`0>oiR>a`03o`000?nVU<?oYYC3013oYYC300Go0000ok:K`?nbVl3o/Y_0o`00
000?okZVa003o`000?o9[l3obJo000SobJo000?o0000om:j`_oB^/802ooB^/801?l0003og/2jomk0
^_l0000=onK9^P04o`000?o/d[[ok=:jo`0000Kok=:j00?o0000oo3M_?o`gK`00_o`gK`00ol0003o
l]>aoo;C/@02oo;C/@03o`000?ocfKGolmVe00KolmVe00?o0000oo;P^oobh;/01_obh;/00ol0003o
k^S7onkXa`05onkXa`;o00008?ooool002Gooooo00?o0000ooooooooool0:_ooool00ol0003oW[[]
oijjk@0=oijjk@03o`000?n0[_;oP:kb00WoP:kb00?o0000of:Kl?mRVo002?mRVo000ol0003oCX[Y
odj:j@06odj:j@Go00001omYS>400ol0003oLHOIog67f@0:og67f@03o`000?mmQm;oOHOB00[oOHOB
00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0>oiR>a`03o`000?nVU<?oYYC3013oYYC3
00Co0000ok:K`?nbVl3o00004?njY/@00ol0003obJo0olV_`007olV_`003o`000?oB^/;od[[200go
d[[200?o0000omk0^_l000003?oVbKX00ol0003ok=:joncB^P02oncB^P03o`000?o/d[[ok=:j00;o
k=:j00?o0000oo3M_?o`gK`01?o`gK`01?l0003ol]>aoo;C/Ol00009oo?I]@03o`000?obh;_ol^2k
00Kol^2k00?o0000onkXaoo^j<L01Oo^j<L2o`00023ooooo000Uooooo`03o`000?oooooooooo02_o
oooo00?o0000oijjkOnN^^d03OnN^^d00ol0003oP:kboh2^lP09oh2^lP03o`000?mRVo3oHY_`00So
HY_`00?o0000odj:jOm>R^T01Om>R^T2o`0000;oBh7S0ol00006ofV<h@03o`000?maQmWoLHOI00Wo
LHOI00?o0000ogf7d_mmQm802ommQm800ol0003oRhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700ko
V8k700?o0000ojJD`onVU<<03onVU<<00ol0003o/Y_0o`00000BokZVa003o`000?o9[l3obJo000Go
bJo000?o0000om:j`_oB^/803ooB^/800ol0003oi/VjonK9^P0:onK9^P03o`000?o/d[[ok=:j00Co
k=:j00Go0000oncB^_o/d[[ok=:jo`000007oo3M_003o`000?obdk7o000000SolmVe00?o0000oo;P
^oobh;/01_obh;/00ol0003ok^S7onkXa`07onkXa`;o00007oooool002Gooooo00?o0000oooooooo
ool0;?ooool00ol0003oW[[]oijjk@0=oijjk@03o`000?n0[_;oP:kb00WoP:kb00?o0000of:Kl?mR
Vo002?mRVo001?l0003oCX[Yodj:jOm>R^T3o`0000;oCX[Y00?o0000od^1hom;PN<00_m;PN<4o`00
00?oJHcQ00?o0000og67fOmaQmT02OmaQmT00ol0003oOHOBogf7dP0:ogf7dP03o`000?n;RLcoRhW<
00_oRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0003oYYC3ojJD``0?ojJD``;o00004onjY/@00ol0
003obJo0olV_`004olV_`003o`000?oB^/;od[[2013od[[200?o0000onK9^_oVbKX02_oVbKX00ol0
003ok=:joncB^P04oncB^P04o`000?o/d[[ok=:jo`0000Wol=fl00?o0000oo?I]OocfKD01oocfKD0
0ol0003ol^2koo;P^`05oo;P^`03o`000?o^j<Ook^S700Wok^S70_l0000Nooooo`009?ooool00ol0
003oooooooooo`0^ooooo`03o`000?nN^^goW[[]00goW[[]00?o0000oh2^l_n0[_802On0[_800ol0
003oHY_`of:Kl007of:Kl0Co00001_m>R^T00ol0003oBh7Sod^1h`05od^1h`Co00002omaQmT00ol0
003oOHOBogf7dP0:ogf7dP03o`000?n;RLcoRhW<00coRhW<00?o0000oiR>aonHS/L03_nHS/L00ol0
003oYYC3ojJD``0<ojJD``;o000000?oZYg9o`000?njY/@04onjY/@00ol0003obJo0olV_`003olV_
`003o`000?oB^/;od[[200ood[[200?o0000omc7aOl000002_oVbKX00ol0003ok=:joncB^P06oncB
^P03o`000?o/d[[o000000Wol=fl0_l00007oo?I]@03o`000?obh;_ol^2k00Kol^2k00?o0000onkX
aoo^j<L02Oo^j<L2o`0001kooooo000Tooooo`;o0000<?ooool00ol0003oW[[]oijjk@0;oijjkA7o
00001?mRVo04o`0000WoCX[Y00?o0000od^1hom;PN<01om;PN<4o`0000WoLHOI00?o0000ogf7d_mm
Qm802_mmQm800ol0003oRhW<oh^9c00;oh^9c003o`000?nHS/OoV8k700koV8k700?o0000ojJD`onV
U<<02OnVU<<3o`0000CoZYg900?o0000okZVa?njY/@04OnjY/@00ol0003obJo0olV_`002olV_`003
o`000?oB^/;od[[200ood[[200Go0000omc7aOoLalGog<O5o`000009onK9^P03o`000?o/d[[ok=:j
00Ook=:j00?o0000oo3M_?o`gK`01oo`gK`01?l0003ol^Rooo;X_ol00006oo?I]@03o`000?obh;_o
l^2k00Gol^2k00?o0000onkXaoo^j<L02Oo^j<L01?l0003oho3Go`000?l0000Mooooo`009?ooool0
0ol0003oooooooooo`0`ooooo`03o`000?nN^^goW[[]00GoW[[]1Ol00003oibik@03o`000?mgZo?o
Mj_c00WoMj_c00?o0000odjCkol000001?l00003of:Kl003o`000?m>R^WoCX[Y00KoCX[Y00?o0000
od^1hom;PN<02?m;PN<00ol0003oEh3OoeN0g`03o`0000KoLHOI00?o0000ogf7d_mmQm802_mmQm80
0ol0003oRhW<oh^9c00<oh^9c003o`000?nHS/OoV8k700goV8k700?o0000ojJD`onVU<<01onVU<<2
o`0000OoZYg900?o0000okZVa?njY/@04_njY/@01?l0003obJo0olV_`?l0000Aom:j`P03o`000?oL
alGog<O500;og<O500?o0000onK9^_oVbKX01_oVbKX00ol0003ok=:joncB^P07oncB^P03o`000?o`
gKco000000Sol=fl00Go0000oo;X_oobj;ool^Roo`000004oo?I]@03o`000?obh;_ol^2k00Kol^2k
00?o0000onkXaoo^j<L02?o^j<L01?l0003oho3Gon?`eooSl=L2o`0001cooooo000Tooooo`03o`00
0?oooooooooo037ooooo00?o0000oijjkOnN^^d01?l00009oibik@03o`000?mgZo?oMj_c00SoMj_c
0ol00004odjCk`Go00002?m>R^T00ol0003oBh7Sod^1h`08od^1h`03o`000?mGP=ooEh3O00;oEh3O
1?l00003og67f@03o`000?mmQm;oOHOB00[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7
oiR>a`0>oiR>a`03o`000?nVU<?oYYC300CoYYC30_l0000:ojZMb@03o`000?njY/Co^ZK4017o^ZK4
00?o0000olV_`?l000004_oB^/800ol0003og<O5omc7a@03omc7a@03o`000?oVbK[oi/Vj00Goi/Vj
00?o0000oncB^_o/d[X01oo/d[X00ol0003ol=flo`000007oo3M_003o`000?obj;ool^Ro00?ol^Ro
00Co0000oo?I]OocfKGo00002?obh;/00ol0003ok^S7onkXa`08onkXa`03o`000?oSl=Ooho3G00;o
ho3G0_l0000Looooo`009?ooool00ol0003oooooooooo`0booooo`;o00003_nL^Nd00ol0003oMj_c
ogN[l`04ogN[l`?o00000_mgZo<00ol0003oCY?_odjCk`06odjCk`?o00001om>R^T00ol0003oBh7S
od^1h`08od^1h`03o`000?mGP=ooEh3O00GoEh3O1?l0000<ogf7dP03o`000?n;RLcoRhW<00coRhW<
00?o0000oiR>aonHS/L03OnHS/L01?l0003oYYC3ojJD`onVU<<3o`0000coZYg900?o0000okZVa?nj
Y/@04OnjY/@2o`0001;od[[200?o0000omc7aOoLalD01OoLalD00ol0003oi/VjonK9^P03onK9^P03
o`000?o/d[[ok=:j00Ook=:j00Go0000oo3M_?o`gKcol=flo`000005oo3M_003o`000?obj;ool^Ro
00Gol^Ro00?o0000oo?I]Ol000001oobh;/00ol0003ok^S7onkXa`08onkXa`03o`000?oSl=Ooho3G
00Coho3G0_l0000Kooooo`009?ooool00ol0003oooooooooo`0dooooo`03o`000?nL^NgoW;W]00co
W;W]00Co0000ogN[lomgZo?oMj_c0_l00006ogN[l`03o`000?m>TnooCY?_00KoCY?_00?o0000oc1n
iol000000_l00005odj:j@03o`000?m;PN?oBh7S00OoBh7S00?o0000oeN0gomGP=l02?mGP=l4o`00
00[oOHOB00?o0000oh^9c?n;RL`02on;RL`00ol0003oV8k7oiR>a`0=oiR>a`04o`000?nVU<?o0000
o`0000ooZYg900?o0000okZVa?njY/@04?njY/@00ol0003o`k?:o`00000Aom:j`P03o`000?oLalGo
g<O500Kog<O500?o0000onK9^_oVbKX00ooVbKX00ol0003ok=:joncB^P07oncB^P03o`000?o`gKco
l=fl00;ol=fl00?o0000oo3M_?o`gK`00_o`gK`00ol0003ol^Rooo;X_`06oo;X_`03o`000?obh;_o
l^2k00Kol^2k00?o0000onkXaoo^j<L01oo^j<L00ol0003oho3Gon?`e`05on?`e`;o00006oooool0
02?ooooo00?o0000ooooooooool0=_ooool00ol0003oW;W]oibik@0<oibik@?o00002OmgZo<00ol0
003oCY?_odjCk`06odjCk`04o`000?l`O^Oo<7kWoc1ni`?o00000_m>R^T00ol0003oBh7Sod^1h`08
od^1h`03o`000?mGP=ooEh3O00SoEh3O00?o0000of^4f_m[Q=X01Ol00005ogf7dP03o`000?n;RLco
RhW<00_oRhW<00?o0000oiR>aonHS/L03?nHS/L3o`0001;oZYg900?o0000okZVa?njY/@03_njY/@0
1Ol0003o`k?:ol>cb_o3/l[o000000ood[[200?o0000omc7aOoLalD02?oLalD01Ol0003oi/VjonK9
^_oVbK[o000000Wok=:j00?o0000oo3M_?o`gK`01?o`gK`01?l0003ol=floo3M_?l00009oo;X_`;o
00001_obh;/00ol0003ok^S7onkXa`07onkXa`03o`000?oSl=Ooho3G00Ooho3G0_l0000Jooooo`00
8oooool3o`0003Oooooo00?o0000oibikOnL^Nd02?nL^Nd3o`000003oibikOl0003oMj_c00[oMj_c
00?o0000odjCkom>Tnl01_m>Tnl00ol0003o<7kWoc1ni`03oc1ni`;o000000?oCX[Yo`000?m;PN<0
2?m;PN<00ol0003oEh3OoeN0g`09oeN0g`03o`000?m[Q=[oJhCJ00CoJhCJ1_l0000>oh^9c003o`00
0?nHS/OoV8k700KoV8k71Ol00002oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@0
3OnjY/@00ol0003o`k?:ol>cbP02ol>cbP03o`000?oB^/;od[[200god[[200?o0000omc7aOoLalD0
2?oLalD01?l0003oi/VjonK9^_l0000:oncB^P03o`000?o`gKcol=fl00Col=fl00Co0000oo3M_?o`
gKco00002?obj;l01?l0003okoC3onod`ol00004oo;P^`03o`000?o^j<Ook^S700Ook^S700?o0000
on?`eooSl=L02?oSl=L3o`0001Wooooo000Sooooo`03o`000?oooooooooo03Sooooo00?o0000oibi
kOnL^Nd01?nL^Nd3o`0000GoW;W]00?o0000ogN[lomgZo<02OmgZo<00ol0003oCY?_odjCk`06odjC
k`03o`000?l`O^Oo<7kW00Co<7kW0ol00009od^1h`03o`000?mGP=ooEh3O00SoEh3O00?o0000of^4
f_m[Q=X02Om[Q=X:o`0000GoRhW<00Co0000oiR>aonHS/OoV8k71Ol00008oiNDc`03o`000?nZWLWo
ZYg9013oZYg900?o0000okZVa?njY/@02onjY/@00ol0003o`k?:ol>cbP04ol>cbP03o`000?oB^/;o
d[[200_od[[200?o0000omc7aOoLalD02_oLalD00ol0003oi/Vjo`000009oncB^P03o`000?o`gKco
l=fl00Kol=fl0_l00008oo;X_`03o`000?o_m<?okoC300;okoC300Go0000oo;P^oobh;_ol^2ko`00
0008onkXa`03o`000?oSl=Ooho3G00Soho3G00?o0000olWbkOl000000_l00008ooooo`Co000000?o
410@ooooooooool02Oooool000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0>Oooool00ol0003oW;W]oibik@03o`0000OoW;W]2_l0
0004ogN[l`03o`000?m>TnooCY?_00KoCY?_00?o0000oc1niol`O^L01_l`O^L2o`0000SoBh7S00?o
0000oeN0gomGP=l02?mGP=l00ol0003oJhCJof^4fP09of^4fP03o`000?n2S=GoPXcE00KoPXcE2Ol0
000=oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@02_njY/@00ol0003o`k?:ol>c
bP06ol>cbP03o`000?oB^/;od[[200Wod[[200?o0000omc7aOoLalD03?oLalD00ol0003ok=:joncB
^P07oncB^P03o`000?o`gKcol=fl00Sol=fl00?o0000oo;X_oobj;l01_obj;l00ol0003okoC3onod
``03onod``03o`000?obh;_o000000Sok^S700?o0000on?`eooSl=L01ooSl=L2o`0000?obO;]0_l0
000:ooooo`03o`000?oooooooooo00_ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03Wooooo
0ol00006oibik@Co00001?nJ^Nh00ol0003oL:Sdog2Xm003og2Xm0So00001_m>Tnl00ol0003o<7kW
oc1ni`05oc1ni`03o`000?lWLn7o000000;o00001Om;PN<00ol0003oEh3OoeN0g`08oeN0g`03o`00
0?m[Q=[oJhCJ00[oJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0>oiNDc`03o`00
0?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@01onjY/@2o`0000Wo`k?:00?o0000om:j`_oB^/80
2?oB^/800ol0003og<O5omc7a@0=omc7a@03o`000?o/d[[ok=:j00Ook=:j00?o0000oo3M_?o`gK`0
1oo`gK`2o`0000Ool^Ro00?o0000onod`oo_m<<01Oo_m<<2o`0000Ook^S700?o0000on?`eooSl=L0
1ooSl=L00ol0003obO;]olWbk@04olWbk@;o00002Oooool00ol0003oooooooooo`0;ooooo`002?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003ooooo
ooooo`0fooooo`?o00000_ooool00ol0003oW;W]oibik@04o`0000WoV[W^00?o0000og2Xm?m`Z?@0
2?m`Z?@00ol0003o?Hg^o`000003o`0000?oCY?_00?o0000oc1niol`O^L01Ol`O^L01?l0003o9g?Q
obMchOlWLn43o`0000?oBh7S00?o0000oeN0gomGP=l02?mGP=l00ol0003oJhCJof^4fP09of^4fP03
o`000?n2S=GoPXcE00coPXcE00?o0000oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@0@ojZMb@03
o`000?njY/Co^ZK400Ko^ZK400?o0000ol>cb_o3/lX02_o3/lX00ol0003od[[2om:j`P07om:j`P03
o`000?oLalGog<O500cog<O500?o0000onCFb?l000001oo/d[X00ol0003ol=floo3M_007oo3M_004
o`000?obj;ool^Roo`0000Gol^Ro00?o0000onod`oo_m<<01_o_m<<01?l0003oh_g8o`000?l00004
onkXa`03o`000?oSl=Ooho3G00Koho3G0_l00007olWbk@;o00002Oooool00ol0003oooooooooo`0;
ooooo`002?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ol0003oooooooooo`0eooooo`;o00001_ooool2o`0000koV[W^00?o0000og2Xm?m`Z?@02?m`Z?@0
0ol0003o?Hg^ocf=kP02ocf=kPGo00001ol`O^L00ol0003o9g?QobMch@03obMch@;o000000?oBh7S
o`000?mGP=l02OmGP=l00ol0003oJhCJof^4fP0:of^4fP03o`000?n2S=GoPXcE00_oPXcE00?o0000
oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@0AojZMb@03o`000?njY/Co^ZK400Co^ZK400?o0000
ol>cb_o3/lX02oo3/lX00ol0003od[[2om:j`P06om:j`P03o`000?oLalGog<O500cog<O500Go0000
onCFb?oTe/Soi=K8o`000006oncB^P03o`000?o`gKcol=fl00Ool=fl00Go0000oo;X_oobj;ool^Ro
o`000004oo;X_`03o`000?o_m<?okoC300GokoC300?o0000on;mb?oRoLP00_oRoLP2o`000003onkX
aol0003oho3G00Ooho3G00?o0000olWbkOo9l^d02?o9l^d2o`0000Sooooo00?o0000ooooooooool0
2oooool000Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0<_ooool3o`0000Wooooo00?o0000oiZik_nJ^Nh03OnJ^Nh00ol0003oL:Sd
og2Xm008og2Xm003o`000?lmSNko?Hg^00Go?Hg^0ol00006oc1ni`03o`000?lWLn7o9g?Q00Co9g?Q
0ol0000:oeN0g`03o`000?m[Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D03?n2S=D00ol0003oUiC?
oiNDc`0=oiNDc`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@00onjY/@00ol0003o`k?:
ol>cbP0=ol>cbP03o`000?oB^/;od[[200Cod[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8
onCFb003onCFb003o`000?o/d[[ok=:j00;ok=:j00?o0000oo3M_?o`gK`01oo`gK`00ol0003ol^Ro
oo;X_`03oo;X_`04o`000?obj;ool^Roo`0000OokoC300?o0000on;mb?oRoLP01?oRoLP3o`0000Oo
ho3G00?o0000olWbkOo9l^d02Oo9l^d3o`0000Oooooo00?o0000ooooooooool02oooool000Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo0_l0000`ooooo`?o
00003Oooool00ol0003oV[W^oiZikP0=oiZikP03o`000?m`Z?CoL:Sd00SoL:Sd00?o0000ocf=k_lm
SNh01OlmSNh01?l0003o57;Qo`000?l00005oc1ni`03o`000?lWLn7o9g?Q00Ko9g?Q0_l00009oeN0
g`03o`000?m[Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0=oiND
c`03o`000?nZWLWoZYg9013oZYg900?o0000okZVa?njY/@00_njY/@00ol0003o`k?:ol>cbP0>ol>c
bP03o`000?oB^/;od[[200?od[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8onCFb005onCF
b004o`000?o/d[[ok=:jo`0000[ol=fl00?o0000oo;X_oobj;l00oobj;l00ol0003ol^Roo`000007
onod``03o`000?oRoLSoh_g800Coh_g800Co0000ol7mbOo1oLWo`Og90_l00003on?`e`;o00003Oo9
l^d2o`0000Oooooo00?o0000ooooooooool02oooool000Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`0/ooooo`?o0000
4Oooool00ol0003oV[W^oiZikP0=oiZikP03o`000?m`Z?CoL:Sd00SoL:Sd00?o0000ocf=k_lmSNh0
1OlmSNh00ol0003o57;QoaAbh@02o`0000?o<7kW00?o0000obMchOlWLn401_lWLn400ol0003o=GKQ
o`000002o`0000KoEh3O00?o0000of^4f_m[Q=X02Om[Q=X00ol0003oPXcEoh:<e@0;oh:<e@03o`00
0?nGU<ooUiC?00koUiC?00?o0000ojZMbOnZWLT04?nZWLT01?l0003o^ZK4okZVa?l0000Bol>cbP03
o`000?oB^/;od[[200;od[[200?o0000omc7aOoLalD03?oLalD00ol0003oi=K8onCFb006onCFb003
o`000?o/d[[o000000Wol=fl00?o0000oo;X_oobj;l01Oobj;l2o`0000KokoC300?o0000on;mb?oR
oLP01?oRoLP00ol0003o`Og9ol7mb@04ol7mb@03o`000?oSl=Oo000000kobO;]0ol00005ooooo`03
oeEEEOmVIVKo000000gooooo0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0:Oooool3o`0001Gooooo00?o0000oiZi
k_nJ^Nh03OnJ^Nh00ol0003oL:Sdog2Xm008og2Xm003o`000?lmSNko?Hg^00Go?Hg^00Co0000oaAb
hOlDL^7o57;Q0ol000000ol`O^Oo0000obMch@07obMch@04o`000?leM^7o=GKQocEfh@;o00001OmG
P=l00ol0003oJhCJof^4fP09of^4fP03o`000?n2S=GoPXcE00_oPXcE00?o0000oiNDconGU<l03OnG
U<l00ol0003oZYg9ojZMb@0@ojZMb@03o`000?njY/Co000001Co`k?:00Co0000om:j`_oB^/;o0000
3_oLalD00ol0003oi=K8onCFb008onCFb0;o00002Oo`gK`00ol0003ol^Rooo;X_`05oo;X_`;o0000
1_o_m<<00ol0003oh_g8on;mb003on;mb003o`000?o1oLWo`Og900Go`Og90ol0000;olWbk@?o0000
0_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0Vooooo`?o00006Ooo
ool00ol0003oV[W^oiZikP0;oiZikPWo00001?m`Z?@00ol0003o?Hg^ocf=kP05ocf=kP03o`000?lD
L^7o57;Q00?o57;Q0ol00008obMch@03o`000?leM^7o=GKQ00;o=GKQ0_l00003oeN0g`03o`000?m[
Q=[oJhCJ00WoJhCJ00?o0000oh:<eOn2S=D02on2S=D00ol0003oUiC?oiNDc`0>oiNDc`03o`000?nZ
WLWoZYg900ooZYg90_l0000Eol>cbP03o`000?oB^/;o000000kog<O500?o0000onCFb?oTe/P02OoT
e/P00ol0003oj^O<o`000007oo3M_003o`000?obj;ool^Ro00Kol^Ro0_l00005onod``03o`000?oR
oLSoh_g800?oh_g800?o0000ol7mbOo1oLT01Oo1oLT01Ol0003oPnK0oh?V`?n3i/3o000000KobO;]
1?l00005ooooo`03o`000?oooooooooo01?ooooo000Qooooo`03o`000?oooooooooo02Cooooo0ol0
000Mooooo`03o`000?nJ^NkoV[W^00GoV[W^1Ol00003oiZikP03o`000?m^Z?CoKZSd00?oKZSd2?l0
0005ocf=kP03o`000?lDL^7o57;Q00Co57;Q0_l00007obMch@03o`000?leM^7o=GKQ00Co=GKQ0ol0
00000omGP=oo0000of^4fP09of^4fP03o`000?n2S=GoPXcE00coPXcE00?o0000oiNDconGU<l03OnG
U<l00ol0003oZYg9ojZMb@0=ojZMb@;o000000?o[j[Co`000?o3/lX05?o3/lX2o`0000kog<O500?o
0000onCFb?oTe/P02OoTe/P01Ol0003oj^O<on[Wc?oZilco000000Kol=fl00?o0000oo;X_oobj;l0
1Oobj;l01?l0003okoC3onod`ol00003onod``03o`000?oRoLSoh_g800?oh_g800?o0000ol7mbOo1
oLT01?o1oLT2o`0000GoPnK000?o0000olWbkOo9l^d00ol0000:ooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo02;ooooo0_l0000Qooooo`03o`000?nJ^NkoV[W^00Co0000
2OnJ^Nh00ol0003oKZSdofjXm008ofjXm003o`000?ldRngo000000;o00000olmSNh00ol0003o57;Q
oaAbh@05oaAbh@;o00001_lWLn400ol0003o=GKQocEfh@06ocEfh@;o00002om[Q=X00ol0003oPXcE
oh:<e@0;oh:<e@03o`000?nGU<ooUiC?00koUiC?00?o0000ojZMbOnZWLT02OnZWLT3o`0000Co[j[C
00?o0000ol>cb_o3/lX04Oo3/lX00ol0003ocLCBo`00000=omc7a@03o`000?oTe/Soi=K800Woi=K8
00?o0000on[Wc?oZil`00ooZil`00ol0003ol=floo3M_002oo3M_003o`000?obj;ool^Ro00Gol^Ro
00?o0000onod`oo_m<<00_o_m<<00ol0003okoC3o`000005on;mb003o`000?o1oLWo`Og900Co`Og9
00?o0000oh?V`?n3i/001?n3i/04o`0000gooooo00?o0000ooooooooool04_ooool0027ooooo0_l0
000Pooooo`?o00009?ooool2o`0000koV[W^00?o0000ofjXm?m^Z?@02?m^Z?@01?l0003o=8_]ocB;
kOldRnd3o`000003ocf=k_l0003o57;Q00Go57;Q00Co0000o`=UfOl0003o00001OlWLn400ol0003o
=GKQocEfh@07ocEfh@;o00002Om[Q=X00ol0003oPXcEoh:<e@0<oh:<e@03o`000?nGU<ooUiC?00go
UiC?00?o0000ojZMbOnZWLT01onZWLT2o`0000Oo[j[C00?o0000ol>cb_o3/lX04?o3/lX01Ol0003o
cLCBolg4d_o=a=;o000000cog<O500?o0000onCFb?oTe/P02?oTe/P00ol0003oj^O<on[Wc005on[W
c004o`000?o`gKcol=flo`0000Sol^Ro00?o0000onod`oo_m<<00oo_m<<00ol0003oh_g8on;mb003
on;mb003o`000?o1oLWo`Og900?o`Og90_l00004oh?V`0?o00004Oooool00ol0003oooooooooo`0B
ooooo`008Oooool00ol0003oooooooooo`0Looooo`?o0000:Oooool00ol0003oV[W^oiZikP0<oiZi
kP03o`000?m^Z?CoKZSd00SoKZSd00?o0000ocB;kOldRnd00oldRnd3o`0000Ko57;Q00?o0000o`=U
fOl3IMT00_l00003obMch@03o`000?leM^7o=GKQ00Oo=GKQ00?o0000oe:2h_l000000_l00007of^4
fP03o`000?n2S=GoPXcE00_oPXcE00?o0000oiNDconGU<l03OnGU<l00ol0003oZYg9ojZMb@05ojZM
b@;o00002_n_Z]<00ol0003o`k?:ol>cbP0>ol>cbP03o`000?o=a=;ocLCB00?ocLCB00?o0000omc7
aOoLalD02?oLalD00ol0003oi=K8onCFb009onCFb003o`000?oZilcoj^O<00Koj^O<00?o0000oo3M
_?l000001oobj;l00ol0003okoC3onod``03onod``;o00001?oRoLP00ol0003o`Og9ol7mb@02ol7m
b@;o00000on3i/03o`0001Cooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool06Oooool3o`0002gooooo00?o0000oiZik_nJ^Nh03?nJ^Nh00ol0003oKZSdofjXm008ofjXm003
o`000?ldRngo=8_]00Go=8_]0_l00005oaAbh@04o`000?l3IMWo0fGIo`=Uf@;o00000_lWLn400ol0
003o=GKQocEfh@07ocEfh@04o`000?mBP^;oDX;Roe:2hP?o00001?m[Q=X00ol0003oPXcEoh:<e@0<
oh:<e@03o`000?nGU<ooUiC?00goUiC?00Co0000ojZMbOnZWLWoZYg90ol0000=ojnZd`03o`000?o3
/l[o`k?:00co`k?:00?o0000olg4d_o=a=801?o=a=800ol0003og<O5omc7a@07omc7a@03o`000?oT
e/Soi=K800Woi=K800?o0000on[Wc?oZil`02?oZil`2o`0000Kol^Ro00?o0000onod`oo_m<<01?o_
m<<00ol0003oh_g8o`000002on;mb003o`000?o1oLWo`Og900;o`Og900?o0000oh?V`?n3i/000ol0
000Gooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo01Kooooo0ol0000a
ooooo`;o00003OnJ^Nh00ol0003oKZSdofjXm008ofjXm003o`000?ldRngo=8_]00Ko=8_]0_l00004
oaAbh@03o`000?l3IMWo0fGI00;o0fGI00Co0000obMchOlWLn7o00002OleM^400ol0003oDX;Roe:2
hP03oe:2hP?o00000_m[Q=X00ol0003oPXcEoh:<e@0;oh:<e@03o`000?nGU<ooUiC?00goUiC?00Co
0000ojZMbOl0003o00004?n_Z]<00ol0003o`k?:ol>cbP0;ol>cbP03o`000?o=a=;ocLCB00KocLCB
00?o0000omc7aOoLalD01OoLalD00ol0003oi=K8onCFb009onCFb003o`000?oZilcoj^O<00Woj^O<
00Co0000onShcOl0003o00001?obj;l00ol0003okoC3onod``03onod``04o`000?oRoLSoh_g8on;m
b0;o00000oo1oLT5o`0001[ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool04oooool3o`0003Kooooo00?o0000oiZik_nJ^Nh02onJ^Nh00ol0003oKZSdofjXm008ofjXm003
o`000?ldRngo=8_]00Ko=8_]0ol00003oaAbh@03o`000?l3IMWo0fGI00;o0fGI0ol00009ocEfh@03
o`000?mBP^;oDX;R00KoDX;R0ol0000=oh:<e@03o`000?nGU<ooUiC?00coUiC?0ol0000CojnZd`03
o`000?o3/l[o`k?:00So`k?:0_l0000:olg4dP03o`000?oLalGog<O500Cog<O500?o0000onCFb?oT
e/P02?oTe/P00ol0003oj^O<on[Wc009on[Wc003o`000?oXn<goj?S=00;oj?S=0_l000000oobj;oo
0000onod``04onod``03o`000?oRoLSoh_g800;oh_g80_l00002ol7mb@?o00007Oooool00ol0003o
ooooooooo`0Booooo`008?ooool00ol0003oooooooooo`0Aooooo`?o0000>_ooool00ol0003oV[W^
oiZikP08oiZikP[o00001?m^Z?@00ol0003o=8_]ocB;k@06ocB;k@03o`000?l0Jm_o000000;o0000
00?o57;Qo`000?l3IMT01?l3IMT2o`0000Wo=GKQ00?o0000oe:2h_mBP^802?mBP^85o`0000WoPXcE
00?o0000oiNDconGU<l01_nGU<l5o`0000;oUIoK00?o0000ojnZdon_Z]<04On_Z]<00ol0003o`k?:
ol>cbP07ol>cbP03o`000?o=a=;ocLCB00_ocLCB00?o0000omc7aOoLalD00_oLalD00ol0003oi=K8
onCFb009onCFb003o`000?oZilcoj^O<00Soj^O<00?o0000onShcOoXn<d01OoXn<d4o`0000;okoC3
00?o0000on;mb?oRoLP00_oRoLP00ol0003o`Og9o`000002o`00027ooooo00?o0000ooooooooool0
4Oooool0023ooooo00?o0000ooooooooool03oooool2o`0003kooooo00Co0000oiZik_nJ^NkoV[W^
1_l00005oiZikP03o`000?m_ZOCoKjWd00;oKjWd2?l00006ocB;k@04o`000?l0Jm_o06_Ko`1[f`?o
00001_l3IMT2o`0000Oo=GKQ00?o0000oe:2h_mBP^802?mBP^800ol0003oMI7QogFAh@02ogFAh@Oo
00000_n2S=D01?l0003oUiC?oiNDconGU<l5o`0000SoUIoK00?o0000ojnZdon_Z]<04On_Z]<00ol0
003o`k?:ol>cbP05ol>cbP03o`000?o=a=;ocLCB00cocLCB00Go0000omc7aOoLalGog<O5o`00000;
onCFb003o`000?oZilcoj^O<00Soj^O<00?o0000onShcOoXn<d01_oXn<d01?l0003oeOo5omGoaOoE
olD;o`0002;ooooo00?o0000ooooooooool04Oooool0023ooooo0_l0000=ooooo`?o0000@Oooool3
o`0000coV[W^00?o0000ofnYm?m_ZO@02?m_ZO@5o`0000?o=8_]00?o0000o`1[fol0Jm/00_l0Jm/2
o`0000Go0fGI00Co0000o`eYg?l0003o00001_leM^400ol0003oDX;Roe:2hP08oe:2hP03o`000?me
TN7oMI7Q00SoMI7Q1_l0000=oiFOf`03o`000?n_Z]?o[j[C017o[j[C00?o0000ol>cb_o3/lX01?o3
/lX00ol0003ocLCBolg4dP0>olg4dP03o`000?oLalGo000000_oi=K800?o0000on[Wc?oZil`02?oZ
il`00ol0003oj?S=onShc@06onShc@05o`000?oEolGoeOo5omGoaOl000001?nUkj`4o`0000?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003ooooooooo
o`09ooooo`?o0000AOooool00ol0003oV[W^oiZikP0<oiZikP03o`000?m_ZOCoKjWd00SoKjWd00Co
0000ocB=k_ldSNko=8g^1Ol00005o`1[f`;o00001?l3IMT00ol0003o3FWLo`eYg002o`0000Go=GKQ
00?o0000oe:2h_mBP^802?mBP^800ol0003oMI7QogFAh@0:ogFAh@03o`000?nEWm_oUIoK00koUIoK
00?o0000ojnZdon_Z]<04On_Z]<00ol0003o`k?:ol>cbP02ol>cbP03o`000?o=a=;ocLCB00oocLCB
0_l0000<onCFb003o`000?oZilcoj^O<00Ooj^O<00?o0000onShcOoXn<d01_oXn<d01Ol0003oeOo5
omGoaOoEolGo000000CoYNn/0ol00005ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool04Oooool0023ooooo00?o0000ooooooooool01_ooool3o`0004Wooooo00?o0000oiZik_nJ^Nh0
3?nJ^Nh00ol0003oKjWdofnYm008ofnYm003o`000?ldSNko=8g^00Co=8g^0ol00005o`1[f`;o0000
0ol3IMT01?l0003o3FWLo`eYg?l=JM`2o`0000?o=GKQ00?o0000oe:2h_mBP^802?mBP^800ol0003o
MI7QogFAh@0;ogFAh@03o`000?nEWm_oUIoK00goUIoK00?o0000ojnZdon_Z]<04_n_Z]<01?l0003o
`k?:ol>cb_l0000Aolg4dP04o`000?oEfM_oeMWKo`0000[oi=K800?o0000on[Wc?oZil`02?oZil`0
0ol0003oj?S=onShc@05onShc@05o`000?oEolGoeOo5omGoaOl000000onUkj`3o`0000Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003oooooooooo`03
ooooo`?o0000COooool00ol0003oV[W^oiZikP0<oiZikP03o`000?m_ZOCoKjWd00SoKjWd00?o0000
ocB=k_ldSNh01_ldSNh2o`0000Co06_K0ol00002o`=Uf@03o`000?l=JMco3FWL00;o3FWL0_l00002
ocEfh@03o`000?mBP^;oDX;R00SoDX;R00?o0000ogFAhOmeTN402_meTN400ol0003oUIoKoiFOf`0>
oiFOf`03o`000?n_Z]?o[j[C017o[j[C00?o0000ol>cb_l000004Oo=a=800ol0003oeMWKomGIf`02
omGIf`03o`000?oTe/Soi=K800Koi=K800?o0000on[Wc?oZil`02?oZil`00ol0003oj?S=onShc@05
onShc@05o`000?oEolGoeOo5omGoaOl000000onUkj`2o`0000_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Aooooo`007oooool01?l0003oooooooooooooool3o`00057ooooo00?o
0000oiZik_nJ^Nh03?nJ^Nh00ol0003oKjWdofnYm008ofnYm003o`000?ldSNko=8g^00Ko=8g^0ol0
0003o`1[f`06o`000?l0F<go0000o`000?l3IMWo00001Ol=JM`3o`0000[oDX;R00?o0000ogFAhOme
TN402omeTN400ol0003oUIoKoiFOf`0=oiFOf`03o`000?n_Z]?o[j[C017o[j[C0_l0000Aolg4dP03
o`000?oEfM_oeMWK00CoeMWK00?o0000onCFb?oTe/P01?oTe/P00ol0003oj^O<on[Wc008on[Wc003
o`000?oXn<goj?S=00Goj?S=00Go0000omGoaOoEolGoeOo5o`000003ojG_[003o`000?oooooooooo
00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`007oooool4o`0005Go
oooo00?o0000oiZik_nJ^Nh02_nJ^Nh9o`0000CoKjWd00?o0000ocB=k_ldSNh01_ldSNh00ol0003o
06_Ho`000002o`000007o`1[fol0003o05S=o`1HcOl0003o0fGIo`000006o`eYg0;o00002_mBP^80
0ol0003oMI7QogFAh@0;ogFAh@03o`000?nEWm_oUIoK00goUIoK00?o0000ojnZdon_Z]<03_n_Z]<2
o`000003okBmh?l0003ocLCB00oocLCB00?o0000omGIfooEfM/01_oEfM/00ol0003oi=K8onCFb003
onCFb003o`000?oZilcoj^O<00Ooj^O<00?o0000onShcOoXn<d01OoXn<d01Ol0003oeOo5omGoaOoE
olGo000000?oYNn/00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo013ooooo000Oooooo`;o0000F?ooool00ol0003oV[W^oiZikP05oiZikPCo00000onL^Nd0
0ol0003oMJceogF/m@03ogF/m@So00001_ldSNh01?l0003o06_Ho`1[f?l0JmP3o`0000;o05S=0ol0
0007o`eYg0;o00002OmBP^800ol0003oMI7QogFAh@0:ogFAh@03o`000?nEWm_oUIoK00koUIoK00?o
0000ojnZdon_Z]<02on_Z]<2o`0000Co];gP00?o0000olg4d_o=a=803?o=a=800ol0003oeMWKomGI
f`08omGIf`05o`000?oTe/Soi=K8onCFb?l000002OoZil`00ol0003oj?S=onShc@05onShc@05o`00
0?oEolGoeOo5omGoaOl000000_nUkj`2o`00017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`1Fooooo`03o`000?nJ^NkoV[W^00Co0000
2?nL^Nd00ol0003oMJceogF/m@09ogF/m@Go00000oldSNh00ol0003o06_Ho`1[f002o`1[f0;o0000
0ol0F<d2o`0000Ko3FWL00?o0000oc1niol000000_l00006oe:2hP03o`000?meTN7oMI7Q00_oMI7Q
00?o0000oiFOfonEWm/03OnEWm/00ol0003o[j[CojnZd`09ojnZd`;o00001ond_N000ol0003ocLCB
olg4dP0:olg4dP03o`000?oEfM_oeMWK00[oeMWK00?o0000onCFb?l000002_oZil`00ol0003oj?S=
onShc@04onShc@05o`000?oEolGoeOo5omGoaOl000000_nUkj`00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0
E_ooool2o`0000goW;W]00?o0000ogF/mOme[?D02Ome[?D01?l0003o?IGaocfElOlmUO45o`0000Go
06_H0_l00003o`1Hc@;o00001Ol=JM`01?l0003o<7kWoc1niol`O^L3o`0000CoDX;R00?o0000ogFA
hOmeTN402_meTN400ol0003oUIoKoiFOf`0>oiFOf`03o`000?n_Z]?o[j[C00Ko[j[C0_l00009okBm
h003o`000?o=a=;ocLCB00WocLCB00?o0000omGIfooEfM/02ooEfM/3o`0000Woj^O<00?o0000onSh
cOoXn<d01?oXn<d01Ol0003oeOo5omGoaOoEolGo000000;oYNn/00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo000Sooooo`03o`000?oooooooooo
05Kooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`000?lmUO7o?IGa
00Co?IGa0ol00005o`1[f0;o00000ol0F<d2o`0000Co3FWL00?o0000oc1niol`O^L00ol`O^L3o`00
0003oe:2h_l0003oMI7Q00coMI7Q00?o0000oiFOfonEWm/03OnEWm/00ol0003o[j[CojnZd`04ojnZ
d`;o00003?nd_N000ol0003ocLCBolg4dP07olg4dP03o`000?oEfM_oeMWK00_oeMWK00Co0000omS`
h_oHl>;of?3R0_l00006on[Wc003o`000?oXn<goj?S=00Coj?S=00Ko0000omGoaOoEolGoeOo5o`00
0?nUkj`2o`0001Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`009?oo
ool2o`0005Oooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`000?lm
UO7o?IGa00Ko?IGa0ol00003o`1[f0?o00000_l0F<d3o`0000?o3FWL00?o0000oc1niol`O^L01Ol`
O^L3o`0000coMI7Q00?o0000oiFOfonEWm/03_nEWm/01?l0003o[j[CojnZdon_Z]<2o`0000oo];gP
00?o0000olg4d_o=a=801Oo=a=800ol0003oeMWKomGIf`0;omGIf`03o`000?oHl>;of?3R00Cof?3R
00?o0000on[Wc?oZil`00_oZil`00ol0003oj?S=onShc@04onShc@04o`000?oEolGoeOo5omGoa@?o
00006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo000Vooooo`03o`00
0?oooooooooo05Gooooo00?o0000oibikOnL^Nd03?nL^Nd00ol0003oMJceogF/m@09ogF/m@03o`00
0?lmUO7o?IGa00Ko?IGa1Ol000000ol0JmSo0000o`000002o`000003o`1HcOl0003o05_>00;o0000
0_l=JM`00ol0003o<7kWoc1ni`07oc1ni`Co00002OmeTN400ol0003oUIoKoiFOf`0=oiFOf`04o`00
0?n_Z]?o0000o`00017o];gP00?o0000olg4d_o=a=801?o=a=800ol0003oeMWKomGIf`0;omGIf`03
o`000?oHl>;of?3R00Kof?3R0_l000000ooZilco0000onShc@05onShc@04o`000?oEolGoeOo5omGo
a@;o00007Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo000Wooooo`03
o`000?oooooooooo05Gooooo00?o0000oibikOnL^Nd02_nL^NdBo`0000Ko?IGa0_l000002Ol0Lm_o
0000o`000?l0JmSo0000o`1A`Ol0003o05S=o`000002o`1KcP;o000000?o3FWLo`000?l`O^L01ol`
O^L01?l0003oHIW^of6Ik_mQVNh5o`0000GoMI7Q00?o0000oiFOfonEWm/02OnEWm/5o`0001Co];gP
00?o0000olg4d_o=a=800_o=a=800ol0003oeMWKomGIf`0;omGIf`03o`000?oHl>;of?3R00Sof?3R
1Ol00003onShc@03o`000?oEolGo000000?o00007_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00oooooo000Xooooo`03o`000?oooooooooo05Gooooo00?o0000oibikOnL^Nd01OnL
^Nd4o`0000CoW[[]00?o0000ogjam?mn/O@02Omn/O@00ol0003oCZ7fo`000006o`000004ocfElOl0
003o07?Ko`1cf`?o000000Co0571o`000?l0003o00000ol0Flh3o`0000So<7kW00?o0000of6Ik_mQ
VNh01OmQVNh6o`0000CoUIoK1ol00004oi6_j`03o`000?nd_N3o];gP01;o];gP00Go0000olg4d_o=
a=;ocLCBo`00000=omGIf`03o`000?oHl>;of?3R00Sof?3R00?o0000olOofoo7om/00oo7om/7o`00
027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`00:Oooool2o`0005Ko
oooo00?o0000oibikOnL^Nd01?l00009oijjk@03o`000?mn/OCoO[7d00WoO[7d00?o0000odjQm_m>
XOH01Om>XOH5o`0000;o07?K0_l000000ol0DL7o0000o`000004o`1KcP;o00002?l`O^L00ol0003o
HIW^of6IkP09of6IkPGo00003?nA[n/00ol0003o];gPokBmh00BokBmh003o`000?o=a=;o000000co
eMWK0_l0000:omS`hP03o`000?o7om_oaooK00CoaooK00?o0000oi;Z]?nBj[@00_l0000Tooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool002_ooooo00?o0000ooooooooool0
E?ooool2o`0000koW[[]00?o0000ogjam?mn/O@02Omn/O@2o`0000WoCZ7f1?l000001?l0Lm_o0000
o`000?l0DL42o`0000Co05_>0_l00007oc1ni`03o`000?mQVNkoHIW^00WoHIW^00?o0000oi6_jonA
[n/03_nA[n/00ol0003o];gPokBmh00AokBmh0?o00002ooEfM/00ol0003of?3RomS`hP09omS`hP03
o`000?o7om_oaooK00CoaooK00Co0000oi;Z]?nBj[Co00009oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00oooooo000/ooooo`03o`000?oooooooooo05Gooooo00?o0000oijjkOnN
^^d03?nN^^d00ol0003oO[7dogjam00:ogjam003o`000?m>XOKoCZ7f00OoCZ7f0_l000000ol?QNCo
0000o`000003o`000003o`1A`Ol0003o000000Co05_>0ol00005oc1ni`03o`000?mQVNkoHIW^00Wo
HIW^00?o0000oi6_jonA[n/03_nA[n/00ol0003o];gPokBmh00>okBmh0;o00000ongeNl00ol0003o
eMWKomGIf`07omGIf`03o`000?oHl>;of?3R00Sof?3R0_l00005olOof`;o000000?oT^Zdo`000?l0
0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo000]ooooo`03o`00
0?oooooooooo05Gooooo00?o0000oijjkOnN^^d03?nN^^d00ol0003oO[7dogjam00:ogjam003o`00
0?m>XOKoCZ7f00SoCZ7f00Co0000o`n5i?l?QNCo3hGT1ol00003o`1KcP04o`000?l3M=ko0000o`00
00?o<7kW00?o0000of6Ik_mQVNh02_mQVNh00ol0003oTJo[oi6_j`0>oi6_j`03o`000?nd_N3o];gP
00_o];gP0_l00006okOEk`03o`000?oEfM_oeMWK00GoeMWK00?o0000omS`h_oHl>802?oHl>800ol0
003oaooKolOof`04olOof`04o`000?nBj[Co0000o`0002_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`00;_ooool00ol0003oooooooooo`1Eooooo`03o`000?nN^^goW[[]
00coW[[]00?o0000ogjam?mn/O@01?mn/O@=o`0000CoCZ7f00?o0000o`n5i?l?QN@00ol?QN@6o`00
00;o05_>00?o0000o`=dg_l3M=h00_l00002oc1ni`03o`000?mQVNkoHIW^00[oHIW^00?o0000oi6_
jonA[n/03OnA[n/00ol0003o];gPokBmh008okBmh0?o00002OngeNl00ol0003oeMWKomGIf`03omGI
f`03o`000?oHl>;of?3R00Sof?3R00?o0000olOofoo7om/00oo7om/2o`000003oi;Z]?l0003ooooo
02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`00;oooool2o`0005Ko
oooo00?o0000oijjkOnN^^d02_nN^^d8o`0000SoR;Gc00?o0000ofF^nOmU[_T00_mU[_T8o`0000Co
3hGT1_l000000ol0Flko0000o`=dgP02o`=dgPCo00003?mQVNh00ol0003oTJo[oi6_j`0=oi6_j`03
o`000?nd_N3o];gP00Go];gP0_l0000=okOEk`05o`000?oEfM_oeMWKomGIfol000002_oHl>800ol0
003oaooKolOof`03olOof`04o`000?nBj[Co0000o`0002oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0>ooooo`00<Oooool00ol0003oooooooooo`1Dooooo`03o`000?nN^^goW[[]
00GoW[[]1?l00003oj2kk003o`000?n8]O?oR;Gc00_oR;Gc00?o0000ofF^nOmU[_T02?mU[_T6o`00
0003o`n5i?l0003o000000Go00001Ol3M=h2o`0000_oHIW^00?o0000oi6_jonA[n/03_nA[n/00ol0
003o];gPokBmh002okBmh0;o00004?ngeNl00ol0003oeMWKo`000009omS`hP;o00001Oo7om/00ol0
003oT^Zdo`00000booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool003;o
oooo00?o0000ooooooooool0E?ooool00ol0003oW[[]oijjk@04o`0000SoX;_/00?o0000ohRelon8
]O<02on8]O<00ol0003oIJkiofF^n@08ofF^n@;o00000ol_W_49o`0000Ko0gCN1?l00008of6IkP03
o`000?nA[n_oTJo[00koTJo[00Co0000okBmh?l0003o00004_ngeNl3o`0000Sof?3R00?o0000olOo
foo7om/00oo7om/4o`0003Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>oooo
o`00<oooool00ol0003oooooooooo`1Dooooo`;o00003OnP^n`00ol0003oR;GcohRel`0;ohRel`03
o`000?mU[_WoIJki00WoIJki00?o0000obnNlOl_W_401?l_W_47o`0000Ko0gCN00?o0000ocjMm?l0
00001?l00004of6IkP03o`000?nA[n_oTJo[00[oTJo[1_l0000AokOEk`;o00000on]k_P3o`0000Co
f?3R00?o0000olOofoo7om/00oo7om/3o`0003Oooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0>ooooo`00=?ooool2o`0005Gooooo00?o0000oj2kk?nP^n`03?nP^n`00ol0003oR;Gc
ohRel`0;ohRel`03o`000?mU[_WoIJki00WoIJki00?o0000obnNlOl_W_401ol_W_46o`0000Co0gCN
00?o0000ocjMm?lnWO@00olnWO@6o`0000CoTJo[1ol00006oh?3o003o`000?ngeNoo]mG_00co]mG_
0_l00008ojg^n0;o000000?of?3Ro`000?o7om/01?o7om/2o`0003Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`00=_ooool00ol0003oooooooooo`1Cooooo`03o`000?nP
^ncoX;_/00coX;_/00?o0000ohRelon8]O<02?n8]O<Qo`0000;o0gCN0_l00008ocjMm0Go00003_n3
`o`00ol0003o]mG_okOEk`08okOEk`?o00002on]k_P8o`0003cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0>ooooo`00=oooool00ol0003oooooooooo`1Cooooo`03o`000?nP^nco
X;_/00coX;_/00Co0000ohRelon8]O?oR;Gc1_l00005oiBjl@03o`000?mn^o[oO[_j00WoO[_j0_l0
000;oeVio0;o000000Ko06;0o`000?l0003o0000o`=dg_l0000:ocjMm003o`000?n3`ocoPl?l00ko
Pl?l00?o0000okOEkongeNl01OngeNl2o`0000co[Nkh0_l00003ogoXf`?o0000?oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo000hooooo`03o`000?oooooooooo05?ooooo
00?o0000oj2kk?nP^n`02_nP^n`5o`0000coU;[a0_l0000;ogjknP03o`000?mI^OcoFKWl00WoFKWl
0ol00002o`1R`0?o00002_lnWO@00ol0003oPl?loh?3o00>oh?3o003o`000?ngeNoo]mG_00;o]mG_
0_l0000<ojg^n0;o00000omoj=/2o`0004?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0>ooooo`00>Oooool2o`0005Cooooo00?o0000oj2kk?nP^n`01OnP^n`4o`0000CoXkc[00?o
0000oiBjlOnD^_403?nD^_400ol0003oO[_jogjknP09ogjknP;o00000omI^O`6o`0000?oP/go0ol0
0002o`1R`0Co00001olnWO@2o`0000ooPl?l00Co0000okOEkol0003o00002on]k_P3o`0000?oOnSK
0_l00015ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool003_ooooo00?o
0000ooooooooool0D_ooool00ol0003oX;_/oj2kk004o`0000WoXkc[00?o0000oiBjlOnD^_403?nD
^_400ol0003oO[_jogjknP04ogjknPWo00003?n2cOl3o`000003o`1R`?l0003o000000Go00001?ln
WO@00ol0003oPl?loh?3o00:oh?3o0Go00002_n]k_P2o`0000?oOnSK0ol00018ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool003cooooo00?o0000ooooooooool0D_ooool2
o`0000koXkc[00?o0000oiBjlOnD^_402_nD^_48o`0000SoULCg0ol00007oh;=o`?o00000oooool4
o`0000Co2i7M1_l00004oh?3o0Oo00001OmOc?T3o`0000Go[Nkh0_l00003ogoXf`;o0000C?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000mooooo`03o`000?oooooooooo
05?ooooo00?o0000oj>ljonS_>/03?nS_>/00ol0003oU;[aoiBjl@05oiBjl@Co00001?nO_Nh00ol0
003oULCgoiG4m`0<oiG4m`;o00000_n2cOl3o`0000Wooooo0ol00007o`^Ag@Go00003omOc?T2o`00
0004ojg^n?l0003o0000ogoXf`Co0000C_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo000nooooo`;o0000E?ooool00ol0003oXkc[oj>lj`0<oj>lj`03o`000?nD^_7oU;[a
00Co00002OnO_Nh00ol0003oULCgoiG4m`0<oiG4m`?o00003oooool5o`0000Go2i7M0ol0000=oeo<
n@Oo0000Doooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0010ooooo`03
o`000?oooooooooo05;ooooo00?o0000oj>ljonS_>/02_nS_>/4o`0000koWkg^00?o0000oiG4monE
a?L02?nEa?L3o`0001Oooooo1ol000000ol;TMgo0000o`000004oeo<n@Oo0000Foooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo0011ooooo`03o`000?oooooooooo05;ooooo
00?o0000oj>ljonS_>/01OnS_>/4o`0000CoY[cY00?o0000oinmk_nO_Nh03?nO_Nh00ol0003oULCg
oiG4m`04oiG4m`?o00008Oooool7o`0006?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0=ooooo`00@_ooool00ol0003oooooooooo`1Booooo`03o`000?nS_>_oXkc[00Co00002OnV
_>T00ol0003oWkg^oinmkP0<oinmkP03o`000?nEa?OoULCg00?o0000S_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo0013ooooo`03o`000?oooooooooo05;ooooo0_l0000>
ojJlj@03o`000?nO_NkoWkg^00[oWkg^1?l0002Booooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool004Cooooo0_l0001Cooooo`03o`000?nV_>WoY[cY00goY[cY00?o0000oinm
k_nO_Nh01OnO_Nh4o`0009Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`00A_ooool00ol0003oooooooooo`1Aooooo`03o`000?nV_>WoY[cY00goY[cY00?o0000oinmk_nO
_Nh01?l0002Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool004Oooooo
00?o0000ooooooooool0DOooool00ol0003oY[cYojJlj@0<ojJlj@?o0000X?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00cooooo0018ooooo`03o`000?oooooooooo057ooooo00?o
0000ojJljOnV_>T02?nV_>T3o`000:Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`00BOooool2o`0005;ooooo00?o0000ojJljOnV_>T01?nV_>T3o`000:Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`00Boooool00ol0003oooooooooo`1@oooo
o`03o`000?nV_>WoY[cY00?o0000Zoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo001<ooooo`03o`000?oooooooooo053ooooo0_l0002_ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool004gooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`2_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool004kooooo0_l0
001?ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0;ooooo`00D?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0;3ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`00DOooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`00D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`00Doooool2o`0004[ooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo001Eooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo001Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0]?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo001Gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0]Oooool01Ol0003ooooooooooooooooo000000cooooo001Hoooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0]Oooool01Ol0003ooooooooooooooooo
000000cooooo001Iooooo`;o0000A?ooool00ol0003oooooooooo`2fooooo`04o`000?oooooooooo
o`0000cooooo001Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0]oooool00ol0
003oooooo`00000<ooooo`00G?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Oo
oooo00Co0000oooooooooooo00002oooool005gooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`2hooooo`03o`000?oooooo000000_ooooo001Nooooo`;o0000?oooool00ol0003ooooo
ooooo`2iooooo`;o00002oooool0063ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2iooooo`?o00002oooool0067ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2e
ooooo`Co00003_ooool006;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2aoooo
o`Co00004_ooool006?ooooo0_l0000iooooo`03o`000?oooooooooo0:kooooo0ol0000Fooooo`00
IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:[ooooo1?l0000Iooooo`00I_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:Kooooo1?l0000Mooooo`00Ioooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;ooooo1?l0000Qooooo`00J?ooool2o`00
03Cooooo00?o0000ooooooooool0W_ooool4o`0002Gooooo001Zooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0Voooool3o`0002Wooooo001[ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0Uoooool4o`0002cooooo001/ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0Toooool4o`00033ooooo001]ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Soooool4o`0003Cooooo001^ooooo`;o0000;_ooool00ol0003oooooooooo`2;oooo
o`Co0000>?ooool0073ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`27ooooo`Co
0000??ooool0077ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`24ooooo`?o0000
@?ooool007;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`20ooooo`Co0000@ooo
ool007?ooooo0_l0000Yooooo`03o`000?oooooooooo07cooooo1?l00017ooooo`00MOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Sooooo1?l0001;ooooo`00M_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1?l0001?ooooo`00Moooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo077ooooo0ol0001Cooooo`00N?ooool2o`0002Cooooo00?o
0000ooooooooool0KOooool4o`0005Kooooo001jooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0JOooool4o`0005[ooooo001kooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0IOooool4o`0005kooooo001looooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0HOooool4o`0006;ooooo001mooooo`;o00007oooool00ol0003oooooooooo`1Mooooo`Co0000
I_ooool007oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`?o0000J_oo
ool0083ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Fooooo`Co0000KOooool0
087ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Booooo`Co0000LOooool008;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`Co0000MOooool008?ooooo
0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001iooooo`00QOooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo1?l0001mooooo`00Q_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04?ooooo0ol00021ooooo`00Qoooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03oooooo1?l00024ooooo`00R?ooool2o`0001Cooooo00?o0000oooooooo
ool0>oooool4o`0008Sooooo002:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
>?ooool4o`0008cooooo002;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?oo
ool4o`00093ooooo002<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool3
o`0009Cooooo002=ooooo`;o00003_ooool00ol0003oooooooooo`0]ooooo`Co0000Uoooool008oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`Co0000Voooool0093ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000Woooool0097ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Xoooool009;ooooo0_l00009
ooooo`03o`000?oooooooooo01gooooo1?l0002Wooooo`00U?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo0ol0002[ooooo`00UOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo1?l0002^ooooo`00U_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01;ooooo1?l0002booooo`00Uoooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00kooooo1?l0002fooooo`00V?ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4
o`000;[ooooo002Jooooo`04o`000?ooooooooooo`0000Wooooo0ol0002nooooo`00Voooool00ol0
003oooooo`000005ooooo`Co0000`Oooool009cooooo0_l000000ooooooo0000o`000002o`000<Go
oooo002Mooooo`;o0000bOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00<Gooooo0ol000000ol@413oooooooooo`2Mooooo`00Yoooool00ol0003ogMgMoooo
o`08ooooo`;o00002oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00Cooooo0_l0
002Hooooo`00Yoooool00olb<S;o^[Zjooooo`08ooooo`03o`000?oooooooooo00[ooooo0_lb<S86
ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000ooooooooool0U_ooool00:Oooooo00KoMgMgohN7
Qom4A4Co0000oa0@4?n7QhL5ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_oo
ool00on7QhOo0000okZj^P05ooooo`03omgMgOl0003o^[Zj00Gooooo00?o0000ooooooooool0U_oo
ool00:Oooooo00OoZJVYo`000?nj^[[oooooomgMgOlQ8B7oQhN700Cooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool00omE
EEGoMgMgodA4A005ooooo`03o`000?oooooooooo09Kooooo002Wooooo`03omgMgOl@413ooooo00;o
oooo00?ogMgMoa0@4?ooool00oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<
c0[ooooo00GogMgMoa0@4?oooooo8B4QomgMg@04ooooo`03o`000?oooooooooo09Kooooo002Xoooo
o`03oa0@4?oMgMgooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@04ooooo`03o`000?oo
oooooooo09Kooooo002Xooooo`06ohN7QolQ8B7ogMgMoooooomgMgOo<S8b1?ooool00ol0003ooooo
ooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003o
gMgMooooo`02ooooo`03o`000?oooooooooo09Kooooo002Yooooo`05ogMgMol0003o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0
003ooooo0_l000001Ol@413ooooooooooooooooo000009Sooooo002booooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0U_ooool00;;ooooo0_l0000Jooooo`;o0000V?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0939778, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "\tWe now create a matrix with elements ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(j\ k\)\)]],
  ", and convert the matrix to approximate numbers in order to assure that no \
exact arithmetic is attempted in what follows:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]matrix = 
        Table[\[Rho][j\ \[CapitalDelta]x, k\ \[CapitalDelta]y], {j, 0, 
              M\_x - 1}, {k, 0, M\_y - 1}]\  // N;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.123"],

Cell[TextData[{
  "We next determine the Fourier coefficient matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  ",",
  " using an FFT:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]ft = Fourier[\[Rho]matrix];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.124"],

Cell[TextData[{
  "The (1,1) element of this matrix corresponds to the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, n = 0\)]],
  " term, and should be zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho]ft[\([1, 1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.125"],

Cell[BoxData[
    \(\(-0.006666008589945491`\) + 0.`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This element is not quite zero because of the discretization of the charge \
density: the discrete Fourier transform is not exactly the same as the \
integral of the charge over the rectangular domain, although it is close for \
large ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y\)]],
  ". Therefore, we simply set this term equal to zero directly:"
}], "Text"],

Cell[BoxData[
    \(\(\[Rho]ft[\([1, 1]\)] = 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.126"],

Cell[TextData[{
  "Now we define the factor by which we are to divide ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&~\_\(m\ n\)\)]],
  " [see Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>"(6.2.43)",
    ButtonStyle->"Hyperlink"],
  " ]:"
}], "Text"],

Cell[BoxData[{
    \(\(factor[m_, 
          n_]\  := \(-\ \((\(4\/\[CapitalDelta]x\^2\) 
                Sin[\[Pi]\ m/M\_x]^2 + \(4\/\[CapitalDelta]y\^2\) 
                Sin[\[Pi]\ n/M\_y]^2\ )\)\);\)\), "\n", 
    \(\(factor[0, 0] = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.127"],

Cell[TextData[{
  "This factor is defined so that we may safely divide by it without getting \
an error when ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(n = 0\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi]\&~ = 
        Table[\[Rho]ft[\([m + 1, n + 1]\)]/factor[m, n], {m, 0, 
            M\_x - 1}, {n, 0, M\_y - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.128"],

Cell[TextData[{
  "Finally, we obtain the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j\ k\)\)]],
  " at the grid points ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ j \[LessEqual] \ M\_x - 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ \ k\  \[LessEqual] \ M\_y - 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi]matrix\  = \ InverseFourier[\[Phi]\&~];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.129"],

Cell["\<\
\t It is enlightening to compare the time required to complete \
these operations with that required by the direct solution method, or the \
relaxation methods for the same fine grid.  The reader is invited to evaluate \
these methods, which should provide convincing proof of the efficacy of the \
FFT method for this rectangular geometry.  \
\>", "Text"],

Cell[TextData[{
  "\tWe can create an interpolation of the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]matrix\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by first adding to the data the corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\(y\)\(\ \)\)\)]],
  "positions for each grid point, and then interpolating the resulting data \
list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi]\  = \ 
        Table[{j\ \[CapitalDelta]x, \ 
            k\ \[CapitalDelta]y, \ \[Phi]matrix[\([j + 1, k + 1]\)]}, {j, 0, 
            M\_x - 1}, {k, 0, M\_y - 1}];\)\), "\n", 
    \(\[Phi]sol\  = \ Interpolation[Flatten[\[Phi], 1]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.130"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 0.98`}, {0.`, 0.98`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This function is defined only in the square from 0 to 0.98, rather than \
from 0 to 1, because of the discretization.  If we wished, we could use the \
periodicity of the system to extend the result to the entire ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane."
}], "Text"],

Cell[TextData[{
  "The solution is plotted in Cell ",
  ButtonBox["6.131",
    ButtonData:>"Cell 6.131",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\[Phi]sol[x, y], {x, 0,  .98}, {y, 0,  .98}, 
        PlotLabel \[Rule] "\<\[Phi](x,y)\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.131"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -20 0 ]
[.5 .82364 20 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14845 .1986 -17.8706 -9 ]
[.14845 .1986 .12936 0 ]
[.27533 .14869 -17.1047 -9 ]
[.27533 .14869 .89525 0 ]
[.40865 .09626 -16.3389 -9 ]
[.40865 .09626 1.66114 0 ]
[.54892 .04112 -15.573 -9 ]
[.54892 .04112 2.42702 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76874 .09901 0 -6.15994 ]
[.76874 .09901 18 2.84006 ]
[.83048 .19354 0 -6.06902 ]
[.83048 .19354 18 2.93098 ]
[.88694 .28 0 -5.98753 ]
[.88694 .28 18 3.01247 ]
[.93877 .35938 0 -5.91409 ]
[.93877 .35938 18 3.08591 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.01531 .32029 -36 -2.78898 ]
[.01531 .32029 0 6.21102 ]
[.00397 .39137 -6 -2.84932 ]
[.00397 .39137 0 6.15068 ]
[-0.0079 .46575 -30 -2.91276 ]
[-0.0079 .46575 0 6.08724 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.15767 .20795 m
.16227 .21262 L
s
[(0.2)] .14845 .1986 .98563 1 Mshowa
.28411 .15844 m
.2885 .16331 L
s
[(0.4)] .27533 .14869 .90053 1 Mshowa
.41694 .10643 m
.42109 .11151 L
s
[(0.6)] .40865 .09626 .81543 1 Mshowa
.55666 .05172 m
.56052 .05702 L
s
[(0.8)] .54892 .04112 .73033 1 Mshowa
.125 Mabswid
.06675 .24355 m
.0696 .24627 L
s
.0967 .23182 m
.09952 .23457 L
s
.127 .21996 m
.12979 .22273 L
s
.1887 .1958 m
.19144 .19863 L
s
.22012 .1835 m
.22282 .18636 L
s
.25192 .17104 m
.25459 .17394 L
s
.3167 .14568 m
.3193 .14863 L
s
.3497 .13276 m
.35226 .13575 L
s
.38311 .11967 m
.38563 .12269 L
s
.4512 .09301 m
.45365 .09609 L
s
.4859 .07942 m
.48831 .08254 L
s
.52105 .06566 m
.52342 .06881 L
s
.59272 .0376 m
.595 .04081 L
s
.62926 .02329 m
.63149 .02653 L
s
.66629 .00879 m
.66847 .01207 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75643 .10355 m
.75028 .10582 L
s
[(0.2)] .76874 .09901 -1 .36888 Mshowa
.81809 .19786 m
.81189 .20002 L
s
[(0.4)] .83048 .19354 -1 .34867 Mshowa
.87448 .28412 m
.86825 .28618 L
s
[(0.6)] .88694 .28 -1 .33056 Mshowa
.92625 .36331 m
.91999 .36528 L
s
[(0.8)] .93877 .35938 -1 .31424 Mshowa
.125 Mabswid
.70627 .02683 m
.7026 .02824 L
s
.72339 .05301 m
.71971 .05441 L
s
.74011 .07858 m
.73642 .07996 L
s
.77238 .12795 m
.76868 .12929 L
s
.78796 .15178 m
.78426 .15311 L
s
.8032 .17508 m
.79948 .1764 L
s
.83265 .22014 m
.82893 .22142 L
s
.8469 .24193 m
.84317 .2432 L
s
.86084 .26326 m
.85711 .26451 L
s
.88783 .30455 m
.88409 .30577 L
s
.90091 .32455 m
.89716 .32575 L
s
.91371 .34413 m
.90996 .34532 L
s
.93854 .38211 m
.93478 .38328 L
s
.95058 .40053 m
.94681 .40168 L
s
.96238 .41858 m
.95861 .41972 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02757 .31563 m
.03371 .31329 L
s
[(-0.005)] .01531 .32029 1 -0.38023 Mshowa
.01629 .38685 m
.02245 .38459 L
s
[(0)] .00397 .39137 1 -0.36682 Mshowa
.00448 .46139 m
.01066 .4592 L
s
[(0.005)] -0.0079 .46575 1 -0.35272 Mshowa
.125 Mabswid
.02536 .32962 m
.02904 .32823 L
s
.02312 .34373 m
.02681 .34235 L
s
.02086 .35798 m
.02455 .3566 L
s
.01859 .37235 m
.02228 .37098 L
s
.01397 .40149 m
.01767 .40014 L
s
.01163 .41626 m
.01533 .41492 L
s
.00927 .43116 m
.01297 .42983 L
s
.00688 .4462 m
.01059 .44488 L
s
.02977 .30176 m
.03345 .30035 L
s
.03195 .28801 m
.03562 .2866 L
s
.03411 .27439 m
.03778 .27296 L
s
.03625 .26088 m
.03992 .25945 L
s
.00205 .47671 m
.00576 .47541 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.554 .684 .926 r
.3752 .77366 .39834 .7978 .43696 .79532 .41405 .77169 Metetra
.654 .725 .901 r
.41405 .77169 .43696 .79532 .47643 .78485 .45384 .7606 Metetra
.716 .738 .869 r
.45384 .7606 .47643 .78485 .51649 .76687 .49429 .74121 Metetra
.748 .737 .842 r
.49429 .74121 .51649 .76687 .55692 .74311 .53512 .71551 Metetra
.76 .73 .825 r
.53512 .71551 .55692 .74311 .59759 .71607 .57618 .68629 Metetra
.757 .718 .816 r
.57618 .68629 .59759 .71607 .63848 .68858 .61742 .65664 Metetra
.74 .704 .817 r
.61742 .65664 .63848 .68858 .67972 .66343 .65897 .62959 Metetra
.711 .685 .823 r
.65897 .62959 .67972 .66343 .72151 .64296 .70104 .60771 Metetra
.669 .663 .835 r
.70104 .60771 .72151 .64296 .76417 .62881 .74397 .5928 Metetra
.616 .637 .848 r
.74397 .5928 .76417 .62881 .80801 .62167 .7881 .58565 Metetra
.557 .61 .861 r
.7881 .58565 .80801 .62167 .85329 .62108 .83373 .58587 Metetra
.503 .589 .873 r
.83373 .58587 .85329 .62108 .9001 .62534 .88101 .5917 Metetra
.473 .585 .886 r
.88101 .5917 .9001 .62534 .94833 .63149 .92983 .59993 Metetra
.485 .609 .9 r
.92983 .59993 .94833 .63149 .99755 .63554 .97974 .60602 Metetra
.553 .643 .893 r
.35174 .74396 .3752 .77366 .41405 .77169 .39073 .74308 Metetra
.657 .692 .871 r
.39073 .74308 .41405 .77169 .45384 .7606 .43081 .73121 Metetra
.719 .708 .839 r
.43081 .73121 .45384 .7606 .49429 .74121 .47162 .70967 Metetra
.748 .705 .812 r
.47162 .70967 .49429 .74121 .53512 .71551 .51283 .68093 Metetra
.756 .694 .793 r
.51283 .68093 .53512 .71551 .57618 .68629 .55422 .64824 Metetra
.75 .679 .782 r
.55422 .64824 .57618 .68629 .61742 .65664 .59573 .61518 Metetra
.731 .659 .779 r
.59573 .61518 .61742 .65664 .65897 .62959 .63746 .58518 Metetra
.701 .637 .781 r
.63746 .58518 .65897 .62959 .70104 .60771 .67967 .56117 Metetra
.661 .611 .788 r
.67967 .56117 .70104 .60771 .74397 .5928 .72271 .5452 Metetra
.611 .584 .798 r
.72271 .5452 .74397 .5928 .7881 .58565 .76701 .53828 Metetra
.556 .557 .81 r
.76701 .53828 .7881 .58565 .83373 .58587 .8129 .54007 Metetra
.503 .537 .824 r
.8129 .54007 .83373 .58587 .88101 .5917 .86062 .5487 Metetra
.47 .533 .84 r
.86062 .5487 .88101 .5917 .92983 .59993 .91006 .56054 Metetra
.478 .56 .86 r
.91006 .56054 .92983 .59993 .97974 .60602 .96073 .5701 Metetra
.541 .619 .88 r
.32792 .71103 .35174 .74396 .39073 .74308 .36698 .71142 Metetra
.659 .677 .856 r
.36698 .71142 .39073 .74308 .43081 .73121 .40734 .69877 Metetra
.724 .695 .823 r
.40734 .69877 .43081 .73121 .47162 .70967 .44852 .67487 Metetra
.753 .694 .795 r
.44852 .67487 .47162 .70967 .51283 .68093 .49011 .64273 Metetra
.761 .683 .776 r
.49011 .64273 .51283 .68093 .55422 .64824 .53185 .60618 Metetra
.754 .667 .766 r
.53185 .60618 .55422 .64824 .59573 .61518 .57361 .56933 Metetra
.734 .647 .763 r
.57361 .56933 .59573 .61518 .63746 .58518 .61552 .53608 Metetra
.703 .624 .766 r
.61552 .53608 .63746 .58518 .67967 .56117 .65782 .50973 Metetra
.66 .596 .773 r
.65782 .50973 .67967 .56117 .72271 .5452 .70094 .49265 Metetra
.606 .566 .783 r
.70094 .49265 .72271 .5452 .76701 .53828 .74533 .48603 Metetra
.544 .535 .795 r
.74533 .48603 .76701 .53828 .8129 .54007 .79143 .4896 Metetra
.484 .509 .808 r
.79143 .4896 .8129 .54007 .86062 .5487 .83952 .50134 Metetra
.444 .501 .823 r
.83952 .50134 .86062 .5487 .91006 .56054 .88954 .51716 Metetra
.452 .528 .845 r
.88954 .51716 .91006 .56054 .96073 .5701 .94092 .5305 Metetra
.523 .611 .882 r
.30362 .67732 .32792 .71103 .36698 .71142 .34274 .6789 Metetra
.662 .677 .854 r
.34274 .6789 .36698 .71142 .40734 .69877 .38337 .66552 Metetra
.732 .697 .817 r
.38337 .66552 .40734 .69877 .44852 .67487 .42494 .6394 Metetra
.763 .697 .788 r
.42494 .6394 .44852 .67487 .49011 .64273 .46697 .60407 Metetra
.772 .687 .77 r
.46697 .60407 .49011 .64273 .53185 .60618 .5091 .5639 Metetra
.765 .673 .761 r
.5091 .5639 .53185 .60618 .57361 .56933 .55119 .52349 Metetra
.745 .654 .76 r
.55119 .52349 .57361 .56933 .61552 .53608 .59331 .4872 Metetra
.711 .63 .765 r
.59331 .4872 .61552 .53608 .65782 .50973 .63576 .45868 Metetra
.664 .601 .775 r
.63576 .45868 .65782 .50973 .70094 .49265 .67897 .44055 Metetra
.601 .567 .788 r
.67897 .44055 .70094 .49265 .74533 .48603 .72346 .43417 Metetra
.528 .529 .8 r
.72346 .43417 .74533 .48603 .79143 .4896 .76974 .43933 Metetra
.454 .495 .812 r
.76974 .43933 .79143 .4896 .83952 .50134 .81814 .45387 Metetra
.404 .481 .825 r
.81814 .45387 .83952 .50134 .88954 .51716 .86865 .47325 Metetra
.415 .507 .845 r
.86865 .47325 .88954 .51716 .94092 .5305 .92067 .49 Metetra
.499 .615 .898 r
.27866 .64507 .30362 .67732 .34274 .6789 .31786 .64752 Metetra
.665 .689 .863 r
.31786 .64752 .34274 .6789 .38337 .66552 .35878 .63349 Metetra
.743 .71 .821 r
.35878 .63349 .38337 .66552 .42494 .6394 .4008 .60554 Metetra
.777 .711 .79 r
.4008 .60554 .42494 .6394 .46697 .60407 .44332 .56758 Metetra
.787 .704 .772 r
.44332 .56758 .46697 .60407 .5091 .5639 .48592 .52443 Metetra
.781 .691 .765 r
.48592 .52443 .5091 .5639 .55119 .52349 .52842 .48112 Metetra
.761 .675 .767 r
.52842 .48112 .55119 .52349 .59331 .4872 .57088 .44234 Metetra
.726 .653 .777 r
.57088 .44234 .59331 .4872 .63576 .45868 .61356 .41201 Metetra
.672 .624 .792 r
.61356 .41201 .63576 .45868 .67897 .44055 .65694 .39297 Metetra
.598 .585 .809 r
.65694 .39297 .67897 .44055 .72346 .43417 .70159 .3867 Metetra
.506 .537 .823 r
.70159 .3867 .72346 .43417 .76974 .43933 .74805 .39301 Metetra
.411 .491 .831 r
.74805 .39301 .76974 .43933 .81814 .45387 .79674 .40965 Metetra
.349 .467 .839 r
.79674 .40965 .81814 .45387 .86865 .47325 .84768 .43173 Metetra
.366 .496 .857 r
.84768 .43173 .86865 .47325 .92067 .49 .90025 .45103 Metetra
.468 .632 .925 r
.25285 .61598 .27866 .64507 .31786 .64752 .29217 .61887 Metetra
.669 .714 .882 r
.29217 .61887 .31786 .64752 .35878 .63349 .33343 .60431 Metetra
.755 .734 .833 r
.33343 .60431 .35878 .63349 .4008 .60554 .37593 .57502 Metetra
.792 .735 .799 r
.37593 .57502 .4008 .60554 .44332 .56758 .41902 .53523 Metetra
.805 .73 .781 r
.41902 .53523 .44332 .56758 .48592 .52443 .46219 .49002 Metetra
.801 .721 .777 r
.46219 .49002 .48592 .52443 .52842 .48112 .50522 .44469 Metetra
.782 .71 .783 r
.50522 .44469 .52842 .48112 .57088 .44234 .54812 .40417 Metetra
.746 .692 .8 r
.54812 .40417 .57088 .44234 .61356 .41201 .59118 .37254 Metetra
.686 .665 .824 r
.59118 .37254 .61356 .41201 .65694 .39297 .63486 .35276 Metetra
.594 .621 .848 r
.63486 .35276 .65694 .39297 .70159 .3867 .67976 .34639 Metetra
.474 .56 .863 r
.67976 .34639 .70159 .3867 .74805 .39301 .72647 .35328 Metetra
.35 .495 .864 r
.72647 .35328 .74805 .39301 .79674 .40965 .77544 .37109 Metetra
.274 .459 .861 r
.77544 .37109 .79674 .40965 .84768 .43173 .82676 .3947 Metetra
.302 .491 .877 r
.82676 .3947 .84768 .43173 .90025 .45103 .87981 .41547 Metetra
.427 .658 .956 r
.22597 .59113 .25285 .61598 .29217 .61887 .26549 .59395 Metetra
.671 .748 .908 r
.26549 .59395 .29217 .61887 .33343 .60431 .30714 .57896 Metetra
.767 .765 .851 r
.30714 .57896 .33343 .60431 .37593 .57502 .35018 .54895 Metetra
.808 .766 .814 r
.35018 .54895 .37593 .57502 .41902 .53523 .39388 .50823 Metetra
.823 .764 .797 r
.39388 .50823 .41902 .53523 .46219 .49002 .43772 .462 Metetra
.823 .762 .795 r
.43772 .462 .46219 .49002 .50522 .44469 .48139 .41567 Metetra
.807 .758 .807 r
.48139 .41567 .50522 .44469 .54812 .40417 .52489 .37425 Metetra
.77 .749 .834 r
.52489 .37425 .54812 .40417 .59118 .37254 .56847 .34188 Metetra
.701 .728 .871 r
.56847 .34188 .59118 .37254 .63486 .35276 .6126 .32156 Metetra
.585 .681 .907 r
.6126 .32156 .63486 .35276 .67976 .34639 .65787 .31488 Metetra
.422 .6 .919 r
.65787 .31488 .67976 .34639 .72647 .35328 .70492 .32168 Metetra
.259 .506 .9 r
.70492 .32168 .72647 .35328 .77544 .37109 .75421 .33961 Metetra
.172 .453 .881 r
.75421 .33961 .77544 .37109 .82676 .3947 .80589 .36347 Metetra
.223 .492 .898 r
.80589 .36347 .82676 .3947 .87981 .41547 .85939 .38444 Metetra
.379 .687 .979 r
.19783 .57086 .22597 .59113 .26549 .59395 .23765 .5731 Metetra
.67 .788 .937 r
.23765 .5731 .26549 .59395 .30714 .57896 .27975 .5578 Metetra
.776 .801 .873 r
.27975 .5578 .30714 .57896 .35018 .54895 .32336 .52768 Metetra
.821 .803 .834 r
.32336 .52768 .35018 .54895 .39388 .50823 .36773 .48698 Metetra
.84 .805 .817 r
.36773 .48698 .39388 .50823 .43772 .462 .41229 .44083 Metetra
.843 .81 .818 r
.41229 .44083 .43772 .462 .48139 .41567 .45671 .39456 Metetra
.83 .817 .838 r
.45671 .39456 .48139 .41567 .52489 .37425 .50094 .35311 Metetra
.792 .822 .876 r
.50094 .35311 .52489 .37425 .56847 .34188 .5452 .32058 Metetra
.71 .812 .928 r
.5452 .32058 .56847 .34188 .6126 .32156 .58994 .29992 Metetra
.556 .76 .973 r
.58994 .29992 .6126 .32156 .65787 .31488 .63574 .29269 Metetra
.334 .645 .967 r
.63574 .29269 .65787 .31488 .70492 .32168 .68323 .29872 Metetra
.13 .511 .911 r
.68323 .29872 .70492 .32168 .75421 .33961 .73293 .31568 Metetra
.048 .444 .875 r
.73293 .31568 .75421 .33961 .80589 .36347 .78498 .33844 Metetra
.133 .496 .906 r
.78498 .33844 .80589 .36347 .85939 .38444 .83891 .35833 Metetra
.334 .711 .983 r
.16829 .55479 .19783 .57086 .23765 .5731 .20851 .55593 Metetra
.662 .825 .961 r
.20851 .55593 .23765 .5731 .27975 .5578 .25111 .54042 Metetra
.779 .837 .897 r
.25111 .54042 .27975 .5578 .32336 .52768 .29531 .5108 Metetra
.828 .84 .857 r
.29531 .5108 .32336 .52768 .36773 .48698 .34038 .47105 Metetra
.85 .848 .84 r
.34038 .47105 .36773 .48698 .41229 .44083 .38572 .42603 Metetra
.856 .862 .844 r
.38572 .42603 .41229 .44083 .45671 .39456 .43097 .38084 Metetra
.843 .881 .868 r
.43097 .38084 .45671 .39456 .50094 .35311 .47604 .3402 Metetra
.798 .899 .914 r
.47604 .3402 .50094 .35311 .5452 .32058 .52112 .30806 Metetra
.691 .896 .971 r
.52112 .30806 .5452 .32058 .58994 .29992 .56662 .28726 Metetra
.482 .823 .998 r
.56662 .28726 .58994 .29992 .63574 .29269 .6131 .27925 Metetra
.202 .659 .944 r
.6131 .27925 .63574 .29269 .68323 .29872 .66118 .28385 Metetra
0 .495 .857 r
.66118 .28385 .68323 .29872 .73293 .31568 .71136 .29879 Metetra
0 .432 .83 r
.71136 .29879 .73293 .31568 .78498 .33844 .76384 .31914 Metetra
.056 .504 .892 r
.76384 .31914 .78498 .33844 .83891 .35833 .8182 .33667 Metetra
.314 .732 .976 r
.1373 .54175 .16829 .55479 .20851 .55593 .17803 .54135 Metetra
.65 .85 .977 r
.17803 .54135 .20851 .55593 .25111 .54042 .22116 .52574 Metetra
.772 .865 .918 r
.22116 .52574 .25111 .54042 .29531 .5108 .26596 .49714 Metetra
.825 .871 .879 r
.26596 .49714 .29531 .5108 .34038 .47105 .31172 .45914 Metetra
.85 .885 .864 r
.31172 .45914 .34038 .47105 .38572 .42603 .35784 .41617 Metetra
.855 .906 .868 r
.35784 .41617 .38572 .42603 .43097 .38084 .40396 .37295 Metetra
.837 .933 .892 r
.40396 .37295 .43097 .38084 .47604 .3402 .44995 .33387 Metetra
.774 .955 .931 r
.44995 .33387 .47604 .3402 .52112 .30806 .49596 .30261 Metetra
.627 .936 .963 r
.49596 .30261 .52112 .30806 .56662 .28726 .54236 .28182 Metetra
.369 .821 .937 r
.54236 .28182 .56662 .28726 .6131 .27925 .58967 .27284 Metetra
.084 .628 .842 r
.58967 .27284 .6131 .27925 .66118 .28385 .63846 .27542 Metetra
0 .475 .765 r
.63846 .27542 .66118 .28385 .71136 .29879 .68923 .28739 Metetra
0 .434 .774 r
.68923 .28739 .71136 .29879 .76384 .31914 .74218 .30415 Metetra
.025 .526 .873 r
.74218 .30415 .76384 .31914 .8182 .33667 .79701 .31818 Metetra
.337 .757 .977 r
.10492 .52986 .1373 .54175 .17803 .54135 .14625 .5276 Metetra
.639 .86 .983 r
.14625 .5276 .17803 .54135 .22116 .52574 .18991 .51199 Metetra
.758 .877 .933 r
.18991 .51199 .22116 .52574 .26596 .49714 .23528 .48479 Metetra
.812 .889 .899 r
.23528 .48479 .26596 .49714 .31172 .45914 .2817 .44909 Metetra
.838 .907 .885 r
.2817 .44909 .31172 .45914 .35784 .41617 .32859 .40882 Metetra
.841 .933 .889 r
.32859 .40882 .35784 .41617 .40396 .37295 .37559 .36819 Metetra
.813 .96 .907 r
.37559 .36819 .40396 .37295 .44995 .33387 .42253 .3312 Metetra
.73 .972 .929 r
.42253 .3312 .44995 .33387 .49596 .30261 .46954 .30118 Metetra
.557 .928 .925 r
.46954 .30118 .49596 .30261 .54236 .28182 .51692 .28054 Metetra
.298 .792 .862 r
.51692 .28054 .54236 .28182 .58967 .27284 .56515 .27043 Metetra
.05 .615 .771 r
.56515 .27043 .58967 .27284 .63846 .27542 .61476 .27055 Metetra
0 .494 .725 r
.61476 .27055 .63846 .27542 .68923 .28739 .66621 .27884 Metetra
0 .478 .765 r
.66621 .27884 .68923 .28739 .74218 .30415 .71972 .29113 Metetra
.062 .575 .881 r
.71972 .29113 .74218 .30415 .79701 .31818 .77506 .3008 Metetra
.4 .781 .991 r
.07138 .51663 .10492 .52986 .14625 .5276 .11332 .51243 Metetra
.636 .852 .982 r
.11332 .51243 .14625 .5276 .18991 .51199 .15752 .49686 Metetra
.741 .871 .94 r
.15752 .49686 .18991 .51199 .23528 .48479 .20342 .47118 Metetra
.794 .886 .912 r
.20342 .47118 .23528 .48479 .2817 .44909 .25044 .43794 Metetra
.818 .907 .901 r
.25044 .43794 .2817 .44909 .32859 .40882 .29805 .40053 Metetra
.82 .933 .906 r
.29805 .40053 .32859 .40882 .37559 .36819 .34587 .36267 Metetra
.79 .959 .921 r
.34587 .36267 .37559 .36819 .42253 .3312 .39375 .32792 Metetra
.708 .966 .937 r
.39375 .32792 .42253 .3312 .46954 .30118 .44175 .29925 Metetra
.55 .924 .929 r
.44175 .29925 .46954 .30118 .51692 .28054 .49015 .27879 Metetra
.328 .811 .877 r
.49015 .27879 .51692 .28054 .56515 .27043 .53935 .2675 Metetra
.123 .67 .811 r
.53935 .2675 .56515 .27043 .61476 .27055 .58984 .265 Metetra
.01 .577 .788 r
.58984 .265 .61476 .27055 .66621 .27884 .64203 .26935 Metetra
.023 .571 .835 r
.64203 .26935 .66621 .27884 .71972 .29113 .69615 .27679 Metetra
.171 .649 .928 r
.69615 .27679 .71972 .29113 .77506 .3008 .75203 .28175 Metetra
.473 .784 .998 r
.03702 .49924 .07138 .51663 .11332 .51243 .07955 .49337 Metetra
.64 .826 .972 r
.07955 .49337 .11332 .51243 .15752 .49686 .12423 .4778 Metetra
.727 .844 .936 r
.12423 .4778 .15752 .49686 .20342 .47118 .17062 .45333 Metetra
.774 .859 .913 r
.17062 .45333 .20342 .47118 .25044 .43794 .21821 .42205 Metetra
.798 .878 .905 r
.21821 .42205 .25044 .43794 .29805 .40053 .26649 .38692 Metetra
.802 .9 .911 r
.26649 .38692 .29805 .40053 .34587 .36267 .31508 .35127 Metetra
.781 .923 .931 r
.31508 .35127 .34587 .36267 .39375 .32792 .36382 .31829 Metetra
.724 .936 .957 r
.36382 .31829 .39375 .32792 .44175 .29925 .41274 .29066 Metetra
.615 .919 .976 r
.41274 .29066 .44175 .29925 .49015 .27879 .46207 .27026 Metetra
.458 .857 .97 r
.46207 .27026 .49015 .27879 .53935 .2675 .51218 .25788 Metetra
.299 .765 .943 r
.51218 .25788 .53935 .2675 .58984 .265 .56352 .25307 Metetra
.204 .691 .927 r
.56352 .25307 .58984 .265 .64203 .26935 .61646 .25393 Metetra
.211 .673 .944 r
.61646 .25393 .64203 .26935 .69615 .27679 .67122 .25709 Metetra
.317 .708 .98 r
.67122 .25709 .69615 .27679 .75203 .28175 .72768 .25782 Metetra
.524 .753 .98 r
.00232 .47502 .03702 .49924 .07955 .49337 .04527 .46819 Metetra
.645 .785 .949 r
.04527 .46819 .07955 .49337 .12423 .4778 .09039 .45238 Metetra
.718 .801 .917 r
.09039 .45238 .12423 .4778 .17062 .45333 .1373 .42812 Metetra
.759 .811 .894 r
.1373 .42812 .17062 .45333 .21821 .42205 .18549 .39734 Metetra
.78 .821 .884 r
.18549 .39734 .21821 .42205 .26649 .38692 .23443 .36284 Metetra
.784 .83 .888 r
.23443 .36284 .26649 .38692 .31508 .35127 .28375 .32776 Metetra
.77 .838 .904 r
.28375 .32776 .31508 .35127 .36382 .31829 .33324 .29517 Metetra
.735 .842 .93 r
.33324 .29517 .36382 .31829 .41274 .29066 .38292 .26764 Metetra
.672 .834 .961 r
.38292 .26764 .41274 .29066 .46207 .27026 .433 .24692 Metetra
.58 .805 .985 r
.433 .24692 .46207 .27026 .51218 .25788 .48383 .23373 Metetra
.477 .757 .992 r
.48383 .23373 .51218 .25788 .56352 .25307 .53584 .22757 Metetra
.398 .708 .985 r
.53584 .22757 .56352 .25307 .61646 .25393 .58941 .22656 Metetra
.379 .685 .979 r
.58941 .22656 .61646 .25393 .67122 .25709 .64477 .22744 Metetra
.429 .698 .977 r
.64477 .22744 .67122 .25709 .72768 .25782 .70185 .22585 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.15767 .20795 m
.16227 .21262 L
s
[(0.2)] .14845 .1986 .98563 1 Mshowa
.28411 .15844 m
.2885 .16331 L
s
[(0.4)] .27533 .14869 .90053 1 Mshowa
.41694 .10643 m
.42109 .11151 L
s
[(0.6)] .40865 .09626 .81543 1 Mshowa
.55666 .05172 m
.56052 .05702 L
s
[(0.8)] .54892 .04112 .73033 1 Mshowa
.125 Mabswid
.06675 .24355 m
.0696 .24627 L
s
.0967 .23182 m
.09952 .23457 L
s
.127 .21996 m
.12979 .22273 L
s
.1887 .1958 m
.19144 .19863 L
s
.22012 .1835 m
.22282 .18636 L
s
.25192 .17104 m
.25459 .17394 L
s
.3167 .14568 m
.3193 .14863 L
s
.3497 .13276 m
.35226 .13575 L
s
.38311 .11967 m
.38563 .12269 L
s
.4512 .09301 m
.45365 .09609 L
s
.4859 .07942 m
.48831 .08254 L
s
.52105 .06566 m
.52342 .06881 L
s
.59272 .0376 m
.595 .04081 L
s
.62926 .02329 m
.63149 .02653 L
s
.66629 .00879 m
.66847 .01207 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00ooooool7ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0GOooool00?oooooo1oooool01Omg
MgOoV9RHoooooonHV9SoMgMg05gooooo003oooooo`Oooooo00Go410@oooooooooooooooooa0@401M
ooooo`00ooooool7ooooo`05o`000?ooooooooooooooool00000GOooool00?oooooo1oooool01Ol0
003ooooooooooooooooo000005gooooo003oooooo`Oooooo00Go410@oooooooooooooooooa0@401M
ooooo`00ooooool1ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo003moooo
o`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^05gooooo003koooo
o`;o00001?ooool2o`0006Gooooo003hooooo`?o00001_ooool00ol0003oooooo`00001Tooooo`00
`Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`08?ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001Toooo
o`00`Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B407Oooool3o`0000_ooooo00Co0000oooooooooooo0000Hoooool00<7ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000006_ooool3o`0000kooooo
00Go0000ooooooooooooooooo`00001Rooooo`00`Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Hooooo`;o00004Oooool01Ol0003ooooooooooooooooo
000006;ooooo0031ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0
003oc<c<01Gooooo1?l0000Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Gooo
ool00<7ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
4oooool2o`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03o`00063ooooo
0031ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000013o
oooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool00<7ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03_ooool2o`00
01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`00hOooool3o`0001ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Looooo`00goooool2o`0000;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05cooooo
001looooo`;o00000_ooool2o`0005[ooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Foooool007cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeHooooo`;o0000
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo001mooooo`04omgMgOl0
003o410@olc<c5Kooooo0ol0000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
F_ooool007gooooo00Cok^k^ob4Q8Ol@413ok^k^Doooool5o`0002Wooooo00?o0000ooooooooool0
1_ooool2o`0005_ooooo001mooooo`04ob4Q8OmgMgOoMgMgoc8b<U7ooooo0_l00005ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00O?oo
ool2o`0000;ooooo0_l0001=ooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Sooooo003=ooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo05Oooooo003:ooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Oooooo002Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b
<_l0003o410@olc<c00Oooooo`;o00000oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0E_ooool009Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01cooooo0ol0000jooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0EOooool009Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000006_ooool2o`0003kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Eooooo`00U?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@0Gooooo`?o0000@?ooool00ol0003oooooooooo`0:ooooo`;o
0000E_ooool009Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`05Oooool2o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05?ooooo002Dooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`0Dooooo`?o0000AOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0003Sooooo002Doooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Booooo`;o0000B?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A403Sooooo002Dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410=ooooo`?o0000B_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^03Wooooo002cooooo`Co0000C?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
03Sooooo002aooooo`;o00001?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool0=oooool00:kooooo0ol0001Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0=_ooool00:co
oooo0_l0001Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400hooooo`00ZOooool4o`00
05Kooooo00?o0000ooooooooool03oooool00ol0003oooooo`000003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<03Sooooo002Wooooo`;o00001?ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
0:Cooooo0ol0001Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool00:;o
oooo0_l0001Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool006Wooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01oo
oooo0ol0001Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Boooool006Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Nooooo`;o
00000_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Boooool006Wooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool3o`0006Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`00JOooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool3o`0006[ooooo00?o0000oooo
ooooool04oooool3o`0004_ooooo001Yooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0000Hooooo`;o0000KOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Wooooo001Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000E
ooooo`?o00000_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0B?ooool006Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000001?ooooo0_l0001booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool0
06Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0ol0001d
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool008_ooooo0_l0001goooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool008Sooooo0ol000000ooooooo
0000ooooo`1fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool008Kooooo
0_l0001looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool008?ooooo0ol0
001nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000A_ooool0087ooooo0_l00021
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool007kooooo0ol000000ooo
oooo0000ooooo`20ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool007_o
oooo0ol00005ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`12ooooo`00NOooool2o`0008Wooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`12ooooo`00@?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
8Oooool3o`0008_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`00@?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@07oooool2o`0000;ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo043ooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP0Mooooo`?o0000TOooool00ol0003oooooooooo`0Looooo`;o0000@_ooool0043ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0002Dooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08_ooool0043ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo0ol0002Fooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo02?ooooo0010ooooo`05oa0@4?ooooooooooooooool@41003oooool0
0ol0003oooooooooo`0Cooooo`;o00000_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
0008ooooo`?o000000?o410@ooooooooool05_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004_ooool3o`0009_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool0000;ooooo`03oa0@4?nj^[[ooooo01Oooooo0010ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<013ooooo0_l0002Nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
gMgMoeEEEOoooooo00002oooool00onHV9So<S8booooo`0Gooooo`00H_ooool3o`000:3ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`00000;ooooo`03omgMgOl0003o^[Zj01Oooooo001Pooooo`;o00000_oo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000;ooooo`03oeEEEOmgMgOoA4A401Oooooo
001Mooooo`?o0000YOooool00ol0003oooooooooo`0Sooooo`09o`000?ooooooooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool02Oooool01OoMgMgo410@oooooolQ8B7o
gMgM01Kooooo001Jooooo`?o0000Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01oooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`00F?ooool3o`000:[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool05?ooool005Gooooo0ol00003ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Looooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool04oooool005?ooooo0_l0002`ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?ooool002Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Rooooo`?o0000/_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo000Yooooo`05ogMgMonHV9SooooooiRHV?mg
MgL08?ooool3o`000;Cooooo00?o0000ooooooooool09Oooool3o`0003Sooooo000Yooooo`05oa0@
4?ooooooooooooooool@41007Oooool3o`0000?ooooo00?o0000ooooooooool0Z?ooool;o`0002So
oooo00?o0000ooooooooool0=_ooool002Wooooo00Go0000ooooooooooooooooo`00000Kooooo`;o
0000P_ooool_o`0000WoKK;j0_l0000Yooooo`03o`000?oooooooooo03Gooooo000Yooooo`05o`00
0?ooooooooooooooool000006?ooool3o`0007_ooooo2Ol00006og[1o@03o`000?mU]OcoIKGl00go
IKGl00?o0000of6_n_mQ[oX03_mQ[oX00ol0003oKK;joffbnP0?offbnP03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=Oooool002Wooooo00Go410@oooooooooooooooooa0@400Fooooo`;o
000000?oooooo`000?ooool0MOooool6o`00013oN/7m00?o0000ofFeo?mU]O`03OmU]O`00ol0003o
HJojof6_nP0>of6_nP03o`000?m]/_[oKK;j00koKK;j0_l0000Yooooo`03o`000?oooooooooo03Co
oooo000Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool3o`0007Kooooo1?l00004oiC>o003
o`000?mj`OgoN/7m013oN/7m00?o0000ofFeo?mU]O`03OmU]O`00ol0003oHJojof6_nP0>of6_nP03
o`000?m]/_[oKK;j00goKK;j00?o0000offbn_l00000:Oooool00ol0003oooooooooo`0cooooo`00
:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0ol0001eooooo`Co00002OnDc_`00ol0003o
N/7mog[1o@0@og[1o@03o`000?mU]OcoIKGl00goIKGl00?o0000of6_n_mQ[oX03_mQ[oX00ol0003o
KK;joffbnP0<offbnP03o`000?m]/_[o000002Wooooo00?o0000ooooooooool0<oooool003cooooo
0_l0001dooooo`Co00003_nDc_`00ol0003oN/7mog[1o@0@og[1o@03o`000?mU]OcoIKGl00goIKGl
00?o0000of6_n_mQ[oX03_mQ[oX00ol0003oKK;joffbnP0;offbnP04o`000?m]/_[oKK;jo`0002So
oooo0_l0000dooooo`00>Oooool3o`0000;ooooo00?o0000ooooooooool0K_ooool3o`0001?oU<kl
00?o0000og[1oOmj`Od04?mj`Od00ol0003oIKGlofFeo00=ofFeo003o`000?mQ[o[oHJoj00koHJoj
00?o0000offbn_m]/_X02Om]/_X2o`0000?oKK;j00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0aooooo`00=oooool2o`0007Cooooo0_l00003ojcEmP03o`000?nDc_coU<kl017oU<kl00?o
0000og[1oOmj`Od04?mj`Od00ol0003oIKGlofFeo00=ofFeo003o`000?mQ[o[oHJoj00koHJoj00?o
0000offbn_m]/_X01Om]/_X3o`000003offbn_l0003oKK;j00;oKK;j00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0aooooo`00=?ooool3o`0007Cooooo0_l00006ojcEmP03o`000?nDc_co
U<kl017oU<kl00?o0000og[1oOmj`Od03?mj`OdNo`0000OoHJoj00Co0000offbn_m]/_[oKK;j0ol0
0005offbnP05o`000?m]/_[oKK;joffbn_l00000:Oooool00ol0003oooooooooo`0`ooooo`00<ooo
ool2o`0007?ooooo0ol00009ojcEmP03o`000?nDc_coU<kl017oU<kl00?o0000og[1oOmj`Od00_mj
`Od9o`0000KoC<?a0_l0000>ocB`k@03o`000?lf[?7o=Zca00Go=Zca4_l00002offbnP05o`000?m]
/_[oKK;joffbn_l00000:Oooool00ol0003oooooooooo`0_ooooo`00<oooool3o`00073ooooo0_l0
000=ojcEmP;o00004?nDc_`6o`00017oC<?a0_l0000=ocB`k@;o00002_lf[?43o`000003ocJ/lOl0
003oDKGj00OoDKGj2Ol0000Wooooo`03o`000?oooooooooo02oooooo000cooooo`04o`000?oooooo
ooooo`0006gooooo0_l0000AojcEmP03o`000?nDc_coU<kl00WoU<kl1?l00005ogGKn0?o00004Om<
`o42o`0000go=;3]0_l00005ocJ/l@?o00001Olf[?400ol0003oDKGjoe6enP08oe6enP03o`000?mA
]O[oDKGj00?oDKGj00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00<oooool0
1Ol0003ooooooooooooooooo000006[ooooo0_l0000DojcEmP03o`000?nDc_coU<kl00GoU<kl0ol0
000<ogGKn0?o00002?m<`o4Ao`0000Ko=;3]00?o0000ocJ/lOl000000_l00009ocJ/l@03o`000?mA
]O[oDKGj00SoDKGj00?o0000oe6en_mA]OX00omA]OX00ol0003oooooooooo`0Sooooo`03o`000?oo
oooo000000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<01;ooooo000booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
IOooool3o`0001Ko[=Gf00?o0000oiC>o?nDc_`01?l0000?ogGKn0_o00002olOZll4o`0000;o0Y?9
2ol0000:ocJ/l@03o`000?mA]O[oDKGj00SoDKGj00?o0000oe6en_mA]OX00omA]OX00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01;ooooo000booooo`?o00001?ooool00ol0003o
ooooooooo`1Rooooo`;o00000onlenh00ol0003o[=GfojcEmP0CojcEmPCo00003OmefoP5o`0000So
DloP6Ol00004o`:Cb@So00001Olf[?400ol0003oDKGjoe6enP07oe6enP03o`000?mA]O[oDKGj00Co
DKGj00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001;ooooo000booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Goooool2o`0000Ko_=O^00?o0000ojcEm_n/eOH03on/eOH3o`00
00CoWN_i1?l00004ogGKn0Go00002OmCcn05o`0000?oC<[L1Ol00005oekBk`?o00000olEX=L?o`00
00;o1I;E1Ol000000olf[?7o0000oe6enP08oe6enP03o`000?mA]O[oDKGj00CoDKGj00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oV9RHoooooonHV9So8B4Q01;ooooo000booooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0G?ooool2o`0000Wo_=O^0_l0000<ojcEmP?o00002onMjoT7o`0000KoDloP1Ol00003
odc:g0Go00003?mNd^l7o`0000Go5J3G2_l00004o`FBe@go00001_mA]OX00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`04_ooool003;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Iooooo`;o00003Onlenh00ol0003o[=GfojcEmP07ojcEmP;o00003?nMjoT2o`0000OoS>c]3_l0
000<oekBk`Ko00000omkd_l00ol0003o<jSaoc>Xl@07o`000003oaFPeol0003o000000Wo00001?l5
T]D2o`0000Ko:jK]2_l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo01Cooooo000booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool2o`00013o_=O^00?o0000ojcEm_n/eOH00on/eOH3o`0000coWN_i0_l0
0008ohc/k@?o00001_n>kN`2o`0000CoX>of1?l00003oekBk`So00001omkd_l2o`0000Oo<jSa1_l0
00000ol0NL?o0000o`000008o`000003o`FBeOl0003o000000Go:jK]00?o0000ob^VkOl[Y^d01_l[
Y^d00ol0003oooooooooo`0Qooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?ogMgMoa0@4?nHV9P05?ooool003;ooooo0_l0000:ooooo`03o`000?oooooooooo05?ooooo0_l0
000CokcGkP03o`000?n/eOKo000000;o00003?nMjoT3o`0000SoS>c]0_l00007ohk]k0;o00002_nP
koH3o`0000;oNm;o0ol0000<og_Bo`03o`000?lcZ?7o<jSa00Wo<jSa1?l00002o`1i``Co00000_l0
N/<5o`0000Co:jK]00?o0000ob^VkOl[Y^d01_l[Y^d00ol0003oooooooooo`0Oooooo`03o`000?oo
oooo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41;o
oooo000aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool2o`0001Go_=O^
1?l0000;oig[n@;o00002?n<k>d3o`0000KoS^g/0ol00009oj3_mP?o00000_n`iOP3o`00013oNm;o
00?o0000oc>XlOlcZ?402_lcZ?400ol0003o07kKo`000002o`0000;o07W31?l00003o`1j``Go0000
00?o:jK]o`000?l[Y^d01ol[Y^d00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Sooooo
000aooooo`03o`000?oooooooooo00cooooo0_l0001>ooooo`?o00005?nlenh2o`0000Co^Nod0ol0
0006oig[n@;o00002?n<k>d2o`0000OoS^g/0_l0000:oj3_mP;o00000_n`iOP3o`0000?o/>Gh00?o
0000og_Boomkd_l02omkd_l<o`0000Co<jSa0_l00002o`1nf`?o000000?o07W3o`000?l0KlH01?l0
0002o`1j``So00001Ol[Y^d00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Oooooo000a
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool01Ol0003oaMKWolGFioo5
e^Oo000001;o_=O^00?o0000okW_m?niko@01oniko@3o`000003oig[nOl0003o000000OoS>c]0ol0
0007ohk]k0;o00002OnPkoH3o`000004ok3Un?l0003o0000o`0000Oo/>Gh0_l00004og_Bo`Oo0000
1?n>`_T00ol0003oEJGgoeFUm`05oeFUm`So00000ol0O]/4o`0000?o06o60ol000001?l0N/?o0000
o`nChOl00003o`nCh@Go000000?o:jK]o`000?ooool08Oooool00ol0003oooooooooo`0Wooooo`00
<Oooool2o`00013ooooo00?o0000ooooooooool0Aoooool2o`0000GoaMKW00?o0000okcGk_nlenh0
3Onlenh2o`0000co^Nod3ol00004ohk]k0;o00002OnPkoH2o`0000;o/>Gh0_l0000;ok3Un0Go0000
3?n>`_T00ol0003oEJGgoeFUm`0:oeFUm`03o`000?lQP^Wo000000;o00000ol0O]/3o`0000Co06o6
1Ol00007o`nCh@Co00008Oooool00ol0003oooooooooo`0Vooooo`00<Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo04Gooooo00?o0000olGFioo5e^L01_o5e^L00ol0003o_=O^okcG
kP0:okcGkP;o00003?niko@2o`0000So]OO_00?o0000ok[hkOnjn>d01?njn>d8o`0000CoX>of0ol0
00001?n`iOSo0000o`000?l0000:ok3Un0?o00000_necnd00ol0003oS/;iohk2n@0=ohk2n@03o`00
0?mEYOOoEJGg00[oEJGg00Co0000ob62jOlQP^Wo8H;Y0ol00003o`1nf`?o00001?l0KlH4o`0000Wo
3i?Q00?o0000ooooooooool07_ooool2o`0002Oooooo000aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0@_ooool2o`0000[oaMKW0_l00009okcGkP03o`000?nikoCo^Nod00_o^Nod
00?o0000okGgkonemnl01_nemnl2o`0000So^_S]00?o0000olKdk_o6m>h01?o6m>h8o`0000_o/>Gh
0_l00006okG?k@03o`000?n>`_WoS/;i00goS/;i00?o0000oeFUmomEYOL02_mEYOL00ol0003o8H;Y
ob62j@03ob62j@;o00000_l0O]/5o`0000?o06o61Ol00007o`nCh@03o`000?oooooooooo01gooooo
0_l0000Wooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo043ooooo00?o
0000olGFioo5e^L03?o5e^L00ol0003o_=O^okcGkP04okcGkP;o00003?niko@2o`0000So]OO_00?o
0000ok[hkOnjn>d01_njn>d2o`0000Soa_C^1_l0000:ok3Un0;o00002Onecnd00ol0003oS/;iohk2
n@0=ohk2n@03o`000?mEYOOoEJGg00[oEJGg00?o0000ob62jOlQP^T01?lQP^T3o`000004o`1nfol0
003o06kDo`1^e0?o000000Go06o6o`000?l0003o0000o`J6g`04o`0000Co3i?Q00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Tooooo`00<?ooool3o`0001Cooooo00?o0000ooooooooool0
?_ooool00ol0003oaMKWolGFi`0>olGFi`04o`000?nlenko_=O^okcGkP;o00003?niko@2o`0000So
]OO_0_l00008ok[hk@03o`000?o6m>koa_C^00Koa_C^0ol00005olcVj@;o00001On`iOP3o`0000co
]Lo]00?o0000ohk2nOn>`_T03On>`_T00ol0003oEJGgoeFUm`0:oeFUm`03o`000?lQP^Wo8H;Y00Ko
8H;Y0ol00004o`1^e0?o000000?o06o6o`000?l6Q]l00ol6Q]l3o`0000;o3i?Q00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Tooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03_ooooo0_l0000BolGFi`03o`000?nlenko000000go^Nod00?o0000okGgkonemnl0
1onemnl00ol0003o^_S]ok[hk@07ok[hk@03o`000?o6m>koa_C^00Coa_C^1?l00009olcVj@;o0000
00?o/>Gho`000?l000004?necnd00ol0003oS/;iohk2n@0:ohk2n@So00002?mEYOL00ol0003o8H;Y
ob62j@08ob62j@;o00001Ol0K]@3o`0000Ko1XKO1?l0000Oooooo`03o`000?oooooooooo02?ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0iooooo`03o`000?o5e^Oo
aMKW01;oaMKW1?l0000:okW_m0;o00002?nemnl2o`0000So^_S]0_l00004olKdkP?o000000?oa_C^
o`000?l000002oo<i^T2o`0001?o]Lo]00?o0000ohk2nOn>`_T00_n>`_T7o`0000?oUJkX00?o0000
ofbIjom/VN/00_m/VN/7o`0000;oEJGg00?o0000ob62jOlQP^T02?lQP^T3o`0000?o06kD00?o0000
o`1^e?l0K]@00ol00006o`J6g`?o00007_ooool00ol0003oooooooooo`0Rooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Kooooo0_l0000DolGFi`03o`000?o7k>koanc^00;oanc^
0ol00005okW_m0;o00002Onemnl00ol0003o^_S]ok[hk@07ok[hk@04o`000?o6m>koa_C^olKdkP?o
00000oo6m>h00ol0003oc>KYolcVj@0:olcVj@04o`000?o:d^3ob];Po`0001;o]Lo]1Ol0000;oiF^
j003o`000?m/VN_oK9W[00SoK9W[1_l00008ob62j@03o`000?l<LMoo000000;o000000Ko06kDo`00
0?l0K]Co06kDo`000?l>PN@3o`0000Ko1XKO00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Rooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`03o`000?o5e^OoaMKW01;o
aMKW0_l00008olO/kP?o000000?o^Nodo`000?nemnl02?nemnl2o`0000So^_S]0_l000001?o6m>ko
0000o`000?l00005olKdkP03o`000?o<i^Woc>KY00[oc>KY00?o0000ol[Bh?o:d^000_o:d^000ol0
003o]Lo]okG?k@0<okG?k@?o000000?o/k[No`000?nE[^P03_nE[^P00ol0003oK9W[ofbIj`0:ofbI
j`03o`000?m2PNKo@X7V00?o00001_lQP^T01?l0003o377Oo`aagol<LMl3o`0000;o06kD00Co0000
o`j1i?l>PNCo3X7T1?l00003o`J6g`;o00006oooool2o`0002?ooooo0006ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Jooooo`03o`000?oooooooooo037o
oooo0ol0000BolGFi`;o00003?o7k>h7o`0000Co]OO_00?o0000ok[hkOnjn>d01onjn>d01?l0003o
a_C^o`000?l00006olKdkP;o00003?o<i^T00ol0003ob];Pol[Bh004ol[Bh003o`000?necngo]Lo]
00Wo]Lo]0_l00005ok>jgP03o`000?nE[^SoUJkX00coUJkX00?o0000ofbIjom/VN/02om/VN/00ol0
003o@X7Vod:1iP02od:1iP?o00001?lQP^T00ol0003o377Oo`aag`02o`aag`;o00000_l0K]@00ol0
003o3X7To`j1i004o`j1i0?o00000_l6Q]l00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
023ooooo0006ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Jooooo`;o0000<?ooool01Ol0003ob=CSolSDhoo8e>?o0000013o
aMKW00?o0000olO/k_o7k>h02oo7k>h00ol0003ob_G[ol[ej`05ol[ej`Wo00001?njn>d3o`0000Oo
a_C^00?o0000olcVjOo<i^T02_o<i^T2o`0000Sob];P00?o0000okG?kOnecnd01_necnd2o`0000So
/k[N00?o0000oiF^j?nE[^P03?nE[^P00ol0003oK9W[ofbIj`0;ofbIj`03o`000?m2PNKo@X7V00Co
@X7V0ol00002ob62j@03o`000?l<LMoo377O00;o377O1Ol00008o`j1i0Co00006oooool00ol0003o
ooooooooo`0Pooooo`001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool00ol0003ob=CSolSDh`03
olSDh`;o00003?o5e^L2o`0000goanc^00?o0000ol[ejoo:mN/01oo:mN/00ol0003od?GXom3ej005
om3ej0Ko00001oo6m>h00ol0003oc>KYolcVj@0:olcVj@03o`000?o:d^3ob];P00Wob];P00?o0000
okG?kOnecnd00_necnd3o`0000[o/k[N00?o0000oiF^j?nE[^P03OnE[^P00ol0003oK9W[ofbIj`0:
ofbIj`03o`000?m2PNKo@X7V00Oo@X7V1?l00004o`aag`03o`000?l<LMoo377O00;o00002_l>PN@2
o`0001_ooooo00?o0000ooooooooool07oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo
0_l00008olSDh`03o`000?o5e^OoaMKW00SoaMKW00?o0000olO/k_o7k>h02oo7k>h2o`0000Wob_G[
00?o0000om3ej?o@mNP01?o@mNP4o`0000Coe^kT1?l00002olKdkP03o`000?o<i^Woc>KY00[oc>KY
00?o0000ol[Bh?o:d^002oo:d^001?l0003o]Lo]o`000?l0000>ok>jgP03o`000?nE[^SoUJkX00go
UJkX00?o0000ofbIjom/VN/02_m/VN/00ol0003o@X7Vod:1iP09od:1iP?o00000ol<LMl01?l0003o
377Oo`aagol<LMl2o`0000Wo3X7T00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Noooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo0_l0000Pooooo`03o`000?oo
oooooooo02Oooooo00?o0000olSDhoo8e><02Oo8e><00ol0003oaMKWolGFi`05olGFi`;o00003Oo7
k>h00ol0003ob_G[ol[ej`07ol[ej`;o00001?o@mNP3o`0000;od?GX00?o0000omK^i?oFk^@01ooF
k^@3o`0000[oc>KY0_l0000>ol[Bh0;o00004Onc^]h00ol0003oUJkXoiF^j00<oiF^j003o`000?m/
VN_oK9W[00_oK9W[00?o0000od:1i_m2PNH02Om2PNH01_l0003o;7?Qo`000?l0003o377Oo`0000?o
377O00?o0000ob9niol000000_l00007o`j1i003o`000?oooooooooo01Wooooo00?o0000oooooooo
ool07_ooool002oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Tooooo`;o0000
3Oo8e><2o`0000?oaMKW0_l0000=olO/kP;o00002Oo:mN/01?l0003od?GXom3ej?o@mNP3o`0000Co
d?GX00?o0000omK^i?oFk^@01ooFk^@01?l0003oen7NomOQg_oGhMh2o`0000Ooc>KY00?o0000ol[B
h?o:d^003Oo:d^000ol0003oaKoEo`00000Bok>jgP03o`000?nE[^SoUJkX00coUJkX00?o0000ofbI
jom/VN/02om/VN/00ol0003o@X7Vod:1iP09od:1iP03o`000?l/Ln7o;7?Q00?o00000ol<LMl01?l0
003o8WkWob9niolRO^L3o`0000Go3X7T00?o0000ooooooooool06?ooool2o`0000Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00;ooooo
000_ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003ob=CSolSD
h`0?olSDh`03o`000?o5e^Oo000000koanc^00?o0000ol[ejoo:mN/01oo:mN/2o`000004om3ej?l0
003o0000o`0000God?GX0_l00009omK^i003o`000?oGhMkoen7N00Coen7N0_l00004olcVj@03o`00
0?o:d^3ob];P00cob];P0_l00003olFoe@03o`000?nc^]ko/k[N00oo/k[N00?o0000oiF^j?nE[^P0
2_nE[^P8o`0000SoK9W[00?o0000od:1i_m2PNH02_m2PNH01?l0003o;7?QobachOl/Ln42o`0000?o
377O00?o0000ob9niolRO^L00olRO^L3o`0000?o3X7T00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@02ooooo`00;oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
023ooooo00?o0000olSDhoo8e><04?o8e><3o`0000goanc^00?o0000ol[ejoo:mN/01oo:mN/4o`00
00Ood?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQgP07omOQgP;o000000?oc>KYo`00
0?o:d^003Oo:d^000ol0003oaKoEolFoe@04olFoe@03o`000?nc^]ko/k[N00oo/k[N00?o0000oiF^
j?nE[^P00_nE[^P7o`0000?oV9kI00?o0000ogV?g?miSm`00_miSm`7o`0000;oK9W[00?o0000od:1
i_m2PNH02Om2PNH00ol0003o;7?Qobach@03obach@;o00000_l<LMl00ol0003o8WkWob9ni`05ob9n
i`?o000000?o3X7To`000?ooool06Oooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000;ooooo000^ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool07Oooool2o`0001;ob=CS00Co0000olgVjOo=i^WocNKY0ol0
0008olO/kP;o00002Oo:mN/2o`0000Wod?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQ
gP09omOQgP?o00003Oo:d^000ol0003oaKoEolFoe@05olFoe@03o`000?nc^]ko/k[N00oo/k[N1Ol0
000;oiRNf@03o`000?miSmcoNHoL00SoNHoL1_l00009od:1iP03o`000?l/Ln7o;7?Q00;o;7?Q00Ko
0000obachOl0003o0000o`aagol00009ob9ni`?o00006_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00;ooooo000^oooo
o`;o00009_ooool00ol0003oooooooooo`0Kooooo`03o`000?o8e>?ob=CS017ob=CS00?o0000olgV
jOo=i^T01Oo=i^T2o`0000Goanc^00?o0000ol[ejoo:mN/01_o:mN/3o`0000[od?GX00?o0000omK^
i?oFk^@02?oFk^@00ol0003oen7NomOQgP09omOQgP05o`000?oDdMKoe=7FomCAe_l000002_o:d^02
o`0000WoaKoE00?o0000ok>jg_nc^]h02onc^]h3o`000003ojnZd_l0003oV9kI00goV9kI00?o0000
ogV?g?miSm`02omiSm`00ol0003oFGkMoeUng@03o`0000Ko@X7V00?o0000obachOl/Ln400ol/Ln40
0ol0003o;7?Qobach@03o`0000_o8WkW00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00;ooooo
000^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06Oooool00ol0003ob=CSolSD
h`0@olSDh`;o00002_o=i^T3o`000003olO/k_l0003ob_G[00Gob_G[1?l0000:om3ej0;o00002OoF
k^@2o`0000_oen7N00?o0000omCAe_oDdMH00ooDdMH00ol0003ob];Pol[Bh006ol[Bh003o`000?o5
_mGoaKoE00[oaKoE00?o0000ok>jg_nc^]h02?nc^]h2o`0000Go[j[B00?o0000oiRNfOnHW]T03?nH
W]T00ol0003oNHoLogV?g00;ogV?g003o`000?mIO]goFGkM00;oFGkM0ol00004od:1iP03o`000?l/
Ln7o;7?Q00?o;7?Q00Co0000obachOl/Ln7o;7?Q0_l0000:ob9ni`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4002ooooo`00;_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Ko
oooo0ol0000AolSDh`03o`000?o=i^WocNKY00cocNKY2Ol00002ol[ej`03o`000?o@mNSod?GX00So
d?GX00?o0000omK^i?oFk^@02?oFk^@00ol0003oen7NomOQgP0:omOQgP03o`000?oDdMKoe=7F00Go
e=7F00?o0000ol[Bh?o:d^000oo:d^02o`0000koaKoE00?o0000ok>jg_nc^]h01Onc^]h2o`0000Oo
[j[B00?o0000oiRNfOnHW]T03OnHW]T00ol0003oNHoLogV?g00:ogV?g003o`000?mIO]goFGkM00Go
FGkM0ol00002od:1iP03o`000?l/Ln7o;7?Q00?o;7?Q00?o0000obachOl/Ln400_l/Ln42o`0000Wo
8WkW00?o0000ooooooooool05oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000000_ooool002kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Dooooo`05o`000?o7d^;oam;RolOBh_l000003_o8e><2o`0000kocNKY00Co0000
om7^iooAk^OodNkW0ol000000ooAk^Oo0000o`000004o`0000Sod?GX00?o0000omK^i?oFk^@02?oF
k^@00ol0003oen7NomOQgP0:omOQgP03o`000?oDdMKoe=7F00Ooe=7F00Go0000ol[Bh?o:d^3ob];P
o`00000@olFoe@03o`000?nc^]ko/k[N00;o/k[N0ol0000:ojnZdP03o`000?nHW]WoV9kI00coV9kI
00?o0000ogV?g?miSm`02omiSm`00ol0003oFGkMoeUng@07oeUng@?o00001Ol/Ln400ol0003o;7?Q
obach@02obach@03o`000?liONGo000000;o00001olRO^L00ol0003oooooooooo`0Eooooo`04o`00
0?ooooooooooo`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT00_ooool002kooooo0_l0000Zooooo`;o00004_ooool2o`0000Goam;R0_l0000;olSD
h`03o`000?o=i^WocNKY00gocNKY00?o0000om7^iol000000_l00005om7^i`03o`000?oGk^?oenkS
00;oenkS1Ol00002om3ej003o`000?oFk^Coe^kT00Soe^kT00?o0000omOQg_oGhMh02_oGhMh00ol0
003oe=7FomCAeP09omCAeP03o`000?o:d^3o000001;oaKoE00Co0000ok>jg_l0003o00003_n_Z]80
0ol0003oV9kIoiRNf@0<oiRNf@03o`000?miSmcoNHoL00_oNHoL00?o0000oeUngOmIO]d02OmIO]d2
o`0000Co;7?Q00?o0000obachOl/Ln400_l/Ln401?l0003o>GgUocUmiOliOND2o`0000Ko8WkW00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`00;_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00kooooo00?o0000olOBh_o7d^801oo7d^800ol0003ob=CSolSDh`07
olSDh`03o`000?o=i^WocNKY00gocNKY0ol00007om7^i`03o`000?oGk^?oenkS00SoenkS1?l00008
omK^i003o`000?oGhMkoen7N00[oen7N00?o0000omCAe_oDdMH02ooDdMH00ol0003oaKoEolFoe@0A
olFoe@;o00004?n_Z]800ol0003oV9kIoiRNf@0<oiRNf@03o`000?miSmcoNHoL00_oNHoL00?o0000
oeUngOmIO]d02OmIO]d01?l0003oAWGLo`000?l00003obach@03o`000?l/Ln7o;7?Q00;o;7?Q00?o
0000ocUmiOliOND00_liOND3o`0000Co8WkW00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`00;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo0_l0000;
olOBhP03o`000?o8e>?ob=CS00Cob=CS0_l0000=olgVj@?o00002OoAk^L00ol0003oenkSomO^h`09
omO^h`04o`000?oJimkof^ONom[WgPGo00000_oFk^@00ol0003oen7NomOQgP0:omOQgP03o`000?oD
dMKoe=7F00_oe=7F0_l0000BolFoe@03o`000?nn/Lco0000017o[j[B00?o0000oiRNfOnHW]T03?nH
W]T00ol0003oNHoLogV?g00;ogV?g003o`000?mIO]goFGkM00WoFGkM00?o0000odIeg?m6MM`00_l0
00000ol/Ln7o0000obach@03obach@03o`000?liONGo>GgU00Go>GgU0_l00002ob9ni`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05_ooool002gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`09ooooo`03o`000?o7d^;oam;R00coam;R0_l00003olSDh`03o`000?o=i^Wo
cNKY00[ocNKY1?l0000:om7^i`03o`000?oGk^?oenkS00WoenkS00?o0000om[Wg_oJimh01ooJimh3
o`0000_oen7N00?o0000omCAe_oDdMH02ooDdMH01?l0003oc/;>olk2c_l0000@olFoe@05o`000?nn
/Lco_[7<okjac?l000004?n_Z]800ol0003oV9kIoiRNf@0=oiRNf@03o`000?miSmcoNHoL00[oNHoL
00?o0000oeUngOmIO]d02OmIO]d00ol0003oAWGLodIeg002odIeg0?o00001?l/Ln400ol0003o>GgU
ocUmi@06ocUmi@;o000000?o8WkWo`000?ooool06?ooool00ol0003oooooooooo`0Fooooo`00;Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o0000olOBh_o7d^803oo7
d^800ol0003ob=CSo`00000;olgVj@;o00000_o=i^T00ol0003odNkWom7^i`08om7^i`03o`000?oG
k^?oenkS00WoenkS00?o0000om[Wg_oJimh02?oJimh01?l0003ofmcHom_Lf?l00009omOQgP03o`00
0?oDdMKoe=7F00_oe=7F00?o0000olk2c_o>`/h00_o>`/h00ol0003oaKoEolFoe@0;olFoe@;o0000
1?nn/L`00ol0003o[j[BojnZdP0?ojnZdP03o`000?nHW]WoV9kI00coV9kI00?o0000ogV?g?miSm`0
2omiSm`00ol0003oFGkMoeUng@09oeUng@03o`000?m6MMcoAWGL00?oAWGL0ol00003obach@03o`00
0?liONGo>GgU00Oo>GgU0ol0000Hooooo`;o00005oooool002gooooo0ol0000`ooooo`03o`000?oo
oooooooo00Cooooo0_l0000BolOBhP?o00002?o=i^T3o`0000?ocNKY00?o0000om7^iooAk^L01ooA
k^L2o`0000_oenkS00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf002om_Lf0;o00001_oG
hMh00ol0003oe=7FomCAeP0;omCAeP03o`000?o>`/koc/;>00Coc/;>00?o0000olFoeOo5_mD02Oo5
_mD00ol0003o_[7<okjac005okjac003o`000?n_Z];o[j[B00oo[j[B00?o0000oiRNfOnHW]T02OnH
W]T8o`0000WoNHoL00?o0000oeUngOmIO]d02?mIO]d00ol0003oAWGLodIeg005odIeg0?o00000_l/
Ln400ol0003o>GgUocUmi@09ocUmi@03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?oo
ool002gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`03o`000?o7d^;o
am;R017oam;R00Co0000olcPioo<h>Ooc>3W0_l00003olgVj@?o00001?o=i^T2o`0000WodNkW00?o
0000omO^hooGk^<02_oGk^<00ol0003of^ONom[WgP08om[WgP03o`000?oKg=SofmcH00GofmcH0_l0
0003omOQgP03o`000?oDdMKoe=7F00_oe=7F00?o0000olk2c_o>`/h01_o>`/h00ol0003oaKoEolFo
e@07olFoe@03o`000?nn/Lco_[7<00Oo_[7<00?o0000ojnZd_n_Z]803_n_Z]800ol0003oV9kIoiRN
f@02oiRNf@Oo00000onIULl00ol0003oPHWBoh69dP02oh69dPOo00000_miSm`00ol0003oFGkMoeUn
g@09oeUng@03o`000?m6MMcoAWGL00CoAWGL00?o0000odIeg?m6MM`00ol0000;ocUmi@03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool05?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo03;ooooo00Co0000ooooool0003o00004oo7d^800ol0003oc>3W
olcPi`04olcPi`?o00001_o=i^T00ol0003odNkWom7^i`08om7^i`03o`000?oGk^?oenkS00[oenkS
00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf008om_Lf003o`000?oGhMko000000goe=7F
00?o0000olk2c_o>`/h01oo>`/h00ol0003oaKoEolFoe@06olFoe@03o`000?nn/Lco_[7<00So_[7<
00?o0000ojnZd_n_Z]803_n_Z]85o`0000_oVIG?00?o0000oh69d_n1RM802?n1RM85o`0000[oFGkM
00?o0000odIeg?m6MM`01?m6MM`01?l0003oAWGLodIeg?m6MM`2o`0000_o>GgU00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Cooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0<oooool00ol0003oam;RolOBhP0AolOBhP;o00001?o<h>L3o`0000;o
c>3W0_l00004olgVj@03o`000?oAk^OodNkW00SodNkW00?o0000omO^hooGk^<02_oGk^<00ol0003o
f^ONom[WgP08om[WgP03o`000?oKg=SofmcH00[ofmcH0_l0000<omCAeP03o`000?o>`/koc/;>00Wo
c/;>00?o0000olFoeOo5_mD00oo5_mD2o`0000co_[7<00?o0000ojnZd_n_Z]802_n_Z]83o`000003
ojbOb_l0003oVIG?00goVIG?00?o0000oh69d_n1RM802on1RM800ol0003oJGgDo`000002o`0000Oo
FGkM00?o0000odIeg?m6MM`01Om6MM`00ol0003oAWGLodIeg002odIeg0;o00002_liOND00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo000Rooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`0booooo`?o00004_o7d^801?l0003oc>3WolcPioo<h>L3o`00
00Ooc>3W0_l000000oo=i^Wo0000om7^i`09om7^i`03o`000?oGk^?oenkS00[oenkS00?o0000om[W
g_oJimh02?oJimh00ol0003ofmcHom_Lf00:om_Lf004o`000?oGcm7oeloAo`0000[oe=7F00?o0000
olk2c_o>`/h02oo>`/h01Ol0003oaKoEolFoeOo5_mGo000000ko_[7<00?o0000ojnZd_n_Z]802?n_
Z]82o`0000Go[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP04o`000?mY
OMCoJGgDofUme0;o00001_mIO]d00ol0003oAWGLodIeg005odIeg006o`000?m6MMcoAWGLodIeg?l0
003oCGgP0ol00007ocUmi@03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool002;o
oooo00Go0000ooooooooooooooooo`000005ooooo`;o0000<Oooool2o`0000?o`/oT00?o0000olOB
h_o7d^803Oo7d^82o`000004olcPiol0003o0000o`0000_oc>3W1?l00008om7^i`03o`000?oGk^?o
enkS00[oenkS00?o0000om[Wg_oJimh02?oJimh00ol0003ofmcHom_Lf00:om_Lf003o`000?oGcm7o
eloA00;oeloA00?o0000omCAe_oDdMH01_oDdMH00ol0003oc/;>olk2cP0=olk2cP03o`000?o5_mGo
0000013o_[7<00?o0000ojnZd_n_Z]801On_Z]82o`0000Oo[9o:00?o0000oiVEconIULl03?nIULl0
0ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00?oJGgD0ol00003oeUng@03o`000?m6MMco
AWGL00GoAWGL00?o0000odIeg?m6MM`00_m6MM`01?l0003oCGgPodemh?m=ON03o`0000Go>GgU00?o
0000ooooooooool05_ooool2o`0001?ooooo000Rooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?o2cnCo`/oT00Co`/oT0_l0000<olOBhPCo00003Oo<
h>L00ol0003odNSVom7XiP02om7XiPGo00000_oAk^L00ol0003oenkSomO^h`0:omO^h`03o`000?oJ
imkof^ON00Sof^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@04omO?d@;o00001OoD
dMH00ol0003oc/;>olk2cP0>olk2cP;o00004_nn/L`01?l0003o[j[BojnZd_n_Z]83o`0000[o[9o:
00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00GoJGgD
0_l00002oeUng@03o`000?m6MMcoAWGL00GoAWGL00Go0000odIeg?m6MMcoAWGLo`000006odemh0;o
00001?liOND00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo000Rooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0]ooooo`;o00002Oo2cn@2o`0000Wo
am;R0_l0000?olcPi`03o`000?oAj>KodNSV00SodNSV1?l0000:omO^h`03o`000?oJimkof^ON00So
f^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@07omO?d@05o`000?oDdMKoe=7FomCA
e_l000004?o>`/h00ol0003ob;G8o`00000Bokjac004o`000?n_Z];o0000o`0000go[9o:00?o0000
oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00OoJGgD0ol00008
odIeg005o`000?m6MMcoAWGLodIeg?l000001om=ON03o`000003ocUmiOl0003ooooo01Sooooo00?o
0000ooooooooool04?ooool002;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo02_ooooo0_l0000=ol;?i003o`000?o7d^;oam;R00?oam;R0ol0000?olcPi`;o00002_oA
j>H00ol0003oe^SRomKXhP02omKXhP?o00001_oGk^<00ol0003of^ONom[WgP08om[WgP03o`000?oK
g=SofmcH00[ofmcH00?o0000omO?dOoGcm402OoGcm400ol0003oe=7Fo`00000@olk2cP05o`000?o8
]LSob;G8olReb?l000004Onn/L`2o`00013o[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWB
oh69dP0;oh69dP03o`000?mYOMCoJGgD00WoJGgD0_l00006odIeg005o`000?m6MMcoAWGLodIeg?l0
00002_m=ON03o`0001Wooooo00?o0000ooooooooool03oooool002;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o0000:oooool00ol0003o`/oTol;?i00>ol;?i0Ko00004?o<h>L00ol0003o
dNSVom7XiP09om7XiP03o`000?oFj>;oe^SR00Koe^SR0ol00002omO^h`03o`000?oJimkof^ON00So
f^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@0;omO?d@03o`000?o>`/koc/;>00ko
c/;>00?o0000olReb?o8]LP00_o8]LP00ol0003o_[7<okjac00>okjac003o`000?niYlKo0000013o
[9o:00?o0000oiVEconIULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00Wo
JGgD00?o0000oeUge_l000000_l00004odIeg005o`000?m6MMcoAWGLodIeg?l000003?m=ON000ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo02Wo
oooo0_l0000@ol;?i0Co000000?oam;Ro`000?o<h>L03_o<h>L2o`0000_odNSV00?o0000omKXh_oF
j>802_oFj>83o`0000Wof^ON00?o0000om_Lf?oKg=P02_oKg=P00ol0003oeloAomO?d@0<omO?d@03
o`000?o>`/koc/;>00goc/;>00?o0000olReb?o8]LP01?o8]LP00ol0003o_[7<okjac00<okjac005
o`000?niYlKo^JO6okVWa_l000004?n/WlX00ol0003oVIG?oiVEc`0;oiVEc`03o`000?n1RM;oPHWB
00coPHWB00?o0000ofUme?mYOM@02OmYOM@01?l0003oFGOFoeUge_mIMmH3o`0000;oAWGL00Go0000
odIeg?m6MMcoAWGLo`00000;odemh003o`000?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool002_ooooo00?o0000ooooooooool09oooool2o`0000oo`/oT0ol00003ol;?i0?o00003_o<h>L0
0ol0003odNSVom7XiP0:om7XiP03o`000?oFj>;oe^SR00[oe^SR00Co0000omWRgOoIh]gofN;M0ol0
0005om[WgP03o`000?oKg=SofmcH00[ofmcH00?o0000omO?dOoGcm403?oGcm400ol0003od/?;o`00
000=olk2cP03o`000?o8]LSob;G800Kob;G800?o0000okjac?nn/L`02Onn/L`2o`0000Co^JO600?o
0000ojbOb_n/WlX03_n/WlX00ol0003oVIG?oiVEc`0<oiVEc`03o`000?n1RM;oPHWB00_oPHWB00?o
0000ofUme?mYOM@02OmYOM@00ol0003oFGOFoeUgeP04oeUgeP;o000000GoAWGLo`000?m6MMcoAWGL
o`00000<odemh003o`000?oooooooooo01Gooooo00?o0000ooooool000003oooool002_ooooo00?o
0000ooooooooool09_ooool00ol0003o`/oTol;?i00<ol;?i0?o00001Oo2cn@01?l0003oa]_YolKK
jOo6fnT2o`0000_oc>3W00?o0000om7Xi_oAj>H02_oAj>H00ol0003oe^SRomKXhP0:omKXhP03o`00
0?oIh]gofN;M00GofN;M0ol000000ooJimko0000om_Lf00;om_Lf003o`000?oGcm7oeloA00coeloA
00Go0000om;3booB`l_od/?;o`00000;olk2cP03o`000?o8]LSob;G800Oob;G800?o0000okjac?nn
/L`02?nn/L`00ol0003o^JO6okVWaP05okVWaP03o`000?n/Wl[o[9o:00go[9o:00?o0000oiVEconI
ULl03?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00[oJGgD00?o0000oeUge_mI
MmH01OmIMmH3o`0000;oAWGL00?o0000odemh?m=ON002Om=ON000ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00gooooo000[ooooo`03o`000?oooooooooo02Cooooo0ol0000;ol;?i0?o0000
1_o2cn@2o`0000Koa]_Y0_l00007olcPi`;o00003?oAj>H00ol0003oe^SRomKXhP0:omKXhP03o`00
0?oIh]gofN;M00WofN;M0_l0000;om_Lf003o`000?oGcm7oeloA00coeloA00?o0000om;3booB`l/0
0_oB`l/00ol0003oc/;>olk2cP08olk2cP03o`000?o8]LSob;G800Wob;G800?o0000okjac?nn/L`0
1_nn/L`00ol0003o^JO6okVWaP06okVWaP03o`000?n/Wl[o[9o:00ko[9o:00?o0000oiVEconIULl0
3?nIULl00ol0003oPHWBoh69dP0;oh69dP03o`000?mYOMCoJGgD00WoJGgD00?o0000oeUge_mIMmH0
1omIMmH4o`0000coCGgP00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`00:ooo
ool2o`0002?ooooo0_l00003okO=jP03o`000?o2cnCo`/oT00Go`/oT0ol00008ol;?i003o`000?o6
fnWoa]_Y00Soa]_Y0_l00004olcPi`03o`000?oAj>KodNSV00_odNSV00?o0000omKXh_oFj>802_oF
j>800ol0003ofN;MomWRg@09omWRg@03o`000?oIfMOofMWG00;o00002?oKg=P00ol0003oeloAomO?
d@0<omO?d@03o`000?oB`l_od/?;00Cod/?;00?o0000olk2c_o>`/h01_o>`/h00ol0003ob;G8olRe
b00:olReb003o`000?nn/Lco_[7<00Go_[7<00?o0000okVWa_niYlH02?niYlH00ol0003o[9o:ojbO
bP0=ojbObP03o`000?nIULooVIG?00coVIG?00?o0000oh69d_n1RM802on1RM800ol0003oJGgDofUm
e00:ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUge_mIMmH00_l0000;odemh003o`000?oo
oooooooo01Gooooo0ol0000=ooooo`00:oooool00ol0003oooooooooo`0Pooooo`;o00001_ngcNX0
1?l0003o`/oTol;?i?o2cn@3o`0000Wo`/oT0_l0000=olKKj@;o000000?oc>3Wo`000?oAj>H03?oA
j>H00ol0003oe^SRomKXhP0:omKXhP03o`000?oIh]gofN;M00WofN;M00?o0000omWIeooIfML00ooI
fML3o`0000CofmcH00?o0000omO?dOoGcm403?oGcm400ol0003od/?;om;3b`06om;3b`03o`000?o>
`/koc/;>00Coc/;>00?o0000olReb?o8]LP03?o8]LP00ol0003o_[7<okjac002okjac0;o00002oni
YlH00ol0003o[9o:ojbObP0>ojbObP03o`000?nIULooVIG?00WoVIG?2?l00009oh69dP03o`000?mY
OMCoJGgD00[oJGgD00?o0000oeUge_mIMmH01omIMmH01?l0003oFGOFo`000?mMO]/3o`0000SoCGgP
00?o0000ooooooooool04_ooool3o`0000;ooooo00?o0000ooooooooool02oooool002_ooooo00?o
0000ooooooooool07_ooool2o`0000Wo]lgZ0ol0000;ol;?i003o`000?o6fnWoa]_Y00koa]_Y0ol0
000<om7XiP03o`000?oFj>;oe^SR00Woe^SR0_l0000;omWRg@03o`000?oIfMOofMWG00OofMWG0_l0
00000ooKg=So0000omO?d@0=omO?d@03o`000?oB`l_od/?;00Sod/?;00?o0000olk2c_o>`/h00_o>
`/h00ol0003ob;G8olReb00>olReb004o`000?nn/Lco_[7<o`0000ko^JO600?o0000ojbOb_n/WlX0
3On/WlX00ol0003oVIG?oiVEc`02oiVEc`Oo00000onITLT00ol0003oQhO<ohN7c002ohN7c0Oo0000
0_n1RM800ol0003oJGgDofUme00:ofUme003o`000?mIMmKoFGOF00OoFGOF00Co0000oeUge_mIMmKo
00000omMO]/2o`0000OoCGgP00?o0000ooooooooool03_ooool3o`0000Gooooo00?o0000oooooooo
ool02oooool002[ooooo00?o0000ooooooooool07_ooool00ol0003o]lgZokO=jP07okO=jP?o0000
00?o]lgZo`000?o2cn@02?o2cn@2o`00013oa]_Y00Co0000ol_RjOo;h^Wobn;Y0ol00008om7XiP03
o`000?oFj>;oe^SR00Woe^SR00?o0000omWRgOoIh]d02_oIh]d00ol0003ofMWGomWIe`0:omWIe`;o
00003OoGcm400ol0003od/?;om;3b`09om;3b`05o`000?o>`/koc/;>olk2c_l000004Oo8]LP00ol0
003o_[7<o`00000?okVWaP03o`000?n/Wl[o[9o:00go[9o:1Ol0000;oiVAb@03o`000?n7QlcoQhO<
00SoQhO<1_l0000:ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUge_l000001OmMO]/3o`00
00CoCGgP00?o0000ooooooooool02_ooool4o`0000Sooooo00?o0000ooooooooool02oooool002[o
oooo00?o0000ooooooooool07?ooool2o`0000Oo]lgZ0ol00005okO=jP;o00001_o2cn@00ol0003o
a]_YolKKj@0?olKKj@03o`000?o;h^Wobn;Y00Gobn;Y0_l00005om7XiP03o`000?oFj>;oe^SR00Wo
e^SR00?o0000omWRgOoIh]d02_oIh]d00ol0003ofMWGomWIe`0;omWIe`03o`000?oGc]7o000000_o
eloA00?o0000om;3booB`l/02ooB`l/00ol0003oc/;>o`00000BolReb0;o00004?niYlH00ol0003o
[9o:ojbObP0:ojbObP?o000000?oZIW6o`000?nITLT03OnITLT00ol0003oQhO<ohN7c00;ohN7c003
o`000?mdO/ooM7k?00Co00001_mYOM@00ol0003oFGOFoeUgeP08oeUgeP03o`000?mIMmKo000000Oo
GGkK0_l00003odemh003o`000?oooooooooo00Kooooo0ol0000<ooooo`03o`000?oooooooooo00_o
oooo000Zooooo`;o00006oooool2o`0000Ko]lgZ0ol0000:okO=jP04o`000?o2cnCo`/oTol;?i0;o
00004?o6fnT2o`0000[obn;Y0ol000000ooAj>Ko0000omKXhP0:omKXhP03o`000?oIh]gofN;M00[o
fN;M00?o0000omWIeooIfML02ooIfML01Ol0003oelkAomO>dOoGc]7o000000WoeloA00?o0000om;3
booB`l/03OoB`l/00ol0003ob;G8olReb00@olReb003o`000?o2[<Co0000017o^JO600?o0000ojbO
b_n/WlX01on/WlX2o`0000GoZIW600?o0000oiVAbOnITLT02onITLT00ol0003oQhO<ohN7c00<ohN7
c003o`000?mdO/ooM7k?00?oM7k?0ol00004ofUme003o`000?mIMmKoFGOF00OoFGOF00?o0000oeUg
e_l000002OmMO]/2o`0000;oCGgP00?o0000ooooooooool00_ooool3o`00013ooooo00?o0000oooo
ooooool02_ooool002[ooooo00?o0000ooooooooool06?ooool2o`0000Go]lgZ0ol0000>okO=jP03
o`000?o2cnCo0000017oa]_Y00?o0000ol_RjOo;h^T03?o;h^T4o`0000Woe^SR00?o0000omWRgOoI
h]d02_oIh]d00ol0003ofMWGomWIe`0;omWIe`03o`000?oGc]7oelkA00?oelkA00?o0000omO?dOoG
cm401OoGcm400ol0003od/?;om;3b`0>om;3b`03o`000?o8]LSob;G800oob;G800Go0000ol:/a?o2
[<Co`Zc4o`00000@okVWaP03o`000?n/Wl[o[9o:00Go[9o:0_l00007ojVIaP03o`000?nITLWoVI79
00coVI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`06ogAnc`Go00002_mIMmH00ol0
003oFGOFo`00000:oeenf`Oo00004oooool00ol0003oooooooooo`0:ooooo`00:_ooool00ol0003o
ooooooooo`0Fooooo`?o00000ongcNX3o`00017o]lgZ0ol0000?olKKj@;o00003_o;h^T00ol0003o
cn?VoloSiP02oloSiP?o00001OoFj>800ol0003ofN;MomWRg@0:omWRg@03o`000?oIfMOofMWG00_o
fMWG00?o0000omO>dOoGc]401OoGc]400ol0003oeloAomO?d@03omO?d@03o`000?oB`l_od/?;00ko
d/?;00?o0000olfha_l000003oo8]LP00ol0003o`Zc4ol:/a002ol:/a003o`000?niYlKo^JO600oo
^JO600Co0000ojbOb_n/Wl[o[9o:0ol00009ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7
c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`0:ogAnc`?o00002OmIMmH2o`0000goGGkK00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0:ooooo`00:_ooool00ol0003oooooooooo`0Cooooo`?o
00000onUb?83o`0001;o]lgZ0_l00003ok[Hk`;o00003?o6fnT00ol0003obn;Yol_Rj@0=ol_Rj@03
o`000?o?hnKocn?V00Kocn?V0ol000000ooFj>;o0000omWRg@0;omWRg@03o`000?oIfMOofMWG00_o
fMWG00?o0000omO>dOoGc]401ooGc]401Ol0003oeloAomO?dOoGcm7o0000013od/?;00Go0000olfh
a_o=^<KocKS6o`00000=olReb003o`000?o2[<Co`Zc400Co`Zc400?o0000okVWa_niYlH03_niYlH0
1?l0003o[9o:o`000?l0000=ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02on7
Ql`00ol0003oM7k?ogAnc`0:ogAnc`04o`000?mWNm?o0000o`0000SoFGOF0_l0000<oeenf`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool02_ooool002[ooooo0_l0000Aooooo`?o00000onU
b?83o`000003ojG8l_l0003o]lgZ013o]lgZ0_l00007ok[Hk`03o`000?o6fnWoa]_Y00Soa]_Y00?o
0000ol_RjOo;h^T03?o;h^T2o`0000_ocn?V0ol0000;omWRg@03o`000?oIfMOofMWG00_ofMWG00?o
0000omO>dOoGc]402OoGc]400ol0003oeloAo`00000@om;3b`03o`000?o=^<KocKS600;ocKS600?o
0000olReb?o8]LP02_o8]LP00ol0003o`Zc4ol:/a005ol:/a003o`000?niYlKo^JO600ko^JO60_l0
000?ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAn
c`0;ogAnc`03o`000?mWNm?oIg_C00?o00001OmIMmH2o`0000goGGkK00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`0>ooooo`?o00001?nUb?82
o`0000GoYLSb0_l0000=okO=jP;o00002_njf>l2o`0000Koa]_Y0_l0000>ol_Rj@03o`000?o?hnKo
cn?V00[ocn?V00Co0000om?NhOoCg^7odmkQ0_l00008omWRg@03o`000?oIfMOofMWG00_ofMWG00?o
0000omO>dOoGc]402ooGc]400ol0003od/?;om;3b`0>om;3b`03o`000?o=^<KocKS600CocKS600?o
0000olReb?o8]LP01oo8]LP2o`0000Wo`Zc400?o0000okVWa_niYlH03?niYlH00ol0003o]Z73o`00
000@ojVIaP03o`000?nITLWoVI7900coVI7900?o0000ohN7c?n7Ql`02_n7Ql`00ol0003oM7k?ogAn
c`0;ogAnc`03o`000?mWNm?oIg_C00?oIg_C0_l00004oeUgeP;o00003?mMO]/00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00[ooooo00000ol0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0;ooooo`?o00001?nUb?83o`0000Wo
YLSb00?o0000okO=j_ngcNX02OngcNX00ol0003o^]S_ok[Hk`0<ok[Hk`;o00000oo6fnT00ol0003o
bn;Yol_Rj@0<ol_Rj@;o00003?o?hnH00ol0003odmkQom?Nh@04om?Nh@?o00001?oIh]d00ol0003o
fMWGomWIe`0;omWIe`03o`000?oGc]7oelkA00coelkA00?o0000om;3booB`l/03OoB`l/00ol0003o
cKS6olfhaP06olfhaP03o`000?o8]LSob;G800Gob;G800?o0000ol:/a?o2[<@02Oo2[<@00ol0003o
^JO6okVWaP0:okVWaP;o00000onfXL<00ol0003oZIW6ojVIaP0=ojVIaP03o`000?nITLWoVI7900co
VI7900?o0000ohN7c?n7Ql`02on7Ql`00ol0003oM7k?ogAnc`0;ogAnc`03o`000?mWNm?oIg_C00Co
Ig_C0_l00003oeUgeP03o`000?mMO]_oGGkK00_oGGkK00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`0000?ooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo00Oooooo1Ol00003ojG8lP?o00003OnUb?82o`0000Oo]lgZ0_l0000Aok[H
k`03o`000?o6fnWo000000kobn;Y00?o0000oloSi_o?hnH02oo?hnH00ol0003odmkQom?Nh@08om?N
h@;o000000?ofN;Mo`000?oIfML03?oIfML00ol0003oelkAomO>d@0<omO>d@03o`000?oB`lco0000
00god/?;00?o0000olfha_o=^<H01oo=^<H00ol0003ob;G8olReb004olReb003o`000?o2[<Co`Zc4
00_o`Zc400?o0000okVWa_niYlH02?niYlH00ol0003o]Z73okJQ``03okJQ``03o`000?nYVLKoZIW6
00koZIW600?o0000oiVAbOnITLT02onITLT00ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?
00_oM7k?00?o0000ofMkdomWNm<01_mWNm<5o`0000coGGkK00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0:ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07o`0000GoQ/3j0ol0000BojG8lP03o`000?ngcN[o]lgZ00;o]lgZ0_l0000C
ok[Hk`?o00003Oo;h^T00ol0003ocn?VoloSiP0;oloSiP03o`000?oCg^7odmkQ00[odmkQ0ol0000<
omWIe`03o`000?oGc]7oelkA00coelkA00Go0000om;3c?oB`lcod/?<o`00000;om;3b`03o`000?o=
^<KocKS600WocKS600?o0000olReb?o8]LP00_o8]LP00ol0003o`Zc4ol:/a00<ol:/a003o`000?ni
YlKo^JO600Ko^JO60_l00007okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT03?nI
TLT00ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?00_oM7k?00?o0000ofMkdomWNm<02?mW
Nm<2o`0000goGGkK00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`000_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?oMgMgoc8b<_ooool00oooool4o`0000WoQ/3j0ol000000on6`?[o0000
ojG8lP0CojG8lP04o`000?ngcN[o0000o`0001?o^]S_0_l00003okgNl0?o00002?o;h^T2o`0000go
cn?V00?o0000om?NhOoCg^402_oCg^401?l0003odmOKom?GfooCem/2o`0000WofMWG00?o0000omO>
dOoGc]403?oGc]400ol0003od/?<om;3c003om;3c003o`000?oB`l_od/?;00Ood/?;00?o0000olfh
a_o=^<H02_o=^<H01Ol0003ob;G8olReb?o8]LSo0000013o`Zc400?o0000okVWa_niYlH01?niYlH0
0ol0003o]Z73okJQ``07okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT03?nITLT0
0ol0003oQhO<ohN7c00;ohN7c003o`000?mdO/ooM7k?00_oM7k?00?o0000ofMkdomWNm<02_mWNm<3
o`0000[oGGkK00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`000_ooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`?o00001on6`?X3o`0000GoQ/3j
0_l0000BojG8lP?o00004_njf>l2o`0000So_Mk`0_l00005ol_Rj@03o`000?o?hnKocn?V00_ocn?V
0_l0000<om?Nh@03o`000?oCem_odmOK00CodmOK0_l00006omWIe`03o`000?oGc]7oelkA00coelkA
00?o0000om;3c?oB`l`01OoB`l`00ol0003od/?;om;3b`05om;3b`03o`000?o=^<KocKS600cocKS6
00?o0000olReb?l000004Oo2[<@00ol0003o^JO6okVWaP03okVWaP03o`000?nfXL?o]Z7300So]Z73
00?o0000ojVIa_nYVLH03_nYVLH00ol0003oVI79oiVAb@0<oiVAb@03o`000?n7QlcoQhO<00[oQhO<
00?o0000ogAncomdO/l03?mdO/l00ol0003oIg_CofMkd`09ofMkd`;o000000CoJX7Ho`000?l0003o
00002?mMO]/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo0002ooooo`03oa0@
4?oooooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000?oQ/3j0ol0000:ohK0
nP03o`000?nUb?;oYLSb00coYLSb0ol00003oj?Cn0;o00003_njf>l2o`0000co_Mk`0ol000000oo;
h^Wo0000oloSiP0<oloSiP03o`000?oCg^7odmkQ00_odmkQ00?o0000om?GfooCem/01ooCem/00ol0
003ofMWGomWIe`02omWIe`03o`000?oGc]7oelkA00coelkA00?o0000om;3c?oB`l`01ooB`l`00ol0
003od/?;om;3b`03om;3b`03o`000?o=^<KocKS600kocKS600?o0000ol:/a?o2[<@04Oo2[<@00ol0
003o^JO6okVWaP02o`0000co]Z7300?o0000ojVIa_nYVLH03OnYVLH00ol0003oVI79oiVAb@0<oiVA
b@03o`000?n7QlcoQhO<00_oQhO<00?o0000ogAncomdO/l02omdO/l00ol0003oIg_CofMkd`0:ofMk
d`03o`000?mZPMSoJX7H00;oJX7H0ol00005oeenf`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02Oooool00003oooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooooooo`?o00003_n6`?X2o`0000WoYLSb0ol00008oj?Cn003o`000?njf>oo^]S_00[o^]S_00?o
0000okgNl?nmg_003_nmg_03o`0000cocn?V00?o0000om?NhOoCg^402ooCg^400ol0003odmOKom?G
f`09om?Gf`;o000000?ofMWGo`000?oGc]403OoGc]400ol0003od/?<om;3c009om;3c005o`000?oB
`l_od/?;om;3bol000004Oo=^<H00ol0003o`Zc4ol:/a00Aol:/a003o`000?niYlKo000000ko]Z73
00?o0000ojVIa_nYVLH03_nYVLH00ol0003oVI79oiVAb@0;oiVAb@03o`000?n7QlcoQhO<00_oQhO<
00?o0000ogAncomdO/l02omdO/l00ol0003oIg_CofMkd`0:ofMkd`;o00001_mZPMP3o`0000?oGGkK
00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`0000?o0000oc8b<_o^k^h02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co
00001Oooool4o`0000;ooooo00?o0000ohK0n_n6`?X03_n6`?X00ol0003oYLSbojG8lP03ojG8lP?o
00003?nSdoP2o`0000So^]S_0_l0000@okgNl004o`000?o2h>ko`^3^ol;PkP?o00002?o?hnH00ol0
003odmkQom?Nh@0;om?Nh@03o`000?oCem_odmOK00_odmOK0ol0000=omO>d@03o`000?oB`lcod/?<
00_od/?<00?o0000om;3bol000004Oo=^<H00ol0003oak33o`00000Bol:/a0;o00004?nfXL<00ol0
003oZIW6ojVIaP0=ojVIaP03o`000?nITLWoVI7900WoVI792ol00005ohN7c003o`000?mdO/ooM7k?
00coM7k?00?o0000ofMkdomWNm<02_mWNm<2o`0000SoJX7H1?l0000Booooo`03o`000?oooooooooo
00Wooooo000Xooooo`;o00001Oooool2o`0000ooQ/3j00?o0000ojG8l_l000000_l0000Aoj?Cn0;o
00001?njf>l2o`00013o_Mk`0_l00007ol;PkP;o00001Oo?hnH00ol0003odmkQom?Nh@0:om?Nh@;o
00003OoCem/01Ol0003od/gEom;=eOoBcMGo000000_oelkA00?o0000om;3c?oB`l`03OoB`l`00ol0
003ocKS6olfhaP0?olfhaP05o`000?o7/<?oak33olN``ol000004?o2[<@00ol0003o_ZO2o`00000@
okJQ``03o`000?nYVLKoZIW600goZIW600?o0000oiVAbOnITLT00_nITLT7o`0000?oVi3800?o0000
oh^8bon;R</01On;R</:o`0000[oM7k?00?o0000ofMkdomWNm<02_mWNm<00ol0003oJX7Ho`00000:
ofZ1f0;o00004Oooool00ol0003oooooooooo`09ooooo`00:_ooool00ol0003oooooooooo`04oooo
o`03o`000?n6`?[oQ/3j00[oQ/3j1Ol0000Eoj?Cn004o`000?njf>oo0000o`00017o_Mk`00?o0000
ol;Pk_o2h>h02Oo2h>h3o`000003oloSi_l0003odmkQ00_odmkQ00?o0000om?GfooCem/03?oCem/0
0ol0003od/gEom;=e@03om;=e@03o`000?oGc]7oelkA00OoelkA00?o0000om;3c?oB`l`03OoB`l`2
o`00013ocKS600?o0000olN``oo7/<<00_o7/<<00ol0003o`Zc4ol:/a00=ol:/a005o`000?nnYl;o
_ZO2okjW`_l000004?nfXL<00ol0003oZIW6ojVIaP0<ojVIaPGo00002onKT<P00ol0003oRhS;oh^8
b`0:oh^8b`04o`000?mkP/koNh;>og^2cPGo00001_mdO/l00ol0003oIg_CofMkd`0:ofMkd`;o0000
2omZPMP00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000[ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ohK0n_n6`?X00_n6`?X7o`0000GoNLSo0_l0000Coj?Cn0?o00004?nm
g_02o`0000ko`^3^0ol0000;om?Nh@03o`000?oCem_odmOK00codmOK00?o0000om;=eOoBcMD01OoB
cMD00ol0003oelkAomO>d@05omO>d@03o`000?oB`lcod/?<00god/?<00Co0000oljjaoo>^/Oo0000
3_o=^<H00ol0003oak33olN```04olN```03o`000?o2[<Co`Zc400_o`Zc400?o0000okjW`_nnYl80
0_nnYl800ol0003o]Z73okJQ``0>okJQ``03o`000?nYVLKoZIW600WoZIW60ol000000onXV<Go0000
oi^@b00=oi^@b003o`000?n;R<_oRhS;00_oRhS;00?o0000og^2c_mkP/h01OmkP/h5o`000003ogAn
col0003oIg_C00_oIg_C00?o0000ofZ1f?l000002omZPMP00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo000/ooooo`03o`000?oooooooooo00Cooooo1?l0000>ogW8o`03o`000?nS
doSoXm?h00goXm?h0ol00003oj;Jn`;o00003?nmg_02o`0000ko`^3^0_l00003olGMj`;o00002?oC
g^400ol0003odmOKom?Gf`0<om?Gf`03o`000?oBcMGod/gE00Ood/gE00?o0000omO>dOoGc]400ooG
c]400ol0003od/?<om;3c00=om;3c003o`000?o>^/Ooc[[700;oc[[700?o0000olfha_o=^<H02_o=
^<H00ol0003oak33olN```05olN```03o`000?o2[<Co`Zc400[o`Zc400?o0000okjW`_nnYl801?nn
Yl800ol0003o]Z73okJQ``0=okJQ``03o`000?nYVLKoZIW600KoZIW60ol00005ojRHa@03o`000?nK
T<SoVi3800coVi3800?o0000oh^8bon;R</02_n;R</00ol0003oNh;>og^2cP0:og^2cPGo00002OmW
Nm<01?l0003oJX7HofZ1f?l0000:ofZ1f003o`000?oooooooooo00oooooo00?o0000ooooooooool0
2?ooool002gooooo0_l00006ooooo`;o00003omib?l2o`0000[oXm?h0ol00008oj;Jn`?o00002?nm
g_000ol0003o`^3^ol;PkP0=ol;PkP03o`000?o5gN_oaMg[00GoaMg[0ol00004om?Nh@03o`000?oC
em_odmOK00codmOK00?o0000om;=eOoBcMD02OoBcMD01Ol0003oelkAomO>dOoGc]7o000000ood/?<
00?o0000oljjaoo>^/L00oo>^/L00ol0003ocKS6olfhaP09olfhaP03o`000?o7/<?oak3300Ooak33
00?o0000ol:/a?o2[<@01oo2[<@2o`0000Oo_ZO200?o0000okJQ`onfXL<03_nfXL<00ol0003oZIW6
ojVIaP02ojVIaP?o00002?nXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_oRhS;
00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP03o`0000OoIg_C00?o0000ofZ1f?l00000
2omZPMP00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo000_ooooo`03o`000?oo
oooooooo00Gooooo0ol0000>ogW8o`;o00001OnSdoP3o`0000koX][k0_l00004okgNl0;o00003_o2
h>h2o`0000_oaMg[0_l000000ooCg^7o0000om?Gf`0=om?Gf`03o`000?oBcMGod/gE00_od/gE00?o
0000omO>dOl000003ooB`l`00ol0003oc[[7oljja`05oljja`03o`000?o=^<KocKS600OocKS600?o
0000olN``oo7/<<02Oo7/<<00ol0003o`Zc4ol:/a005ol:/a003o`000?nnYl;o_ZO200So_ZO200?o
0000okJQ`onfXL<03OnfXL<00ol0003oZIW6o`000002o`0000coZ9S500?o0000oi^@b?nKT<P02onK
T<P00ol0003oRhS;oh^8b`0;oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=800_ma
P=83o`0000CoIg_C00Co0000ofZ1f?mZPMSo00002_mZPMP00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0000>ogW8o`03o`000?nS
doSo000000;o00004onRf_/2o`000003okgNl?l0003o`^3^00go`^3^0_l0000>olGMj`?o00003OoC
em/00ol0003od/gEom;=e@0<om;=e@;o00003ooB`l`00ol0003oc[[7oljja`07oljja`03o`000?o=
^<KocKS600GocKS600?o0000olN``oo7/<<02_o7/<<00ol0003o`Zc4ol:/a004ol:/a003o`000?nn
Yl;o_ZO200Wo_ZO200?o0000okJQ`onfXL<03OnfXL<2o`0000ooZ9S500?o0000oi^@b?nKT<P03?nK
T<P00ol0003oRhS;oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=801Oma
P=83o`0000;oIg_C00Co0000ofZ1f?mZPMSo00002_mZPMP00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo000aooooo`03o`000?oooooooooo00Sooooo0_l00007ogW8o`So00005_nR
f_/3o`0000go`^3^00?o0000olGMjoo5gN/03Oo5gN/01Ol0003oamKUolOFiOo7e^Go000000_odmOK
00?o0000om;=eOoBcMD03?oBcMD01?l0003oc/C@olk4d?l0000=om;3c003o`000?o>^/Ooc[[700So
c[[700?o0000olfha_o=^<H01?o=^<H00ol0003oak33olN```0<olN```03o`000?o2[<Co`Zc400;o
`Zc400?o0000okjW`_nnYl802onnYl800ol0003o]Z73okJQ``0;okJQ``03o`000?ncWlCo000000oo
Z9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;oh^8b`0;oh^8b`03o`000?mkP/koNh;>00_o
Nh;>00?o0000og60d_maP=802?maP=83o`0000?oJX7H00?o0000ofZ1f?mZPMP02?mZPMP00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000booooo`;o00002_ooool7o`0000SoI/Om
0_l0000Aoj;Jn`?o00000onSg?/2o`0000Wo`^3^0_l0000>olGMj`;o00001Oo7e^D2o`0000SodmOK
00?o0000om;=eOoBcMD03?oBcMD00ol0003oc/C@olk4d002olk4d003o`000?oB`lcod/?<00Wod/?<
00?o0000oljjaoo>^/L02_o>^/L00ol0003ocKS6olfhaP02olfhaP03o`000?o7/<?oak3300goak33
00Go0000ol:/a?o2[<Co`Zc4o`00000>okjW`P03o`000?nfXL?o]Z7300Wo]Z730_l00003ok>Oa003
o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;oh^8b`0:oh^8b`03
o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=84o`0000[oJX7H00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`08ooooo`00=?ooool00ol0003oooooooooo`09ooooo`?o0000
3?mVaod3o`0000_oX][k0ol00008oj?Ln`?o00001?o2h>h2o`0000ooaMg[00?o0000olOFiOo7e^D0
1oo7e^D00ol0003odmOKom?Gf`04om?Gf`03o`000?oBcMGod/gE00cod/gE00?o0000olk4d?o>a=00
1?o>a=000ol0003od/?<om;3c007om;3c003o`000?o>^/Ooc[[700_oc[[700Go0000olfha_o=^<Ko
cKS6o`00000AolN```03o`000?o2[<Co000000oo_ZO200?o0000okJQ`onfXL<01onfXL<2o`0000Go
/io400?o0000ojRHaOnXV<D03OnXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_o
RhS;00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0:og60dP03o`000?mcQmSoLhOH00?o
00002OmZPMP00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000eooooo`03o`00
0?oooooooooo00_ooooo0ol0000<ofK7o@;o00001_nRf_/3o`0000koXmck0_l000000oo2h>ko0000
olGMj`0?olGMj`03o`000?o7e^GoamKU00WoamKU0_l00003om?Gf`03o`000?oBcMGod/gE00cod/gE
00?o0000olk4d?o>a=001_o>a=000ol0003od/?<om;3c005om;3c003o`000?o>^/Ooc[[700goc[[7
00?o0000olfha_l000004_o7/<<2o`00017o_ZO200?o0000okJQ`onfXL<01OnfXL<00ol0003o/io4
ok>Oa006ok>Oa003o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P03?nKT<P00ol0003oRhS;
oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=801?l0003oLhOH
og>7f?mcQmP5o`0000GoJX7H00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`00
=_ooool00ol0003oooooooooo`0=ooooo`?o00002omVaod2o`000004oj;Jnol0003o0000o`0001;o
Xmck0ol0000>olGMj`;o00003_o7e^D00ol0003odmOKo`00000>om;=e@03o`000?o>a=3oc/C@00So
c/C@00?o0000om;3c?oB`l`00ooB`l`00ol0003oc[[7oljja`0?oljja`03o`000?o7/<?oak33013o
ak3300?o0000ol>/`_l000004OnnYl800ol0003o]Z73okJQ``03okJQ``;o00002OncWl@00ol0003o
Z9S5ojRHa@0=ojRHa@03o`000?nKT<SoVi3800coVi3800?o0000oh^8bon;R</02on;R</00ol0003o
Nh;>og^2cP0;og^2cP03o`000?maP=;oLH3B00[oLH3B00?o0000og>7f?mcQmP00_mcQmP01?l0003o
LhOHog>7f?mcQmP3o`0000?oJX7H00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooo
o`00=oooool00ol0003oooooooooo`0?ooooo`oo00004OnSg?/3o`0000?oY]Wj0_l0000;olGMj`03
o`000?o7e^GoamKU00koamKU0ol0000<om;=e@;o00003?o>a=001Ol0003od/?<om;3c?oB`lco0000
017oc[[70_l0000AolN```05o`000?o3[<;o`jc2ol>/`_l000004OnnYl800ol0003o]Z73okJQ``02
o`0000_o/io400?o0000ojRHaOnXV<D03_nXV<D00ol0003oVi38oi^@b00;oi^@b003o`000?n;R<_o
RhS;00_oRhS;00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0;og60dP05o`000?mcQmSo
LhOHog>7f?l000001_mcQmP4o`0000gooooo00?o0000ooooooooool01oooool003Sooooo0_l0000A
ooooo`?o00002_mF`OX3o`0000_oXmck0ol00008ojKInP;o00001oo5gN/2o`00013oamKU00Go0000
olK=goo6cMooa/gOo`00000:om;=e@03o`000?o>a=3oc/C@00goc/C@00?o0000om;3c?l000004Oo>
^/L01?l0003obKC5olVdaOl0000?olN```03o`000?o3[<;o`jc200;o`jc200?o0000okjW`_nnYl80
3onnYl800ol0003o]Z73o`00000>ok>Oa003o`000?nXV<GoZ9S500goZ9S500?o0000oi^@b?nKT<P0
3?nKT<P00ol0003oRhS;oh^8b`0:oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=80
2_maP=800ol0003oLhOHog>7f002og>7f003o`000?mcQmSoLhOH00KoLhOH0_l0000<ooooo`03o`00
0?oooooooooo00Oooooo000jooooo`03o`000?oooooooooo017ooooo0_l0000;oeK1nP;o00001onS
g?/2o`0000goY]Wj0_l00004olGMj`03o`000?o7e^GoamKU00koamKU0_l00005olK=g`03o`000?oB
cMGod/gE00Kod/gE00?o0000olk4d?o>a=003_o>a=02o`00017oc[[700Go0000olVdaOo9]<GobKC5
o`00000>olN```03o`000?o3[<;o`jc200Co`jc200?o0000okjW`_nnYl803_nnYl82o`0000oo/io4
00?o0000ojRHaOnXV<D03OnXV<D00ol0003oVi38oi^@b00<oi^@b003o`000?n;R<_oRhS;00_oRhS;
00?o0000og^2c_mkP/h02omkP/h00ol0003oLH3Bog60dP0;og60dP03o`000?mcQmSoLhOH00;oLhOH
00?o0000og>7f?mcQmP01_mcQmP00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo
000kooooo`03o`000?oooooooooo01;ooooo0ol0000:oeK1nP?o000000CoXmcko`000?l0003o0000
4OnVfOX2o`000003olGMjol0003oamKU00ooamKU00?o0000olK=goo6cMl01_o6cMl2o`0000God/gE
00?o0000olk4d?o>a=003_o>a=000ol0003ob[c<o`00000@oljja`03o`000?o9]<GobKC500?obKC5
00?o0000olN``oo7/<<02_o7/<<00ol0003o`jc2ol>/`P05ol>/`P03o`000?nnYl;o_ZO200go_ZO2
00?o0000ok^U`ol000004?ncWl@00ol0003oZ9S5ojRHa@0=ojRHa@03o`000?nKT<SoVi3800WoVi38
2ol00005oh^8b`03o`000?mkP/koNh;>00coNh;>00?o0000og60d_maP=802_maP=800ol0003oLhOH
og>7f002og>7f003o`000?mcQmSoLhOH00OoLhOH00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`00??ooool00ol0003oooooooooo`0Dooooo`oo00005?nVfOX3o`0000koamKU0_l0
000;olK=g`05o`000?oBcMGod/gEom;=eOl000004?o>a=001Ol0003ob[c<olZlc?o:_<co000000ko
c[[700?o0000olVdaOo9]<D01Oo9]<D00ol0003oak33olN```08olN```03o`000?o3[<;o`jc200Oo
`jc200?o0000okjW`_nnYl802onnYl801Ol0003o^jG3ok^U`onkYL?o000000oo/io400?o0000ojRH
aOnXV<D03OnXV<D00ol0003oVi38oi^@b002oi^@b0Oo00000onLUL`00ol0003oSXk?ohj>c`05ohj>
c`_o00002OmkP/h00ol0003oLH3Bog60dP0;og60dP03o`000?mcQmSoLhOH00;oLhOH00?o0000og>7
f?mcQmP01_mcQmP00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000mooooo`;o
00005_ooool3o`0000[oD;_i0_l0000?ojKInP?o00000onYdoH2o`0000[oamKU0_l0000>olK=g`03
o`000?oBcMGo0000013oc/C@00?o0000olZlc?o:_<`00oo:_<`00ol0003oc[[7oljja`0:oljja`03
o`000?o9]<GobKC500KobKC500?o0000olN``oo7/<<01oo7/<<00ol0003o`jc2ol>/`P08ol>/`P03
o`000?nnYl;o_ZO200[o_ZO200?o0000ok^U`onkYL<00_nkYL<00ol0003o/io4ok>Oa00>ok>Oa003
o`000?nXV<GoZ9S500coZ9S51Ol0000;oibEc003o`000?n>S/ooSXk?00[oSXk?00?o0000oh29d_n0
RM800_n0RM87o`0000;oNh;>00?o0000og60d_maP=802omaP=800ol0003oLhOHog>7f003og>7f003
o`000?mcQmSoLhOH00KoLhOH00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`00
?oooool00ol0003oooooooooo`0Fooooo`;o00002_m@^oT2o`0000[oY]Wj0ol00008ojWCmP;o0000
1oo7e^D00ol0003oa/gOolK=g`0>olK=g`;o00004?o>a=000ol0003ob[c<olZlc005olZlc003o`00
0?o>^/Ooc[[700Soc[[700?o0000olVdaOo9]<D02?o9]<D00ol0003oak33olN```05olN```03o`00
0?o3[<;o`jc200[o`jc200?o0000okjW`_nnYl802?nnYl800ol0003o^jG3ok^U``04ok^U``03o`00
0?ncWlCo/io400go/io400?o0000ojRHaOnXV<D02OnXV<D3o`000003ojVLbOl0003oW9G<00goW9G<
00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP08oh29dPKo00002omaP=800ol0003oLhOH
og>7f003og>7f003o`000?mcQmSoLhOH00GoLhOH00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`00@?ooool00ol0003oooooooooo`0Gooooo`?o00002Om@^oT00ol0003oY]WjojKI
nP04ojKInP?o00003OnYdoH00ol0003oamKUolOFi@02olOFi@;o00004?o6cMl00ol0003oa<?Io`00
000?olk4d003o`000?o:_<cob[c<00Oob[c<00?o0000oljjaoo>^/L01_o>^/L00ol0003obKC5olVd
a@09olVda@03o`000?o7/<?oak3300Coak3300?o0000ol>/`_o3[<802oo3[<800ol0003o_ZO2okjW
`P06okjW`P;o00001onkYL<00ol0003o/io4ok>Oa00=ok>Oa003o`000?nXV<GoZ9S500KoZ9S50ol0
0005ojVLb@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29
dP0;oh29dP03o`000?mhR=OoN8SG00Co00001omaP=800ol0003oLhOHog>7f003og>7f003o`000?mc
QmSoLhOH00KoLhOH00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00@Oooool0
0ol0003oooooooooo`0Iooooo`Oo00000om@^oT2o`000004ojKIn_l0003o0000o`00017oZM?f0_l0
00000oo7e^Go0000olK=g`0@olK=g`05o`000?o4`mWoa<?IolC3fOl000003Oo>a=000ol0003ob[c<
olZlc008olZlc003o`000?o>^/Ooc[[700Goc[[700?o0000olVdaOo9]<D02oo9]<D00ol0003oak33
olN```02olN```03o`000?o3[<;o`jc200co`jc200?o0000okjW`_nnYl801OnnYl800ol0003o^jG3
ok^U``07ok^U``03o`000?ncWlCo/io400ko/io400?o0000ojRHaOnXV<D00_nXV<D3o`0000SoZIc9
00?o0000oibEc?nLUL`03?nLUL`00ol0003oSXk?ohj>c`0;ohj>c`03o`000?n0RM;oP8WB00_oP8WB
00?o0000ogR8eomhR=L00omhR=L4o`0000CoLH3B00?o0000og>7f?mcQmP00omcQmP00ol0003oLhOH
og>7f005og>7f003o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool004;ooooo0_l0
000Kooooo`;o00000omE]_/7o`0001CoZM?f0ol0000?olK=g`;o00001Oo4`mT00ol0003oc/C@olk4
d009olk4d003o`000?o:_<cob[c<00[ob[c<00?o0000oljjaoo>^/L00oo>^/L00ol0003obKC5olVd
a@0=olVda@04o`000?o7/<?oak33o`00013o`jc200?o0000okjW`_nnYl800onnYl800ol0003o^jG3
ok^U``09ok^U``03o`000?ncWlCo/io400go/io400?o0000ojRHaOl000000_l0000<ojVLb@03o`00
0?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`00
0?mhR=OoN8SG00OoN8SG1Ol00006og>7f003o`000?mcQmSoLhOH00GoLhOH00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`00A?ooool00ol0003oooooooooo`0Jooooo`;o00002?mE
]_/2o`0000ooZM?f0ol00003oj_9k`03o`000?o6cMooa/gO00_oa/gO00?o0000olC3fOo4`mT01_o4
`mT00ol0003oc/C@olk4d007olk4d003o`000?o:_<cob[c<00cob[c<00Go0000oljjaoo>^/Ooc[[7
o`00000@olVda@03o`000?o7/<?o0000017o`jc200?o0000okjW`_nnYl800_nnYl800ol0003o^jG3
ok^U``0:ok^U``03o`000?ncWlCo/io400go/io40_l0000?ojVLb@03o`000?nLULcoW9G<00coW9G<
00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mhR=OoN8SG00[oN8SG
1Ol00003og>7f003o`000?mcQmSoLhOH00CoLhOH00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`00AOooool00ol0003oooooooooo`0Kooooo`03o`000?mE]__oEKKk00OoEKKk0_l0
000:ojWCmP?o00001on[bNl00ol0003oa/gOolK=g`09olK=g`03o`000?o4`mWoa<?I00Soa<?I00?o
0000olk4d?o>a=001Oo>a=000ol0003ob[c<olZlc00>olZlc003o`000?o>^/Oo000001;obKC500?o
0000ol>/`_o3[<804Oo3[<801?l0003o_ZO2okjW`_l0000>ok^U``03o`000?ncWlCo/io400_o/io4
00?o0000ok>Saol000004?nYW<T00ol0003oW9G<oibEc00;oibEc003o`000?n>S/ooSXk?00_oSXk?
00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;ogR8e`04o`000?mjSmcoNXoLogZ?g0Go
00001_mcQmP00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0016ooooo`03o`00
0?oooooooooo01_ooooo0_l00009oeFfn`;o00001_nYdoH2o`0000_oZlW_0_l00008olK=g`03o`00
0?o4`mWoa<?I00[oa<?I00?o0000olk4d?o>a=000oo>a=000ol0003ob[c<olZlc00?olZlc0;o0000
4_o9]<D2o`0001?o`jc200?o0000okjW`_l000003onkYL<00ol0003o/io4ok>Oa009ok>Oa0;o0000
0oncXlL00ol0003oZIc9ojVLb@0=ojVLb@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l0
3?n>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mhR=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`0
1?mjSm`6o`000003og>7f?l0003ooooo00Oooooo00?o0000ooooooooool01_ooool004Oooooo0_l0
000Mooooo`So00000omE]_/2o`000004ojWCm_l0003o0000o`0000ooZlW_00?o0000olK=goo6cMl0
0oo6cMl2o`0000koa<?I00Go0000olk4d?o>a=3oc/C@o`00000AolZlc003o`000?o6]/[o0000017o
bKC500Co0000olF_aOo5[lGo00004_o3[<82o`00017o^jG300?o0000ok>Oa?ncWl@01_ncWl@2o`00
00Go/j?700?o0000ojVLbOnYW<T03_nYW<T00ol0003oW9G<oibEc00;oibEc003o`000?n>S/ooSXk?
00_oSXk?00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;ogR8e`03o`000?mjSmcoNXoL
00GoNXoL00?o0000ogZ?g?mjSm`00_mjSm`3o`0000Sooooo00?o0000ooooooooool01Oooool004Wo
oooo00?o0000ooooooooool07?ooool00ol0003oHJojof6_nP03of6_nPOo00004_n[bNl01Ol0003o
a/gOolK=goo6cMoo0000017oa<?I00?o0000olk4d?l000004Oo:_<`01Ol0003oa[K:olJfb_o6]/[o
000000oobKC500Go0000olF_aOo5[lGoaJo5o`00000Aol>/`P03o`000?o1Z/Co0000017o^jG300?o
0000ok>Oa?ncWl@01OncWl@00ol0003o/j?7ok>Sa`06ok>Sa`03o`000?nYW<WoZIc900goZIc900?o
0000oibEc?nLUL`02onLUL`00ol0003oSXk?ohj>c`0<ohj>c`03o`000?n0RM;oP8WB00_oP8WB00?o
0000ogR8eomhR=L02omhR=L00ol0003oNXoLogZ?g004ogZ?g003o`000?mjSmcoNXoL00CoNXoL00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`00B_ooool00ol0003oooooooooo`0L
ooooo`03o`000?mQ[o[oHJoj00WoHJoj00?o0000oj_9kon[bNl04?n[bNl00ol0003oa/gOo`00000B
olC3f@;o00004Oo:_<`00ol0003oa[K:olJfbP02olJfbP03o`000?o9]<GobKC500cobKC500?o0000
olF_aOo5[lD00oo5[lD00ol0003o`jc2ol>/`P0=ol>/`P05o`000?o1Z/Co`J[4ol6Za?l000004?nk
YL<00ol0003o/io4ok>Oa003ok>Oa0;o00002OncXlL00ol0003oZIc9ojVLb@0=ojVLb@03o`000?nL
ULcoW9G<00coW9G<00?o0000ohj>con>S/l02on>S/l00ol0003oP8WBoh29dP0;oh29dP03o`000?mh
R=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`01OmjSm`00ol0003oNXoLogZ?g004ogZ?g003o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool004_ooooo00?o0000ooooooooool07?ooool2
o`0000[oHJoj00?o0000oj_9kon[bNl03on[bNl2o`0001;oa<?I00?o0000ol6keOl000004?o:_<`0
0ol0003oa[K:olJfbP04olJfbP03o`000?o9]<GobKC500[obKC500?o0000olF_aOo5[lD01Oo5[lD0
0ol0003o`jc2ol>/`P0;ol>/`P03o`000?o1Z/Co`J[400;o`J[400?o0000ok^U`onkYL<03onkYL<0
0ol0003o/io4ok>Oa002o`0000co/j?700?o0000ojVLbOnYW<T03OnYW<T00ol0003oW9G<oibEc00;
oibEc003o`000?n>S/ooSXk?00coSXk?00?o0000oh29d_n0RM802on0RM800ol0003oN8SGogR8e`0;
ogR8e`03o`000?mjSmcoNXoL00GoNXoL00?o0000ogZ?g?mjSm`00omjSm`00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo001<ooooo`;o00007_ooool00ol0003oHJojof6_nP08of6_
nP03o`000?n[bNooZlW_00_oZlW_0ol00002oj^oj003o`000?o4`mWoa<?I00goa<?I0_l00003ol6k
e@03o`000?o:_<cob[c<00cob[c<00?o0000olJfb_o6]/X01_o6]/X00ol0003obKC5olVda@08olVd
a@03o`000?o5[lGoaJo500KoaJo500?o0000ol>/`_o3[<802_o3[<800ol0003o`J[4ol6Za004ol6Z
a003o`000?nkYL?o^jG300ko^jG300?o0000ok>Oa?l000003_ncXlL00ol0003oZIc9ojVLb@0=ojVL
b@03o`000?nLULcoW9G<00_oW9G<00?o0000ohj>con>S/l03?n>S/l00ol0003oP8WBoh29dP0;oh29
dP03o`000?mhR=OoN8SG00_oN8SG00?o0000ogZ?g?mjSm`01_mjSm`00ol0003oNXoLogZ?g003ogZ?
g003o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool004kooooo00?o0000oooooooo
ool07?ooool00ol0003oHJojof6_nP08of6_nP03o`000?n[bNooZlW_00OoZlW_0ol00006oj^oj003
o`000?o4`mWoa<?I00_oa<?I00?o0000ol6keOo1^mD01?o1^mD00ol0003ob[c<olZlc009olZlc0;o
00002Oo6]/X00ol0003obKC5olVda@07olVda@03o`000?o5[lGoaJo500SoaJo500?o0000ol>/`_o3
[<802?o3[<800ol0003o`J[4ol6Za005ol6Za003o`000?nkYL?o^jG300ko^jG30_l0000@ok>Sa`03
o`000?nYW<WoZIc900goZIc900?o0000oibEc?nLUL`02?nLUL`Go`0000WoP8WB00?o0000ogR8eomh
R=L02_mhR=L00ol0003oNXoLogZ?g006ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`00Coooool00ol0003oooooooooo`0Looooo`03o`00
0?mQ[o[oHJoj00SoHJoj00?o0000oj_9kon[bNl00on[bNl3o`0000[oZkoX00?o0000olC3fOo4`mT0
2?o4`mT2o`0000So`K_E00?o0000olZlc?o:_<`01oo:_<`00ol0003oa[K:olJfbP0:olJfbP03o`00
0?o9]<GobKC500GobKC500?o0000olF_aOo5[lD02Oo5[lD00ol0003o`jc2ol>/`P07ol>/`P03o`00
0?o1Z/Co`J[400Oo`J[400?o0000ok^U`onkYL<03?nkYL<00ol0003o^jS7o`00000@ok>Sa`03o`00
0?nYW<WoZIc900goZIc900Co0000oibEc?nLULcoW9G<1ol00003oifSf@03o`000?n>W=coSYcL00co
SYcL00?o0000oh2Fgon0U]l00_n0U]l7o`0000;oP8WB00?o0000ogR8eomhR=L02omhR=L00ol0003o
NXoLogZ?g006ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`00D?ooool00ol0003oooooooooo`0Looooo`Oo00001?mQ[oX00ol0003oZlW_
o`000002o`0000koZkoX00?o0000olC3fOo4`mT01_o4`mT00ol0003o`K_Eol6ke@09ol6ke@03o`00
0?o:_<cob[c<00Gob[c<00?o0000olJfb_o6]/X02oo6]/X00ol0003obKC5olVda@04olVda@03o`00
0?o5[lGoaJo500_oaJo500?o0000ol>/`_o3[<801Oo3[<800ol0003o`J[4ol6Za008ol6Za003o`00
0?nkYL?o^jG300[o^jG30_l00003ok^Xa`03o`000?ncXlOo/j?700go/j?700?o0000ojVLbOnYW<T0
3OnYW<T4o`0000_oWJ?I00?o0000ohjLg?n>W=`03?n>W=`00ol0003oP9KOoh2Fg`08oh2Fg`Oo0000
2OmhR=L00ol0003oNXoLogZ?g007ogZ?g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`00DOooool00ol0003oooooooooo`0Looooo`03o`000?m]
Z?CoKJSd00?oKJSd1ol0000Aoj^oj003o`000?o4`mWoa<?I00Coa<?I00?o0000ol6keOo1^mD02oo1
^mD00ol0003ob[c<olZlc003olZlc003o`000?o6]/[oa[K:00goa[K:00?o0000olVdaOo9]<D00_o9
]<D00ol0003oaJo5olF_a@0<olF_a@03o`000?o3[<;o`jc200Co`jc200?o0000ol6Za?o1Z/@02_o1
Z/@00ol0003o^jG3ok^U``08ok^U``03o`000?nkZ<Oo^jS700?o^jS700?o0000ok>SaoncXlL03_nc
XlL00ol0003oZIc9ojVLb@09ojVLb@?o000000?oZjWEo`000?nMXmT03OnMXmT00ol0003oSYcLohjL
g00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00Co0000ogVEh_miUN;oNIGR1Ol00005ogR8e`03o`00
0?mjSmcoNXoL00OoNXoL00?o0000ogZ?g?mjSm`00_mjSm`00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo001Booooo`;o00007Oooool00ol0003oKJSdoffXm009offXm003o`000?n[
_nSoZkoX00ooZkoX00Co0000olC3fOo4`mWoa<?I0_l0000?ol6ke@05o`000?o:_<cob[c<olZlc?l0
00004Oo6]/X01?l0003obKC5olVdaOl0000@olF_a@03o`000?o3[<;o`jc200;o`jc200?o0000ol6Z
a?o1Z/@02oo1Z/@00ol0003o^jG3ok^U``06ok^U``;o00001onkZ<L00ol0003o/j?7ok>Sa`0=ok>S
a`03o`000?nYW<WoZIc900KoZIc90ol00005oj^Ye@03o`000?nMXmWoWJ?I00_oWJ?I00?o0000ohjL
g?n>W=`03?n>W=`00ol0003oP9KOoh2Fg`0;oh2Fg`03o`000?miUN;oNIGR00GoNIGR1_l00009ogZ?
g003o`000?mjSmcoNXoL00?oNXoL00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`00E?ooool00ol0003oooooooooo`0Kooooo`03o`000?m]Z?CoKJSd00WoKJSd00?o0000oj^oj?n[
_nP03on[_nP00ol0003oa<?Io`00000Bol6ke@03o`000?o:_<co000001;oa[K:00?o0000olVdaOl0
00004_o5[lD01?l0003o`jc2ol>/`_l0000?ol6Za003o`000?nkYL?o^jG300Co^jG300?o0000ok^X
aonkZ<L01onkZ<L00ol0003o/j?7ok>Sa`0>ok>Sa`03o`000?nYW<WoZIc900;oZIc90ol00008oj^Y
e@03o`000?nMXmWoWJ?I00coWJ?I00?o0000ohjLg?n>W=`02on>W=`00ol0003oP9KOoh2Fg`0;oh2F
g`03o`000?miUN;oNIGR00[oNIGR2_l000000omjSmco0000ogZ?g003ogZ?g003o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool005Gooooo00?o0000ooooooooool06oooool00ol0003o
KJSdoffXm009offXm003o`000?n[_nSoZkoX00koZkoX0_l0000Col6ke@;o00004oo6]/X2o`0001?o
aJo500?o0000ol>/`_l000004?o1Z/@00ol0003o^jG3ok^U``03ok^U``03o`000?nkZ<Oo^jS700Wo
^jS700?o0000ok>SaoncXlL03OncXlL00ol0003oZIc9o`000002o`0000coZjWE00?o0000oifSfOnM
XmT03?nMXmT00ol0003oSYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_mi
UN802_miUN800ol0003oO9_VogbKiP06ogbKiPSo00000oooool00ol0003oooooooooo`04ooooo`00
E_ooool00ol0003oooooooooo`0Kooooo`03o`000?m]Z?CoKJSd00WoKJSd00?o0000oj^oj?n[_nP0
2_n[_nP3o`000003oj^fhOl0003o`K_E017o`K_E00?o0000okjed_l000004_o6]/X00ol0003o`k;9
o`00000ColF_a@;o00004_o1Z/@00ol0003o^jG3ok^U``02o`0000co^jS700?o0000ok>SaoncXlL0
3OncXlL2o`0000ooZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00<ohjLg003o`00
0?n0U]ooP9KO00[oP9KO00?o0000ogVEh_miUN802omiUN800ol0003oO9_VogbKiP07ogbKiP03o`00
0?mlVnKoO9_V00;oO9_V00Go0000ooooooooooooooooo`000006ooooo`00Eoooool2o`0001cooooo
00?o0000offXm?m]Z?@02Om]Z?@00ol0003oZkoXoj^oj006oj^oj0?o00001On[]^400ol0003o`K_E
ol6ke@0=ol6ke@;o00000onn]M800ol0003oa[K:olJfbP0>olJfbP05o`000?o3//Wo`k;9ol>bbOl0
00004Oo5[lD00ol0003o`Zk6o`00000Bol6Za003o`000?nkYL?o000000oo^jS700?o0000ok>Saonc
XlL02_ncXlL2o`000003okJ_d_l0003oZjWE00ooZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003o
SYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_miUN802omiUN800ol0003o
O9_VogbKiP07ogbKiP03o`000?mlVnKoO9_V00;oO9_V00Co0000oooooooooooo00001_ooool005Wo
oooo00?o0000ooooooooool06_ooool00ol0003oKJSdoffXm009offXm003o`000?n[_nSoZkoX00?o
ZkoX0_l00009oj^fh@03o`000?o1^mGo`K_E00_o`K_E00?o0000okjed_nn]M801?nn]M800ol0003o
a[K:olJfbP0<olJfbP03o`000?o3//Wo`k;900;o`k;900?o0000olF_aOo5[lD03_o5[lD01Ol0003o
`Zk6ol:^a_o2[/Ko0000017o`J[40_l0000@ok^Xa`03o`000?ncXlOo/j?700So/j?70_l00004okJ_
dP03o`000?n[ZMGoZjWE00goZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00<ohjL
g003o`000?n0U]ooP9KO00_oP9KO00?o0000ogVEh_miUN802_miUN800ol0003oO9_VogbKiP08ogbK
iP03o`000?mlVnKoO9_V00;oO9_V00?o0000ooooool000001_ooool005[ooooo00?o0000oooooooo
ool06_ooool8o`0000CoKJSd00?o0000oj^oj?l000000_l0000<oj^fh@03o`000?o1^mGo`K_E00So
`K_E0_l00008okjedP03o`000?o6]/[oa[K:00[oa[K:00?o0000ol>bbOo3//T01?o3//T00ol0003o
aJo5olF_a@0<olF_a@03o`000?o2[/Ko`Zk600;o`Zk600?o0000ol6Za?o1Z/@03_o1Z/@00ol0003o
_jg8o`00000Aok^Xa`03o`000?ncXlOo/j?700Go/j?70_l00006okJ_dP03o`000?n[ZMGoZjWE00ko
ZjWE00?o0000oifSfOnMXmT03?nMXmT00ol0003oSYcLohjLg00;ohjLg003o`000?n0U]ooP9KO00_o
P9KO00?o0000ogVEh_miUN802omiUN800ol0003oO9_VogbKiP08ogbKiP05o`000?mlVnKoO9_VogbK
i_l000000_ooool00ol0003oooooooooo`03ooooo`00Foooool00ol0003oooooooooo`0Jooooo`03
o`000?mgXNcoMj7/00CoMj7/1_l0000@oj^fh@03o`000?o1^mGo`K_E00Ko`K_E00?o0000okjed_nn
]M802?nn]M800ol0003oa[K:olJfbP08olJfbP;o00002?o3//T00ol0003oaJo5olF_a@09olF_a@;o
00001_o2[/H00ol0003o`J[4ol6Za00<ol6Za005o`000?no[LSo_jg8okn]b?l000004?nkZ<L00ol0
003o/j?7ok>Sa`04ok>Sa`03o`000?nf[m;o]ZoB00Oo]ZoB00?o0000oj^YeOn[ZMD03On[ZMD00ol0
003oWJ?IoifSf@0;oifSfAGo00002On0U]l00ol0003oNIGRogVEhP0:ogVEhP03o`000?mlVnKoO9_V
00SoO9_V00?o0000ogbKi_mlVnH00_mlVnH00ol0003oooooo`000005ooooo`00G?ooool2o`0001_o
oooo00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0?oj^fh@03o`000?o1^mGo`K_E00Co
`K_E00?o0000okjed_nn]M802_nn]M800ol0003oa[K:olJfbP06olJfbP03o`000?o3//Wo`k;900So
`k;900?o0000olF_aOo5[lD02?o5[lD00ol0003o`Zk6ol:^aP06ol:^aP03o`000?o1Z/Co`J[400_o
`J[400?o0000okn]b?no[LP00_no[LP00ol0003o^jS7ok^Xa`0?ok^Xa`04o`000?ncXlOo/j?7ok>S
a`;o00002_nf[m800ol0003oZjWEoj^Ye@0>oj^Ye@03o`000?nMXmWoWJ?I00GoWJ?I1Ol0000Eoooo
o`Oo00000_n0U]l00ol0003oNIGRogVEhP0;ogVEhP03o`000?mlVnKoO9_V00SoO9_V00Oo0000ogbK
i_mlVnKoO9_Vo`000?oooooo000000Gooooo001Nooooo`03o`000?oooooooooo01Wooooo00?o0000
ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0?oj^fh@04o`000?o1^mGo`K_Eol6ke@;o00003_nn
]M800ol0003oa[K:olJfbP04olJfbP03o`000?o3//Wo`k;900[o`k;900?o0000olF_aOo5[lD01_o5
[lD00ol0003o`Zk6ol:^aP08ol:^aP03o`000?o1Z/Co`J[400Wo`J[400?o0000okn]b?no[LP01?no
[LP00ol0003o^jS7ok^Xa`0>ok^Xa`04o`000?ncXlOo0000o`0000go]ZoB00?o0000oj^YeOn[ZMD0
3On[ZMD00ol0003oWJ?IoifSf@05o`00027ooooo2?l00009ogVEhP03o`000?mlVnKoO9_V00SoO9_V
00Co0000ogbKi_mlVnKoO9_V0_l00005ooooo`00Goooool00ol0003oooooooooo`0Iooooo`03o`00
0?mgXNcoMj7/00SoMj7/00?o0000oj^fhOn[]^403on[]^400ol0003o`K_Eo`00000@okjedP03o`00
0?o6]/[oa[K:00?oa[K:00?o0000ol>bbOo3//T02oo3//T00ol0003oaJo5olF_a@04olF_a@;o0000
3?o2[/H00ol0003o`J[4ol6Za006ol6Za0;o00001ono[LP00ol0003o^jS7ok^Xa`0>ok^Xa`;o0000
4?nf[m800ol0003oZjWEoj^Ye@0;oj^Ye@Co0000;_ooool7o`0000;oNIGR00?o0000ogbKi_mlVnH0
2OmlVnH01Ol0003oO9_VogbKi_mlVnKo000000Gooooo001Pooooo`03o`000?oooooooooo01Wooooo
00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQoj^fh@0>oj^fh@;o00004_nn]M801Ol0003oa[K:
olJfb_o6]/[o000000oo`k;900?o0000olF_aOo5[lD00_o5[lD00ol0003o`Zk6ol:^aP0<ol:^aP03
o`000?o1Z/Co`J[400Go`J[400?o0000okn]b?no[LP02?no[LP00ol0003o^jS7ok^Xa`0<ok^Xa`03
o`000?nm]=7o0000013o]ZoB00?o0000oj^YeOn[ZMD02?n[ZMD3o`0003Wooooo3?l00002ogbKiP05
o`000?mlVnKoO9_VogbKi_l000001Oooool0067ooooo0_l0000Jooooo`03o`000?mgXNcoMj7/00So
Mj7/00?o0000oj^fhOn[]^402_n[]^43o`000003ojZ`g?l0003o_[GB01;o_[GB00?o0000olJfb_l0
00004Oo3//T01?l0003oaJo5olF_aOl0000@ol:^aP03o`000?o1Z/Co`J[400?o`J[400?o0000okn]
b?no[LP02_no[LP00ol0003o^jS7ok^Xa`09ok^Xa`;o00000onm]=400ol0003o]ZoBokJ_dP0>okJ_
dP03o`000?n[ZMGoZjWE00?oZjWE1?l00018ooooo`So00001?ooool006?ooooo00?o0000oooooooo
ool06?ooool00ol0003oMj7/ogNQk008ogNQk003o`000?n[]^7oZkKQ00KoZkKQ0ol00005ojZ`g003
o`000?nn]M;o_[GB013o_[GB0_l0000Bol>bb@03o`000?o5[lGo0000017o`Zk600?o0000ol6Za?o1
Z/@00_o1Z/@00ol0003o_jg8okn]b00;okn]b003o`000?nkZ<Oo^jS700Oo^jS70_l00005okfdd@03
o`000?nf[m;o]ZoB00ko]ZoB00?o0000oj^YeOn[ZMD00ol0001@ooooo`03o`000?oooooo000000Go
oooo001Tooooo`03o`000?oooooooooo01Sooooo00?o0000ogNQk?mgXN`02?mgXN`00ol0003oZkKQ
oj^fh@03oj^fh@;o00002OnZ/=`00ol0003o_[GBokjedP0>okjedP03o`000?nk/]7o000001;o`k;9
0_l0000Col:^aP04o`000?o1Z/Co`J[4o`0000oo_jg800?o0000ok^XaonkZ<L01OnkZ<L00ol0003o
_KCAokfdd@06okfdd@03o`000?nf[m;o]ZoB00go]ZoB0ol0001Cooooo`04o`000?ooooooooooo`00
00Cooooo001Uooooo`03o`000?oooooooooo01Sooooo1ol00004ogNQk003o`000?n[]^7o000000;o
00003?nZ/=`00ol0003o_[GBokjedP0;okjedP;o00000onk/]400ol0003o`k;9ol>bb@0>ol>bb@03
o`000?o0/L_o000001?o`Zk600?o0000ol6Za?l000004?no[LP00ol0003o^jS7ok^Xa`03ok^Xa`;o
00002Onm]=400ol0003o]ZoBokJ_dP0;okJ_dP;o0000Eoooool00ol0003oooooo`000004ooooo`00
I_ooool2o`0001Sooooo00?o0000ognMiOmoWND01?moWND6o`00013oZ[3L00?o0000okjed_nn]M80
2?nn]M82o`0000Ko^k;A00?o0000ol>bbOo3//T03?o3//T01Ol0003o`;7;ol2aboo0/L_o000001;o
`Zk60_l0000Bokn]b003o`000?nkZ<Oo^jS700;o00003?nm]=400ol0003o]ZoBokJ_dP08okJ_dP;o
0000F_ooool2o`0000Cooooo001Xooooo`03o`000?oooooooooo01Kooooo00?o0000ognMiOmoWND0
2?moWND00ol0003oZ[3LojZ`g00>ojZ`g003o`000?nn]M;o_[GB00Oo_[GB00?o0000ok^bdOnk/]40
1_nk/]400ol0003o`k;9ol>bb@0:ol>bb@;o00001Oo0/L/00ol0003o`Zk6ol:^aP0>ol:^aP03o`00
0?o1/L_o000001;o_jg800?o0000ok^Xaol000003onm]=400ol0003o]ZoBokJ_dP05okJ_dP;o0000
Foooool3o`0000Cooooo001Yooooo`03o`000?oooooooooo01Kooooo00?o0000ognMiOmoWND02?mo
WND00ol0003oZ[3LojZ`g00>ojZ`g003o`000?nn]M;o_[GB00Co_[GB0_l0000:ok^bd@03o`000?o3
//Wo`k;900So`k;900?o0000ol2aboo0/L/01Oo0/L/00ol0003o`Zk6ol:^aP0=ol:^aP05o`000?o1
/L_o`K7;ol6abol000004Ono[LP2o`00013o_KCA00?o0000okJ_d_nf[m801?nf[m800ol0003ooooo
ooooo`1Gooooo`Co00001oooool006[ooooo00?o0000ooooooooool05_ooool00ol0003oOigUognM
i@08ognMi@03o`000?nZ/=coZ[3L00koZ[3L00Co0000okjed_nn]M;o_[GB0_l0000=ok^bd@03o`00
0?o3//Wo`k;900Ko`k;900?o0000ol2aboo0/L/01oo0/L/00ol0003o`Zk6ol:^aP0:ol:^aP;o0000
1?o1/L/00ol0003o_jg8okn]b00>okn]b003o`000?o1]m3o0000017o_KCA00Co0000okJ_d_nf[m;o
]ZoB0_l0001Fooooo`Co00002oooool006_ooooo00?o0000ooooooooool05_ooool00ol0003oOigU
ognMi@08ognMi@03o`000?nZ/=coZ[3L00koZ[3L00?o0000okjed_l000003onk/]400ol0003o`k;9
ol>bb@05ol>bb@03o`000?o0/L_o`;7;00Wo`;7;00?o0000ol:^a_o2[/H02?o2[/H00ol0003o`K7;
ol6ab`05ol6ab`03o`000?no[LSo_jg800co_jg800Go0000ol6gd?o1]m3o`KO@o`00000@okfdd@04
o`000?nf[m;o0000o`0005Gooooo0ol0000?ooooo`00K?ooool2o`0001Kooooo00?o0000ognMiOmo
WND02OmoWND00ol0003oZ[3LojZ`g00=ojZ`g0;o00004Onk/]400ol0003o`k;9ol>bb@02ol>bb@;o
00003?o0/L/00ol0003o`Zk6ol:^aP07ol:^aP03o`000?o1/L_o`K7;00Oo`K7;00?o0000okn]b?no
[LP02Ono[LP2o`0000Co`KO@00?o0000okfddOnm]=403_nm]=42o`0005?ooooo1?l0000Booooo`00
K_ooool00ol0003oooooooooo`0Dooooo`03o`000?moWNGoOigU00SoOigU00?o0000ojZ`g?nZ/=`0
2_nZ/=`3o`000003ojV]f_l0003o^k;A013o^k;A00Go0000ol>bbOo3//Wo`k;9o`00000?ol2ab`03
o`000?o2[/Ko`Zk600Go`Zk600?o0000ol6aboo1/L/02?o1/L/00ol0003o_jg8okn]b008okn]b003
o`000?o1]m3o`KO@00Go`KO@00?o0000okfddOnm]=403?nm]=400ol0003oooooooooo`1?ooooo`Co
00005_ooool006oooooo00?o0000ooooooooool05?ooool00ol0003oOigUognMi@08ognMi@03o`00
0?nZ/=coZ[3L00KoZ[3L0ol00005ojV]fP03o`000?nk/]7o^k;A00oo^k;A00?o0000ol>bbOl00000
4Oo0/L/00ol0003o`Zk6ol:^aP02ol:^aP;o00003?o1/L/00ol0003o_jg8okn]b006okn]b003o`00
0?o1]m3o`KO@00Ko`KO@00?o0000okfddOnm]=402_nm]=42o`0004kooooo1?l0000Jooooo`00L?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?moWNGoOigU00SoOigU00?o0000ojZ`g?nZ/=`00onZ
/=`2o`0000WoZJgJ00?o0000ok^bdOnk/]403_nk/]42o`0001;o`;7;00Go0000ol:^a_o2[/Ko`Zk6
o`00000>ol6ab`03o`000?no[LSo_jg800Go_jg800?o0000ol6gd?o1]m002?o1]m000ol0003o_KCA
okfdd@07okfdd@;o0000C?ooool4o`0001kooooo001aooooo`;o00005Oooool7o`0000CoOigU00?o
0000ojZ`g?l000000_l0000;ojV]fP03o`000?nk/]7o^k;A00go^k;A00?o0000okVad_l000004oo0
/L/00ol0003o`Zk6o`00000@ol6ab`03o`000?no[LSo_jg800;o_jg80_l0000<ol6gd003o`000?nm
]=7o_KCA00Go_KCA00?o0000ooooooooool0BOooool3o`0002;ooooo001cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ohFLhOn5W>401?n5W>46o`0000ooZJgJ00?o0000ok^bdOnk/]402_nk/]42
o`0000?o^K7B00?o0000ol2aboo0/L/04?o0/L/2o`0001;o`K7;00Co0000okn]b?no[LSo00003_o1
]m000ol0003o_KCAokfdd@03okfdd@;o0000B?ooool4o`0002Gooooo001dooooo`03o`000?oooooo
oooo01;ooooo00?o0000ohFLhOn5W>402?n5W>400ol0003oZJgJojV]fP0>ojV]fP03o`000?nk/]7o
^k;A00Oo^k;A0_l00006okVadP03o`000?o0/L_o`;7;00ko`;7;00?o0000okndcol000004_o1/L/0
0ol0003o_jg8o`00000@ol6gd003o`000?nm]=7o_KCA00;o0000A_ooool4o`0002Wooooo001eoooo
o`03o`000?oooooooooo01;ooooo00?o0000ohFLhOn5W>402?n5W>400ol0003oZJgJojV]fP0=ojV]
fP03o`000?nk/]7o^k;A00Ko^k;A00?o0000okVad_ni/M801oni/M800ol0003o`;7;ol2ab`0;ol2a
b`;o00000ono]<l00ol0003o`K7;ol6ab`0?ol6ab`;o00004Oo1]m000ol0003o_KCAo`000014oooo
o`Co0000;Oooool007Kooooo0_l0000Booooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000ojV]f_nY
[MX03OnY[MX00ol0003o^k;Aok^bd@03ok^bd@;o00002_ni/M800ol0003o`;7;ol2ab`0:ol2ab`03
o`000?no]<oo_kC?00Co_kC?00?o0000ol6aboo1/L/03Oo1/L/00ol0003o`[[Co`00000Aol6gd0;o
0000@Oooool4o`00037ooooo001hooooo`03o`000?oooooooooo013ooooo00?o0000ohFLhOn5W>40
2On5W>400ol0003oZJgJojV]fP0<ojV]fP04o`000?nk/]7o^k;Aok^bd@;o00003Oni/M800ol0003o
`;7;ol2ab`07ol2ab`;o00001ono]<l00ol0003o`K7;ol6ab`0;ol6ab`;o00000oo2^]<00ol0003o
`KO@ol6gd00=ol6gd003o`000?oooooooooo03kooooo0ol0000eooooo`00NOooool00ol0003ooooo
ooooo`0@ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000ojV]f_nY[MX03?nY[MX00ol0003o^k;A
o`00000@okVadP03o`000?o0/L_o`;7;00Go`;7;00?o0000okndcono]<l02?no]<l00ol0003o`K7;
ol6ab`09ol6ab`03o`000?o2^]?o`[[C00Co`[[C00?o0000ol6gd?o1]m002_o1]m02o`0003gooooo
1?l0000hooooo`00N_ooool00ol0003oooooooooo`0?ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o
0000ojV]f_nY[MX03?nY[MX2o`00017o^K7B00?o0000ol2aboo0/L/01?o0/L/00ol0003o_kC?oknd
c`0:okndc`03o`000?o1/L_o`K7;00Ko`K7;0_l00007ol:jd`03o`000?o1]m3o`KO@00So`KO@0_l0
000kooooo`Co0000??ooool007_ooooo0_l0000@ooooo`03o`000?n5W>7oQIcQ00WoQIcQ00?o0000
ojV]f_nY[MX02?nY[MX3o`000003ojR]fol0003o^K7B017o^K7B00Co0000ol2aboo0/L_o`;7;0_l0
000=okndc`03o`000?o1/L_o`K7;00Go`K7;00?o0000ol:jdoo2^]<02?o2^]<00ol0003o`KO@ol6g
d006ol6gd003o`000?oooooooooo03Oooooo1?l00010ooooo`00OOooool00ol0003oooooooooo`0=
ooooo`03o`000?n5W>7oQIcQ00[oQIcQ00?o0000ojV]f_nY[MX01?nY[MX3o`0000GoZ:gK00?o0000
okVad_ni/M804?ni/M800ol0003o`;7;o`00000@okndc`03o`000?o1/L_o`K7;00?o`K7;00?o0000
ol:jdoo2^]<02_o2^]<00ol0003o`KO@ol6gd003ol6gd0;o0000=_ooool4o`0004Cooooo001noooo
o`03o`000?oooooooooo00gooooo00?o0000ohFLhOn5W>402_n5W>400ol0003oZJgJojV]fP03o`00
00WoZ:gK00?o0000okVad_ni/M803oni/M82o`00017o_kC?00Co0000ol6aboo1/L_o`K7;0_l0000=
ol:jd`04o`000?o1]m3o`KO@ol6gd0;o0000=Oooool3o`0004Sooooo001oooooo`03o`000?oooooo
oooo00gooooo3ol0000=ojR]f`03o`000?ni/M;o^K7B00co^K7B0_l000000onh]MKo0000okndc`0A
okndc`03o`000?o1/L_o0000013o`[[C00?o0000ol6gd?l00000<oooool4o`0004_ooooo0020oooo
o`03o`000?oooooooooo00cooooo00?o0000ohZNhOn:W^402_n:W^400ol0003oZ:gKojR]f`0=ojR]
f`03o`000?ni/M;o^K7B00Wo^K7B0_l00004okReeP03o`000?no]<oo_kC?00oo_kC?0_l0000Aol:j
d`;o0000<?ooool4o`0004oooooo0021ooooo`;o00003Oooool00ol0003oRYkQohZNh@0:ohZNh@03
o`000?nX[M_oZ:gK00coZ:gK00?o0000okVad_ni/M801oni/M82o`0000Oo^;GF00?o0000okndcono
]<l03Ono]<l00ol0003o_kcGo`00000@ol:jd`03o`000?oooooooooo02cooooo1?l0001Cooooo`00
Poooool00ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00[oRYkQ00?o0000ojR]fonX[M/0
3?nX[M/00ol0003o^K7BokVadP05okVadP03o`000?nh]MKo^;GF00Oo^;GF00?o0000okndcono]<l0
2ono]<l2o`0000?o_kcG00?o0000ol:jdoo2^]<02oo2^]<2o`0002_ooooo1?l0001Gooooo`00Q?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]fonX[M/03OnX
[M/00ol0003o^K7BokVadP02okVadP;o00002onh]MH00ol0003o_kC?okndc`08okndc`;o00001_no
_=L00ol0003o`[[Col:jd`09ol:jd`03o`000?oooooooooo02Sooooo0ol0001Kooooo`00QOooool0
0ol0003oooooooooo`0;ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]fonX[M/03OnX[M/0
1?l0003o^K7Bo`000?l0000>okReeP03o`000?no]<oo_kC?00Ko_kC?00?o0000oknleono_=L01_no
_=L00ol0003o`[[Col:jd`07ol:jd`;o00009oooool4o`0005kooooo0026ooooo`;o00002oooool0
0ol0003oRYkQohZNh@0:ohZNh@03o`000?nX[M_oZ:gK00_oZ:gK0ol0000AokReeP03o`000?no]<oo
_kC?00?o_kC?0_l0000:oknle`03o`000?o2^]?o`[[C00Go`[[C00?o0000ooooooooool08oooool4
o`0006;ooooo0028ooooo`03o`000?oooooooooo00Wooooo00?o0000ohZNhOn:W^402_n:W^400ol0
003oZ:gKojR]f`07ojR]f`?o00000_nX/Mh00ol0003o^;GFokReeP0?okReeP04o`000?no]<oo_kC?
okndc`;o00003Ono_=L00ol0003o`[[Col:jd`03ol:jd`03o`000?oooooooooo023ooooo1?l0001V
ooooo`00ROooool00ol0003oooooooooo`09ooooo`03o`000?n:W^7oRYkQ00WoRYkQ00?o0000ojR]
fonX[M/01?nX[M/3o`0000KoZ;7N00?o0000okRee_nh]MH03onh]MH00ol0003o_kC?o`00000?oknl
e`04o`000?o2^]?o`[[Col:jd`;o00007oooool4o`0006[ooooo002:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ohZNhOn:W^402On:W^400ol0003oZ:gKojR]f`03o`0000[oZ;7N00?o0000okRe
e_nh]MH03_nh]MH2o`00017o_kcG00?o0000ol:jdol000007_ooool3o`0006kooooo002;ooooo`;o
00002_ooool>o`0000koZ;7N00?o0000okRee_nh]MH02onh]MH2o`000003okNlg_l0003o_kcG013o
_kcG0_l0000Kooooo`Co0000LOooool008gooooo00?o0000ooooooooool01oooool00ol0003oSJCT
ohfTi009ohfTi003o`000?nX/MkoZ;7N00koZ;7N00?o0000okRee_nh]MH02?nh]MH2o`0000Co]kcN
00?o0000oknleono_=L03?no_=L2o`0001Wooooo1?l0001eooooo`00S_ooool00ol0003ooooooooo
o`07ooooo`03o`000?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh03OnX/Mh00ol0003o^;GFokRe
eP05okReeP?o00001ong_=h00ol0003o_kcGoknle`0:oknle`03o`000?oooooooooo01Gooooo1?l0
001iooooo`00Soooool00ol0003oooooooooo`07ooooo`03o`000?n=Y>CoSJCT00WoSJCT00?o0000
ojRag_nX/Mh03OnX/Mh00ol0003o^;GFokReeP02okReeP;o00002ong_=h00ol0003o_kcGoknle`07
oknle`;o00005?ooool4o`0007gooooo002@ooooo`;o00002?ooool00ol0003oSJCTohfTi009ohfT
i003o`000?nX/MkoZ;7N00goZ;7N00Co0000okRee_l0003o00003_ng_=h00ol0003o_kcGoknle`04
oknle`;o00004oooool3o`00087ooooo002Booooo`03o`000?oooooooooo00Kooooo00?o0000ohfT
i?n=Y>@02On=Y>@00ol0003oZ;7NojRagP0;ojRagP?o00004Ong_=h00ol0003o_kcGoknle`02oknl
e`03o`000?oooooooooo00oooooo1?l00024ooooo`00Toooool00ol0003oooooooooo`05ooooo`03
o`000?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh02?nX/Mh3o`0000;oYkWV00?o0000okNlg_ng
_=h04?ng_=h01?l0003o_kcGo`000?l0000>ooooo`Co0000R?ooool009Cooooo00?o0000oooooooo
ool01Oooool00ol0003oSJCTohfTi009ohfTi003o`000?nX/MkoZ;7N00CoZ;7N0ol00006ojNiiP03
o`000?ng_=ko]kcN00oo]kcN0_l0000<ooooo`Co0000S?ooool009Gooooo0_l00006ooooo`03o`00
0?n=Y>CoSJCT00WoSJCT00?o0000ojRag_nX/Mh00ol0000:ojNiiP03o`000?ng_=ko]kcN00co]kcN
0_l0000:ooooo`Co0000T?ooool009Oooooo00?o0000ooooooooool01?ooool>o`0000koYkWV00?o
0000okNlg_ng_=h02Ong_=h2o`0000Wooooo0ol0002Dooooo`00V?ooool00ol0003oooooooooo`03
ooooo`03o`000?n=[ngoSJo]00_oSJo]00?o0000ojNii_nW^NH03?nW^NH00ol0003o]kcNokNlgP05
okNlgP?o00001oooool4o`0009Oooooo002Iooooo`03o`000?oooooooooo00?ooooo00?o0000ohf_
kOn=[nd02on=[nd00ol0003oYkWVojNiiP0<ojNiiP03o`000?ng_=ko]kcN00;o]kcN0_l00006oooo
o`Co0000Voooool009[ooooo00?o0000ooooooooool00oooool00ol0003oSJo]ohf_k@0;ohf_k@03
o`000?nW^NKoYkWV00coYkWV00Co0000okNlg_l0003o00001?ooool4o`0009oooooo002Kooooo`;o
00001?ooool00ol0003oSJo]ohf_k@0;ohf_k@03o`000?nW^NKoYkWV00[oYkWV0ol00002ooooo`Co
0000Xoooool009gooooo00?o0000ooooooooool00_ooool00ol0003oSJo]ohf_k@0;ohf_k@03o`00
0?nW^NKoYkWV00GoYkWV1?l00002ooooo`?o0000Yoooool009kooooo00?o0000ooooooooool00_oo
ool00ol0003oSJo]ohf_k@0;ohf_k@03o`000?nW^NKoYkWV00Co00000_ooool4o`000:[ooooo002O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ohf_kOn=[nd01On=[nd8o`0000;ooooo1?l0002^
ooooo`00X?ooool2o`0000?ooooo1ol00006ooooo`Co0000/_ooool00:;ooooo00Co0000oooooooo
oooo00002?ooool4o`000;Kooooo002Sooooo`03o`000?oooooo000000Gooooo0ol0002jooooo`00
Y?ooool2o`000003ooooool0003o000000;o0000_Oooool00:Gooooo0_l00031ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00cOooool3
o`000003oa0@4?oooooooooo09Gooooo002booooo`03o`000?oooooooooo00Kooooo00?oMgMgofIV
I_ooool02Oooool00ol0003o^[Zjooooo`05ooooo`03oa0@4?nj^[[ooooo00?ooooo00?oIVIVogMg
Moooool0T?ooool00;;ooooo00?o410@omgMgOooool01Oooool00ooMgMgo410@onk^kP0:ooooo`;o
<S8b1_ooool00onHV9So<S8booooo`03ooooo`03onk^k_l@413ogMgM093ooooo002`ooooo`05olc<
c?l@413o0000o`000?n7QhL01Oooool00omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;o
oooo00?oQhN7o`000?nj^[X01Oooool00ooMgMgo0000okZj^P04ooooo`03ohN7QomVIVKooooo08oo
oooo002`ooooo`06ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN71?ooool00ol0003oooooooooo`02oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`03oeEEEOmg
MgOoA4A400Cooooo00?ok^k^o`000?ooool0Soooool00;3ooooo00Ko0000oooooomVIVKoQhN7omgM
gOl@4104ooooo`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo
410@oooooolQ8B7ogMgM00Cooooo00?o0000ooooooooool0S_ooool00;3ooooo00Ko410@omgMgOmg
MgOoMgMgooooool00004ooooo`03oc8b<_oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2_oo
ool01OmVIVKoQhN7oooooonHV9SoEEEE00Cooooo00?o0000ooooooooool0S_ooool00;3ooooo00Ko
ZJVYodA4A?nHV9SoA4A4oiRHV?l@4104ooooo`03o`000?o^k^kooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`06o`000?oMgMgoooooooooooo^k^ko0000T?oo
ool00;7ooooo00GoV9RHo`000?l0003o410@olc<c004ooooo`03oeEEEOmgMgOooooo00;ooooo0_l0
0002ooooo`;o00002?ooool01?l@413o0000o`000?ooool2o`000005oa0@4?ooooooooooogMgMomE
EED0T?ooool00;;ooooo00?o^[Zjoc8b<_ooool01Oooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM093ooooo002cooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool05ooo
ool00omVIVKoMgMgooooo`2@ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.121221, 0.0265831, \
0.00377224, 0.00377224}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.2", "Subsubtitle",
  CellTags->"c:27"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Consider the following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 \[LessEqual] \ x \[LessEqual] \ 1\)\(:\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            RowBox[{\(\[Chi](x)\), 
              
              FractionBox[\(\[PartialD]\^2\( T(x, t)\)\), \(\[PartialD]x\^2\),
                
                MultilineFunction->None]}], "+", \(2\ x\)}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = \(T(1, t) = 0\)\)]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 0\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x)\  = \ 1\ \ for\ 0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x) = 2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\  < x < 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the FTCS method, and taking  ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  " (i.e., 11 grid points including the end points), what is the largest time \
step size one can use? "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve the equation with the largest possible time step size.  Make an \
animation showing only every fifth time step for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  "  Using the Lax method with the largest possible time step size, solve the \
following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0 \[LessEqual] \ x \[LessEqual] \ 
          1\)\(:\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], \(\[Chi](x)\), 
            FractionBox[\(\[PartialD]\(T(x, t)\)\), \(\[PartialD]x\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = sin(6  \[Pi]\ t), \ T(1, t) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = 0\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x)\  = \ x\ \ for\ 0 < x < 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi](x) = 2  x - 1/2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\  < x < 1\)]],
  ".Make an animation showing only every fifth time step for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Consider the following first-order PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None], "+", 
            RowBox[{"c", 
              FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]x\),
                MultilineFunction->None]}]}], "=", "0"}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
Using von Neumann  stability analysis, show that the CTCS method \
applied to that equation is stable provided that the following Courant \
condition is satisfied:\
\>", "Text",
  CellTags->"i:66"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], " ", "\[LessEqual]", "  ", 
          "1"}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(6.2.44)"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " For the time-dependent Schr\[ODoubleDot]dinger equation in 1D [Eq. ",
  ButtonBox["(3.1.81)",
    ButtonData:>{"Chapter3.nb", "(3.1.81)"},
    ButtonStyle->"Hyperlink"],
  "], and for a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in a constant potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = V\_o\)]],
  ", show that the CTCS method is stable only if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "[", 
            RowBox[{"|", \(V\_o\), "|", 
              RowBox[{\(\(/\)\(\[HBar]\)\), " ", "+", " ", 
                RowBox[{"4", " ", 
                  RowBox[{"\[HBar]", "/", 
                    RowBox[{"(", 
                      RowBox[{"m", " ", 
                        SuperscriptBox[
                          StyleBox[
                            RowBox[{"\[CapitalDelta]", 
                              StyleBox["x",
                                FontSlant->"Italic"]}]], "2"]}], 
                      ")"}]}]}]}]}], "]"}], " ", "<", "2"}], 
        TraditionalForm]]],
  ". This sets a rather stringent condition on ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", rendering CTCS  of only academic interest for quantum problems."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)(a)",
    FontWeight->"Bold"],
  " Use the CTCS method to finite-difference the wave equation in ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " dimensions (on a uniform Cartesian grid). Perform a von Neumann  \
stability analysis to show that this method is stable provided that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"c", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], " ", "\[LessEqual]", 
          "  ", \(1/\(\(\@D\)\(.\)\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For the 1-D wave equation,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2 y\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(c\^2\), " ", \((x)\), 
            FractionBox[\(\[PartialD]\^2\( y(x, t)\)\), \(\[PartialD]x\^2\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  "on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-4\) < x < 4\)]],
  ",  where ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \ 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \(\(1/2\)\(\ \)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[GreaterEqual] \ 0\)]],
  ", use the CTCS method to solve the following problem for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ". Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", "0.25"}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.2"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0) = \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\(y(x, t)\)\), \(\[PartialD]t\),
              
              MultilineFunction->
                None], \( \[VerticalSeparator] \_\(t = 0\)\)}], 
          "=", \(\(-2\) \((x - 
                2)\)\ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)}], 
        TraditionalForm]]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y(\(-4\), t)\  = \(y(4, t)\  = \ 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Make an animation of the result showing every fifth time step. Note: The \
CTCS scheme will require you to specify  ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\%1\)]],
  " directly from the two initial conditions. To determine ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\%1\)]],
  "use the equation for uniform acceleration, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y\_k\%1\), "=", 
          RowBox[{\(y\_k\%0\), "+", 
            RowBox[{\(v\_\(0\ k\)\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "  ", "+", " ", 
            RowBox[{\(a\_\(\(k\)\(\ \)\)\), 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], "/", "2"}]}]}]}], 
        TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(o\ k\)\)]],
  " is the initial velocity of the ",
  Cell[BoxData[
      FormBox[
        RowBox[{Cell["k"], "th"}], TraditionalForm]]],
  " point and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k\)]],
  " is the initial acceleration, determined by"
}], "Text"],

Cell[TextData[{
  "  \t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_\(\(k\)\(\ \)\)\), "=", " ", 
          RowBox[{
            RowBox[{\(c\^2\), " ", 
              
              FractionBox[\(\[PartialD]\^2\( y(x, 0)\)\), \(\[PartialD]x\^2\),
                
                MultilineFunction->None]}], \( | \_\(x = x\_k\)\)}]}], 
        TraditionalForm]]],
  " . "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(6.2.15)",
    ButtonData:>"(6.2.15)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(6.2.17)",
    ButtonData:>"(6.2.17)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Repeat Exercise (1) using the Crank-Nicolson method. Now take as a time \
step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.02"}], 
        TraditionalForm]]],
  " and show every frame of the animation for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1/2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)(a)",
    FontWeight->"Bold"],
  " For the 1-D Schr\[ODoubleDot]dinger equation and for a particle of mass \
",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in a uniform potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = V\_o\)]],
  ", show that the Crank-Nicolson method is stable for any time step size. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the Crank-Nicolson method to solve the Schr\[ODoubleDot]dinger \
equation for a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", described by a wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  ", moving in a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ 8\ x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-4\) < x < 4\)]],
  ", over the time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  ". Animate ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  " over this time interval. Take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  " on the boundaries, and assume an initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          0) = \[ExponentialE]\^\(5\ \[ImaginaryI]\ x\  - 2\ \((x + 2)\)\^2\)\
\)]],
  ". Also, take ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\[HBar] = 1\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(9) ",
    FontWeight->"Bold"],
  "Consider the following heat equation problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ r \[LessEqual] \ 1\)]],
  " in ",
  StyleBox["cylindrical",
    FontSlant->"Italic"],
  " geometry:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]T\), \(\[PartialD]t\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox[\(\[PartialD]\^2 T\), \(\[PartialD]r\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(1\/r\), 
              FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
                MultilineFunction->None]}], "+", 
            RowBox[{\(1\/r\^2\), 
              FractionBox[\(\[PartialD]\^2 T\), \(\[PartialD]\[Theta]\^2\),
                MultilineFunction->None]}], "+", 
            " ", \(\(r\^2\) cos\ m\ \[Theta]\)}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T(1, \[Theta], \ t)\), "=", 
            RowBox[{
              RowBox[{"-", 
                
                FractionBox[\(\[PartialD]\(T(r, \[Theta], \ 
                      t)\)\), \(\[PartialD]r\),
                  MultilineFunction->None]}], 
              SubscriptBox[
                StyleBox["\[VerticalSeparator]",
                  FontSize->14], \(r = 1\)]}]}], ","}], TraditionalForm]]],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, \[Theta], 0) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " The solution will depend on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ m\ \[Theta]\)]],
  ", so only a radial grid is necessary. While this simplifies the numerics, \
we now require a boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". Recall from Sec. ",
  ButtonBox["6.1",
    ButtonData:>"c:2",
    ButtonStyle->"Hyperlink"],
  " that the proper boundary condition is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(lim\_\(r \[Rule] 0\)\), 
              FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
                MultilineFunction->None]}], "-", \(\(m\^2\/r\) T\)}], " ", 
          "=", " ", "0"}], TraditionalForm]]]
}], "Text",
  CellTags->"i:38"],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(6.1.37)",
    ButtonData:>"(6.1.37)",
    ButtonStyle->"Hyperlink"],
  "].   For ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " this implies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]T\), \(\[PartialD]r\),
            MultilineFunction->None], "=", "0"}], TraditionalForm]]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", but for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  " it implies ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". In both cases the grid must avoid ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". The best choice is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r(j)\), " ", "=", " ", 
          RowBox[{\((j - 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1,  ... \)]],
  "., using a centered-difference for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]r\)\( | \_\(r = 
              0\)\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ if\ m = 0)\)\)]],
  ",  or the average value at grid points ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)]],
  " and 1 for ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(|\_\(r = 0\)\)\)]],
  "(if ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  "). Use the differencing techniques discussed in connection with Eqs. ",
  ButtonBox["(6.2.23)",
    ButtonData:>"(6.2.23)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.2.25)",
    ButtonData:>"(6.2.25)",
    ButtonStyle->"Hyperlink"],
  " to  satisfy the mixed boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the  Crank-Nicolson method to solve this problem for the case ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  ". Take the time step size  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], "=", " ", "0.02"}], ","}], 
        TraditionalForm]]],
  " and take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  " (i.e. 11 grid points in ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "). Make an animation of the solution as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " A sandbar causes the water depth in the ocean to vary as ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\  = \ 1 - \[ExponentialE]\^\(-x\^2\)/2\)]],
  ". Water waves impinge on the sand bar at normal incidence, satisfying the \
1-D shallow water wave equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( z(x, t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{\(c\^2\), " ", \((x)\), 
                FractionBox[\(\[PartialD]\(z(x, t)\)\), \(\[PartialD]x\),
                  MultilineFunction->None]}], ")"}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\)(x)\  = \ g\ \(h(x)\)\)]],
  ". Solve using CTCS for ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  "on a grid with ",
  Cell[BoxData[
      \(TraditionalForm\`M = 50\)]],
  " points, with ",
  StyleBox["periodic",
    FontSlant->"Italic"],
  " boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  ", and with initial conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, 
          0)\  = \ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\& . \)(x, 
          0) = \(-4\) \((x - 
              2)\)\ \[ExponentialE]\^\(\(-2\) \((x - 2)\)\^2\)\)]],
  " . [Hint: Periodic boundary conditions imply that ",
  Cell[BoxData[
      \(TraditionalForm\`z(\(-5\), t) = z(5, t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\^\[Prime]\)(\(-5\), t) = \(z\^\[Prime]\)(5, 
          t)\)]],
  ". ] Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`g\  = 1\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " as large as possible."
}], "Text"],

Cell[TextData[{
  StyleBox["(11) ",
    FontWeight->"Bold"],
  "A square pool with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < a\)]],
  ",  has a sloped bottom, becoming deeper  as ",
  Cell[BoxData[
      \(TraditionalForm\`x\ or\ y\)]],
  " increases: ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\  = \ \(h\_o\)(1 + x/a + y/a)\)]],
  ". Assuming potential flow, the horizontal fluid displacement satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Eta]",
            FontWeight->"Bold"], " ", "=", 
          " ", \(\[Del]\(\[Phi](x, y, t)\)\)}], TraditionalForm]]],
  "and the wave height is given by ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 
          t) = \(-\[Del]\)\[CenterDot]\([\(h(x, y)\) \[Del]\[Phi]]\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfying the following wave equation:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FractionBox[\(\[PartialD]\^2\( \[Phi](x, y, 
                t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]x\),
                MultilineFunction->None], 
              RowBox[{"(", 
                RowBox[{\(\(c\^2\)(x, y)\), 
                  
                  FractionBox[\(\[PartialD]\(\[Phi](x, , y, 
                        t)\)\), \(\[PartialD]x\),
                    MultilineFunction->None]}], ")"}]}], "+", 
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]y\),
                MultilineFunction->None], 
              RowBox[{"(", 
                RowBox[{\(\(c\^2\)(x, y)\), 
                  
                  FractionBox[\(\[PartialD]\(\[Phi](x, , y, 
                        t)\)\), \(\[PartialD]y\),
                    MultilineFunction->None]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(6.2.45)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 = g\ h\)]],
  ". Initially, the fluid is stationary, but an inlet at the center of the ",
  "left-hand",
  " side, of length ",
  Cell[BoxData[
      \(TraditionalForm\`a/2\)]],
  " begins to add and remove water according to  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Eta]\_x\)(0, y)\  = \ x\_o\ \(sin(\[Omega]\_o\ t)\)\), 
          ",", " ", 
          RowBox[{\(a/4\), "<", "y", "<", 
            RowBox[{"3", " ", \(a/4\), " ", Cell[""]}]}]}], 
        TraditionalForm]]],
  ". Around the rest of the pool, the normal component of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is zero."
}], "Text"],

Cell[TextData[{
  "Using CTCS, solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, t)\)]],
  " on a 15-by-15 grid for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \)]],
  "4 s, assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"a", "=", 
            RowBox[{"5", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], ",", \(h\_o = 10\ cm\), ",", " ", 
          RowBox[{\(\[Omega]\_o\), "=", 
            RowBox[{"3", Cell[""]}]}], ",", " ", 
          RowBox[{\(x\_o\), "=", 
            RowBox[{"2", " ", "cm", Cell[""]}]}]}], TraditionalForm]]],
  ". Make an animation of the resulting wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, t)\)]],
  " over this time period. "
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " An electrolytic cell consists of a glass tank of width ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and height ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", and length ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction (into the page).  The tank is filled with fluid that has \
electrical conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " . The tank has electrodes of length ",
  Cell[BoxData[
      \(TraditionalForm\`L = a/2\)]],
  ", located as shown in Fig. ",
  ButtonBox["6.8",
    ButtonData:>"Fig. 6.8",
    ButtonStyle->"Hyperlink"],
  ",  and attached on the left and right sides; the rest of the surface is \
electrically insulated.  The right electrode  is grounded and the left \
electrode is at a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ".  Using the direct method, solve for the potential in the fluid, and use \
this result to find the total current ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(I\)\(\ \)\)\)]],
  " running between the two electrodes . (See Example 2 in Sec. ",
  ButtonBox["3.2.2",
    ButtonData:>{"Chapter3.nb", "c:30"},
    ButtonStyle->"Hyperlink"],
  " for help on setting up the equations for this problem.) Do this problem \
for ",
  Cell[BoxData[
      \(TraditionalForm\`b = n\ a/5\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2,  ... , 10\)]],
  ", and plot the result  for ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`b/a\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " suitably normalized in terms of the given parameters.  [Hint: This is \
really a two-dimensional problem; current density and potential depend only \
on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". Part of the boundary has a von Neumann  boundary condition, and part has \
a Dirichlet condition. For second-order accuracy, use a grid for which the \
boundary falls halfway between the grid points. For the von Neumann  portion \
of the boundary, use the centered-difference method discussed in relation to \
Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  ", and for the Dirichlet part of the boundary, use the averaging technique \
discussed in relation to Eq. ",
  ButtonBox["(6.2.22)",
    ButtonData:>"(6.2.22)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:@0001F2000`400?l00000o`00003ooooooooo
oooooi;ooooo003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo
003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003ooooooooo
ooooT_ooool00?oooooooooooonBooooo`004?oooomZ0?ooo`030820P000000000000?l00000c000
000g0?oooa7ooooo000@ooooofX0oooo00<0P820000000000000o`00003<000003L0oooo4Oooool0
013oooooJP3oool00`20P80000000000003o00000<`00000=`3ooolAooooo`004?oooomZ0?ooo`04
0820P0000000000000000?l0ooooaP3oool5000003L0oooo4Oooool0013oooooJP3oool01020P800
000000000000003o0?ooolH0oooo1@00000g0?oooa7ooooo000@ooooob@0oooo00<000000?ooo`3o
ool0@03oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo903oool00`000000oooo
0?ooo`100?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`030820P000
0000P8200440oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`000011
0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<0000
0?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo8P3oool500000400oooo3000003o0?oool40
oooo1@00000g0?oooa7ooooo000@ooooob80oooo1@0000100?ooo``00000o`3oooo10?ooo`D00000
=`3ooolAooooo`004?oooolR0?ooo`D00000@03oool<00000?l0oooo`@3oool5000003L0oooo4Ooo
ool0013ooooo8@3oool7000003l0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob40oooo1`00000o0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolQ0?ooo`L0
0000?`3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo803oool9000003h0oooo
3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob00oooo2@00000n0?ooo``00000o`3o
ooo10?ooo`D00000=`3ooolAooooo`004?oooolP0?ooo`T00000?P3oool<00000?l0oooo`@3oool5
000003L0oooo4Oooool0013ooooo7`3oool;000003d0oooo3000003o0?oool40oooo1@00000g0?oo
oa7ooooo000@oooooal0oooo2`00000m0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`00
4?oooolN0?ooo``0000000<0P8200?ooo`3oool0>P3oool<00000?l0oooo`@3oool5000003L0oooo
4Oooool0013ooooo7P3oool=000003`0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@
oooooad0oooo3P00000l0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolM0?oo
o`l00000>`3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo7@3oool?000003/0
oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooa`0oooo4@00000j0?ooo``00000
o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolL0?oooa400000>P3oool<00000?l0oooo`@3o
ool5000003L0oooo4Oooool0013ooooo6`3ooolB000003X0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@oooooa/0oooo4`00000i0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAoooo
o`004?oooolK0?oooa<00000>@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo
6`3ooolC000003T0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaX0oooo5@00
000h0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolJ0?oooaD00000>03oool<
00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo6P3ooolE000003P0oooo3000003o0?oo
ol40oooo1@00000g0?oooa7ooooo000@oooooaT0oooo5`00000g0?ooo``00000o`3oooo10?ooo`D0
0000=`3ooolAooooo`004?oooolI0?oooaL00000=`3oool<00000?l0oooo`@3oool5000003L0oooo
4Oooool0013ooooo603ooolI000003H0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@
oooooaP0oooo6@00000f0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolG0?oo
oaX00000=P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo5`3ooolJ00000003
0820P03oool0oooo03<0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaL0oooo
6P0000000`20P800oooo0?ooo`0c0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oo
oolF0?oooa/0000000<0P8200?ooo`3oool0<`3oool<00000?l0oooo`@3oool5000003L0oooo4Ooo
ool0013ooooo5P3ooolL000003D0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
oaH0oooo7000000e0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolF0?oooa`0
0000=@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo5@3oool00`20P8000000
0000000K000003@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooooaD0oooo00<0
P8200000000000006`00000d0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolH
0?oooaT00000=P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo6`3oool60820
P0T000001020P80i0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<0
0000@@3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0013ooooo8`3oool3000001H0oooo
6@00000B0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000603o
oolH00000140oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I
0?ooo`030820P0000000000000800000303oool600000140oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P0000000000000000100oooo0`00000A
0?ooo``00000o`3oooo10?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<000006@3oool01020
P800000000000000000A0?ooo`<00000403oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0
013ooooo8`3oool3000001T0oooo00@0P82000000000000000004P3oool200000100oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000001<0oooo00<000000?ooo`3oool03P3oool<00000?l0oooo`@3oool5000003L0oooo4Oooool0
013ooooo8`3oool3000001T0oooo00@0P82000000000000000004`3oool2000000l0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o
0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000
000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00000I0?oo
o`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000003o0?oool40oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`00000I0?ooo`040820P00000000000000002@0oooo3000000/
0?ooo`80P820o`3ooonC0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<000006@3oool50000
02<0oooo3000000[0?ooo`@00000o`3ooonB0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<0
0000603oool700000280oooo3000000Z0?ooo`D0000000<0P8200?ooo`3oool0o`3ooon?0?ooo`D0
0000=`3ooolAooooo`004?oooolS0?ooo`<000005P3oool;00000200oooo3000000[0?ooo`D00000
o`3ooonA0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000002`0oooo1P00
003o0?ooohl0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000;@3oool6
00000?l0ooooSP3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000000^0?oo
o`H00000o`3ooon=0?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000002l0
oooo00<0P8200000000000000`00003o0?oooh`0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo
0`0000110?ooo``00000<03oool600000?l0ooooR`3oool5000003L0oooo4Oooool0013ooooo8`3o
ool300000440oooo3000000a0?ooo`H00000o`3ooon:0?ooo`D00000=`3ooolAooooo`004?oooolS
0?ooo`<00000@@3oool<00000380oooo1P00003o0?ooohT0oooo1@00000g0?oooa7ooooo000@oooo
ob<0oooo0`0000110?ooo``00000<`3oool600000?l0ooooR03oool5000003L0oooo4Oooool0013o
oooo8`3oool300000440oooo3000000d0?ooo`H00000o`3ooon70?ooo`D00000=`3ooolAooooo`00
4?oooolS0?ooo`<00000@@3oool<000003D0oooo1P00003o0?ooohH0oooo1@00000g0?oooa7ooooo
000@ooooob<0oooo0`0000110?ooo``00000=P3oool00`20P800000000000004000000030<30`03o
ool0oooo0?l0ooooP@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000000h
0?ooo`H00000o`3ooon30?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<0000
03X0oooo1@00003o0?oooh80oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``0
0000>`3oool500000?l0ooooP@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo
3000000l0?ooo`D00000o`3ooon00?ooo`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3o
ool<000003d0oooo1@00003o0?ooogl0oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`000011
0?ooo``00000?@3oool00`20P80000000000000300000?l0ooooOP3oool5000003L0oooo4Oooool0
013ooooo8`3oool300000440oooo3000000n0?ooo`H00000o`3ooomm0?ooo`D00000=`3ooolAoooo
o`004?oooolS0?ooo`<00000@@3oool<000003l0oooo1`00003o0?ooog/0oooo1@00000g0?oooa7o
oooo000@ooooob<0oooo0`0000110?ooo``00000@03oool700000?l0ooooNP3oool5000003L0oooo
4Oooool0013ooooo8`3oool300000440oooo300000110?ooo`L00000o`3ooomi0?ooo`D00000=`3o
oolAooooo`004?oooolS0?ooo`<00000@@3oool<000004<0oooo1P00003o0?ooogP0oooo1@00000g
0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000A03oool600000?l0ooooM`3oool50000
03L0oooo4Oooool0013ooooo8`3oool300000440oooo300000150?ooo`H00000o`3ooomf0?ooo`D0
0000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000004H0oooo00<0P820000000000000
0`0000000`10@400oooo0?ooo`3o0?ooog80oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`00
00110?ooo``00000B03oool600000?l0ooooL`3oool5000003L0oooo4Oooool0013ooooo8`3oool3
00000440oooo3000001:0?ooo`D00000o`3ooomb0?ooo`D00000=`3ooolAooooo`004?oooolS0?oo
o`<00000@@3oool<000004/0oooo1@00003o0?ooog40oooo1@00000g0?oooa7ooooo000@ooooob<0
oooo0`0000110?ooo``00000C03oool500000?l0ooooL03oool5000003L0oooo4Oooool0013ooooo
8`3oool300000440oooo3000001<0?ooo`030820P0000000000000@00000o`3ooom^0?ooo`D00000
=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<000004d0oooo1`00003o0?ooofd0oooo1@00
000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000CP3oool700000?l0ooooK03oool5
000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000001@0?ooo`H00000o`3ooom[0?oo
o`D00000=`3ooolAooooo`004?oooolS0?ooo`<00000@@3oool<00000540oooo1@00003o0?ooof/0
oooo1@00000g0?oooa7ooooo000@ooooob<0oooo0`0000110?ooo``00000DP3oool600000?l0oooo
J@3oool5000003L0oooo4Oooool0013ooooo8`3oool300000440oooo3000001C0?ooo`H00000o`3o
oomX0?ooo`D00000=`3ooolAooooo`004?ooool40?ooo`@000001`3oool300000140oooo0`000011
0?ooo``00000E03oool6000000030820P03oool0oooo0?l0ooooI03oool5000003L0oooo4Oooool0
013ooooo0`3oool7000000@0oooo1P00000?0?ooo`<00000@@3oool<000005H0oooo1@00003o0?oo
ofH0oooo1@00000g0?oooa7ooooo000@ooooo`030?ooo`20P800000000@000000`20P8000`000000
P8200820P004000000<0P82000<000000?ooo`3oool0303oool300000440oooo3000001G0?ooo`03
0820P00000000000008000000P20P83o0?ooof<0oooo1@00000g0?oooa7ooooo000@ooooo`030?oo
o`000000000000<000001P3oool500000180oooo0`0000110?ooo``00000F@3oool600000?l0oooo
HP3oool5000003L0oooo4Oooool0013ooooo00<0oooo0000000000000P0000080?ooo`@000004P3o
ool300000440oooo3000001J0?ooo`030820P0000000000000<00000o`3ooomQ0?ooo`D00000=`3o
oolAooooo`004?ooool00`3oool0000000000002000000P0oooo1000000B0?ooo`<00000@@3oool<
000005/0oooo1`00003o0?oooel0oooo1@00000g0?oooa7ooooo000@ooooo`030?ooo`0000000000
00800000203oool400000180oooo0`0000110?ooo``00000G03oool700000?l0ooooGP3oool50000
03L0oooo4Oooool0013ooooo0P3oool3000000P0oooo1000000B0?ooo`<00000@@3oool<000005h0
oooo1`00003o0?oooe`0oooo1@00000g0?oooa7ooooo000@ooooo`<0oooo0`0000070?ooo`@00000
4P3oool300000440oooo3000001O0?ooo`L00000o`3ooomK0?ooo`D00000=`3ooolAooooo`004?oo
ool40?ooo`<000001P3oool400000180oooo0`0000110?ooo``00000H03oool700000?l0ooooFP3o
ool5000003L0oooo4Oooool0013ooooo1@3oool2000000030820P03oool0oooo00<0oooo1000000B
0?ooo`<00000@@3oool<00000680oooo1P0000000`20P800oooo0?ooo`3o0?oooeH0oooo1@00000g
0?oooa7ooooo000@ooooo`L0oooo00<0P8200000003oool00`3oool400000180oooo0`0000110?oo
o``00000H`3oool600000?l0ooooF03oool5000003L0oooo4Oooool0013ooooo2@3oool300000003
0?ooo`0000000000008000004P3oool300000440oooo3000001T0?ooo`H00000o`3ooomG0?ooo`D0
0000=`3ooolAooooo`004?ooool<0?ooo`D000004P3oool300000440oooo3000001U0?ooo`L00000
o`3ooomE0?ooo`D00000=`3ooolAooooo`004?ooool=0?ooo`@000004P3oool300000440oooo3000
001W0?ooo`H00000o`3ooomD0?ooo`D00000=`3ooolAooooo`004?ooool30?ooo`800000203oool4
00000180oooo0`0000110?ooo``00000J03oool700000?l0ooooDP3oool5000003L0oooo4Oooool0
013ooooo0P3oool4000000L0oooo1000000B0?ooo`<00000@@3oool<000006P0oooo00<0P8200000
000000001@00003o0?oooe40oooo1@00000g0?oooa7ooooo000@ooooo`80oooo100000070?ooo`<0
000000<0P8200?ooo`3oool0403oool300000440oooo0`20P8001010@40000000000000000050820
P6X0oooo00<0P820000000000000100000020820P?l0ooooCP3oool5000003L0oooo4Oooool0013o
oooo0`3oool3000000H0oooo1000000C0?ooo`<00000A03oool01020P800000000000000001b0?oo
o`L00000o`3ooom=0?ooo`D00000=`3ooolAooooo`004?ooool40?ooo`<00000103oool4000001@0
oooo0`0000140?ooo`040820P00000000000000007<0oooo1`00001Q0?ooo`/00000g`3oool50000
03L0oooo4Oooool0013ooooo1`3oool6000001H0oooo0`0000140?ooo`040820P000000000000000
07@0oooo1`0000000`20P800oooo0?ooo`1O0?ooo`L00000h@3oool5000003L0oooo4Oooool0013o
oooo8`3oool3000004@0oooo00@0P8200000000000000000MP3oool600000680oooo00@0P8200000
000000000000h`3oool5000003L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000
000000000000M`3oool700000600oooo00@0P8200000000000000000h`3oool5000003L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000N@3oool6000005l0oooo00@0
P8200000000000000000h`3oool5000003L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0
P8200000000000000000NP3oool6000005h0oooo00@0P8200000000000000000g`3oool00`20P800
00000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820000000000000
0000N`3oool7000005`0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:0000
03<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000O03oool70000
05/0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0
013ooooo8`3oool3000004@0oooo00@0P8200000000000000000O@3oool8000005T0oooo00@0P820
0000000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000O`3oool7000005P0oooo00@0P8200000000000000000
g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0
P8200000000000000000P03oool8000005H0oooo00@0P8200000000000000000g`3oool00`20P800
00000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820000000000000
0000PP3oool7000005D0oooo00@0P8200000000000000000g`3oool00`20P80000000000000:0000
03<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000P`3oool20820
P0D000000P20P81B0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000008H0oooo1`00001A
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000008P0oooo1`00001?0?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P00000000000000008T0oooo2000001=0?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P00000000000000008X0oooo2000001<0?ooo`040820P0000000000000000=l0oooo00<0P8200000
000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P000000000000000
08`0oooo2000001:0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000008d0oooo20000019
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000008l0oooo200000170?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P0000000000000000900oooo200000160?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P0000000000000000980oooo200000140?ooo`040820P0000000000000000=l0oooo00<0P8200000
000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P000000000000000
09<0oooo2@0000120?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c
0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P00000000000000009D0oooo20000011
0?ooo`040820P0000000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P00000000000000009L0oooo2000000o0?ooo`040820P000
0000000000000=l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`00
00140?ooo`040820P00000000000000009P0oooo2@00000m0?ooo`040820P0000000000000000=l0
oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820
P00000000000000009X0oooo00<0P8200000000000001P0000020820P3T0oooo00@0P82000000000
00000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0
oooo00@0P8200000000000000000W@3oool9000000030820P03oool0oooo03D0oooo00@0P8200000
000000000000g`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool30000
04@0oooo00@0P8200000000000000000W`3oool8000003L0oooo00@0P8200000000000000000g`3o
ool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000X@3oool8000003@0oooo1`00003M0?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000002S0?ooo`P00000<03o
ool;00000=/0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:D0oooo2000003o0?oooaD0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000:H0oooo2@00
003o0?oooa<0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:L0oooo2P00003o0?oooa40oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000:T0oooo2P00
003o0?ooo`l0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000:/0oooo2@0000000`20P800oooo0?ooo`3o0?ooo`/0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000:h0oooo2000003o0?ooo``0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000;00oooo2000003o0?ooo`X0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000;80oooo2000003o0?ooo`P0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000;@0oooo00<0P8200000000000001@00
003o0?ooo`H0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000;H0oooo0P20P80600000080P820o`3oool20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
002j0?ooo`P0000000<0P8200?ooo`3oool0o03oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000_@3oool700000?d0oooo00<0
P8200000000000002P00000D0?oooaT000001P3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000002o0?ooo`P00000nP3oool00`20P80000000000000:000001H0oooo6000
00050?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000<40oooo2000
003h0?ooo`030820P0000000000000X00000603oool5000000`0oooo1@0000050?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000<<0oooo2@00003e0?ooo`030820P000
0000000000X00000603oool4000000l0oooo00<0P8200000000000001@3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P80000000000000000350?ooo`T00000l`3oool00`20P80000000000
000:000001P0oooo1000000@0?ooo`<00000103ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P80000000000000000370?ooo`T0000000<0P8200?ooo`3oool0kP3oool00`20P80000000000
000:000001P0oooo1000000A0?ooo`800000103ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003:0?ooo`P00000k`3oool00`20P80000000000000:000001P0oooo1000
000B0?ooo`030000003oool0oooo0080oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000c03oool900000>`0oooo00<0P8200000000000002P00000H0?ooo`@000004P3o
ool2000000<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000cP3o
ool:00000>T0oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003@0?ooo`/00000iP3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000=80oooo3000003S0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000e03oool<00000>40oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003G0?ooo`<0P8202@0000030820P=/0oooo00<0P8200000000000002P00
000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
003M0?ooo``00000f03oool00`20P80000000000000:000001P0oooo1000000G0?oooa7ooooo000@
ooooob<0oooo0`0000140?ooo`040820P0000000000000000=l0oooo3@00003E0?ooo`030820P000
0000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000hP3oool=00000=80oooo00<0P8200000000000002P00000H0?ooo`@000005`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003U0?ooo`h00000cP3o
ool00`20P80000000000000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000>P0oooo3`00003:0?ooo`030820P0000000000000X00000603o
ool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000j`3o
ool@00000<H0oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003^0?oooa000000``3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?80oooo4000002o0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000mP3oool@00000;/0oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003j0?oooa000000]`3oool00`20P80000000000000:000001P0oooo1000
000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?d0oooo4@00
002c0?ooo`030820P0000000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3oool20?oooa400000L03oool3000003`0oooo00<0
P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS0?ooo`<00000A03oool0
1020P800000000000000003o0?ooo`H0oooo4P00001Z0?ooo`H00000>P3oool00`20P80000000000
000:000001P0oooo1000000G0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?l0oooo2P3oool00`20P80000000000000>000006L0oooo2@00000g0?ooo`030820P000
0000000000X00000603oool4000001L0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P820
0000000000000000o`3oool>0?ooo`@0P820400000060820P5T0oooo00<0P8200000000000002P00
00020820P380oooo00<0P8200000000000002P00000H0?ooo`@000005`3ooolAooooo`004?oooolS
0?ooo`<00000A03oool01020P800000000000000003o0?oooaL0oooo5`00001C0?oooa800000;`3o
ool00`20P80000000000000:000001L0oooo1P00000F0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0oooo6P3ooolJ000000030820P03oool0oooo04X0oooo5000
000]0?ooo`030820P0000000000000X000005P3oool7000000030820P03oool0oooo01<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3ooolQ0?oooa`00000A03o
oolF000000030820P03oool0oooo02P0oooo00<0P8200000000000002P00000D0?ooo`/00000503o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003o0?ooobL0oooo7`00
000k0?oooaP00000:@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3oool]0?ooob800000<@3ooolL000002H0oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000
000000000?l0oooo=03ooolT000002P0oooo8000000R0?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000003o0?ooocX0oooo9`00
000O0?ooob@000007P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooom20?ooobT000005@3ooolU000000030820P03o
ool0oooo01X0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooB03ooomO000001/0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooC`3o
oomJ000001T0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooG@3ooom@000001D0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooJ`3o
oom4000001<0oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0ooooP03oool/000001H0oooo00<0P8200000000000002P00
000c0?oooa7ooooo000@ooooob<0oooo0`0000140?ooo`040820P0000000000000000?l0ooooP03o
oolV000000<0P8206@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon00?ooob@000007P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon00?ooob4000008@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon00?oooah00000903oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon00?oooa/000009`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon10?oooaP00000:@3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon10?oooaH00000:`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon10?oooa<00000;P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon10?oooa000000<@3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo8`3oool3
000004@0oooo00@0P8200000000000000000o`3ooon20?ooo``00000=03oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo8`3oool3000004@0oooo00@0P8200000000000000000o`3o
oon20?ooo`T00000=`3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo7P3oool<
00000400oooo00@0P8200000000000000000o`3ooon30?ooo`H00000>@3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo6`3ooolC000003`0oooo00@0P8200000000000000000o`3o
oon30?ooo`<00000?03oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo603ooolJ
000003P0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolE0?ooo`030820P0000000000001/00000=`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooaH0oooo7000000h
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo5P3ooolL000003P0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolF0?oooa`00000>03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooaH0oooo6`000000
0`20P800oooo0?ooo`0f0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000
000:000003<0oooo4Oooool0013ooooo5`3ooolJ000000030820P03oool0oooo03H0oooo00@0P820
0000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3ooolAooooo`004?oooolG
0?oooaX0000000<0P8200?ooo`3oool0=P3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaP0oooo6@00000i0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo603ooolI
000003T0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolI0?oooaP00000>@3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaT0oooo5`00000j0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo6@3ooolG
000003X0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P0000000000000X00000<`3o
oolAooooo`004?oooolJ0?oooaD00000>`3oool01020P800000000000000003o0?oool80oooo00<0
P8200000000000002P00000c0?oooa7ooooo000@oooooaX0oooo5@00000k0?ooo`040820P0000000
000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Oooool0013ooooo6P3ooolD
000000030820P03oool0oooo03T0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolK0?oooa<00000?03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooa/0oooo4`00000l
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo6`3ooolB000003d0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolK0?oooa800000?@3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooa`0oooo4@00000m
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo703oool@000003h0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolM0?ooo`l00000?P3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooad0oooo3`00000n
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo7@3oool>000003l0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolN0?ooo`d00000?`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooah0oooo3@00000o
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo7P3oool<00000400oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolO0?ooo`/00000@03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@oooooal0oooo2`000010
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo803oool900000440oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolQ0?ooo`P00000@@3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob40oooo1`000012
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8@3oool700000480oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolR0?ooo`D00000@`3oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob80oooo1@000013
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8P3oool5000004<0oooo00@0P8200000000000000000o`3oooo20?ooo`030820P000
0000000000X00000<`3ooolAooooo`004?oooolS0?ooo`<00000A03oool01020P800000000000000
003o0?oool80oooo00<0P8200000000000002P00000c0?oooa7ooooo000@ooooob<0oooo0`000014
0?ooo`040820P0000000000000000?l0oooo`P3oool00`20P80000000000000:000003<0oooo4Ooo
ool0013ooooo8`3oool3000004@0oooo00<0P820000000000000o`00003@000003<0oooo4Oooool0
013ooooo8`3oool00`20P80000000?ooo`140?ooo`030820P000000000000?l00000d000000c0?oo
oa7ooooo000@ooooob<0oooo00<0P8200000003oool0A03oool00`20P80000000000003o00000<`0
0000=`3ooolAooooo`004?oooolT0?ooo`030000003oool0oooo04<0oooo00<0P820000000000000
o`00003<000003L0oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo
0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40
oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Ooo
ool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013o
ooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3o
oooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?oo
og40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo4Oooool0013oooooo`3ooooo0?ooog40oooo
4Oooool0013oooooo`3ooomA0?ooo`P0P820o`3ooolH0?oooa7ooooo000@ooooool0ooooC`3oool<
00000?l0oooo5P3ooolAooooo`004?oooooo0?ooodd0oooo00<0P8200000000000000`0000060?oo
o`80000000<0P8200?ooo`3oool0o`3ooolC0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
00000000000000090?ooo`<00000o`3ooolD0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
000000000000000:0?ooo`800000o`3ooolD0?oooa7ooooo000@ooooool0ooooC@3oool01020P800
000000000000000:0?ooo`030820P000000000000?l0oooo4`3ooolAooooo`004?oooooo0?ooodd0
oooo00@0P82000000000000000002P3oool01020P800000000000000003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo0`00003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo0`00003o0?oooa80oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000/0oooo1000003o0?oooa40oooo4Oooool0
013oooooo`3ooom=0?ooo`040820P00000000000000000X0oooo00<0P8200000000000000P00003o
0?oooa40oooo4Oooool0013oooooo`3ooom=0?ooo`040820P00000000000000000X0oooo00@0P820
0000000000000000o`3ooolB0?oooa7ooooo000@ooooool0ooooC@3oool01020P800000000000000
000:0?ooo`@00000o`3ooolB0?oooa7ooooo000@ooooool0ooooC@3oool00`20P800000000000002
000000P0oooo1@00003o0?oooa80oooo4Oooool0013oooooo`3ooom=0?ooo`030820P00000000000
00@000001@3oool500000?l0oooo4`3ooolAooooo`004?oooooo0?ooodd0oooo00D0P82000000000
000000000?ooo`0;00000?l0oooo503ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
000000000P3oool900000?l0oooo5@3ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000103oool600000?l0oooo5P3ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000o`3ooolP0?oooa7ooooo000@ooooool0ooooC@3oool01020P800000000000000003o0?oo
ob00oooo4Oooool0013oooooo`3ooom=0?ooo`040820P0000000000000000?l0oooo803ooolAoooo
o`004?oooooo0?ooodd0oooo00@0P8200000000000000000o`3ooolP0?oooa7ooooo000@ooooool0
ooooC@3oool01020P800000000000000003o0?ooob00oooo4Oooool0013oooooo`3ooom=0?ooo`04
0820P0000000000000000?l0oooo803ooolAooooo`004?oooooo0?ooodd0oooo00@0P82000000000
00000000o`3ooolP0?oooa7ooooo000@ooooool0ooooB`3oool600000?l0oooo803ooolAooooo`00
4?oooooo0?ooodd0oooo1000003o0?ooob00oooo4Oooool0013oooooo`3ooom?0?ooo`800000o`3o
oolP0?oooa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo000@ooooool0ooooo`3oooma0?oo
oa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo000@ooooool0ooooo`3oooma0?oooa7ooooo
003oooooooooooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003ooooooooo
ooooT_ooool00?oooooooooooonBooooo`00oooooooooooooi;ooooo003oooooooooooooT_ooool0
0?oooooooooooonBooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{192.25, 100.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.8 Exercise (12).", "Caption",
  CellTags->"Fig. 6.8"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " An enclosure in the shape of an isosceles triangle with base of length ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and with height ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " is filled with a uniform charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]/\[Epsilon]\_o\), "=", 
          RowBox[{"2", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The surface of the triangle is grounded. Find the best grid to fit this \
problem, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = \ 20\)\)]],
  ", and solve it using the direct method, for the case ",
  Cell[BoxData[
      \(TraditionalForm\`b = \(\@5\) meter\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1.5\ meter\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(14) ",
    FontWeight->"Bold"],
  "A room is heated with a corner radiator, held at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o = 70\ \[Degree]C\)]],
  ". As seen in Fig. ",
  ButtonBox["6.9",
    ButtonData:>"Fig. 6.9",
    ButtonStyle->"Hyperlink"],
  ", the bottom and left wall  of the room are insulated, but the right and \
top walls are at constant temperature of 15\[Degree]C. Treating the air in \
the room as a thermally-conductive material, and for the dimensions of the \
room shown in the figure, find the temperature distribution ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, y)\)]],
  " in the room using the direct method. What is the total heat flux entering \
the room through the radiator in watss per square meter, assuming that, for \
air,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", "=", 
          RowBox[{"0.1", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], "  ", "\[Degree]K"}], ")"}]}]}]}], 
        TraditionalForm]]],
  "? "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009U0001DB000`400?l00000o`00003ooooooooo
ooooofOooooo003oooooooooooooIoooool00?oooooooooooomWooooo`00ooooooooooooofOooooo
003oooooooooooooIoooool00?oooooooooooomWooooo`00ooooooooooooofOooooo003ooooooooo
ooooIoooool00?oooooooooooomWooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo
0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0
ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3o
ool@ooooo`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?ooool0ooooB@3oool@oooo
o`003_oooooo0?ooool0ooooB@3oool@ooooo`003_oooooo0?oooa@0oooo1000000@0?ooo`L00000
0P3oool700000080oooo1`00003o0?ooo`P0oooo4?ooool000koooooo`3ooolA0?ooo`040820P000
0000P8200<30`0<0oooo00<0P82000000020P8003P3oool01@30`<000000000000000000`<3000@0
oooo00D0`<3000000000000000000820P0040?ooo`050<30`0000000000000000020P800o`3oool9
0?oooa3ooooo000>ooooool0oooo403oool2000000L0oooo0P0000000`20P800oooo0?ooo`0<0?oo
o`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool?0?ooo`03
0410@0000000P82000P0oooo0P00000>0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0
oooo4?ooool000koooooo`3oool?0?ooo`8000002P3oool2000000d0oooo0`0000060?ooo`<00000
1P3oool300000?l0oooo2P3oool@ooooo`003_oooooo0?ooo`h0oooo0`00000:0?ooo`80000000<0
`<300?ooo`3oool02P3oool3000000H0oooo0`0000060?ooo`<00000o`3oool:0?oooa3ooooo000>
ooooool0oooo3P3oool2000000/0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<000001P3oool3
000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P00000000000
00/0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<000001P3oool3000000H0oooo0`00003o0?oo
o`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P0000000000000/0oooo0P0000000`20P800
oooo0?ooo`0:0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000kooooo
o`3oool=0?ooo`030820P0000000000000X0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`<00000
1P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`030820P000
0000000000T0oooo00D0P82000000000000000000<30`00<0?ooo`<000001P3oool3000000H0oooo
0`00003o0?ooo`X0oooo4?ooool000koooooo`3oool=0?ooo`040820P00000000000000000P0oooo
1000000=0?ooo`<000001P3oool3000000H0oooo0`00003o0?ooo`X0oooo4?ooool000koooooo`3o
ool=0?ooo`050<30`0000000000000000010@4001@3oool01@20P800@410000000000000@41000h0
oooo0`0000000`30`<00oooo0?ooo`020?ooo`030<30`000000000000080P82000D0`<300?ooo`3o
ool0oooo0<30`00300000?l0oooo2P3oool@ooooo`003_oooooo0?ooo`h0oooo0`0000000`20P800
00000000000600000100oooo0`0000000`20P80000000?ooo`020?ooo`<000000P3oool010000000
oooo0?ooo`3oool3000000030820P03oool0oooo0?l0oooo203oool@ooooo`003_oooooo0?ooo`h0
oooo0`0000030?ooo`@0000000<0P8200?ooo`3oool03@3oool5000000030?ooo`000000000000D0
00000P3oool00`20P800000000000004000000030820P03oool0oooo0?l0oooo203oool@ooooo`00
3_oooooo0?ooo`l0oooo0P0000000`10@400oooo0?ooo`0E0?ooo`040<30`020P800@41000000080
oooo00<0P8200410@00000000P0000001P30`<00oooo0?ooo`3oool0P8200410@0<0000000<0P820
0?ooo`3oool0o`3oool90?oooa3ooooo000>ooooool0oooo3`3oool00`20P80000000000003o0?oo
ocL0oooo4?ooool000koooooo`3oool@0?ooo`040820P000000000000820P?l0oooo=@3oool@oooo
o`003_oooooo0?oooa40oooo00@0P820000000000000P820o`3ooold0?oooa3ooooo000>ooooool0
oooo4P3oool01020P800000000000020P83o0?oooc<0oooo4?ooool000koooooo`3ooolD0?ooo`80
000000<0P8200?ooo`3oool0o`3oool`0?oooa3ooooo000>ooooool0oooo5@3oool3000000030820
P03oool0oooo0?l0oooo;P3oool@ooooo`003_oooooo0?oooaL0oooo0P20P80200000080P820o`3o
ool/0?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oo
oa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo
000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>oooo
ool0ooooo`3ooom90?oooa3ooooo000>ooooool0ooooo`3ooom90?oooa3ooooo000>ooooodT0oooo
o`00002d000004/0oooo4?ooool000koooooAP3ooooo00000;L00000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`20P82/0820P0030410@0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo
2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0
oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000kooooo1P3oool00`20
P80000000410@00=0?ooo`030<30`020P800@41000<0P82000<000000820P03oool0503oool20820
P0H000000P20P8090?ooo`P000005P3oool30820P0@000000`20P80<0?ooo`80P820100000001@20
P800oooo0?ooo`30`<00P82000@0000000D0P8200<30`03oool0`<300820P004000000030820P030
`<00oooo0?l0ooooI@3oool00`20P80000000000001;0?oooa3ooooo000>ooooo`L0oooo0P00000=
0?ooo`8000001@3oool00`20P80000000?ooo`0A0?ooo`030820P00000000000008000001@3oool0
0`20P8000000000000080?ooo`P000006@3oool00`20P80000000000000B0?ooo`030820P0000000
000000H0oooo00<0P8200000000000001P3oool01020P800000000000020P83o0?ooofP0oooo00<0
P820000000000000B`3oool@ooooo`003_ooool70?ooo`800000303oool2000000L0oooo00<00000
0820P03oool0403oool3000000030820P03oool0oooo00H0oooo0P0000070?ooo`P000006@3oool0
0`20P80000000000000B0?ooo`030820P0000000000000H0oooo00<0P8200000000000001P3oool0
1020P800000000000020P83o0?ooofP0oooo00<0P820000000000000B`3oool@ooooo`003_ooool8
0?ooo`8000002P3oool2000000030820P03oool0oooo00D0oooo00<0P8200000003oool03P3oool0
1@30`<000000000000000000P82000X0oooo00<0P82000000020P8001@3oool8000001T0oooo00<0
P8200000000000004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0oooo00@0
P820000000000000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000kooooo203o
ool2000000030820P03oool0oooo00H0oooo00<0P8200000000000002@3oool2000000h0oooo0`00
000=0?ooo`030820P03oool0oooo00@0oooo2000000I0?ooo`030820P000000000000180oooo00<0
P8200000000000001P3oool00`20P8000000000000060?ooo`040820P000000000000820P?l0oooo
J03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`P0oooo00<0P82000000020P800203o
ool00`10@4000000000000090?ooo`80000000<0`<300?ooo`3oool02P3oool3000000030820P03o
ool0oooo0180oooo2000000I0?ooo`030820P000000000000180oooo00<0P8200000000000001P3o
ool00`20P8000000000000060?ooo`040820P000000000000820P?l0ooooJ03oool00`20P8000000
0000001;0?oooa3ooooo000>ooooo`T0oooo0P0000080?ooo`8000002P3oool00`20P80000000820
P00;0?ooo`040820P00000000000000001D0oooo2000000I0?ooo`030820P000000000000180oooo
00<0P8200000000000001P3oool00`20P8000000000000060?ooo`040820P000000000000820P?l0
ooooJ03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`T0oooo0P0000070?ooo`030820
P0000000000000X0oooo00<0P82000000020P8002`3oool01020P800000000000000000E0?ooo`P0
00006@3oool00`20P80000000000000B0?ooo`030820P0000000000000H0oooo00<0P82000000000
00001P3oool01020P800000000000020P83o0?ooofP0oooo00<0P820000000000000B`3oool@oooo
o`003_ooool:0?ooo`8000001P3oool3000000X0oooo00<0P8200000000000002`3oool3000001H0
oooo2000000I0?ooo`030820P000000000000180oooo00<0P8200000000000001P3oool00`20P800
0000000000060?ooo`040820P000000000000820P?l0ooooJ03oool00`20P80000000000001;0?oo
oa3ooooo000>ooooo`X0oooo0P0000000`30`<00oooo0?ooo`030?ooo`<000002P3oool00`20P800
00000000000;0?ooo`<000005P3oool8000001T0oooo00<0P8200000000000004P3oool00`20P800
0000000000060?ooo`030820P0000000000000H0oooo00@0P820000000000000P820o`3ooomX0?oo
o`030820P0000000000004/0oooo4?ooool000kooooo2P3oool00`20P80000000820P0050?ooo`<0
00002P3oool00`20P80000000000000;0?ooo`<000005P3oool8000001T0oooo00<0P82000000000
00004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0oooo00@0P82000000000
0000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000kooooo2P3oool00`20P800
00000820P0050?ooo`<000002P3oool00`20P80000000000000;0?ooo`<000005P3oool8000001T0
oooo00<0P8200000000000004P3oool00`20P8000000000000060?ooo`030820P0000000000000H0
oooo00@0P820000000000000P820o`3ooomX0?ooo`030820P0000000000004/0oooo4?ooool000ko
oooo2P3oool00`30`<000000000000050?ooo`<000002P3oool00`20P80000000000000;0?ooo`<0
00005P3oool8000001T0oooo00<0P8200000000000004P3oool01020P800000000000020P8050?oo
o`030410@0000000@4100080P820103oool01010@400000000000020P83o0?ooofP0oooo00<0P820
000000000000B`3oool@ooooo`003_ooool;0?ooo`8000001@3oool3000000X0oooo00<0P8200000
000000002`3oool3000001H0oooo2000000I0?ooo`030820P000000000000180oooo00D0P8200000
00000000oooo000000030?ooo`<0000000@0P8200?ooo`000000P8200P3oool400000?l0ooooJ@3o
ool00`20P80000000000001;0?oooa3ooooo000>ooooo``0oooo0P0000040?ooo`<000002P3oool0
0`20P80000000000000;0?ooo`040410@000000000000820P1D0oooo2000000I0?ooo`030820P000
000000000100oooo0P20P803000000030?ooo`30`<00000000D0000000@0`<300?ooo`3oool0@410
1@0000000`20P800oooo0?ooo`3o0?ooofL0oooo00<0P820000000000000B`3oool@ooooo`003_oo
ool<0?ooo`8000001@3oool2000000X0oooo00<0P82000000020P8002`3oool01020P80000000000
0000000>0?ooo`030820P03oool0oooo00@0oooo2000000I0?ooo`030820P0000000000001@0oooo
00<000000?ooo`3oool00P3oool3000000H0oooo0`00003o0?ooof/0oooo00<0P820000000000000
B`3oool@ooooo`003_ooool<0?ooo`030820P0000000000000@0oooo0`0000090?ooo`80000000<0
P8200?ooo`3oool02@3oool01@30`<000000000000000000`<3000d0oooo00<0P8200?ooo`3oool0
103oool8000001T0oooo00<0P820000000000000o`3ooon@0?ooo`030820P0000000000004/0oooo
4?ooool000kooooo00<000000?ooo`3oool02@3oool01020P800000000000020P8030?ooo`030820
P0000000000000T0oooo0P00000=0?ooo`<0000000<0P8200?ooo`3oool02`3oool00`000000oooo
0?ooo`040?ooo`P000006@3oool00`20P80000000000003o0?oooi00oooo00<0P820000000000000
B`3oool@ooooo`003_ooool00`000000P8200?ooo`0:0?ooo`80000000D0P8200?ooo`3oool0oooo
0820P002000000T0oooo0P00000>0?ooo`<00000303oool2000000H0oooo2000000I0?ooo`030820
P000000000000?l0ooooT03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`030?ooo`00
0000P82000X0oooo00<0P82000000010@400103oool2000000030820P03oool0oooo00D0oooo0P00
000?0?ooo`050<30`0000000000000000020P8002@3oool00`30`<000000000000060?ooo`P00000
5P3oool01020P800oooo0?ooo`20P80200000?l0ooooT03oool00`20P80000000000001;0?oooa3o
oooo000>ooooo`030?ooo`20P800000000d000001@3oool2000000H0oooo00<0P82000000020P800
4@3oool3000000030820P03oool0oooo00D0oooo100000060?ooo`P000005`3oool500000?l0oooo
T03oool00`20P80000000000001;0?oooa3ooooo000>ooooo`030?ooo`30`<00000000d0000000<0
P8200?ooo`3oool00`3oool00`10@40000000<30`0030?ooo`030820P0000000P8200180oooo00<0
`<300820P00000000P0000050820P080000000<0@4100820P00000001P3oool8000001P0oooo00@0
P8200410@00000000000o`3ooon@0?ooo`030820P0000000000004/0oooo4?ooool000kooooo0P3o
ool?000000L0oooo1@00000H0?ooo`H00000103oool00`20P800oooo0?ooo`040?ooo`P000006`3o
ool00`20P800oooo0?ooo`3o0?ooohh0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo
2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool800000?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodH0oooo2000003o0?oooj`0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom60?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0
oooo4?ooool000koooooAP3oool800000?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodH0oooo2000003o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom6
0?ooo`P00000o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooAP3oool80000
0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800
oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3o
ool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>
ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000503oool6
000001<0oooo1`0000020?ooo`L000000P3oool7000000D0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000B0?ooo`050820P00000000000
00000010@4001020P8000`10@400P8200<30`00@0?ooo`050820P0000000000000000030`<00103o
ool01@30`<000000000000000000`<3000@0oooo00D0`<3000000000000000000820P0060?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000
4P3oool00`20P8000000000000070?ooo`8000004@3oool3000000H0oooo0`0000060?ooo`<00000
1`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000001d0oooo00<0@41000000020P8003`3oool3000000H0oooo0`0000060?ooo`<000001`3o
ool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000
000001h0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`000007
0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000
000000007P3oool2000000030820P03oool0oooo00`0oooo0`0000060?ooo`<000001P3oool30000
00L0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P800
00000000000N0?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<000001`3oool@ooooo`00
3_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000001h0oooo
0`00000>0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000007@3oool01020P80000000000
0000000>0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000007@3oool3000000030820P03o
ool0oooo00`0oooo0`0000060?ooo`<000001P3oool3000000L0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000J0?ooo`80P82010000000
0`30`<00oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`0000070?oooa3ooooo000>oooo
odT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P8200000000000005P3oool90000
0100oooo0`0000060?ooo`<000001P3oool3000000L0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0?l0oooo[03oool00`20P80000000000000H0?ooo`060820P010@40000000000
0020P800`<304@3oool3000000030<30`03oool0oooo0080oooo00<0`<300000000000000P20P804
0?ooo`040<30`00000000000000000L0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0?l0oooo[03oool00`20P80000000000000K0?ooo`8000004P3oool3000000030820P0000000
oooo0080oooo0`0000000`3oool0P820000000030?ooo`<00000203oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000001/0oooo00<0P8200000
000000003`3oool5000000030?ooo`000000000000D000000P3oool7000000P0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000L0?ooo`03
0820P0000000P82000l0oooo0P20P8001@10@40000000?ooo`3oool0P82000@0000000H0`<300?oo
o`3oool0oooo0820P010@403000000030<30`03oool0oooo00H0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000M0?ooo`<00000:`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P00000000000
0180oooo00<0`<300?ooo`3oool0203oool3000002/0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0?l0oooo[03oool00`20P80000000000000C0?ooo`030000003oool0oooo00L0
oooo0`00000[0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo
00<0P8200000000000004`3oool00`20P800@4100?ooo`050?ooo`050<30`0000000000000000020
P800:`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820
P0000000000001@0oooo0P0000001020P800oooo0?ooo`3oool5000002`0oooo4?ooool000kooooo
B@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000000E0?ooo`T00000
;@3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000001H0oooo00<0P8200000000000000`0000000`20P800`<300?ooo`0/0?oooa3ooooo000>
ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P00000000000
04/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P800
00000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo
00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3o
oon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80
000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000kooooo
B@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo
000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3o
ool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0
o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03o
ool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P000000
0`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000
B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P000
0000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool0
0`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3o
ool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820
P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom9
0?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool0
00koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oo
oa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0oooo00<0P82000000000
0000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820
P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03o
ool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o
0?oooc`0oooo1P00000C0?ooo`L000000P3oool700000080oooo1`00000n0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo>P3oool00`20
P800000000000002000000@0P82000<0@4100820P030`<00403oool01@30`<000000000000000000
`<3000@0oooo00D0`<3000000000000000000820P0040?ooo`050<30`0000000000000000020P800
?`3oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?oo
o`3o0?ooocX0oooo00<0P8200000000000001`3oool200000140oooo0`0000060?ooo`<000001P3o
ool300000400oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P820
0?ooo`3oool0o`3ooom50?ooo`030410@0000000P82000l0oooo0`0000060?ooo`<000001P3oool3
00000400oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0o`3ooom60?ooo`80000000<0P8200?ooo`3oool0303oool3000000H0oooo0`0000060?oo
o`<00000@03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800
oooo0?ooo`3o0?ooodH0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0
oooo0`0000100?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820
P03oool0oooo0?l0ooooAP3oool3000000h0oooo0`0000060?ooo`<000001P3oool300000400oooo
00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3o
oom60?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?ooodD0oooo00@0P820
00000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20P80000000000
001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?ooodD0oooo0`000000
0`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo0`0000100?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo@P3oool20820
P0@0000000<0`<300?ooo`3oool0303oool3000000H0oooo0`0000060?ooo`<00000@03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooch0
oooo2@00000@0?ooo`<000001P3oool3000000H0oooo0`0000100?ooo`030820P0000000000004/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo@03oool01P20P800@410
000000000000P8200<30`140oooo0`0000000`30`<00oooo0?ooo`020?ooo`030<30`00000000000
0080P82000D0`<300?ooo`3oool0oooo0<30`00300000400oooo00<0P820000000000000B`3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooom30?ooo`8000004P3oool30000
00030820P0000000oooo0080oooo0`0000020?ooo`040000003oool0oooo0?ooo`<0000000<0P820
0?ooo`3oool0?P3oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3o0?oood<0oooo00<0P8200000000000003`3oool5000000030?ooo`0000000000
00D000000P3oool00`20P800000000000004000000030820P03oool0oooo03h0oooo00<0P8200000
00000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooom40?ooo`03
0820P0000000P82000l0oooo00@0`<300820P010@40000000P3oool00`20P800@410000000020000
00060<30`03oool0oooo0?ooo`20P800@4100`0000000`20P800oooo0?ooo`0o0?ooo`030820P000
0000000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0ooooA@3oool3
000006@0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0o`3ooolj0?ooo`030<30`03oool0oooo00P0oooo0`00001T0?ooo`030820P00000000000
04/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo>`3oool00`000000
oooo0?ooo`070?ooo`<00000I03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo
0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo00<0P8200410@03oool01@3oool01@30`<000000
000000000000P82006@0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0o`3oooll0?ooo`<000000`3oool5000006D0oooo00<0P820000000000000
B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0o`3ooolm0?ooo`T00000IP3o
ool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o
0?oooch0oooo00<0P8200410@00000000`0000000`20P800`<300?ooo`1U0?ooo`030820P0000000
000004/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20
P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3o0?oooj`0
oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0
o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000koooooB@3oool2000000030820P03o
ool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3ooooo000>ooooodT0oooo0P000000
0`20P800oooo0?ooo`3o0?oooj`0oooo00<0P820000000000000B`3oool@ooooo`003_oooom90?oo
o`80000000<0P8200?ooo`3oool0o`3ooon/0?ooo`030820P0000000000004/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0?l0oooo[03oool00`20P80000000000001;0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooom@00000B`3oool@ooooo`003_oo
oom90?ooo`80000000<0P8200?ooo`3oool0fP3ooooD000004/0oooo4?ooool000koooooB@3oool2
000000030820P03oool0oooo0=X0ooooe000001;0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0@4100820P020P800c`20P81;0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20
P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0o`3ooolK0?oooa3o
oooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooolK0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool00P3oool00`30`<00P8200000000500000080P8204@3oool00`20P80000000000
0002000000060410@020P800oooo0?ooo`20P800@4100`0000001P10@400P8200?ooo`3oool0P820
0410@0@0000000<0P8200?ooo`3oool0hP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0fP3oool2000000030820P03oool0oooo0080oooo00D0P82000000000000000000820P004
0?ooo`030820P0000000P8200140oooo0`0000060?ooo`<000001P3oool300000>H0oooo4?ooool0
00koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`020?oo
o`030<30`020P800P82000L0oooo00<0P82000000020P800403oool3000000H0oooo0`0000060?oo
o`<00000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool200000003
0820P03oool0oooo00d0oooo00<0P8200000000000003`3oool3000000H0oooo0`0000060?ooo`<0
0000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820
P03oool0oooo00h0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3oool3000000H0oooo
0`00003V0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0
P8200?ooo`3oool03P3oool2000000030410@03oool0oooo00`0oooo0`0000060?ooo`<000001P3o
ool300000>H0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P000000
0`20P800oooo0?ooo`0>0?ooo`<000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00d0oooo00@0`<3000000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00d0oooo00@0P82000000000000000003P3oool3000000H0oooo0`0000060?ooo`<00000iP3oool@
ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo
00`0oooo00D0P82000000000000000000820P00>0?ooo`<000001P3oool3000000H0oooo0`00003V
0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?oo
o`3oool02P3oool6000000l0oooo0`0000060?ooo`<000001P3oool300000>H0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`060?ooo`T0
0000403oool3000000H0oooo0`0000060?ooo`<00000iP3oool@ooooo`003_oooom90?ooo`800000
00<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo00P0oooo00H0P8200410@0000000
00000820P030`<0A0?ooo`<0000000<0`<300?ooo`3oool00P3oool00`30`<000000000000020820
P0@0oooo00@0`<300000000000000000iP3oool@ooooo`003_oooom90?ooo`80000000<0P8200?oo
o`3oool0fP3oool2000000030820P03oool0oooo00/0oooo0P00000B0?ooo`<0000000<0P8200000
003oool00P3oool3000000030?ooo`20P800000000<0oooo0`00003W0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool02`3oool00`30`<00
00000000000?0?ooo`030820P000000000000080000000<0oooo0820P0000000100000001010@400
oooo0?ooo`20P805000000030410@03oool0oooo0>D0oooo4?ooool000koooooB@3oool200000003
0820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`8000004@3oool00`20P800
00000?ooo`020?ooo`@000001@3oool01020P800000000000000003X0?oooa3ooooo000>ooooodT0
oooo0P0000000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool03@3oool300000?l0
oooo2`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820
P03oool0oooo0080oooo00<0P8200?ooo`3oool0203oool300000?l0oooo2`3oool@ooooo`003_oo
oom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2000000030820P03oool0oooo00<0oooo00<0
00000<30`03oool01P3oool01020P800000000000000003o0?ooo`/0oooo4?ooool000koooooB@3o
ool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`040?ooo`030000003o
ool0oooo00@0oooo00@0P8200000000000000000o`3oool<0?oooa3ooooo000>ooooodT0oooo0P00
00000`20P800oooo0?ooo`3J0?ooo`80000000<0P8200?ooo`3oool0103oool2000000040820P03o
ool0oooo0?ooo`D00000o`3oool<0?oooa3ooooo000>ooooodT0oooo0P0000000`20P800oooo0?oo
o`3J0?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P800000000000005000000030410@03o
ool0oooo0?l0oooo2`3oool@ooooo`003_oooom90?ooo`80000000<0P8200?ooo`3oool0fP3oool2
000000030820P03oool0oooo00L0oooo1@00003o0?ooo`l0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0
oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool20000
00030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000ko
ooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo0?ooo`3o0?oooa/0
oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3oool2000000030820P03oool0oooo0=X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool000koooooB@3ooooQ000000030820P03oool0
oooo0?l0oooo6`3oool@ooooo`003_oooom90?ooon40000000<0P8200?ooo`3oool0o`3ooolK0?oo
oa3ooooo000>ooooodT0ooooh@0000000`20P800oooo0?ooo`3o0?oooa/0oooo4?ooool00?oooooo
oooooomWooooo`00ooooooooooooofOooooo003oooooooooooooIoooool00?oooooooooooomWoooo
o`00ooooooooooooofOooooo003oooooooooooooIoooool00?oooooooooooomWooooo`00oooooooo
ooooofOooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{204.375, 112.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.9 Exercise (14).", "Caption",
  CellTags->"Fig. 6.9"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A  grounded square box, with an interior defined by  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 1\)]],
  ", is cut into two sections by a conducting plate at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2\)]],
  ". The plate is held at potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\_o\), "=", 
          RowBox[{"1", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The plate has a gap at the center, leaving an opening at ",
  Cell[BoxData[
      \(TraditionalForm\`1/4\  < \ y < \ 3/4\)]],
  ". Find the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " in the box using a 20 by 20 grid. Solve this problem using simultaneous \
overrelaxation and add conditions to the recursion equation for the interior \
points that avoids the points that fall on the central plate.  The solution \
for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi](x, y)\)\(\ \)\)\)]],
  " is shown in Fig. ",
  ButtonBox["6.10",
    ButtonData:>"Fig. 6.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01569 .31789 -24 -2.78694 ]
[.01569 .31789 0 6.21306 ]
[.00698 .37252 -18 -2.83329 ]
[.00698 .37252 0 6.16671 ]
[-0.00205 .42908 -24 -2.88145 ]
[-0.00205 .42908 0 6.11855 ]
[-0.0114 .48769 -6 -2.93153 ]
[-0.0114 .48769 0 6.06847 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02796 .31322 m
.03409 .31089 L
s
[(0.25)] .01569 .31789 1 -0.38068 Mshowa
.01928 .36796 m
.02543 .36568 L
s
[(0.5)] .00698 .37252 1 -0.37038 Mshowa
.0103 .42464 m
.01647 .42242 L
s
[(0.75)] -0.00205 .42908 1 -0.35968 Mshowa
.00099 .48337 m
.00719 .48121 L
s
[(1)] -0.0114 .48769 1 -0.34855 Mshowa
.125 Mabswid
.03468 .27077 m
.03835 .26934 L
s
.03302 .28127 m
.03669 .27985 L
s
.03134 .29185 m
.03502 .29044 L
s
.02965 .3025 m
.03333 .30109 L
s
.02624 .32402 m
.02993 .32263 L
s
.02452 .33489 m
.02821 .3335 L
s
.02279 .34584 m
.02647 .34446 L
s
.02104 .35686 m
.02473 .35548 L
s
.01751 .37914 m
.0212 .37778 L
s
.01573 .39039 m
.01942 .38904 L
s
.01393 .40173 m
.01763 .40038 L
s
.01212 .41314 m
.01582 .4118 L
s
.00846 .43622 m
.01217 .43489 L
s
.00662 .44788 m
.01033 .44656 L
s
.00475 .45962 m
.00847 .45831 L
s
.00288 .47145 m
.00659 .47015 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.649 .738 .914 r
.39889 .59791 .40512 .60371 .41558 .60058 .40936 .59516 Mtetra
.647 .751 .925 r
.40936 .59516 .41558 .60058 .42607 .59743 .41987 .59239 Mtetra
.645 .765 .936 r
.41987 .59239 .42607 .59743 .4366 .59427 .43042 .58962 Mtetra
.64 .78 .948 r
.43042 .58962 .4366 .59427 .44718 .59109 .44102 .58686 Mtetra
.634 .795 .96 r
.44102 .58686 .44718 .59109 .4578 .58791 .45166 .58411 Mtetra
.626 .812 .971 r
.45166 .58411 .4578 .58791 .46846 .58471 .46234 .58137 Mtetra
.613 .828 .983 r
.46234 .58137 .46846 .58471 .47916 .5815 .47307 .57866 Mtetra
.595 .845 .992 r
.47307 .57866 .47916 .5815 .4899 .57828 .48384 .57598 Mtetra
.567 .86 .997 r
.48384 .57598 .4899 .57828 .50069 .57504 .49466 .57334 Mtetra
.524 .868 .991 r
.49466 .57334 .50069 .57504 .51152 .57179 .50553 .57077 Mtetra
.459 .862 .965 r
.50553 .57077 .51152 .57179 .52239 .56853 .51644 .56828 Mtetra
.36 .827 .902 r
.51644 .56828 .52239 .56853 .5333 .56526 .5274 .5659 Mtetra
.223 .744 .782 r
.5274 .5659 .5333 .56526 .54426 .56197 .53842 .56364 Mtetra
0 0 0 r
.53842 .56364 .54426 .56197 .55526 .55867 .54948 .56158 Mtetra
.127 0 0 r
.54948 .56158 .55526 .55867 .56631 .55536 .5606 .55976 Mtetra
.276 0 0 r
.5606 .55976 .56631 .55536 .5774 .55203 .57178 .55826 Mtetra
.394 0 .034 r
.57178 .55826 .5774 .55203 .58853 .54869 .58303 .55733 Mtetra
.467 .054 .173 r
.58303 .55733 .58853 .54869 .59971 .54534 .59435 .55688 Mtetra
.53 .157 .279 r
.59435 .55688 .59971 .54534 .61094 .54197 .60576 .55767 Mtetra
.567 .231 .358 r
.60576 .55767 .61094 .54197 .62221 .53859 .61729 .55978 Mtetra
.598 .289 .416 r
.61729 .55978 .62221 .53859 .63352 .53519 .62897 .56416 Mtetra
.636 .346 .461 r
.62897 .56416 .63352 .53519 .64488 .53178 .64093 .57386 Mtetra
.704 .426 .501 r
.64093 .57386 .64488 .53178 .65629 .52836 .65377 .60321 Mtetra
.65 .399 .525 r
.65377 .60321 .65629 .52836 .66774 .52493 .66676 .62952 Mtetra
.559 .333 .529 r
.66676 .62952 .66774 .52493 .67924 .52148 .67869 .62616 Mtetra
.463 .257 .514 r
.67869 .62616 .67924 .52148 .69079 .51801 .68923 .59304 Mtetra
.39 .191 .485 r
.68923 .59304 .69079 .51801 .70238 .51453 .69945 .55673 Mtetra
.424 .19 .452 r
.69945 .55673 .70238 .51453 .71403 .51104 .71057 .54008 Mtetra
.42 .159 .41 r
.71057 .54008 .71403 .51104 .72572 .50753 .72197 .52874 Mtetra
.397 .11 .355 r
.72197 .52874 .72572 .50753 .73745 .50401 .73349 .51967 Mtetra
.358 .039 .281 r
.73349 .51967 .73745 .50401 .74924 .50048 .74512 .51192 Mtetra
.311 0 .182 r
.74512 .51192 .74924 .50048 .76108 .49693 .75685 .50541 Mtetra
.231 0 .053 r
.75685 .50541 .76108 .49693 .77296 .49336 .76864 .49937 Mtetra
.127 0 0 r
.76864 .49937 .77296 .49336 .78489 .48978 .78051 .4939 Mtetra
0 0 0 r
.78051 .4939 .78489 .48978 .79688 .48619 .79245 .48874 Mtetra
.79245 .48874 .79688 .48619 .80891 .48258 .80444 .48383 Mtetra
.323 .801 .731 r
.80444 .48383 .80891 .48258 .82099 .47895 .8165 .47911 Mtetra
.447 .882 .862 r
.8165 .47911 .82099 .47895 .83313 .47531 .82861 .47451 Mtetra
.533 .914 .938 r
.82861 .47451 .83313 .47531 .84531 .47166 .84078 .47003 Mtetra
.588 .916 .973 r
.84078 .47003 .84531 .47166 .85755 .46799 .853 .46562 Mtetra
.622 .903 .985 r
.853 .46562 .85755 .46799 .86983 .4643 .86528 .46126 Mtetra
.643 .884 .985 r
.86528 .46126 .86983 .4643 .88217 .4606 .87761 .45695 Mtetra
.656 .864 .978 r
.87761 .45695 .88217 .4606 .89457 .45688 .88999 .45267 Mtetra
.664 .843 .969 r
.88999 .45267 .89457 .45688 .90701 .45315 .90242 .44841 Mtetra
.669 .824 .958 r
.90242 .44841 .90701 .45315 .91951 .4494 .91491 .44416 Mtetra
.672 .806 .947 r
.91491 .44416 .91951 .4494 .93206 .44563 .92745 .43992 Mtetra
.674 .79 .936 r
.92745 .43992 .93206 .44563 .94466 .44185 .94005 .43567 Mtetra
.675 .774 .925 r
.94005 .43567 .94466 .44185 .95732 .43805 .95269 .43142 Mtetra
.676 .76 .914 r
.95269 .43142 .95732 .43805 .97003 .43424 .96539 .42716 Mtetra
.634 .733 .92 r
.39262 .59207 .39889 .59791 .40936 .59516 .4031 .58969 Mtetra
.631 .746 .931 r
.4031 .58969 .40936 .59516 .41987 .59239 .41362 .5873 Mtetra
.627 .76 .942 r
.41362 .5873 .41987 .59239 .43042 .58962 .42419 .58492 Mtetra
.62 .774 .954 r
.42419 .58492 .43042 .58962 .44102 .58686 .4348 .58256 Mtetra
.612 .788 .966 r
.4348 .58256 .44102 .58686 .45166 .58411 .44546 .58023 Mtetra
.6 .803 .978 r
.44546 .58023 .45166 .58411 .46234 .58137 .45617 .57795 Mtetra
.583 .818 .988 r
.45617 .57795 .46234 .58137 .47307 .57866 .46692 .57572 Mtetra
.558 .831 .997 r
.46692 .57572 .47307 .57866 .48384 .57598 .47772 .57358 Mtetra
.522 .841 .999 r
.47772 .57358 .48384 .57598 .49466 .57334 .48857 .57153 Mtetra
.467 .841 .989 r
.48857 .57153 .49466 .57334 .50553 .57077 .49948 .56962 Mtetra
.388 .824 .955 r
.49948 .56962 .50553 .57077 .51644 .56828 .51043 .56785 Mtetra
.27 .771 .879 r
.51043 .56785 .51644 .56828 .5274 .5659 .52144 .56632 Mtetra
.12 .671 .746 r
.52144 .56632 .5274 .5659 .53842 .56364 .5325 .56503 Mtetra
.059 0 0 r
.5325 .56503 .53842 .56364 .54948 .56158 .54362 .56411 Mtetra
.228 0 0 r
.54362 .56411 .54948 .56158 .5606 .55976 .55481 .56365 Mtetra
.363 0 0 r
.55481 .56365 .5606 .55976 .57178 .55826 .56607 .56376 Mtetra
.471 0 .046 r
.56607 .56376 .57178 .55826 .58303 .55733 .57742 .56484 Mtetra
.532 .103 .171 r
.57742 .56484 .58303 .55733 .59435 .55688 .58885 .5668 Mtetra
.593 .203 .273 r
.58885 .5668 .59435 .55688 .60576 .55767 .60042 .57072 Mtetra
.628 .271 .345 r
.60042 .57072 .60576 .55767 .61729 .55978 .61213 .57681 Mtetra
.66 .328 .4 r
.61213 .57681 .61729 .55978 .62897 .56416 .62406 .58639 Mtetra
.702 .389 .444 r
.62406 .58639 .62897 .56416 .64093 .57386 .63637 .60352 Mtetra
.785 .486 .482 r
.63637 .60352 .64093 .57386 .65377 .60321 .64989 .64867 Mtetra
.731 .451 .504 r
.64989 .64867 .65377 .60321 .66676 .62952 .66361 .6893 Mtetra
.547 .304 .498 r
.66361 .6893 .66676 .62952 .67869 .62616 .67581 .68599 Mtetra
.216 .043 .418 r
.67581 .68599 .67869 .62616 .68923 .59304 .686 .6386 Mtetra
0 0 .312 r
.686 .6386 .68923 .59304 .69945 .55673 .6957 .58645 Mtetra
.205 0 .343 r
.6957 .58645 .69945 .55673 .71057 .54008 .70661 .56234 Mtetra
.242 0 .308 r
.70661 .56234 .71057 .54008 .72197 .52874 .71785 .54576 Mtetra
.225 0 .246 r
.71785 .54576 .72197 .52874 .73349 .51967 .72927 .53266 Mtetra
.181 0 .16 r
.72927 .53266 .73349 .51967 .74512 .51192 .7408 .52172 Mtetra
.136 0 .053 r
.7408 .52172 .74512 .51192 .75685 .50541 .75246 .51274 Mtetra
.038 0 0 r
.75246 .51274 .75685 .50541 .76864 .49937 .7642 .50462 Mtetra
0 0 0 r
.7642 .50462 .76864 .49937 .78051 .4939 .77603 .49748 Mtetra
.77603 .49748 .78051 .4939 .79245 .48874 .78793 .49091 Mtetra
.34 .792 .65 r
.78793 .49091 .79245 .48874 .80444 .48383 .7999 .48479 Mtetra
.457 .883 .797 r
.7999 .48479 .80444 .48383 .8165 .47911 .81193 .47904 Mtetra
.546 .928 .893 r
.81193 .47904 .8165 .47911 .82861 .47451 .82403 .47353 Mtetra
.603 .938 .947 r
.82403 .47353 .82861 .47451 .84078 .47003 .83618 .46825 Mtetra
.639 .93 .971 r
.83618 .46825 .84078 .47003 .853 .46562 .84839 .46312 Mtetra
.66 .912 .979 r
.84839 .46312 .853 .46562 .86528 .46126 .86066 .45811 Mtetra
.673 .89 .977 r
.86066 .45811 .86528 .46126 .87761 .45695 .87298 .4532 Mtetra
.68 .869 .97 r
.87298 .4532 .87761 .45695 .88999 .45267 .88536 .44837 Mtetra
.685 .848 .961 r
.88536 .44837 .88999 .45267 .90242 .44841 .89779 .44359 Mtetra
.687 .829 .951 r
.89779 .44359 .90242 .44841 .91491 .44416 .91027 .43884 Mtetra
.688 .811 .941 r
.91027 .43884 .91491 .44416 .92745 .43992 .92281 .43413 Mtetra
.688 .794 .93 r
.92281 .43413 .92745 .43992 .94005 .43567 .93539 .42943 Mtetra
.688 .779 .92 r
.93539 .42943 .94005 .43567 .95269 .43142 .94803 .42473 Mtetra
.688 .765 .91 r
.94803 .42473 .95269 .43142 .96539 .42716 .96071 .42002 Mtetra
.617 .729 .926 r
.3863 .58619 .39262 .59207 .4031 .58969 .39679 .58417 Mtetra
.614 .741 .937 r
.39679 .58417 .4031 .58969 .41362 .5873 .40732 .58215 Mtetra
.608 .754 .948 r
.40732 .58215 .41362 .5873 .42419 .58492 .4179 .58015 Mtetra
.6 .767 .959 r
.4179 .58015 .42419 .58492 .4348 .58256 .42853 .57818 Mtetra
.589 .78 .971 r
.42853 .57818 .4348 .58256 .44546 .58023 .43921 .57627 Mtetra
.573 .793 .982 r
.43921 .57627 .44546 .58023 .45617 .57795 .44994 .57442 Mtetra
.552 .805 .992 r
.44994 .57442 .45617 .57795 .46692 .57572 .46072 .57267 Mtetra
.521 .815 .999 r
.46072 .57267 .46692 .57572 .47772 .57358 .47155 .57103 Mtetra
.477 .819 .999 r
.47155 .57103 .47772 .57358 .48857 .57153 .48243 .56955 Mtetra
.413 .811 .984 r
.48243 .56955 .48857 .57153 .49948 .56962 .49336 .56826 Mtetra
.323 .783 .944 r
.49336 .56826 .49948 .56962 .51043 .56785 .50435 .56719 Mtetra
.193 .717 .859 r
.50435 .56719 .51043 .56785 .52144 .56632 .5154 .56645 Mtetra
.037 .607 .721 r
.5154 .56645 .52144 .56632 .5325 .56503 .52651 .56605 Mtetra
.14 0 0 r
.52651 .56605 .5325 .56503 .54362 .56411 .53769 .56616 Mtetra
.3 0 0 r
.53769 .56616 .54362 .56411 .55481 .56365 .54894 .5669 Mtetra
.424 0 0 r
.54894 .5669 .55481 .56365 .56607 .56376 .56027 .5684 Mtetra
.523 .035 .038 r
.56027 .5684 .56607 .56376 .57742 .56484 .57169 .57112 Mtetra
.581 .134 .154 r
.57169 .57112 .57742 .56484 .58885 .5668 .58323 .57502 Mtetra
.637 .228 .252 r
.58323 .57502 .58885 .5668 .60042 .57072 .59491 .58117 Mtetra
.672 .293 .32 r
.59491 .58117 .60042 .57072 .61213 .57681 .60676 .58992 Mtetra
.704 .349 .372 r
.60676 .58992 .61213 .57681 .62406 .58639 .61885 .60252 Mtetra
.745 .409 .415 r
.61885 .60252 .62406 .58639 .63637 .60352 .63133 .62249 Mtetra
.831 .513 .452 r
.63133 .62249 .63637 .60352 .64989 .64867 .64496 .66983 Mtetra
.809 .492 .453 r
.64496 .66983 .64989 .64867 .66361 .6893 .6588 .71185 Mtetra
.495 .191 .38 r
.6588 .71185 .66361 .6893 .67581 .68599 .67113 .70855 Mtetra
0 0 0 r
.67113 .70855 .67581 .68599 .686 .6386 .68148 .65977 Mtetra
.797 .739 .215 r
.68148 .65977 .686 .6386 .6957 .58645 .69128 .60543 Mtetra
0 0 .083 r
.69128 .60543 .6957 .58645 .70661 .56234 .7022 .57846 Mtetra
0 0 .111 r
.7022 .57846 .70661 .56234 .71785 .54576 .71341 .55881 Mtetra
0 0 .059 r
.71341 .55881 .71785 .54576 .72927 .53266 .72478 .54301 Mtetra
0 0 0 r
.72478 .54301 .72927 .53266 .7408 .52172 .73628 .52978 Mtetra
.73628 .52978 .7408 .52172 .75246 .51274 .74791 .51881 Mtetra
.74791 .51881 .75246 .51274 .7642 .50462 .75962 .509 Mtetra
.75962 .509 .7642 .50462 .77603 .49748 .77143 .50041 Mtetra
.402 .81 .604 r
.77143 .50041 .77603 .49748 .78793 .49091 .78331 .49258 Mtetra
.501 .895 .745 r
.78331 .49258 .78793 .49091 .7999 .48479 .79526 .48537 Mtetra
.575 .942 .849 r
.79526 .48537 .7999 .48479 .81193 .47904 .80729 .47866 Mtetra
.63 .958 .914 r
.80729 .47866 .81193 .47904 .82403 .47353 .81937 .4723 Mtetra
.662 .953 .95 r
.81937 .4723 .82403 .47353 .83618 .46825 .83152 .46626 Mtetra
.683 .937 .966 r
.83152 .46626 .83618 .46825 .84839 .46312 .84372 .46044 Mtetra
.694 .915 .97 r
.84372 .46044 .84839 .46312 .86066 .45811 .85599 .45481 Mtetra
.699 .893 .968 r
.85599 .45481 .86066 .45811 .87298 .4532 .86831 .44932 Mtetra
.702 .871 .961 r
.86831 .44932 .87298 .4532 .88536 .44837 .88068 .44395 Mtetra
.703 .851 .953 r
.88068 .44395 .88536 .44837 .89779 .44359 .89311 .43866 Mtetra
.703 .832 .944 r
.89311 .43866 .89779 .44359 .91027 .43884 .90559 .43344 Mtetra
.703 .814 .934 r
.90559 .43344 .91027 .43884 .92281 .43413 .91812 .42826 Mtetra
.702 .798 .925 r
.91812 .42826 .92281 .43413 .93539 .42943 .9307 .42311 Mtetra
.701 .783 .915 r
.9307 .42311 .93539 .42943 .94803 .42473 .94332 .41797 Mtetra
.7 .769 .905 r
.94332 .41797 .94803 .42473 .96071 .42002 .956 .41282 Mtetra
.601 .724 .931 r
.37994 .58026 .3863 .58619 .39679 .58417 .39043 .5786 Mtetra
.596 .735 .942 r
.39043 .5786 .39679 .58417 .40732 .58215 .40098 .57693 Mtetra
.589 .747 .952 r
.40098 .57693 .40732 .58215 .4179 .58015 .41157 .5753 Mtetra
.579 .759 .964 r
.41157 .5753 .4179 .58015 .42853 .57818 .42222 .57371 Mtetra
.565 .77 .975 r
.42222 .57371 .42853 .57818 .43921 .57627 .43292 .57219 Mtetra
.547 .781 .985 r
.43292 .57219 .43921 .57627 .44994 .57442 .44366 .57076 Mtetra
.521 .79 .994 r
.44366 .57076 .44994 .57442 .46072 .57267 .45446 .56946 Mtetra
.486 .796 .999 r
.45446 .56946 .46072 .57267 .47155 .57103 .46532 .56831 Mtetra
.436 .795 .996 r
.46532 .56831 .47155 .57103 .48243 .56955 .47623 .56735 Mtetra
.365 .781 .979 r
.47623 .56735 .48243 .56955 .49336 .56826 .48719 .56664 Mtetra
.268 .745 .935 r
.48719 .56664 .49336 .56826 .50435 .56719 .49821 .56622 Mtetra
.134 .672 .848 r
.49821 .56622 .50435 .56719 .5154 .56645 .5093 .56619 Mtetra
0 .559 .712 r
.5093 .56619 .5154 .56645 .52651 .56605 .52045 .5666 Mtetra
.194 0 0 r
.52045 .5666 .52651 .56605 .53769 .56616 .53168 .56762 Mtetra
.346 0 0 r
.53168 .56762 .53769 .56616 .54894 .5669 .54298 .56939 Mtetra
.464 0 0 r
.54298 .56939 .54894 .5669 .56027 .5684 .55437 .57206 Mtetra
.558 .052 .01 r
.55437 .57206 .56027 .5684 .57169 .57112 .56587 .57605 Mtetra
.615 .148 .122 r
.56587 .57605 .57169 .57112 .58323 .57502 .57748 .58144 Mtetra
.667 .237 .217 r
.57748 .58144 .58323 .57502 .59491 .58117 .58925 .58907 Mtetra
.704 .301 .281 r
.58925 .58907 .59491 .58117 .60676 .58992 .6012 .5994 Mtetra
.735 .355 .331 r
.6012 .5994 .60676 .58992 .61885 .60252 .61338 .61333 Mtetra
.772 .408 .368 r
.61338 .61333 .61885 .60252 .63133 .62249 .6259 .63291 Mtetra
.857 .515 .404 r
.6259 .63291 .63133 .62249 .64496 .66983 .63933 .67352 Mtetra
.883 .507 .324 r
.63933 .67352 .64496 .66983 .6588 .71185 .65291 .70851 Mtetra
.603 .852 .991 r
.65291 .70851 .6588 .71185 .67113 .70855 .66529 .70519 Mtetra
.961 .786 .62 r
.66529 .70519 .67113 .70855 .68148 .65977 .67606 .66342 Mtetra
.997 .831 .555 r
.67606 .66342 .68148 .65977 .69128 .60543 .68633 .61581 Mtetra
.739 .817 .349 r
.68633 .61581 .69128 .60543 .7022 .57846 .6974 .58921 Mtetra
0 0 0 r
.6974 .58921 .7022 .57846 .71341 .55881 .70866 .56821 Mtetra
.70866 .56821 .71341 .55881 .72478 .54301 .72006 .55079 Mtetra
.72006 .55079 .72478 .54301 .73628 .52978 .73157 .53604 Mtetra
.73157 .53604 .73628 .52978 .74791 .51881 .74319 .52351 Mtetra
.74319 .52351 .74791 .51881 .75962 .509 .7549 .51238 Mtetra
.515 .863 .607 r
.7549 .51238 .75962 .509 .77143 .50041 .7667 .50256 Mtetra
.582 .925 .724 r
.7667 .50256 .77143 .50041 .78331 .49258 .77858 .49364 Mtetra
.635 .962 .818 r
.77858 .49364 .78331 .49258 .79526 .48537 .79053 .48546 Mtetra
.672 .975 .884 r
.79053 .48546 .79526 .48537 .80729 .47866 .80255 .47788 Mtetra
.698 .972 .925 r
.80255 .47788 .80729 .47866 .81937 .4723 .81463 .47074 Mtetra
.711 .957 .948 r
.81463 .47074 .81937 .4723 .83152 .46626 .82678 .464 Mtetra
.719 .937 .958 r
.82678 .464 .83152 .46626 .84372 .46044 .83899 .45753 Mtetra
.722 .914 .96 r
.83899 .45753 .84372 .46044 .85599 .45481 .85125 .4513 Mtetra
.722 .892 .957 r
.85125 .4513 .85599 .45481 .86831 .44932 .86357 .44527 Mtetra
.721 .871 .952 r
.86357 .44527 .86831 .44932 .88068 .44395 .87595 .43938 Mtetra
.72 .851 .944 r
.87595 .43938 .88068 .44395 .89311 .43866 .88837 .43361 Mtetra
.718 .833 .936 r
.88837 .43361 .89311 .43866 .90559 .43344 .90085 .42792 Mtetra
.716 .816 .927 r
.90085 .42792 .90559 .43344 .91812 .42826 .91338 .42229 Mtetra
.714 .8 .919 r
.91338 .42229 .91812 .42826 .9307 .42311 .92596 .41671 Mtetra
.712 .786 .91 r
.92596 .41671 .9307 .42311 .94332 .41797 .93858 .41114 Mtetra
.71 .772 .901 r
.93858 .41114 .94332 .41797 .956 .41282 .95124 .40556 Mtetra
.583 .718 .936 r
.37353 .57429 .37994 .58026 .39043 .5786 .38403 .57296 Mtetra
.578 .729 .946 r
.38403 .57296 .39043 .5786 .40098 .57693 .39458 .57164 Mtetra
.569 .739 .956 r
.39458 .57164 .40098 .57693 .41157 .5753 .40519 .57035 Mtetra
.558 .75 .967 r
.40519 .57035 .41157 .5753 .42222 .57371 .41585 .56912 Mtetra
.542 .759 .977 r
.41585 .56912 .42222 .57371 .43292 .57219 .42657 .56798 Mtetra
.521 .768 .987 r
.42657 .56798 .43292 .57219 .44366 .57076 .43733 .56695 Mtetra
.493 .774 .994 r
.43733 .56695 .44366 .57076 .45446 .56946 .44815 .56606 Mtetra
.454 .776 .998 r
.44815 .56606 .45446 .56946 .46532 .56831 .45903 .56536 Mtetra
.4 .771 .993 r
.45903 .56536 .46532 .56831 .47623 .56735 .46997 .56489 Mtetra
.326 .751 .974 r
.46997 .56489 .47623 .56735 .48719 .56664 .48096 .5647 Mtetra
.228 .712 .93 r
.48096 .5647 .48719 .56664 .49821 .56622 .49202 .56485 Mtetra
.095 .637 .847 r
.49202 .56485 .49821 .56622 .5093 .56619 .50314 .56546 Mtetra
0 .529 .721 r
.50314 .56546 .5093 .56619 .52045 .5666 .51433 .56657 Mtetra
.22 0 0 r
.51433 .56657 .52045 .5666 .53168 .56762 .52559 .56836 Mtetra
.367 0 0 r
.52559 .56836 .53168 .56762 .54298 .56939 .53694 .57098 Mtetra
.483 0 0 r
.53694 .57098 .54298 .56939 .55437 .57206 .54839 .57458 Mtetra
.575 .049 0 r
.54839 .57458 .55437 .57206 .56587 .57605 .55994 .57952 Mtetra
.637 .146 .068 r
.55994 .57952 .56587 .57605 .57748 .58144 .57162 .58599 Mtetra
.686 .229 .161 r
.57162 .58599 .57748 .58144 .58925 .58907 .58345 .5945 Mtetra
.725 .294 .225 r
.58345 .5945 .58925 .58907 .6012 .5994 .59547 .60558 Mtetra
.757 .346 .27 r
.59547 .60558 .6012 .5994 .61338 .61333 .60771 .61972 Mtetra
.787 .387 .296 r
.60771 .61972 .61338 .61333 .6259 .63291 .62022 .63737 Mtetra
.867 .488 .325 r
.62022 .63737 .6259 .63291 .63933 .67352 .63334 .66831 Mtetra
.857 .41 .017 r
.63334 .66831 .63933 .67352 .65291 .70851 .64656 .69371 Mtetra
.637 .584 .778 r
.64656 .69371 .65291 .70851 .66529 .70519 .65895 .69035 Mtetra
.86 .682 .659 r
.65895 .69035 .66529 .70519 .67606 .66342 .67019 .65813 Mtetra
.946 .774 .637 r
.67019 .65813 .67606 .66342 .68633 .61581 .68101 .6202 Mtetra
.952 .94 .616 r
.68101 .6202 .68633 .61581 .6974 .58921 .69229 .59551 Mtetra
.829 .921 .529 r
.69229 .59551 .6974 .58921 .70866 .56821 .70365 .57427 Mtetra
.744 .9 .513 r
.70365 .57427 .70866 .56821 .72006 .55079 .71511 .55605 Mtetra
.694 .899 .538 r
.71511 .55605 .72006 .55079 .73157 .53604 .72666 .54038 Mtetra
.669 .911 .586 r
.72666 .54038 .73157 .53604 .74319 .52351 .73831 .52673 Mtetra
.686 .944 .665 r
.73831 .52673 .74319 .52351 .7549 .51238 .75003 .51459 Mtetra
.697 .967 .738 r
.75003 .51459 .7549 .51238 .7667 .50256 .76185 .50379 Mtetra
.719 .986 .809 r
.76185 .50379 .7667 .50256 .77858 .49364 .77373 .49396 Mtetra
.734 .991 .864 r
.77373 .49396 .77858 .49364 .79053 .48546 .78569 .48495 Mtetra
.743 .985 .903 r
.78569 .48495 .79053 .48546 .80255 .47788 .79772 .47662 Mtetra
.749 .971 .928 r
.79772 .47662 .80255 .47788 .81463 .47074 .80981 .46878 Mtetra
.749 .952 .943 r
.80981 .46878 .81463 .47074 .82678 .464 .82196 .46139 Mtetra
.748 .931 .948 r
.82196 .46139 .82678 .464 .83899 .45753 .83418 .45434 Mtetra
.745 .909 .949 r
.83418 .45434 .83899 .45753 .85125 .4513 .84645 .44756 Mtetra
.741 .888 .947 r
.84645 .44756 .85125 .4513 .86357 .44527 .85877 .44101 Mtetra
.738 .868 .941 r
.85877 .44101 .86357 .44527 .87595 .43938 .87115 .43464 Mtetra
.734 .85 .935 r
.87115 .43464 .87595 .43938 .88837 .43361 .88358 .4284 Mtetra
.73 .833 .928 r
.88358 .4284 .88837 .43361 .90085 .42792 .89606 .42227 Mtetra
.727 .817 .92 r
.89606 .42227 .90085 .42792 .91338 .42229 .90859 .41622 Mtetra
.724 .802 .912 r
.90859 .41622 .91338 .42229 .92596 .41671 .92117 .41021 Mtetra
.722 .788 .904 r
.92117 .41021 .92596 .41671 .93858 .41114 .93379 .40423 Mtetra
.72 .775 .896 r
.93379 .40423 .93858 .41114 .95124 .40556 .94645 .39825 Mtetra
.566 .712 .94 r
.36707 .56828 .37353 .57429 .38403 .57296 .37758 .56726 Mtetra
.56 .722 .949 r
.37758 .56726 .38403 .57296 .39458 .57164 .38814 .56626 Mtetra
.55 .731 .959 r
.38814 .56626 .39458 .57164 .40519 .57035 .39876 .56529 Mtetra
.538 .74 .969 r
.39876 .56529 .40519 .57035 .41585 .56912 .40944 .5644 Mtetra
.52 .747 .978 r
.40944 .5644 .41585 .56912 .42657 .56798 .42017 .56361 Mtetra
.498 .754 .987 r
.42017 .56361 .42657 .56798 .43733 .56695 .43095 .56293 Mtetra
.468 .757 .993 r
.43095 .56293 .43733 .56695 .44815 .56606 .44179 .56243 Mtetra
.428 .756 .995 r
.44179 .56243 .44815 .56606 .45903 .56536 .45269 .56213 Mtetra
.374 .748 .99 r
.45269 .56213 .45903 .56536 .46997 .56489 .46365 .56209 Mtetra
.301 .726 .972 r
.46365 .56209 .46997 .56489 .48096 .5647 .47467 .56236 Mtetra
.207 .687 .933 r
.47467 .56236 .48096 .5647 .49202 .56485 .48576 .563 Mtetra
.084 .618 .862 r
.48576 .563 .49202 .56485 .50314 .56546 .49691 .56414 Mtetra
0 .521 .755 r
.49691 .56414 .50314 .56546 .51433 .56657 .50813 .56582 Mtetra
.211 0 0 r
.50813 .56582 .51433 .56657 .52559 .56836 .51944 .56821 Mtetra
.355 0 0 r
.51944 .56821 .52559 .56836 .53694 .57098 .53083 .57147 Mtetra
.475 0 0 r
.53083 .57147 .53694 .57098 .54839 .57458 .54232 .57574 Mtetra
.572 .017 0 r
.54232 .57574 .54839 .57458 .55994 .57952 .55392 .58134 Mtetra
.641 .118 0 r
.55392 .58134 .55994 .57952 .57162 .58599 .56565 .58846 Mtetra
.695 .203 .073 r
.56565 .58846 .57162 .58599 .58345 .5945 .57753 .59747 Mtetra
.738 .272 .141 r
.57753 .59747 .58345 .5945 .59547 .60558 .58959 .60883 Mtetra
.773 .326 .188 r
.58959 .60883 .59547 .60558 .60771 .61972 .60187 .62285 Mtetra
.8 .364 .211 r
.60187 .62285 .60771 .61972 .62022 .63737 .61438 .63956 Mtetra
.868 .467 .27 r
.61438 .63956 .62022 .63737 .63334 .66831 .62741 .66683 Mtetra
.852 .398 .108 r
.62741 .66683 .63334 .66831 .64656 .69371 .64052 .68867 Mtetra
.637 .8 .961 r
.64052 .68867 .64656 .69371 .65895 .69035 .65295 .68528 Mtetra
.933 .793 .683 r
.65295 .68528 .65895 .69035 .67019 .65813 .66442 .65659 Mtetra
.971 .826 .642 r
.66442 .65659 .67019 .65813 .68101 .6202 .67551 .6223 Mtetra
.97 .931 .676 r
.67551 .6223 .68101 .6202 .69229 .59551 .68694 .59852 Mtetra
.943 .959 .672 r
.68694 .59852 .69229 .59551 .70365 .57427 .69841 .57737 Mtetra
.907 .974 .682 r
.69841 .57737 .70365 .57427 .71511 .55605 .70994 .55884 Mtetra
.871 .985 .705 r
.70994 .55884 .71511 .55605 .72666 .54038 .72156 .54262 Mtetra
.844 .992 .738 r
.72156 .54262 .72666 .54038 .73831 .52673 .73325 .52827 Mtetra
.828 .998 .779 r
.73325 .52827 .73831 .52673 .75003 .51459 .74501 .51543 Mtetra
.814 1 .82 r
.74501 .51543 .75003 .51459 .76185 .50379 .75685 .5039 Mtetra
.806 .997 .857 r
.75685 .5039 .76185 .50379 .77373 .49396 .76876 .49337 Mtetra
.799 .988 .888 r
.76876 .49337 .77373 .49396 .78569 .48495 .78074 .4837 Mtetra
.791 .974 .91 r
.78074 .4837 .78569 .48495 .79772 .47662 .79278 .47473 Mtetra
.784 .958 .925 r
.79278 .47473 .79772 .47662 .80981 .46878 .80489 .46631 Mtetra
.776 .939 .934 r
.80489 .46631 .80981 .46878 .82196 .46139 .81706 .45837 Mtetra
.77 .919 .937 r
.81706 .45837 .82196 .46139 .83418 .45434 .82928 .45079 Mtetra
.763 .9 .938 r
.82928 .45079 .83418 .45434 .84645 .44756 .84157 .44352 Mtetra
.756 .881 .935 r
.84157 .44352 .84645 .44756 .85877 .44101 .8539 .4365 Mtetra
.751 .863 .931 r
.8539 .4365 .85877 .44101 .87115 .43464 .86629 .42968 Mtetra
.745 .846 .926 r
.86629 .42968 .87115 .43464 .88358 .4284 .87873 .42302 Mtetra
.741 .831 .92 r
.87873 .42302 .88358 .4284 .89606 .42227 .89122 .41647 Mtetra
.737 .816 .913 r
.89122 .41647 .89606 .42227 .90859 .41622 .90376 .41001 Mtetra
.734 .802 .906 r
.90376 .41001 .90859 .41622 .92117 .41021 .91634 .40361 Mtetra
.731 .79 .899 r
.91634 .40361 .92117 .41021 .93379 .40423 .92896 .39725 Mtetra
.729 .778 .892 r
.92896 .39725 .93379 .40423 .94645 .39825 .94162 .39088 Mtetra
.549 .706 .943 r
.36056 .56222 .36707 .56828 .37758 .56726 .37108 .5615 Mtetra
.542 .715 .952 r
.37108 .5615 .37758 .56726 .38814 .56626 .38166 .56079 Mtetra
.532 .723 .961 r
.38166 .56079 .38814 .56626 .39876 .56529 .39229 .56013 Mtetra
.518 .73 .97 r
.39229 .56013 .39876 .56529 .40944 .5644 .40297 .55954 Mtetra
.5 .736 .978 r
.40297 .55954 .40944 .5644 .42017 .56361 .41372 .55906 Mtetra
.477 .74 .986 r
.41372 .55906 .42017 .56361 .43095 .56293 .42452 .55872 Mtetra
.446 .741 .991 r
.42452 .55872 .43095 .56293 .44179 .56243 .43538 .55856 Mtetra
.406 .738 .992 r
.43538 .55856 .44179 .56243 .45269 .56213 .4463 .55862 Mtetra
.353 .727 .987 r
.4463 .55862 .45269 .56213 .46365 .56209 .45728 .55895 Mtetra
.283 .705 .97 r
.45728 .55895 .46365 .56209 .47467 .56236 .46833 .55962 Mtetra
.196 .667 .937 r
.46833 .55962 .47467 .56236 .48576 .563 .47944 .56068 Mtetra
.082 .605 .877 r
.47944 .56068 .48576 .563 .49691 .56414 .49062 .56224 Mtetra
0 .52 .788 r
.49062 .56224 .49691 .56414 .50813 .56582 .50188 .56438 Mtetra
.189 0 0 r
.50188 .56438 .50813 .56582 .51944 .56821 .51322 .56724 Mtetra
.327 0 0 r
.51322 .56724 .51944 .56821 .53083 .57147 .52465 .57096 Mtetra
.448 0 0 r
.52465 .57096 .53083 .57147 .54232 .57574 .53618 .5757 Mtetra
.55 0 0 r
.53618 .5757 .54232 .57574 .55392 .58134 .54782 .58169 Mtetra
.627 .075 0 r
.54782 .58169 .55392 .58134 .56565 .58846 .55959 .58914 Mtetra
.686 .16 0 r
.55959 .58914 .56565 .58846 .57753 .59747 .57151 .59831 Mtetra
.734 .231 .032 r
.57151 .59831 .57753 .59747 .58959 .60883 .5836 .60955 Mtetra
.772 .286 .075 r
.5836 .60955 .58959 .60883 .60187 .62285 .59589 .62306 Mtetra
.799 .322 .089 r
.59589 .62306 .60187 .62285 .61438 .63956 .60841 .63877 Mtetra
.871 .441 .179 r
.60841 .63877 .61438 .63956 .62741 .66683 .62136 .66357 Mtetra
.819 .338 0 r
.62136 .66357 .62741 .66683 .64052 .68867 .63441 .68313 Mtetra
.642 .785 .95 r
.63441 .68313 .64052 .68867 .65295 .68528 .64688 .67972 Mtetra
.923 .791 .697 r
.64688 .67972 .65295 .68528 .66442 .65659 .65852 .65325 Mtetra
.955 .811 .662 r
.65852 .65325 .66442 .65659 .67551 .6223 .66982 .6214 Mtetra
.959 .889 .717 r
.66982 .6214 .67551 .6223 .68694 .59852 .68138 .59859 Mtetra
.957 .923 .729 r
.68138 .59859 .68694 .59852 .69841 .57737 .69296 .57791 Mtetra
.944 .951 .747 r
.69296 .57791 .69841 .57737 .70994 .55884 .70459 .55946 Mtetra
.923 .97 .77 r
.70459 .55946 .70994 .55884 .72156 .54262 .71628 .54304 Mtetra
.902 .981 .794 r
.71628 .54304 .72156 .54262 .73325 .52827 .72803 .52831 Mtetra
.881 .985 .821 r
.72803 .52831 .73325 .52827 .74501 .51543 .73984 .51502 Mtetra
.862 .984 .848 r
.73984 .51502 .74501 .51543 .75685 .5039 .75172 .50298 Mtetra
.846 .978 .871 r
.75172 .50298 .75685 .5039 .76876 .49337 .76367 .49193 Mtetra
.831 .968 .891 r
.76367 .49193 .76876 .49337 .78074 .4837 .77568 .48174 Mtetra
.817 .955 .906 r
.77568 .48174 .78074 .4837 .79278 .47473 .78775 .47225 Mtetra
.805 .94 .916 r
.78775 .47225 .79278 .47473 .80489 .46631 .79988 .46334 Mtetra
.794 .923 .923 r
.79988 .46334 .80489 .46631 .81706 .45837 .81207 .45492 Mtetra
.784 .906 .926 r
.81207 .45492 .81706 .45837 .82928 .45079 .82431 .44688 Mtetra
.775 .889 .926 r
.82431 .44688 .82928 .45079 .84157 .44352 .83662 .43918 Mtetra
.768 .873 .925 r
.83662 .43918 .84157 .44352 .8539 .4365 .84897 .43174 Mtetra
.761 .857 .921 r
.84897 .43174 .8539 .4365 .86629 .42968 .86137 .42451 Mtetra
.755 .842 .917 r
.86137 .42451 .86629 .42968 .87873 .42302 .87383 .41745 Mtetra
.75 .828 .912 r
.87383 .41745 .87873 .42302 .89122 .41647 .88633 .41052 Mtetra
.746 .815 .906 r
.88633 .41052 .89122 .41647 .90376 .41001 .89887 .40368 Mtetra
.742 .802 .9 r
.89887 .40368 .90376 .41001 .91634 .40361 .91146 .39691 Mtetra
.739 .791 .894 r
.91146 .39691 .91634 .40361 .92896 .39725 .92409 .39018 Mtetra
.737 .78 .887 r
.92409 .39018 .92896 .39725 .94162 .39088 .93675 .38345 Mtetra
.533 .7 .946 r
.35401 .55612 .36056 .56222 .37108 .5615 .36453 .55566 Mtetra
.525 .708 .954 r
.36453 .55566 .37108 .5615 .38166 .56079 .37512 .55522 Mtetra
.515 .714 .962 r
.37512 .55522 .38166 .56079 .39229 .56013 .38576 .55483 Mtetra
.501 .72 .97 r
.38576 .55483 .39229 .56013 .40297 .55954 .39646 .55453 Mtetra
.482 .724 .977 r
.39646 .55453 .40297 .55954 .41372 .55906 .40722 .55433 Mtetra
.459 .727 .984 r
.40722 .55433 .41372 .55906 .42452 .55872 .41804 .55428 Mtetra
.429 .726 .988 r
.41804 .55428 .42452 .55872 .43538 .55856 .42892 .55442 Mtetra
.39 .721 .989 r
.42892 .55442 .43538 .55856 .4463 .55862 .43986 .55479 Mtetra
.34 .709 .984 r
.43986 .55479 .4463 .55862 .45728 .55895 .45086 .55543 Mtetra
.276 .688 .97 r
.45086 .55543 .45728 .55895 .46833 .55962 .46193 .55643 Mtetra
.198 .654 .944 r
.46193 .55643 .46833 .55962 .47944 .56068 .47307 .55782 Mtetra
.098 .6 .897 r
.47307 .55782 .47944 .56068 .49062 .56224 .48428 .55972 Mtetra
0 .529 .829 r
.48428 .55972 .49062 .56224 .50188 .56438 .49556 .5622 Mtetra
0 .434 .734 r
.49556 .5622 .50188 .56438 .51322 .56724 .50694 .56539 Mtetra
.274 0 0 r
.50694 .56539 .51322 .56724 .52465 .57096 .5184 .56942 Mtetra
.393 0 0 r
.5184 .56942 .52465 .57096 .53618 .5757 .52996 .57443 Mtetra
.5 0 0 r
.52996 .57443 .53618 .5757 .54782 .58169 .54163 .58063 Mtetra
.586 .012 0 r
.54163 .58063 .54782 .58169 .55959 .58914 .55344 .58821 Mtetra
.654 .099 0 r
.55344 .58821 .55959 .58914 .57151 .59831 .56538 .59736 Mtetra
.709 .174 0 r
.56538 .59736 .57151 .59831 .5836 .60955 .5775 .60835 Mtetra
.75 .233 0 r
.5775 .60835 .5836 .60955 .59589 .62306 .5898 .62135 Mtetra
.776 .27 0 r
.5898 .62135 .59589 .62306 .60841 .63877 .60232 .63623 Mtetra
.861 .411 .097 r
.60232 .63623 .60841 .63877 .62136 .66357 .61523 .6593 Mtetra
.776 .28 0 r
.61523 .6593 .62136 .66357 .63441 .68313 .62824 .67731 Mtetra
.644 .777 .945 r
.62824 .67731 .63441 .68313 .64688 .67972 .64075 .67387 Mtetra
.916 .79 .707 r
.64075 .67387 .64688 .67972 .65852 .65325 .65252 .64891 Mtetra
.944 .803 .674 r
.65252 .64891 .65852 .65325 .66982 .6214 .66398 .61875 Mtetra
.942 .859 .73 r
.66398 .61875 .66982 .6214 .68138 .59859 .67566 .59672 Mtetra
.943 .887 .746 r
.67566 .59672 .68138 .59859 .69296 .57791 .68735 .57651 Mtetra
.938 .911 .767 r
.68735 .57651 .69296 .57791 .70459 .55946 .69907 .55826 Mtetra
.926 .93 .789 r
.69907 .55826 .70459 .55946 .71628 .54304 .71084 .54182 Mtetra
.912 .943 .811 r
.71084 .54182 .71628 .54304 .72803 .52831 .72266 .52692 Mtetra
.895 .949 .833 r
.72266 .52692 .72803 .52831 .73984 .51502 .73453 .51337 Mtetra
.877 .95 .854 r
.73453 .51337 .73984 .51502 .75172 .50298 .74646 .501 Mtetra
.861 .947 .871 r
.74646 .501 .75172 .50298 .76367 .49193 .75845 .48959 Mtetra
.844 .939 .886 r
.75845 .48959 .76367 .49193 .77568 .48174 .7705 .47901 Mtetra
.83 .93 .898 r
.7705 .47901 .77568 .48174 .78775 .47225 .78261 .46913 Mtetra
.816 .918 .906 r
.78261 .46913 .78775 .47225 .79988 .46334 .79477 .45982 Mtetra
.804 .905 .911 r
.79477 .45982 .79988 .46334 .81207 .45492 .80699 .45101 Mtetra
.794 .891 .914 r
.80699 .45101 .81207 .45492 .82431 .44688 .81926 .44258 Mtetra
.784 .877 .915 r
.81926 .44258 .82431 .44688 .83662 .43918 .83159 .4345 Mtetra
.776 .863 .914 r
.83159 .4345 .83662 .43918 .84897 .43174 .84396 .42668 Mtetra
.769 .85 .912 r
.84396 .42668 .84897 .43174 .86137 .42451 .85638 .41909 Mtetra
.763 .837 .909 r
.85638 .41909 .86137 .42451 .87383 .41745 .86886 .41167 Mtetra
.758 .825 .905 r
.86886 .41167 .87383 .41745 .88633 .41052 .88137 .40439 Mtetra
.753 .813 .9 r
.88137 .40439 .88633 .41052 .89887 .40368 .89393 .39721 Mtetra
.749 .802 .895 r
.89393 .39721 .89887 .40368 .91146 .39691 .90653 .3901 Mtetra
.746 .791 .889 r
.90653 .3901 .91146 .39691 .92409 .39018 .91917 .38302 Mtetra
.744 .781 .883 r
.91917 .38302 .92409 .39018 .93675 .38345 .93184 .37595 Mtetra
.517 .694 .949 r
.34741 .54998 .35401 .55612 .36453 .55566 .35794 .54976 Mtetra
.51 .701 .956 r
.35794 .54976 .36453 .55566 .37512 .55522 .36853 .54956 Mtetra
.499 .706 .963 r
.36853 .54956 .37512 .55522 .38576 .55483 .37919 .54942 Mtetra
.485 .71 .97 r
.37919 .54942 .38576 .55483 .39646 .55453 .3899 .54936 Mtetra
.467 .713 .976 r
.3899 .54936 .39646 .55453 .40722 .55433 .40067 .54941 Mtetra
.444 .714 .981 r
.40067 .54941 .40722 .55433 .41804 .55428 .41151 .54962 Mtetra
.415 .712 .985 r
.41151 .54962 .41804 .55428 .42892 .55442 .4224 .55001 Mtetra
.379 .706 .985 r
.4224 .55001 .42892 .55442 .43986 .55479 .43336 .55064 Mtetra
.333 .694 .981 r
.43336 .55064 .43986 .55479 .45086 .55543 .44439 .55155 Mtetra
.276 .674 .97 r
.44439 .55155 .45086 .55543 .46193 .55643 .45548 .5528 Mtetra
.207 .644 .95 r
.45548 .5528 .46193 .55643 .47307 .55782 .46664 .55445 Mtetra
.122 .6 .916 r
.46664 .55445 .47307 .55782 .48428 .55972 .47788 .55659 Mtetra
.025 .541 .866 r
.47788 .55659 .48428 .55972 .49556 .5622 .48919 .5593 Mtetra
0 .464 .797 r
.48919 .5593 .49556 .5622 .50694 .56539 .50059 .56269 Mtetra
0 .373 .71 r
.50059 .56269 .50694 .56539 .5184 .56942 .51208 .56689 Mtetra
.313 0 0 r
.51208 .56689 .5184 .56942 .52996 .57443 .52367 .57202 Mtetra
.419 0 0 r
.52367 .57202 .52996 .57443 .54163 .58063 .53538 .57826 Mtetra
.511 0 0 r
.53538 .57826 .54163 .58063 .55344 .58821 .5472 .58577 Mtetra
.586 .015 0 r
.5472 .58577 .55344 .58821 .56538 .59736 .55918 .59474 Mtetra
.649 .095 0 r
.55918 .59474 .56538 .59736 .5775 .60835 .57131 .60539 Mtetra
.697 .159 0 r
.57131 .60539 .5775 .60835 .5898 .62135 .58362 .61787 Mtetra
.725 .201 0 r
.58362 .61787 .5898 .62135 .60232 .63623 .59614 .63209 Mtetra
.842 .378 .01 r
.59614 .63209 .60232 .63623 .61523 .6593 .60903 .65411 Mtetra
.729 .228 0 r
.60903 .65411 .61523 .6593 .62824 .67731 .62201 .67122 Mtetra
.645 .77 .939 r
.62201 .67122 .62824 .67731 .64075 .67387 .63456 .66775 Mtetra
.911 .788 .713 r
.63456 .66775 .64075 .67387 .65252 .64891 .64644 .64364 Mtetra
.934 .793 .681 r
.64644 .64364 .65252 .64891 .66398 .61875 .65803 .61448 Mtetra
.923 .83 .736 r
.65803 .61448 .66398 .61875 .67566 .59672 .66981 .59307 Mtetra
.924 .851 .752 r
.66981 .59307 .67566 .59672 .68735 .57651 .6816 .57333 Mtetra
.92 .871 .772 r
.6816 .57333 .68735 .57651 .69907 .55826 .69341 .55537 Mtetra
.913 .888 .793 r
.69341 .55537 .69907 .55826 .71084 .54182 .70526 .53907 Mtetra
.903 .901 .813 r
.70526 .53907 .71084 .54182 .72266 .52692 .71715 .52418 Mtetra
.89 .909 .832 r
.71715 .52418 .72266 .52692 .73453 .51337 .72909 .51055 Mtetra
.876 .914 .85 r
.72909 .51055 .73453 .51337 .74646 .501 .74108 .49801 Mtetra
.862 .914 .865 r
.74108 .49801 .74646 .501 .75845 .48959 .75313 .48638 Mtetra
.847 .91 .878 r
.75313 .48638 .75845 .48959 .7705 .47901 .76522 .47554 Mtetra
.834 .904 .888 r
.76522 .47554 .7705 .47901 .78261 .46913 .77737 .46537 Mtetra
.821 .896 .895 r
.77737 .46537 .78261 .46913 .79477 .45982 .78957 .45576 Mtetra
.809 .887 .9 r
.78957 .45576 .79477 .45982 .80699 .45101 .80183 .44663 Mtetra
.799 .876 .903 r
.80183 .44663 .80699 .45101 .81926 .44258 .81413 .43788 Mtetra
.79 .865 .905 r
.81413 .43788 .81926 .44258 .83159 .4345 .82648 .42948 Mtetra
.782 .854 .905 r
.82648 .42948 .83159 .4345 .84396 .42668 .83888 .42134 Mtetra
.775 .843 .903 r
.83888 .42134 .84396 .42668 .85638 .41909 .85133 .41342 Mtetra
.769 .832 .901 r
.85133 .41342 .85638 .41909 .86886 .41167 .86382 .40569 Mtetra
.763 .821 .898 r
.86382 .40569 .86886 .41167 .88137 .40439 .87636 .39809 Mtetra
.759 .811 .894 r
.87636 .39809 .88137 .40439 .89393 .39721 .88894 .39059 Mtetra
.755 .801 .89 r
.88894 .39059 .89393 .39721 .90653 .3901 .90155 .38316 Mtetra
.752 .791 .885 r
.90155 .38316 .90653 .3901 .91917 .38302 .91421 .37578 Mtetra
.75 .782 .88 r
.91421 .37578 .91917 .38302 .93184 .37595 .92689 .3684 Mtetra
.503 .688 .951 r
.34076 .54378 .34741 .54998 .35794 .54976 .3513 .54378 Mtetra
.495 .694 .957 r
.3513 .54378 .35794 .54976 .36853 .54956 .3619 .5438 Mtetra
.485 .698 .963 r
.3619 .5438 .36853 .54956 .37919 .54942 .37256 .54387 Mtetra
.471 .701 .969 r
.37256 .54387 .37919 .54942 .3899 .54936 .38329 .54403 Mtetra
.453 .703 .974 r
.38329 .54403 .3899 .54936 .40067 .54941 .39408 .5443 Mtetra
.432 .703 .979 r
.39408 .5443 .40067 .54941 .41151 .54962 .40493 .54472 Mtetra
.405 .7 .981 r
.40493 .54472 .41151 .54962 .4224 .55001 .41584 .54533 Mtetra
.372 .693 .982 r
.41584 .54533 .4224 .55001 .43336 .55064 .42682 .54617 Mtetra
.331 .681 .979 r
.42682 .54617 .43336 .55064 .44439 .55155 .43787 .54729 Mtetra
.281 .663 .97 r
.43787 .54729 .44439 .55155 .45548 .5528 .44898 .54874 Mtetra
.223 .638 .956 r
.44898 .54874 .45548 .5528 .46664 .55445 .46017 .55057 Mtetra
.151 .601 .931 r
.46017 .55057 .46664 .55445 .47788 .55659 .47143 .55287 Mtetra
.072 .555 .897 r
.47143 .55287 .47788 .55659 .48919 .5593 .48277 .55572 Mtetra
0 .494 .849 r
.48277 .55572 .48919 .5593 .50059 .56269 .49419 .5592 Mtetra
0 .423 .79 r
.49419 .5592 .50059 .56269 .51208 .56689 .50571 .56344 Mtetra
0 .344 .722 r
.50571 .56344 .51208 .56689 .52367 .57202 .51733 .56853 Mtetra
0 .257 .647 r
.51733 .56853 .52367 .57202 .53538 .57826 .52905 .57465 Mtetra
.396 0 0 r
.52905 .57465 .53538 .57826 .5472 .58577 .5409 .58193 Mtetra
.472 0 0 r
.5409 .58193 .5472 .58577 .55918 .59474 .55289 .59054 Mtetra
.539 0 0 r
.55289 .59054 .55918 .59474 .57131 .60539 .56503 .60071 Mtetra
.592 .056 0 r
.56503 .60071 .57131 .60539 .58362 .61787 .57735 .61259 Mtetra
.631 .112 0 r
.57735 .61259 .58362 .61787 .59614 .63209 .58987 .62632 Mtetra
.817 .351 0 r
.58987 .62632 .59614 .63209 .60903 .65411 .60275 .64834 Mtetra
.711 .214 0 r
.60275 .64834 .60903 .65411 .62201 .67122 .61575 .66558 Mtetra
.641 .786 .951 r
.61575 .66558 .62201 .67122 .63456 .66775 .62833 .66209 Mtetra
.916 .797 .714 r
.62833 .66209 .63456 .66775 .64644 .64364 .64028 .63778 Mtetra
.929 .785 .681 r
.64028 .63778 .64644 .64364 .65803 .61448 .65196 .60857 Mtetra
.903 .801 .736 r
.65196 .60857 .65803 .61448 .66981 .59307 .66383 .5876 Mtetra
.901 .814 .753 r
.66383 .5876 .66981 .59307 .6816 .57333 .67571 .56841 Mtetra
.898 .832 .772 r
.67571 .56841 .6816 .57333 .69341 .55537 .68762 .55089 Mtetra
.894 .848 .791 r
.68762 .55089 .69341 .55537 .70526 .53907 .69955 .53489 Mtetra
.887 .862 .81 r
.69955 .53489 .70526 .53907 .71715 .52418 .71152 .52019 Mtetra
.878 .873 .827 r
.71152 .52019 .71715 .52418 .72909 .51055 .72353 .50662 Mtetra
.867 .88 .843 r
.72353 .50662 .72909 .51055 .74108 .49801 .73559 .49406 Mtetra
.856 .883 .857 r
.73559 .49406 .74108 .49801 .75313 .48638 .74769 .48234 Mtetra
.844 .883 .868 r
.74769 .48234 .75313 .48638 .76522 .47554 .75984 .47136 Mtetra
.832 .881 .878 r
.75984 .47136 .76522 .47554 .77737 .46537 .77204 .461 Mtetra
.822 .876 .885 r
.77204 .461 .77737 .46537 .78957 .45576 .78428 .45117 Mtetra
.811 .869 .89 r
.78428 .45117 .78957 .45576 .80183 .44663 .79657 .4418 Mtetra
.802 .862 .894 r
.79657 .4418 .80183 .44663 .81413 .43788 .80892 .4328 Mtetra
.793 .853 .895 r
.80892 .4328 .81413 .43788 .82648 .42948 .8213 .42412 Mtetra
.786 .844 .896 r
.8213 .42412 .82648 .42948 .83888 .42134 .83373 .41571 Mtetra
.779 .835 .895 r
.83373 .41571 .83888 .42134 .85133 .41342 .84621 .40751 Mtetra
.773 .826 .894 r
.84621 .40751 .85133 .41342 .86382 .40569 .85873 .39949 Mtetra
.768 .817 .891 r
.85873 .39949 .86382 .40569 .87636 .39809 .87129 .39161 Mtetra
.764 .808 .888 r
.87129 .39161 .87636 .39809 .88894 .39059 .88389 .38383 Mtetra
.76 .799 .885 r
.88389 .38383 .88894 .39059 .90155 .38316 .89653 .37612 Mtetra
.757 .791 .881 r
.89653 .37612 .90155 .38316 .91421 .37578 .9092 .36844 Mtetra
.755 .783 .876 r
.9092 .36844 .91421 .37578 .92689 .3684 .9219 .36078 Mtetra
.489 .683 .952 r
.33406 .53754 .34076 .54378 .3513 .54378 .34461 .53773 Mtetra
.482 .687 .957 r
.34461 .53773 .3513 .54378 .3619 .5438 .35522 .53793 Mtetra
.472 .691 .963 r
.35522 .53793 .3619 .5438 .37256 .54387 .36589 .53819 Mtetra
.459 .693 .968 r
.36589 .53819 .37256 .54387 .38329 .54403 .37663 .53854 Mtetra
.443 .694 .972 r
.37663 .53854 .38329 .54403 .39408 .5443 .38743 .539 Mtetra
.423 .693 .976 r
.38743 .539 .39408 .5443 .40493 .54472 .3983 .5396 Mtetra
.398 .689 .978 r
.3983 .5396 .40493 .54472 .41584 .54533 .40923 .54038 Mtetra
.369 .682 .978 r
.40923 .54038 .41584 .54533 .42682 .54617 .42023 .54139 Mtetra
.334 .672 .976 r
.42023 .54139 .42682 .54617 .43787 .54729 .43129 .54265 Mtetra
.292 .656 .97 r
.43129 .54265 .43787 .54729 .44898 .54874 .44243 .54424 Mtetra
.243 .634 .96 r
.44243 .54424 .44898 .54874 .46017 .55057 .45364 .54619 Mtetra
.186 .605 .943 r
.45364 .54619 .46017 .55057 .47143 .55287 .46492 .54857 Mtetra
.123 .569 .921 r
.46492 .54857 .47143 .55287 .48277 .55572 .47629 .55146 Mtetra
.052 .523 .89 r
.47629 .55146 .48277 .55572 .49419 .5592 .48774 .55493 Mtetra
0 .469 .853 r
.48774 .55493 .49419 .5592 .50571 .56344 .49928 .55909 Mtetra
0 .409 .81 r
.49928 .55909 .50571 .56344 .51733 .56853 .51092 .56403 Mtetra
0 .341 .761 r
.51092 .56403 .51733 .56853 .52905 .57465 .52267 .5699 Mtetra
0 .274 .712 r
.52267 .5699 .52905 .57465 .5409 .58193 .53454 .57679 Mtetra
0 .202 .661 r
.53454 .57679 .5409 .58193 .55289 .59054 .54654 .58493 Mtetra
0 .132 .61 r
.54654 .58493 .55289 .59054 .56503 .60071 .55869 .59448 Mtetra
0 .061 .559 r
.55869 .59448 .56503 .60071 .57735 .61259 .57101 .60571 Mtetra
0 0 .483 r
.57101 .60571 .57735 .61259 .58987 .62632 .58352 .61922 Mtetra
.81 .357 0 r
.58352 .61922 .58987 .62632 .60275 .64834 .59642 .64275 Mtetra
.759 .27 0 r
.59642 .64275 .60275 .64834 .61575 .66558 .60946 .66162 Mtetra
.616 .841 .986 r
.60946 .66162 .61575 .66558 .62833 .66209 .6221 .6581 Mtetra
.938 .821 .704 r
.6221 .6581 .62833 .66209 .64028 .63778 .63408 .6321 Mtetra
.934 .786 .673 r
.63408 .6321 .64028 .63778 .65196 .60857 .64579 .60132 Mtetra
.888 .777 .733 r
.64579 .60132 .65196 .60857 .66383 .5876 .65773 .58051 Mtetra
.879 .783 .752 r
.65773 .58051 .66383 .5876 .67571 .56841 .66971 .56192 Mtetra
.876 .799 .77 r
.66971 .56192 .67571 .56841 .68762 .55089 .6817 .54497 Mtetra
.874 .815 .788 r
.6817 .54497 .68762 .55089 .69955 .53489 .69372 .52939 Mtetra
.869 .828 .805 r
.69372 .52939 .69955 .53489 .71152 .52019 .70577 .51503 Mtetra
.863 .841 .821 r
.70577 .51503 .71152 .52019 .72353 .50662 .71786 .50166 Mtetra
.855 .85 .836 r
.71786 .50166 .72353 .50662 .73559 .49406 .72998 .48921 Mtetra
.847 .855 .849 r
.72998 .48921 .73559 .49406 .74769 .48234 .74215 .47751 Mtetra
.838 .858 .86 r
.74215 .47751 .74769 .48234 .75984 .47136 .75436 .46648 Mtetra
.828 .859 .869 r
.75436 .46648 .75984 .47136 .77204 .461 .76661 .45603 Mtetra
.819 .857 .876 r
.76661 .45603 .77204 .461 .78428 .45117 .7789 .44605 Mtetra
.81 .853 .881 r
.7789 .44605 .78428 .45117 .79657 .4418 .79124 .43651 Mtetra
.802 .848 .885 r
.79124 .43651 .79657 .4418 .80892 .4328 .80362 .42731 Mtetra
.795 .842 .887 r
.80362 .42731 .80892 .4328 .8213 .42412 .81605 .41842 Mtetra
.788 .835 .888 r
.81605 .41842 .8213 .42412 .83373 .41571 .82852 .40978 Mtetra
.782 .828 .888 r
.82852 .40978 .83373 .41571 .84621 .40751 .84103 .40135 Mtetra
.776 .82 .887 r
.84103 .40135 .84621 .40751 .85873 .39949 .85358 .39308 Mtetra
.772 .813 .886 r
.85358 .39308 .85873 .39949 .87129 .39161 .86616 .38495 Mtetra
.768 .805 .883 r
.86616 .38495 .87129 .39161 .88389 .38383 .87879 .37691 Mtetra
.764 .798 .88 r
.87879 .37691 .88389 .38383 .89653 .37612 .89145 .36895 Mtetra
.761 .791 .877 r
.89145 .36895 .89653 .37612 .9092 .36844 .90414 .36102 Mtetra
.759 .784 .873 r
.90414 .36102 .9092 .36844 .9219 .36078 .91687 .3531 Mtetra
.477 .678 .953 r
.32731 .53126 .33406 .53754 .34461 .53773 .33786 .5316 Mtetra
.47 .681 .958 r
.33786 .5316 .34461 .53773 .35522 .53793 .34848 .53197 Mtetra
.461 .684 .962 r
.34848 .53197 .35522 .53793 .36589 .53819 .35917 .53239 Mtetra
.449 .685 .966 r
.35917 .53239 .36589 .53819 .37663 .53854 .36992 .53289 Mtetra
.434 .685 .97 r
.36992 .53289 .37663 .53854 .38743 .539 .38074 .53351 Mtetra
.416 .684 .973 r
.38074 .53351 .38743 .539 .3983 .5396 .39162 .53425 Mtetra
.394 .68 .975 r
.39162 .53425 .3983 .5396 .40923 .54038 .40257 .53518 Mtetra
.369 .674 .975 r
.40257 .53518 .40923 .54038 .42023 .54139 .41359 .5363 Mtetra
.339 .664 .974 r
.41359 .5363 .42023 .54139 .43129 .54265 .42467 .53768 Mtetra
.304 .65 .969 r
.42467 .53768 .43129 .54265 .44243 .54424 .43583 .53935 Mtetra
.265 .632 .962 r
.43583 .53935 .44243 .54424 .45364 .54619 .44706 .54135 Mtetra
.219 .609 .951 r
.44706 .54135 .45364 .54619 .46492 .54857 .45837 .54375 Mtetra
.171 .581 .937 r
.45837 .54375 .46492 .54857 .47629 .55146 .46976 .5466 Mtetra
.118 .546 .918 r
.46976 .5466 .47629 .55146 .48774 .55493 .48123 .54998 Mtetra
.063 .506 .895 r
.48123 .54998 .48774 .55493 .49928 .55909 .4928 .55396 Mtetra
.009 .462 .87 r
.4928 .55396 .49928 .55909 .51092 .56403 .50446 .55863 Mtetra
0 .412 .84 r
.50446 .55863 .51092 .56403 .52267 .5699 .51623 .56412 Mtetra
0 .365 .813 r
.51623 .56412 .52267 .5699 .53454 .57679 .52812 .57047 Mtetra
0 .308 .78 r
.52812 .57047 .53454 .57679 .54654 .58493 .54013 .57796 Mtetra
0 .255 .749 r
.54013 .57796 .54654 .58493 .55869 .59448 .55228 .58668 Mtetra
0 .194 .711 r
.55228 .58668 .55869 .59448 .57101 .60571 .56459 .59695 Mtetra
0 .093 .635 r
.56459 .59695 .57101 .60571 .58352 .61922 .57709 .60974 Mtetra
.739 .307 0 r
.57709 .60974 .58352 .61922 .59642 .64275 .58998 .63349 Mtetra
.606 .168 0 r
.58998 .63349 .59642 .64275 .60946 .66162 .60301 .65283 Mtetra
.65 .699 .882 r
.60301 .65283 .60946 .66162 .6221 .6581 .61568 .64927 Mtetra
.893 .749 .695 r
.61568 .64927 .6221 .6581 .63408 .6321 .62772 .62275 Mtetra
.903 .742 .671 r
.62772 .62275 .63408 .6321 .64579 .60132 .63949 .59168 Mtetra
.86 .739 .728 r
.63949 .59168 .64579 .60132 .65773 .58051 .65152 .57152 Mtetra
.852 .749 .749 r
.65152 .57152 .65773 .58051 .66971 .56192 .66359 .55384 Mtetra
.852 .766 .767 r
.66359 .55384 .66971 .56192 .6817 .54497 .67567 .53767 Mtetra
.852 .784 .784 r
.67567 .53767 .6817 .54497 .69372 .52939 .68778 .52269 Mtetra
.85 .799 .801 r
.68778 .52269 .69372 .52939 .70577 .51503 .69992 .50881 Mtetra
.847 .813 .816 r
.69992 .50881 .70577 .51503 .71786 .50166 .71208 .49578 Mtetra
.842 .824 .831 r
.71208 .49578 .71786 .50166 .72998 .48921 .72428 .48355 Mtetra
.837 .832 .843 r
.72428 .48355 .72998 .48921 .74215 .47751 .73651 .47197 Mtetra
.83 .837 .853 r
.73651 .47197 .74215 .47751 .75436 .46648 .74878 .46098 Mtetra
.823 .84 .862 r
.74878 .46098 .75436 .46648 .76661 .45603 .76109 .45051 Mtetra
.815 .84 .868 r
.76109 .45051 .76661 .45603 .7789 .44605 .77344 .44046 Mtetra
.808 .839 .874 r
.77344 .44046 .7789 .44605 .79124 .43651 .78582 .4308 Mtetra
.801 .836 .878 r
.78582 .4308 .79124 .43651 .80362 .42731 .79825 .42146 Mtetra
.795 .832 .88 r
.79825 .42146 .80362 .42731 .81605 .41842 .81072 .4124 Mtetra
.789 .827 .882 r
.81072 .4124 .81605 .41842 .82852 .40978 .82323 .40358 Mtetra
.783 .821 .882 r
.82323 .40358 .82852 .40978 .84103 .40135 .83577 .39494 Mtetra
.778 .815 .882 r
.83577 .39494 .84103 .40135 .85358 .39308 .84836 .38647 Mtetra
.774 .809 .881 r
.84836 .38647 .85358 .39308 .86616 .38495 .86098 .37812 Mtetra
.771 .803 .879 r
.86098 .37812 .86616 .38495 .87879 .37691 .87364 .36986 Mtetra
.767 .796 .876 r
.87364 .36986 .87879 .37691 .89145 .36895 .88633 .36166 Mtetra
.765 .79 .874 r
.88633 .36166 .89145 .36895 .90414 .36102 .89905 .35351 Mtetra
.763 .784 .871 r
.89905 .35351 .90414 .36102 .91687 .3531 .91179 .34535 Mtetra
.466 .673 .954 r
.32051 .52493 .32731 .53126 .33786 .5316 .33107 .52541 Mtetra
.46 .676 .958 r
.33107 .52541 .33786 .5316 .34848 .53197 .3417 .52591 Mtetra
.452 .678 .961 r
.3417 .52591 .34848 .53197 .35917 .53239 .3524 .52647 Mtetra
.441 .679 .965 r
.3524 .52647 .35917 .53239 .36992 .53289 .36317 .5271 Mtetra
.427 .678 .968 r
.36317 .5271 .36992 .53289 .38074 .53351 .374 .52783 Mtetra
.412 .677 .97 r
.374 .52783 .38074 .53351 .39162 .53425 .3849 .52869 Mtetra
.393 .673 .972 r
.3849 .52869 .39162 .53425 .40257 .53518 .39586 .52972 Mtetra
.371 .667 .972 r
.39586 .52972 .40257 .53518 .41359 .5363 .4069 .53093 Mtetra
.346 .658 .971 r
.4069 .53093 .41359 .5363 .42467 .53768 .41801 .53237 Mtetra
.318 .646 .968 r
.41801 .53237 .42467 .53768 .43583 .53935 .42918 .53408 Mtetra
.287 .632 .963 r
.42918 .53408 .43583 .53935 .44706 .54135 .44044 .53608 Mtetra
.253 .613 .956 r
.44044 .53608 .44706 .54135 .45837 .54375 .45177 .53844 Mtetra
.218 .591 .947 r
.45177 .53844 .45837 .54375 .46976 .5466 .46318 .54119 Mtetra
.181 .566 .935 r
.46318 .54119 .46976 .5466 .48123 .54998 .47468 .5444 Mtetra
.145 .537 .922 r
.47468 .5444 .48123 .54998 .4928 .55396 .48627 .54811 Mtetra
.112 .506 .907 r
.48627 .54811 .4928 .55396 .50446 .55863 .49796 .5524 Mtetra
.082 .472 .891 r
.49796 .5524 .50446 .55863 .51623 .56412 .50975 .55735 Mtetra
.064 .441 .876 r
.50975 .55735 .51623 .56412 .52812 .57047 .52164 .563 Mtetra
.046 .405 .858 r
.52164 .563 .52812 .57047 .54013 .57796 .53366 .56952 Mtetra
.047 .375 .841 r
.53366 .56952 .54013 .57796 .55228 .58668 .54581 .57697 Mtetra
.053 .342 .82 r
.54581 .57697 .55228 .58668 .56459 .59695 .55811 .58557 Mtetra
.046 .296 .786 r
.55811 .58557 .56459 .59695 .57709 .60974 .57056 .59588 Mtetra
0 .024 .597 r
.57056 .59588 .57709 .60974 .58998 .63349 .58332 .61427 Mtetra
.174 .262 .715 r
.58332 .61427 .58998 .63349 .60301 .65283 .5962 .6288 Mtetra
.616 .509 .709 r
.5962 .6288 .60301 .65283 .61568 .64927 .60884 .6252 Mtetra
.763 .595 .669 r
.60884 .6252 .61568 .64927 .62772 .62275 .62103 .60339 Mtetra
.81 .64 .671 r
.62103 .60339 .62772 .62275 .63949 .59168 .63301 .57762 Mtetra
.804 .673 .72 r
.63301 .57762 .63949 .59168 .65152 .57152 .64517 .55989 Mtetra
.814 .703 .743 r
.64517 .55989 .65152 .57152 .66359 .55384 .65735 .54383 Mtetra
.821 .729 .763 r
.65735 .54383 .66359 .55384 .67567 .53767 .66954 .52888 Mtetra
.827 .752 .781 r
.66954 .52888 .67567 .53767 .68778 .52269 .68174 .51481 Mtetra
.83 .772 .798 r
.68174 .51481 .68778 .52269 .69992 .50881 .69396 .50159 Mtetra
.83 .788 .812 r
.69396 .50159 .69992 .50881 .71208 .49578 .70621 .48905 Mtetra
.828 .802 .826 r
.70621 .48905 .71208 .49578 .72428 .48355 .71848 .47714 Mtetra
.825 .812 .837 r
.71848 .47714 .72428 .48355 .73651 .47197 .73078 .46578 Mtetra
.821 .819 .847 r
.73078 .46578 .73651 .47197 .74878 .46098 .74312 .45491 Mtetra
.816 .823 .856 r
.74312 .45491 .74878 .46098 .76109 .45051 .75549 .44448 Mtetra
.81 .826 .862 r
.75549 .44448 .76109 .45051 .77344 .44046 .76789 .43442 Mtetra
.805 .826 .867 r
.76789 .43442 .77344 .44046 .78582 .4308 .78033 .4247 Mtetra
.799 .825 .871 r
.78033 .4247 .78582 .4308 .79825 .42146 .79281 .41527 Mtetra
.794 .822 .874 r
.79281 .41527 .79825 .42146 .81072 .4124 .80532 .40608 Mtetra
.789 .819 .876 r
.80532 .40608 .81072 .4124 .82323 .40358 .81787 .39711 Mtetra
.784 .815 .877 r
.81787 .39711 .82323 .40358 .83577 .39494 .83046 .38831 Mtetra
.78 .81 .877 r
.83046 .38831 .83577 .39494 .84836 .38647 .84308 .37965 Mtetra
.776 .805 .876 r
.84308 .37965 .84836 .38647 .86098 .37812 .85574 .37111 Mtetra
.773 .8 .875 r
.85574 .37111 .86098 .37812 .87364 .36986 .86843 .36266 Mtetra
.77 .795 .873 r
.86843 .36266 .87364 .36986 .88633 .36166 .88115 .35426 Mtetra
.768 .789 .871 r
.88115 .35426 .88633 .36166 .89905 .35351 .8939 .3459 Mtetra
.766 .784 .868 r
.8939 .3459 .89905 .35351 .91179 .34535 .90668 .33755 Mtetra
.457 .669 .955 r
.31365 .51855 .32051 .52493 .33107 .52541 .32423 .51914 Mtetra
.451 .672 .958 r
.32423 .51914 .33107 .52541 .3417 .52591 .33487 .51976 Mtetra
.444 .673 .961 r
.33487 .51976 .3417 .52591 .3524 .52647 .34558 .52042 Mtetra
.434 .673 .963 r
.34558 .52042 .3524 .52647 .36317 .5271 .35636 .52116 Mtetra
.422 .673 .966 r
.35636 .52116 .36317 .5271 .374 .52783 .36721 .52199 Mtetra
.409 .67 .968 r
.36721 .52199 .374 .52783 .3849 .52869 .37812 .52294 Mtetra
.393 .667 .969 r
.37812 .52294 .3849 .52869 .39586 .52972 .38911 .52403 Mtetra
.375 .661 .969 r
.38911 .52403 .39586 .52972 .4069 .53093 .40016 .5253 Mtetra
.354 .654 .968 r
.40016 .5253 .4069 .53093 .41801 .53237 .41129 .52677 Mtetra
.332 .644 .966 r
.41129 .52677 .41801 .53237 .42918 .53408 .42249 .52847 Mtetra
.309 .632 .963 r
.42249 .52847 .42918 .53408 .44044 .53608 .43377 .53044 Mtetra
.284 .617 .958 r
.43377 .53044 .44044 .53608 .45177 .53844 .44512 .5327 Mtetra
.259 .6 .952 r
.44512 .5327 .45177 .53844 .46318 .54119 .45656 .5353 Mtetra
.235 .582 .944 r
.45656 .5353 .46318 .54119 .47468 .5444 .46808 .53828 Mtetra
.214 .561 .936 r
.46808 .53828 .47468 .5444 .48627 .54811 .4797 .54166 Mtetra
.198 .539 .926 r
.4797 .54166 .48627 .54811 .49796 .5524 .4914 .5455 Mtetra
.188 .517 .916 r
.4914 .5455 .49796 .5524 .50975 .55735 .50321 .54982 Mtetra
.187 .495 .904 r
.50321 .54982 .50975 .55735 .52164 .563 .51512 .55467 Mtetra
.195 .474 .891 r
.51512 .55467 .52164 .563 .53366 .56952 .52715 .56005 Mtetra
.217 .455 .873 r
.52715 .56005 .53366 .56952 .54581 .57697 .5393 .56602 Mtetra
.249 .437 .85 r
.5393 .56602 .54581 .57697 .55811 .58557 .55157 .57258 Mtetra
.297 .424 .822 r
.55157 .57258 .55811 .58557 .57056 .59588 .56398 .57959 Mtetra
.241 .338 .763 r
.56398 .57959 .57056 .59588 .58332 .61427 .57657 .59007 Mtetra
.444 .399 .713 r
.57657 .59007 .58332 .61427 .5962 .6288 .58927 .59746 Mtetra
.606 .474 .675 r
.58927 .59746 .5962 .6288 .60884 .6252 .60185 .5938 Mtetra
.692 .529 .662 r
.60185 .5938 .60884 .6252 .62103 .60339 .6142 .57904 Mtetra
.74 .58 .677 r
.6142 .57904 .62103 .60339 .63301 .57762 .62643 .56113 Mtetra
.761 .635 .721 r
.62643 .56113 .63301 .57762 .64517 .55989 .63873 .54664 Mtetra
.783 .675 .745 r
.63873 .54664 .64517 .55989 .65735 .54383 .65102 .53257 Mtetra
.796 .704 .764 r
.65102 .53257 .65735 .54383 .66954 .52888 .66331 .51904 Mtetra
.805 .73 .781 r
.66331 .51904 .66954 .52888 .68174 .51481 .67561 .50607 Mtetra
.812 .752 .797 r
.67561 .50607 .68174 .51481 .69396 .50159 .68792 .4936 Mtetra
.815 .77 .811 r
.68792 .4936 .69396 .50159 .70621 .48905 .70025 .48163 Mtetra
.816 .785 .823 r
.70025 .48163 .70621 .48905 .71848 .47714 .7126 .47012 Mtetra
.815 .796 .834 r
.7126 .47012 .71848 .47714 .73078 .46578 .72498 .45904 Mtetra
.812 .804 .843 r
.72498 .45904 .73078 .46578 .74312 .45491 .73738 .44835 Mtetra
.809 .81 .851 r
.73738 .44835 .74312 .45491 .75549 .44448 .74981 .43801 Mtetra
.805 .813 .857 r
.74981 .43801 .75549 .44448 .76789 .43442 .76227 .42798 Mtetra
.801 .815 .863 r
.76227 .42798 .76789 .43442 .78033 .4247 .77477 .41824 Mtetra
.797 .815 .866 r
.77477 .41824 .78033 .4247 .79281 .41527 .7873 .40875 Mtetra
.792 .814 .869 r
.7873 .40875 .79281 .41527 .80532 .40608 .79986 .39948 Mtetra
.788 .812 .871 r
.79986 .39948 .80532 .40608 .81787 .39711 .81245 .39039 Mtetra
.784 .809 .872 r
.81245 .39039 .81787 .39711 .83046 .38831 .82508 .38145 Mtetra
.781 .805 .873 r
.82508 .38145 .83046 .38831 .84308 .37965 .83775 .37265 Mtetra
.777 .802 .872 r
.83775 .37265 .84308 .37965 .85574 .37111 .85044 .36394 Mtetra
.775 .797 .871 r
.85044 .36394 .85574 .37111 .86843 .36266 .86317 .35532 Mtetra
.772 .793 .87 r
.86317 .35532 .86843 .36266 .88115 .35426 .87592 .34675 Mtetra
.77 .789 .868 r
.87592 .34675 .88115 .35426 .8939 .3459 .88871 .33821 Mtetra
.768 .784 .866 r
.88871 .33821 .8939 .3459 .90668 .33755 .90152 .32967 Mtetra
.449 .666 .955 r
.30675 .51212 .31365 .51855 .32423 .51914 .31734 .5128 Mtetra
.444 .668 .957 r
.31734 .5128 .32423 .51914 .33487 .51976 .32799 .51351 Mtetra
.437 .669 .96 r
.32799 .51351 .33487 .51976 .34558 .52042 .33871 .51426 Mtetra
.429 .669 .962 r
.33871 .51426 .34558 .52042 .35636 .52116 .34951 .51508 Mtetra
.419 .668 .964 r
.34951 .51508 .35636 .52116 .36721 .52199 .36037 .51598 Mtetra
.407 .666 .966 r
.36037 .51598 .36721 .52199 .37812 .52294 .3713 .51699 Mtetra
.394 .662 .966 r
.3713 .51699 .37812 .52294 .38911 .52403 .3823 .51813 Mtetra
.379 .657 .967 r
.3823 .51813 .38911 .52403 .40016 .5253 .39338 .51943 Mtetra
.363 .651 .966 r
.39338 .51943 .40016 .5253 .41129 .52677 .40452 .5209 Mtetra
.346 .643 .965 r
.40452 .5209 .41129 .52677 .42249 .52847 .41575 .52257 Mtetra
.328 .633 .962 r
.41575 .52257 .42249 .52847 .43377 .53044 .42705 .52446 Mtetra
.311 .622 .959 r
.42705 .52446 .43377 .53044 .44512 .5327 .43843 .5266 Mtetra
.295 .608 .954 r
.43843 .5266 .44512 .5327 .45656 .5353 .44989 .52902 Mtetra
.281 .594 .949 r
.44989 .52902 .45656 .5353 .46808 .53828 .46143 .53173 Mtetra
.27 .579 .942 r
.46143 .53173 .46808 .53828 .4797 .54166 .47307 .53475 Mtetra
.265 .564 .935 r
.47307 .53475 .4797 .54166 .4914 .5455 .4848 .53811 Mtetra
.268 .549 .926 r
.4848 .53811 .4914 .5455 .50321 .54982 .49663 .54177 Mtetra
.275 .532 .915 r
.49663 .54177 .50321 .54982 .51512 .55467 .50856 .5458 Mtetra
.297 .521 .901 r
.50856 .5458 .51512 .55467 .52715 .56005 .5206 .55008 Mtetra
.325 .506 .882 r
.5206 .55008 .52715 .56005 .5393 .56602 .53275 .55461 Mtetra
.363 .495 .858 r
.53275 .55461 .5393 .56602 .55157 .57258 .54501 .55925 Mtetra
.424 .494 .827 r
.54501 .55925 .55157 .57258 .56398 .57959 .55738 .56338 Mtetra
.46 .475 .787 r
.55738 .56338 .56398 .57959 .57657 .59007 .56986 .56747 Mtetra
.54 .468 .724 r
.56986 .56747 .57657 .59007 .58927 .59746 .58242 .5692 Mtetra
.61 .486 .687 r
.58242 .5692 .58927 .59746 .60185 .5938 .59496 .56548 Mtetra
.661 .518 .679 r
.59496 .56548 .60185 .5938 .6142 .57904 .60743 .5563 Mtetra
.701 .565 .698 r
.60743 .5563 .6142 .57904 .62643 .56113 .61985 .54471 Mtetra
.736 .624 .734 r
.61985 .54471 .62643 .56113 .63873 .54664 .63226 .53304 Mtetra
.762 .663 .753 r
.63226 .53304 .63873 .54664 .65102 .53257 .64464 .52083 Mtetra
.778 .693 .77 r
.64464 .52083 .65102 .53257 .66331 .51904 .65703 .50869 Mtetra
.789 .718 .786 r
.65703 .50869 .66331 .51904 .67561 .50607 .66942 .49678 Mtetra
.797 .74 .799 r
.66942 .49678 .67561 .50607 .68792 .4936 .68181 .48507 Mtetra
.801 .757 .812 r
.68181 .48507 .68792 .4936 .70025 .48163 .69422 .4737 Mtetra
.805 .772 .823 r
.69422 .4737 .70025 .48163 .7126 .47012 .70665 .46262 Mtetra
.805 .784 .833 r
.70665 .46262 .7126 .47012 .72498 .45904 .71909 .45185 Mtetra
.804 .793 .841 r
.71909 .45185 .72498 .45904 .73738 .44835 .73156 .44136 Mtetra
.803 .799 .848 r
.73156 .44136 .73738 .44835 .74981 .43801 .74406 .43115 Mtetra
.8 .803 .854 r
.74406 .43115 .74981 .43801 .76227 .42798 .75658 .4212 Mtetra
.797 .806 .859 r
.75658 .4212 .76227 .42798 .77477 .41824 .76913 .41147 Mtetra
.794 .807 .863 r
.76913 .41147 .77477 .41824 .7873 .40875 .78171 .40195 Mtetra
.791 .807 .865 r
.78171 .40195 .7873 .40875 .79986 .39948 .79433 .39261 Mtetra
.787 .806 .867 r
.79433 .39261 .79986 .39948 .81245 .39039 .80697 .38344 Mtetra
.784 .804 .869 r
.80697 .38344 .81245 .39039 .82508 .38145 .81965 .37439 Mtetra
.781 .801 .869 r
.81965 .37439 .82508 .38145 .83775 .37265 .83235 .36546 Mtetra
.778 .798 .869 r
.83235 .36546 .83775 .37265 .85044 .36394 .84509 .35662 Mtetra
.776 .795 .869 r
.84509 .35662 .85044 .36394 .86317 .35532 .85785 .34785 Mtetra
.774 .792 .868 r
.85785 .34785 .86317 .35532 .87592 .34675 .87065 .33913 Mtetra
.772 .788 .866 r
.87065 .33913 .87592 .34675 .88871 .33821 .88347 .33043 Mtetra
.771 .784 .864 r
.88347 .33043 .88871 .33821 .90152 .32967 .89632 .32173 Mtetra
.442 .663 .955 r
.29979 .50564 .30675 .51212 .31734 .5128 .31039 .5064 Mtetra
.438 .664 .957 r
.31039 .5064 .31734 .5128 .32799 .51351 .32106 .50718 Mtetra
.432 .665 .959 r
.32106 .50718 .32799 .51351 .33871 .51426 .33179 .508 Mtetra
.425 .665 .961 r
.33179 .508 .33871 .51426 .34951 .51508 .3426 .50887 Mtetra
.417 .664 .962 r
.3426 .50887 .34951 .51508 .36037 .51598 .35348 .50983 Mtetra
.407 .662 .964 r
.35348 .50983 .36037 .51598 .3713 .51699 .36443 .51088 Mtetra
.396 .659 .964 r
.36443 .51088 .3713 .51699 .3823 .51813 .37545 .51204 Mtetra
.384 .654 .964 r
.37545 .51204 .3823 .51813 .39338 .51943 .38654 .51334 Mtetra
.372 .649 .964 r
.38654 .51334 .39338 .51943 .40452 .5209 .39771 .51479 Mtetra
.359 .642 .963 r
.39771 .51479 .40452 .5209 .41575 .52257 .40896 .5164 Mtetra
.346 .634 .961 r
.40896 .5164 .41575 .52257 .42705 .52446 .42028 .5182 Mtetra
.335 .626 .958 r
.42028 .5182 .42705 .52446 .43843 .5266 .43168 .5202 Mtetra
.325 .615 .954 r
.43168 .5202 .43843 .5266 .44989 .52902 .44317 .52241 Mtetra
.318 .605 .95 r
.44317 .52241 .44989 .52902 .46143 .53173 .45474 .52485 Mtetra
.315 .594 .944 r
.45474 .52485 .46143 .53173 .47307 .53475 .4664 .5275 Mtetra
.317 .583 .938 r
.4664 .5275 .47307 .53475 .4848 .53811 .47815 .53038 Mtetra
.327 .573 .929 r
.47815 .53038 .4848 .53811 .49663 .54177 .49 .53343 Mtetra
.339 .56 .918 r
.49 .53343 .49663 .54177 .50856 .5458 .50195 .53669 Mtetra
.364 .552 .904 r
.50195 .53669 .50856 .5458 .5206 .55008 .514 .53999 Mtetra
.392 .542 .886 r
.514 .53999 .5206 .55008 .53275 .55461 .52616 .54331 Mtetra
.427 .534 .864 r
.52616 .54331 .53275 .55461 .54501 .55925 .53842 .54646 Mtetra
.478 .534 .837 r
.53842 .54646 .54501 .55925 .55738 .56338 .55078 .54886 Mtetra
.519 .531 .808 r
.55078 .54886 .55738 .56338 .56986 .56747 .56323 .55037 Mtetra
.571 .53 .77 r
.56323 .55037 .56986 .56747 .58242 .5692 .57574 .54998 Mtetra
.626 .544 .741 r
.57574 .54998 .58242 .5692 .59496 .56548 .58827 .54622 Mtetra
.671 .568 .731 r
.58827 .54622 .59496 .56548 .60743 .5563 .60079 .53906 Mtetra
.703 .601 .739 r
.60079 .53906 .60743 .5563 .61985 .54471 .61328 .52999 Mtetra
.729 .638 .756 r
.61328 .52999 .61985 .54471 .63226 .53304 .62577 .51999 Mtetra
.751 .666 .767 r
.62577 .51999 .63226 .53304 .64464 .52083 .63824 .50921 Mtetra
.766 .691 .78 r
.63824 .50921 .64464 .52083 .65703 .50869 .65071 .49822 Mtetra
.777 .714 .793 r
.65071 .49822 .65703 .50869 .66942 .49678 .66317 .48722 Mtetra
.786 .733 .804 r
.66317 .48722 .66942 .49678 .68181 .48507 .67565 .47624 Mtetra
.791 .75 .815 r
.67565 .47624 .68181 .48507 .69422 .4737 .68813 .46543 Mtetra
.795 .764 .824 r
.68813 .46543 .69422 .4737 .70665 .46262 .70063 .45477 Mtetra
.797 .775 .833 r
.70063 .45477 .70665 .46262 .71909 .45185 .71315 .44431 Mtetra
.797 .784 .84 r
.71315 .44431 .71909 .45185 .73156 .44136 .72568 .43405 Mtetra
.797 .791 .847 r
.72568 .43405 .73156 .44136 .74406 .43115 .73824 .42398 Mtetra
.795 .796 .852 r
.73824 .42398 .74406 .43115 .75658 .4212 .75082 .41411 Mtetra
.794 .799 .856 r
.75082 .41411 .75658 .4212 .76913 .41147 .76343 .40442 Mtetra
.791 .8 .86 r
.76343 .40442 .76913 .41147 .78171 .40195 .77607 .39489 Mtetra
.789 .801 .862 r
.77607 .39489 .78171 .40195 .79433 .39261 .78873 .38552 Mtetra
.786 .801 .864 r
.78873 .38552 .79433 .39261 .80697 .38344 .80143 .37627 Mtetra
.783 .8 .866 r
.80143 .37627 .80697 .38344 .81965 .37439 .81415 .36714 Mtetra
.781 .798 .866 r
.81415 .36714 .81965 .37439 .83235 .36546 .8269 .35811 Mtetra
.779 .796 .866 r
.8269 .35811 .83235 .36546 .84509 .35662 .83968 .34915 Mtetra
.777 .793 .866 r
.83968 .34915 .84509 .35662 .85785 .34785 .85249 .34025 Mtetra
.775 .79 .865 r
.85249 .34025 .85785 .34785 .87065 .33913 .86532 .3314 Mtetra
.773 .787 .864 r
.86532 .3314 .87065 .33913 .88347 .33043 .87818 .32256 Mtetra
.772 .784 .863 r
.87818 .32256 .88347 .33043 .89632 .32173 .89107 .31372 Mtetra
.437 .66 .955 r
.29278 .49911 .29979 .50564 .31039 .5064 .30339 .49992 Mtetra
.433 .661 .957 r
.30339 .49992 .31039 .5064 .32106 .50718 .31407 .50076 Mtetra
.428 .662 .958 r
.31407 .50076 .32106 .50718 .33179 .508 .32482 .50163 Mtetra
.422 .662 .96 r
.32482 .50163 .33179 .508 .3426 .50887 .33565 .50255 Mtetra
.415 .66 .961 r
.33565 .50255 .3426 .50887 .35348 .50983 .34654 .50354 Mtetra
.407 .659 .962 r
.34654 .50354 .35348 .50983 .36443 .51088 .35751 .50461 Mtetra
.399 .656 .962 r
.35751 .50461 .36443 .51088 .37545 .51204 .36855 .50578 Mtetra
.389 .652 .962 r
.36855 .50578 .37545 .51204 .38654 .51334 .37966 .50706 Mtetra
.38 .648 .962 r
.37966 .50706 .38654 .51334 .39771 .51479 .39085 .50847 Mtetra
.371 .643 .961 r
.39085 .50847 .39771 .51479 .40896 .5164 .40212 .51001 Mtetra
.362 .636 .959 r
.40212 .51001 .40896 .5164 .42028 .5182 .41346 .51171 Mtetra
.356 .63 .957 r
.41346 .51171 .42028 .5182 .43168 .5202 .42489 .51355 Mtetra
.35 .622 .953 r
.42489 .51355 .43168 .5202 .44317 .52241 .4364 .51555 Mtetra
.349 .614 .95 r
.4364 .51555 .44317 .52241 .45474 .52485 .448 .5177 Mtetra
.351 .606 .945 r
.448 .5177 .45474 .52485 .4664 .5275 .45968 .51999 Mtetra
.358 .598 .938 r
.45968 .51999 .4664 .5275 .47815 .53038 .47146 .52241 Mtetra
.372 .591 .93 r
.47146 .52241 .47815 .53038 .49 .53343 .48333 .52489 Mtetra
.388 .582 .919 r
.48333 .52489 .49 .53343 .50195 .53669 .4953 .52743 Mtetra
.414 .577 .905 r
.4953 .52743 .50195 .53669 .514 .53999 .50737 .52987 Mtetra
.442 .57 .887 r
.50737 .52987 .514 .53999 .52616 .54331 .51953 .53214 Mtetra
.474 .564 .866 r
.51953 .53214 .52616 .54331 .53842 .54646 .5318 .53405 Mtetra
.515 .562 .841 r
.5318 .53405 .53842 .54646 .55078 .54886 .54415 .5352 Mtetra
.549 .56 .818 r
.54415 .5352 .55078 .54886 .56323 .55037 .55659 .53543 Mtetra
.588 .564 .795 r
.55659 .53543 .56323 .55037 .57574 .54998 .5691 .53411 Mtetra
.635 .579 .774 r
.5691 .53411 .57574 .54998 .58827 .54622 .58163 .53031 Mtetra
.674 .599 .763 r
.58163 .53031 .58827 .54622 .60079 .53906 .59418 .524 Mtetra
.701 .621 .764 r
.59418 .524 .60079 .53906 .61328 .52999 .60672 .51614 Mtetra
.721 .644 .772 r
.60672 .51614 .61328 .52999 .62577 .51999 .61926 .50731 Mtetra
.74 .667 .779 r
.61926 .50731 .62577 .51999 .63824 .50921 .6318 .49771 Mtetra
.754 .69 .79 r
.6318 .49771 .63824 .50921 .65071 .49822 .64434 .48772 Mtetra
.766 .711 .8 r
.64434 .48772 .65071 .49822 .66317 .48722 .65688 .47752 Mtetra
.776 .729 .81 r
.65688 .47752 .66317 .48722 .67565 .47624 .66943 .4672 Mtetra
.782 .745 .819 r
.66943 .4672 .67565 .47624 .68813 .46543 .68199 .45691 Mtetra
.787 .758 .827 r
.68199 .45691 .68813 .46543 .70063 .45477 .69455 .44665 Mtetra
.79 .769 .834 r
.69455 .44665 .70063 .45477 .71315 .44431 .70714 .4365 Mtetra
.791 .778 .84 r
.70714 .4365 .71315 .44431 .72568 .43405 .71974 .42646 Mtetra
.792 .784 .846 r
.71974 .42646 .72568 .43405 .73824 .42398 .73236 .41654 Mtetra
.791 .789 .851 r
.73236 .41654 .73824 .42398 .75082 .41411 .745 .40677 Mtetra
.79 .793 .855 r
.745 .40677 .75082 .41411 .76343 .40442 .75767 .39713 Mtetra
.789 .795 .858 r
.75767 .39713 .76343 .40442 .77607 .39489 .77036 .38761 Mtetra
.787 .796 .86 r
.77036 .38761 .77607 .39489 .78873 .38552 .78308 .37821 Mtetra
.785 .796 .862 r
.78308 .37821 .78873 .38552 .80143 .37627 .79582 .36892 Mtetra
.783 .796 .863 r
.79582 .36892 .80143 .37627 .81415 .36714 .80859 .35972 Mtetra
.781 .795 .864 r
.80859 .35972 .81415 .36714 .8269 .35811 .82139 .3506 Mtetra
.779 .793 .864 r
.82139 .3506 .8269 .35811 .83968 .34915 .83422 .34155 Mtetra
.777 .791 .864 r
.83422 .34155 .83968 .34915 .85249 .34025 .84707 .33254 Mtetra
.776 .789 .864 r
.84707 .33254 .85249 .34025 .86532 .3314 .85995 .32356 Mtetra
.775 .787 .863 r
.85995 .32356 .86532 .3314 .87818 .32256 .87285 .3146 Mtetra
.774 .784 .862 r
.87285 .3146 .87818 .32256 .89107 .31372 .88578 .30565 Mtetra
.433 .659 .955 r
.28572 .49254 .29278 .49911 .30339 .49992 .29634 .49339 Mtetra
.429 .659 .957 r
.29634 .49339 .30339 .49992 .31407 .50076 .30704 .49426 Mtetra
.425 .659 .958 r
.30704 .49426 .31407 .50076 .32482 .50163 .3178 .49516 Mtetra
.42 .659 .959 r
.3178 .49516 .32482 .50163 .33565 .50255 .32864 .49611 Mtetra
.415 .658 .96 r
.32864 .49611 .33565 .50255 .34654 .50354 .33955 .49712 Mtetra
.408 .656 .96 r
.33955 .49712 .34654 .50354 .35751 .50461 .35053 .4982 Mtetra
.401 .654 .961 r
.35053 .4982 .35751 .50461 .36855 .50578 .36159 .49937 Mtetra
.394 .651 .961 r
.36159 .49937 .36855 .50578 .37966 .50706 .37272 .50062 Mtetra
.387 .647 .96 r
.37272 .50062 .37966 .50706 .39085 .50847 .38394 .50198 Mtetra
.381 .643 .959 r
.38394 .50198 .39085 .50847 .40212 .51001 .39522 .50345 Mtetra
.375 .638 .958 r
.39522 .50345 .40212 .51001 .41346 .51171 .40659 .50503 Mtetra
.372 .633 .956 r
.40659 .50503 .41346 .51171 .42489 .51355 .41804 .50672 Mtetra
.37 .628 .953 r
.41804 .50672 .42489 .51355 .4364 .51555 .42958 .50852 Mtetra
.372 .622 .949 r
.42958 .50852 .4364 .51555 .448 .5177 .4412 .5104 Mtetra
.378 .617 .945 r
.4412 .5104 .448 .5177 .45968 .51999 .45291 .51236 Mtetra
.387 .611 .939 r
.45291 .51236 .45968 .51999 .47146 .52241 .46472 .51437 Mtetra
.403 .607 .931 r
.46472 .51437 .47146 .52241 .48333 .52489 .47661 .51635 Mtetra
.42 .601 .921 r
.47661 .51635 .48333 .52489 .4953 .52743 .4886 .51828 Mtetra
.446 .598 .908 r
.4886 .51828 .4953 .52743 .50737 .52987 .50069 .52001 Mtetra
.473 .594 .893 r
.50069 .52001 .50737 .52987 .51953 .53214 .51287 .52145 Mtetra
.503 .591 .875 r
.51287 .52145 .51953 .53214 .5318 .53405 .52514 .52242 Mtetra
.538 .59 .854 r
.52514 .52242 .5318 .53405 .54415 .5352 .53751 .52264 Mtetra
.571 .59 .833 r
.53751 .52264 .54415 .5352 .55659 .53543 .54995 .52188 Mtetra
.604 .592 .812 r
.54995 .52188 .55659 .53543 .5691 .53411 .56245 .51985 Mtetra
.64 .6 .794 r
.56245 .51985 .5691 .53411 .58163 .53031 .575 .516 Mtetra
.672 .616 .784 r
.575 .516 .58163 .53031 .59418 .524 .58757 .51034 Mtetra
.695 .635 .785 r
.58757 .51034 .59418 .524 .60672 .51614 .60015 .50339 Mtetra
.716 .657 .79 r
.60015 .50339 .60672 .51614 .61926 .50731 .61275 .49543 Mtetra
.734 .677 .795 r
.61275 .49543 .61926 .50731 .6318 .49771 .62535 .48669 Mtetra
.748 .697 .803 r
.62535 .48669 .6318 .49771 .64434 .48772 .63795 .47747 Mtetra
.759 .715 .81 r
.63795 .47747 .64434 .48772 .65688 .47752 .65056 .46793 Mtetra
.769 .73 .817 r
.65056 .46793 .65688 .47752 .66943 .4672 .66317 .45815 Mtetra
.775 .744 .825 r
.66317 .45815 .66943 .4672 .68199 .45691 .67579 .4483 Mtetra
.781 .756 .831 r
.67579 .4483 .68199 .45691 .69455 .44665 .68843 .4384 Mtetra
.784 .766 .837 r
.68843 .4384 .69455 .44665 .70714 .4365 .70107 .42852 Mtetra
.786 .774 .842 r
.70107 .42852 .70714 .4365 .71974 .42646 .71374 .41868 Mtetra
.787 .78 .846 r
.71374 .41868 .71974 .42646 .73236 .41654 .72642 .40892 Mtetra
.787 .785 .85 r
.72642 .40892 .73236 .41654 .745 .40677 .73912 .39924 Mtetra
.787 .789 .854 r
.73912 .39924 .745 .40677 .75767 .39713 .75185 .38964 Mtetra
.786 .791 .856 r
.75185 .38964 .75767 .39713 .77036 .38761 .76459 .38014 Mtetra
.785 .792 .859 r
.76459 .38014 .77036 .38761 .78308 .37821 .77737 .37073 Mtetra
.784 .793 .86 r
.77737 .37073 .78308 .37821 .79582 .36892 .79016 .3614 Mtetra
.782 .793 .861 r
.79016 .3614 .79582 .36892 .80859 .35972 .80298 .35215 Mtetra
.781 .792 .862 r
.80298 .35215 .80859 .35972 .82139 .3506 .81583 .34295 Mtetra
.779 .791 .863 r
.81583 .34295 .82139 .3506 .83422 .34155 .8287 .33381 Mtetra
.778 .79 .863 r
.8287 .33381 .83422 .34155 .84707 .33254 .8416 .32471 Mtetra
.777 .788 .862 r
.8416 .32471 .84707 .33254 .85995 .32356 .85453 .31563 Mtetra
.775 .786 .862 r
.85453 .31563 .85995 .32356 .87285 .3146 .86747 .30657 Mtetra
.775 .784 .861 r
.86747 .30657 .87285 .3146 .88578 .30565 .88044 .2975 Mtetra
.429 .657 .955 r
.2786 .48591 .28572 .49254 .29634 .49339 .28924 .48679 Mtetra
.426 .657 .956 r
.28924 .48679 .29634 .49339 .30704 .49426 .29995 .48768 Mtetra
.423 .657 .957 r
.29995 .48768 .30704 .49426 .3178 .49516 .31073 .48861 Mtetra
.419 .657 .958 r
.31073 .48861 .3178 .49516 .32864 .49611 .32158 .48958 Mtetra
.415 .656 .959 r
.32158 .48958 .32864 .49611 .33955 .49712 .33251 .49059 Mtetra
.409 .655 .959 r
.33251 .49059 .33955 .49712 .35053 .4982 .34351 .49167 Mtetra
.404 .653 .959 r
.34351 .49167 .35053 .4982 .36159 .49937 .35459 .49282 Mtetra
.399 .65 .959 r
.35459 .49282 .36159 .49937 .37272 .50062 .36574 .49404 Mtetra
.394 .647 .959 r
.36574 .49404 .37272 .50062 .38394 .50198 .37697 .49534 Mtetra
.39 .644 .958 r
.37697 .49534 .38394 .50198 .39522 .50345 .38828 .49673 Mtetra
.387 .64 .956 r
.38828 .49673 .39522 .50345 .40659 .50503 .39967 .4982 Mtetra
.386 .637 .955 r
.39967 .4982 .40659 .50503 .41804 .50672 .41115 .49974 Mtetra
.387 .633 .952 r
.41115 .49974 .41804 .50672 .42958 .50852 .42271 .50135 Mtetra
.391 .629 .949 r
.42271 .50135 .42958 .50852 .4412 .5104 .43436 .50299 Mtetra
.399 .626 .945 r
.43436 .50299 .4412 .5104 .45291 .51236 .44609 .50465 Mtetra
.41 .622 .939 r
.44609 .50465 .45291 .51236 .46472 .51437 .45792 .5063 Mtetra
.427 .62 .932 r
.45792 .5063 .46472 .51437 .47661 .51635 .46984 .50784 Mtetra
.445 .617 .923 r
.46984 .50784 .47661 .51635 .4886 .51828 .48185 .50926 Mtetra
.47 .615 .912 r
.48185 .50926 .4886 .51828 .50069 .52001 .49396 .51041 Mtetra
.496 .613 .898 r
.49396 .51041 .50069 .52001 .51287 .52145 .50616 .5112 Mtetra
.524 .612 .882 r
.50616 .5112 .51287 .52145 .52514 .52242 .51845 .51148 Mtetra
.555 .613 .865 r
.51845 .51148 .52514 .52242 .53751 .52264 .53083 .51103 Mtetra
.586 .615 .848 r
.53083 .51103 .53751 .52264 .54995 .52188 .54328 .50963 Mtetra
.615 .618 .831 r
.54328 .50963 .54995 .52188 .56245 .51985 .55579 .50715 Mtetra
.645 .626 .816 r
.55579 .50715 .56245 .51985 .575 .516 .56836 .50327 Mtetra
.672 .638 .807 r
.56836 .50327 .575 .516 .58757 .51034 .58095 .49798 Mtetra
.694 .654 .806 r
.58095 .49798 .58757 .51034 .60015 .50339 .59358 .49158 Mtetra
.713 .671 .807 r
.59358 .49158 .60015 .50339 .61275 .49543 .60622 .48423 Mtetra
.73 .688 .81 r
.60622 .48423 .61275 .49543 .62535 .48669 .61886 .47612 Mtetra
.743 .704 .815 r
.61886 .47612 .62535 .48669 .63795 .47747 .63152 .46749 Mtetra
.754 .719 .82 r
.63152 .46749 .63795 .47747 .65056 .46793 .64419 .45846 Mtetra
.763 .733 .825 r
.64419 .45846 .65056 .46793 .66317 .45815 .65686 .44914 Mtetra
.77 .745 .83 r
.65686 .44914 .66317 .45815 .67579 .4483 .66955 .43966 Mtetra
.776 .755 .835 r
.66955 .43966 .67579 .4483 .68843 .4384 .68225 .43006 Mtetra
.779 .764 .839 r
.68225 .43006 .68843 .4384 .70107 .42852 .69496 .42042 Mtetra
.782 .772 .844 r
.69496 .42042 .70107 .42852 .71374 .41868 .70768 .41077 Mtetra
.784 .778 .847 r
.70768 .41077 .71374 .41868 .72642 .40892 .72042 .40113 Mtetra
.784 .782 .851 r
.72042 .40113 .72642 .40892 .73912 .39924 .73319 .39154 Mtetra
.785 .786 .853 r
.73319 .39154 .73912 .39924 .75185 .38964 .74597 .38199 Mtetra
.784 .788 .856 r
.74597 .38199 .75185 .38964 .76459 .38014 .75877 .37251 Mtetra
.783 .789 .858 r
.75877 .37251 .76459 .38014 .77737 .37073 .77159 .36309 Mtetra
.782 .79 .859 r
.77159 .36309 .77737 .37073 .79016 .3614 .78444 .35373 Mtetra
.781 .79 .86 r
.78444 .35373 .79016 .3614 .80298 .35215 .79732 .34443 Mtetra
.78 .79 .861 r
.79732 .34443 .80298 .35215 .81583 .34295 .81021 .33517 Mtetra
.779 .789 .861 r
.81021 .33517 .81583 .34295 .8287 .33381 .82314 .32595 Mtetra
.778 .788 .861 r
.82314 .32595 .8287 .33381 .8416 .32471 .83608 .31677 Mtetra
.777 .787 .861 r
.83608 .31677 .8416 .32471 .85453 .31563 .84905 .3076 Mtetra
.776 .786 .861 r
.84905 .3076 .85453 .31563 .86747 .30657 .86205 .29845 Mtetra
.775 .784 .86 r
.86205 .29845 .86747 .30657 .88044 .2975 .87506 .28929 Mtetra
.426 .656 .955 r
.27143 .47923 .2786 .48591 .28924 .48679 .28208 .48012 Mtetra
.424 .656 .956 r
.28208 .48012 .28924 .48679 .29995 .48768 .2928 .48103 Mtetra
.422 .656 .957 r
.2928 .48103 .29995 .48768 .31073 .48861 .3036 .48197 Mtetra
.418 .656 .957 r
.3036 .48197 .31073 .48861 .32158 .48958 .31447 .48294 Mtetra
.415 .655 .958 r
.31447 .48294 .32158 .48958 .33251 .49059 .32541 .48396 Mtetra
.411 .653 .958 r
.32541 .48396 .33251 .49059 .34351 .49167 .33643 .48503 Mtetra
.407 .652 .958 r
.33643 .48503 .34351 .49167 .35459 .49282 .34753 .48615 Mtetra
.403 .65 .958 r
.34753 .48615 .35459 .49282 .36574 .49404 .3587 .48734 Mtetra
.399 .648 .958 r
.3587 .48734 .36574 .49404 .37697 .49534 .36995 .48858 Mtetra
.397 .645 .957 r
.36995 .48858 .37697 .49534 .38828 .49673 .38129 .48989 Mtetra
.396 .642 .956 r
.38129 .48989 .38828 .49673 .39967 .4982 .3927 .49126 Mtetra
.397 .64 .954 r
.3927 .49126 .39967 .4982 .41115 .49974 .4042 .49266 Mtetra
.399 .637 .952 r
.4042 .49266 .41115 .49974 .42271 .50135 .41578 .4941 Mtetra
.405 .635 .949 r
.41578 .4941 .42271 .50135 .43436 .50299 .42746 .49553 Mtetra
.415 .634 .945 r
.42746 .49553 .43436 .50299 .44609 .50465 .43922 .49693 Mtetra
.427 .632 .94 r
.43922 .49693 .44609 .50465 .45792 .5063 .45107 .49827 Mtetra
.444 .631 .934 r
.45107 .49827 .45792 .5063 .46984 .50784 .46302 .49945 Mtetra
.463 .63 .926 r
.46302 .49945 .46984 .50784 .48185 .50926 .47506 .50045 Mtetra
.486 .631 .916 r
.47506 .50045 .48185 .50926 .49396 .51041 .48719 .50114 Mtetra
.512 .631 .905 r
.48719 .50114 .49396 .51041 .50616 .5112 .49941 .50142 Mtetra
.538 .632 .891 r
.49941 .50142 .50616 .5112 .51845 .51148 .51172 .50117 Mtetra
.567 .633 .877 r
.51172 .50117 .51845 .51148 .53083 .51103 .52411 .50023 Mtetra
.595 .637 .862 r
.52411 .50023 .53083 .51103 .54328 .50963 .53658 .49843 Mtetra
.621 .641 .849 r
.53658 .49843 .54328 .50963 .55579 .50715 .54911 .49568 Mtetra
.649 .649 .837 r
.54911 .49568 .55579 .50715 .56836 .50327 .5617 .49176 Mtetra
.674 .66 .828 r
.5617 .49176 .56836 .50327 .58095 .49798 .57432 .48667 Mtetra
.694 .672 .824 r
.57432 .48667 .58095 .49798 .59358 .49158 .58698 .48061 Mtetra
.712 .685 .823 r
.58698 .48061 .59358 .49158 .60622 .48423 .59966 .47367 Mtetra
.727 .699 .824 r
.59966 .47367 .60622 .48423 .61886 .47612 .61235 .46602 Mtetra
.74 .713 .826 r
.61235 .46602 .61886 .47612 .63152 .46749 .62507 .45783 Mtetra
.75 .726 .829 r
.62507 .45783 .63152 .46749 .64419 .45846 .63779 .4492 Mtetra
.759 .737 .832 r
.63779 .4492 .64419 .45846 .65686 .44914 .65052 .44024 Mtetra
.766 .748 .836 r
.65052 .44024 .65686 .44914 .66955 .43966 .66327 .43106 Mtetra
.772 .757 .839 r
.66327 .43106 .66955 .43966 .68225 .43006 .67602 .42171 Mtetra
.776 .765 .843 r
.67602 .42171 .68225 .43006 .69496 .42042 .68879 .41226 Mtetra
.779 .771 .846 r
.68879 .41226 .69496 .42042 .70768 .41077 .70158 .40276 Mtetra
.781 .776 .849 r
.70158 .40276 .70768 .41077 .72042 .40113 .71438 .39323 Mtetra
.782 .78 .851 r
.71438 .39323 .72042 .40113 .73319 .39154 .72719 .38371 Mtetra
.783 .784 .853 r
.72719 .38371 .73319 .39154 .74597 .38199 .74003 .37421 Mtetra
.782 .786 .855 r
.74003 .37421 .74597 .38199 .75877 .37251 .75289 .36474 Mtetra
.782 .787 .857 r
.75289 .36474 .75877 .37251 .77159 .36309 .76577 .35531 Mtetra
.782 .788 .858 r
.76577 .35531 .77159 .36309 .78444 .35373 .77867 .34592 Mtetra
.781 .788 .859 r
.77867 .34592 .78444 .35373 .79732 .34443 .7916 .33658 Mtetra
.78 .788 .86 r
.7916 .33658 .79732 .34443 .81021 .33517 .80454 .32727 Mtetra
.779 .788 .86 r
.80454 .32727 .81021 .33517 .82314 .32595 .81752 .31799 Mtetra
.778 .787 .86 r
.81752 .31799 .82314 .32595 .83608 .31677 .83051 .30873 Mtetra
.777 .786 .86 r
.83051 .30873 .83608 .31677 .84905 .3076 .84353 .29948 Mtetra
.777 .785 .86 r
.84353 .29948 .84905 .3076 .86205 .29845 .85657 .29025 Mtetra
.776 .784 .859 r
.85657 .29025 .86205 .29845 .87506 .28929 .86963 .28101 Mtetra
.424 .655 .955 r
.2642 .4725 .27143 .47923 .28208 .48012 .27487 .4734 Mtetra
.423 .655 .956 r
.27487 .4734 .28208 .48012 .2928 .48103 .2856 .47432 Mtetra
.421 .655 .956 r
.2856 .47432 .2928 .48103 .3036 .48197 .29641 .47526 Mtetra
.418 .654 .957 r
.29641 .47526 .3036 .48197 .31447 .48294 .3073 .47623 Mtetra
.415 .654 .957 r
.3073 .47623 .31447 .48294 .32541 .48396 .31826 .47723 Mtetra
.412 .653 .957 r
.31826 .47723 .32541 .48396 .33643 .48503 .3293 .47828 Mtetra
.409 .651 .957 r
.3293 .47828 .33643 .48503 .34753 .48615 .34041 .47938 Mtetra
.406 .65 .957 r
.34041 .47938 .34753 .48615 .3587 .48734 .35161 .48053 Mtetra
.404 .648 .957 r
.35161 .48053 .3587 .48734 .36995 .48858 .36288 .48172 Mtetra
.402 .646 .956 r
.36288 .48172 .36995 .48858 .38129 .48989 .37423 .48296 Mtetra
.402 .644 .955 r
.37423 .48296 .38129 .48989 .3927 .49126 .38567 .48423 Mtetra
.405 .643 .954 r
.38567 .48423 .3927 .49126 .4042 .49266 .3972 .48552 Mtetra
.408 .642 .952 r
.3972 .48552 .4042 .49266 .41578 .4941 .4088 .48681 Mtetra
.415 .641 .95 r
.4088 .48681 .41578 .4941 .42746 .49553 .4205 .48807 Mtetra
.425 .641 .946 r
.4205 .48807 .42746 .49553 .43922 .49693 .43229 .48926 Mtetra
.438 .641 .943 r
.43229 .48926 .43922 .49693 .45107 .49827 .44417 .49035 Mtetra
.455 .642 .937 r
.44417 .49035 .45107 .49827 .46302 .49945 .45614 .49124 Mtetra
.474 .643 .931 r
.45614 .49124 .46302 .49945 .47506 .50045 .4682 .49191 Mtetra
.497 .645 .923 r
.4682 .49191 .47506 .50045 .48719 .50114 .48036 .49224 Mtetra
.522 .647 .913 r
.48036 .49224 .48719 .50114 .49941 .50142 .4926 .49214 Mtetra
.548 .65 .902 r
.4926 .49214 .49941 .50142 .51172 .50117 .50494 .4915 Mtetra
.574 .653 .889 r
.50494 .4915 .51172 .50117 .52411 .50023 .51735 .4902 Mtetra
.602 .657 .877 r
.51735 .4902 .52411 .50023 .53658 .49843 .52984 .48809 Mtetra
.627 .662 .865 r
.52984 .48809 .53658 .49843 .54911 .49568 .54239 .48512 Mtetra
.652 .669 .853 r
.54239 .48512 .54911 .49568 .5617 .49176 .555 .48116 Mtetra
.674 .678 .845 r
.555 .48116 .5617 .49176 .57432 .48667 .56766 .47621 Mtetra
.693 .689 .841 r
.56766 .47621 .57432 .48667 .58698 .48061 .58035 .47039 Mtetra
.711 .701 .839 r
.58035 .47039 .58698 .48061 .59966 .47367 .59307 .46375 Mtetra
.726 .712 .838 r
.59307 .46375 .59966 .47367 .61235 .46602 .60582 .45643 Mtetra
.738 .724 .838 r
.60582 .45643 .61235 .46602 .62507 .45783 .61857 .44855 Mtetra
.748 .734 .839 r
.61857 .44855 .62507 .45783 .63779 .4492 .63135 .44021 Mtetra
.757 .744 .841 r
.63135 .44021 .63779 .4492 .65052 .44024 .64414 .43151 Mtetra
.764 .753 .843 r
.64414 .43151 .65052 .44024 .66327 .43106 .65694 .42256 Mtetra
.77 .76 .844 r
.65694 .42256 .66327 .43106 .67602 .42171 .66975 .41339 Mtetra
.774 .767 .847 r
.66975 .41339 .67602 .42171 .68879 .41226 .68258 .4041 Mtetra
.777 .772 .849 r
.68258 .4041 .68879 .41226 .70158 .40276 .69542 .39471 Mtetra
.779 .777 .85 r
.69542 .39471 .70158 .40276 .71438 .39323 .70828 .38526 Mtetra
.78 .78 .852 r
.70828 .38526 .71438 .39323 .72719 .38371 .72115 .37579 Mtetra
.781 .783 .854 r
.72115 .37579 .72719 .38371 .74003 .37421 .73404 .36632 Mtetra
.781 .785 .855 r
.73404 .36632 .74003 .37421 .75289 .36474 .74696 .35686 Mtetra
.781 .786 .857 r
.74696 .35686 .75289 .36474 .76577 .35531 .75989 .34742 Mtetra
.781 .787 .858 r
.75989 .34742 .76577 .35531 .77867 .34592 .77284 .338 Mtetra
.78 .787 .858 r
.77284 .338 .77867 .34592 .7916 .33658 .78582 .32861 Mtetra
.779 .787 .859 r
.78582 .32861 .7916 .33658 .80454 .32727 .79882 .31925 Mtetra
.79882 .31925 .80454 .32727 .81752 .31799 .81184 .30991 Mtetra
.778 .786 .859 r
.81184 .30991 .81752 .31799 .83051 .30873 .82489 .30059 Mtetra
.777 .785 .859 r
.82489 .30059 .83051 .30873 .84353 .29948 .83796 .29128 Mtetra
.83796 .29128 .84353 .29948 .85657 .29025 .85105 .28196 Mtetra
.776 .784 .859 r
.85105 .28196 .85657 .29025 .86963 .28101 .86416 .27265 Mtetra
.423 .654 .955 r
.25692 .46572 .2642 .4725 .27487 .4734 .2676 .46662 Mtetra
.422 .654 .956 r
.2676 .46662 .27487 .4734 .2856 .47432 .27835 .46753 Mtetra
.42 .654 .956 r
.27835 .46753 .2856 .47432 .29641 .47526 .28917 .46846 Mtetra
.418 .654 .956 r
.28917 .46846 .29641 .47526 .3073 .47623 .30008 .46942 Mtetra
.416 .653 .957 r
.30008 .46942 .3073 .47623 .31826 .47723 .31106 .47042 Mtetra
.413 .652 .957 r
.31106 .47042 .31826 .47723 .3293 .47828 .32211 .47145 Mtetra
.411 .651 .957 r
.32211 .47145 .3293 .47828 .34041 .47938 .33325 .47252 Mtetra
.409 .65 .956 r
.33325 .47252 .34041 .47938 .35161 .48053 .34446 .47363 Mtetra
.407 .648 .956 r
.34446 .47363 .35161 .48053 .36288 .48172 .35575 .47478 Mtetra
.407 .647 .956 r
.35575 .47478 .36288 .48172 .37423 .48296 .36713 .47595 Mtetra
.407 .646 .955 r
.36713 .47595 .37423 .48296 .38567 .48423 .37859 .47715 Mtetra
.41 .645 .954 r
.37859 .47715 .38567 .48423 .3972 .48552 .39013 .47833 Mtetra
.414 .645 .952 r
.39013 .47833 .3972 .48552 .4088 .48681 .40177 .47951 Mtetra
.422 .645 .95 r
.40177 .47951 .4088 .48681 .4205 .48807 .41349 .48063 Mtetra
.432 .646 .948 r
.41349 .48063 .4205 .48807 .43229 .48926 .4253 .48165 Mtetra
.445 .648 .945 r
.4253 .48165 .43229 .48926 .44417 .49035 .43721 .48254 Mtetra
.462 .651 .941 r
.43721 .48254 .44417 .49035 .45614 .49124 .4492 .48322 Mtetra
.481 .654 .936 r
.4492 .48322 .45614 .49124 .4682 .49191 .46129 .48364 Mtetra
.503 .657 .929 r
.46129 .48364 .4682 .49191 .48036 .49224 .47347 .48371 Mtetra
.527 .662 .921 r
.47347 .48371 .48036 .49224 .4926 .49214 .48575 .48333 Mtetra
.553 .666 .912 r
.48575 .48333 .4926 .49214 .50494 .4915 .4981 .48242 Mtetra
.579 .671 .902 r
.4981 .48242 .50494 .4915 .51735 .4902 .51054 .48087 Mtetra
.605 .677 .892 r
.51054 .48087 .51735 .4902 .52984 .48809 .52306 .47857 Mtetra
.63 .683 .882 r
.52306 .47857 .52984 .48809 .54239 .48512 .53564 .47547 Mtetra
.654 .691 .872 r
.53564 .47547 .54239 .48512 .555 .48116 .54828 .47148 Mtetra
.676 .699 .864 r
.54828 .47148 .555 .48116 .56766 .47621 .56097 .46658 Mtetra
.695 .708 .858 r
.56097 .46658 .56766 .47621 .58035 .47039 .57369 .46089 Mtetra
.712 .717 .853 r
.57369 .46089 .58035 .47039 .59307 .46375 .58645 .45442 Mtetra
.726 .726 .851 r
.58645 .45442 .59307 .46375 .60582 .45643 .59924 .4473 Mtetra
.738 .735 .849 r
.59924 .4473 .60582 .45643 .61857 .44855 .61205 .43963 Mtetra
.748 .744 .848 r
.61205 .43963 .61857 .44855 .63135 .44021 .62487 .43149 Mtetra
.756 .751 .848 r
.62487 .43149 .63135 .44021 .64414 .43151 .63771 .42297 Mtetra
.763 .758 .849 r
.63771 .42297 .64414 .43151 .65694 .42256 .65057 .41417 Mtetra
.768 .764 .849 r
.65057 .41417 .65694 .42256 .66975 .41339 .66343 .40513 Mtetra
.772 .769 .85 r
.66343 .40513 .66975 .41339 .68258 .4041 .67632 .39594 Mtetra
.775 .774 .851 r
.67632 .39594 .68258 .4041 .69542 .39471 .68921 .38663 Mtetra
.778 .777 .852 r
.68921 .38663 .69542 .39471 .70828 .38526 .70213 .37723 Mtetra
.779 .78 .853 r
.70213 .37723 .70828 .38526 .72115 .37579 .71505 .3678 Mtetra
.78 .782 .854 r
.71505 .3678 .72115 .37579 .73404 .36632 .728 .35833 Mtetra
.78 .784 .855 r
.728 .35833 .73404 .36632 .74696 .35686 .74097 .34887 Mtetra
.78 .785 .856 r
.74097 .34887 .74696 .35686 .75989 .34742 .75396 .33941 Mtetra
.78 .785 .857 r
.75396 .33941 .75989 .34742 .77284 .338 .76696 .32997 Mtetra
.78 .786 .858 r
.76696 .32997 .77284 .338 .78582 .32861 .77999 .32054 Mtetra
.779 .786 .858 r
.77999 .32054 .78582 .32861 .79882 .31925 .79304 .31113 Mtetra
.779 .786 .859 r
.79304 .31113 .79882 .31925 .81184 .30991 .80612 .30174 Mtetra
.778 .785 .859 r
.80612 .30174 .81184 .30991 .82489 .30059 .81921 .29235 Mtetra
.81921 .29235 .82489 .30059 .83796 .29128 .83233 .28298 Mtetra
.777 .784 .859 r
.83233 .28298 .83796 .29128 .85105 .28196 .84547 .2736 Mtetra
.84547 .2736 .85105 .28196 .86416 .27265 .85864 .26422 Mtetra
.422 .654 .955 r
.24958 .45888 .25692 .46572 .2676 .46662 .26027 .45977 Mtetra
.421 .654 .956 r
.26027 .45977 .2676 .46662 .27835 .46753 .27104 .46067 Mtetra
.42 .653 .956 r
.27104 .46067 .27835 .46753 .28917 .46846 .28188 .4616 Mtetra
.418 .653 .956 r
.28188 .4616 .28917 .46846 .30008 .46942 .2928 .46255 Mtetra
.416 .652 .956 r
.2928 .46255 .30008 .46942 .31106 .47042 .3038 .46352 Mtetra
.414 .651 .956 r
.3038 .46352 .31106 .47042 .32211 .47145 .31487 .46453 Mtetra
.412 .651 .956 r
.31487 .46453 .32211 .47145 .33325 .47252 .32602 .46558 Mtetra
.41 .65 .956 r
.32602 .46558 .33325 .47252 .34446 .47363 .33725 .46666 Mtetra
.409 .649 .956 r
.33725 .46666 .34446 .47363 .35575 .47478 .34857 .46776 Mtetra
.409 .648 .955 r
.34857 .46776 .35575 .47478 .36713 .47595 .35996 .46889 Mtetra
.41 .647 .955 r
.35996 .46889 .36713 .47595 .37859 .47715 .37145 .47002 Mtetra
.413 .648 .954 r
.37145 .47002 .37859 .47715 .39013 .47833 .38301 .47114 Mtetra
.417 .648 .953 r
.38301 .47114 .39013 .47833 .40177 .47951 .39467 .47223 Mtetra
.425 .649 .952 r
.39467 .47223 .40177 .47951 .41349 .48063 .40642 .47324 Mtetra
.435 .652 .951 r
.40642 .47324 .41349 .48063 .4253 .48165 .41825 .47415 Mtetra
.447 .655 .948 r
.41825 .47415 .4253 .48165 .43721 .48254 .43018 .4749 Mtetra
.464 .659 .946 r
.43018 .4749 .43721 .48254 .4492 .48322 .44221 .47543 Mtetra
.482 .663 .942 r
.44221 .47543 .4492 .48322 .46129 .48364 .45432 .47567 Mtetra
.504 .669 .937 r
.45432 .47567 .46129 .48364 .47347 .48371 .46653 .47556 Mtetra
.529 .675 .931 r
.46653 .47556 .47347 .48371 .48575 .48333 .47883 .47499 Mtetra
.554 .682 .924 r
.47883 .47499 .48575 .48333 .4981 .48242 .49121 .47389 Mtetra
.58 .688 .915 r
.49121 .47389 .4981 .48242 .51054 .48087 .50368 .47217 Mtetra
.607 .695 .906 r
.50368 .47217 .51054 .48087 .52306 .47857 .51622 .46972 Mtetra
.631 .702 .896 r
.51622 .46972 .52306 .47857 .53564 .47547 .52883 .46652 Mtetra
.656 .709 .887 r
.52883 .46652 .53564 .47547 .54828 .47148 .54151 .46249 Mtetra
.677 .717 .879 r
.54151 .46249 .54828 .47148 .56097 .46658 .55423 .45763 Mtetra
.696 .725 .873 r
.55423 .45763 .56097 .46658 .57369 .46089 .567 .45201 Mtetra
.713 .733 .867 r
.567 .45201 .57369 .46089 .58645 .45442 .5798 .44565 Mtetra
.727 .741 .863 r
.5798 .44565 .58645 .45442 .59924 .4473 .59263 .43865 Mtetra
.738 .748 .86 r
.59263 .43865 .59924 .4473 .61205 .43963 .60548 .4311 Mtetra
.748 .754 .857 r
.60548 .4311 .61205 .43963 .62487 .43149 .61835 .42307 Mtetra
.757 .76 .856 r
.61835 .42307 .62487 .43149 .63771 .42297 .63124 .41466 Mtetra
.763 .765 .855 r
.63124 .41466 .63771 .42297 .65057 .41417 .64415 .40595 Mtetra
.768 .77 .854 r
.64415 .40595 .65057 .41417 .66343 .40513 .65707 .39698 Mtetra
.772 .774 .854 r
.65707 .39698 .66343 .40513 .67632 .39594 .67001 .38784 Mtetra
.775 .777 .854 r
.67001 .38784 .67632 .39594 .68921 .38663 .68296 .37856 Mtetra
.777 .779 .854 r
.68296 .37856 .68921 .38663 .70213 .37723 .69592 .36919 Mtetra
.778 .781 .855 r
.69592 .36919 .70213 .37723 .71505 .3678 .70891 .35976 Mtetra
.779 .783 .855 r
.70891 .35976 .71505 .3678 .728 .35833 .72191 .35029 Mtetra
.78 .784 .856 r
.72191 .35029 .728 .35833 .74097 .34887 .73493 .3408 Mtetra
.73493 .3408 .74097 .34887 .75396 .33941 .74797 .33132 Mtetra
.78 .785 .857 r
.74797 .33132 .75396 .33941 .76696 .32997 .76103 .32184 Mtetra
.779 .785 .857 r
.76103 .32184 .76696 .32997 .77999 .32054 .77411 .31237 Mtetra
.779 .785 .858 r
.77411 .31237 .77999 .32054 .79304 .31113 .78721 .30291 Mtetra
.778 .785 .858 r
.78721 .30291 .79304 .31113 .80612 .30174 .80034 .29347 Mtetra
.80034 .29347 .80612 .30174 .81921 .29235 .81349 .28403 Mtetra
.778 .784 .858 r
.81349 .28403 .81921 .29235 .83233 .28298 .82666 .2746 Mtetra
.777 .784 .858 r
.82666 .2746 .83233 .28298 .84547 .2736 .83985 .26516 Mtetra
.83985 .26516 .84547 .2736 .85864 .26422 .85307 .25572 Mtetra
.422 .654 .955 r
.24218 .452 .24958 .45888 .26027 .45977 .25289 .45287 Mtetra
.421 .653 .956 r
.25289 .45287 .26027 .45977 .27104 .46067 .26367 .45375 Mtetra
.42 .653 .956 r
.26367 .45375 .27104 .46067 .28188 .4616 .27453 .45466 Mtetra
.418 .653 .956 r
.27453 .45466 .28188 .4616 .2928 .46255 .28546 .45559 Mtetra
.417 .652 .956 r
.28546 .45559 .2928 .46255 .3038 .46352 .29648 .45655 Mtetra
.415 .651 .956 r
.29648 .45655 .3038 .46352 .31487 .46453 .30757 .45754 Mtetra
.413 .65 .956 r
.30757 .45754 .31487 .46453 .32602 .46558 .31874 .45856 Mtetra
.411 .649 .956 r
.31874 .45856 .32602 .46558 .33725 .46666 .32999 .45961 Mtetra
.411 .649 .955 r
.32999 .45961 .33725 .46666 .34857 .46776 .34133 .46068 Mtetra
.411 .648 .955 r
.34133 .46068 .34857 .46776 .35996 .46889 .35274 .46177 Mtetra
.35274 .46177 .35996 .46889 .37145 .47002 .36425 .46286 Mtetra
.414 .649 .955 r
.36425 .46286 .37145 .47002 .38301 .47114 .37584 .46393 Mtetra
.418 .65 .954 r
.37584 .46393 .38301 .47114 .39467 .47223 .38751 .46496 Mtetra
.425 .652 .954 r
.38751 .46496 .39467 .47223 .40642 .47324 .39928 .46592 Mtetra
.434 .655 .953 r
.39928 .46592 .40642 .47324 .41825 .47415 .41114 .46675 Mtetra
.446 .659 .952 r
.41114 .46675 .41825 .47415 .43018 .4749 .4231 .46742 Mtetra
.462 .665 .95 r
.4231 .46742 .43018 .4749 .44221 .47543 .43515 .46786 Mtetra
.48 .671 .948 r
.43515 .46786 .44221 .47543 .45432 .47567 .44729 .46801 Mtetra
.502 .679 .945 r
.44729 .46801 .45432 .47567 .46653 .47556 .45952 .4678 Mtetra
.526 .687 .941 r
.45952 .4678 .46653 .47556 .47883 .47499 .47185 .46713 Mtetra
.552 .696 .935 r
.47185 .46713 .47883 .47499 .49121 .47389 .48426 .46592 Mtetra
.578 .705 .929 r
.48426 .46592 .49121 .47389 .50368 .47217 .49676 .46411 Mtetra
.606 .714 .921 r
.49676 .46411 .50368 .47217 .51622 .46972 .50933 .46158 Mtetra
.631 .722 .913 r
.50933 .46158 .51622 .46972 .52883 .46652 .52198 .45832 Mtetra
.656 .73 .904 r
.52198 .45832 .52883 .46652 .54151 .46249 .53469 .45425 Mtetra
.679 .738 .895 r
.53469 .45425 .54151 .46249 .55423 .45763 .54745 .44938 Mtetra
.698 .745 .888 r
.54745 .44938 .55423 .45763 .567 .45201 .56025 .44377 Mtetra
.715 .751 .88 r
.56025 .44377 .567 .45201 .5798 .44565 .5731 .43743 Mtetra
.729 .757 .875 r
.5731 .43743 .5798 .44565 .59263 .43865 .58597 .43047 Mtetra
.741 .762 .87 r
.58597 .43047 .59263 .43865 .60548 .4311 .59887 .42295 Mtetra
.75 .766 .866 r
.59887 .42295 .60548 .4311 .61835 .42307 .61179 .41496 Mtetra
.758 .77 .862 r
.61179 .41496 .61835 .42307 .63124 .41466 .62473 .40657 Mtetra
.764 .773 .86 r
.62473 .40657 .63124 .41466 .64415 .40595 .63769 .39788 Mtetra
.769 .776 .858 r
.63769 .39788 .64415 .40595 .65707 .39698 .65066 .38892 Mtetra
.773 .778 .857 r
.65066 .38892 .65707 .39698 .67001 .38784 .66365 .37979 Mtetra
.775 .78 .856 r
.66365 .37979 .67001 .38784 .68296 .37856 .67665 .3705 Mtetra
.777 .781 .856 r
.67665 .3705 .68296 .37856 .69592 .36919 .68967 .36112 Mtetra
.778 .782 .856 r
.68967 .36112 .69592 .36919 .70891 .35976 .70271 .35167 Mtetra
.779 .783 .856 r
.70271 .35167 .70891 .35976 .72191 .35029 .71576 .34217 Mtetra
.779 .784 .856 r
.71576 .34217 .72191 .35029 .73493 .3408 .72884 .33266 Mtetra
.78 .784 .856 r
.72884 .33266 .73493 .3408 .74797 .33132 .74193 .32313 Mtetra
.779 .784 .857 r
.74193 .32313 .74797 .33132 .76103 .32184 .75504 .31361 Mtetra
.75504 .31361 .76103 .32184 .77411 .31237 .76818 .3041 Mtetra
.76818 .3041 .77411 .31237 .78721 .30291 .78133 .29459 Mtetra
.778 .784 .858 r
.78133 .29459 .78721 .30291 .80034 .29347 .79451 .2851 Mtetra
.79451 .2851 .80034 .29347 .81349 .28403 .80771 .27561 Mtetra
.777 .784 .858 r
.80771 .27561 .81349 .28403 .82666 .2746 .82093 .26613 Mtetra
.82093 .26613 .82666 .2746 .83985 .26516 .83418 .25664 Mtetra
.777 .783 .858 r
.83418 .25664 .83985 .26516 .85307 .25572 .84745 .24714 Mtetra
.422 .654 .955 r
.23472 .44505 .24218 .452 .25289 .45287 .24545 .4459 Mtetra
.421 .653 .955 r
.24545 .4459 .25289 .45287 .26367 .45375 .25625 .44677 Mtetra
.42 .653 .955 r
.25625 .44677 .26367 .45375 .27453 .45466 .26712 .44765 Mtetra
.419 .652 .955 r
.26712 .44765 .27453 .45466 .28546 .45559 .27807 .44856 Mtetra
.417 .652 .955 r
.27807 .44856 .28546 .45559 .29648 .45655 .2891 .44949 Mtetra
.415 .651 .955 r
.2891 .44949 .29648 .45655 .30757 .45754 .30021 .45046 Mtetra
.414 .65 .955 r
.30021 .45046 .30757 .45754 .31874 .45856 .3114 .45146 Mtetra
.412 .649 .955 r
.3114 .45146 .31874 .45856 .32999 .45961 .32267 .45249 Mtetra
.411 .648 .955 r
.32267 .45249 .32999 .45961 .34133 .46068 .33402 .45354 Mtetra
.33402 .45354 .34133 .46068 .35274 .46177 .34546 .45461 Mtetra
.34546 .45461 .35274 .46177 .36425 .46286 .35698 .45568 Mtetra
.413 .649 .955 r
.35698 .45568 .36425 .46286 .37584 .46393 .36859 .45672 Mtetra
.416 .651 .955 r
.36859 .45672 .37584 .46393 .38751 .46496 .38029 .45773 Mtetra
.422 .654 .955 r
.38029 .45773 .38751 .46496 .39928 .46592 .39208 .45866 Mtetra
.431 .658 .956 r
.39208 .45866 .39928 .46592 .41114 .46675 .40397 .45947 Mtetra
.441 .663 .956 r
.40397 .45947 .41114 .46675 .4231 .46742 .41595 .46012 Mtetra
.456 .67 .955 r
.41595 .46012 .4231 .46742 .43515 .46786 .42802 .46053 Mtetra
.473 .678 .955 r
.42802 .46053 .43515 .46786 .44729 .46801 .44019 .46066 Mtetra
.494 .688 .953 r
.44019 .46066 .44729 .46801 .45952 .4678 .45245 .46042 Mtetra
.519 .698 .951 r
.45245 .46042 .45952 .4678 .47185 .46713 .4648 .45972 Mtetra
.545 .709 .947 r
.4648 .45972 .47185 .46713 .48426 .46592 .47725 .45849 Mtetra
.572 .72 .943 r
.47725 .45849 .48426 .46592 .49676 .46411 .48978 .45665 Mtetra
.602 .732 .936 r
.48978 .45665 .49676 .46411 .50933 .46158 .50239 .45409 Mtetra
.629 .742 .929 r
.50239 .45409 .50933 .46158 .52198 .45832 .51507 .45079 Mtetra
.656 .751 .92 r
.51507 .45079 .52198 .45832 .53469 .45425 .52781 .44669 Mtetra
.68 .759 .91 r
.52781 .44669 .53469 .45425 .54745 .44938 .54061 .44178 Mtetra
.7 .764 .902 r
.54061 .44178 .54745 .44938 .56025 .44377 .55346 .43614 Mtetra
.718 .769 .893 r
.55346 .43614 .56025 .44377 .5731 .43743 .56635 .42976 Mtetra
.733 .773 .885 r
.56635 .42976 .5731 .43743 .58597 .43047 .57927 .42275 Mtetra
.744 .776 .879 r
.57927 .42275 .58597 .43047 .59887 .42295 .59222 .41519 Mtetra
.754 .778 .873 r
.59222 .41519 .59887 .42295 .61179 .41496 .60519 .40716 Mtetra
.761 .78 .868 r
.60519 .40716 .61179 .41496 .62473 .40657 .61818 .39873 Mtetra
.767 .781 .865 r
.61818 .39873 .62473 .40657 .63769 .39788 .63118 .38999 Mtetra
.771 .782 .862 r
.63118 .38999 .63769 .39788 .65066 .38892 .64421 .38099 Mtetra
.774 .783 .86 r
.64421 .38099 .65066 .38892 .66365 .37979 .65724 .3718 Mtetra
.777 .783 .858 r
.65724 .3718 .66365 .37979 .67665 .3705 .6703 .36247 Mtetra
.778 .784 .857 r
.6703 .36247 .67665 .3705 .68967 .36112 .68337 .35304 Mtetra
.779 .784 .857 r
.68337 .35304 .68967 .36112 .70271 .35167 .69646 .34354 Mtetra
.78 .784 .856 r
.69646 .34354 .70271 .35167 .71576 .34217 .70956 .334 Mtetra
.70956 .334 .71576 .34217 .72884 .33266 .72269 .32444 Mtetra
.72269 .32444 .72884 .33266 .74193 .32313 .73583 .31487 Mtetra
.779 .784 .857 r
.73583 .31487 .74193 .32313 .75504 .31361 .749 .3053 Mtetra
.749 .3053 .75504 .31361 .76818 .3041 .76219 .29574 Mtetra
.778 .784 .857 r
.76219 .29574 .76818 .3041 .78133 .29459 .7754 .28618 Mtetra
.7754 .28618 .78133 .29459 .79451 .2851 .78863 .27664 Mtetra
.778 .783 .858 r
.78863 .27664 .79451 .2851 .80771 .27561 .80188 .26711 Mtetra
.777 .783 .858 r
.80188 .26711 .80771 .27561 .82093 .26613 .81516 .25757 Mtetra
.81516 .25757 .82093 .26613 .83418 .25664 .82846 .24804 Mtetra
.82846 .24804 .83418 .25664 .84745 .24714 .84178 .23849 Mtetra
.422 .654 .955 r
.22721 .43805 .23472 .44505 .24545 .4459 .23795 .43888 Mtetra
.422 .653 .955 r
.23795 .43888 .24545 .4459 .25625 .44677 .24876 .43971 Mtetra
.421 .653 .955 r
.24876 .43971 .25625 .44677 .26712 .44765 .25965 .44057 Mtetra
.42 .652 .955 r
.25965 .44057 .26712 .44765 .27807 .44856 .27062 .44145 Mtetra
.418 .651 .955 r
.27062 .44145 .27807 .44856 .2891 .44949 .28167 .44237 Mtetra
.416 .65 .955 r
.28167 .44237 .2891 .44949 .30021 .45046 .2928 .44331 Mtetra
.414 .649 .955 r
.2928 .44331 .30021 .45046 .3114 .45146 .30401 .44429 Mtetra
.412 .648 .955 r
.30401 .44429 .3114 .45146 .32267 .45249 .31529 .4453 Mtetra
.411 .648 .955 r
.31529 .4453 .32267 .45249 .33402 .45354 .32666 .44634 Mtetra
.41 .648 .955 r
.32666 .44634 .33402 .45354 .34546 .45461 .33812 .4474 Mtetra
.409 .648 .955 r
.33812 .4474 .34546 .45461 .35698 .45568 .34966 .44847 Mtetra
.41 .649 .956 r
.34966 .44847 .35698 .45568 .36859 .45672 .36129 .44952 Mtetra
.412 .651 .956 r
.36129 .44952 .36859 .45672 .38029 .45773 .37301 .45054 Mtetra
.416 .654 .957 r
.37301 .45054 .38029 .45773 .39208 .45866 .38482 .45148 Mtetra
.423 .659 .958 r
.38482 .45148 .39208 .45866 .40397 .45947 .39672 .45232 Mtetra
.432 .665 .959 r
.39672 .45232 .40397 .45947 .41595 .46012 .40872 .453 Mtetra
.446 .673 .96 r
.40872 .453 .41595 .46012 .42802 .46053 .42082 .45345 Mtetra
.462 .682 .961 r
.42082 .45345 .42802 .46053 .44019 .46066 .43301 .45363 Mtetra
.482 .694 .961 r
.43301 .45363 .44019 .46066 .45245 .46042 .4453 .45343 Mtetra
.506 .707 .961 r
.4453 .45343 .45245 .46042 .4648 .45972 .45769 .45278 Mtetra
.533 .721 .96 r
.45769 .45278 .4648 .45972 .47725 .45849 .47016 .4516 Mtetra
.562 .735 .957 r
.47016 .4516 .47725 .45849 .48978 .45665 .48273 .44979 Mtetra
.594 .75 .951 r
.48273 .44979 .48978 .45665 .50239 .45409 .49537 .44725 Mtetra
.624 .762 .945 r
.49537 .44725 .50239 .45409 .51507 .45079 .50809 .44395 Mtetra
.655 .773 .936 r
.50809 .44395 .51507 .45079 .52781 .44669 .52088 .43981 Mtetra
.682 .781 .925 r
.52088 .43981 .52781 .44669 .54061 .44178 .53372 .43484 Mtetra
.704 .786 .915 r
.53372 .43484 .54061 .44178 .55346 .43614 .54662 .42911 Mtetra
.723 .789 .905 r
.54662 .42911 .55346 .43614 .56635 .42976 .55955 .42262 Mtetra
.738 .791 .895 r
.55955 .42262 .56635 .42976 .57927 .42275 .57252 .4155 Mtetra
.749 .791 .887 r
.57252 .4155 .57927 .42275 .59222 .41519 .58551 .40782 Mtetra
.758 .791 .88 r
.58551 .40782 .59222 .41519 .60519 .40716 .59853 .39967 Mtetra
.765 .791 .874 r
.59853 .39967 .60519 .40716 .61818 .39873 .61157 .39112 Mtetra
.77 .79 .869 r
.61157 .39112 .61818 .39873 .63118 .38999 .62463 .38227 Mtetra
.774 .789 .865 r
.62463 .38227 .63118 .38999 .64421 .38099 .6377 .37317 Mtetra
.777 .788 .862 r
.6377 .37317 .64421 .38099 .65724 .3718 .65079 .36388 Mtetra
.778 .787 .86 r
.65079 .36388 .65724 .3718 .6703 .36247 .66389 .35447 Mtetra
.78 .786 .858 r
.66389 .35447 .6703 .36247 .68337 .35304 .67701 .34495 Mtetra
.78 .786 .857 r
.67701 .34495 .68337 .35304 .69646 .34354 .69015 .33538 Mtetra
.78 .785 .857 r
.69015 .33538 .69646 .34354 .70956 .334 .70331 .32577 Mtetra
.78 .784 .856 r
.70331 .32577 .70956 .334 .72269 .32444 .71649 .31614 Mtetra
.71649 .31614 .72269 .32444 .73583 .31487 .72969 .30652 Mtetra
.779 .784 .856 r
.72969 .30652 .73583 .31487 .749 .3053 .74291 .29689 Mtetra
.779 .783 .857 r
.74291 .29689 .749 .3053 .76219 .29574 .75615 .28728 Mtetra
.778 .783 .857 r
.75615 .28728 .76219 .29574 .7754 .28618 .76941 .27768 Mtetra
.76941 .27768 .7754 .28618 .78863 .27664 .78269 .26809 Mtetra
.777 .783 .857 r
.78269 .26809 .78863 .27664 .80188 .26711 .796 .25851 Mtetra
.777 .783 .858 r
.796 .25851 .80188 .26711 .81516 .25757 .80933 .24893 Mtetra
.80933 .24893 .81516 .25757 .82846 .24804 .82268 .23935 Mtetra
.82268 .23935 .82846 .24804 .84178 .23849 .83606 .22976 Mtetra
.423 .654 .955 r
.21963 .431 .22721 .43805 .23795 .43888 .23039 .43179 Mtetra
.23039 .43179 .23795 .43888 .24876 .43971 .24122 .43259 Mtetra
.422 .653 .955 r
.24122 .43259 .24876 .43971 .25965 .44057 .25213 .43342 Mtetra
.421 .652 .955 r
.25213 .43342 .25965 .44057 .27062 .44145 .26312 .43427 Mtetra
.419 .651 .955 r
.26312 .43427 .27062 .44145 .28167 .44237 .27418 .43515 Mtetra
.417 .65 .954 r
.27418 .43515 .28167 .44237 .2928 .44331 .28533 .43608 Mtetra
.415 .649 .954 r
.28533 .43608 .2928 .44331 .30401 .44429 .29655 .43704 Mtetra
.412 .648 .954 r
.29655 .43704 .30401 .44429 .31529 .4453 .30786 .43804 Mtetra
.41 .647 .955 r
.30786 .43804 .31529 .4453 .32666 .44634 .31924 .43907 Mtetra
.408 .647 .955 r
.31924 .43907 .32666 .44634 .33812 .4474 .33072 .44013 Mtetra
.406 .647 .955 r
.33072 .44013 .33812 .4474 .34966 .44847 .34228 .44122 Mtetra
.406 .648 .956 r
.34228 .44122 .34966 .44847 .36129 .44952 .35392 .4423 Mtetra
.406 .649 .957 r
.35392 .4423 .36129 .44952 .37301 .45054 .36566 .44336 Mtetra
.408 .653 .958 r
.36566 .44336 .37301 .45054 .38482 .45148 .37749 .44436 Mtetra
.413 .658 .96 r
.37749 .44436 .38482 .45148 .39672 .45232 .38941 .44527 Mtetra
.42 .664 .962 r
.38941 .44527 .39672 .45232 .40872 .453 .40143 .44604 Mtetra
.431 .673 .964 r
.40143 .44604 .40872 .453 .42082 .45345 .41355 .4466 Mtetra
.444 .684 .967 r
.41355 .4466 .42082 .45345 .43301 .45363 .42577 .4469 Mtetra
.463 .698 .969 r
.42577 .4469 .43301 .45363 .4453 .45343 .43808 .44683 Mtetra
.486 .713 .971 r
.43808 .44683 .4453 .45343 .45769 .45278 .45049 .44632 Mtetra
.514 .731 .972 r
.45049 .44632 .45769 .45278 .47016 .4516 .463 .44527 Mtetra
.545 .749 .971 r
.463 .44527 .47016 .4516 .48273 .44979 .4756 .44358 Mtetra
.581 .768 .968 r
.4756 .44358 .48273 .44979 .49537 .44725 .48828 .44112 Mtetra
.615 .783 .962 r
.48828 .44112 .49537 .44725 .50809 .44395 .50105 .43786 Mtetra
.651 .797 .953 r
.50105 .43786 .50809 .44395 .52088 .43981 .51388 .43369 Mtetra
.683 .806 .941 r
.51388 .43369 .52088 .43981 .53372 .43484 .52677 .42861 Mtetra
.708 .81 .929 r
.52677 .42861 .53372 .43484 .54662 .42911 .53971 .42273 Mtetra
.729 .811 .916 r
.53971 .42273 .54662 .42911 .55955 .42262 .5527 .41606 Mtetra
.745 .81 .904 r
.5527 .41606 .55955 .42262 .57252 .4155 .56571 .40873 Mtetra
.756 .808 .894 r
.56571 .40873 .57252 .4155 .58551 .40782 .57876 .40084 Mtetra
.765 .805 .885 r
.57876 .40084 .58551 .40782 .59853 .39967 .59182 .39248 Mtetra
.771 .802 .878 r
.59182 .39248 .59853 .39967 .61157 .39112 .60491 .38374 Mtetra
.775 .798 .872 r
.60491 .38374 .61157 .39112 .62463 .38227 .61802 .37471 Mtetra
.778 .796 .867 r
.61802 .37471 .62463 .38227 .6377 .37317 .63114 .36544 Mtetra
.78 .793 .863 r
.63114 .36544 .6377 .37317 .65079 .36388 .64428 .35602 Mtetra
.781 .791 .861 r
.64428 .35602 .65079 .36388 .66389 .35447 .65743 .34647 Mtetra
.781 .789 .859 r
.65743 .34647 .66389 .35447 .67701 .34495 .67061 .33684 Mtetra
.781 .787 .857 r
.67061 .33684 .67701 .34495 .69015 .33538 .6838 .32717 Mtetra
.781 .786 .856 r
.6838 .32717 .69015 .33538 .70331 .32577 .69701 .31747 Mtetra
.781 .785 .856 r
.69701 .31747 .70331 .32577 .71649 .31614 .71023 .30777 Mtetra
.78 .784 .856 r
.71023 .30777 .71649 .31614 .72969 .30652 .72348 .29807 Mtetra
.779 .783 .856 r
.72348 .29807 .72969 .30652 .74291 .29689 .73675 .28839 Mtetra
.73675 .28839 .74291 .29689 .75615 .28728 .75005 .27872 Mtetra
.778 .782 .856 r
.75005 .27872 .75615 .28728 .76941 .27768 .76336 .26907 Mtetra
.777 .782 .857 r
.76336 .26907 .76941 .27768 .78269 .26809 .7767 .25944 Mtetra
.7767 .25944 .78269 .26809 .796 .25851 .79007 .24982 Mtetra
.79007 .24982 .796 .25851 .80933 .24893 .80345 .2402 Mtetra
.777 .783 .858 r
.80345 .2402 .80933 .24893 .82268 .23935 .81686 .23058 Mtetra
.776 .783 .858 r
.81686 .23058 .82268 .23935 .83606 .22976 .83029 .22096 Mtetra
.425 .655 .955 r
.212 .42389 .21963 .431 .23039 .43179 .22277 .42464 Mtetra
.424 .654 .955 r
.22277 .42464 .23039 .43179 .24122 .43259 .23362 .4254 Mtetra
.424 .653 .955 r
.23362 .4254 .24122 .43259 .25213 .43342 .24455 .42619 Mtetra
.422 .652 .954 r
.24455 .42619 .25213 .43342 .26312 .43427 .25555 .42701 Mtetra
.42 .651 .954 r
.25555 .42701 .26312 .43427 .27418 .43515 .26663 .42786 Mtetra
.418 .649 .954 r
.26663 .42786 .27418 .43515 .28533 .43608 .2778 .42876 Mtetra
.415 .648 .954 r
.2778 .42876 .28533 .43608 .29655 .43704 .28904 .4297 Mtetra
.412 .647 .954 r
.28904 .4297 .29655 .43704 .30786 .43804 .30036 .43069 Mtetra
.408 .646 .954 r
.30036 .43069 .30786 .43804 .31924 .43907 .31176 .43173 Mtetra
.405 .645 .955 r
.31176 .43173 .31924 .43907 .33072 .44013 .32325 .43282 Mtetra
.402 .645 .955 r
.32325 .43282 .33072 .44013 .34228 .44122 .33483 .43393 Mtetra
.4 .646 .956 r
.33483 .43393 .34228 .44122 .35392 .4423 .34649 .43506 Mtetra
.397 .647 .958 r
.34649 .43506 .35392 .4423 .36566 .44336 .35824 .4362 Mtetra
.397 .65 .959 r
.35824 .4362 .36566 .44336 .37749 .44436 .37009 .4373 Mtetra
.399 .655 .962 r
.37009 .4373 .37749 .44436 .38941 .44527 .38203 .43833 Mtetra
.402 .661 .964 r
.38203 .43833 .38941 .44527 .40143 .44604 .39407 .43925 Mtetra
.41 .671 .968 r
.39407 .43925 .40143 .44604 .41355 .4466 .40621 .43998 Mtetra
.42 .683 .972 r
.40621 .43998 .41355 .4466 .42577 .4469 .41844 .44048 Mtetra
.436 .698 .976 r
.41844 .44048 .42577 .4469 .43808 .44683 .43078 .44063 Mtetra
.458 .716 .979 r
.43078 .44063 .43808 .44683 .45049 .44632 .44322 .44035 Mtetra
.486 .737 .983 r
.44322 .44035 .45049 .44632 .463 .44527 .45576 .43952 Mtetra
.52 .76 .984 r
.45576 .43952 .463 .44527 .4756 .44358 .46839 .43801 Mtetra
.561 .784 .982 r
.46839 .43801 .4756 .44358 .48828 .44112 .48112 .43569 Mtetra
.601 .804 .977 r
.48112 .43569 .48828 .44112 .50105 .43786 .49393 .43249 Mtetra
.645 .821 .968 r
.49393 .43249 .50105 .43786 .51388 .43369 .50681 .42829 Mtetra
.683 .831 .954 r
.50681 .42829 .51388 .43369 .52677 .42861 .51975 .42308 Mtetra
.712 .835 .94 r
.51975 .42308 .52677 .42861 .53971 .42273 .53274 .41699 Mtetra
.736 .834 .925 r
.53274 .41699 .53971 .42273 .5527 .41606 .54578 .41006 Mtetra
.753 .831 .911 r
.54578 .41006 .5527 .41606 .56571 .40873 .55885 .40244 Mtetra
.765 .825 .899 r
.55885 .40244 .56571 .40873 .57876 .40084 .57194 .39426 Mtetra
.773 .819 .889 r
.57194 .39426 .57876 .40084 .59182 .39248 .58506 .38561 Mtetra
.778 .813 .881 r
.58506 .38561 .59182 .39248 .60491 .38374 .5982 .37659 Mtetra
.781 .808 .874 r
.5982 .37659 .60491 .38374 .61802 .37471 .61136 .36732 Mtetra
.783 .803 .868 r
.61136 .36732 .61802 .37471 .63114 .36544 .62453 .35783 Mtetra
.784 .798 .864 r
.62453 .35783 .63114 .36544 .64428 .35602 .63772 .3482 Mtetra
.784 .794 .861 r
.63772 .3482 .64428 .35602 .65743 .34647 .65092 .33848 Mtetra
.784 .791 .859 r
.65092 .33848 .65743 .34647 .67061 .33684 .66414 .32871 Mtetra
.783 .789 .857 r
.66414 .32871 .67061 .33684 .6838 .32717 .67738 .31891 Mtetra
.782 .787 .856 r
.67738 .31891 .6838 .32717 .69701 .31747 .69064 .3091 Mtetra
.781 .785 .856 r
.69064 .3091 .69701 .31747 .71023 .30777 .70392 .29931 Mtetra
.78 .784 .855 r
.70392 .29931 .71023 .30777 .72348 .29807 .71722 .28953 Mtetra
.779 .783 .855 r
.71722 .28953 .72348 .29807 .73675 .28839 .73055 .27978 Mtetra
.779 .782 .856 r
.73055 .27978 .73675 .28839 .75005 .27872 .7439 .27006 Mtetra
.778 .782 .856 r
.7439 .27006 .75005 .27872 .76336 .26907 .75727 .26036 Mtetra
.777 .782 .856 r
.75727 .26036 .76336 .26907 .7767 .25944 .77066 .25069 Mtetra
.777 .782 .857 r
.77066 .25069 .7767 .25944 .79007 .24982 .78408 .24103 Mtetra
.776 .782 .857 r
.78408 .24103 .79007 .24982 .80345 .2402 .79752 .23138 Mtetra
.776 .782 .858 r
.79752 .23138 .80345 .2402 .81686 .23058 .81098 .22173 Mtetra
.776 .783 .858 r
.81098 .22173 .81686 .23058 .83029 .22096 .82447 .21208 Mtetra
.427 .656 .955 r
.2043 .41673 .212 .42389 .22277 .42464 .21509 .41742 Mtetra
.426 .655 .955 r
.21509 .41742 .22277 .42464 .23362 .4254 .22596 .41814 Mtetra
.426 .654 .954 r
.22596 .41814 .23362 .4254 .24455 .42619 .23691 .41888 Mtetra
.424 .652 .954 r
.23691 .41888 .24455 .42619 .25555 .42701 .24793 .41965 Mtetra
.422 .651 .954 r
.24793 .41965 .25555 .42701 .26663 .42786 .25903 .42047 Mtetra
.419 .649 .953 r
.25903 .42047 .26663 .42786 .2778 .42876 .27021 .42134 Mtetra
.416 .647 .953 r
.27021 .42134 .2778 .42876 .28904 .4297 .28146 .42226 Mtetra
.412 .645 .953 r
.28146 .42226 .28904 .4297 .30036 .43069 .2928 .42325 Mtetra
.407 .644 .953 r
.2928 .42325 .30036 .43069 .31176 .43173 .30422 .4243 Mtetra
.403 .643 .954 r
.30422 .4243 .31176 .43173 .32325 .43282 .31573 .42541 Mtetra
.397 .642 .955 r
.31573 .42541 .32325 .43282 .33483 .43393 .32732 .42658 Mtetra
.393 .642 .956 r
.32732 .42658 .33483 .43393 .34649 .43506 .339 .42778 Mtetra
.388 .643 .957 r
.339 .42778 .34649 .43506 .35824 .4362 .35076 .42902 Mtetra
.384 .645 .959 r
.35076 .42902 .35824 .4362 .37009 .4373 .36262 .43025 Mtetra
.382 .649 .962 r
.36262 .43025 .37009 .4373 .38203 .43833 .37458 .43145 Mtetra
.381 .655 .965 r
.37458 .43145 .38203 .43833 .39407 .43925 .38663 .43258 Mtetra
.384 .664 .969 r
.38663 .43258 .39407 .43925 .40621 .43998 .39879 .43356 Mtetra
.389 .676 .974 r
.39879 .43356 .40621 .43998 .41844 .44048 .41104 .43434 Mtetra
.401 .692 .979 r
.41104 .43434 .41844 .44048 .43078 .44063 .4234 .43481 Mtetra
.419 .713 .985 r
.4234 .43481 .43078 .44063 .44322 .44035 .43587 .43486 Mtetra
.444 .737 .99 r
.43587 .43486 .44322 .44035 .45576 .43952 .44843 .43437 Mtetra
.479 .766 .994 r
.44843 .43437 .45576 .43952 .46839 .43801 .4611 .43318 Mtetra
.525 .797 .995 r
.4611 .43318 .46839 .43801 .48112 .43569 .47387 .43111 Mtetra
.574 .825 .992 r
.47387 .43111 .48112 .43569 .49393 .43249 .48672 .42807 Mtetra
.632 .85 .983 r
.48672 .42807 .49393 .43249 .50681 .42829 .49965 .42383 Mtetra
.683 .863 .968 r
.49965 .42383 .50681 .42829 .51975 .42308 .51265 .4184 Mtetra
.719 .865 .951 r
.51265 .4184 .51975 .42308 .53274 .41699 .5257 .41199 Mtetra
.746 .861 .933 r
.5257 .41199 .53274 .41699 .54578 .41006 .5388 .40468 Mtetra
.764 .853 .917 r
.5388 .40468 .54578 .41006 .55885 .40244 .55192 .39664 Mtetra
.776 .843 .903 r
.55192 .39664 .55885 .40244 .57194 .39426 .56507 .38805 Mtetra
.782 .833 .891 r
.56507 .38805 .57194 .39426 .58506 .38561 .57824 .37901 Mtetra
.787 .824 .881 r
.57824 .37901 .58506 .38561 .5982 .37659 .59143 .36964 Mtetra
.788 .815 .874 r
.59143 .36964 .5982 .37659 .61136 .36732 .60464 .36004 Mtetra
.789 .808 .868 r
.60464 .36004 .61136 .36732 .62453 .35783 .61786 .35027 Mtetra
.788 .802 .864 r
.61786 .35027 .62453 .35783 .63772 .3482 .63109 .3404 Mtetra
.788 .797 .86 r
.63109 .3404 .63772 .3482 .65092 .33848 .64435 .33047 Mtetra
.786 .793 .858 r
.64435 .33047 .65092 .33848 .66414 .32871 .65762 .32051 Mtetra
.785 .789 .856 r
.65762 .32051 .66414 .32871 .67738 .31891 .67091 .31056 Mtetra
.784 .787 .855 r
.67091 .31056 .67738 .31891 .69064 .3091 .68422 .30063 Mtetra
.782 .784 .855 r
.68422 .30063 .69064 .3091 .70392 .29931 .69755 .29073 Mtetra
.781 .783 .854 r
.69755 .29073 .70392 .29931 .71722 .28953 .71091 .28088 Mtetra
.779 .782 .855 r
.71091 .28088 .71722 .28953 .73055 .27978 .72428 .27106 Mtetra
.778 .781 .855 r
.72428 .27106 .73055 .27978 .7439 .27006 .73768 .26128 Mtetra
.777 .781 .855 r
.73768 .26128 .7439 .27006 .75727 .26036 .75111 .25154 Mtetra
.777 .78 .856 r
.75111 .25154 .75727 .26036 .77066 .25069 .76456 .24183 Mtetra
.776 .781 .857 r
.76456 .24183 .77066 .25069 .78408 .24103 .77803 .23214 Mtetra
.77803 .23214 .78408 .24103 .79752 .23138 .79153 .22246 Mtetra
.775 .782 .858 r
.79153 .22246 .79752 .23138 .81098 .22173 .80505 .21279 Mtetra
.80505 .21279 .81098 .22173 .82447 .21208 .8186 .20311 Mtetra
.429 .657 .955 r
.19654 .4095 .2043 .41673 .21509 .41742 .20735 .41014 Mtetra
.429 .656 .955 r
.20735 .41014 .21509 .41742 .22596 .41814 .21824 .4108 Mtetra
.429 .654 .954 r
.21824 .4108 .22596 .41814 .23691 .41888 .2292 .41148 Mtetra
.427 .653 .953 r
.2292 .41148 .23691 .41888 .24793 .41965 .24024 .41221 Mtetra
.425 .651 .953 r
.24024 .41221 .24793 .41965 .25903 .42047 .25136 .41298 Mtetra
.421 .648 .952 r
.25136 .41298 .25903 .42047 .27021 .42134 .26256 .41382 Mtetra
.417 .646 .952 r
.26256 .41382 .27021 .42134 .28146 .42226 .27383 .41472 Mtetra
.412 .644 .952 r
.27383 .41472 .28146 .42226 .2928 .42325 .28519 .4157 Mtetra
.406 .642 .952 r
.28519 .4157 .2928 .42325 .30422 .4243 .29663 .41676 Mtetra
.4 .64 .953 r
.29663 .41676 .30422 .4243 .31573 .42541 .30814 .41791 Mtetra
.392 .638 .954 r
.30814 .41791 .31573 .42541 .32732 .42658 .31975 .41914 Mtetra
.385 .637 .955 r
.31975 .41914 .32732 .42658 .339 .42778 .33144 .42043 Mtetra
.377 .637 .957 r
.33144 .42043 .339 .42778 .35076 .42902 .34322 .4218 Mtetra
.369 .638 .959 r
.34322 .4218 .35076 .42902 .36262 .43025 .35509 .42321 Mtetra
.362 .641 .961 r
.35509 .42321 .36262 .43025 .37458 .43145 .36706 .42462 Mtetra
.354 .645 .965 r
.36706 .42462 .37458 .43145 .38663 .43258 .37912 .42603 Mtetra
.351 .653 .969 r
.37912 .42603 .38663 .43258 .39879 .43356 .39129 .42732 Mtetra
.347 .663 .973 r
.39129 .42732 .39879 .43356 .41104 .43434 .40356 .42849 Mtetra
.352 .679 .978 r
.40356 .42849 .41104 .43434 .4234 .43481 .41593 .42938 Mtetra
.362 .7 .984 r
.41593 .42938 .4234 .43481 .43587 .43486 .42842 .42989 Mtetra
.381 .726 .99 r
.42842 .42989 .43587 .43486 .44843 .43437 .44101 .42989 Mtetra
.417 .761 .995 r
.44101 .42989 .44843 .43437 .4611 .43318 .45371 .42914 Mtetra
.47 .801 .999 r
.45371 .42914 .4611 .43318 .47387 .43111 .46652 .42742 Mtetra
.532 .84 .999 r
.46652 .42742 .47387 .43111 .48672 .42807 .47942 .42459 Mtetra
.61 .875 .991 r
.47942 .42459 .48672 .42807 .49965 .42383 .49241 .42033 Mtetra
.68 .895 .975 r
.49241 .42033 .49965 .42383 .51265 .4184 .50547 .41462 Mtetra
.726 .896 .956 r
.50547 .41462 .51265 .4184 .5257 .41199 .51859 .40778 Mtetra
.759 .888 .937 r
.51859 .40778 .5257 .41199 .5388 .40468 .53174 .39996 Mtetra
.778 .876 .918 r
.53174 .39996 .5388 .40468 .55192 .39664 .54493 .39137 Mtetra
.789 .861 .903 r
.54493 .39137 .55192 .39664 .56507 .38805 .55813 .38224 Mtetra
.794 .847 .891 r
.55813 .38224 .56507 .38805 .57824 .37901 .57136 .3727 Mtetra
.797 .835 .88 r
.57136 .3727 .57824 .37901 .59143 .36964 .5846 .36286 Mtetra
.796 .823 .873 r
.5846 .36286 .59143 .36964 .60464 .36004 .59786 .35287 Mtetra
.796 .814 .866 r
.59786 .35287 .60464 .36004 .61786 .35027 .61113 .34274 Mtetra
.794 .806 .862 r
.61113 .34274 .61786 .35027 .63109 .3404 .62442 .33258 Mtetra
.791 .799 .859 r
.62442 .33258 .63109 .3404 .64435 .33047 .63772 .3224 Mtetra
.789 .794 .856 r
.63772 .3224 .64435 .33047 .65762 .32051 .65104 .31223 Mtetra
.787 .79 .855 r
.65104 .31223 .65762 .32051 .67091 .31056 .66438 .30212 Mtetra
.785 .786 .854 r
.66438 .30212 .67091 .31056 .68422 .30063 .67774 .29205 Mtetra
.783 .784 .853 r
.67774 .29205 .68422 .30063 .69755 .29073 .69113 .28204 Mtetra
.781 .782 .853 r
.69113 .28204 .69755 .29073 .71091 .28088 .70453 .27209 Mtetra
.779 .78 .854 r
.70453 .27209 .71091 .28088 .72428 .27106 .71796 .26221 Mtetra
.778 .78 .854 r
.71796 .26221 .72428 .27106 .73768 .26128 .73142 .25238 Mtetra
.777 .779 .855 r
.73142 .25238 .73768 .26128 .75111 .25154 .7449 .24259 Mtetra
.776 .779 .856 r
.7449 .24259 .75111 .25154 .76456 .24183 .7584 .23285 Mtetra
.775 .779 .856 r
.7584 .23285 .76456 .24183 .77803 .23214 .77193 .22314 Mtetra
.775 .78 .857 r
.77193 .22314 .77803 .23214 .79153 .22246 .78549 .21345 Mtetra
.775 .781 .858 r
.78549 .21345 .79153 .22246 .80505 .21279 .79907 .20376 Mtetra
.775 .782 .859 r
.79907 .20376 .80505 .21279 .8186 .20311 .81267 .19407 Mtetra
.433 .659 .955 r
.18872 .40222 .19654 .4095 .20735 .41014 .19955 .40279 Mtetra
.433 .657 .954 r
.19955 .40279 .20735 .41014 .21824 .4108 .21046 .40337 Mtetra
.432 .655 .953 r
.21046 .40337 .21824 .4108 .2292 .41148 .22144 .40399 Mtetra
.431 .653 .953 r
.22144 .40399 .2292 .41148 .24024 .41221 .2325 .40465 Mtetra
.428 .651 .952 r
.2325 .40465 .24024 .41221 .25136 .41298 .24364 .40538 Mtetra
.424 .648 .951 r
.24364 .40538 .25136 .41298 .26256 .41382 .25486 .40617 Mtetra
.419 .645 .951 r
.25486 .40617 .26256 .41382 .27383 .41472 .26615 .40705 Mtetra
.413 .642 .951 r
.26615 .40705 .27383 .41472 .28519 .4157 .27752 .40802 Mtetra
.406 .639 .951 r
.27752 .40802 .28519 .4157 .29663 .41676 .28897 .40909 Mtetra
.397 .636 .952 r
.28897 .40909 .29663 .41676 .30814 .41791 .3005 .41027 Mtetra
.388 .634 .952 r
.3005 .41027 .30814 .41791 .31975 .41914 .31212 .41157 Mtetra
.378 .632 .953 r
.31212 .41157 .31975 .41914 .33144 .42043 .32382 .41298 Mtetra
.365 .63 .955 r
.32382 .41298 .33144 .42043 .34322 .4218 .33561 .4145 Mtetra
.353 .629 .957 r
.33561 .4145 .34322 .4218 .35509 .42321 .34749 .41611 Mtetra
.339 .629 .959 r
.34749 .41611 .35509 .42321 .36706 .42462 .35946 .41779 Mtetra
.324 .631 .961 r
.35946 .41779 .36706 .42462 .37912 .42603 .37153 .41951 Mtetra
.312 .636 .965 r
.37153 .41951 .37912 .42603 .39129 .42732 .38371 .42121 Mtetra
.297 .642 .967 r
.38371 .42121 .39129 .42732 .40356 .42849 .39599 .42286 Mtetra
.289 .655 .97 r
.39599 .42286 .40356 .42849 .41593 .42938 .40838 .4243 Mtetra
.286 .672 .972 r
.40838 .4243 .41593 .42938 .42842 .42989 .42088 .42543 Mtetra
.292 .696 .974 r
.42088 .42543 .42842 .42989 .44101 .42989 .43349 .42609 Mtetra
.322 .735 .978 r
.43349 .42609 .44101 .42989 .45371 .42914 .44622 .42597 Mtetra
.373 .782 .982 r
.44622 .42597 .45371 .42914 .46652 .42742 .45907 .42485 Mtetra
.448 .837 .984 r
.45907 .42485 .46652 .42742 .47942 .42459 .47202 .42241 Mtetra
.565 .897 .983 r
.47202 .42241 .47942 .42459 .49241 .42033 .48507 .41811 Mtetra
.671 .93 .971 r
.48507 .41811 .49241 .42033 .50547 .41462 .4982 .41194 Mtetra
.735 .931 .954 r
.4982 .41194 .50547 .41462 .51859 .40778 .51139 .40445 Mtetra
.774 .917 .934 r
.51139 .40445 .51859 .40778 .53174 .39996 .52461 .39592 Mtetra
.796 .899 .915 r
.52461 .39592 .53174 .39996 .54493 .39137 .53786 .38659 Mtetra
.804 .878 .9 r
.53786 .38659 .54493 .39137 .55813 .38224 .55113 .37676 Mtetra
.808 .86 .887 r
.55113 .37676 .55813 .38224 .57136 .3727 .56441 .3666 Mtetra
.808 .843 .877 r
.56441 .3666 .57136 .3727 .5846 .36286 .57771 .3562 Mtetra
.805 .829 .87 r
.57771 .3562 .5846 .36286 .59786 .35287 .59102 .34573 Mtetra
.802 .818 .863 r
.59102 .34573 .59786 .35287 .61113 .34274 .60434 .3352 Mtetra
.799 .808 .859 r
.60434 .3352 .61113 .34274 .62442 .33258 .61768 .3247 Mtetra
.795 .8 .856 r
.61768 .3247 .62442 .33258 .63772 .3224 .63103 .31423 Mtetra
.792 .794 .854 r
.63103 .31423 .63772 .3224 .65104 .31223 .6444 .30384 Mtetra
.789 .789 .852 r
.6444 .30384 .65104 .31223 .66438 .30212 .65779 .29354 Mtetra
.786 .785 .852 r
.65779 .29354 .66438 .30212 .67774 .29205 .6712 .28332 Mtetra
.783 .782 .852 r
.6712 .28332 .67774 .29205 .69113 .28204 .68464 .2732 Mtetra
.781 .78 .852 r
.68464 .2732 .69113 .28204 .70453 .27209 .6981 .26316 Mtetra
.779 .779 .852 r
.6981 .26316 .70453 .27209 .71796 .26221 .71158 .25321 Mtetra
.777 .778 .853 r
.71158 .25321 .71796 .26221 .73142 .25238 .72509 .24333 Mtetra
.776 .778 .854 r
.72509 .24333 .73142 .25238 .7449 .24259 .73862 .23351 Mtetra
.775 .778 .855 r
.73862 .23351 .7449 .24259 .7584 .23285 .75219 .22375 Mtetra
.774 .778 .856 r
.75219 .22375 .7584 .23285 .77193 .22314 .76577 .21403 Mtetra
.774 .779 .857 r
.76577 .21403 .77193 .22314 .78549 .21345 .77939 .20433 Mtetra
.774 .78 .858 r
.77939 .20433 .78549 .21345 .79907 .20376 .79303 .19464 Mtetra
.774 .781 .859 r
.79303 .19464 .79907 .20376 .81267 .19407 .80669 .18495 Mtetra
.437 .661 .955 r
.18084 .39488 .18872 .40222 .19955 .40279 .19169 .39536 Mtetra
.438 .659 .954 r
.19169 .39536 .19955 .40279 .21046 .40337 .20262 .39586 Mtetra
.437 .657 .953 r
.20262 .39586 .21046 .40337 .22144 .40399 .21362 .3964 Mtetra
.435 .654 .952 r
.21362 .3964 .22144 .40399 .2325 .40465 .22471 .39699 Mtetra
.432 .651 .951 r
.22471 .39699 .2325 .40465 .24364 .40538 .23586 .39765 Mtetra
.428 .648 .95 r
.23586 .39765 .24364 .40538 .25486 .40617 .2471 .39839 Mtetra
.422 .644 .95 r
.2471 .39839 .25486 .40617 .26615 .40705 .2584 .39923 Mtetra
.415 .64 .949 r
.2584 .39923 .26615 .40705 .27752 .40802 .26979 .40018 Mtetra
.406 .636 .949 r
.26979 .40018 .27752 .40802 .28897 .40909 .28126 .40126 Mtetra
.396 .633 .95 r
.28126 .40126 .28897 .40909 .3005 .41027 .2928 .40248 Mtetra
.384 .628 .95 r
.2928 .40248 .3005 .41027 .31212 .41157 .30443 .40385 Mtetra
.371 .625 .951 r
.30443 .40385 .31212 .41157 .32382 .41298 .31614 .40536 Mtetra
.354 .621 .952 r
.31614 .40536 .32382 .41298 .33561 .4145 .32793 .40705 Mtetra
.337 .618 .954 r
.32793 .40705 .33561 .4145 .34749 .41611 .33982 .40889 Mtetra
.316 .615 .955 r
.33982 .40889 .34749 .41611 .35946 .41779 .3518 .41086 Mtetra
.292 .613 .956 r
.3518 .41086 .35946 .41779 .37153 .41951 .36388 .41297 Mtetra
.269 .613 .957 r
.36388 .41297 .37153 .41951 .38371 .42121 .37605 .41514 Mtetra
.238 .612 .954 r
.37605 .41514 .38371 .42121 .39599 .42286 .38833 .41737 Mtetra
.213 .617 .951 r
.38833 .41737 .39599 .42286 .40838 .4243 .40073 .41949 Mtetra
.186 .623 .944 r
.40073 .41949 .40838 .4243 .42088 .42543 .41323 .42143 Mtetra
.165 .635 .931 r
.41323 .42143 .42088 .42543 .43349 .42609 .42586 .42301 Mtetra
.176 .667 .921 r
.42586 .42301 .43349 .42609 .44622 .42597 .43862 .4238 Mtetra
.204 .706 .908 r
.43862 .4238 .44622 .42597 .45907 .42485 .45149 .42363 Mtetra
.288 .776 .905 r
.45149 .42363 .45907 .42485 .47202 .42241 .4645 .42188 Mtetra
.471 .887 .925 r
.4645 .42188 .47202 .42241 .48507 .41811 .47762 .41755 Mtetra
.649 .957 .936 r
.47762 .41755 .48507 .41811 .4982 .41194 .49083 .41064 Mtetra
.747 .966 .934 r
.49083 .41064 .4982 .41194 .51139 .40445 .5041 .40212 Mtetra
.793 .946 .923 r
.5041 .40212 .51139 .40445 .52461 .39592 .5174 .39261 Mtetra
.817 .92 .906 r
.5174 .39261 .52461 .39592 .53786 .38659 .53072 .38229 Mtetra
.823 .893 .892 r
.53072 .38229 .53786 .38659 .55113 .37676 .54405 .37158 Mtetra
.822 .869 .881 r
.54405 .37158 .55113 .37676 .56441 .3666 .55739 .36065 Mtetra
.82 .849 .871 r
.55739 .36065 .56441 .3666 .57771 .3562 .57075 .34959 Mtetra
.814 .833 .864 r
.57075 .34959 .57771 .3562 .59102 .34573 .58411 .33856 Mtetra
.809 .819 .858 r
.58411 .33856 .59102 .34573 .60434 .3352 .59748 .32757 Mtetra
.804 .808 .855 r
.59748 .32757 .60434 .3352 .61768 .3247 .61087 .31668 Mtetra
.799 .799 .852 r
.61087 .31668 .61768 .3247 .63103 .31423 .62427 .30591 Mtetra
.794 .792 .85 r
.62427 .30591 .63103 .31423 .6444 .30384 .63769 .29527 Mtetra
.79 .787 .849 r
.63769 .29527 .6444 .30384 .65779 .29354 .65114 .28478 Mtetra
.787 .783 .849 r
.65114 .28478 .65779 .29354 .6712 .28332 .6646 .27441 Mtetra
.783 .78 .849 r
.6646 .27441 .6712 .28332 .68464 .2732 .67809 .26417 Mtetra
.781 .778 .85 r
.67809 .26417 .68464 .2732 .6981 .26316 .6916 .25405 Mtetra
.778 .776 .851 r
.6916 .25405 .6981 .26316 .71158 .25321 .70513 .24404 Mtetra
.776 .776 .852 r
.70513 .24404 .71158 .25321 .72509 .24333 .7187 .23413 Mtetra
.775 .775 .853 r
.7187 .23413 .72509 .24333 .73862 .23351 .73229 .22429 Mtetra
.774 .776 .855 r
.73229 .22429 .73862 .23351 .75219 .22375 .74591 .21452 Mtetra
.773 .776 .856 r
.74591 .21452 .75219 .22375 .76577 .21403 .75956 .20479 Mtetra
.772 .777 .857 r
.75956 .20479 .76577 .21403 .77939 .20433 .77323 .1951 Mtetra
.772 .779 .858 r
.77323 .1951 .77939 .20433 .79303 .19464 .78693 .18542 Mtetra
.772 .78 .859 r
.78693 .18542 .79303 .19464 .80669 .18495 .80066 .17574 Mtetra
.443 .663 .955 r
.17289 .38748 .18084 .39488 .19169 .39536 .18377 .38786 Mtetra
.443 .661 .954 r
.18377 .38786 .19169 .39536 .20262 .39586 .19472 .38826 Mtetra
.443 .658 .952 r
.19472 .38826 .20262 .39586 .21362 .3964 .20575 .3887 Mtetra
.441 .655 .951 r
.20575 .3887 .21362 .3964 .22471 .39699 .21685 .3892 Mtetra
.437 .652 .95 r
.21685 .3892 .22471 .39699 .23586 .39765 .22803 .38978 Mtetra
.432 .648 .949 r
.22803 .38978 .23586 .39765 .2471 .39839 .23928 .39045 Mtetra
.426 .643 .948 r
.23928 .39045 .2471 .39839 .2584 .39923 .25061 .39124 Mtetra
.418 .639 .947 r
.25061 .39124 .2584 .39923 .26979 .40018 .26201 .39216 Mtetra
.408 .634 .947 r
.26201 .39216 .26979 .40018 .28126 .40126 .27349 .39324 Mtetra
.396 .629 .947 r
.27349 .39324 .28126 .40126 .2928 .40248 .28505 .39448 Mtetra
.381 .623 .948 r
.28505 .39448 .2928 .40248 .30443 .40385 .29668 .39592 Mtetra
.365 .617 .948 r
.29668 .39592 .30443 .40385 .31614 .40536 .3084 .39756 Mtetra
.344 .611 .949 r
.3084 .39756 .31614 .40536 .32793 .40705 .3202 .39942 Mtetra
.32 .605 .949 r
.3202 .39942 .32793 .40705 .33982 .40889 .33209 .4015 Mtetra
.292 .598 .949 r
.33209 .4015 .33982 .40889 .3518 .41086 .34407 .40381 Mtetra
.257 .59 .948 r
.34407 .40381 .3518 .41086 .36388 .41297 .35615 .40635 Mtetra
.219 .583 .944 r
.35615 .40635 .36388 .41297 .37605 .41514 .36832 .40907 Mtetra
.166 .57 .934 r
.36832 .40907 .37605 .41514 .38833 .41737 .38059 .412 Mtetra
.116 .561 .918 r
.38059 .412 .38833 .41737 .40073 .41949 .39298 .41498 Mtetra
.052 .544 .887 r
.39298 .41498 .40073 .41949 .41323 .42143 .40549 .41797 Mtetra
0 .525 .838 r
.40549 .41797 .41323 .42143 .42586 .42301 .41811 .42078 Mtetra
0 .535 .792 r
.41811 .42078 .42586 .42301 .43862 .4238 .43088 .42281 Mtetra
0 .547 .738 r
.43088 .42281 .43862 .4238 .45149 .42363 .44378 .42392 Mtetra
.065 .629 .729 r
.44378 .42392 .45149 .42363 .4645 .42188 .45683 .42306 Mtetra
.339 .819 .802 r
.45683 .42306 .4645 .42188 .47762 .41755 .47003 .4187 Mtetra
.616 .958 .867 r
.47003 .4187 .47762 .41755 .49083 .41064 .48334 .41083 Mtetra
.756 .989 .893 r
.48334 .41083 .49083 .41064 .5041 .40212 .4967 .40097 Mtetra
.814 .972 .899 r
.4967 .40097 .5041 .40212 .5174 .39261 .51009 .39014 Mtetra
.841 .941 .889 r
.51009 .39014 .5174 .39261 .53072 .38229 .52349 .37851 Mtetra
.844 .907 .88 r
.52349 .37851 .53072 .38229 .54405 .37158 .5369 .36667 Mtetra
.839 .878 .871 r
.5369 .36667 .54405 .37158 .55739 .36065 .5503 .35481 Mtetra
.832 .854 .862 r
.5503 .35481 .55739 .36065 .57075 .34959 .56371 .34296 Mtetra
.824 .835 .857 r
.56371 .34296 .57075 .34959 .58411 .33856 .57713 .3313 Mtetra
.816 .819 .852 r
.57713 .3313 .58411 .33856 .59748 .32757 .59056 .31979 Mtetra
.809 .807 .849 r
.59056 .31979 .59748 .32757 .61087 .31668 .604 .30849 Mtetra
.802 .797 .847 r
.604 .30849 .61087 .31668 .62427 .30591 .61745 .29739 Mtetra
.797 .79 .846 r
.61745 .29739 .62427 .30591 .63769 .29527 .63093 .28649 Mtetra
.791 .784 .846 r
.63093 .28649 .63769 .29527 .65114 .28478 .64442 .2758 Mtetra
.787 .78 .846 r
.64442 .2758 .65114 .28478 .6646 .27441 .65793 .26528 Mtetra
.783 .777 .847 r
.65793 .26528 .6646 .27441 .67809 .26417 .67147 .25494 Mtetra
.78 .774 .848 r
.67147 .25494 .67809 .26417 .6916 .25405 .68503 .24475 Mtetra
.777 .773 .849 r
.68503 .24475 .6916 .25405 .70513 .24404 .69863 .23469 Mtetra
.775 .773 .851 r
.69863 .23469 .70513 .24404 .7187 .23413 .71225 .22475 Mtetra
.773 .773 .852 r
.71225 .22475 .7187 .23413 .73229 .22429 .7259 .2149 Mtetra
.772 .773 .854 r
.7259 .2149 .73229 .22429 .74591 .21452 .73957 .20513 Mtetra
.771 .774 .856 r
.73957 .20513 .74591 .21452 .75956 .20479 .75328 .19542 Mtetra
.77 .776 .857 r
.75328 .19542 .75956 .20479 .77323 .1951 .76702 .18575 Mtetra
.77 .778 .859 r
.76702 .18575 .77323 .1951 .78693 .18542 .78078 .1761 Mtetra
.771 .779 .86 r
.78078 .1761 .78693 .18542 .80066 .17574 .79457 .16645 Mtetra
.45 .666 .955 r
.16488 .38002 .17289 .38748 .18377 .38786 .17578 .38028 Mtetra
.45 .663 .953 r
.17578 .38028 .18377 .38786 .19472 .38826 .18676 .38056 Mtetra
.45 .66 .951 r
.18676 .38056 .19472 .38826 .20575 .3887 .19781 .38089 Mtetra
.448 .656 .95 r
.19781 .38089 .20575 .3887 .21685 .3892 .20894 .38128 Mtetra
.444 .652 .948 r
.20894 .38128 .21685 .3892 .22803 .38978 .22014 .38176 Mtetra
.439 .648 .947 r
.22014 .38176 .22803 .38978 .23928 .39045 .23141 .38234 Mtetra
.432 .643 .946 r
.23141 .38234 .23928 .39045 .25061 .39124 .24276 .38306 Mtetra
.423 .637 .945 r
.24276 .38306 .25061 .39124 .26201 .39216 .25418 .38393 Mtetra
.412 .631 .944 r
.25418 .38393 .26201 .39216 .27349 .39324 .26567 .38499 Mtetra
.398 .624 .944 r
.26567 .38499 .27349 .39324 .28505 .39448 .27724 .38625 Mtetra
.381 .617 .944 r
.27724 .38625 .28505 .39448 .29668 .39592 .28889 .38774 Mtetra
.361 .61 .944 r
.28889 .38774 .29668 .39592 .3084 .39756 .30062 .38948 Mtetra
.337 .601 .944 r
.30062 .38948 .3084 .39756 .3202 .39942 .31242 .39151 Mtetra
.307 .591 .944 r
.31242 .39151 .3202 .39942 .33209 .4015 .32431 .39384 Mtetra
.271 .58 .942 r
.32431 .39384 .33209 .4015 .34407 .40381 .33629 .39649 Mtetra
.226 .566 .938 r
.33629 .39649 .34407 .40381 .35615 .40635 .34835 .39948 Mtetra
.173 .549 .929 r
.34835 .39948 .35615 .40635 .36832 .40907 .36052 .4028 Mtetra
.1 .523 .909 r
.36052 .4028 .36832 .40907 .38059 .412 .37278 .40649 Mtetra
.022 .495 .877 r
.37278 .40649 .38059 .412 .39298 .41498 .38515 .41044 Mtetra
0 .448 .816 r
.38515 .41044 .39298 .41498 .40549 .41797 .39764 .41465 Mtetra
0 .391 .723 r
.39764 .41465 .40549 .41797 .41811 .42078 .41025 .41897 Mtetra
.24 0 0 r
.41025 .41897 .41811 .42078 .43088 .42281 .42301 .42277 Mtetra
.338 0 0 r
.42301 .42277 .43088 .42281 .44378 .42392 .4359 .42651 Mtetra
.281 0 0 r
.4359 .42651 .44378 .42392 .45683 .42306 .44897 .4278 Mtetra
0 0 0 r
.44897 .4278 .45683 .42306 .47003 .4187 .46226 .42342 Mtetra
.512 .877 .657 r
.46226 .42342 .47003 .4187 .48334 .41083 .47571 .41334 Mtetra
.772 .995 .801 r
.47571 .41334 .48334 .41083 .4967 .40097 .4892 .40077 Mtetra
.844 .984 .864 r
.4892 .40077 .4967 .40097 .51009 .39014 .50269 .38811 Mtetra
.867 .946 .865 r
.50269 .38811 .51009 .39014 .52349 .37851 .51618 .37489 Mtetra
.864 .908 .861 r
.51618 .37489 .52349 .37851 .5369 .36667 .52966 .36174 Mtetra
.853 .877 .856 r
.52966 .36174 .5369 .36667 .5503 .35481 .54314 .34882 Mtetra
.843 .851 .85 r
.54314 .34882 .5503 .35481 .56371 .34296 .55661 .33613 Mtetra
.831 .831 .847 r
.55661 .33613 .56371 .34296 .57713 .3313 .57009 .32378 Mtetra
.821 .815 .844 r
.57009 .32378 .57713 .3313 .59056 .31979 .58357 .31174 Mtetra
.812 .802 .842 r
.58357 .31174 .59056 .31979 .604 .30849 .59706 .30001 Mtetra
.804 .793 .841 r
.59706 .30001 .604 .30849 .61745 .29739 .61057 .28858 Mtetra
.798 .785 .841 r
.61057 .28858 .61745 .29739 .63093 .28649 .62409 .27743 Mtetra
.792 .779 .842 r
.62409 .27743 .63093 .28649 .64442 .2758 .63763 .26655 Mtetra
.787 .775 .843 r
.63763 .26655 .64442 .2758 .65793 .26528 .6512 .2559 Mtetra
.782 .772 .844 r
.6512 .2559 .65793 .26528 .67147 .25494 .66479 .24546 Mtetra
.778 .77 .846 r
.66479 .24546 .67147 .25494 .68503 .24475 .67841 .23521 Mtetra
.775 .769 .847 r
.67841 .23521 .68503 .24475 .69863 .23469 .69205 .22512 Mtetra
.773 .769 .849 r
.69205 .22512 .69863 .23469 .71225 .22475 .70573 .21517 Mtetra
.771 .77 .851 r
.70573 .21517 .71225 .22475 .7259 .2149 .71944 .20534 Mtetra
.77 .771 .853 r
.71944 .20534 .7259 .2149 .73957 .20513 .73318 .19559 Mtetra
.769 .772 .855 r
.73318 .19559 .73957 .20513 .75328 .19542 .74695 .18592 Mtetra
.768 .774 .857 r
.74695 .18592 .75328 .19542 .76702 .18575 .76075 .17628 Mtetra
.768 .776 .859 r
.76075 .17628 .76702 .18575 .78078 .1761 .77457 .16668 Mtetra
.769 .778 .861 r
.77457 .16668 .78078 .1761 .79457 .16645 .78843 .15707 Mtetra
.457 .67 .955 r
.1568 .3725 .16488 .38002 .17578 .38028 .16773 .37262 Mtetra
.459 .666 .952 r
.16773 .37262 .17578 .38028 .18676 .38056 .17874 .37276 Mtetra
.458 .663 .95 r
.17874 .37276 .18676 .38056 .19781 .38089 .18982 .37295 Mtetra
.456 .658 .948 r
.18982 .37295 .19781 .38089 .20894 .38128 .20097 .37321 Mtetra
.452 .653 .946 r
.20097 .37321 .20894 .38128 .22014 .38176 .21219 .37357 Mtetra
.447 .648 .944 r
.21219 .37357 .22014 .38176 .23141 .38234 .22349 .37404 Mtetra
.439 .642 .943 r
.22349 .37404 .23141 .38234 .24276 .38306 .23486 .37467 Mtetra
.429 .636 .942 r
.23486 .37467 .24276 .38306 .25418 .38393 .2463 .37547 Mtetra
.417 .628 .941 r
.2463 .37547 .25418 .38393 .26567 .38499 .25781 .37648 Mtetra
.402 .621 .94 r
.25781 .37648 .26567 .38499 .27724 .38625 .26939 .37773 Mtetra
.384 .612 .94 r
.26939 .37773 .27724 .38625 .28889 .38774 .28105 .37925 Mtetra
.361 .602 .94 r
.28105 .37925 .28889 .38774 .30062 .38948 .29278 .38108 Mtetra
.333 .591 .939 r
.29278 .38108 .30062 .38948 .31242 .39151 .30459 .38326 Mtetra
.298 .577 .938 r
.30459 .38326 .31242 .39151 .32431 .39384 .31648 .38582 Mtetra
.255 .561 .934 r
.31648 .38582 .32431 .39384 .33629 .39649 .32845 .38881 Mtetra
.199 .54 .927 r
.32845 .38881 .33629 .39649 .34835 .39948 .3405 .39226 Mtetra
.129 .512 .912 r
.3405 .39226 .34835 .39948 .36052 .4028 .35265 .39622 Mtetra
.036 .471 .88 r
.35265 .39622 .36052 .4028 .37278 .40649 .36489 .40073 Mtetra
0 .415 .825 r
.36489 .40073 .37278 .40649 .38515 .41044 .37724 .4058 Mtetra
0 .331 .722 r
.37724 .4058 .38515 .41044 .39764 .41465 .38969 .41148 Mtetra
.367 0 0 r
.38969 .41148 .39764 .41465 .41025 .41897 .40227 .41777 Mtetra
.49 0 0 r
.40227 .41777 .41025 .41897 .42301 .42277 .41497 .42454 Mtetra
.673 .147 0 r
.41497 .42454 .42301 .42277 .4359 .42651 .42772 .43493 Mtetra
.601 .138 .124 r
.42772 .43493 .4359 .42651 .44897 .4278 .44073 .4421 Mtetra
.301 0 .082 r
.44073 .4421 .44897 .4278 .46226 .42342 .45416 .4377 Mtetra
0 0 0 r
.45416 .4377 .46226 .42342 .47571 .41334 .46785 .42169 Mtetra
.732 .915 .554 r
.46785 .42169 .47571 .41334 .4892 .40077 .48157 .40239 Mtetra
.876 .993 .798 r
.48157 .40239 .4892 .40077 .50269 .38811 .49519 .38668 Mtetra
.895 .949 .834 r
.49519 .38668 .50269 .38811 .51618 .37489 .50878 .3714 Mtetra
.883 .907 .84 r
.50878 .3714 .51618 .37489 .52966 .36174 .52235 .3567 Mtetra
.867 .873 .839 r
.52235 .3567 .52966 .36174 .54314 .34882 .53589 .34257 Mtetra
.851 .845 .837 r
.53589 .34257 .54314 .34882 .55661 .33613 .54943 .32897 Mtetra
.838 .825 .836 r
.54943 .32897 .55661 .33613 .57009 .32378 .56297 .3159 Mtetra
.825 .808 .834 r
.56297 .3159 .57009 .32378 .58357 .31174 .57651 .3033 Mtetra
.815 .796 .834 r
.57651 .3033 .58357 .31174 .59706 .30001 .59005 .29115 Mtetra
.806 .786 .835 r
.59005 .29115 .59706 .30001 .61057 .28858 .60361 .2794 Mtetra
.798 .779 .835 r
.60361 .2794 .61057 .28858 .62409 .27743 .61718 .26802 Mtetra
.791 .773 .837 r
.61718 .26802 .62409 .27743 .63763 .26655 .63078 .25696 Mtetra
.785 .769 .839 r
.63078 .25696 .63763 .26655 .6512 .2559 .64439 .2462 Mtetra
.78 .767 .841 r
.64439 .2462 .6512 .2559 .66479 .24546 .65804 .2357 Mtetra
.776 .765 .843 r
.65804 .2357 .66479 .24546 .67841 .23521 .67171 .22541 Mtetra
.773 .765 .845 r
.67171 .22541 .67841 .23521 .69205 .22512 .68542 .21532 Mtetra
.771 .765 .848 r
.68542 .21532 .69205 .22512 .70573 .21517 .69915 .20538 Mtetra
.768 .766 .85 r
.69915 .20538 .70573 .21517 .71944 .20534 .71292 .19558 Mtetra
.767 .767 .853 r
.71292 .19558 .71944 .20534 .73318 .19559 .72672 .18588 Mtetra
.766 .769 .855 r
.72672 .18588 .73318 .19559 .74695 .18592 .74055 .17626 Mtetra
.766 .772 .858 r
.74055 .17626 .74695 .18592 .76075 .17628 .75441 .16669 Mtetra
.766 .774 .86 r
.75441 .16669 .76075 .17628 .77457 .16668 .76831 .15715 Mtetra
.766 .777 .862 r
.76831 .15715 .77457 .16668 .78843 .15707 .78223 .14761 Mtetra
.467 .674 .954 r
.14865 .36491 .1568 .3725 .16773 .37262 .15962 .36487 Mtetra
.468 .67 .951 r
.15962 .36487 .16773 .37262 .17874 .37276 .17065 .36485 Mtetra
.468 .665 .949 r
.17065 .36485 .17874 .37276 .18982 .37295 .18176 .36488 Mtetra
.466 .66 .946 r
.18176 .36488 .18982 .37295 .20097 .37321 .19295 .36498 Mtetra
.462 .655 .944 r
.19295 .36498 .20097 .37321 .21219 .37357 .2042 .36519 Mtetra
.456 .649 .942 r
.2042 .36519 .21219 .37357 .22349 .37404 .21552 .36553 Mtetra
.448 .642 .94 r
.21552 .36553 .22349 .37404 .23486 .37467 .22691 .36604 Mtetra
.438 .635 .938 r
.22691 .36604 .23486 .37467 .2463 .37547 .23837 .36674 Mtetra
.425 .626 .937 r
.23837 .36674 .2463 .37547 .25781 .37648 .2499 .36767 Mtetra
.409 .617 .936 r
.2499 .36767 .25781 .37648 .26939 .37773 .2615 .36888 Mtetra
.389 .607 .935 r
.2615 .36888 .26939 .37773 .28105 .37925 .27317 .3704 Mtetra
.364 .595 .934 r
.27317 .3704 .28105 .37925 .29278 .38108 .28491 .37228 Mtetra
.334 .581 .933 r
.28491 .37228 .29278 .38108 .30459 .38326 .29672 .37457 Mtetra
.295 .564 .931 r
.29672 .37457 .30459 .38326 .31648 .38582 .30861 .37733 Mtetra
.245 .543 .926 r
.30861 .37733 .31648 .38582 .32845 .38881 .32057 .38063 Mtetra
.182 .516 .916 r
.32057 .38063 .32845 .38881 .3405 .39226 .33261 .38452 Mtetra
.097 .477 .895 r
.33261 .38452 .3405 .39226 .35265 .39622 .34474 .3891 Mtetra
0 .424 .856 r
.34474 .3891 .35265 .39622 .36489 .40073 .35695 .39442 Mtetra
0 .342 .779 r
.35695 .39442 .36489 .40073 .37724 .4058 .36926 .40065 Mtetra
0 .231 .649 r
.36926 .40065 .37724 .4058 .38969 .41148 .38167 .40785 Mtetra
.49 0 0 r
.38167 .40785 .38969 .41148 .40227 .41777 .39419 .41626 Mtetra
.637 .075 0 r
.39419 .41626 .40227 .41777 .41497 .42454 .4068 .42647 Mtetra
.799 .336 .137 r
.4068 .42647 .41497 .42454 .42772 .43493 .41932 .44518 Mtetra
.712 .288 .24 r
.41932 .44518 .42772 .43493 .44073 .4421 .43221 .45985 Mtetra
.344 0 .156 r
.43221 .45985 .44073 .4421 .45416 .4377 .44579 .45544 Mtetra
0 0 0 r
.44579 .45544 .45416 .4377 .46785 .42169 .45981 .43188 Mtetra
.864 .924 .534 r
.45981 .43188 .46785 .42169 .48157 .40239 .47381 .40417 Mtetra
.923 .973 .759 r
.47381 .40417 .48157 .40239 .49519 .38668 .48759 .38493 Mtetra
.916 .93 .805 r
.48759 .38493 .49519 .38668 .50878 .3714 .50129 .36745 Mtetra
.896 .89 .817 r
.50129 .36745 .50878 .3714 .52235 .3567 .51495 .35113 Mtetra
.876 .858 .82 r
.51495 .35113 .52235 .3567 .53589 .34257 .52857 .33575 Mtetra
.856 .832 .822 r
.52857 .33575 .53589 .34257 .54943 .32897 .54218 .32126 Mtetra
.841 .813 .823 r
.54218 .32126 .54943 .32897 .56297 .3159 .55578 .30747 Mtetra
.827 .798 .824 r
.55578 .30747 .56297 .3159 .57651 .3033 .56937 .29435 Mtetra
.815 .786 .825 r
.56937 .29435 .57651 .3033 .59005 .29115 .58297 .28181 Mtetra
.805 .777 .827 r
.58297 .28181 .59005 .29115 .60361 .2794 .59658 .26977 Mtetra
.796 .77 .829 r
.59658 .26977 .60361 .2794 .61718 .26802 .61021 .25819 Mtetra
.789 .766 .832 r
.61021 .25819 .61718 .26802 .63078 .25696 .62385 .247 Mtetra
.783 .762 .834 r
.62385 .247 .63078 .25696 .64439 .2462 .63752 .23616 Mtetra
.778 .761 .837 r
.63752 .23616 .64439 .2462 .65804 .2357 .65122 .22561 Mtetra
.774 .76 .84 r
.65122 .22561 .65804 .2357 .67171 .22541 .66495 .21533 Mtetra
.77 .76 .843 r
.66495 .21533 .67171 .22541 .68542 .21532 .67871 .20525 Mtetra
.767 .76 .846 r
.67871 .20525 .68542 .21532 .69915 .20538 .69251 .19536 Mtetra
.765 .762 .849 r
.69251 .19536 .69915 .20538 .71292 .19558 .70633 .18562 Mtetra
.764 .764 .852 r
.70633 .18562 .71292 .19558 .72672 .18588 .72019 .17599 Mtetra
.763 .766 .855 r
.72019 .17599 .72672 .18588 .74055 .17626 .73409 .16645 Mtetra
.763 .769 .858 r
.73409 .16645 .74055 .17626 .75441 .16669 .74802 .15696 Mtetra
.763 .772 .861 r
.74802 .15696 .75441 .16669 .76831 .15715 .76198 .14751 Mtetra
.763 .776 .863 r
.76198 .14751 .76831 .15715 .78223 .14761 .77598 .13806 Mtetra
.478 .678 .953 r
.14044 .35727 .14865 .36491 .15962 .36487 .15144 .35703 Mtetra
.479 .674 .95 r
.15144 .35703 .15962 .36487 .17065 .36485 .16251 .35682 Mtetra
.479 .669 .947 r
.16251 .35682 .17065 .36485 .18176 .36488 .17366 .35667 Mtetra
.477 .663 .944 r
.17366 .35667 .18176 .36488 .19295 .36498 .18487 .35659 Mtetra
.473 .657 .941 r
.18487 .35659 .19295 .36498 .2042 .36519 .19615 .35662 Mtetra
.467 .65 .938 r
.19615 .35662 .2042 .36519 .21552 .36553 .2075 .35679 Mtetra
.459 .642 .936 r
.2075 .35679 .21552 .36553 .22691 .36604 .21892 .35715 Mtetra
.448 .634 .934 r
.21892 .35715 .22691 .36604 .23837 .36674 .23041 .35771 Mtetra
.435 .625 .932 r
.23041 .35771 .23837 .36674 .2499 .36767 .24196 .35853 Mtetra
.418 .614 .931 r
.24196 .35853 .2499 .36767 .2615 .36888 .25357 .35965 Mtetra
.398 .602 .93 r
.25357 .35965 .2615 .36888 .27317 .3704 .26525 .36112 Mtetra
.372 .589 .928 r
.26525 .36112 .27317 .3704 .28491 .37228 .277 .36301 Mtetra
.34 .573 .926 r
.277 .36301 .28491 .37228 .29672 .37457 .28882 .36537 Mtetra
.299 .553 .923 r
.28882 .36537 .29672 .37457 .30861 .37733 .3007 .36827 Mtetra
.246 .528 .917 r
.3007 .36827 .30861 .37733 .32057 .38063 .31266 .37181 Mtetra
.178 .496 .905 r
.31266 .37181 .32057 .38063 .33261 .38452 .32469 .37606 Mtetra
.086 .449 .882 r
.32469 .37606 .33261 .38452 .34474 .3891 .33679 .38117 Mtetra
0 .389 .841 r
.33679 .38117 .34474 .3891 .35695 .39442 .34898 .3872 Mtetra
0 .294 .758 r
.34898 .3872 .35695 .39442 .36926 .40065 .36125 .39442 Mtetra
0 .174 .628 r
.36125 .39442 .36926 .40065 .38167 .40785 .37361 .40293 Mtetra
.533 0 0 r
.37361 .40293 .38167 .40785 .39419 .41626 .38607 .4131 Mtetra
.689 .145 0 r
.38607 .4131 .39419 .41626 .4068 .42647 .39861 .42592 Mtetra
.851 .406 .151 r
.39861 .42592 .4068 .42647 .41932 .44518 .41094 .45033 Mtetra
.788 .348 .202 r
.41094 .45033 .41932 .44518 .43221 .45985 .42372 .47011 Mtetra
.197 0 0 r
.42372 .47011 .43221 .45985 .44579 .45544 .43742 .46567 Mtetra
.884 .93 .549 r
.43742 .46567 .44579 .45544 .45981 .43188 .45172 .43695 Mtetra
.981 .913 .626 r
.45172 .43695 .45981 .43188 .47381 .40417 .46598 .40346 Mtetra
.947 .92 .752 r
.46598 .40346 .47381 .40417 .48759 .38493 .47991 .38152 Mtetra
.921 .887 .782 r
.47991 .38152 .48759 .38493 .50129 .36745 .49372 .36219 Mtetra
.897 .858 .795 r
.49372 .36219 .50129 .36745 .51495 .35113 .50748 .34448 Mtetra
.876 .833 .801 r
.50748 .34448 .51495 .35113 .52857 .33575 .52118 .32801 Mtetra
.856 .812 .806 r
.52118 .32801 .52857 .33575 .54218 .32126 .53486 .31272 Mtetra
.84 .796 .81 r
.53486 .31272 .54218 .32126 .55578 .30747 .54851 .29831 Mtetra
.825 .783 .813 r
.54851 .29831 .55578 .30747 .56937 .29435 .56216 .28474 Mtetra
.813 .773 .816 r
.56216 .28474 .56937 .29435 .58297 .28181 .57582 .27186 Mtetra
.802 .766 .819 r
.57582 .27186 .58297 .28181 .59658 .26977 .58948 .2596 Mtetra
.793 .76 .823 r
.58948 .2596 .59658 .26977 .61021 .25819 .60316 .24787 Mtetra
.786 .757 .826 r
.60316 .24787 .61021 .25819 .62385 .247 .61686 .23659 Mtetra
.78 .754 .83 r
.61686 .23659 .62385 .247 .63752 .23616 .63058 .22572 Mtetra
.774 .753 .834 r
.63058 .22572 .63752 .23616 .65122 .22561 .64434 .21517 Mtetra
.77 .753 .837 r
.64434 .21517 .65122 .22561 .66495 .21533 .65812 .20492 Mtetra
.766 .753 .841 r
.65812 .20492 .66495 .21533 .67871 .20525 .67194 .1949 Mtetra
.764 .755 .845 r
.67194 .1949 .67871 .20525 .69251 .19536 .68579 .18509 Mtetra
.761 .757 .849 r
.68579 .18509 .69251 .19536 .70633 .18562 .69968 .17543 Mtetra
.76 .76 .852 r
.69968 .17543 .70633 .18562 .72019 .17599 .71361 .1659 Mtetra
.759 .763 .855 r
.71361 .1659 .72019 .17599 .73409 .16645 .72757 .15647 Mtetra
.759 .766 .859 r
.72757 .15647 .73409 .16645 .74802 .15696 .74156 .14709 Mtetra
.759 .77 .862 r
.74156 .14709 .74802 .15696 .76198 .14751 .7556 .13776 Mtetra
.76 .774 .865 r
.7556 .13776 .76198 .14751 .77598 .13806 .76966 .12842 Mtetra
.49 .683 .952 r
.13216 .34956 .14044 .35727 .15144 .35703 .1432 .34911 Mtetra
.491 .678 .948 r
.1432 .34911 .15144 .35703 .16251 .35682 .15431 .34868 Mtetra
.491 .672 .945 r
.15431 .34868 .16251 .35682 .17366 .35667 .16549 .34831 Mtetra
.489 .666 .941 r
.16549 .34831 .17366 .35667 .18487 .35659 .17674 .34801 Mtetra
.485 .659 .938 r
.17674 .34801 .18487 .35659 .19615 .35662 .18806 .34784 Mtetra
.479 .651 .935 r
.18806 .34784 .19615 .35662 .2075 .35679 .19944 .34781 Mtetra
.471 .643 .932 r
.19944 .34781 .2075 .35679 .21892 .35715 .21089 .34797 Mtetra
.461 .634 .929 r
.21089 .34797 .21892 .35715 .23041 .35771 .2224 .34836 Mtetra
.448 .623 .927 r
.2224 .34836 .23041 .35771 .24196 .35853 .23398 .34902 Mtetra
.431 .612 .925 r
.23398 .34902 .24196 .35853 .25357 .35965 .24561 .35001 Mtetra
.41 .599 .923 r
.24561 .35001 .25357 .35965 .26525 .36112 .25731 .35138 Mtetra
.384 .584 .921 r
.25731 .35138 .26525 .36112 .277 .36301 .26907 .3532 Mtetra
.352 .566 .918 r
.26907 .3532 .277 .36301 .28882 .36537 .2809 .35555 Mtetra
.31 .544 .914 r
.2809 .35555 .28882 .36537 .3007 .36827 .29278 .35852 Mtetra
.257 .516 .908 r
.29278 .35852 .3007 .36827 .31266 .37181 .30473 .3622 Mtetra
.189 .481 .896 r
.30473 .3622 .31266 .37181 .32469 .37606 .31675 .36671 Mtetra
.098 .432 .874 r
.31675 .36671 .32469 .37606 .33679 .38117 .32884 .37219 Mtetra
0 .369 .835 r
.32884 .37219 .33679 .38117 .34898 .3872 .341 .37875 Mtetra
0 .278 .764 r
.341 .37875 .34898 .3872 .36125 .39442 .35324 .38665 Mtetra
0 .166 .657 r
.35324 .38665 .36125 .39442 .37361 .40293 .36556 .39602 Mtetra
.49 0 0 r
.36556 .39602 .37361 .40293 .38607 .4131 .37798 .40718 Mtetra
.642 .112 0 r
.37798 .40718 .38607 .4131 .39861 .42592 .39049 .42077 Mtetra
.85 .39 .033 r
.39049 .42077 .39861 .42592 .41094 .45033 .40281 .445 Mtetra
.784 .289 0 r
.40281 .445 .41094 .45033 .42372 .47011 .4156 .46433 Mtetra
.632 .827 .975 r
.4156 .46433 .42372 .47011 .43742 .46567 .42934 .45986 Mtetra
.932 .813 .705 r
.42934 .45986 .43742 .46567 .45172 .43695 .44375 .4315 Mtetra
.946 .806 .674 r
.44375 .4315 .45172 .43695 .46598 .40346 .45814 .39812 Mtetra
.921 .838 .745 r
.45814 .39812 .46598 .40346 .47991 .38152 .47218 .37533 Mtetra
.904 .832 .764 r
.47218 .37533 .47991 .38152 .49372 .36219 .4861 .35492 Mtetra
.885 .816 .775 r
.4861 .35492 .49372 .36219 .50748 .34448 .49994 .33625 Mtetra
.867 .801 .784 r
.49994 .33625 .50748 .34448 .52118 .32801 .51372 .31902 Mtetra
.849 .788 .791 r
.51372 .31902 .52118 .32801 .53486 .31272 .52746 .3031 Mtetra
.834 .776 .796 r
.52746 .3031 .53486 .31272 .54851 .29831 .54118 .28823 Mtetra
.82 .766 .802 r
.54118 .28823 .54851 .29831 .56216 .28474 .55489 .27432 Mtetra
.808 .758 .807 r
.55489 .27432 .56216 .28474 .57582 .27186 .5686 .26121 Mtetra
.798 .753 .811 r
.5686 .26121 .57582 .27186 .58948 .2596 .58231 .24879 Mtetra
.789 .749 .816 r
.58231 .24879 .58948 .2596 .60316 .24787 .59604 .23699 Mtetra
.781 .746 .821 r
.59604 .23699 .60316 .24787 .61686 .23659 .6098 .22568 Mtetra
.775 .745 .826 r
.6098 .22568 .61686 .23659 .63058 .22572 .62357 .21483 Mtetra
.77 .745 .83 r
.62357 .21483 .63058 .22572 .64434 .21517 .63738 .20434 Mtetra
.765 .745 .835 r
.63738 .20434 .64434 .21517 .65812 .20492 .65122 .19416 Mtetra
.762 .747 .839 r
.65122 .19416 .65812 .20492 .67194 .1949 .6651 .18424 Mtetra
.759 .749 .843 r
.6651 .18424 .67194 .1949 .68579 .18509 .67901 .17454 Mtetra
.757 .752 .848 r
.67901 .17454 .68579 .18509 .69968 .17543 .69296 .16501 Mtetra
.755 .755 .852 r
.69296 .16501 .69968 .17543 .71361 .1659 .70695 .15561 Mtetra
.755 .759 .856 r
.70695 .15561 .71361 .1659 .72757 .15647 .72098 .14631 Mtetra
.754 .763 .859 r
.72098 .14631 .72757 .15647 .74156 .14709 .73505 .13708 Mtetra
.755 .767 .863 r
.73505 .13708 .74156 .14709 .7556 .13776 .74915 .12789 Mtetra
.756 .772 .866 r
.74915 .12789 .7556 .13776 .76966 .12842 .76329 .11869 Mtetra
.503 .689 .951 r
.12381 .34178 .13216 .34956 .1432 .34911 .13489 .34109 Mtetra
.505 .683 .946 r
.13489 .34109 .1432 .34911 .15431 .34868 .14605 .34042 Mtetra
.505 .676 .942 r
.14605 .34042 .15431 .34868 .16549 .34831 .15727 .33979 Mtetra
.503 .669 .938 r
.15727 .33979 .16549 .34831 .17674 .34801 .16856 .33926 Mtetra
.499 .661 .934 r
.16856 .33926 .17674 .34801 .18806 .34784 .17992 .33884 Mtetra
.493 .653 .93 r
.17992 .33884 .18806 .34784 .19944 .34781 .19134 .33857 Mtetra
.485 .644 .927 r
.19134 .33857 .19944 .34781 .21089 .34797 .20282 .3385 Mtetra
.475 .634 .924 r
.20282 .3385 .21089 .34797 .2224 .34836 .21436 .33867 Mtetra
.462 .623 .921 r
.21436 .33867 .2224 .34836 .23398 .34902 .22597 .33912 Mtetra
.446 .61 .918 r
.22597 .33912 .23398 .34902 .24561 .35001 .23763 .33992 Mtetra
.426 .597 .916 r
.23763 .33992 .24561 .35001 .25731 .35138 .24935 .34112 Mtetra
.4 .58 .913 r
.24935 .34112 .25731 .35138 .26907 .3532 .26112 .34282 Mtetra
.368 .561 .91 r
.26112 .34282 .26907 .3532 .2809 .35555 .27296 .34508 Mtetra
.327 .538 .905 r
.27296 .34508 .2809 .35555 .29278 .35852 .28485 .34801 Mtetra
.276 .508 .898 r
.28485 .34801 .29278 .35852 .30473 .3622 .2968 .35174 Mtetra
.21 .472 .887 r
.2968 .35174 .30473 .3622 .31675 .36671 .30881 .35638 Mtetra
.123 .423 .866 r
.30881 .35638 .31675 .36671 .32884 .37219 .32088 .36209 Mtetra
.014 .358 .831 r
.32088 .36209 .32884 .37219 .341 .37875 .33302 .36904 Mtetra
0 .273 .772 r
.33302 .36904 .341 .37875 .35324 .38665 .34522 .37741 Mtetra
0 .166 .681 r
.34522 .37741 .35324 .38665 .36556 .39602 .35751 .38742 Mtetra
0 .045 .557 r
.35751 .38742 .36556 .39602 .37798 .40718 .36989 .39928 Mtetra
.574 .07 0 r
.36989 .39928 .37798 .40718 .39049 .42077 .38238 .4131 Mtetra
.811 .345 0 r
.38238 .4131 .39049 .42077 .40281 .445 .39474 .43577 Mtetra
.648 .17 0 r
.39474 .43577 .40281 .445 .4156 .46433 .40756 .45339 Mtetra
.645 .698 .884 r
.40756 .45339 .4156 .46433 .42934 .45986 .42134 .44888 Mtetra
.887 .75 .705 r
.42134 .44888 .42934 .45986 .44375 .4315 .4358 .42214 Mtetra
.916 .766 .68 r
.4358 .42214 .44375 .4315 .45814 .39812 .45026 .39024 Mtetra
.901 .797 .736 r
.45026 .39024 .45814 .39812 .47218 .37533 .4644 .36713 Mtetra
.891 .796 .749 r
.4644 .36713 .47218 .37533 .4861 .35492 .47841 .34593 Mtetra
.874 .786 .76 r
.47841 .34593 .4861 .35492 .49994 .33625 .49234 .32653 Mtetra
.857 .775 .769 r
.49234 .32653 .49994 .33625 .51372 .31902 .5062 .30874 Mtetra
.841 .765 .778 r
.5062 .30874 .51372 .31902 .52746 .3031 .52 .29234 Mtetra
.826 .755 .785 r
.52 .29234 .52746 .3031 .54118 .28823 .53378 .27715 Mtetra
.813 .748 .792 r
.53378 .27715 .54118 .28823 .55489 .27432 .54755 .26301 Mtetra
.802 .743 .798 r
.54755 .26301 .55489 .27432 .5686 .26121 .56131 .24977 Mtetra
.791 .739 .804 r
.56131 .24977 .5686 .26121 .58231 .24879 .57508 .2373 Mtetra
.783 .736 .81 r
.57508 .2373 .58231 .24879 .59604 .23699 .58886 .2255 Mtetra
.775 .735 .816 r
.58886 .2255 .59604 .23699 .6098 .22568 .60266 .21424 Mtetra
.769 .735 .821 r
.60266 .21424 .6098 .22568 .62357 .21483 .6165 .20347 Mtetra
.764 .735 .827 r
.6165 .20347 .62357 .21483 .63738 .20434 .63036 .19309 Mtetra
.759 .737 .832 r
.63036 .19309 .63738 .20434 .65122 .19416 .64426 .18304 Mtetra
.756 .739 .837 r
.64426 .18304 .65122 .19416 .6651 .18424 .65819 .17326 Mtetra
.753 .742 .842 r
.65819 .17326 .6651 .18424 .67901 .17454 .67217 .16371 Mtetra
.751 .746 .847 r
.67217 .16371 .67901 .17454 .69296 .16501 .68618 .15434 Mtetra
.75 .75 .852 r
.68618 .15434 .69296 .16501 .70695 .15561 .70023 .14511 Mtetra
.75 .754 .856 r
.70023 .14511 .70695 .15561 .72098 .14631 .71433 .13598 Mtetra
.749 .759 .86 r
.71433 .13598 .72098 .14631 .73505 .13708 .72847 .12692 Mtetra
.75 .764 .864 r
.72847 .12692 .73505 .13708 .74915 .12789 .74264 .1179 Mtetra
.751 .77 .868 r
.74264 .1179 .74915 .12789 .76329 .11869 .75685 .10887 Mtetra
.518 .694 .949 r
.11539 .33394 .12381 .34178 .13489 .34109 .12652 .33298 Mtetra
.52 .688 .944 r
.12652 .33298 .13489 .34109 .14605 .34042 .13773 .33202 Mtetra
.519 .681 .939 r
.13773 .33202 .14605 .34042 .15727 .33979 .149 .33112 Mtetra
.517 .673 .934 r
.149 .33112 .15727 .33979 .16856 .33926 .16033 .33031 Mtetra
.514 .664 .93 r
.16033 .33031 .16856 .33926 .17992 .33884 .17173 .32961 Mtetra
.509 .655 .925 r
.17173 .32961 .17992 .33884 .19134 .33857 .18319 .32906 Mtetra
.501 .645 .921 r
.18319 .32906 .19134 .33857 .20282 .3385 .19471 .32872 Mtetra
.491 .635 .917 r
.19471 .32872 .20282 .3385 .21436 .33867 .20629 .3286 Mtetra
.479 .623 .914 r
.20629 .3286 .21436 .33867 .22597 .33912 .21793 .32879 Mtetra
.463 .61 .91 r
.21793 .32879 .22597 .33912 .23763 .33992 .22962 .32934 Mtetra
.444 .595 .907 r
.22962 .32934 .23763 .33992 .24935 .34112 .24137 .3303 Mtetra
.419 .577 .903 r
.24137 .3303 .24935 .34112 .26112 .34282 .25317 .33178 Mtetra
.39 .558 .899 r
.25317 .33178 .26112 .34282 .27296 .34508 .26502 .33385 Mtetra
.351 .533 .894 r
.26502 .33385 .27296 .34508 .28485 .34801 .27692 .33665 Mtetra
.302 .503 .887 r
.27692 .33665 .28485 .34801 .2968 .35174 .28887 .3403 Mtetra
.241 .467 .876 r
.28887 .3403 .2968 .35174 .30881 .35638 .30088 .34494 Mtetra
.159 .418 .858 r
.30088 .34494 .30881 .35638 .32088 .36209 .31294 .35075 Mtetra
.056 .355 .828 r
.31294 .35075 .32088 .36209 .33302 .36904 .32505 .35792 Mtetra
0 .275 .779 r
.32505 .35792 .33302 .36904 .34522 .37741 .33723 .36664 Mtetra
0 .171 .7 r
.33723 .36664 .34522 .37741 .35751 .38742 .34948 .37715 Mtetra
0 .055 .593 r
.34948 .37715 .35751 .38742 .36989 .39928 .36182 .38964 Mtetra
0 0 .478 r
.36182 .38964 .36989 .39928 .38238 .4131 .37427 .40399 Mtetra
.789 .329 0 r
.37427 .40399 .38238 .4131 .39474 .43577 .38659 .42671 Mtetra
.653 .172 0 r
.38659 .42671 .39474 .43577 .40756 .45339 .3994 .4442 Mtetra
.647 .741 .918 r
.3994 .4442 .40756 .45339 .42134 .44888 .41322 .43964 Mtetra
.901 .773 .711 r
.41322 .43964 .42134 .44888 .4358 .42214 .42777 .41295 Mtetra
.918 .769 .68 r
.42777 .41295 .4358 .42214 .45026 .39024 .44235 .38091 Mtetra
.892 .776 .727 r
.44235 .38091 .45026 .39024 .4644 .36713 .45658 .35718 Mtetra
.879 .769 .737 r
.45658 .35718 .4644 .36713 .47841 .34593 .47069 .33526 Mtetra
.863 .759 .747 r
.47069 .33526 .47841 .34593 .49234 .32653 .48469 .31526 Mtetra
.846 .75 .757 r
.48469 .31526 .49234 .32653 .5062 .30874 .49862 .29703 Mtetra
.831 .741 .765 r
.49862 .29703 .5062 .30874 .52 .29234 .51249 .28031 Mtetra
.817 .734 .774 r
.51249 .28031 .52 .29234 .53378 .27715 .52633 .26493 Mtetra
.804 .729 .782 r
.52633 .26493 .53378 .27715 .54755 .26301 .54014 .25071 Mtetra
.793 .725 .789 r
.54014 .25071 .54755 .26301 .56131 .24977 .55396 .23745 Mtetra
.783 .723 .796 r
.55396 .23745 .56131 .24977 .57508 .2373 .56777 .22504 Mtetra
.774 .722 .804 r
.56777 .22504 .57508 .2373 .58886 .2255 .58161 .21333 Mtetra
.768 .722 .81 r
.58161 .21333 .58886 .2255 .60266 .21424 .59547 .20221 Mtetra
.761 .723 .817 r
.59547 .20221 .60266 .21424 .6165 .20347 .60935 .19159 Mtetra
.757 .725 .823 r
.60935 .19159 .6165 .20347 .63036 .19309 .62327 .18138 Mtetra
.753 .728 .829 r
.62327 .18138 .63036 .19309 .64426 .18304 .63722 .17152 Mtetra
.749 .731 .835 r
.63722 .17152 .64426 .18304 .65819 .17326 .65122 .16194 Mtetra
.747 .735 .841 r
.65122 .16194 .65819 .17326 .67217 .16371 .66525 .15259 Mtetra
.745 .739 .847 r
.66525 .15259 .67217 .16371 .68618 .15434 .67933 .14342 Mtetra
.744 .744 .852 r
.67933 .14342 .68618 .15434 .70023 .14511 .69345 .13439 Mtetra
.744 .749 .857 r
.69345 .13439 .70023 .14511 .71433 .13598 .70761 .12546 Mtetra
.744 .755 .862 r
.70761 .12546 .71433 .13598 .72847 .12692 .72182 .11661 Mtetra
.744 .761 .866 r
.72182 .11661 .72847 .12692 .74264 .1179 .73607 .10778 Mtetra
.746 .767 .87 r
.73607 .10778 .74264 .1179 .75685 .10887 .75036 .09896 Mtetra
.533 .7 .946 r
.1069 .32604 .11539 .33394 .12652 .33298 .11809 .32477 Mtetra
.535 .693 .941 r
.11809 .32477 .12652 .33298 .13773 .33202 .12934 .32351 Mtetra
.535 .685 .935 r
.12934 .32351 .13773 .33202 .149 .33112 .14066 .32229 Mtetra
.533 .677 .93 r
.14066 .32229 .149 .33112 .16033 .33031 .15205 .32116 Mtetra
.53 .668 .925 r
.15205 .32116 .16033 .33031 .17173 .32961 .1635 .32015 Mtetra
.525 .658 .92 r
.1635 .32015 .17173 .32961 .18319 .32906 .17501 .31928 Mtetra
.517 .647 .915 r
.17501 .31928 .18319 .32906 .19471 .32872 .18657 .31861 Mtetra
.508 .636 .911 r
.18657 .31861 .19471 .32872 .20629 .3286 .19819 .31818 Mtetra
.497 .624 .906 r
.19819 .31818 .20629 .3286 .21793 .32879 .20987 .31804 Mtetra
.482 .61 .902 r
.20987 .31804 .21793 .32879 .22962 .32934 .2216 .31826 Mtetra
.464 .595 .898 r
.2216 .31826 .22962 .32934 .24137 .3303 .23338 .3189 Mtetra
.441 .576 .893 r
.23338 .3189 .24137 .3303 .25317 .33178 .24521 .32008 Mtetra
.414 .556 .888 r
.24521 .32008 .25317 .33178 .26502 .33385 .25708 .32186 Mtetra
.378 .532 .883 r
.25708 .32186 .26502 .33385 .27692 .33665 .269 .3244 Mtetra
.333 .502 .875 r
.269 .3244 .27692 .33665 .28887 .3403 .28097 .32783 Mtetra
.277 .465 .865 r
.28097 .32783 .28887 .3403 .30088 .34494 .29298 .33231 Mtetra
.203 .418 .849 r
.29298 .33231 .30088 .34494 .31294 .35075 .30503 .33805 Mtetra
.109 .358 .823 r
.30503 .33805 .31294 .35075 .32505 .35792 .31713 .34526 Mtetra
0 .283 .783 r
.31713 .34526 .32505 .35792 .33723 .36664 .32928 .35414 Mtetra
0 .184 .718 r
.32928 .35414 .33723 .36664 .34948 .37715 .34149 .36501 Mtetra
0 .072 .625 r
.34149 .36501 .34948 .37715 .36182 .38964 .35377 .37804 Mtetra
0 0 .522 r
.35377 .37804 .36182 .38964 .37427 .40399 .36616 .3931 Mtetra
.774 .332 0 r
.36616 .3931 .37427 .40399 .38659 .42671 .37839 .41699 Mtetra
.665 .194 0 r
.37839 .41699 .38659 .42671 .3994 .4442 .39113 .43547 Mtetra
.647 .754 .928 r
.39113 .43547 .3994 .4442 .41322 .43964 .405 .43087 Mtetra
.909 .779 .706 r
.405 .43087 .41322 .43964 .42777 .41295 .41969 .4031 Mtetra
.917 .761 .674 r
.41969 .4031 .42777 .41295 .44235 .38091 .43441 .36979 Mtetra
.881 .752 .716 r
.43441 .36979 .44235 .38091 .45658 .35718 .44874 .34526 Mtetra
.866 .742 .725 r
.44874 .34526 .45658 .35718 .47069 .33526 .46294 .32269 Mtetra
.849 .732 .735 r
.46294 .32269 .47069 .33526 .48469 .31526 .47702 .30225 Mtetra
.833 .724 .745 r
.47702 .30225 .48469 .31526 .49862 .29703 .491 .28375 Mtetra
.818 .718 .754 r
.491 .28375 .49862 .29703 .51249 .28031 .50493 .2669 Mtetra
.805 .713 .763 r
.50493 .2669 .51249 .28031 .52633 .26493 .51882 .2515 Mtetra
.792 .709 .773 r
.51882 .2515 .52633 .26493 .54014 .25071 .53268 .23734 Mtetra
.782 .707 .781 r
.53268 .23734 .54014 .25071 .55396 .23745 .54655 .22422 Mtetra
.773 .707 .79 r
.54655 .22422 .55396 .23745 .56777 .22504 .56041 .21197 Mtetra
.765 .707 .798 r
.56041 .21197 .56777 .22504 .58161 .21333 .57429 .20047 Mtetra
.759 .709 .805 r
.57429 .20047 .58161 .21333 .59547 .20221 .5882 .18957 Mtetra
.753 .711 .813 r
.5882 .18957 .59547 .20221 .60935 .19159 .60214 .17919 Mtetra
.748 .715 .82 r
.60214 .17919 .60935 .19159 .62327 .18138 .61611 .16922 Mtetra
.745 .718 .827 r
.61611 .16922 .62327 .18138 .63722 .17152 .63012 .15961 Mtetra
.742 .723 .834 r
.63012 .15961 .63722 .17152 .65122 .16194 .64418 .15027 Mtetra
.74 .728 .84 r
.64418 .15027 .65122 .16194 .66525 .15259 .65827 .14116 Mtetra
.738 .733 .846 r
.65827 .14116 .66525 .15259 .67933 .14342 .67241 .13224 Mtetra
.737 .738 .852 r
.67241 .13224 .67933 .14342 .69345 .13439 .6866 .12345 Mtetra
.737 .744 .858 r
.6866 .12345 .69345 .13439 .70761 .12546 .70083 .11476 Mtetra
.737 .751 .863 r
.70083 .11476 .70761 .12546 .72182 .11661 .71511 .10614 Mtetra
.738 .757 .868 r
.71511 .10614 .72182 .11661 .73607 .10778 .72944 .09755 Mtetra
.74 .764 .873 r
.72944 .09755 .73607 .10778 .75036 .09896 .74381 .08896 Mtetra
.55 .706 .943 r
.09834 .31807 .1069 .32604 .11809 .32477 .10959 .31646 Mtetra
.551 .698 .937 r
.10959 .31646 .11809 .32477 .12934 .32351 .1209 .31486 Mtetra
.551 .69 .931 r
.1209 .31486 .12934 .32351 .14066 .32229 .13228 .31331 Mtetra
.549 .681 .925 r
.13228 .31331 .14066 .32229 .15205 .32116 .14372 .31183 Mtetra
.546 .671 .919 r
.14372 .31183 .15205 .32116 .1635 .32015 .15522 .31046 Mtetra
.541 .661 .914 r
.15522 .31046 .1635 .32015 .17501 .31928 .16678 .30923 Mtetra
.535 .65 .909 r
.16678 .30923 .17501 .31928 .18657 .31861 .1784 .30819 Mtetra
.526 .638 .903 r
.1784 .30819 .18657 .31861 .19819 .31818 .19007 .30737 Mtetra
.516 .625 .898 r
.19007 .30737 .19819 .31818 .20987 .31804 .20179 .30684 Mtetra
.502 .611 .893 r
.20179 .30684 .20987 .31804 .2216 .31826 .21356 .30667 Mtetra
.487 .595 .888 r
.21356 .30667 .2216 .31826 .23338 .3189 .22539 .3069 Mtetra
.465 .577 .882 r
.22539 .3069 .23338 .3189 .24521 .32008 .23725 .30767 Mtetra
.441 .556 .876 r
.23725 .30767 .24521 .32008 .25708 .32186 .24916 .30905 Mtetra
.409 .532 .87 r
.24916 .30905 .25708 .32186 .269 .3244 .26111 .31119 Mtetra
.369 .502 .862 r
.26111 .31119 .269 .3244 .28097 .32783 .27309 .31425 Mtetra
.319 .467 .852 r
.27309 .31425 .28097 .32783 .29298 .33231 .28512 .31839 Mtetra
.253 .422 .837 r
.28512 .31839 .29298 .33231 .30503 .33805 .29717 .32387 Mtetra
.168 .366 .815 r
.29717 .32387 .30503 .33805 .31713 .34526 .30926 .33092 Mtetra
.061 .294 .782 r
.30926 .33092 .31713 .34526 .32928 .35414 .32139 .33981 Mtetra
0 .199 .726 r
.32139 .33981 .32928 .35414 .34149 .36501 .33355 .35092 Mtetra
0 .085 .644 r
.33355 .35092 .34149 .36501 .35377 .37804 .34577 .3645 Mtetra
0 0 .543 r
.34577 .3645 .35377 .37804 .36616 .3931 .35808 .38045 Mtetra
.77 .35 0 r
.35808 .38045 .36616 .3931 .37839 .41699 .37016 .40624 Mtetra
.684 .23 0 r
.37016 .40624 .37839 .41699 .39113 .43547 .3828 .42643 Mtetra
.647 .748 .923 r
.3828 .42643 .39113 .43547 .405 .43087 .39671 .42178 Mtetra
.912 .774 .696 r
.39671 .42178 .405 .43087 .41969 .4031 .41157 .39221 Mtetra
.914 .75 .664 r
.41157 .39221 .41969 .4031 .43441 .36979 .42646 .35689 Mtetra
.871 .731 .705 r
.42646 .35689 .43441 .36979 .44874 .34526 .4409 .33137 Mtetra
.853 .718 .713 r
.4409 .33137 .44874 .34526 .46294 .32269 .45517 .30816 Mtetra
.835 .707 .723 r
.45517 .30816 .46294 .32269 .47702 .30225 .46932 .28737 Mtetra
.818 .699 .733 r
.46932 .28737 .47702 .30225 .491 .28375 .48336 .26877 Mtetra
.803 .694 .744 r
.48336 .26877 .491 .28375 .50493 .2669 .49734 .25199 Mtetra
.79 .69 .754 r
.49734 .25199 .50493 .2669 .51882 .2515 .51127 .23675 Mtetra
.779 .688 .764 r
.51127 .23675 .51882 .2515 .53268 .23734 .52518 .22284 Mtetra
.769 .689 .774 r
.52518 .22284 .53268 .23734 .54655 .22422 .53908 .21 Mtetra
.761 .69 .783 r
.53908 .21 .54655 .22422 .56041 .21197 .55299 .19807 Mtetra
.754 .692 .792 r
.55299 .19807 .56041 .21197 .57429 .20047 .56692 .18689 Mtetra
.748 .695 .801 r
.56692 .18689 .57429 .20047 .5882 .18957 .58088 .17631 Mtetra
.743 .699 .81 r
.58088 .17631 .5882 .18957 .60214 .17919 .59486 .16625 Mtetra
.739 .704 .818 r
.59486 .16625 .60214 .17919 .61611 .16922 .60889 .1566 Mtetra
.736 .708 .825 r
.60889 .1566 .61611 .16922 .63012 .15961 .62296 .14729 Mtetra
.733 .714 .833 r
.62296 .14729 .63012 .15961 .64418 .15027 .63707 .13826 Mtetra
.732 .72 .84 r
.63707 .13826 .64418 .15027 .65827 .14116 .65122 .12944 Mtetra
.73 .726 .846 r
.65122 .12944 .65827 .14116 .67241 .13224 .66543 .1208 Mtetra
.73 .732 .853 r
.66543 .1208 .67241 .13224 .6866 .12345 .67968 .11229 Mtetra
.73 .739 .859 r
.67968 .11229 .6866 .12345 .70083 .11476 .69399 .10387 Mtetra
.73 .746 .865 r
.69399 .10387 .70083 .11476 .71511 .10614 .70834 .09551 Mtetra
.731 .753 .87 r
.70834 .09551 .71511 .10614 .72944 .09755 .72274 .08719 Mtetra
.733 .761 .876 r
.72274 .08719 .72944 .09755 .74381 .08896 .73719 .07886 Mtetra
.567 .712 .94 r
.08971 .31003 .09834 .31807 .10959 .31646 .10102 .30806 Mtetra
.568 .703 .933 r
.10102 .30806 .10959 .31646 .1209 .31486 .1124 .30609 Mtetra
.568 .694 .926 r
.1124 .30609 .1209 .31486 .13228 .31331 .12384 .30416 Mtetra
.566 .685 .92 r
.12384 .30416 .13228 .31331 .14372 .31183 .13534 .3023 Mtetra
.563 .674 .914 r
.13534 .3023 .14372 .31183 .15522 .31046 .1469 .30054 Mtetra
.559 .664 .907 r
.1469 .30054 .15522 .31046 .16678 .30923 .15852 .2989 Mtetra
.552 .652 .901 r
.15852 .2989 .16678 .30923 .1784 .30819 .17019 .29744 Mtetra
.545 .64 .895 r
.17019 .29744 .1784 .30819 .19007 .30737 .18192 .29619 Mtetra
.536 .627 .889 r
.18192 .29619 .19007 .30737 .20179 .30684 .1937 .29521 Mtetra
.524 .612 .883 r
.1937 .29521 .20179 .30684 .21356 .30667 .20552 .29456 Mtetra
.51 .597 .877 r
.20552 .29456 .21356 .30667 .22539 .3069 .21739 .2943 Mtetra
.491 .578 .87 r
.21739 .2943 .22539 .3069 .23725 .30767 .22931 .29456 Mtetra
.47 .558 .863 r
.22931 .29456 .23725 .30767 .24916 .30905 .24126 .2954 Mtetra
.442 .534 .856 r
.24126 .2954 .24916 .30905 .26111 .31119 .25325 .29699 Mtetra
.407 .505 .847 r
.25325 .29699 .26111 .31119 .27309 .31425 .26527 .29951 Mtetra
.364 .472 .837 r
.26527 .29951 .27309 .31425 .28512 .31839 .27732 .30312 Mtetra
.304 .429 .823 r
.27732 .30312 .28512 .31839 .29717 .32387 .28938 .30813 Mtetra
.231 .376 .804 r
.28938 .30813 .29717 .32387 .30926 .33092 .30147 .31479 Mtetra
.131 .307 .775 r
.30147 .31479 .30926 .33092 .32139 .33981 .31358 .32348 Mtetra
0 .214 .728 r
.31358 .32348 .32139 .33981 .33355 .35092 .3257 .33471 Mtetra
0 .097 .653 r
.3257 .33471 .33355 .35092 .34577 .3645 .33784 .34882 Mtetra
0 0 .551 r
.33784 .34882 .34577 .3645 .35808 .38045 .35005 .36585 Mtetra
.775 .378 0 r
.35005 .36585 .35808 .38045 .37016 .40624 .36192 .39436 Mtetra
.718 .281 0 r
.36192 .39436 .37016 .40624 .3828 .42643 .37441 .41704 Mtetra
.647 .742 .919 r
.37441 .41704 .3828 .42643 .39671 .42178 .38836 .41235 Mtetra
.916 .768 .682 r
.38836 .41235 .39671 .42178 .41157 .39221 .40342 .38018 Mtetra
.913 .739 .652 r
.40342 .38018 .41157 .39221 .42646 .35689 .41852 .34204 Mtetra
.862 .711 .693 r
.41852 .34204 .42646 .35689 .4409 .33137 .43306 .31532 Mtetra
.84 .695 .701 r
.43306 .31532 .4409 .33137 .45517 .30816 .44742 .29147 Mtetra
.82 .682 .712 r
.44742 .29147 .45517 .30816 .46932 .28737 .46162 .27047 Mtetra
.802 .674 .723 r
.46162 .27047 .46932 .28737 .48336 .26877 .4757 .25197 Mtetra
.787 .669 .734 r
.4757 .25197 .48336 .26877 .49734 .25199 .48971 .23548 Mtetra
.774 .667 .745 r
.48971 .23548 .49734 .25199 .51127 .23675 .50368 .22061 Mtetra
.763 .667 .756 r
.50368 .22061 .51127 .23675 .52518 .22284 .51763 .20715 Mtetra
.755 .669 .767 r
.51763 .20715 .52518 .22284 .53908 .21 .53157 .19477 Mtetra
.747 .672 .777 r
.53157 .19477 .53908 .21 .55299 .19807 .54552 .18329 Mtetra
.741 .676 .788 r
.54552 .18329 .55299 .19807 .56692 .18689 .55949 .17256 Mtetra
.736 .681 .797 r
.55949 .17256 .56692 .18689 .58088 .17631 .57349 .16241 Mtetra
.731 .686 .807 r
.57349 .16241 .58088 .17631 .59486 .16625 .58753 .15277 Mtetra
.728 .692 .815 r
.58753 .15277 .59486 .16625 .60889 .1566 .6016 .14351 Mtetra
.726 .698 .824 r
.6016 .14351 .60889 .1566 .62296 .14729 .61572 .13457 Mtetra
.724 .705 .832 r
.61572 .13457 .62296 .14729 .63707 .13826 .62989 .12589 Mtetra
.723 .711 .839 r
.62989 .12589 .63707 .13826 .65122 .12944 .64411 .11742 Mtetra
.722 .719 .847 r
.64411 .11742 .65122 .12944 .66543 .1208 .65838 .1091 Mtetra
.721 .726 .854 r
.65838 .1091 .66543 .1208 .67968 .11229 .6727 .1009 Mtetra
.722 .733 .86 r
.6727 .1009 .67968 .11229 .69399 .10387 .68707 .09279 Mtetra
.722 .741 .867 r
.68707 .09279 .69399 .10387 .70834 .09551 .7015 .08474 Mtetra
.723 .749 .873 r
.7015 .08474 .70834 .09551 .72274 .08719 .71598 .0767 Mtetra
.725 .758 .879 r
.71598 .0767 .72274 .08719 .73719 .07886 .73051 .06866 Mtetra
.584 .718 .936 r
.081 .30192 .08971 .31003 .10102 .30806 .09238 .29956 Mtetra
.585 .709 .928 r
.09238 .29956 .10102 .30806 .1124 .30609 .10383 .2972 Mtetra
.584 .699 .921 r
.10383 .2972 .1124 .30609 .12384 .30416 .11534 .29486 Mtetra
.583 .689 .914 r
.11534 .29486 .12384 .30416 .13534 .3023 .12691 .29259 Mtetra
.58 .678 .908 r
.12691 .29259 .13534 .3023 .1469 .30054 .13853 .2904 Mtetra
.576 .667 .901 r
.13853 .2904 .1469 .30054 .15852 .2989 .15022 .28832 Mtetra
.57 .656 .894 r
.15022 .28832 .15852 .2989 .17019 .29744 .16195 .2864 Mtetra
.564 .643 .887 r
.16195 .2864 .17019 .29744 .18192 .29619 .17374 .28466 Mtetra
.556 .63 .88 r
.17374 .28466 .18192 .29619 .1937 .29521 .18558 .28316 Mtetra
.545 .615 .874 r
.18558 .28316 .1937 .29521 .20552 .29456 .19747 .28197 Mtetra
.533 .6 .866 r
.19747 .28197 .20552 .29456 .21739 .2943 .2094 .28113 Mtetra
.517 .581 .859 r
.2094 .28113 .21739 .2943 .22931 .29456 .22137 .28077 Mtetra
.499 .562 .851 r
.22137 .28077 .22931 .29456 .24126 .2954 .23339 .28094 Mtetra
.475 .538 .842 r
.23339 .28094 .24126 .2954 .25325 .29699 .24543 .28184 Mtetra
.445 .511 .832 r
.24543 .28184 .25325 .29699 .26527 .29951 .25749 .28362 Mtetra
.409 .48 .821 r
.25749 .28362 .26527 .29951 .27732 .30312 .26959 .28646 Mtetra
.358 .439 .808 r
.26959 .28646 .27732 .30312 .28938 .30813 .28169 .29074 Mtetra
.297 .392 .791 r
.28169 .29074 .28938 .30813 .30147 .31479 .2938 .29665 Mtetra
.21 .327 .766 r
.2938 .29665 .30147 .31479 .31358 .32348 .3059 .30477 Mtetra
.089 .241 .727 r
.3059 .30477 .31358 .32348 .3257 .33471 .318 .31567 Mtetra
0 .13 .666 r
.318 .31567 .3257 .33471 .33784 .34882 .33007 .3299 Mtetra
0 0 .57 r
.33007 .3299 .33784 .34882 .35005 .36585 .34216 .34795 Mtetra
.769 .406 0 r
.34216 .34795 .35005 .36585 .36192 .39436 .35372 .38048 Mtetra
.752 .342 0 r
.35372 .38048 .36192 .39436 .37441 .41704 .36596 .40708 Mtetra
.647 .73 .91 r
.36596 .40708 .37441 .41704 .38836 .41235 .37995 .40234 Mtetra
.921 .759 .664 r
.37995 .40234 .38836 .41235 .40342 .38018 .39529 .36615 Mtetra
.91 .723 .637 r
.39529 .36615 .40342 .38018 .41852 .34204 .41065 .32386 Mtetra
.844 .679 .678 r
.41065 .32386 .41852 .34204 .43306 .31532 .42529 .29601 Mtetra
.819 .662 .688 r
.42529 .29601 .43306 .31532 .44742 .29147 .4397 .27194 Mtetra
.798 .651 .7 r
.4397 .27194 .44742 .29147 .46162 .27047 .45393 .25116 Mtetra
.781 .645 .712 r
.45393 .25116 .46162 .27047 .4757 .25197 .46805 .23313 Mtetra
.766 .642 .725 r
.46805 .23313 .4757 .25197 .48971 .23548 .48208 .21729 Mtetra
.756 .643 .737 r
.48208 .21729 .48971 .23548 .50368 .22061 .49607 .20307 Mtetra
.745 .645 .749 r
.49607 .20307 .50368 .22061 .51763 .20715 .51004 .19029 Mtetra
.738 .649 .761 r
.51004 .19029 .51763 .20715 .53157 .19477 .52401 .17855 Mtetra
.732 .654 .773 r
.52401 .17855 .53157 .19477 .54552 .18329 .538 .16769 Mtetra
.726 .66 .784 r
.538 .16769 .54552 .18329 .55949 .17256 .55201 .15754 Mtetra
.723 .667 .794 r
.55201 .15754 .55949 .17256 .57349 .16241 .56605 .14792 Mtetra
.719 .673 .805 r
.56605 .14792 .57349 .16241 .58753 .15277 .58013 .13878 Mtetra
.717 .681 .814 r
.58013 .13878 .58753 .15277 .6016 .14351 .59426 .12998 Mtetra
.715 .688 .823 r
.59426 .12998 .6016 .14351 .61572 .13457 .60843 .12148 Mtetra
.713 .696 .832 r
.60843 .12148 .61572 .13457 .62989 .12589 .62266 .11321 Mtetra
.713 .703 .84 r
.62266 .11321 .62989 .12589 .64411 .11742 .63693 .10511 Mtetra
.712 .711 .848 r
.63693 .10511 .64411 .11742 .65838 .1091 .65127 .09717 Mtetra
.712 .719 .855 r
.65127 .09717 .65838 .1091 .6727 .1009 .66565 .08931 Mtetra
.713 .728 .862 r
.66565 .08931 .6727 .1009 .68707 .09279 .6801 .08154 Mtetra
.713 .736 .869 r
.6801 .08154 .68707 .09279 .7015 .08474 .6946 .07381 Mtetra
.715 .745 .876 r
.6946 .07381 .7015 .08474 .71598 .0767 .70915 .06609 Mtetra
.716 .754 .882 r
.70915 .06609 .71598 .0767 .73051 .06866 .72376 .05837 Mtetra
.601 .724 .931 r
.07222 .29375 .081 .30192 .09238 .29956 .08368 .29097 Mtetra
.601 .714 .923 r
.08368 .29097 .09238 .29956 .10383 .2972 .0952 .28818 Mtetra
.601 .703 .916 r
.0952 .28818 .10383 .2972 .11534 .29486 .10678 .28542 Mtetra
.599 .693 .908 r
.10678 .28542 .11534 .29486 .12691 .29259 .11842 .2827 Mtetra
.596 .682 .901 r
.11842 .2827 .12691 .29259 .13853 .2904 .13012 .28005 Mtetra
.593 .671 .894 r
.13012 .28005 .13853 .2904 .15022 .28832 .14188 .27749 Mtetra
.588 .659 .886 r
.14188 .27749 .15022 .28832 .16195 .2864 .15368 .27506 Mtetra
.583 .646 .879 r
.15368 .27506 .16195 .2864 .17374 .28466 .16555 .27278 Mtetra
.576 .633 .871 r
.16555 .27278 .17374 .28466 .18558 .28316 .17746 .27071 Mtetra
.567 .618 .863 r
.17746 .27071 .18558 .28316 .19747 .28197 .18941 .26889 Mtetra
.557 .603 .855 r
.18941 .26889 .19747 .28197 .2094 .28113 .20142 .26737 Mtetra
.543 .585 .846 r
.20142 .26737 .2094 .28113 .22137 .28077 .21346 .26628 Mtetra
.529 .566 .837 r
.21346 .26628 .22137 .28077 .23339 .28094 .22554 .26565 Mtetra
.509 .543 .827 r
.22554 .26565 .23339 .28094 .24543 .28184 .23766 .26567 Mtetra
.485 .518 .816 r
.23766 .26567 .24543 .28184 .25749 .28362 .24979 .26648 Mtetra
.456 .489 .804 r
.24979 .26648 .25749 .28362 .26959 .28646 .26195 .26827 Mtetra
.413 .45 .79 r
.26195 .26827 .26959 .28646 .28169 .29074 .27411 .27147 Mtetra
.368 .411 .774 r
.27411 .27147 .28169 .29074 .2938 .29665 .28627 .27619 Mtetra
.292 .35 .751 r
.28627 .27619 .2938 .29665 .3059 .30477 .2984 .28332 Mtetra
.191 .274 .721 r
.2984 .28332 .3059 .30477 .318 .31567 .31049 .29337 Mtetra
.043 .167 .669 r
.31049 .29337 .318 .31567 .33007 .3299 .32251 .30734 Mtetra
0 0 .553 r
.32251 .30734 .33007 .3299 .34216 .34795 .33439 .32747 Mtetra
.853 .508 0 r
.33439 .32747 .34216 .34795 .35372 .38048 .34524 .37061 Mtetra
.904 .499 .105 r
.34524 .37061 .35372 .38048 .36596 .40708 .35688 .40778 Mtetra
.393 .852 .853 r
.35688 .40778 .36596 .40708 .37995 .40234 .37095 .403 Mtetra
.984 .831 .612 r
.37095 .403 .37995 .40234 .39529 .36615 .38693 .35614 Mtetra
.943 .746 .608 r
.38693 .35614 .39529 .36615 .41065 .32386 .40285 .3031 Mtetra
.837 .661 .663 r
.40285 .3031 .41065 .32386 .42529 .29601 .41762 .27305 Mtetra
.795 .629 .675 r
.41762 .27305 .42529 .29601 .4397 .27194 .43206 .24911 Mtetra
.772 .618 .688 r
.43206 .24911 .4397 .27194 .45393 .25116 .4463 .22907 Mtetra
.755 .614 .701 r
.4463 .22907 .45393 .25116 .46805 .23313 .46041 .21193 Mtetra
.74 .612 .715 r
.46041 .21193 .46805 .23313 .48208 .21729 .47445 .1972 Mtetra
.733 .616 .729 r
.47445 .1972 .48208 .21729 .49607 .20307 .48845 .18396 Mtetra
.724 .62 .742 r
.48845 .18396 .49607 .20307 .51004 .19029 .50243 .17214 Mtetra
.718 .627 .755 r
.50243 .17214 .51004 .19029 .52401 .17855 .51642 .16128 Mtetra
.714 .635 .768 r
.51642 .16128 .52401 .17855 .538 .16769 .53044 .15122 Mtetra
.71 .643 .78 r
.53044 .15122 .538 .16769 .55201 .15754 .54448 .14179 Mtetra
.707 .651 .792 r
.54448 .14179 .55201 .15754 .56605 .14792 .55856 .13283 Mtetra
.705 .66 .803 r
.55856 .13283 .56605 .14792 .58013 .13878 .57268 .12428 Mtetra
.704 .669 .813 r
.57268 .12428 .58013 .13878 .59426 .12998 .58685 .11602 Mtetra
.703 .677 .823 r
.58685 .11602 .59426 .12998 .60843 .12148 .60108 .10801 Mtetra
.702 .686 .832 r
.60108 .10801 .60843 .12148 .62266 .11321 .61536 .1002 Mtetra
.702 .695 .84 r
.61536 .1002 .62266 .11321 .63693 .10511 .62969 .09254 Mtetra
.702 .704 .849 r
.62969 .09254 .63693 .10511 .65127 .09717 .64409 .08499 Mtetra
.702 .713 .857 r
.64409 .08499 .65127 .09717 .66565 .08931 .65854 .07752 Mtetra
.703 .722 .864 r
.65854 .07752 .66565 .08931 .6801 .08154 .67306 .07011 Mtetra
.704 .731 .871 r
.67306 .07011 .6801 .08154 .6946 .07381 .68763 .06273 Mtetra
.705 .74 .879 r
.68763 .06273 .6946 .07381 .70915 .06609 .70226 .05536 Mtetra
.707 .75 .885 r
.70226 .05536 .70915 .06609 .72376 .05837 .71695 .04798 Mtetra
.617 .729 .926 r
.06337 .2855 .07222 .29375 .08368 .29097 .07491 .28228 Mtetra
.618 .718 .918 r
.07491 .28228 .08368 .29097 .0952 .28818 .08651 .27906 Mtetra
.617 .708 .91 r
.08651 .27906 .0952 .28818 .10678 .28542 .09817 .27584 Mtetra
.615 .697 .902 r
.09817 .27584 .10678 .28542 .11842 .2827 .10989 .27266 Mtetra
.613 .686 .895 r
.10989 .27266 .11842 .2827 .13012 .28005 .12166 .26952 Mtetra
.61 .675 .887 r
.12166 .26952 .13012 .28005 .14188 .27749 .13349 .26645 Mtetra
.606 .663 .879 r
.13349 .26645 .14188 .27749 .15368 .27506 .14538 .26348 Mtetra
.601 .65 .871 r
.14538 .26348 .15368 .27506 .16555 .27278 .15732 .26062 Mtetra
.595 .637 .863 r
.15732 .26062 .16555 .27278 .17746 .27071 .16931 .25791 Mtetra
.588 .623 .854 r
.16931 .25791 .17746 .27071 .18941 .26889 .18135 .25541 Mtetra
.58 .608 .845 r
.18135 .25541 .18941 .26889 .20142 .26737 .19343 .25314 Mtetra
.569 .591 .835 r
.19343 .25314 .20142 .26737 .21346 .26628 .20556 .25122 Mtetra
.557 .572 .825 r
.20556 .25122 .21346 .26628 .22554 .26565 .21773 .24966 Mtetra
.541 .551 .814 r
.21773 .24966 .22554 .26565 .23766 .26567 .22993 .24864 Mtetra
.522 .527 .802 r
.22993 .24864 .23766 .26567 .24979 .26648 .24216 .24829 Mtetra
.5 .501 .789 r
.24216 .24829 .24979 .26648 .26195 .26827 .25441 .24876 Mtetra
.466 .466 .774 r
.25441 .24876 .26195 .26827 .27411 .27147 .26665 .25053 Mtetra
.434 .433 .758 r
.26665 .25053 .27411 .27147 .28627 .27619 .27891 .25358 Mtetra
.37 .377 .737 r
.27891 .25358 .28627 .27619 .2984 .28332 .2911 .25907 Mtetra
.296 .316 .712 r
.2911 .25907 .2984 .28332 .31049 .29337 .30325 .26737 Mtetra
.178 .224 .672 r
.30325 .26737 .31049 .29337 .32251 .30734 .31528 .27987 Mtetra
0 .031 .572 r
.31528 .27987 .32251 .30734 .33439 .32747 .32701 .3004 Mtetra
.825 .523 0 r
.32701 .3004 .33439 .32747 .34524 .37061 .33726 .35093 Mtetra
.872 .52 .022 r
.33726 .35093 .34524 .37061 .35688 .40778 .34834 .39591 Mtetra
.643 .692 .881 r
.34834 .39591 .35688 .40778 .37095 .403 .36245 .39109 Mtetra
.935 .734 .607 r
.36245 .39109 .37095 .403 .38693 .35614 .37894 .33628 Mtetra
.909 .69 .595 r
.37894 .33628 .38693 .35614 .40285 .3031 .39531 .2757 Mtetra
.803 .614 .646 r
.39531 .2757 .40285 .3031 .41762 .27305 .41013 .24513 Mtetra
.76 .587 .662 r
.41013 .24513 .41762 .27305 .43206 .24911 .42454 .22255 Mtetra
.74 .581 .677 r
.42454 .22255 .43206 .24911 .4463 .22907 .43874 .20416 Mtetra
.726 .581 .692 r
.43874 .20416 .4463 .22907 .46041 .21193 .45282 .18857 Mtetra
.712 .582 .708 r
.45282 .18857 .46041 .21193 .47445 .1972 .46683 .17541 Mtetra
.708 .591 .723 r
.46683 .17541 .47445 .1972 .48845 .18396 .48082 .16352 Mtetra
.7 .597 .738 r
.48082 .16352 .48845 .18396 .50243 .17214 .49481 .15293 Mtetra
.697 .607 .752 r
.49481 .15293 .50243 .17214 .51642 .16128 .50881 .14315 Mtetra
.694 .617 .766 r
.50881 .14315 .51642 .16128 .53044 .15122 .52284 .13403 Mtetra
.692 .627 .779 r
.52284 .13403 .53044 .15122 .54448 .14179 .53691 .12545 Mtetra
.691 .637 .791 r
.53691 .12545 .54448 .14179 .55856 .13283 .55102 .11723 Mtetra
.69 .647 .802 r
.55102 .11723 .55856 .13283 .57268 .12428 .56518 .10935 Mtetra
.69 .657 .813 r
.56518 .10935 .57268 .12428 .58685 .11602 .5794 .1017 Mtetra
.69 .667 .823 r
.5794 .1017 .58685 .11602 .60108 .10801 .59367 .09423 Mtetra
.69 .677 .833 r
.59367 .09423 .60108 .10801 .61536 .1002 .608 .08692 Mtetra
.69 .687 .842 r
.608 .08692 .61536 .1002 .62969 .09254 .62239 .07972 Mtetra
.691 .696 .85 r
.62239 .07972 .62969 .09254 .64409 .08499 .63685 .0726 Mtetra
.692 .706 .859 r
.63685 .0726 .64409 .08499 .65854 .07752 .65137 .06554 Mtetra
.693 .716 .867 r
.65137 .06554 .65854 .07752 .67306 .07011 .66595 .05851 Mtetra
.694 .725 .874 r
.66595 .05851 .67306 .07011 .68763 .06273 .68059 .05151 Mtetra
.695 .735 .882 r
.68059 .05151 .68763 .06273 .70226 .05536 .6953 .04451 Mtetra
.697 .745 .889 r
.6953 .04451 .70226 .05536 .71695 .04798 .71008 .03748 Mtetra
.634 .733 .92 r
.05443 .27718 .06337 .2855 .07491 .28228 .06606 .27351 Mtetra
.633 .723 .912 r
.06606 .27351 .07491 .28228 .08651 .27906 .07775 .26983 Mtetra
.632 .712 .904 r
.07775 .26983 .08651 .27906 .09817 .27584 .08949 .26614 Mtetra
.631 .701 .896 r
.08949 .26614 .09817 .27584 .10989 .27266 .10129 .26247 Mtetra
.629 .69 .888 r
.10129 .26247 .10989 .27266 .12166 .26952 .11315 .25883 Mtetra
.626 .679 .88 r
.11315 .25883 .12166 .26952 .13349 .26645 .12507 .25522 Mtetra
.623 .667 .872 r
.12507 .25522 .13349 .26645 .14538 .26348 .13704 .25168 Mtetra
.619 .655 .863 r
.13704 .25168 .14538 .26348 .15732 .26062 .14906 .2482 Mtetra
.614 .642 .854 r
.14906 .2482 .15732 .26062 .16931 .25791 .16114 .24483 Mtetra
.608 .628 .845 r
.16114 .24483 .16931 .25791 .18135 .25541 .17327 .24159 Mtetra
.602 .613 .835 r
.17327 .24159 .18135 .25541 .19343 .25314 .18544 .23852 Mtetra
.593 .597 .825 r
.18544 .23852 .19343 .25314 .20556 .25122 .19767 .23567 Mtetra
.585 .58 .814 r
.19767 .23567 .20556 .25122 .21773 .24966 .20993 .23309 Mtetra
.572 .56 .802 r
.20993 .23309 .21773 .24966 .22993 .24864 .22224 .23089 Mtetra
.558 .539 .789 r
.22224 .23089 .22993 .24864 .24216 .24829 .23458 .22919 Mtetra
.542 .515 .775 r
.23458 .22919 .24216 .24829 .25441 .24876 .24695 .22809 Mtetra
.516 .484 .76 r
.24695 .22809 .25441 .24876 .26665 .25053 .25932 .22804 Mtetra
.495 .456 .742 r
.25932 .22804 .26665 .25053 .27891 .25358 .27171 .22893 Mtetra
.449 .41 .723 r
.27171 .22893 .27891 .25358 .2911 .25907 .28404 .23194 Mtetra
.401 .362 .7 r
.28404 .23194 .2911 .25907 .30325 .26737 .29632 .2373 Mtetra
.324 .294 .67 r
.29632 .2373 .30325 .26737 .31528 .27987 .30849 .24646 Mtetra
.137 .148 .607 r
.30849 .24646 .31528 .27987 .32701 .3004 .32029 .26386 Mtetra
0 0 .201 r
.32029 .26386 .32701 .3004 .33726 .35093 .33044 .31197 Mtetra
0 0 .315 r
.33044 .31197 .33726 .35093 .34834 .39591 .34139 .35539 Mtetra
.573 .428 .646 r
.34139 .35539 .34834 .39591 .36245 .39109 .35541 .35048 Mtetra
.82 .595 .597 r
.35541 .35048 .36245 .39109 .37894 .33628 .37188 .29709 Mtetra
.836 .606 .591 r
.37188 .29709 .37894 .33628 .39531 .2757 .38821 .2388 Mtetra
.747 .551 .63 r
.38821 .2388 .39531 .2757 .41013 .24513 .40291 .21124 Mtetra
.712 .536 .649 r
.40291 .21124 .41013 .24513 .42454 .22255 .41718 .1919 Mtetra
.698 .538 .667 r
.41718 .1919 .42454 .22255 .43874 .20416 .43127 .17635 Mtetra
.69 .545 .684 r
.43127 .17635 .43874 .20416 .45282 .18857 .44528 .16314 Mtetra
.68 .551 .702 r
.44528 .16314 .45282 .18857 .46683 .17541 .45924 .15205 Mtetra
.679 .564 .718 r
.45924 .15205 .46683 .17541 .48082 .16352 .4732 .14189 Mtetra
.675 .574 .735 r
.4732 .14189 .48082 .16352 .49481 .15293 .48717 .13278 Mtetra
.674 .587 .75 r
.48717 .13278 .49481 .15293 .50881 .14315 .50117 .12427 Mtetra
.673 .599 .764 r
.50117 .12427 .50881 .14315 .52284 .13403 .51521 .11625 Mtetra
.673 .611 .778 r
.51521 .11625 .52284 .13403 .53691 .12545 .52929 .10861 Mtetra
.674 .624 .791 r
.52929 .10861 .53691 .12545 .55102 .11723 .54343 .10122 Mtetra
.674 .635 .803 r
.54343 .10122 .55102 .11723 .56518 .10935 .55763 .09407 Mtetra
.675 .647 .814 r
.55763 .09407 .56518 .10935 .5794 .1017 .57189 .08706 Mtetra
.676 .658 .825 r
.57189 .08706 .5794 .1017 .59367 .09423 .5862 .08019 Mtetra
.677 .669 .834 r
.5862 .08019 .59367 .09423 .608 .08692 .60059 .07341 Mtetra
.678 .679 .844 r
.60059 .07341 .608 .08692 .62239 .07972 .61503 .06669 Mtetra
.679 .689 .853 r
.61503 .06669 .62239 .07972 .63685 .0726 .62955 .06003 Mtetra
.68 .7 .861 r
.62955 .06003 .63685 .0726 .65137 .06554 .64413 .05339 Mtetra
.682 .71 .869 r
.64413 .05339 .65137 .06554 .66595 .05851 .65878 .04677 Mtetra
.683 .72 .877 r
.65878 .04677 .66595 .05851 .68059 .05151 .67349 .04016 Mtetra
.684 .73 .885 r
.67349 .04016 .68059 .05151 .6953 .04451 .68828 .03354 Mtetra
.686 .741 .893 r
.68828 .03354 .6953 .04451 .71008 .03748 .70314 .02689 Mtetra
.649 .738 .914 r
.04542 .2688 .05443 .27718 .06606 .27351 .05714 .26466 Mtetra
.648 .727 .906 r
.05714 .26466 .06606 .27351 .07775 .26983 .06892 .2605 Mtetra
.647 .716 .898 r
.06892 .2605 .07775 .26983 .08949 .26614 .08075 .25633 Mtetra
.646 .705 .89 r
.08075 .25633 .08949 .26614 .10129 .26247 .09264 .25216 Mtetra
.644 .694 .882 r
.09264 .25216 .10129 .26247 .11315 .25883 .10459 .248 Mtetra
.642 .683 .873 r
.10459 .248 .11315 .25883 .12507 .25522 .11659 .24384 Mtetra
.639 .671 .865 r
.11659 .24384 .12507 .25522 .13704 .25168 .12865 .2397 Mtetra
.636 .659 .856 r
.12865 .2397 .13704 .25168 .14906 .2482 .14077 .23558 Mtetra
.632 .647 .847 r
.14077 .23558 .14906 .2482 .16114 .24483 .15294 .23151 Mtetra
.628 .634 .837 r
.15294 .23151 .16114 .24483 .17327 .24159 .16516 .2275 Mtetra
.623 .62 .827 r
.16516 .2275 .17327 .24159 .18544 .23852 .17744 .22356 Mtetra
.617 .604 .816 r
.17744 .22356 .18544 .23852 .19767 .23567 .18977 .21974 Mtetra
.61 .588 .803 r
.18977 .21974 .19767 .23567 .20993 .23309 .20215 .21604 Mtetra
.602 .57 .791 r
.20215 .21604 .20993 .23309 .22224 .23089 .21458 .21254 Mtetra
.593 .551 .777 r
.21458 .21254 .22224 .23089 .23458 .22919 .22706 .2093 Mtetra
.582 .529 .761 r
.22706 .2093 .23458 .22919 .24695 .22809 .23957 .20639 Mtetra
.565 .504 .745 r
.23957 .20639 .24695 .22809 .25932 .22804 .25211 .2041 Mtetra
.552 .479 .726 r
.25211 .2041 .25932 .22804 .27171 .22893 .26469 .20231 Mtetra
.524 .444 .707 r
.26469 .20231 .27171 .22893 .28404 .23194 .27724 .20186 Mtetra
.499 .409 .684 r
.27724 .20186 .28404 .23194 .29632 .2373 .28978 .20284 Mtetra
.461 .364 .659 r
.28978 .20284 .29632 .2373 .30849 .24646 .30225 .20628 Mtetra
.376 .286 .625 r
.30225 .20628 .30849 .24646 .32029 .26386 .31446 .21552 Mtetra
.017 .009 .502 r
.31446 .21552 .32029 .26386 .33044 .31197 .32546 .24622 Mtetra
.228 .13 .53 r
.32546 .24622 .33044 .31197 .34139 .35539 .33703 .2737 Mtetra
.539 .347 .568 r
.33703 .2737 .34139 .35539 .35541 .35048 .35078 .26867 Mtetra
.679 .453 .572 r
.35078 .26867 .35541 .35048 .37188 .29709 .36629 .23103 Mtetra
.718 .492 .582 r
.36629 .23103 .37188 .29709 .38821 .2388 .38175 .19005 Mtetra
.666 .472 .613 r
.38175 .19005 .38821 .2388 .40291 .21124 .39603 .17054 Mtetra
.648 .475 .635 r
.39603 .17054 .40291 .21124 .41718 .1919 .41003 .15682 Mtetra
.644 .487 .656 r
.41003 .15682 .41718 .1919 .43127 .17635 .42393 .14556 Mtetra
.644 .503 .676 r
.42393 .14556 .43127 .17635 .44528 .16314 .43781 .13572 Mtetra
.641 .517 .696 r
.43781 .13572 .44528 .16314 .45924 .15205 .45168 .12722 Mtetra
.645 .535 .714 r
.45168 .12722 .45924 .15205 .4732 .14189 .46558 .11922 Mtetra
.645 .55 .732 r
.46558 .11922 .4732 .14189 .48717 .13278 .47952 .11183 Mtetra
.648 .566 .749 r
.47952 .11183 .48717 .13278 .50117 .12427 .49351 .10477 Mtetra
.65 .581 .764 r
.49351 .10477 .50117 .12427 .51521 .11625 .50755 .09796 Mtetra
.653 .596 .779 r
.50755 .09796 .51521 .11625 .52929 .10861 .52165 .09135 Mtetra
.655 .61 .792 r
.52165 .09135 .52929 .10861 .54343 .10122 .53581 .08486 Mtetra
.657 .624 .804 r
.53581 .08486 .54343 .10122 .55763 .09407 .55003 .07848 Mtetra
.659 .636 .816 r
.55003 .07848 .55763 .09407 .57189 .08706 .56432 .07217 Mtetra
.661 .648 .827 r
.56432 .07217 .57189 .08706 .5862 .08019 .57868 .06591 Mtetra
.663 .66 .837 r
.57868 .06591 .5862 .08019 .60059 .07341 .59311 .05969 Mtetra
.665 .672 .846 r
.59311 .05969 .60059 .07341 .61503 .06669 .60761 .05348 Mtetra
.667 .682 .855 r
.60761 .05348 .61503 .06669 .62955 .06003 .62218 .04729 Mtetra
.669 .693 .864 r
.62218 .04729 .62955 .06003 .64413 .05339 .63683 .04109 Mtetra
.67 .704 .872 r
.63683 .04109 .64413 .05339 .65878 .04677 .65154 .03489 Mtetra
.672 .714 .88 r
.65154 .03489 .65878 .04677 .67349 .04016 .66633 .02868 Mtetra
.673 .725 .888 r
.66633 .02868 .67349 .04016 .68828 .03354 .68119 .02245 Mtetra
.675 .736 .896 r
.68119 .02245 .68828 .03354 .70314 .02689 .69613 .01619 Mtetra
.664 .741 .908 r
.03634 .26033 .04542 .2688 .05714 .26466 .04815 .25572 Mtetra
.662 .73 .9 r
.04815 .25572 .05714 .26466 .06892 .2605 .06002 .25108 Mtetra
.661 .719 .892 r
.06002 .25108 .06892 .2605 .08075 .25633 .07194 .24643 Mtetra
.66 .709 .884 r
.07194 .24643 .08075 .25633 .09264 .25216 .08393 .24175 Mtetra
.658 .698 .876 r
.08393 .24175 .09264 .25216 .10459 .248 .09597 .23704 Mtetra
.656 .687 .867 r
.09597 .23704 .10459 .248 .11659 .24384 .10806 .23232 Mtetra
.654 .676 .858 r
.10806 .23232 .11659 .24384 .12865 .2397 .12022 .22757 Mtetra
.652 .664 .849 r
.12022 .22757 .12865 .2397 .14077 .23558 .13243 .2228 Mtetra
.649 .652 .84 r
.13243 .2228 .14077 .23558 .15294 .23151 .1447 .21801 Mtetra
.646 .64 .829 r
.1447 .21801 .15294 .23151 .16516 .2275 .15703 .21319 Mtetra
.643 .626 .818 r
.15703 .21319 .16516 .2275 .17744 .22356 .16942 .20835 Mtetra
.639 .612 .807 r
.16942 .20835 .17744 .22356 .18977 .21974 .18187 .20349 Mtetra
.635 .597 .794 r
.18187 .20349 .18977 .21974 .20215 .21604 .19438 .1986 Mtetra
.63 .581 .78 r
.19438 .1986 .20215 .21604 .21458 .21254 .20695 .19369 Mtetra
.625 .563 .765 r
.20695 .19369 .21458 .21254 .22706 .2093 .21959 .18876 Mtetra
.619 .544 .749 r
.21959 .18876 .22706 .2093 .23957 .20639 .23228 .1838 Mtetra
.612 .524 .731 r
.23228 .1838 .23957 .20639 .25211 .2041 .24504 .17882 Mtetra
.604 .501 .71 r
.24504 .17882 .25211 .2041 .26469 .20231 .25786 .17381 Mtetra
.595 .478 .69 r
.25786 .17381 .26469 .20231 .27724 .20186 .27074 .16878 Mtetra
.585 .452 .666 r
.27074 .16878 .27724 .20186 .28978 .20284 .28368 .16372 Mtetra
.574 .425 .641 r
.28368 .16372 .28978 .20284 .30225 .20628 .29669 .15864 Mtetra
.562 .398 .616 r
.29669 .15864 .30225 .20628 .31446 .21552 .30977 .15353 Mtetra
.549 .368 .588 r
.30977 .15353 .31446 .21552 .32546 .24622 .32291 .1484 Mtetra
.532 .329 .551 r
.32291 .1484 .32546 .24622 .33703 .2737 .33611 .14324 Mtetra
.524 .312 .535 r
.33611 .14324 .33703 .2737 .35078 .26867 .34938 .13806 Mtetra
.34938 .13806 .35078 .26867 .36629 .23103 .36272 .13285 Mtetra
.532 .329 .551 r
.36272 .13285 .36629 .23103 .38175 .19005 .37612 .12761 Mtetra
.549 .368 .588 r
.37612 .12761 .38175 .19005 .39603 .17054 .3896 .12235 Mtetra
.562 .398 .616 r
.3896 .12235 .39603 .17054 .41003 .15682 .40314 .11706 Mtetra
.574 .425 .641 r
.40314 .11706 .41003 .15682 .42393 .14556 .41674 .11175 Mtetra
.585 .452 .666 r
.41674 .11175 .42393 .14556 .43781 .13572 .43042 .10641 Mtetra
.595 .478 .69 r
.43042 .10641 .43781 .13572 .45168 .12722 .44417 .10104 Mtetra
.604 .501 .71 r
.44417 .10104 .45168 .12722 .46558 .11922 .45799 .09564 Mtetra
.612 .524 .731 r
.45799 .09564 .46558 .11922 .47952 .11183 .47187 .09021 Mtetra
.619 .544 .748 r
.47187 .09021 .47952 .11183 .49351 .10477 .48583 .08476 Mtetra
.625 .563 .765 r
.48583 .08476 .49351 .10477 .50755 .09796 .49986 .07928 Mtetra
.63 .581 .78 r
.49986 .07928 .50755 .09796 .52165 .09135 .51397 .07377 Mtetra
.635 .597 .794 r
.51397 .07377 .52165 .09135 .53581 .08486 .52814 .06824 Mtetra
.639 .612 .807 r
.52814 .06824 .53581 .08486 .55003 .07848 .54239 .06267 Mtetra
.643 .626 .818 r
.54239 .06267 .55003 .07848 .56432 .07217 .55671 .05708 Mtetra
.646 .639 .829 r
.55671 .05708 .56432 .07217 .57868 .06591 .57111 .05145 Mtetra
.649 .652 .839 r
.57111 .05145 .57868 .06591 .59311 .05969 .58558 .0458 Mtetra
.652 .664 .849 r
.58558 .0458 .59311 .05969 .60761 .05348 .60013 .04012 Mtetra
.654 .676 .858 r
.60013 .04012 .60761 .05348 .62218 .04729 .61476 .0344 Mtetra
.656 .687 .867 r
.61476 .0344 .62218 .04729 .63683 .04109 .62946 .02866 Mtetra
.658 .698 .876 r
.62946 .02866 .63683 .04109 .65154 .03489 .64424 .02289 Mtetra
.66 .709 .884 r
.64424 .02289 .65154 .03489 .66633 .02868 .6591 .01709 Mtetra
.661 .719 .892 r
.6591 .01709 .66633 .02868 .68119 .02245 .67403 .01125 Mtetra
.662 .73 .9 r
.67403 .01125 .68119 .02245 .69613 .01619 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00n?ooool4o`000003oa0@4?oooooooooo06Wooooo003jooooo`03o`00
0?oooooooooo06_ooooo003jooooo`03o`000?oooooooooo06_ooooo003jooooo`03o`000?oooooo
oooo06_ooooo003jooooo`03o`000?oooooooooo06_ooooo003jooooo`03o`000?oooooooooo06_o
oooo003jooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Oooooo`00
n?ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Goooool00?oooooo
1Oooool01Ol@413ooooooooooooooooo410@05oooooo003oooooo`Gooooo00Go0000oooooooooooo
ooooo`00001Oooooo`00ooooool5ooooo`05o`000?ooooooooooooooool00000Goooool00?oooooo
1Oooool01Ol@413ooooooooooooooooo410@05oooooo003oooooo`Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1Oooooo`00o_ooool2o`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Oooooo`00
noooool3o`000003ooooool0003ooooo06Oooooo003iooooo`;o00001?ooool2o`0006Oooooo003f
ooooo`?o00001Oooool01?nY^^Ko0000ooooool0001Vooooo`00loooool3o`0000Gooooo1?nY^^H0
0ol0003oZK[Vo`00001Vooooo`00lOooool3o`0000Gooooo0_nY^>@4ojVjiP04o`000?nY^^KoZK[V
o`0006Gooooo002jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c00Oooooo`?o00000oooool00ol0003oooooooooo`05ojVhi0?oZK[V00Go
0000ojVji_n/_>Goooooo`00001Tooooo`00^_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B407Oooool2o`0000Kooooo0_nX]N87ojVhi003
ojVji_n/_>Go000000?o[;cU00?o0000ooooooooool0H_ooool00;[ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000006_ooool3o`0000Cooooo00?oZ;;PojRe
h_nX]N801?nX]N85ojVhi004ojbihon/_>Go[;cUo`0000?o[;cU00?oooooo`000?ooool0H_ooool0
0;[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S806?oo
ool2o`0000Cooooo1OnX/^06ojRehP03ojVhi?n/^N?o[;WS00?o[;WS0_n/_>D01?l0003o[;cUojbl
iOn/_>D2o`0006;ooooo002jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000
o`000?l0003oc<c<01Gooooo0ol000001Ooooooo0000ooooooooooooYjoM00KoZ;;P1OnX]N800on/
]^7o[;WSojbih`04ojbih`;o[;cU00Ko0000ojbliOn/_>Go[kgTooooool0001Rooooo`00^_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Booooo`?o0000
1?ooool5ojN_g@KoZ;;P00?oZ;GRojbfhOn/]^400on/]^46ojbih`03ojbliOl0003o[kgT00?o[kgT
00?oooooo`000?ooool0H?ooool00;[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooookZj^_l000004?ooool2o`0000Gooooo00?oYjgKojN_gOnW[md01?nW[md5ojRbh003
oj^dgon/]^7o[;KQ00Co[;KQ1On/^N<00on_^^;o[kgTo`000005ojnmi003ooooool0003ooooo05oo
oooo002jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00gooooo0ol00004ooooo`GoYjgK1_nW[md00onX/^3oZkCOoj^dg`03oj^dg`Ko[;KQ00?o[;WSojnj
h_n_^^800on_^^800ol0003o[kgTojnmi002ojnmi003ok:nhooooooo0000063ooooo003Jooooo`?o
00001?ooool00onVZMWoYjgKojN]f`04ojN]f`GoYjoM00?oZk7Moj^dgon[]=l01?n[]=l5ojbfh@03
ojjhh?n_^^;o[k[R00Co[k[R00?o0000ojnmi?n__N@01?nb_^<00ooooooo0000ooooo`1Nooooo`00
eoooool3o`0000?ooooo00?o0000oooooonVZMT00onVZMT6ojN]f`03ojN_gOn[/MgoZk7M00?oZk7M
1_n[]=l00on/]^7o[[SPojjhh003ojjhh0Go[k[R00?o0000ojnmi?nb_^<01?nb_^<2ooooo`03o`00
0?oooooooooo05cooooo003Eooooo`;o00001_ooool00onVY]KoYZWIojJYf@04ojJYf@CoYjgK00?o
ZZkJoj^agOn[/Md01On[/Md4oj^dg`03ojjeg_n^^>3o[[SP00Go[[SP1?n_^^800ol0003o/KcQok:n
h`05ok:nh`03ooooool0003ooooo05gooooo003Booooo`?o00001Oooool5ojJVePKoYZWI00?oYjgK
ojZ^f_nZ[]X00_nZ[]X7oj^ag@03oj^dgon^]Mko[[GN00;o[[GN1on^^>001?n_^^;o/KcQok6lhOl0
0002ok6lh@Co/[kS0_nd_n82o`0005gooooo003@ooooo`;o00001_ooool00onUXmCoYZKFojJVeP04
ojJVePGoYZWI00?oZZcHojZ^f_nZ[]X01?nZ[]X5oj^ag@03ojjcg?n^]Mko[[GN00Co[[GN1On^^>00
1Ona^Moo/KcQok6lhOna_>7o000000?o/KcQ00?o/[kSokBoh_nd_n800ond_n800ooooooo0000oooo
o`1Kooooo`00cOooool3o`000003ooooool0003ooooo00;ooooo1OnUXm@6ojJVeP03ojJYfOnZ[=So
ZZcH00?oZZcH1OnZ[]X3oj^ag@Co[[?L1_n^]Mh00on^^>3o/KWOok6ig`03ok6ig`;o/KcQ00Co0000
ok6lhOna_>7o];gQ1ond_n800ol0003oooooooooo`1Jooooo`00b_ooool3o`0000Gooooo00?o0000
ojBPdOnUXm@01OnUXm@5ojJVeP03ojVXe_nZ[=SoZZcH00CoZZcH1_nZ[]X00on[/Mgo[[?Lojjcg003
ojjcg0Go[[GN00?o/KOMok6igona^Ml01Ona^Ml00ona_>7o0000okBmh@03okBmh@Go];oR00?o]l7Q
ooooool00000Foooool00<Sooooo0_l00004ooooo`03oj>Lc_nTX=7oY:3A00CoY:3A1_nUXm@00onV
Y]KoZJSFojVXeP03ojVXePGoZZcH1OnZ[]X00on]/=[o[[?Lojjcg005ojjcg003ojjeg_na]mgo/KOM
00?o/KOM1Ona^Ml00ond^mko];gQo`000004okBmh@?o];oR1?ng`N400ol0003oooooooooo`1Ioooo
o`00aOooool3o`0000Cooooo1?nSW<h6ojBPd@CoYJ?D00?oZJGCojVXe_nYZ=H01?nYZ=H6ojZ/f003
ojZ^f_n]/=[o[K3J00?o[K3J1On^/m`00ona]=_o/KOMok6gg@04ok6gg@?o/KWO1?nd^mh00ol0003o
];gQokBmh@03okBmh@03okBoh_ng`N7o]l7Q00Co]l7Q00?o0000ooooooooool0F?ooool008cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
02;ooooo0ol00004ooooo`03oj:HbonSW<koXic>00?oXic>1_nTX=43ojFSe0?oZJGC1OnYZ=H5ojZ/
f003ojf]f?n]/=[o[K3J00Co[K3J0on^/m`4ok6df`Ko/KOM00?o/KWOokBkg_nd^mh00ond^mh00ol0
003o];gQokBmh@02okBmh@03okNnh?ng`N7o]l7Q00Co]l7Q00?o^L;Qooooool00000FOooool008co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q01oooooo0ol00003ooooo`03o`000?nRV<_oXYS;00?oXYS;1OnSW<h6ojBPd@03ojFSe?nYYM?o
ZJGC00?oZJGC1OnYZ=H00onZ[=So[JgHojf]f003ojf]f0Ko[K3J00?o[[?Lok6dfona]=/00ona]=/5
ok6gg@03ok>hgOnd^mko];_N00Co];_N00?o0000okBmhOng_^001?ng_^03okO1h@Co^L;Q00?o0000
ooooooooool0Eoooool008cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000007Oooool2o`0000Gooooo00?oXIC7oj:HbonRV</01?nRV</5oj>LcPGoY:3A00?o
Z:;@ojVUdonYYM<01?nYYM<4ojVXeP03ojf[eOn][MSo[JgH00Go[JgH1?n]/=X00on`/]Wo/KCKok6d
f`05ok6df`03ok6ggOnc^=go/kSM00?o/kSM1Ond^mh00onf_=ko0000okNnh005okNnh003okO1hOni
`^7o^L;Q00?o^L;Q00?oooooo`000?l00000Eoooool008cooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406_ooool3o`0000Cooooo1OnQU<L5oj:Hb`KoXic>
00?oY:3AojRRd?nXX]000onXX]06ojVUd`03ojVXe_n]ZmGo[J_E00;o[J_E1on][MP00on]/=[o/;;I
ok2bf@02ok2bf@Go/KCK00?o/kKKok>hgOnc^=d01?nc^=d3okBkgP?o][cN00?o0000okNnh?ng_^00
0ong_^000oni_moo^L;QokW2h@05okW2h@03ooooool0003ooooo05Kooooo002<ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Oooooo0ol00005ooooo`03
oin@`onQU<OoXIC700CoXIC71_nRV</4oj>LcP03ojROcOnXX]3oZ:;@00CoZ:;@1OnYYM<00on]Z=?o
[J_Eojf[e@04ojf[e@Go[JgH00?o/:oGok2bfOn`/]T01?n`/]T3ok6df`?o/kKK1_nc^=d00ond^mko
][cNokJlgP02okJlgP04o`000?ng_^3o]kkPokNnh0Co^KoO1Oni`^400onk`^3oooooo`000009oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000iooooo`00S?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool05oooool2o`0000?ooooo00?o0000
ooooooooool01?nOT<<6oj6Da`GoXYS;00?oXic>ojROcOnXWld00onXWld6ojRRd003ojVUdon]Z=?o
[JSC00?o[JSC1_n]ZmD00on][MSo/:oGok2_e`03ok2_e`Ko/;;I00?o/KCKok>ffonc]]/00onc]]/4
ok>hg@;o][[L1?nf_=h00ol0003o][cNokNnh006okVog`03okW2hOnk`^3o^l;P00?o^l;P00?ooooo
o`000?ooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0>Oooool008cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH01Cooooo0ol00005ooooo`;oWX^o1OnOT<<6oj6Da`CoXYS;00?oYic:ojROcOnXWld0
1?nXWld5ojRRd003ojbUd?n]Z=?o[JSC00Co[JSC1On]ZmD00on`[MGo/:oGok2_e`04ok2_e`Go/;;I
00?o/kCIok>ffonc]]/01Onc]]/00onc^=go][[LokJjg003okJjg0?o][cN00?o0000okRmgOnh_Md0
1Oni_ml00onk`=ko^l;Pok_2h005ok_2h003ooooool0003ooooo00Kooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^03[ooooo002<ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@410@ooooo`;o00001?ooool00onLQ[_oWX^ooij;_`04oij;
_`GoWi331_nQU<L00onRV<_oYic:ojNLbP02ojNLbPGoZ9o=0onXX]04ojbUd0Go[JSC0on]ZmD4ok2]
e@Ko/:oG00?o/;;Iok>dfOnc]=T00onc]=T5ok>ff`03okJhf_nf^]co][[L00Go][[L00?o][cNokRm
gOl000000onh_Md3okVog`?o^l3N1Onk`^000onm`mooooooo`000007ooooo`05o`000?oooooooooo
ooooool000003Oooool00onHV9So8B4Qonk^kP0iooooo`00[_ooool3o`0000Cooooo1?nLQ[/5oij;
_`GoWi331OnQU<L00onWV<OoYic:ojNLbP04ojNLbPGoZ9o=00?oZ:;@ojbUd?n/YM000on/YM06ojfX
d`03ojf[eOn`[MGo/:gE00?o/:gE1On`[mL00onc/MOo/kCIok>df@04ok>df@?o/kKK1?nf^=X5okJj
g004okRkg?nh_Mgo^;gMo`0000Co^;gM00?o^KoOok_0g_nk`=h00onk`=h3ok_2h0?o_L?O00?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0>?oo
ool00:cooooo0_l000000ooooooo0000ooooo`02ooooo`03oiZ0]OnLQ[_oW8Jk00?oW8Jk1OnNRkl6
oin@``03oj6DaonWV<OoYiS700?oYiS71OnWW<X4ojROc@03ojbRcOn/YM3o[:G@00Co[:G@1On]Z=<0
0on`Z];o/:gEok2]e@04ok2]e@?o/:oG1?nc/ML6ok>df@03ok>ffonf^=[o][SJ00?o][SJ0onf^]`4
okRkg003okRmgOl0003o^;gM00;o^;gM00?o^[kMok_0g_nk`=h01Onk`=h00onk`^3o_L?Ookg3g`03
okg3g`03ooooool0003ooooo00Cooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo03Oooooo002Yooooo`?o00000oooool00ol0003oVX2eoiZ0]@02oiZ0]@GoW8Jk1_nNRkl4
oin@``03ojJD`onWV<OoYiS700CoYiS71_nWW<X00onXWlgo[:;=ojbRc@02ojbRc@Ko[:G@00?o[JSC
ok2Zd_n`Z]800on`Z]86ok2]e@03ok2_eonc/MOo/k7G00?o/k7G1Onc]=T00onf]]Wo][SJokJhfP05
okJhfP03okJjg?nh^mco^;_L00?o^;_L00?o^;gMo`000?nh_Md01?nj_]d5ok_0gP03okc1g_nm`moo
_L?O00?o_L?O00Co_/CNooooool0003o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400iooooo`00Y_ooool3o`0000Gooooo00?oV7Z`oiZ0]OnJP;D0
1?nJP;D5oib6^`GoWX^o00?oWi33ojJD`onVU<<00onVU<<5ojNHa`GoYic:00?o[9o:ojbRcOn/X/d0
1?n/X/d4ojbUd003ok2Xd?n`Z];o/:[B00Go/:[B1?n`[MD00onc[mCo/k7Gok>ae`05ok>ae`03ok>d
fOnf]]Wo][KI00?o][KI1Onf^=X00onh^M[o^;_LokRkg005okRkg003o`000?nj_]go^[kM00?o^[kM
0onk`=h4okc1gP?o_L?O0onna=h00ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<03Wooooo002Tooooo`;o00001_ooool4oiQj/0Go
VX2e1OnLQ[/4oij;_`03ojF@_onVU<?oYYC300CoYYC31_nWV<L00onWW<[o[9o:ojbObP03ojbObPGo
[:;=0on/YM03ok2Xd0Oo/:[B00?o/:gEok>_e?nc[m@00_nc[m@5ok>ae`03okJceonf]]Wo][KI00Co
][KI0onf^=X4okRifPGo^;_L00?o^[gKo`000?nj_]d01Onj_]d00onk`=ko_<7Nokc1gP04okc1gP03
okg3gonna=ko_/CN00;o_/CN0_ooool00ol0003oooooooooo`1?ooooo`00XOooool4o`0000Cooooo
0_nELjX5oiQj/0GoVX2e1OnLQ[/3oij;_`?oYI2o1_nVU<<4ojNHa`03ojbLaon/Wl[o[9o:00Co[9o:
1_n/X/d00on/YM3o/:S@ok2Xd003ok2Xd0Go/:[B00?o/jgBok>_e?nc[m@01?nc[m@3ok>ae`?o][?G
1_nf]]T00onf^=[o^;WJokRifP03okRifP?o^;_L0onj_M/00ol0003o^[kMokZng@03okZng@03okc0
g?nl`Mko_<7N00Co_<7N00?o_/;Mokk4g_nna=h01?nna=h00ooooooo0000ooooo`1@ooooo`00Wooo
ool2o`0000Cooooo00?o0000oiEcZ_nELjX00onELjX5oiQj/0GoVX2e1_nLQ[/00onNRkooYI2oojF@
_`02ojF@_`KoYYC30onWV<L3ojbLa`Go[9o:1On/X/d00on`YLgo/:S@ok2Xd004ok2Xd0?o/:[B1?nc
[M86ok>_e003ok>aeonf/mOo][?G00?o][?G1?nf]]T2okRhf0Ko^;WJ00?o^;_LokZmfonj_M/00_nj
_M/00ol0003o^[gKokZng@05okc0g0?o_<7N1?nn`]d4okk4gP;o`<GN00?oooooo`000?ooool0Cooo
ool009cooooo0ol00004ooooo`?oTVbT1_nELjX5oiQj/0GoVX2e1?nLQ[/00onUS;_oYI2oojF@_`04
ojF@_`KoYYC300?oYiS7ojbLaon/W<L00_n/W<L6ojbObP03ojbRcOn`YLgo/:G=00?o/:G=1_n`Z=00
0on`Z];o/jgBok>]dP03ok>]dPGo/joD00?o][;DokJceonf/mL01Onf/mL00onf]]Wo^;SHokRhf003
okRhf0Co^;WJ0_nj^mX4okZmf`03o`000?nl_]_o_<3L00Ko_<3L00?o_<7Nokk2gOnn`]d01?nn`]d0
0onna=ko`<GNol35gP03ol35gP03ooooool0003ooooo04kooooo002Jooooo`;o00001Oooool00on?
IIgoTVbToi9/Y003oi9/Y0GoUG>Z1OnHN[05oiZ0]@03oib6^onUS;_oYHbk00?oYHbk1OnUT;l5ojJD
``03ojbI`on/W<Oo[9c700Co[9c71?n/WlX00on`Xl[o/:G=ok2Uc@04ok2Uc@Go/:S@00?o]:_@ok>]
d_nc[M801?nc[M83ok>_e0Co][;D1Onf/mL00oni]]Ko^;SHokRhf005okRhf003okRif_nj^m[o^[_J
00?o^[_J0onj_M/00ol0003o_;kKokbnf`05okc0g003okk1g?nn`]go_/;M00Co_/;M00?o_l?Mol35
g_o0aMh01Oo0aMh00ol0003oooooooooo`1=ooooo`00HOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool07oooool3o`0000Cooooo1?n?IId5oi9/
Y0GoUG>Z1OnHN[04oiZ0]@03ojF8]_nUS;_oYHbk00CoYHbk1OnUT;l3ojJD``Co[9W31On/W<L3ojbO
bP?o/:?:1On`YLd3ok2Xd0Co]:_@1_nc[M800onc[mCo][;DokJbe003okJbe0?o][?G1?ni]]H5okRh
f003okZif?nj^m[o^[_J00Go^[_J00?o^[gKokbnfol000000_nl_]/3okc0g0Co_/7L0onn`]d4oko3
g@Go`<GN00?o`LGMooooool00000C_ooool0067ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000oooool00ol0003oooooohaNUP05ohmU
W@GoTVbT1OnELjX6oiQj/0;oVX2e0onUR;H5ojF<^`KoYI2o00?oYYC3ojbI`on/VL<00on/VL<6ojbL
a`03ojbOb_n`Xl[o/:?:00?o/:?:1On`YLd00on`Z=3o]:_@okB[d003okB[d0Go/jgB00?o]k3BokJb
e?nf/]@01Onf/]@00onf/mOo^KKFokVfeP03okVfeP?o^;SH1?nj^MP5okZkfP05okblf_nl_]_o_;kK
okbnfol000000_nl_]/00onl`=co_/7Lokk1g004okk1g003okk2gOno`mgo_l?M00?o_l?M0oo0aMh4
ol75g@;o0000COooool0067ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00007?ooool2
o`0000Kooooo0on<GYH6ohmUW@CoTVbT1OnELjX6oiQj/003oiZ0]OnUR;KoYHRf00;oYHRf1_nUS;/4
ojF@_`03ojbF_on/VL?o[9W300Co[9W31On/W<L00onaX<Oo/:?:ok2SbP04ok2SbPCo/:G=00?o]:S=
okB[d?ndZm001OndZm000onc[M;o]k3BokN`dP03okN`dPGo][;D00?o^KCDokVfe_ni]]H01Oni]]H0
0onh^=So^[WHokZif003okZif0?o^[_J1?nl_=X2okbnf`04o`000?nl_]_o_[oKokjof`Go_/7L00?o
_l;Loko3gOno`md01Ono`md00oo0aMko`LGMol75g@04ol75g@03o`000?oooooooooo04_ooooo001Q
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Jooooo`?o0000
1Oooool2ohQDS@CoS5jF1_n?IId5oi9/Y0GoUG>Z1?nHN[000onTQ;;oYHRfojF8]P04ojF8]PGoYHbk
00?oYI2oojbF_on/U[l00on/U[l6ojbI``;o[9c71?naX<L6ok2SbP03ok2UcOndZ<go]:S=00;o]:S=
1OndZm000ong[]3o]k3BokN`dP04okN`dP?o][;D1?ni]=@5okVfeP03ok^heonj^MSo^[WH00Go^[WH
00?o^[_Jokblf_nl_=X00onl_=X2okbnf`03o`000?nn_m_o_[oK00;o_[oK0onn`M`3oko2g0Go_l?M
00?o`LCLol75gOo1aMd01?o1aMd00oo2a]goooooo`00001<ooooo`00HOooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00006?ooool2o`0000Gooooo00?oQTn8ohQDSOn8
E8d00_n8E8d5ohaNUPGoSfFM1OnBK:@5oiEcZP03oiQj/?nTQ;;oY8Bb00;oY8Bb1_nUR;H4ojF<^`03
ojbB_?n/U[oo[9Jo00Co[9Jo1_n/VL<00on/W<Oo/J37ok6Pa`03ok6Pa`Go/:?:00?o]:K:okBXcOnd
Z<d01?ndZ<d3okB[d0?o]jk@1_ng/=800onf/]Co^KCDokVde003okVde0?o^KKF1?nk^=L5okZif003
okbkf?nl_=[o_;cJ00Go_;cJ00?o_;kKo`000?nn_m/01?nn_m/00onn`Mco_l;Loko2g002oko2g0?o
_l?M1?o1a=`3ol75g@Co`/KM00?oooooo`000?ooool0B_ooool0067ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000001Gooooo0ol00002ooooo`03o`000?ooooooQTn800?o
QTn81?n8E8d5ohaNUPGoSfFM1OnBK:@5oiEcZPKoY8Bb1OnUR;H3ojF<^`?o[9:l1On/U[l5ojbI``03
ok6Ma?naX<Oo/J3700Co/J370on`XlX4okBVbPKo]:S=00?o]:_@okN^d?ng[]000ong[]04okN`dP03
okVbd_ni]=Co^KCD00Go^KCD00?o^KKFok^heonk^=L00onk^=L3okZif0Co_;_H1Onl_=X00onn_][o
_[oKo`000004okjof`03oko1fono`]co_l;L00Co_l;L00?o_l?Mol74g?o1a=`01?o1a=`00oo1aMgo
`/KMol;6g@04ol;6g@03o`000?oooooooooo04Wooooo001Qooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`00000Cooooo`;o00001Oooool6ohI?R0CoR5B=1On<GYH5ohmUW@Go
TVbT1?nELjX2ojB0[@GoY8Bb1_nUR;H00onUS;_o[9:lojbB_002ojbB_0Ko[9Jo0_n/VL<4ok6Ma0Ko
/J3700?o/:?:okBVb_ndY/X00ondY/X5okBXc@03okR/c_ng[]3o]jk@00Co]jk@0ong/=83okVbdPGo
^KCD00?o^kKEok^heonk^=L01Onk^=L00onj^MSo_;_Hokbkf003okbkf0?o_;cJ1?nn_]X00ol0003o
_[oKokjof`04oko1f`Co_l;L00?o`L?Kol74g?o1a=`01?o1a=`00oo2aMco`/KMol;6g@04ol;6g@03
ol?6g?oooooo000004[ooooo001Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo
0000ooooo`0?ooooo`?o00001Oooool8ohI?R0CoR5B=1On<GYH5ohmUW@KoTVbT0_nELjX3ojB0[@Go
Y8Bb1OnUR;H00on]T;Oo[9:lojbB_004ojbB_0Go[9Jo00?o[9W3ok6Ma?naWL@00onaWL@5ok6Pa`03
okFTaondY/[o]:K:00Co]:K:0ondZ<d4okR/cPKo]jk@00?o]k3BokVbd_ni/]800oni/]83okVde0?o
^kKE1Onk^=L00onm^]Oo_;_Hokbkf005okbkf003okblf_nn_][o_[kJ00?o_[kJ00?o0000okjofono
`M/01?no`M/3oko2g0?o`L?K0oo1a=`4ol;5g0?o`/KM1?o3a]`00ooooooo0000ooooo`18ooooo`00
Poooool2o`0000Gooooo0_n8E8d9ohI?R0GoR5B=1?n<GYH5ohmUW@KoTVbT00?oUG>ZojB0[OnTP:d0
0_nTP:d5ojB4/PCoYHRf0_n]T;L6ojbB_0Co[9Jo00?o/Y_0ok6Ma?naWL@01?naWL@3ok6Pa`Co]JC7
1_ndY/X00ondZ<go^:c>okR/cP03okR/cPGo]jk@00?o^[7@okVbd_ni/]801Oni/]800oni]=Co^kKE
ok^fe@03ok^fe@?o^kSG0onm^]L5okbkf003okjmf?nn_][o_[kJ00Co_[kJ00?o0000oko1fono`M/0
1Ono`M/00ono`]co`L?Kol73f`03ol73f`03ol74g?o2aMco`/GL00Co`/GL00?o`/KMol?6g?o3a]`0
1?o3a]`00ol0003oooooooooo`17ooooo`00P?ooool3o`0000;ooooo00?o0000oooooon<GYH01?n8
E8d9ohI?R0GoR5B=1On<GYH5ohmUW@CoTVbT00?oY7bWojB0[OnTP:d01?nTP:d5ojB4/P;oYHRf1?n]
T;L5ojbB_0?o[9Jo0onbVl06ok6Ma003ok6PaoneY<Oo]JC700Co]JC71?ndY/X00oniZ/_o^:c>okR/
cP04okR/cP?o]jk@1?nj/M05okVbdP03okbedonk]]Go^kKE00Go^kKE00?o^kSGokfjeonm^]L00onm
^]L3okbkf0?o_[gH0onn_]X2oknofP03o`000?no_m[o_l7K00Co_l7K00?o`L;Kol73foo1`m/00oo1
`m/2ol;4f`Go`/GL00?o`lGLol?6g?o3a]`01?o3a]`00oo4a]co0000o`000018ooooo`00OOooool3
o`0000Cooooo1?n<GYH4ohQDS@WoQTn81On8E8d5ohaNUPGoSfFM0_nBK:@3ojAlY`KoY82]1OnTQ;80
0onUR;Ko[I2gojf@]`03ojf@]`Ko[9:l00?o[9Jook:K`?nbVl000_nbVl06ok6Ma0Oo]JC70ondY/X3
okVZb`Ko^:c>00?o]jk@okZad?nj/M000onj/M03okVbdPCo_;GC1Onk]]D00onm^MGo_K[Gokfje`05
okfje`03okbkf?nn_MSo_[gH00?o_[gH00Ko_[kJoknof_no_m[o_koJo`000?no_mX3oko1f`Co`L;K
0oo1`m/4ol;4f`?o`/GL0oo3aM`3ol?6g0Coa<KL00?oooooo`000?ooool0A_ooool007_ooooo0_l0
0005ooooo`03ohmUWOn<GYKoS5jF00?oS5jF1?n8E8d9ohI?R0GoR5B=1On<GYH5ohmUW@03oi9/Y?nT
O:OoY7bW00?oY7bW1OnTP:d4ojB4/P03ojj=/on]T;Oo[I2g00Co[I2g1On/T[`00oncV;co/Y_0ok:K
`004ok:K`0Co/Ig40_nfX/@7okFTa`03okBVb_niZ/_o^J[;00?o^J[;1?nh[<h00onk[lko^[7@okZa
d005okZad003okVbd_nl]M?o_;GC00?o_;GC0onk]]D4okfie@Go_K[G00?o_kcGokjmf?nn_MP00onn
_MP00oo0_]So_koJoknofP02oknofP04o`000?no_m[o_koJoko1f`Ko`L;K00?o`L?Kol;4foo2a=/0
1?o2a=/00oo2aMco`lGLol?5g003ol?5g003ol?6g?o4a]coa<KL00Coa<KL00?o0000ooooooooool0
AOooool007Sooooo0ol00005ooooo`?oSfFM1On<GYH4ohQDS@WoQTn81On8E8d5ohaNUPGoSfFM1_nT
O:L6ojB0[@;oY8Bb0on^SK<6ojf@]`;o[9:l1?ncV;`5ok:K`0?o/Ig40onfX/@6okFTa`03okVXb?ni
Z/_o^J[;00Co^J[;0onh[<h3ok^_cPGo^[7@00?o_KCAokbedonl]M<01Onl]M<00onk]]Go_KWEokfi
e@03okfie@?o_K[G1?no_=L3okjmf0?o`;kH0ono_mX00ol0003o_koJol71fP06ol72f`03ol;3f_o2
a=_o`/CK00Co`/CK00?o`lCKol?5g?o3aM`00oo3aM`7olC6g003olC7g?oooooo000004Kooooo001f
ooooo`;o00000_ooool00ol0003oooooooooo`02oi9/Y0CoSfFM1On<GYH4ohQDS@WoQTn81On8E8d5
ohaNUPGoSfFM1_nTO:L6ojB0[@03ojB4/_n^SK?o[Xfc00;o[Xfc1_n]T;L00on/T[co/iRlok>H_003
ok>H_0Ko/Y_000?o/Ig4okJRa?nfX/@00onfX/@4okFTa`?o^JS81_niZ//00onh[<ko^jo>ok^_cP03
ok^_cP?o^[7@0onm]=45okbed`03okjgdonm^MGo_KWE00Go_KWE00?o_K[Goknleono_=L01?no_=L0
0onn_MSo`;kHol2nf003ol2nf0;o_koJ00Co0000ol71f_o1`M[o`L7J0oo1`]/4ol;3fP?o`/CK1?o3
a=/3ol?5g0Koa<KL1?o4am`00ooooooo0000ooooo`14ooooo`00Loooool3o`0000Cooooo00?oUG>Z
o`000?nBK:@00_nBK:@4ohmUW@GoS5jF1?n8E8d9ohI?R0GoR5B=1_n<GYH3ohmUW@03ojEiX_nTO:Oo
Y7bW00CoY7bW1_nTP:d6ojj=/`Go[I2g1_ncV;`5ok:K`003okNP`OnfX/Co]Z;400Co]Z;40oneY<L4
okVXb0Go^J[;00?o_:k<ok^_c_nk[lh01Onk[lh00onj/M3o_KCAokfdd@02okfdd@?o_;GC1?nn]m<5
okfie@03oknkeOno_=Oo_kcG00Co_kcG00?o`;gGol2nf?o0_]P01Oo0_]P00ono_m[o0000ol71fP03
ol71fP03ol72foo2`m[o`/?J00Co`/?J00?o`/CKol?4foo3a=/01?o3a=/00oo3aMcoa<KLolC6g004
olC6g0Koa<OL00?o0000ooooooooool0@oooool0077ooooo0_l00005ooooo`?oUG>Z1?nBK:@4ohmU
W@GoS5jF1?n8E8d9ohI?R0GoR5B=1_n<GYH2ohmUW@?oYGVR1OnTO:L5ojB0[@03ok2;[on^SK?o[Xfc
00Co[Xfc1?n]T;L2okFG^@Ko/iRl0_nbVl04okNP`@Ko]Z;400?o]JC7okVXb?niZ<P00oniZ<P3okVZ
b`Co_:k<1Onk[lh00onn//oo_KCAokfdd@04okfdd@03okbedonn]m?o_[OC00?o_[OC0onm^MD4oknk
e@Co_kcG0oo0_ML5ol2nf003ol70fOo1`M[o000000?o`L7J00?o`/;Jol;3f_o2`mX01?o2`mX00oo3
a=[o`lCKol?4f`04ol?4f`03olC5foo4a]coa<KL00Coa<KL1_o4am`00oo5amcoooooo`000014oooo
o`00=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00008_ooool3o`00
00Gooooo00?oV7Z`oiEcZ_nELjX00_nELjX4oi9/Y0GoSfFM1?n<GYH4ohQDS@WoQTn81On8E8d6ohaN
UP03ohmUWOnUNJ;oYGVR00;oYGVR1_nTO:L3ojB0[@?o/8^_1On^SK<3ojf@]`?o]INi1_ncV;`00onb
Vl3o]j31okNP`@03okNP`@Go]Z;400?o^jO5okVXb?niZ<P01OniZ<P00oniZ/_o_:k<okb^c003okb^
c0Co^jo>0onn//l5okfdd@Oo_[OC00?o_KWEoknkeOno^mD00ono^mD3oknle`Co`;gG0oo0_]P4ol70
f@03o`000?o1`M[o`L7J00?o`/;J0oo2`mX4ol?4fPCo`lCK0oo4aM/4olC6g0;oa<KK1?o4am`3olG7
g0;o0000@oooool003Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401oooooo0ol00002ooooo`03o`000?oooooooooo00CoV7Z`1OnELjX4
oi9/Y0CoSfFM1?n<GYH4ohQDS@WoQTn81On8E8d6ohaNUPGoYGVR1_nTO:L2ojB0[@Co/8^_1_n^SK<0
0on]T;Oo]INiokFG^@03okFG^@Go/iRl1_ngX<43okJRa0Co^jO51OniZ<P00onm[LWo_:k<okb^c004
okb^c0?o^jo>1?nn//l4okfdd@;o_kOA1Onn]m<00oo0^]Co_k_Eoknke@05oknke@03oknleoo0_MOo
`;gG00Co`;gG00?o`;kHol70fOo1`=T01?o1`=T00ol0003o`/;Jol;2fP03ol;2fP03ol;3f_o3a=[o
`lCJ00?o`lCJ0oo3a=/4olC5f`?oa<KL0oo4a]/3olC7g0GoaLOL00?o0000ooooooooool01oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool08ooo
ool003Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01kooooo0_l0
0005ooooo`;oVX2e1OnHN[05oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2On6ChP6ohQDS@GoS5jF1OnU
NJ86ojAlY`03ojB0[On`Rjoo/8^_00?o/8^_1_n^SK<6okFG^@Co/iRl0_niW[d6okNP`@03okJRa?nk
YlGo^jO500?o^jO51?niZ<P3okf]b@Ko_:k<00?o^jo>okjbconn//l00onn//l3okfdd@Co_kOA0onn
]m<3ol2je0Go_k_E00?o`KgFol2meoo0_ML01?o0_ML00oo2_mOo`L3Iol70f@04ol70f@03ol;1fOl0
003o`/;J00Co`/;J1oo3a=X00oo3a=_oa<GKolC5f`04olC5f`03olC6g?o4a]_oa<KK00?oa<KK00?o
a<OLolG7g?o5am`00oo5am`00oo5am_oooooo`000008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool09?ooool003Oooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0ol00004ooooo`03oib6^onJP;GoVX2e00?oVX2e
1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2On6ChP6ohQDS@CoS5jF00?oZWRLojEiX_nUNJ80
0onUNJ86ojAlY`Ko/8^_1On^SK<00onfU;Go]INiokFG^@04okFG^@?o/iRl0oniW[d6okNP`@Ko^jO5
0oniZ<P4okf]b@Go_:k<00?o_k7=okjbconn//l01Onn//l00onm]=7o_kOAokngd@04okngd@03okjg
doo0^]Co`;[D00?o`;[D0ono^mD3ol6meP?o`;gG1?o2_mL3ol70f@?o`/7I00?o0000ol;2f_o2`]X0
0_o2`]X2ol?3fPGo`lCJ00?oa<CJolC5foo4aM/01?o4aM/6olC6f`03olG7foo5amcoaLOL00?oaLOL
0oo5am/00ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0002Go
oooo000gooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Gooooo`;o
00001Oooool4oib6^`CoVX2e1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@?o
S5jF0onZN9`4ojEiXPGoY7bW0_nbRJX5ok2;[`Co[Xfc0onfU;D6okFG^@03ok>H_?niW[go^Ijm00?o
^Ijm1?ngX<42okbV`PKo^jO500?o^JS8okf]bOnm[LT00onm[LT3okb^c0Co_k7=1Onn//l00oo0]]3o
_kOAokngd@04okngd@03ol6id_o0^]Co`;[D00Go`;[D00?o_k_Eol6me_o1_MH00oo1_MH00oo0_MOo
`[oGol:oe`04ol:oe`03ol70fOo2`MWo`/7I00;o`/7I00Co0000ol;2f_o2`][o`/;J1?o3`mX3ol?4
fP?oa<CJ0oo4aM/7olC6f`?oaLOK0oo5am`5olG7f`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0002Kooooo000gooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`0Cooooo`?o00000_ooool01?l0003ooooooooo
oonNRkl5oib6^`CoVX2e1OnHN[04oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@;oS5jF
1?nZN9`5ojEiXP?oY7bW0onbRJX6ok2;[`;o[Xfc1?nfU;D5okFG^@03ok^M^_niW[go^Ijm00Co^Ijm
0ongX<43okbV`PKo^jO51onm[LT00onl[/co_k7=oknac@03oknac@?o_[;?1?o0]]04okngd@?o`KWB
1Oo0^]@00oo2_=Co`KgFol6meP03ol6meP03ol>oe_o2_mOo`[oG00Go`[oG1Oo2`MT00ol0003o`/7I
ol;2fP06ol?3fP03ol?4f_o4a=[oa<CJ00?oa<CJ00?oa<GKolC6foo4a]/01Oo4a]/5olG7f`03olG7
g?o5am_oaLOK00?oaLOK00?oa/OKooooool000001_ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00009_ooool003Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41004oooool2o`0000Kooooo0onNRkl5oib6^`GoVX2e1?nHN[04
oiEcZPCoTVbT1?n?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@03ohaNU_nZN9coZWRL00?oZWRL1OnUNJ82
ojAlY`Co/XVZ1_n`Rjl00on^SK?o]YBeokJD]@03okJD]@Co]INi0onkWKX6okVN_@03okNP`OnlY/;o
_:K200?o_:K21?nkYlD2okn/aPKo_Jg91ono/Ld00onn//oo`;K@ol2fd003ol2fd0?o_kOA1?o1^M83
ol2je0Co`[cD0oo1_MH3ol>oePGo`[oG0_o3`MP4ol;1f@03o`000?o3`mWo`l?J00Go`l?J1_o4a=X0
0oo4aM[oa<KKolC6f`04olC6f`03olG6foo5am_oaLOK00WoaLOK0oo6am/00ol0003oooooooooo`04
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Vooooo`00=oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00@ooooo`?o0000
1Oooool2oin@``GoWX^o1OnLQ[/4oiZ0]@CoV7Z`1?nELjX4oi9/Y0CoSfFM1?n<GYH4ohQDS@[oQTn8
1On8E8d6ojYhW0GoYGVR00?oY7bWok:9Z_nbRJX01?nbRJX5ok2;[`Oo]YBe0_neUkT4ok^M^PGo^Ijm
00?o_ZFookbV`_nlY/801?nlY/83ok^Wa@Co_jc61?nm[LT2ol6abPGo_k7=00?o`[G>ol2fd?o0]]00
1Oo0]]000ono]m7o`KWBol6idP04ol6idP03ol2je?o2_=Co`[cD00Co`[cD00?o`KgFol>oe_o3_mH0
0oo3_mH3ol:oe`?o`l7H0oo2`MT01?o3`mWo0000ol?3fOo3`mT3ol?3fPOoa<CJ0oo4aMX3olC6f`Co
aLKK2Oo5am/5olK7f`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000009_ooool005Wooooo0ol00005ooooo`03oj6DaonOT<?oWi3300?oWi331?nNRkl5oib6^`Co
VX2e1OnHN[04oiEcZPCoTVbT0on?IId4ohaNUPCoR5B=2_n6ChP5ohQDS@KoZWRL1OnUNJ87ok:9ZPGo
/8^_00?o^IBaokJD]OnfU;D01?nfU;D00oneUkWo^ifjok^M^P03ok^M^PCo^Ijm0onnYKl6okbV`P03
ok^WaOno[<Ko_jc600?o_jc60onm[LT4ol6abP?o_k7=0oo2]Lh5ol2fd0;o`[WA1Oo1^M800oo3_=?o
`[cDol:le004ol:le003ol>neOo3_mKo`koF00Go`koF00?o`[oGol?1f?o3`MP00oo3`MP01?o2`MWo
`l?Iol?3fOl00003ol?3f@03ol?3f_o4a=[oa<CJ00Goa<CJ1Oo4aMX00oo4a]_oaLKKolG6f`04olG6
f`OoaLOK1Oo6am/00oo6b=_oooooo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`0Uooooo`00Eoooool2o`0000?ooooo00?o0000ooooooooool01?nQU<L4oin@
``CoWX^o1OnLQ[/5oiZ0]@CoV7Z`1?nELjX4oi9/Y0?oSfFM1On<GYH3ohQDS@[oQTn81?n8E8d00ong
OICoZWRLojYhW004ojYhW0GoYGVR1onbRJX4ok2;[`;o^IBa1_nfU;D7ok^M^P;o^Ijm1?nnYKl5okbV
`P03ol6[a?no[<Ko_jc600Go_jc600?o_Jg9ol6ab_o1/LX01?o1/LX00ono/Lgo`[G>ol:ecP03ol:e
cP?o`;K@1?o2^M43ol6idP?o`kcC1?o2_=@3ol>ne@Go`koF00?oa<3Gol?1f?o3`MP00oo3`MP2olC2
f0;o`l?I00Co0000ol?3fOo3`mWoa<CI1_o4a=X00oo5aM[oa<GJolC5fP03olC5fPSoaLKK1Oo5am/6
olK7f`?oa/SK00?o0000ooooooooool0??ooool005Cooooo0ol00005ooooo`;oXYS;1OnQU<L4oin@
``GoWX^o1OnLQ[/4oiZ0]@CoV7Z`1?nELjX4oi9/Y0CoSfFM1?n<GYH3ohQDS@[oQTn81?n8E8d00ong
OICoZWRLojYhW004ojYhW0CoYGVR0_nfRJH7ok:9ZP;o/8^_1?niU;45okJD]@03okfL]onkWK[o^ifj
00Co^ifj00?o^IjmokjU_onnYKl00onnYKl4okbV`P?o`J_41Ono[<H00oo2/<So`K7:ol6abP04ol6a
bP03ol>dc?o2]Lko`[G>00Go`[G>00?o`;K@ol:idOo2^M401?o2^M400oo1^M;o`kcCol>ld`02ol>l
d`?o`[cD1?o3_]D3ol>oePCoa<3G0oo3`MP4olC2f003ol?3fOl0003o`l?I00?oa<CI0oo4a=X4olG5
fP?oa<GJ2_o5a]/3olG7f`Koa/OK1Oo6b=/00ol0003oooooooooo`0kooooo`00D_ooool2o`0000Go
oooo00?oXic>oj:HbonRV</00onRV</4oj6Da`GoWi331?nNRkl5oib6^`;oVX2e0_n=N[T4ohIa]0Co
OfR_0omfGJP00onBK:CoSfFMohmUW@02ohmUW@CoS5jF0on8E8d:ohI?R0CoR5B=0_ngOI@6ojYhW0;o
YGVR0onfRJH7ok:9ZP03ok2;[oniU;7o^IBa00?o^IBa1?nfU;D2okfL]`Ko^ifj1onnYKl2okbV`PCo
`J_41?no[<H3ol:`b0Co`K7:0oo3]<`5ol:ecP03olBhcoo2^M7o`[WA00Co`[WA00?oa;cBol>ldoo3
_=<01?o3_=<00oo2_=Co`kkEol>ne@04ol>ne@03ol>oe_o4`=Ooa<3G00Coa<3G00?o`l7HolC2f?o4
`]P01?o4`]P00ol0003oa<CIolC4f@03olC4f@03olC4f_o5aM[oaLGJ00CoaLGJ00?oa<GJolG6foo5
a]/02_o5a]/00oo5am_oa/OKolK7f`04olK7f`Koa/SK00?oooooo`000?ooool0>oooool004oooooo
0ol00005ooooo`CoXic>1?nRV</5oj6Da`CoWi330_nNRkl2oiB7`PGoT86n1?n=N[T4ohIa]0CoOfR_
1?mfGJP2of19W`;oSfFM1?n<GYH3ohQDS@[oQTn80on8E8d3okMmU0KoZWRL0_nUNJ83okJ9YPOo/XVZ
1_niU;43okJD]@Co_Ibg1OnkWKX00oo1Y;co_ZFookjU_`04okjU_`03okbV`_o1ZlCo`J_400?o`J_4
0ono[<H4ol:`b0?o`K7:1?o3]<`4ol:ecP?oa;S?1?o2^M43olBldPCo`kcC0_o5_]@5ol>ne@03olG0
e_o4`=Ooa<3G00Coa<3G00?oaL;GolC2f?o4`]P01?o4`]P00oo5`mWo0000olC4f@03olC4f@03olG5
fOo5aM[oaLGJ00GoaLGJ3?o5a]/8olK7f`Ooa/SK00?o0000ooooooooool0>_ooool004gooooo0_l0
0002ooooo`05o`000?oooooooooooooooonTX=401OnSW<h4oj:Hb`GoXIC70_nOT<<2oiN=aPGoU8O2
1?n@PKh5ohej^@CoQW6d0omoJ:l4ogIMZ0?oH4VO00?oSfFMohaNU_n<GYH00_n<GYH3ohQDS@[oQTn8
0on8E8d3okMmU0KoZWRL00?oYGVRokJ9Y_nfRJH00onfRJH6ok:9ZPOo^IBa00?o]YBeokfL]onmW;L0
0onmW;L4ok^M^P;o`JBl1_nnYKl7ol6[a003okn/a_o2/<So`[3800Co`[3800?o`K7:ol>dc?o3]<`0
0oo3]<`3ol:ecPCoa;S?0oo2^M44olBldP?o`kcC1?o5_]@3ol>ne@?oaL3F0oo4`=L4olG2e`?oa<;H
0oo5`mT01?l0003oa<CIolC4fOo4a=T3olG5f@OoaLGJ2Oo5a]/;olK7f`Ooa/SK00?o0000oooooooo
ool0>Oooool004[ooooo0ol00005ooooo`03o`000?nTX=7oY:3A00;oY:3A1?nSW<h5oj:Hb`?oXIC7
00?oVY7:oiN=a_nGSLH00onGSLH4oiB7`PGoT86n1?n=N[T4ohIa]0CoOfR_0omfGJP4of19W`CoS5jF
0on8E8d:ohI?R0;oR5B=1?ngOI@6ojYhW0Ko]XVV1OnbRJX2okfD[@Ko^IBa1_nmW;L3ok^M^PCo`JBl
1?nnYKl2ol>Z`@Ko`J_41oo2/<P7ol>dc003ol:ec_o4^<ooa;S?00Coa;S?00?o`[WAolBld_o4_=80
1?o4_=800oo3_=?oaKkDolFne004olFne003ol>neOo5`=KoaL3F00?oaL3F00?oa<3GolG2eoo5`]L0
1?o5`]L00oo4`]SoaL?IolG3f@02olG3f@03o`000?o5`mWoa<CI00GoaLGI1oo5aMX7olG6f`coa/OK
1oo6b=/00ooooooo0000ooooo`0iooooo`00B?ooool2o`0000Gooooo0_nUXm@6ojBPd@GoXic>1?nR
V</00onQU<OoVY7:oiZAbP02oiZAbPCoUhg61OnDQl84oi21_PCoSGZi1?n6LK@4ogmX[`CoMUfX0omP
BIl4ohaNUP?oR5B=2_n6ChP2ohQDS@Co]gfD1_nZN9`6okJ9YPCo/XVZ0onmU:d6okVD/@Oo_Ibg00?o
^ifjol6T_?o1Y;`00oo1Y;`3okjU_`Co`j[11?o1Zl@2olB`aPGo`[380_o5]<X5ol>dc003olJhcOo4
^<ooa;S?00Goa;S?1_o4_=800oo6_]?oaKkDolFne004olFne003olK0eOo5`=KoaL3F00CoaL3F1oo5
`]L5olG3f@03o`000?o5a=WoaLGI00CoaLGI1oo5aMX00oo6a][oaLKKolG6f`03olG6f`goa/OK2Oo6
b=/00ol0003oooooooooo`0hooooo`008?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^023ooooo0ol0
0004ooooo`03ojJVeonUXmCoYJ?D00?oYJ?D1OnTX=45oj>LcP;oXYS;0_nLU/d5oiZAbPGoUhg61?nD
Ql84oi21_PCoSGZi1?n6LK@4ogmX[`CoMUfX0omPBIl01?l40X3oS5jFohaNU_n<GYH3ohQDS@[oQTn8
0_n8E8d4okMmU0GoZWRL00?o_hfQokJ9Y_nfRJH01OnfRJH2ok:9ZPCo_IB]1OniU;42ol6M/`Ko_Ibg
1oo1Y;`00onnYKoo`j[1ol>Z`@03ol>Z`@?o`J_41?o4/<H3ol:`b0CoaKC:0oo3]<`3olJhc@Goa;S?
0_o6_=04olBldP?oa[kC1?o5_]@3olK0e@CoaL3F0_o6`]L5olG2e`;oaL?H1?o5`mT00ol0003oaLCI
olG4f@03olG5f@KoaLGJ1?o6a]X3olG6f`goa/OK2_o6b=/00ooooooo0000ooooo`0hooooo`008?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0ol00003ooooo`03o`000?ooooooYZKG00?oYZKG
1OnUXm@5ojBPd@;oXic>0_nMV]05oibFc@GoVY7:1?nGSLH4oiB7`PGoT86n0on=N[T4ohIa]0CoOfR_
1?mfGJP3of19W`04o`@2P?n<GYKoS5jFohaNUP?oR5B=2_n6ChP00on8E8go]gfDokMmU003okMmU0Go
ZWRL0_noSJ46okJ9YP03ok:9Z_nmU:go_IB]00?o_IB]1?niU;43ol6M/`Go_Ibg0_o4Y;T6ol6T_0Oo
`j[100?o`J_4olB`a_o4/<H01?o4/<H00oo2/<SoaKC:olFdbP04olFdbP03ol>dc?o6^<goa[S=00?o
a[S=0oo4^<l3olJld0?oa;cB1?o6_]<3olFne0Coa/3E0oo5`=H4olK2e`?oaL;G0oo5`mP3olG3f@;o
aLCI00Co0000olG4fOo5a=WoaLGI1_o5aMX6olK6fP03olG6foo6am_oa/OK00_oa/OK2oo6b=/2oooo
o`03o`000?oooooooooo03Kooooo000Pooooo`05oa0@4?ooooooooooooooool@41006oooool2o`00
00Gooooo0_nVZMT6ojJVe`GoYJ?D0_nTX=42oinNd`GoWI[@1OnLU/d4oiZAbPCoUhg61OnDQl84oi21
_PCoSGZi1?n6LK@3ogmX[`CoMUfX0omPBIl01?l40X3oS5jFohaNU_n<GYH3ohQDS@[oQTn800?oR5B=
okMmU?ngOI@00ongOI@4ojYhW0?o_hfQ1_nfRJH7okfD[@;o^IBa1?o1WK<4okfL]`?oa:Bi1Oo1Y;`2
olJZ_PGo`j[100?oak33olB`a_o4/<H01Oo4/<H7olFdbPOoa[S=00?oa;S?olJld?o6_=000oo6_=00
0oo4_=;oa[kColJnd`04olJnd`03olFne?o6`=Goa/3E00Coa/3E00?oaL3FolK2eoo6`]L01?o6`]L0
0oo5`]OoaL?HolG3f003olG3f007olG3fOo5a=WoaLCIolG4fOl0003oaLCIolK5f@05olG5fPOoa/KJ
00?oa/OJolK7foo6am/02oo6am/=olK8f`03ooooool0003ooooo03Oooooo000Pooooo`05o`000?oo
ooooooooooooool000006?ooool3o`0000Cooooo00?oYjgKojJYfOnVZMT00onVZMT5ojJVe`CoYJ?D
00?oX:;FoinNdonOW]<00onOW]<5oifJd0CoW9K=1OnJTLX4oiN=aP;oU8O20_n:PlH4ohAk`P?oOWBm
00?oSGZiohIa]?n6LK@00_n6LK@4ogmX[`?oMUfX1?mPBIl00ol40X3oS5jFohaNUP03ohQDS@[oQTn8
00?oR5B=okMmU?ngOI@01?ngOI@2ojYhW0Co_hfQ1_nfRJH7okfD[@03okVD/Oo1WK?o`Ifc00Co`Ifc
0_nmW;L4olBT^@Co`JBl0oo6Z[h4ol>Z`@?oak331Oo4/<H2olRda`GoaKC:0_o8^L/5olJhc@03olRl
coo6_=3oa[c@00?oa[c@0_o7_]85olJnd`03olO1e?o6`=Goa/3E00Coa/3E00?oal;FolK2eoo6`]L0
1?o6`]L00oo6`mOoaL?HolG3f003olG3f003olK4f?o5a=WoaLCI00;oaLCI00Co0000olK5fOo6aMWo
a/GI0oo5aMX7olK6fP?oa/OJ3Oo6am/=olK8f`03ooooool0003ooooo03Kooooo000Pooooo`05o`00
0?ooooooooooooooool000005_ooool3o`0000Cooooo1?nW[M/5ojJYf@GoYZKG00?oYJ?Doj2Re_nP
X]H00_nPX]H5oinNd`CoWI[@1OnLU/d2oiZAbP;oTXo=1?n>RLT4ohZ3aPCoQ7_21?mnM;d3og9X^@03
ohIa]?moJ:ooOfR_00;oOfR_0omfGJP4of19W`03o`@2P?n<GYKoS5jF00?oR5B=2_n6ChP7okMmU0;o
ZWRL1?noSJ45okJ9YP;o`YJY1_nmU:d7ol6M/`03okfL]oo4Y;Woa:Bi00Coa:Bi0_o1Y;`4olJZ_P?o
`j[11?o7/<<4olB`aP?ob;C71?o5]<X3olRib`?oa[S=1?o8_<l3olJld0CoakkB0oo6_]<3olO1e0?o
a/3E1?o7`]H3olK2e`Coa/?G0oo5`mP3olK4f0?oaLCI00?o0000olK5fOo6aMT00_o6aMT00oo5aM[o
a/KJolK6fP05olK6fPGoa/OJ3Oo6am/<olK8f`;ooooo00?o0000ooooooooool0=?ooool0023ooooo
00Go410@oooooooooooooooooa0@400Cooooo`?o00000oooool00ol0003oooooojN_g@06ojN]f`Go
YZWI0_nVY]L2oj6Uf0KoX:;F1?nOW]<5oifJd0;oW9K=0_nEU=05oi:?c@CoSXW91?n:PlH4ohAk`P?o
OWBm1?mbJ;T3ofIL/`04ogmX[omfGJSoMUfXogIMZ0CoH4VO0_l40X001?n<GYKoR5B=ohQDSOn8E8d:
ohI?R0Oo]gfD00?oZWRLokn=XOnoSJ400onoSJ44okJ9YP?o`YJY1_nmU:d7ol6M/`Ooa:Bi00?o`JBl
olJZ__o6Z[h01?o6Z[h00oo3Z/7oak33olN```03olN```?oa;361?o8]<L3olFdbPGob;W;00?oa[S=
olRlcoo8_<l01?o8_<l00oo6_=3oakkBolNndP04olNndP03olJndoo7`MCoal7D00?oal7D00?oa/3E
olO2e_o7`]H01?o7`]H00oo6`]Ooa/?GolK3e`04olK3e`03olG3f?o6a=Soa/CH00?oa/CH00?oaLCI
olK5fOl000001?o6aMT6olK6fPKoa/OJ3Oo6am/>olK8f`03ooooool0003ooooo03Gooooo000Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool2o`0000Gooooo00?oZ;;PojN_gOnW[md00_nW[md6
ojN]f`;oYZWI0_nRZ=/5oj6Uf0GoX:;F1OnOW]<2oifJd0;oUiSC1OnEU=04oi:?c@CoSXW91?n:PlH4
ohAk`PCoOWBm0ombJ;T4ofIL/`;oDT^[0_mfGJP3of19W`;o10:000CoS5jFohQDSOn8E8goR5B=2On6
ChP00on]Li;o]gfDokMmU005okMmU003ojYhW?noSJ7o_hfQ00Co_hfQ0_nfRJH4ol:FZ@Go_IB]0_o5
W[06ol6M/`03olNU]_o4Y;Woa:Bi00Coa:Bi1oo6Z[h7olN```03olB`a_o8]<Oob;C700Cob;C700?o
aKC:olRiboo8^L/01?o8^L/6olRlc`03olVod?o7_];oakkB00CoakkB00?obL7ColO1e?o7`M@01?o7
`M@00oo8`mGoal;FolO2eP03olO2eP03olO4eoo6`mOoa/?G00Coa/?G00?oalGHolK4f?o6a=P00oo6
a=P3olK5f@04o`000?o6aMWoa/GIolK5f@Goa/KJ1oo6amX<olK7fa7oa/SK0_l0000eooooo`008?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo0ol00005ooooo`CoZ;;P1?nW[md4ojN]f`03oj>[
gOnRZ=_oXZSK00?oXZSK1OnQYMP5oj2ReP;oWikC0_nJW=D5oiNHd`CoUIC@1?nBSld4ohj9b@CoRX?6
1?n4Nl84ogid_@CoLVRi0omVG;<3oe9;Z`04ogIMZ?mPBIooH4VOof19W`;o10:000CoS5jFohQDSOn8
E8goR5B=2On6ChP00on]Li;o]gfDokMmU005okMmU0Oo_hfQ0_nfRJH4ol:FZ@Co_IB]0oo5W[05ol6M
/`;oajFf1_o4Y;T00oo9Zk_oaZZnolJZ_P04olJZ_P03olZ``Oo7/<?oak3300Coak331oo8]<L7olRi
b`03olZmcOo8_<oob;c?00;ob;c?0oo9_m04olNndP?obL7C1?o7`M@3olS3e@?oal;F0oo7a=L3olK3
e`CoalGH0oo6a=P4olK5f@03o`000?o6aMWoa/GI00Goa/KJ1oo6amX<olK7fa;oa/SK0_ooool00ol0
003oooooooooo`0booooo`00<?ooool3o`000003ooooool0003ooooo00;ooooo0_nX]N85ojRbh0Go
YjoM00?oYjgKoj>[gOnSZmd00_nSZmd5oj:Xf`GoXJGH0_nPX]H2oi^Pf0GoVYcE1?nGV=<4oiFDd0Go
TXo=1?n>RLT4ohZ3aP?oQ7_21?mnM;d4og9X^@CoIUbc0omBBj/3of19W`?o10:00on8E8d9ohI?R003
ojecT_ngOICo]gfD00Go]gfD1onoSJ400onfRJKo`YJYol:FZ@04ol:FZ@;o_IB]1?o5W[04ol6M/`Co
ajFf1?o4Y;T3olV[^`CoaZZn0oo:/<44olN```;ob[G51Oo8]<L2ol^ib@Gob;W;0_o:_Ld3olRlc`Co
bKo@0oo7_]84olW1d`?oal7D1Oo8`mD00oo7`]KoalCGolO4e`03olO4e`03olK3eoo7aMSoalGH00Co
alGH00?oa/CHolK5fOo6aMT00_o6aMT2o`000003olK5fOo6a][oa/KJ00?oa/KJ1oo6amX;olK7faGo
a/SK00?oooooo`000?ooool0<oooool002kooooo0_l00005ooooo`03o`000?nX]N;oZ;GR00?oZ;GR
1OnX/^02ojN_g@?oY:kO1OnSZmd5oj:Xf`;oXJGH0_nMY=X5oi^Pf0CoVYcE1?nGV=<5oiFDd0CoTXo=
1?n>RLT4ohZ3aPCoQ7_20omnM;d4og9X^@CoIUbc0omBBj/3of19W`?o10:00on8E8d8ohI?R0?o[G>B
1_ngOI@7okn=X@Oo`YJY00?o_IB]olFN/?o5W[001?o5W[02ol6M/`GoajFf0oo4Y;T4olV[^`?oaZZn
1?o:/<43olN```Cob[G50oo8]<L4ol^ib@?ob;W;1?o:_Ld00oo8_<oobKo@olVod004olVod003olNn
d_o9`M?obL7C00CobL7C00?oal7DolS3eOo8`mD00oo8`mD00oo8a=KoalCGolO4e`04olO4e`03olS5
f?o7aMSoalGH00?oalGH00?oalKIolK5fOo6aMT00ol000000oo6aMWo0000olK6fP04olK6fPWoa/OJ
2Oo6am/GolK8f`03ooooool0003ooooo03;ooooo000[ooooo`?o00001Oooool4ojVhi0GoZ;GR0_nX
/^02ojBah@KoY:kO1OnSZmd2oj:Xf`;oWZOL1OnMY=X4oi^Pf0CoVYcE1OnGV=<4oiFDd0;oTXo=0_n:
SM04ohF6c@CoOh390omgMlH00on4Nl;oOWBmogid_@02ogid_@?oLVRi1?mVG;<3oe9;Z`03ob<UVomP
BIooH4VO00?o10:000?o>R67ohQDSOn8E8d02?n6ChP3ojecTPGo]gfD0_oFViL6okn=X@03olfMYOo2
UZWo`YJY00Co`YJY1oo5W[000oo1WK?oajFfolNU]P05olNU]P03olBT^Oo9Zk_obJ^k00CobJ^k00?o
aZZnolZ``Oo:/<401?o:/<400oo7/<?ob[G5olZea@04olZea@03olRdaoo;^LWobkW900CobkW900?o
b;W;olZmcOo:_Ld00oo:_Ld7olVod003ol_2d_o9`M?obL7C00?obL7C00?obLCDolS3eOo8`mD00oo8
`mD3olS4ePCoalCG0oo8aMP3olO5f004olO6fOl0003o0000o`0000;oa/GI0oo7a]T01?l0003oa/KJ
olK6f_o6a]X;olK7fPOoa/OK6?o6b=/2ooooo`03o`000?oooooooooo033ooooo000Zooooo`;o0000
1Oooool2ojVjiPGoZKST0onX]N800onU]>?oY;7QojBah@03ojBah@KoY:kO0_nSZmd2oinZg`GoWZOL
1?nMY=X5oi^Pf0CoVYcE0_nGV=<2oi6Ge@CoSY;C1On:SM04ohF6c@CoOh390omgMlH3ofm^`P04ogid
_OmbJ;WoLVRiog9X^@CoIUbc0omBBj/2ob<UV`;oH4VO0_l40X000olj8HOoR5B=ohQDS@07ohI?R0Co
[G>B1OngOI@2omJKU`Go_hfQ0_o=WJD6ol:FZ@03ol^Q[?o5W[3oaIj`00CoaIj`2?o7YKH7olV[^`Oo
b[311oo:]LD6ol^ib@03olfnc?o:_Lgob[g=00?ob[g=0_o<`<l5olVod0?obl;B0oo9`M<3olW4e0?o
b<?E1?o8a=H3olO4e`Gob<GH0ol00003olO6f@03olK5fOo7a]WoalKI00?oalKI00?o0000olK6f_o6
amX02oo6amX5olK7fa_oa/SK00?oooooo`000?ooool0<Oooool002[ooooo0ol00002ooooo`GoZK[V
1OnY^>@01?nX]N;oYKCSojFdhonU]><5ojBah@CoY:kO00?oX:gQoinZgonOZ]l00onOZ]l5oijWg0Co
WJCJ0_nKX=P2oiJOfPCoU9_H1OnAUmD4ohjBd`CoRXg@1?n5Q/d4ogn0b@CoMgO60om_K/82oeiP_0;o
LVRi0omVG;<4oe9;Z`03ob<UVomPBIooH4VO00;o10:000?o>R67ohQDSOn8E8d01on6ChP4ojecTPGo
]gfD0_oFViL5okn=X@;ocIfU1Oo2UZT2ol^Q[0KoaIj`00?oc:JcolNU]_o7YKH01Oo7YKH00oo=[;Wo
bJ^kolV[^`04olV[^`03olfa__o:/<7ob[3100?ob[310_o>]/<5olZea@;ocK[81?o;^LT3olfnc0?o
b[g=1?o<`<l3olVod0Gobl;B00?obL7ColW4e?o9a=@00oo9a=@00oo8`mGob<CFolS4eP04olS4eP04
olO4eoo8aMSob<GHolS5f0?o00001Oo7a]T00oo7amWoalKIolO6f@04olO6f@03olO7f_l0003oa/OJ
00?oa/OJ0_o7amX7olK7fP?oa/OK7Oo6b=/00ooooooo0000ooooo`0`ooooo`00:_ooool00ol0003o
ooooo`000003ojVmj0GoZK[V0_nY^>@2ojFgi@GoYKCS1OnT/N400onT[]ooX:gQoj2]h@02oj2]h@Go
Wj[O1OnNYm`2oifTfP03oiRSg?nFWm[oUYoJ00?oUYoJ1?nDVmP5oi6Ge@CoSY;C1?n:SM04ohF6c@Co
Oh390omgMlH4ofm^`P?oGV2l1?mVG;<3oe9;Z`;o8bFK00?oH4VOo`@2P?l40X000_lj8HL00on8E8go
QTn8ohI?R005ohI?R0Co[G>B1OngOI@2omJKU`Co_hfQ1?o=WJD4ol:FZ@;obj6/1Oo5W[02olbV/`Ko
ajFf0_o=[;T5olV[^`;ocK6n1?o:/<43oljf``Cob[G50oo=^/P3ol^ib@GocKk<00?ob[g=olc0coo<
`<l01?o<`<l00oo9_m3obl;Bol_2dP03ol_2dP03ol_5e?o9a=CobLCD00CobLCD00?ob/GFolS4e_o8
a=H00oo8a=H00oo9a]Oob<GHo`000002o`000004olS5f?o8a]Sob<KHolS6f0?oalKI0oo7amT3olO6
f@?oalOJ00Co0000olK7f_o6am[oa/OJ1?o7amX7olK7fP03olK7foo6b=_oa/SK01goa/SK00?ooooo
o`000?ooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`04oooool002[ooooo00?o0000ojVmj?nY_NP01?nY_NP2ojVjiP?oYK[W1?nU
]nD5ojFdh`;oY;7Q0onQ/><5oj2]h@GoWj[O0_nNYm`2oiVVgPCoV:?L1OnFWmX4oiBKf0CoTIOE1?n>
T]<4ohZ=d0CoQHK=1?moP<T4ogMgaP?oKfk20omNH;`2od]@]P;oIUbc0omBBj/3ob<UV`;o10:00_lj
8HL00on8E8goQTn8ohI?R004ohI?R0Go[G>B1?ngOI@3omJKU`Co_hfQ1?o=WJD3ol:FZ@Cobj6/1?o5
W[03olbV/`CoajFf0oo=[;T4olV[^`?ocK6n0oo:/<44oljf``?ob[G51Oo=^/P00oo;^LWocKk<olfn
c004olfnc0Koc<3?00?ocLCAol_2d_o;`]800oo;`]83ol_5e0CobLCD0oo:aMH3olS4eP?o00000oo8
aMP5olS6f003olO6fOo7amWoalOI00?oalOI00?oalKIolO7f_o7amX00oo7amX00ol0003oa/OJolO7
fP04olO7fPKoa/OJ00?oalSKolK8foo6b=/07oo6b=/00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Cooooo`00
7oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01?nY_NP2ojJlj@Go
YK[W1?nU]nD2ojFdh`?oXK?U1OnQ/><5oj2]h@;oWj[O0_nKZN45oiVVgPCoV:?L1?nFWmX5oiBKf0Co
TIOE1?n>T]<4ohZ=d0CoQHK=0omoP<T4ogMgaPCoKfk20omNH;`3od]@]P?oDT^[0olS9I/2o`@2P0;o
>R6700?oR5B=ohI?R?n6ChP01?n6ChP5ojecTPCo]gfD0ooFViL3okn=X@GocIfU0oo2UZT4ol^Q[0?o
aIj`1?o<Y[<3olNU]PGocJbi0_o9Zk/5olfa_P03olZ``Oo>]/?oc[K300Coc[K300?ob[G5olfjb?o=
^/P01?o=^/P6olfnc0;oc/;>1?o<`<l3olg4d@?obl;B1?o;aM@3olW4e0Cob/GF0ol00004olW6e`03
olS5f?o8a]Sob<KH00?ob<KH00?ob<OIolO7fOo7amT00oo7amT8olO7fP03o`000?o7am[oalOJ00Co
alOJ0oo6amX4olO8fb3oa/SK00?oooooo`000?ooool01_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Cooooo`007oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0ol000000oooooooZKgXojJlj@04ojJlj@GoYK[W0_nU]nD2oj6fi`GoXK?U1OnQ/><2
oj2]h@;oW:cS1OnKZN44oiVVgPGoV:?L1?nFWmX2oiBKf0;oSY[J1?n;UMP4ohN@ePCoPX_C1?mlQ=03
ogAmc@04ogn0bOmgMlKoMgO6ogMgaPCoKfk20omNH;`3od]@]P03obdi[?mBBj_oDT^[00?o8bFK0_l4
0X03ocXQQ`KoQTn81On]Li84okMmU0CoeY^G0_noSJ46olfMY@03ol:FZOo;XJcobj6/00?obj6/0_o5
W[06olbV/`03olNU]_o=[;WocJbi00CocJbi00?obJ^kolfa__o=/Kh01?o=/Kh7oljf``OocK[800?o
d;o:olfnc?o=_/`00_o=_/`3olk2cP?oc<3?1Oo=a=400oo;`];oblGDol_5e004ol_5e004olW4e?o:
aMKob/GFol[5eP;o000000?ob/OGolW6eoo9a]L00oo9a]L00oo9amSob<KHolS6f003olS6f0?ob<OI
0oo7amT9olO7fP03o`000?o7am[oalOJ00GoalOJ00?oa/OJolO8foo7b=/01?o7b=/;olK8f`03olO8
foo6b=_oa/SK01;oa/SK00?oooooo`000?ooool01Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@0Cooooo`007oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool00_ooool6ojJlj@;oYK[W0_nR^NT5oj6fi`GoXK?U0_nQ/><3oib_
i@CoW:cS1?nKZN45oiVVgP;oV:?L0_nCX]h4oi6Ng0GoSY[J1?n;UMP4ohN@ePCoPX_C1?mlQ=03ogAm
c@?oJG?:00CoMgO6ofm^`_m_K/;oKfk20omNH;`4od]@]P03obdi[?mBBj_oDT^[00;o8bFK0_l40X03
ocXQQ`?oQTn80_n9F946ojecTP?o]gfD1OoFViL00onoSJ7ocIfUolfMY@05olfMY@03ol:FZOo;XJco
bj6/00Cobj6/00?oaIj`olbV/oo<Y[<01?o<Y[<7olf/^@OocK6n00?odKO1oljf`oo>]/<01?o>]/<0
0ooA^lKocK[8olfjb003olfjb0;od;o:0oo=_/`5olk2cP03olc0coo=a=7ocLCA00CocLCA1_o;aM@0
0oo<amGob/GFo`000002o`000004ol[5e_o:amOob/OGol[7e`?obLKG0oo9amP3olS6f0Gob<OI00?o
alOIolO7f_o7amX02Oo7amX00ol0003oalOJolO7fP03olO7fPSoalSK1Oo6b=/2olO8f`?oa/SK0oo7
b=/DolK8f`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`04oooool001oooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00?ooooo1?nV_>T2oj:kj`CoX[WY1OnQ]^L2oj6ci@?oWK;V1OnL[nD4oib/h`Co
VjWQ0_nIY]h2oiFUh@GoTj;N1?nAW]`5ohjJfPCoRiGH0on7T=H4oh:;d`CoO8C@1?mdOLd3ofUcbP?o
GVW600CoKfk2oeiP_?mNH;coGV2l0om;D;H2obdi[005oe9;ZolS9I_o8bFKob<UVol40X000olj8HL5
ohUHT@Ko[G>B0ongOI@5omJKU`03okn=XOo=WJGocIfU00GocIfU1oo;XJ`7olbV/`03om6^]_o=[;Wo
cJbi00CocJbi00?odK:kolfa__o=/Kh00oo=/Kh3om6g`@Coc[K30ooA^lH3olfjb0Cod;o:00?ocKk<
olk2c_o>`/h01?o>`/h00oo@aM3ocLCAolg4d@03olg4d@;oc/KC0oo;aM@01?o<amGo0000o`000?l0
0003ol[5ePGob/OG00?obLKGolW7f?o9amP00oo9amP00oo8a]Sob<OIolS7f@03olS7f@03olS8f_o7
am[oalOJ00?oalOJ00?oalSJolO7f_o7amX01?o7amX00oo7b=[o0000olO7fP02olO7fP[oalSK0oo6
b=/4olO8f`03olK8foo7b=_oalSK00?oalSK4oo6b=/00ooooooo0000ooooo`04ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Eooooo`007oooool01Ol0003ooooooooo
oooooooo000000Gooooo0_l00005ooooo`03ojJljOnR^n_oX[_[00?oX[_[1?nR^NT2oj6fi`?oWKGX
1OnM/^H5oib_i@CoW:cS0_nKZN400onFZ>;oUJGQoiFUh@03oiFUh@GoTj;N1?nAW]`4ohjJfPCoRiGH
0on7T=H4oh:;d`CoO8C@1?mdOLd4ofUcbP?oGVW60_m:FL001?mNH;coBe2fod]@]_m;D;H3obdi[0?o
8bFK00Co10:0ocXQQolj8HOo>R671On9F946ojecTP?o]gfD1OoFViL8olfMY@Oobj6/00?odJV`olbV
/oo<Y[<00oo<Y[<2om6^]PGocJbi0ooA/[/3olfa_PCodKO10oo>]/<5om6kaP03olfjb?o@_l[od;o:
00?od;o:00?odLC=olk2c_o>`/h00oo>`/h3om35d0?ocLCA1?o>a]<3o`0000Coc<OE00?ob/GFol[7
eoo:amL00oo:amL00oo:b=SobLOHolW7f003olW7f003olW8fOo8amWob<OI00?ob<OI0oo8b=X3olO7
fP?oalSJ0oo7amX4olO8fP03o`000?o7am[oalSK00_oalSK00?oa/SKolO8foo7b=/02Oo7b=/5olK8
f`;oalSK3Oo6b=/2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH01Gooooo000Oooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`06
ooooo`GoX[_[0_nR^NT2oijgj`GoWKGX1OnM/^H2oib_i@;oV:kV1?nGZn@4oiJXhPGoUJGQ1OnCX]h4
oi6Ng0CoSY[J1?n;UMP3ohN@ePCoPX_C1?mlQ=03ogAmc@CoJG?:0omNJLH3odYI`0CoBe2f0_l]>J`3
ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B0_ngOI@5omJKU`03onR`V?o=WJGocIfU00CocIfU0_oFZJT5
ol^Q[0;odJV`1?o<Y[<4om6^]P?ocJbi1?oA/[/3olfa_PGodKO100?oc[K3om6ka_oA^lH00ooA^lH0
0ooC`LSod;o:om2obP03om2obP?odLC=0oo>`/h5om35d003olg4dOo>a]?oc/KC00?o000000?oc/WE
olc7eOo<amD00oo<amD00oo<b=Oob/OGol[7e`03ol[7e`?ob/SH0oo9amP3olW8f@?ob<OI1Oo8b=X0
0oo7am[oalSJolO8fP03olO8fP03olO7f_o7b=[oalSJ00?oalSJ00?o0000olO8foo7b=/06?o7b=/3
olK8f`CoalSK3?o6b=/00ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool01?o<c<coA4A4o`000?l@410Cooooo`007oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool01oooool2oj:kj`?oWK[]1?nN]n/5oifej0;oWK;V0_nI/NP5oiR^iPCoUj_T
1?nFZ>85oiFUh@;oTj;N0_n>XN44oh^Mg`CoR9WM1?n4U=/3ogn?f@CoNHWG0omaP]@00omlQ=3oM7g=
ogAmc@02ogAmc@?oJG?:1?mNJLH3odYI`0?oBe2f0ol]>J`2ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B
00?o]gfDomJKUooFViL01?oFViL00ooX/9SocIfUolfMY@04olfMY@;oeZVY1?o;XJ`3om6Y/0?oc:Jc
1OoA[[H3olf/^@GodK:k00?ocK6nom6g`OoA]l401?oA]l45om6kaP?odl780oo@_lX5om74c@03olk2
c_o@aM3od<G@00?od<G@00Cod<WCo`000?l0003o00000_o>a]<3olk9e@?oc<OE0oo<b=L3ol[7e`Go
b/SH00?obLOHolW8fOo9b=T00oo9b=T00oo8amWob<SJolS8fP04olS8fPgoalSJ00?o0000olO8foo7
b=/06?o7b=/00oo6b=_oalSKolO8f`03olO8f`goa/SK00?oooooo`000?ooool0:_ooool001oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo1OnM^^d4oijgj`;o
WKGX0onI/nX4oiVaj0CoV:kV1OnGZn@4oiJXhP;oUJGQ0_n@Y><5ohjQh@CoRigO1?n8VMd4ohBDf`?o
OhoI1?miRML3og62e0?oJ7[B00?oM7g=ofUcb_mYLlX00_mYLlX3oeiYaP?oBUW00_l`A[P01?m;D;Ko
;CV/obdi[?l]>J`2ob<UV`;o10:00_lj8HL5ohUHT@Oo[G>B00?o]gfDomJKUooFViL00ooFViL2onR`
V0GocIfU0ooFZJT4ol^Q[0CodJV`0_o<Y[<6om6^]P03olf/^OoA/[_odK:k00CodK:k1_oA]l42omBm
``?odK_61OoC`LP00oo@_l[odLC=om74c@03om74c@03om?8d?o@aM3od<G@00;od<G@0ol000001?o@
bM?oc/KColk6doo>a]<5olk9e@03olc7eOo<b=Ooc<SG00?oc<SG00?ob/OGol[8f?o:b=P00oo:b=P0
0oo:bMWobLSIolW8f@03olW8f@?obLSJ1_o8b=X=olO8fP03o`000?o7b=_oalSK01koalSK3Oo6b=/0
0ol0003oooooooooo`0Yooooo`00:?ooool3o`0000[ooooo1OnM^^d2oijgj`;oVKK/1OnI/nX4oiVa
j0CoV:kV0_nGZn@2oi>ZiPGoTJOT1?n@Y><4ohjQh@CoRigO1?n8VMd4ohBDf`CoOhoI1?miRML3og62
e0?oJ7[B0omKL<h01?mYLl[oGVW6oeiYa_mNJLH3odYI`0?o<4Jh00OoBe2fobdi[?l]>Jco00NBob<U
Vol003?o10:000;o>R671On9F947ojecTP03okMmU?oFViOoeY^G00?oeY^G0ooX/9P4olfMY@?oeZVY
0oo;XJ`5om6Y/003olbV/ooA[[KodJjf00GodJjf1ooA/[/00ooE^KkodKO1om6g`@02om6g`@Coe;g3
00?odK_6om?1b?oC`LP01?oC`LP5om74c@?odlS@0ol00005om39d`03olk6doo>bMGoc/WE00?oc/WE
00?ocL_Golc8eoo<b=L00oo<b=L3olc:f0?ob/SH0oo:bMT3olW8f@GobLSJ1_o8b=X<olO8fP03olO8
fol0003oalSK01ooalSK2oo6b=/00oo6b=coooooo`00000Zooooo`00:?ooool00ol0003ooooooooo
o`0;ooooo`;oWK[]0_nI^Nh5oiVfk0GoVK?Z1?nI/NP2oiR^iP;oU:gX1?nCZ^H5oi6Wi0CoT:CS1?n>
XN44oh^Mg`CoR9WM1?n4U=/4ogn?f@?oNHWG1?maP]@3ofQjdP?oFg3>0_m<I<X2oeiYaP?oBUW00ol`
A[P3obdi[003o`07T_lS9I_o10:000;o>R671On9F947ojecTP03okMmU?oFViOoeY^G00?oeY^G0ooX
/9P3olfMY@GoeZVY0_o;XJ`5om6Y/0SodJjf00?oeKBiom6b^ooA/[/00ooA/[/2omFi_P?odKO11OoD
_L<7om?1b004omG6booAa<godLC=om74c@;odlS@0_l000000ooCb=3od<G@om39d`05om39d`Goc/WE
0oo=bmL3olc8e`Goc<[H00?ob/SHol[9fOo:bMT00oo:bMT00oo9b=WobLSJolW8fP03olW8fP03olS9
f_o8b=[ob<SJ00Cob<SJ2oo7b=X2olO8f`03o`000?o7b=_oalSK01goalSK1_o6b=/2olK8g0?oa/SK
0oo6b=`00ooooooo0000ooooo`0Xooooo`00:?ooool00ol0003oooooooooo`0<ooooo`CoVKW^1OnI
]^`2oiVcjP?oUK;[0onE/>T5oiB]j0CoTj[V1OnAYn@4oi2Th`;oSZ7Q00?oRJ3SohJLh_n6W>800_n6
W>84oh:Hh0CoOI?N1?mhS]`3og68f`04ogV9eomaP]CoLH;Dog62e0CoJ7[B0omKL<h3odaTbP?oBUW0
0ol`A[P01_l;:Z_o;CV/obdi[?l01i;o8bFKo`@2P0?o>R671?n9F947ojecTPKoeY^G0ooX/9P3olfM
Y@GoeZVY00?obj6/om6Y/?oAZK001?oAZK000ooG/K?odJjfom6^]P04om6^]P;oeKBi1?oA/[/4omFi
_P03om6g`OoD_L?oe;g300Coe;g300?oel?7om?1b?oC`LP00ooC`LP3omG6b`04om74cOl0003o0000
o`0000?odlS@00?odlcBom39doo@bM<00oo@bM<2om3;e@?oc/WE1Oo=bmL00oo<b=Ooc<[Holc:f003
olc:f003ol_:fOo:bMWob/WI00?ob/WI00?obLWJolW8f_o9b=X00oo9b=X3olS9fPKob<SJ2Oo7b=X4
olO8f`03o`000?o7b=_oalSK01_oalSK1_o6b=/4olK8g003olK8foo6b=coa/SL00?oa/SL00?o0000
ooooooooool09oooool002Sooooo0_l0000>ooooo`CoVKW^0_nI]^`3oiFek@GoUK;[0onE/>T5oiB]
j0CoTj[V0_nAYn@2ohfViPCoRj?U1?n9X><4ohJLhPCoPYSP1?mmTmh4ogR>g0?oLHSK0omXPMP01?ma
P]CoJ7[BofQjd_mXN]83oe]`cP?oC6C:0_leDl@01?m:FL3o<4Jhoc16^?l`A[P2o`/ZZ`04obdi[?l0
1i;o00NBo`@2P0?o>R671?n9F947ojecTPGoeY^G1OoX/9P00oo=WJGoeZVYomJYZ@04omJYZ@KodJV`
0_oG/K<5om6^]P?oeKBi0ooA/[/5omFi_PKoe;g30ooG`lL3om?1b0;oeLK;0ol00005om?8d0?odlcB
0oo@bM<4om3;e@03olk9eOo=bmOocL_G00CocL_G1Oo<b]P3ol_:f@?ob/WI0oo9bMX3olW8fPGob<WJ
1_o8b=X6olO8fPOoalSK00?o0000olO8foo7b=/06Oo7b=/6olK8f`Coa/SL00?oa/WLolK8g?o6b=`0
1?o6b=`2o`0002Sooooo000Xooooo`03o`000?oooooooooo00kooooo0_nI^Nh2oiFgk`GoUKG]1OnE
/^/3oiF`j@;oU:gX0on@[>T4ohnYj0CoSJKV1?n;XnD4ohVPh`CoQYcR1?n2V>04ogfCgPCoN8kL0oma
R=/3ofR1f0?oGGSF00CoJ7[Boe]`c_mKL<koFg3>0om<I<X2ocECa004odYI`?l`A[So<4Jhoc16^0;o
2bZ[00?o;CV/o`07T_l40X000olj8HL4ohUHT@Oo[G>B1OoFViL5onR`V003olfMYOoFZJWoeZVY00Co
eZVY00?of:f]om6Y/?oAZK000ooAZK03omNa/`?odJjf1OoE];T00ooA/[_oeKVnomFi_P04omFi_P03
omRo`OoD_L?oe;g300;oe;g31OoG`lL01?oC`LSo0000o`000?l00002omG6b`;oel_?0ooCb=05om?<
dP03om39doo@bmGod<_E00?od<_E00?oclgGolg;eoo=bmL00oo=bmL2olg<f0?oc<[H1Oo;b]T00oo:
bMWobLWJolW9fP03olW9fP03olW8f_o8bM[ob<WJ00Cob<WJ1Oo8b=X00oo7b=_oalSJolO8fP03olO8
fPSoalSK00?o0000olO8foo7b=/05oo7b=/00oo7bM_oa/SKolK8f`03olK8f`;oa/WL0oo6b=`3olK9
g0Koa/SL00?oooooo`000?ooool09_ooool002Oooooo00?o0000ooooooooool04?ooool4oiFgk`Go
UKG]0_nE/^/2oi6ak@CoT:o[1On@[>T4ohnYj0?oSJKV1On;XnD4ohVPh`CoQYcR1?n2V>04ogfCgP?o
N8kL0omaR=/4ofR1f0?oGGSF0_m=KM801?mKL<koC6C:odaTb_m<I<X3ocECa0?o<4Jh0ol;:Z/00ol0
1i;o000cocXQQ`02ocXQQ`CoRERA1_n]Li800ooAV9SoeY^GomJKU`03omJKU`Goj;2H1_oFZJT2omR]
[@CodJV`1?oG/K<3om6^]PGoeKBi1_oE^Kh3omRo`@?oe;g30ooG`lL3o`0000CoeLK;1?oGbll00ooC
b=3odlcBom?<dP03om?<dP03om?>eOo@bmGod<_E00?od<_E0oo?cML3olg;e`CocLcH00?oc<[Hol_:
fOo;b]T00oo;b]T00oo:bm[obLWJolW9fP03olW9fP;obL[J1oo8bMX3olS8fP?oalSK0oo7b=X:olO8
f`03o`000?o7b=_oalSK013oalSK00CoalWKolO8foo7b=_oalSK1?o7bM/3olK8f`Coa/WL00?oa/SL
olK9g?o6bM`00oo6bM`6olK8g003o`000?oooooooooo02Gooooo000Wooooo`03o`000?oooooooooo
017ooooo1?nE]nl2oiFek@?oTK?^1?nA/Nd4oi2_j`GoT:cY1?n?ZNP3ohfViP;oRj?U0_n6XnL4ohBO
i@CoP9cT1?mlV><4ogNCh@?oL8kP00?oN8kLog68fomaR=/01?mXPMP4oeeheP?oCFgB0om<I<X2ocEC
a0;o5Sfj00Ko<4Jho`/ZZol;:Z_o2bZ[o`07T_l003<3ocXQQ`CoRERA1_n]Li82om6HV0CoeY^G1OoX
/9P6omJYZ@?of:f]0ooAZK05omNa/`03om6^]_oE];WoeKBi00CoeKBi00?ofK^lomFi__oE^Kh00_oE
^Kh5omRo`@03omBm`ooG`lOo000000;o000000?oel?7omW9b_oIbLX00ooEa//5omO;c`GodlcB0ooC
c]D3om3;e@GoclgG00?ocL_Golg<f?o=c=P00_o=c=P00oo<c=[obl[Iol_:f@03ol_:f@?ob/_J0oo9
bMX4olW:fPOob<WJ00?ob<SJolO8foo7b=/00oo7b=/00oo7b=[oalSKolO8f`0:olO8f`03o`000?o7
b=_oalSK00goalSK1?o7bM/00oo7b=_oalWKolO9f`04olO9f`03olK8foo6bMcoa/WL00Woa/WL1_o6
b=`00ooooooo0000ooooo`0Uooooo`009oooool3o`0001;ooooo1OnA]_04oi6ckPCoTK7]1?n@[n/2
oi2/j@;oRj_[1?n:ZNT4ohRVj0CoQZ?W1?n4WnD4oh2Li0CoO9SS1?mgTn43og2>h0?oJ8SN0omXPMP4
oeeheP?oCFgB0_lkH<d01?m<I<[o=E?4ocECa?leDl@2oaHm^P05oc16^?l;:Z_o2bZ[o`00SOl01i80
0olj8HL5ohUHT@Go[G>B0_oAV9P3omJKU`Koj;2H00?olKjKomJYZOoFZJT00_oFZJT4omR][@;odJV`
1_oG/K<6omFd^@?ofK^l0ooE^Kh4omRo`@?o00000ooG`lL4omW9bP03omG6booGblooel_?00?oel_?
0_oGd=83om?<dPGodlkE00?od<_Eolo=eoo?cML00oo?cML2olo>f@?ocLcH0oo<c=X3ol_:f@Gob/_J
00?obLWJolW:f_o9b]X00oo9b]X6olS9fP03olS9foo7b=_oalSK01;oalSK00?o0000olO8foo7b=/0
2oo7b=/;olO9f`03olO9g?o6bMcoa/WL00_oa/WL1_o6b=`00ooooooo0000ooooo`0Tooooo`009ooo
ool00ol0003oooooooooo`0Cooooo`GoTKK`1?nA/nh2oi6ak@;oSK3^1?n<[^`4oh^[j`CoRZWY1?n8
Y^P4ohJSi`CoQ9oU1?n0W>@3ogbHh`CoMi?Q1?m`S^02ofR8gP?oGX3L00CoJ87Hoeehe_mMN=KoGGSF
1?m=KM83oc]Pc@;o=E?40olF?KX3o`/ZZ`04o`07T_lj8HOo>R67ocXQQ`GoRERA1?n]Li83om6HV0?o
eY^G1OoX/9P2oo6nV`?oeZVY1_oH[Jd00ooAZK3oek6comNa/`04omNa/`03omZg]_oE];WoeKBi00;o
eKBi1OoI^k`00ooE^Kkof;o1omRo`@03o`000003omRo`OoKa/Coel?700;oel?71OoIbLX5omO;c`Co
em3B00?odlcBom?>eOoCc]D00ooCc]D2om;@f0?oclgG1Oo?c]T00oo=c=Soc<cJolc<fP03olc<fP03
ol_:fOo:bm[ob/_J00?ob/_J00?obL_KolW:f_o9b]X00oo9b]X2olS9f`?ob<WJ1?o8bM/ColO8f`03
o`000?o7b=_oalSK00WoalSK2oo7bM/4olO9g0coa/WL1Oo6b=`00oo5b=coooooo`00000Uooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05?ooool2oi6fl0?oS;Ca0on=/^l5ohf`
kPCoS:k/1?n;Zn/4ohZYj@CoR:KX1?n6XnL4ohBOi@CoP9cT0omlV><3ogNCh@CoL8kP0omXR=h3oej0
g0?oDGOJ00CoGGSFode]d_m=KM;oCFgB0olkH<d2ob5>aP03ocECa?lF?K[o5Sfj00?o2bZ[00Co002=
ocXQQolj8HOo>R671On9F944ojecTP?odIRH0ooFViL5onR`V0;olKjK0ooFZJT6omR][@Koek6c0_oJ
]kH3omFd^@KofK^l00?of;o1o`000?l000000ooH_l43om_6a003omO3aooIbL[ofLW:00?ofLW:0_oK
clh3omO;c`Goem3B1OoCc]D4om;@f003olo=eoo?c]WoclkI00?oclkI00?ocLkJolc<f_o<c=X00oo<
c=X3ol_<f`?ob/_J0oo9bm/3olW:fPCob<WK00?ob<WJolS9foo8bM/01?o8bM/ColO8f`03o`000?o7
b=_oalSK00OoalSK2oo7bM/5olO9g0goa/WL0oo6b=`3olG8g003ooooool0003ooooo02?ooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000Gooooo`CoS;Ca0on=/^l5ohf`kPCoS:k/
1?n;Zn/2ohZYj@;oQZS[1?n4YNX4oh:Rj@?oOioW1?mkW>H3ogJHi@?oL9?T00?oMi?Qog2>h?m`S^00
0_m`S^03ofR8gP?oGX3L0omAMmX2od1/eP03ode]d_lkH<go>f3=00;o>f3=0_lQC/H3oaHm^P;o2bZ[
00Co002=o`00D?lj8HOo>R671On9F944ojecTP?odIRH0ooFViL5onR`V0?olKjK00?oeZVYomR][OoH
[Jd01OoH[Jd00ooL][7oek6comNa/`02omNa/`Cof[Nf00?oeKBiomVk_?oI^k`00ooI^k`3o`0000Co
f;o11?oKa/@5omW9bPCoflo>00?oel_?omO@d_oGd=800ooGd=82omKCeP?odlkE1OoBd=P5olo>f@?o
cLkJ0oo<c=X5ol_<f`03ol[;f_o9bm_obL_K00?obL_K00?obL[JolS9foo8bM/02Oo8bM/2olO9fa?o
alSK00?o0000olO8foo7b=/01Oo7b=/:olO9f`SoalWL3Oo6bM`00oo6b=coaLSLolG8g003olG8g003
ooooool0003ooooo02;ooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`CoS;Ca0on=/^l2ohf`kP?o
R:o_1?n8[Nh3ohN[k0GoQZS[1?n4YNX4oh:Rj@?oOioW1?mkW>H3ogJHi@CoL9?T0omYS^<3of28hP04
ofR8g_mNP=coGX3Loej0g0?oDGOJ0om0K=H3oc]Pc@?o8Dk60_lF?KX01?l08J[o2bZ[o`00SOl003<2
ocXQQ`GoRERA0on]Li84om6HV0;oeY^G1OoX/9P4oo6nV`03omJYZOoH[Jgof:f]00Cof:f]0_oL][43
omNa/`Gof[Nf0ooI^k`3o`000003omVk_?oL`[oog<:o00?of;o11OoKa/@01?oMcLSofLW:omW9b_oI
bLX5om_?cP;ofmCB0ooGd=84omKCeP03om?>eOoBd=Sod]3H00?od]3H0_o@dMX3olo>f@GocLkJ00?o
c<cJol_<foo;c=/00oo;c=/00oo:c=_obL_KolW;f`05olW;f`[ob<WK1?o7bM/ColO8f`03o`000?o7
b=_oalSK00;oalSK2oo7bM/:olO9g0_oa/WL00?oaLWMolG8g?o5b=`00oo5b=`00oo5b=goooooo`00
000Sooooo`001?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Wooooo1?n8/o84ohRal0CoR:o_1?n8
[Nh3ohN[k0GoQZS[1?n4YNX4oh:Rj@?oOioW0omkW>H4ogJHi@CoL9?T0omYS^<3of28hP?oEH3O00Co
GX3Loe5gf_mAMm[oDGOJ0_m0K=H2ob]Md004oc]PcOlQC/Ko8Dk6ob5>aP;o03Jj00Co5Sfjo`0QZ_l;
:Z_o002=0_lj8HL5ohUHT@?o[G>B1?oAV9P2omJKU`Goj;2H1?oa_Y/7omR][@;og;Ja0ooG/K<5omZg
]P?o00000ooI^k`4omc2_`03omRo`OoKa/CoflK400?oflK40ooMcLP00ooIbL[oflo>om_?cP04om_?
cP?ofmCB00?oem3BomKCe_oFdmH00ooFdmH2omCDf0?od]3H1?o@dMX00oo?c]WocLkJolg>fP03olg>
fP03olc>foo;c=_oblcK00?oblcK0oo:c=/7olW;f`Sob<WK1Oo7bM/ColO8f`04o`000?o7b=_oalSK
olO8f`_oalWK2_o7bM`00oo7b]coa/WLolK9g003olK9g0;oa/WM0oo6bM`3olG9g@?oaLSL0oo5b=d0
0ooooooo0000ooooo`0Qooooo`001?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06_oo
ool4ohRclPCoR;7`1?n8[nl4ohR]kP?oQj_/0_n6Z>/2oh:Wk0CoP:G[1?mmX^X3ogZOj@?oMYcX00?o
NicVogJHiOmfV>D00_mfV>D4og2Ci0?oJHkS0omPR>83oeF0g`;oAWOM00CoDGOJod1/e_m0K=Ko@6cF
0ol[GM03ob5>aP;o03Jj0_l08JX00ol008go001@ocXQQ`05ohUHT@?o[G>B1OoAV9P00ooFViOoj;2H
onR`V003onR`V0ColKjK00?oj;VSomR][OoH[Jd00ooH[Jd4ombf/@04omNa/ooJ]kKof[NfomZg]P?o
00000_oM_KT3omVk_0Gog<:o00?oglW2om_6a?oKa/@00_oKa/@4omg=b003on3EcOoKclkoflo>00?o
flo>1?oKe=85omKCePCoe=CH00?od]3Hom3Af_o@dMX00oo@dMX2oloAf`?ocLkJ0oo<c]/3ol_<f`Go
b/cK1_o9bm/6olS9f`KoalWK5Oo7b=/00ol0003oalSKolO9f`09olO9f`_oalWL0oo7b]`3olK9g0Co
a/WM00?oa/WLolG9gOo5bMd00oo5bMd00oo5b=coaLSMolG8g@03olG8g@03ooooool0003ooooo023o
oooo0004ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo0_l0000Looooo`CoR;?b0_n8/O02ohF`l@CoQ:k`0on4[>l4oh>YkPCo
PZO/1?n0YN/4ogfRjP?oNYoY1?mfW>P4og6Hj0?oJi?W0omSS^H01?mYS^?oH8SRof28h_mPR>83oeF0
g`?oAWOM0om0K=H2ob]Md0;o3d_800So8Dk6o`0f^_l0=[[o03Jjo`0QZ_l008go001@ocXQQ`GoRERA
0_n]Li86om6HV003omJKUooX/9Soj;2H00;oj;2H1?oa_Y/2onRiX`Cof:f]1OoL][401?oJ]kKo0000
o`000?l00002omZg]P?ogKfi0ooI^k`5omc2_`;oglW20ooKa/@4omg=b0;oh=G=0ooKclh4om_DdP;o
fMSF0ooFdmH4omCDf003om;Efoo@dM[od=7J00?od=7J1?o?dM/00oo=c][oc<kKolc>f`03olc>f`03
ol_<foo:c=_ob/cK00?ob/cK00?obLcLolW;foo9bm/00oo9bm/2olS:f`?ob<WK1oo7bM/GolO8f`03
o`000?o7bM_oalWK00OoalWK2oo7bM`5olO:g003olK9g?o6bMgoa/WM00;oa/WM00?oa/[MolG9gOo5
bMd01Oo5bMd4olG8g@03olC8gOoooooo0000027ooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Looooo`CoQ;7b1?n5/?44ohB^l0?oQ:c_1?n3ZNh4oh:Wk0?oP:G[1?mmX^X4ogZO
j@CoMYcX1?maV>P3of^Ci`?oHhkV0omIR>@01?mPR>;oEH3OoeF0gomEP=l2odIgg@?o<f_I00?o@6cF
ob]Md?l[GM000_l?BlP3o`0f^P;o026Z00?o001@ocXQQolj8HL01?n9F942ojecTPKodIRH1OoX/9P4
oo6nV`?oj;VS0ooH[Jd3ombf/@?o00001?oJ]kH5omfm^@03omVk_?oL`[oog<:o00?og<:o1?oObL80
0ooKa/CogLg8omg=b002omg=b0Coh=G=00?oflo>om_Dd_oKe=800_oKe=84omWHeP03omKCe_oDe=So
e=CH00;oe=CH0ooBeM/3om3AfPCocm7K00?ocM7Lolc>foo<c]/00oo<c]/2ol_>g0?ob/cK1?o9c=`3
olW;f`Cob<[K00?ob<WKolO9foo7bM/01Oo7bM/IolO8f`03o`000?o7bM_oalWK00GoalWK2_o7bM`6
olO:g0;oa/[M0oo6bMd3olK:g@OoaLWM00?oaLSMolC8gOo4b=d00_o4b=d00ooooooo0000ooooo`0O
ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`CoQ;7b1?n5/?44ohB^l0?oQ:c_1?n3
ZNh4oh:Wk0?oP:G[1?mmX^X4ogZOj@CoMYcX1?maV>P2of^Ci`CoHhkV0omIR>@3odf0h`03oeF0gom6
MmgoAWOM00?o<f_I0_lKFm800ol[GM3o3d_8o`m;b003o`0f^P04o`0QZ_l0053o>R67ocXQQ`CoRERA
0_n]Li86om6HV0Goj;2H1?oa_Y/3onRiX`;of:f]00Gog;Jao`000?l0003o0000ombf/@03omjk]0?o
f[Nf1OoM_KT5omc2_`GoglW21?oMcLP5on3Ec@04on3KdOoKe=;ofmCBom_DdPGofMSF00CoemWIomCD
f?oDe=Soe=CH1OoBeM/00oo@dM[ocm7KoloAf`02oloAf`?ocM7L0oo<c]/4ol_>g003ol[<foo9c=co
bLcL00CobLcL00?obL_KolS:foo8b]/00_o8b]/9olO9faWoalSK00?o0000olO9foo7bM/01?o7bM/5
olO9g0;oal[L0oo7bM`6olO:g0Coa/[M00?oa/WMolK:gOo6b]d00oo6b]d5olG9g@03olG9g_o4b=go
a<SM00;oa<SM00Coa<SNo`000?oooooo00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00_ooool002Kooooo00?o0000ooooooooool0
7_ooool2ohBalP;oP;3c1?n1[_83oh6]l@CoP:_`1?moZNl3ogjWkPCoO:C]1?miX^`4ogJOj`?oLYc[
1?m]V>X3ofJDj@?oHhkV1?mIR>@3odf0h`;o?GOP1?lcJmT2oa]KdP;o3d_800Co03:io`0f^_l0=[[o
01RW0_l005000olj8HOoRERAohUHT@02ohUHT@03ojecT_oAV9SodIRH00GodIRH00?okk^KonR`V?oX
/9P00_oX/9P3oo6nV`Goj;VS0_l00004ombf/@?og[^d0_oJ]kH6omfm^@04on74_?oL`[oog<:oomc2
_`KoglW200Coh]36omg=b?oMcLSogLg81?oPeLd3on3Kd@03om_Dd_oIf=KofMSF00?ofMSF0ooGfMT0
0ooDe=Sod]GKom;Ef`03om;Ef`;od=GM0oo?dM/5olgAg003olc>foo;c]coblkL00;oblkL0_o9cMd5
olW<g0;ob<_L0oo8b]/;olO9faKoalSK0oo7bM/00ol0003oalWKolO9f`04olO9f`?oalWL1?o7b]`0
0oo7bMcoal[LolO:g004olO:g0Coa/[M00?oa/_MolK:gOo6b]d00oo6b]d01?o6b]koaLWMolG9gOo5
bMd4olG9gP;oa<SM0oo4b=h00ooooooo0000ooooo`07ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@02ooooo`009Oooool3o`00023ooooo
1?n0/?<4oh6^lP?oPJga1?n0Zo04ognYk`?oOZO^1?mlY>d4ogVRk0CoMYo[0ombW>/4offHjP?oIYCY
0_mNSnP01?mSS^KoFHSToeV8i?mIR>@4odf0h`;o?GOP0olcJmT3oa]KdP;o3d_800Ko03:io`0f^_l0
6:Oo01RWo`00D?lj8HL4ohUHT@03ojecT_oAV9SodIRH00GodIRH00Cokk^KonR`V?oX/9Soj;2H1?oa
_Y/2onRiX`?o00001OoL][45omjk]003omZg]_oM_KWogKfi00?ogKfi0ooQa;`00ooL`[ooglW2omo9
`P04omo9`P?oh]3600?ogLg8on3EcOoPeLd00_oPeLd4on3Kd@;ogMoF0ooIf=H4omOIf@;oe=[L0ooB
eM/4om3Eg@03oloAfoo=dMcocM7L00?ocM7L0_o;d=d3ol_>g0CobLgM0oo9c=`4olS;g003olS:foo7
bM_oalWK00WoalWK5_o7b=/5olO9f`03o`000?o7bM_oalWK00CoalWK00?oalWLolO:g?o7b]`02?o7
b]`2olO;g@?oa/[M0oo6bmd2olK:g@Coa/[N00?oaLWMolG9g_o5bMh00oo5bMh00oo4b=goa<SNolC8
gP03olC8gP03ooooool0003ooooo00Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000000_ooool002Gooooo00?o0000ooooooooool08Oooool4oh2`l`CoPJkb
0on1[O44oh2[l0CoOjW_0omnYnh4ogbTk@CoNJ;/1?mfWn/3og:Lj`?oKISZ1?mVU>T3oej?j0;oDhWW
00CoFHSTodf0hom=P>?oCH3S0olmMn000olXJm_o<f_Ioa]KdP02oa]KdP;o04S800Ko3d_8o`0b^Ol0
=[[o01RWo`00D?lj8HL4ohUHT@03ojecT_oAV9SodIRH00CodIRH0oo_^i/2onR`V0?olKjK0ol00003
onRiX`03onVmY_oL][7og;Ja00;og;Ja1OoN^k@5omfm^@CohLBl00?oi<^oomo9`_oObL800ooObL84
on;@aP04onGKbooPeLgoh=G=on3Ec@Goh=_A0ooMgmH00ooIf=KoemWIomOIf@02omOIf@Coe=[L00?o
d]GKom3EgOo@eMd00_o@eMd3olkDgP?ocM7L1?o;d=d00oo;c]cobLgMolW=g@04olW=g@03olW<g?o8
bmcob<_L00;ob<_L00?oal[LolO9foo7bM/02?o7bM/GolO8f`KoalWK00?o0000olO9foo7bM/00oo7
bM/;olO:g0Coal_M00?oa/[MolK;gOo6bmd00_o6bmd00oo6b]goa/[NolK:gP02olK:gP03olG;g_o5
bMkoaLWN00?oaLWN0_o4bMh4olC8gP;o`lSN00?oooooo`000?ooool01Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P02ooooo`009Oooool00ol0003ooooo
ooooo`0Rooooo`CoOJkc0omm[O84ogf/l@GoOJ[`0omlZ?03ogZVk`CoN:C^0omfX^d4og:Ok@CoKYc/
0_mXVN`00om]V>[oIYCYofJDj@02ofJDj@?oGXoX0omCRNL2odJ2i@04odf0holmMn3o?GOPocegh0;o
:6_K0olKFm82o`18b0;o03:i00?o01RWo`00D?l005000on9F9400onBKJGodIRHom6HV005om6HV0?o
kk^K0_oX/9P3o`0000Goj;VS0ooY_JH3ombf/@Gog[^d00CohL2gomfm^OoM_KWogKfi1OoQa;`2onC;
_`?oglW21?oRd<H3onGKb`03on3EcOoPfm7oh=_A00?oh=_A0ooMgmH2om[Pf`?oemWI1?oDf]`2om7I
gP?od=GM1Oo>e=h00oo=dMcobm3Mol_@g@03ol_@g@KobLgM0_o8c=d3olS;g0?oal[L2?o7bM/AolO8
f`03olO8f_o7b=_oalSK00?oalSK1Oo7bM/3olS9f`03o`000?o7bM_oalWK00coal[L1Oo7bmd4olK;
g@;oa/_N0oo6b]h3olG;gP?oaLWN1?o4bMh00oo4b=ko`lSNol?8gP03ol?8gP03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`00_oo
ool002Gooooo0_l0000Tooooo`CoOJkc0omm[O84ogf/l@GoOJ[`0omlZ?03ogZVk`CoN:C^0omfX^d4
og:Ok@CoKYc/0omXVN`3of:Ej`?oFY3[00CoGXoXoe>9iomCRNOoDhWW0om6P^D2ocEhh`05ocegh?lX
Jm_o:6_Ko`iJdolKFm800ol0B<P01Ol0<[Wo01FTo`00D?l0053oRERA00?oTVfU1ooAV9P2onnkV`?o
00000ooa_Y/5onRiX`?ojKfV0_oL][45omjk]0;ohL2g0ooM_KT4on74_0Coi<^o00?oglW2on;@a_oR
d<H00_oRd<H4onGKb`;oiN?A0ooPfm43omgOePCof^3K00?oemWIomCJg?oDf]`00_oDf]`4om7IgP03
om3EgOo>e=koc]CN00?oc]CN00?obm;Ool_@gOo;d=d00oo;d=d2olW>gP?obLgM1Oo8c=d00oo8bmco
al[LolO:g003olO:g0GoalWK3Oo7b=/2olO8fP?oalSK0oo7b=X3olO8f`GoalWK1Oo8bM/00ol0003o
al[LolO:g003olO:g003olS;g?o7b]coal[L00?oal[L2?o7bmd00oo6bmgoa/_NolK;gP03olK;gP03
olK:g_o5bmkoaL_N00?oaL_N00?oaLWNolC9g_o4bMh00_o4bMh00oo3b]oo`lSNol?8gP03ol?8gP03
ol;8gooooooo000000Gooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41000_ooool002Gooooo00?o0000ooooooooool09?ooool4ogf^l`?oOJgb1?mm[?42ogfZ
l0;oNZWa1?miZ?02ogNVl003ogZVkomhY>koN:C^00;oN:C^0omfX^d4og:Ok@CoKYc/0omXVN`3of:E
j`CoFY3[0_m?RnT01?mCRNOoAX;UodJ2iOm6P^D2ocEhh`;o7fcM00?o:6_Ko`iJdol>F]<00_l0B<P2
o`0_]`;o001@1OnBKJD5om6HV0?o00000_o_^i/4oo6nV`Goj;VS1?oY_JH00ooL][7og[^domjk]002
omjk]0CohL2g00?ogKfion74_?oQa;`00ooQa;`4onC;_`04onOD`ooRd<Koh]36on;@aPGoiM_;0ooU
hm401?oPfm7ogMoFomgOe_oMgmH5om[Pf`04omKPg_oDf]coe=[LomCJg0GodMWN1Oo>e=h3ol_Bg`?o
bm3M1?o9c]h00oo9cMgob<cMolS<g@03olS<g@03olO;g?o7b]coal[L00?oal[L0_o7bM`3olO9f`go
alSK1?o7b=X00oo7b=_oalSJolO8fP03olO8fP03olO8foo7bM_oalWK00;oalWK1_o8bM/2olS:f`03
o`000?o7b]coal[L00Cob<_L00?oal[LolO;gOo7bmd02?o7bmd00oo7c=koa/_NolK;gP03olK;gP;o
a/cN1?o5bmh2olG;g`?oa<WN0oo3b]l3ol?8gP?o`/SO0_l00004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000;ooooo000Uooooo`03o`000?oooooooooo
02Kooooo0omj[O<4ogZ/l`CoNZ_b0omjZO44ogVXl0CoMjK`0_meY>l4og:Rk`CoKio^1?m[WNh2ofFJ
kP04ofRIk?mRUN_oHYG[of:Ej`CoFY3[0_m?RnT3od64j003odJ2iOleN>?o=GSS00?o7fcM00Co3U[C
o`16aol0A/Oo04S80_l0;kL00ol0053oTVfUoi9]Y@03oi9]Y@;odIRH0ol00005onnkV`03oo_DW?oa
_Y_olKjK00Goj;VS1OoY_JH5omjk]0CohL2g00?oi<Jjon74_?oQa;`00_oQa;`5onC;_`;oimC300?o
h]36onGKbooUfl/00ooUfl/3onGSd@?oh^SG00?ogMoFom[PfooJh=/00ooJh=/3omKPgP03omCJg?oA
fMkodMWN00?odMWN0_o>en03olkDgPGobm;O00?obm3MolW>g_o9c]h00_o9c]h2olS=gP?ob<cM1?o7
bm`3olO:g0CoalWL00?oalWKolO8foo7b=/02oo7b=/<olO8fP?oalWK1_o8bM/3olS:f`03o`000?o7
b]cob<_L00Cob<_L1Oo7bmd2olO<g@?oal_M0oo7c=h3olK;gPCoa/cN00?oaL_NolG;goo5bml00oo5
bml00oo4bMko`l[Ool?:g`03ol?:g`03ol?8g_o2b=oo`/SO00;o`/SO00?oooooo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@02ooooo`00
9?ooool3o`0002Sooooo0omj[O<4ogZ/l`CoNZ_b0omjZO44ogVXl0CoMjK`0_meY>l4og:Rk`CoKio^
1?m[WNh2ofFJkP?oGiK]00?oHYG[oeZ@jomJT>/00_mJT>/2odn;j@?o@HCX0_l`NnD00oleN>?o7fcM
oam/g@02o`=Ke0;o04K70_l0;kL00ol0053oTVfUoi9]Y@02oi9]Y@?o00000ooAV9P4onnkV`;onmBL
0_oa_Y/5onRiX`GojKfV00CojKnYomjk]?oN^kCog[^d1OoQ`;L2onC6^P;ohLBl1OoTbkl3onOD``;o
jn?80ooUfl/3onGSd@Coh^SG0_oMj=`3om[Pf`?oe^3N0ooBg^43om7IgPCoc]OP00?oc]CNol_Bgoo;
d]l00oo;d]l2olW@g`?obLkN1?o8cMh00oo8c=goal_LolO;g004olO;g003olO:g?o7bMcoalWL00;o
alWL00?oa/SKolO8foo7b=/01?o7b=/00oo6am_oalSKolO8f`03olO8f`;oalOJ3Oo7b=X00oo7bM_o
b<WKolS9f`04olS9f`Cob<[K00?ob<_Lo`000?o8bm`01Oo8bm`3olO;g@CoalcM00?oal_MolO<g_o7
c=h00oo7c=h00oo6bmkoa/cNolK<gP02olK<gP03olG<goo5bmooaL_O00?oaL_O00?oa<_Pol?:goo3
b]l00oo3b]l00oo2b^3o`/SOol;8g`02ol;8g`;o`LSP00?oooooo`000?ooool06Oooool002Cooooo
00?o0000ooooooooool0:?ooool4ogN/m0CoMj_c0omgZ_84ogNXlPCoMZOa0omdY_43og:Tl0CoLZ;_
1?m_Wnh4of^MkP;oII[^0omOU^d4oeNBk@?oC8g/0om1Q>P3oc1ki@;o7fcM0_l3Fm@2o`16a`04o`0_
]ol0053o001@oi9]Y@;o000000?oTVfUom6HV?oAV9P00ooAV9P4onnkV`?onmBL00?olKjKonRiXooX
^J<00_oX^J<5onVmYP;ojKnY0ooN^k@4on70]`Coi<Jj00?ohLBlonC;_ooTbkl00_oTbkl4onOD``?o
jn?800CoiM_;onGSdOoUhm7oiN?A1?oRj=L4omgXg004om[PfooFh=koe^3NomKPgPGod]kQ00?odMWN
olkGh?o>en000_o>en02olcEh@?obm;O1Oo9d=l00oo9c]kob<gNolS=gP02olS=gP;oal_M1Oo7bm`2
olK9g0?oalWL0oo6b=/3olO8f`Coa/OK0oo7b=/4olO7fP_oalSJ00?ob<WJolS9foo8bM/01Oo8bM/3
olS:f`?ob<_L00?o0000olS;g?o8bm`01?o8bm`00oo7bmgoalcMolO<g@02olO<g@03olO=g_o7c=ko
alcN00?oalcN0_o6cMl3olK<gP?oaLcO0oo5bml3olC;h0;o`l[O1?o2b^000oo2b=oo`LSPol78h003
ol78h003ooooool0003ooooo01Sooooo000Tooooo`03o`000?oooooooooo02Wooooo1?mg[?@4ogN[
l`?oMj[b1?mgZ?84ogJWl@?oM:Ka1?mbY?03og2Rl0?oK:3_1?mXWNl3of>Kk`?oGiK]1?mGT^d3odb=
k0;o?XOZ00?o@HCXoc1kiOl`NnD00_lIK]l00olOK=go0e_Do`=Ke002o`16a`?o00000onBKJD4om6H
V0Gokk^K0ooke9`5onRiX`GojKfV0ooY_jT00ooN^kCohL2gon70]`03on70]`Coi<Jj1?oTbkl4onOD
``Cojn?80_oZk/h00ooUhm7oh^SGon;Xe`02on;Xe`CogNSL0ooHj>400ooFh=kod]kQom;Nh@03om;N
h@;oc]cS0oo>en04olcEh@03ol_Bgoo9d=oobM3O00?obM3O0_o7c]l3olS=gPCoal_M0oo7bm`4olK9
g003olO9g?o6b=_oa/SK00?oa/SK00?oalSKolK7foo6am/01?o6am/00oo7b=_oalOJolO7fP03olO7
fP[oalSJ0oo8bMX7olS9f`03olS:foo8bmcob<_L00?ob<_L00?o0000olS;g?o8bm`00_o8bm`2olS<
g@?oalcM0oo7cMh3olO<gPCoa/gO00?oa/cNolG<goo5c=l00oo5c=l00oo5bmooa<_PolC;h002olC;
h003ol?:goo2b^3o`/[P00;o`/[P00?o`L[Qol78h?o1b>000oo1b>000onob>7oooooo`00000Ioooo
o`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Zooooo`CoMjcd1?mgZo<3ogNZlPCoMjSb1?mfYo43
ogBVl@CoLZC`0om`X_03ofbPk`CoJ9g_0omSVnl2oefHk`03oenFkOmGT^goEi;]00;oEi;]0om<SN`3
ocj7jP03obeniol`NnGo6FkO00;o6FkO0ol000000ol0A/Oo001@oi9]Y@04oi9]Y@?odIRH1?o_^i/4
oo_DW004on_2ZOoX^J?oj;VSonRiX`GojKfV1?oY_jT00ooZ`ZcohL2gon70]`02on70]`Goi<Jj00Co
i/blonC;_ooTbkooi<^o1?oWe<<4on_Sb0;oj^k>0ooUl]D00ooRj=OogNSLomgXg002omgXg0Cof>SQ
00Cod^CTom;NhOoBg^7od]kQ1Oo>g><00oo>en3oc=GQolcEh@02olcEh@?obM;Q0oo9d=l4olO>g`03
olS=g_o7bmgoal_M00Coal_M00?oal_LolK9g?o6bM`00_o6bM`00oo6b=coa/SKolK8f`03olK8f`Oo
a/OK0_o6amX6olO7fPSoalSJ1Oo8bMX5olS9f`03olS:foo8bmcob<_L00Cob<_L00Co0000olS;g?o8
bmcob<_L1?o8c=d00oo7c=goalgNolO=gP03olO=gP03olO<g_o6cMooa/gO00;oa/gO00?oa/kPolG<
goo5c=l00oo5c=l00oo5cN7oa<_PolC;h002olC;h0;o`lcQ0oo2b^03ol7:h@?o`LSP0onob>400ooo
oooo0000ooooo`0Gooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo0_l0000]ooooo`CoM:_d0omeZ_<4ogFYl`;oM:Sb1?mcYo84og:U
l@?oL:Ca0om]X_401?m`X_3oK:3_ofbPkom/X>l4ofRMk`?oHi__1?mMV>l3oeFDkP;oBi3^00GoC8g/
ocj7j_lnQn[o?XOZobeni`03o`0000;o05kE00?o0e_Do`15aOl005001OnBKJD3om6HV0Cokk^K0ook
e9`3on_2Z@;oj;VS1OoY_JH4onVoZ@;oj/:/0_oQ`;L5onC6^P?oi/bl00?oi<^oonOD`ooWe<<00_oW
e<<4on_Sb0?oj^k>0ooUl]D01?oMl]gogNSLomgXg?oMj=`4omSXh@?od^CT00?od]kQolkLhoo>g><0
0oo>g><2ol_Hi0?oc=GQ1Oo9d^400oo9d=ooalkOolO>g`02olO>g`03olK<goo7bmgoal_M00Coal_M
0_o6bMd3olK9g0?oa/SL0oo6b=/6olK7f`Goa/OJ1_o7amX5olO8fP03olS8f_o8bM[ob<WJ00?ob<WJ
1Oo8bM/3olS:f`Kob<_L00?o0000olS;g?o8c=d00oo8c=d00oo8cMkoalgNolO=gP03olO=gP;oalkO
0oo6cMl3olK>h0;oaLcO1?o5cN400oo4bn3o`lcQol?<h@03ol?<h@03ol;:h?o1b^7o`L[Q00?o`L[Q
00?o`LSPoko8hOnob>400onob>42o`0001Oooooo0009ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo1?mdZo@3ogFZl`CoMJWc
0_mdZ?84og>WlPCoLZGa0om`Y?44offRl@?oJZ3`1?mVW_02of:Ll003of>KkomMV>ooGIS_00;oGIS_
0omEU>h3od^@kP?o00000_l]O^L00olFL^7o6FkOo`1Ne@02o`1Ne@03o`00D?nBKJGoTVfU00?oTVfU
0ooAV9P4onnkV`?onmBL1?o[`ZT00ooX^J?ojKfVonVmYP02onVmYPCojKnY1?oZ`Z`00ooQ`;Ooi<Jj
onC6^P02onC6^PCoi/bl0_o[e[h2onOD``Cojn?80ooZk/h3onGbe@?ogO;M00?ogNSLomSXhOoHj>40
0_oHj>43om;Ti0?ocN3V0oo>g><4ol_Hi003olcEhOo9d^7obM;Q00?obM;Q0_o7d>43olO>g`?oa/cO
0oo7bmd5olK9g@03olK9g?o6b=coa/SL00?oa/SL00?oa/SKolK7foo6am/01?o6am/5olK7fP03olO6
f_o7am[oalOJ00GoalOJ0oo7b=X3olS8fP?ob<WJ1Oo8bM/5olS:f`Gob<_L00?obLgMo`000?o8c=d0
0_o8c=d3olS=gP?oalgN1?o7c]l00oo6cMooa/kPolK>h002olK>h003olG<goo5cN7oaLgQ00;oaLgQ
0_o4c^84ol?<h@;o`/cR1?o1b^42ol3:hPCo_lSQ00?o_/ORooooool000005oooool000Wooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
;_ooool3og>Zm0CoLjWc0omcZ?<3og:Wl`CoLjOb1?mbYO43og2Tl@CoKJ;a0omZX?04ofJNl0?oHYc`
0omLV_03oeFGl0?o000000?oBi3^ocj;kOlnRnd00_l^Q>X00ol]O^Oo5W;QoaIbh@03o`1Ne@GoTVfU
0_oAV9P4onnkV`?onmBL1Oo[`ZT5onVmYPCojKnY1?oZ`Z`4onC6^PGoi/bl0oo[e[h01?oWe<?ojn?8
on_Sb?o[hlP3on[^cP?oiO;E0ooMl]d4omO`h`04omSXhOoBi>Cod^CTom;Ti0GocN3V00?oc]cSol_H
i?o;f>@00_o;f>@2olSEi0?obM;Q1Oo7d>400oo7c]ooa/cOolK<g`03olK<g`03olO;gOo6bMgoa/WM
00?oa/WM00?oaLSLolK8g?o6b=`00oo6b=`00oo5am_oa/OKolK7f`03olK7f`;oa/KJ0oo6amX4olO6
fPOoalOJ00?oalSJolS8f_o8b=X00oo8b=X00oo8bM[ob<WKolS9f`02olS9f`03olW:foo8b]_ob<[K
00?ob<[K0_o9bm`3olS;g0;obLgM00?o0000olW=gOo8c=d01Oo8cMh00oo7cMkoalkOolO>g`02olO>
g`03olO?h?o6c^3oa/kP00;oa/kP0_o6cn43olG=h@Coa<kR00?o`lcQol;<h_o2c>800oo2c>800oo1
b^7o`<[Rol3:hP03ol3:hP03oko8hOnnan;o_/OR00;o_/OR00?oooooo`000?ooool05Oooool000Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0`ooooo`?oLj[d1?mcZO<3og>Xl`CoLZOc1?maY_82og2UlPCoKZCb1?m/Xo42
ofVQl@03ofZPl?mVW_3oIYk`00;oIYk`0omRW?02oebJl0?o000000GoEIO`odbCl?m<To3oC9?`od^@
kP02ocj;k@?o;XCZ0olFL^400ol0HmOoTVfUoi9]Y@03oi9]Y@;odIRH1?o_^i/3oo_DW0Gojl:Y00?o
j/B^onVmY_oY_JH00_oY_JH3onVoZ@Goj/:/00CojlB^onC6^_oTa[[oi<Jj1?oVc;`4on_F_P;ol^_0
00Cojn?8on[^c_oZk/koj^k>0ooUl]D3omgbg@Coeo3S0ooAjnL00ooBi>CocN3VolgPiP03olgPiP;o
bMcW0oo;f>@4olSEi003olWBhOo7d>7oam3Q00?oam3Q00?oaLgPolK<goo6c=l00oo6c=l2olG:gP?o
a/WM1?o5b=`3olK8g0?oaLOK0oo6am/4olK6fP03olK7f_o7a][oalKJ00CoalKJ1Oo7amX00oo8amWo
b<SJolS8fP03olS8fP;ob<WJ0oo8bM/3olW:f`?ob<[K1?o9bm`00oo8bmcobLgMolW=g@02olW=g@03
o`000?o8cMkob<gN00?ob<gN0_o8cml3olO>g`?oaloP00?oa/kPolK?hOo6cn400oo6cn400oo5cN7o
a<kRolC>hP02olC>hP03ol?>hoo2c>;o`/cR00?o`/cR00?o`LgSol3:h_o0b^800oo0b^800onnb^?o
_/ORokk7hP02okk7hP03okc7hooooooo000001Kooooo0009ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`?o0000<Oooool3og>Zm0CoLjWc0omcZ?<4og:Wl`Co
LJKb0_m`YO84ofjTlPCoK:?a1?mYXO42ofFOl@;oHIga0ol00002oebJl0?oEIO`0om<To03od6?k`?o
;XCZ0_lHN^D00olFL^7o001@oi9]Y@04oi9]Y@04om6HV?o_^i_okk^KonnkV`?onmBL1Oo[`ZT3on[4
[P;ojKfV1?oY_jT4on[2[0?ojlB^00?oi<JjonK<_?oVc;`00ooVc;`4on_F_P;ol^_00oo/nL82on3n
c004onGbeOoMl]gogO;Momgbg@?oeo3S1?oAjnL2ol_VjP?ocN3V1Oo9g>L00oo;f>Cob=GTolSEi002
olSEi0?oaM7S0oo7d>43olG=h0?oa/cO1?o5b]h00oo6bMgoaLSLolG8g004olG8g003olK8g?o5am_o
aLOK00?oaLOK00?oa/OKolK6f_o6a]X00_o6a]X00oo6a]WoalKJolO6fP04olO6fP;oalKI0oo7amX3
olS7f@?ob<SJ1?o8bMX00oo8bM_obL[KolW:f`03olW:f`03olS:foo9bmcobL_L00;obL_L0_o9cM`3
olW=g@;obLkM00Co0000olS=g_o8cMkob<gN1?o8cml01?o7c]ooaloPolO?h?o7cn02olO@h@Coa/oQ
0_o5d>83olC>hP?o`lkS0oo2c>83ol7=h`03ol3:h_nnb^?o_/[S00?o_/[S00?o_/ORokc7honlan<0
0_nlan<00ooooooo0000ooooo`0Dooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`OoLJWd1?maZ?<3og2Wl`?oKjKc
0om^YO84ofjTlPCoK:?a1?mYXO400omUWo7o0000o`000003of6Ml@?oG9ca0_mFVO401?mEUo3oC9?`
odbCl?m<To03od6?k`;o<X[]00Co;XCZoaQjiOlHN^Go67[U1OnBKJD4onnkV`?onmBL1Oo[`ZT4on[4
[P04onVmY_oY_jWojKnYonVoZ@Goj/:/0oo[a:h00ooZa:koi/blonK<_002onK<_0CojmJn0oobjl03
onci`P;oh?k<0_oHnmd3om3hiP03omO`hooAjnOodN_W00;odN_W1?o;i^X00oo=h>KobMcWolWLi`03
olWLi`;oa]OW0oo8eN@5olGAh`03olO@hOo5cN3oaLgP00?oaLgP00?oa/cOolG:g_o5b]h00_o5b]h2
olC7g@GoaLSL00?oa<KKolG7foo5am/00oo5am/2olG6fP?oa/KJ0oo6a]T3olO6fPGoalKI00?oalOJ
olS7fOo8amT00oo8amT00oo8b=[ob<WJolS9fP02olS9fP03olW9f_o9b]_obL[K00?obL[K0_o9bm/3
olW;g0CobLgL00?obLgMolW>gOo9c]d00_o9c]d00ol0003ob<gNolS?g`03olS?g`04olS@h?o7cn3o
aloPolO?h0Coam3Q00?oa/oQolG@h_o5d>800oo5d>800oo4c^;o`lkSol?>h`03ol?>h`05ol;<h_o1
cN?o`LgSol7=honocND01Onnb^<00onmb^Co_<OSokc7h`04okc7h`03ooooool0003ooooo01?ooooo
0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
<oooool7og6Ym0CoLJSc0om`Yo<3ofnVl`CoKZGb1?m]Y?82of^SlP;oJ:;b0ol00002ofFQlPCoHIga
0omLW?44oeJIl@03odjGlOm<To3o@Ho_00;o@Ho_1?lbR^d01?lQPnWoTVfUoi9]YOnBKJD2ojBah@Co
kk^K0ooke9`4on_2Z@Goj/B^1?oY_jT4on[2[0CojlB^0_oZa:h2onK<_0CojmJn0oobjl03onci`P;o
h?k<0_oHnmd3om3hiPCobo;/00?odN_Wol_Vj_o;i^X00_o;i^X3olOPj`?obMcW1?o6enL00oo8eNCo
aM7SolGAh`03olGAh`03ol?>h_o5cN3oaLgP00?oaLgP0_o3b]l3olG:gPCoa<OM0oo5b=`3olC6f`?o
aLOK1?o5a]X00oo6a][oa/KIolK6f@03olK6f@03olO6f_o7a]WoalKI00CoalKI1Oo8amT2olS8f@?o
b<WJ0oo9bMX3olW:f`CobL_K00?obL_LolW=g?o9cM`00_o9cM`2ol[>g@CobLkM00Co0000olS?goo8
cmoob<oO1?o8d>000oo7cn3oam3QolO@h@02olO@h@;oa]7S1?o5d>82olCAi0Co`lkS00Co`/oTol7=
hoo1cN?o`LgS0onocND3okk:h`?o_L[T1?nlan<00onjanCo0000o`00000Dooooo`008oooool00ol0
003oooooooooo`0eooooo`;oKjWd1?m`Z?@4ofnXl`;oKjOc00CoL:OcofnVlom_Y_?oKjKc1?m^YO84
offTlP?o00000omXX_84ofFQlP?oHIob0_mMWO800omLW?7oEYWaoeJIl@02oeJIl@?oCYOa00?oAICa
od6?kolbR^d00olbR^d6ojBah@;okk^K0ooke9`5on_2Z@Goj/B^00CojLJbonVoZOoY_jWojKnY1?oZ
`Z`3on_4[PCoj/B^00Coi/blon_F__o[e[kojmJn0oobjl03onci`P;oh?k<0_oHnmd3om3hiPCobo;/
0_o6j^l3ol_VjPGoan3[00?obMcWolKGioo6enL00_o6enL2ol?CiP?oaM7S1?o3c^83olG=h0Co`l[O
00?oaL[NolC7gOo4amd01?o4amd00oo5b=coa<KKolC6f`03olC6f`03olG7foo5a][oaLKJ00;oaLKJ
00?oaLCIolK6fOo6a]T00oo6a]T00oo6aMWoalKIolO6f@06olO6f@?ob<OI1?o8b=T00oo8bM[obLWJ
olW9fP03olW9fP03olW:foo9bm_obL_K00;obL_K0_o:c=`3olW=g0Cob/kM00KobLkMolW?g_o9cmko
bLoNo`000?o8cml4olS@h0;ob=;Q0oo7d>44olKAh`03olG@h_o4dNCoa=7T00?oa=7T00?o`lkSol;?
i?o2cn@00_o2cn@00oo1cN?o_lgUoko=i@03oko=i@03okk:honmb^Co_L[T00?o_L[T00?o_<OSok[7
i?njan@00_njan@00ooooooo0000ooooo`0Booooo`008oooool2o`0003Oooooo0_m_ZO@4og2Xm0Co
KjSc0om_Yo<4ofjVl`;oKJGc00CoK:Cco`000?l0003o00000omZXo84ofRRlPCoIJ7b0omQWo83oefM
lP?oF9cb0omAV_801?m>Uo7oAICaodFDlOm5U?43ocV@l0GoY;7Q0_o_^i/3oo_DW0Cojl:Y1OoZa:h2
onW6/P;ojKnY1?oZ`Z`4on_4[PCoj/B^00Col/j/on_F__o[e[kojmJn0oobjl02onci`P;oh?k<0_oH
nmd3om3hiP?obo;/1Oo6j^l00oo;i^[oan3[olOPj`03olOPj`?o`m[Z00?oa]OWol?Ci_o3dnH00oo3
dnH00oo5dN?o`lkRol?>hP04ol?>hP03olG=h?o3b]oo`l[O00;o`l[O00?o`/ONolC7gOo4amd01?o4
amd00oo3aMcoa<KKolC6f`03olC6f`;oa<GJ0oo5a]X3olG4f@?oa/KI0oo6aMT8olO6f@03olS7fOo8
b=Wob<SI00?ob<SI1Oo9bMX2ol[;fP?obL_K1?o:c=`00oo9cMcob/kMol[>g@02ol[>g@03ol[@g_o9
cmkobLoN00;obLoN00?obM7Po`000?o8d>000_o8d>04olSBh@03olO@hOo6dN?oa]7S00;oa]7S00?o
aM?TolCAi?o4dN@00oo4dN@00oo3d^Go`/oTol;?i002ol;?i0;o`=3V1?nocND2okg=iPCo_L[T00?o
^l[Vok[7i?njan@00_njan@2okS6i@03ooooool0003ooooo017ooooo000Rooooo`03o`000?oooooo
oooo03Oooooo0om^Z?@4og2Xm0CoKjSc0om_Yo<3ofjVl`?o00001?m/Y?<4ofZSlP?oIj;b0omUX_<3
of:Pl`04of6Ol_mMWO;oGIgboefMlP?oF9cb0omAV_83odZIlP04odFDlOliT?3o>I3`ocV@l0GoY;7Q
00?okk^Koo_DW?nU^^P01Oo[`ZT5on[4[P?ojLJb00?ojKnYon[2[?oZ`Z`00_oZ`Z`4on_4[PCoj/B^
0_obcZ`01_o[e[kol^_0oo;[`?objl3ok?W2omg/R0;o^nZ=00CoaOk=ol7mi?o1oNCo`OgT0onomnl0
0oo;l^coa^[_olKZk`03olKZk`?o`^?_00?oan3[ol?Jj_o3f^X00oo3f^X00oo0e>Wo`m?Vol?CiP03
ol?CiP;o`LkT1Oo3c^82ol;:h@?o`l[O0oo2amh3olC7g@Co`lGL0oo4a]/4olC5fP03olG6f_o5a=Wo
aLCI00?oaLCI00?oa/KIolK5fOo6aMT00oo6aMT6olO6f@03olS7f?o8b=Wob<SI00?ob<SI0_o9b=T3
olW9fPCob/_J00?obL_Kol[<g?o:c=`00_o:c=`00oo;c]cob/kMol[>g@02ol[>g@?ob]3N0_o9cmh3
olWAh003o`000?o8d>3ob=;Q00?ob=;Q0_o8dn<3olKAh`?oaM?T0_o4dN@4ol?Bi@03ol;?i?o0d>Ko
`=3V00?o`=3V00?o_lgUokg=i_nmcNH00onmcNH00onmb^Co^l[Vok_:iP02ok_:iP03ok[7i?nha^Go
^<KU00?o^<KU00?o0000ooooooooool04?ooool002;ooooo00?o0000ooooooooool0>?ooool7ofjX
m0KoKZOc0ol000001?m]Y_?oK:GcofbUlom/YO<4ofbTl`CoJZ?b0omWX_83ofFRl`CoHZ3c0omNWo<2
oeZNl`04oeRLl_mAV_;oDI[boe6JlPCoBYWb0_m1Uo800oliT?3oY;7QojBah@02ofCJfPCoYK[X1?o[
`ZT4on[4[PCojLJb00?oj<Ndon[2[?oZ`Z`00_oZ`Z`3on_4[PCoj/B^0oobcZ`3oo_YX0?ogNb800?o
^nZ=olGncOo1oN@00_o1oN@3okogk`Co_>kd00?oa^[_ol;Skoo2hnl00_o2hnl3okkLkP?o`m[Z0oo0
e>T3ol?CiPCo`LkT00?o`lkRol;:hOo2b^401?o2b^400oo3b]oo`/ONol;7gP03ol;7gP03olC7gOo3
aMco`lGL00Co`lGL00?oa<KKolC5f_o4aMX00_o4aMX00oo4`mWoaLCIolG4f@03olG4f@03olK4f?o6
aMWoa/GI00?oa/GI0_o7aMP3olO6f@Cob<OH0oo8b=T4olW8f@03olW9f_o:bm[ob/_J00;ob/_J00Co
blcKol[<g?o:c=cob/cL1?o;c]`2ol[>g@Cob]3N00?obLoNolWAh?o9dN000_o9dN000ol0003obM?Q
olSBh@02olSBh@Cob=?S00?oa]7SolGCi?o5dn@00_o5dn@00oo4dNCo`m;Uol?Bi@02ol?Bi@;o`]?W
1?o0d>H00onnd>Oo_LgVokg=iP03okg=iP03ok_=ionkb^Ko^l[V00;o^l[V0_nhbNL4okS6i@03okG5
i_oooooo0000017ooooo000Rooooo`03o`000?oooooooooo03Wooooo1om^Z?@2ofjWl`?o00000_m^
Yo<3offVl`CoK:Gc1?m[YO<2ofVTl`?oIj?c00CoIj;bofFRlomUX_?oIJ;c1?mRX?<3oejOl`CoFYkc
00?oEYkdoe6Jl_m:VO800om:VO83od6GlP;o>9Ga00?o;8c]ojFjj?nU^^P00onU^^P2on_2Z@Goj/B^
1?oYa[82onS7]0;oj/:/1?o[a:h4on[4[P?ol/j/0ookjJ02omg/R003ok_ZSOo5o/go`OgT00;o`OgT
0onomnl4okc^m0;o^NGd0oo2hnl5okkLkP03ol?Jj_o0e>Wo`=CY00?o`=CY00?o`m?Vol7>i?o1c^@0
0_o1c^@2oko:h`Go`/[Q00?o`LOOol;7g_o2amh00oo2amh2ol;5g0Go`lGL0_o3`mX3olC5fP?oa<?I
0oo5a=T3olK4f0?oa/GI1?o7aMP00oo7a]Wob<OHolS7f004olS7f003olS8fOo9b=WobLSI00;obLSI
00Cob/WIol[;f_o:bm[ob/_J1?o;c=/00oo:c=coblkLol_>g003ol_>g003ol[>gOo:d=kob]3N00;o
b]3N0_o;d]l3olWAh0;obM?Q00?o0000olWChOo8d^401?o8dn<00oo7eNGoaM?TolGCi002olGCi0?o
a=CV00?o`m;Uol;Cioo2dnL00oo2dnL00oo0d>Ko_]3Wokk@i`02okk@i`03okg=i_nkcNOo^lgW00?o
^lgW00?o^l[VokS9ionhbNL00onhbNL00onha^Go]LGVokG5iP02okG5iP03ooooool0003ooooo00oo
oooo000Rooooo`;o0000??ooool3offXm004offWm?l0003o0000o`0000?oKJOd0_m]Yo<01?m^Yo?o
KJKcoffVlom]Y_<4ofbUl`CoJjGc0_mYY?<4ofNSl`?oIJ;c1?mSX_<2of2Ql`03oejOlomJW_?oFYkc
00;oFYkc0omFW_@4oe2Mm003odZLm?m1Uo;o>9Ga00;o>9Ga1OnU^^P00oo[`ZWoj/B^on[4[P02on[4
[PCojLJb1?oXak@00ooZ`ZcojlB^on_4[P02on_4[P?oj/B^0oobcZ`3oo_YX0;ogNb800Co^nZ=oige
gOnMmMgoWOGM0onVm>l00onomnoo_>kdokc^m006okWUm003ol;Skonng>ko_]c^00?o_]c^0_nleN`4
ol3Dj@;o_/oW0oo1c^@4oko:h`?o`/[Q0oo1aml3ol;7gPCo`/GL00?o`lGLol?3f_o3`mX01?o3`mX0
0oo4aM[oa<?IolC3f@03olC3f@03olG4fOo6a=Soa/CH00?oa/CH00?oa/GIolO5f?o7aMP00_o7aMP0
0oo8aMSob<OHolS7f004olS7f004olW7f?o9b=WobLSIolW8f@Cob/WI00?ob/_Jol_<foo;c=/00oo;
c=/5ol_>g0;oc=3M0oo:d=h4ol_Bg`03olWAh?o9dn7obM?Q00;obM?Q00?o0000olWEhoo8dn<00_o8
dn<3olOEi@03olGCi?o4e>Koa=CV00;oa=CV0_o3e^P4ol;Ci`03okoCjOnnd>Oo_]3W00;o_]3W0_nl
d>T4ok_=i`;o^LgY1?nhbNL00onfbNSo]LGVokG5iP04okG5iP03o`000?oooooooooo00Oooooo1?l0
0001oa0@407ooooo0Oooool002;ooooo00?o0000ooooooooool0??ooool00om]Z?Co0000o`000007
offWm0?oKJOc1?m/Y_<2of^Ul`CoJZGc0omYY?<4ofNSl`?oIJ;c1?mSX_<3of2Ql`?oGJ7d0omJXO@0
0omFW_CoD9gdoe2Mm002oe2Mm0?oBYcd00CoA9cdocRElOnU^^SoYK[X0onU_N/4on[4[PCojLJb1?oX
ak@01?oVaKKojlB^on_4[_o[a:h4on[4[P?ol/j/0ookjJ000ooMk8So^nZ=oigeg@05ojKdk`;oZnkh
0on^iOT4okWUm0?o^=gc00?o_]c^okcEk?nleN`01?nleN`00oo0e>Wo_/oWokk?i`03okk?i`03ol7>
i?nob^?o_l[S00Co_l[S00?o`/[Qol77goo1aml00oo1aml00oo2amko`/GLol;5g002ol;5g0;o`L;K
1Oo3`mX00oo3`]Woa<?IolC3f@03olC3f@03olG2f?o6a=Soa/CH00?oa/CH0_o6`mL3olO5f0?ob<GH
0oo8amP4olW7f003olW8fOo:bMWob/WI00;ob/WI00?obl_Jol_<foo;c=/00oo;c=/2olc>f`?oblkL
1?o<d=d00oo:d=kobm;Ool_Bg`02ol_Bg`;obmCQ0oo9dn401Oo9eN?o0000olWEhoo9eN?ob=?S00?o
amGU0_o6enL3olCDiPCo`mKX00?o`]?WokoCjOnodnT00_nodnT00onnd>Oo_=3Yokc@j@03okc@j@03
ok_=ionicNWo^LgY00?o^LgY00?o^<WWokK9j?nfbNP00_nfbNP4okG5iP03ok?4iooooooo000000[o
oooo00?o0000ooooooooool00_ooool002;ooooo00?o0000ooooooooool0>_ooool3o`0000[oKJOd
0om]Yo<4ofbVl`;oJjGc1?mZYO<4ofVTl`?oIjCc0_mVXo<00omUX_?oHj;cof>Rl`02of>Rl`?oH:7c
0omMXO@4oeZQm0?oEZ7e0omBXOH00om:W?CoA9cdojFmj`05ojFmj`;oj/B^1?oYa[85onS7]0;oi/Ff
0_o[a:h3on[4[PCol/j/0_okjJ02omg/R0CoN>?/00?oY_C_oj_^n?n[k_P01_n^iOT00oniiOCo^=gc
okSMl`02okSMl`?o]]G`1?nleN`2ok[?jPCo_/oW0_nlb^D5oko:h`;o_/KQ1?o1aml2oko4g@?o`/GL
1?o1`]/3ol?3fP?o`l;I0oo4`mT3olG2f0?oa/CH1?o6`mL00oo7aMSob<GHolS5f003olS5f003olS7
f?o9amSobLOH00;obLOH0_o:b=P3ol[9f@?obl_J0oo;c=/4olc>f`03ol_>g?o<d=goc=3M00;oc=3M
0_o<dmh3ol_Bg`CobmCQ00KobM?QolWEhoo9eN?obMGSo`000?o9f>D3olOEi@Coa]OW00?oa=CVol?F
j?o3e^P00_o3e^P00oo1en[o_m?YokoCj@02okoCj@;o_MC[1?nld>T2ok[Aj`Co^LgY00?o]/c[okK9
j?nfbNP00onfbNP00oneaNKo/lCWok?4i`03ok?4i`03ooooool0003ooooo00Sooooo00?o0000oooo
ooooool00_ooool002;ooooo0ol0000gooooo`?o00001?ooool:offWm0KoK:Kd0om[Y_<4ofZUl`Co
JJCc0omWY?<3ofJSl`CoI:?d0omRXo@2of2Sm003oefQm?mJXOCoFZ7d00;oFZ7d0omFXOD4oe:QmP03
odnRmonU_N_oYKg[00CoYKg[00?oj/B^onW6/_oYa[800_oYa[84onS7]0Coi/Ff00CojlB^on[4[_oZ
a:koj/B^0oobcZ`2oo_YX0;ogNb80omhhn`3oi3Un`?oW=om0on^iOT4ojkLm`03okSMlonfeO3o]]G`
00Co]]G`00?o_=G/ok[?j_njcnX00onjcnX00onncnOo_<[Uokc:i@03okc:i@03oko:honna^7o_/KQ
00Co_/KQ00?o`LOOoko4gOnoa=d00onoa=d00oo2aMco`L;Kol72f`04ol72f`03ol?3f_o3`]Wo`l;I
00?o`l;I00?oa<?IolG2f?o5`]P00oo5`]P00oo6a=Soa/?GolK3e`02olK3e`03olO3e_o8aMSob<GH
00?ob<GH0_o9a]L3olW7f0Cob/SH00?ob/WIol_;f_o;bmX00oo;bmX00oo;c=_oc<kKolc>f`02olc>
f`;ocM3L0oo<d=d4olcCgP03ol_Bgoo;e>7obmCQ00;obmCQ0_o;en<3olWEh`04olWHiOl0003obMSU
olOEi@Coa]OW0_o4fNT3ol?Fj0?o`MOZ00?o_m?YokgDjonme>/00onme>/00onld>Wo^]7[ok[Aj`03
ok[Aj`03okW=jOnfc>_o]/c[00;o]/c[0_nfbNP3ok?8jPCo/lCW00?o/<?Xooooool000002Oooool0
0ol0003oooooooooo`02ooooo`008Oooool2o`0003Kooooo0ol00008ooooo`;oK:Od2?m]Yo@6ofbV
m0CoJjKc1?mZYO<2ofVUl`?oJ:Cc00CoIjCcofJSlomVXo?oIZ?c1?mTXo@3of:Sm0CoH:?d0omNXoD2
oebTmP03oeJQmOmBXOKoDZ7f00;oDZ7f00CoCj;gojFmjonU_N_oYKg[0onU_n`4onW6/PCoj<Nd1?oV
aKH4on[4[P?ol/j/0_okjJ000ooMk8SoL]Kkog;Fn`02og;Fn`03oi3UnonLgogoW=om00;oW=om0onQ
fO/4ojkLm`;o[]Cd1OnfeO02okG?k@Co^/oZ0_nibNL4okc:i@;o^lGR1Onna^400onm`mko_lCMoko4
g@03oko4g@03oko1foo1`]_o`L;K00Co`L;K00?o`L3Iol?2fOo3`]T00oo3`]T00oo3`=OoaL;HolG2
f003olG2f0;oaL7F0oo6`mL3olO3eP?ob<GH1?o9a]L00oo9amSob/SHol[8f003ol[8f0Gobl_J0_o<
cMX3olc>f`CocM3L00?oc=3MolcCg_o<dmh00_o<dmh2olgFh0?obmCQ1?o;en<01Oo9eN?obMSUolWH
iOo9f>Go000000;ob=[W00?oa]OWolCIjOo4fNT00oo4fNT01?o3e^So`MOZol7Gj_o1enX2okkHk@Co
_MC[0_njeNd4ok[Aj`03okO@kOnfc>_o]/c[00;o]/c[0_ncc>`5ok?8jP03ok?4ion``nSo/<?X00;o
/<?X00?oooooo`000?ooool01oooool00ol0003oooooooooo`02ooooo`0000Co<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0<_ooool3o`0000cooooo2_m/Yo@3ofbVm0?oJjKd1?m[Y_<4ofZU
l`;oJJGc1?mXY?<4ofNTm0?oIJCd0_mTY?@00omRXoCoH:?dof2Sm002of2Sm0?oGZ?e1?mLY?H3oeZU
m`03oeVWn?nU_ncoYKo/00CoYKo/0_oYa[84onS7]0Goi/Ff00?ohkndon[4[_oZa:h01?obcZ`00ook
jJ3ogNb8o`000002og;Fn`CoR=Oo00?oW=omoj7InonQfO/01?nQfO/00on^g?Oo[]CdojkDm003ojkD
m003okKEl?necngo]Lo]00Co]Lo]00?o^/oZokW9ionibNL00onibNL00onlb^Go^lGRok_5hP03ok_5
hP?o_/KQ0onm`mh3oko4g@?o_l7K0oo1`]/4ol70f@?o`l;I0oo3`=L3olG2f0CoaL7F00?oa/?GolO3
e_o7`mH00oo7`mH00oo8aMSobLKGolW6e`03olW6e`Gob/SH0_o<b]P3ol_;fPCoc<gJ00?oc<kKolg@
g?o=d=`00_o=d=`2olkCg@?oc=?N1?o=e^000oo;e>7obmOSol_Gh`02ol_Gh`;obm[U00GobMSUolSJ
ioo8f^Oo0000olSJi`02olKLj@Coa=WY0_o2fn/00oo1en[o_]S]okkHk@03okkHk@03okgDjonjeNgo
^]G]00?o^]G]00?o^]7[okO@kOngd>d00_ngd>d00onfc>_o/lc/ok?<k003ok?<k0;o/lSZ0_n`an/6
ok33j0;o00001oooool00ol0003oooooooooo`02ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo02oooooo0ol0000@ooooo`[oK:Od0om/Y_@7of^Vm0?oJZGd0omYYO@4ofRTl`CoIjCd0omUY?@3
ofBTm0CoHjCd0_mRYOD00omNXoGoG:CfoebTmP02oebTmP?oFZGg00?oFJOhojFok?nU_n`01?nU_n`0
1?oYa[;oj<NdonS7]?oXak@5onK5]P?ohknd00Coj/B^oo;>[?obcZcol/j/0_okjJ001?l0003oN<go
ogS=oomhcOl2ohSGo`GoT]?m0_nQfO/3ojGBm`Co[]Cd0on^c_04okG?k@;o]<WZ1?nibNL00onga>Co
^lGRok_5hP05ok_5hP03okk6hOnm`mko_L?N00?o_L?N00?o_lCMoko1fono`M/00ono`M/00oo1`]_o
`L3Iol70f@04ol70f@03ol?2fOo3`=Oo`l3G00?o`l3G00?oaL;HolG1e_o5`MH00oo5`MH5olO3eP03
olS4e_o9a]OobLKG00?obLKG0_o:amL3ol[8f0Coc<[H00?obl_Jolc=f_o<cMX00_o<cMX2olk@f`?o
cM3L1?o>dmd00oo<dmkocMKPolgFh002olgFh0;ocMWR00?obmOSol_JiOo;f^D00_o;f^D2ol[Mi`?o
b=[W00Go0000olKLjOo6g>Woa]cYolCIj@03ol;Kj`;o`=c^1?nnf>d00onkfNoo^]G]ok[Ek@03ok[E
k@03okOEkongd>go]m3]00;o]m3]0_ncd>l4ok?<k003ok3;k_n`an_o/<O[00?o/<O[0on``nP2ojg2
j@03ooooool0003ooooo00Kooooo00?o0000ooooooooool00_ooool000?ooooo00?o410@oooooooo
ool02oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l0000]ooooo`?o
00005?ooool:ofbWm0?oK:Kd1om[Y_@3ofZUm0CoJJGd0omXYO@3ofNUm0?oIZGd00CoIJCdofBTm?mT
Y?CoI:Cd1?mSY?@3of:Um@CoHJKf1?mQYoL3ojFok0;oYL7]1?oXak@5onK5]P?ohknd0_o^d;@2oo;>
[004oo_YX?l0003oN<googS=o`CoQ/cn0onBdod3oiW=nPGoYM;g00?o[]Cdojk>l?n^c_001?n^c_00
0onecngo]<WZokC9jP03okC9jP03okW9ionga>Co]lCT00;o]lCT1OnkaN82ok[1g`Co_L?N00?o_;oL
oko1fono`M/00ono`M/00ono_]Wo`L3Iol70f@04ol70f@03ol6neoo3`=Oo`l3G00?o`l3G00?oa;oF
olG1e_o5`MH00oo5`MH2olK1e@?oal?F0oo8a=H3olW6e`Cob/OG00?ob/SHolc:f?o<b]P00_o<b]P2
olg<f@?oc<gJ1?o>d=/00oo=d=coc]?MolkCg@02olkCg@;oc]KO0oo=e^02olgIhP;ocMcT0oo;f^D4
ol[Mi`06olSJioo6g>Woa]cYo`000?o6g>Woa=o/0oo2fn/4ol3LkP03okkHkOnkfNoo^mW_00;o^mW_
00?o^]G]okOEkongeNl00ongeNl00ongd>go/m3_ok?@k`03ok?@k`03ok?<k?n`bnko/<_^00;o/<_^
0_n`an/3ojc6k0Go[L;Y00?o0000ooooooooool00oooool00omEEEGoIVIVo`000004ooooo`000ooo
ool00ol0003oooooooooo`0<ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Yooooo`?o00006?ooool:ofbWm0KoJjKd1_mZY_@00omZYOCoJJGdofVU
m002ofVUm0?oJ:Gd0omWYO@8ofJUm0?oIJGe0_mUY_D00omRYOGoHJKfof6VmP02of6VmPCoHJOg1OnU
`Nd2onS7]0Goi/Ff1?oS_k@3onk@]003oo;>[?oRkXcoN/Cn00;oN/Cn0_n6c?h4oho8n`GoVLgj0_nU
d_L3ojK<l`Go[/k`0_n^an`4okC9jP03ok?3i_nga>Co]lCT00Co]lCT00?o^lGRok[1gonj`Ml01?nj
`Ml00onm`mko_;oLokbog002okbog0?o_l7K0ono_]T3ol70f@Co`KkG0oo3`=L3olBoeP?oaL7F1?o6
`MD00oo7`mKob<CFolS4eP03olS4eP03olW6eoo:amOob/OG00;ob/OG0_o<b=L3olc:f0CocLcI00?o
c<gJolk@foo>d=/00_o>d=/2oloCg0?oc]?M1?o>e]l00oo=e^3ocMWRolgIhP04olgLi003ol_JiOo:
gNOob]gW00;ob]gW0oo8h>X00oo6g>Woa=o/o`000002olCOk003ol;Kjoo0g>ko`=c^00;o`=c^00?o
_=k`ok_IkonkfNl00_nkfNl3okSIl@;o]mG_1?nce?42ok?@k`;o/<o`1?n`bnh2ojc:k`Go[<K/0_n]
`^T2ooooo`03o`000?oooooooooo00[ooooo0003ooooo`03o`000?oooooooooo00cooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09ooo
ool2o`0001gooooo2Om/Yo@6of^Vm0SoJZKd0omYYO@5ofRUm003ofNUm?mVYOCoIZGd00KoIZGd0omU
YOD4ofFVm@?oIZOf0omVZOH00omXZoOoYL7]ojG1k@03ojG1k@03onS7]?oVaKKoi/Ff00;oi/Ff1?oS
_k@4onk@]003on;^S?mja?koN/Cn00CoQL;k1On?b?/2oiW=nP?oWLSf1OnVc?<00on^c_3o[/O/ojk7
k004ojk7k003okC9j_nc`nKo/l?V00;o/l?V1?nga>@2okO0h@Go^/7O00?o^[gLokbog?nl_m`01?nl
_m`00ono`M_o_kkIoknnf@03oknnf@03ol70fOo1_]Oo`KkG00Co`KkG00?o`l3GolBoe_o4_mH00oo4
_mH00oo5`MKoa/7EolK1e@02olK1e@03olO1e?o8a=Kob<CF00?ob<CF0_o:a=D3ol[7e`Coc<SG00?o
c<[Holg<fOo=c=T00_o=c=T2olo?f@?oc]3K1?o?dm`00oo>dmgoc]KOolkFg`02olkFg`;ocm[Q00?o
cMWRolgLi?o=g>@00_o=g>@2olcPi`?ob]gW0oo8h>X01Oo6hngoa=o/olCOk?l0003oa=o/00?o`N7_
00?o`=c^okcNl?nlg_000_nlg_000onkfNoo^=WaokSIl@02okSIl@;o/mWc1?nce?400on_e??o/<o`
ok3?l003ok3?l003ok3;k_n/b^oo[<[_00?o[<[_0_n/a^`6ooooo`03o`000?oooooooooo00[ooooo
0003ooooo`03oa0@4?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Gooooo0ol0000Pooooo`KoK:Od0om[Yo@6of^Vm0SoJZKd0omY
YO@7ofRUm0KoIjGd0omWY_@00omUYOGoIJKeofFVm@02ofFVm@?oIZOf0omVZOH00omXZoOoYL7]ojG1
k@03ojFmj`Coi/Ff1?oS_k@4onk@]003on;^S?ml_?_oO;ck00GoQL;k0_n?b?/3oiC4m`GoWLSf0_nV
c?<4ojO5k`Co[/O/00?o[/;Xok?3i_nc`nH01?nc`nH00onga>Co]l3QokO0h@03okO0h@?o^/7O0onj
_M`4okbog003okblfOno_]Wo_kkI00?o_kkI0_no^mH5ol6ne`03ol:le?o4_mKoa;oF00?oa;oF0_o5
_]@3olK1e@?oal7D0oo8a=H4ol[4e@03ol[7eoo<b=Ooc<SG00?oc<SG00CocL_Golg<fOo=c=WocLcI
1?o?cmT00oo>d=_ocm?LoloCg002oloCg0;od=ON0oo>e]l2oloJh@;ocmkS0oo=g>@4olcPi`04ol[M
ioo8h>[ob>3ZolSPjP?oa^?]00?oa=o/ol7Qkol000000_o1hNl2okgSlP;o_=k`1?nhg_<00onhfO7o
/mWcok?Il`03ok?Il`03ok?DlOn_e??o[mCc00;o[mCc0_n`co03ojc>lPCo[<[_2_ooool00ol0003o
ooooooooo`09ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol@413ooooooooooooooooo<S8b
00Cooooo00?o0000ooooooooool01Oooool3o`0002;ooooo0ol0000Sooooo`OoK:Od0om[Yo@7of^V
m0?oJZKd1?mYY_@5ofVUm0GoJ:Gd1_mWYO@4ofNVm0CoJ:Oe0omYZ?D2of^YmP03ofJYm_nU_N_oYKg[
00CoYKg[0_oVaKH4on>o]0Cok]2d00?oh^j<ogblnon3^oP00_n3^oP5oh^on0GoU<Cg0_nMb?H3oio3
l@KoYlG_00?o[/O/ojk2j?n^`^P00_n^`^P4ok?3iP03ok:nhong`>7o]l3Q00Go]l3Q00?o^/7OokZm
g?nj_M`00onj_M`00onl_mco_;cIokblf@02okblf@?o_kkI1?no^mH3ol6ne`?o`[cD0oo4_mH4olFn
e003olK1eOo7`MCoal7D00?oal7D00?ob<CFol[4eOo:a=D00oo:a=D5olc8e`?ocL_G00?ocLcIolo?
fOo?cmT00oo?cmT01?o@d]_ocm?LoloCg?o?dm`4om3GgP03olkFgoo?f^7ocm[Q00CocmkS00?ocMcT
olcPioo<h>L00_o<h>L3ol_Tj@04olSPj_o6hngoa^?]olKSk@?o`nK`00Co`N7_o`000?nmho;o_N?b
0_nhi?@4okSNl`;o/mkf0oncfO<3ojoImP;o[mCc0on[d_D5ojc>lP03ojc:kooooooooooo00[ooooo
00?o0000ooooooooool02Oooool00004oc8b<_l0003o<S8bonk^kP_ooooo1Ol00004ooooo`Co0000
1?ooool00ol0003oooooooooo`0Oooooo`?o00009oooool4ofbWm0KoJjOd1om[Y_@3ofZVm0CoJJKd
1_mYYO@7ofRUm0;oJ:Kd00?oIjGdofNVm?mWY_@00_mWY_@4ofRWm@?oJJSe0om[ZOH6ojFmj`04onK5
]_oS_kCohkndon>o]0Gok]2d00?oh^j<ogbfn?n3^oP00on3^oP5oh^on0;oU<Cg0onH_o<5oio3l@?o
YlG_0onW`>/5ojk2j003ok?3i_nb_^?o/[kS00;o/[kS1Ong`>42okJkg@Co^[gL00?o^KWIokblfOnl
_=T01?nl_=T00ono_]Wo_k_FoknkeP04oknkeP03ol6neoo2_=Co`[cD00?o`[cD00?oa;oFolFne?o5
_]@00oo5_]@5olO1e003olW2doo:a=Gob/CE00?ob/CE0_o<a]D3olc8e`CocL_G1Oo?cmT3om3Bf`03
oloCg?o@emkod=ON00;od=ON0_oAfn000oo?f^7ocmkSoloNh`02oloNh`?ocn?V00?oc>3Wol_TjOo;
i>T00_o;i>T2olSWk@03olKSkOo3i_3o`nK`00;o`nK`0_nnj?800onmho;o0000okSTm003okSTm004
okSNloncg_Ko/mkfok?NmP;o[]kh1?n_fOH2ojWGn0GoZm;e0_n/c_8?ooooo`03o`000?oooooooooo
00Wooooo000Pooooo`03o`000?oooooooooo01cooooo0ol0000[ooooo`CoK:Od1_m[Yo@3of^Vm0So
JZKd1OmYY_@4ofVUm0OoJ:Gd1?mXY_@2ofVVm0CoJZOd0om/Z?D01?mYZ?GoJjWfof^Ym_m[ZOH3ojFm
j`;oYK;R1?oS_k@4onk@]004on;^S?ml]_SoO;Khogbfn0CoPk_h0_n;_oP3ohnlm0GoV;oc0_nO`o43
oj6mk@KoYl3[0_n^`^P3ojfli@Go/[kS00?o]l3QokJkgOnf^md01?nf^md00onj_Mco^KWIokVif@02
okVif@Co_;cI00?o_;WFoknke_no^mH01?no^mH00ono^MCo`[cDol:le003ol:le003ol>kdoo5_]Co
aKkD00?oaKkD0_o6_]<3olO1e0?obL;C0oo:a=D4olc6e@03olc8eoo=bmOocL_G00;ocL_G0_o?cML3
olo?f@Cod=;K00Cod]OLom3Gg_o@emkod=ON0ooAfn001?oBh>;ocmkSoloNhoo?g^<3oloSiP;ocNOY
0oo;i>T2olSWk@?oaN__00Co`nK`okkXl_nnj?;o_^Sb0_nhjOD01?l0003o^>CdokSTm?nhi?@2ok;T
m`03ok?Nm_n^g_So[]kh00?o[]kh00?o[mWfojWGn?nYeoP00onYeoP2oj_BmA?ooooo00?o0000oooo
ooooool02Oooool0023ooooo00?o0000ooooooooool06Oooool3o`00033ooooo0om/Yo@6of^Wm0?o
JjKd2?mZY_@6ofVVm0GoJJGd1OmXYO@4ofRVm0;oJJKd1?mZYo@4ofbXm@;oKZ[e1_nU/^82on>o]0Co
k]2d0_oRkX`4oh6dmPCoR;Se1On?_?@2oiRol`?oV[__1OnQ_Nd4ojO0j`03ojNjion]_>Go[KcU00Co
[KcU0_nb_^<3ok:ig`Go][_M00?o][OJokVifOni^MT01?ni^MT00onl_=Wo_;WFokbieP02okbieP?o
_k_F1?no^M@3ol:le0?o`k_C0oo5_]@4olJnd`03olO1e?o9`]?obL;C00?obL;C00?ob/CEolc6eOo<
a]D00_o<a]D2olk8e@?ocL_G1?o?cML00oo?cmWod=;Kom3Bf`02om3Bf`?od]OL00Cod=ONom7Kh?oA
fn3odM_P0ooBh>801?o?g^?ocn?VoloSi_o?hnH4olgWj@03ol_TjOo8ingob>O]00?oaN__0_nok_80
0onnj?;o^>WeokSYm@03okSYm@04o`000?nbi?Oo/^Cgok;Tm`?o[>?j0_n^g_P3ojOMnP?oZMOh5ooo
ool00ol0003oooooooooo`09ooooo`008?ooool2o`0001Oooooo0ol0000dooooo`?oK:Od2_m[Yo@6
ofZVm0OoJJKd2_mYYO@3ofVVm0?oJZKd1?mZYo@4ofbXm@;oKZ[e1_nU/^800ooS_kCok]2donk@]002
onk@]003on;^S?mk/OKoNk7f00CoPKCf1?n8^?D2ohnlm0;oT[Sa1_nJ^nl5oj6mk@03ojO0jonW^^Oo
Yk[W00;oYk[W1?n]_>D00on]]n7o/[WOok:ig`04ok:ig`?o][_M0onf]mX4okVif@03okVfe_nl^MKo
_;WF00Co_;WF00?o_k_Foknie?no^M@01?no^M@00oo2_=Co`k_Col>kd`03ol>kd`03olFne?o6_]?o
a[kC00?oa[kC1Oo9`]<2ol_3dP?oc<KE1?o>b=D00oo=bmOoclgGolo=e`02olo=e`;od]7H0oo@d]/3
om;Gg004om?Kg_oAfn3odM_Pom7Kh0?od^3R0ooBiND00oo?hnKocNOYolgWj@02olgWj@;obnc/00Co
b>O]olG[koo5jnooaN__0_nok_83okS_m@;o^>We0onaj_P00ol0003o[>?jojcSnP02ojcSnP;oY>;l
0_nWgOXLooooo`03o`000?oooooooooo00Wooooo000Oooooo`03o`000?oooooooooo01Cooooo0ol0
000hooooo`CoK:Od2Om[Yo@6ofZVm0[oJJKd1omYYO@3ofVVm0CoJZKd1?m/Yo@4ofjXm003og2Ym?nU
/^;oYK;R00;oYK;R0onQdoT2onk@]004on;^S?mn/??oO[3cogj`l`CoQ;;c1On;]O84oi:hl@KoV[__
0_nQ_Nd3oj6hj@GoYk[W00?o[KcUojfghOn]]n400_n]]n46ok:ig`03okJkgOnf]m[o][OJ00?o][OJ
00?o^KWIokVfe_ni]]H00_ni]]H4okbieP;o_KKC1Ono^M@00oo1^=7o`k_Col>kd`03ol>kd`03olBj
dOo6_]?oa[kC00?oa[kC0_o8_]43olW2d`Cobl?B00?oc<KEolk8eOo>b=D00oo>b=D01?o@bmGoclgG
olo=eoo?cML4om;Af004om3BfooBemcod]OLom;Gg0?odm_N00CodM_Pom;Ph_oBh>;od^3R0ooBiND3
om3[i`04olgWjOo;k>cobnc/ol_/k0?oa_3_00?oaN__oko^l_nok_800onhkoD2ojk_m`;o/N[h0_nX
jOX00ol0003oZ>WjojcSnP03ojCRo1oooooo00?o0000ooooooooool02Oooool001oooooo00?o0000
ooooooooool04_ooool2o`0003cooooo1?m/Yo@9of^Wm0?oJZKd0_mYY_@00omZY_CoJJKdofVVm008
ofVVm0OoJJGd0omYY_@4ofZVm0CoK:Od1?m^Z?@00om`ZOCoYK;Roj7Cn@05oj7Cn@03onk@]?mi[OCo
O[3c00?oO[3c1?n4/_<5oh^elPCoT[Sa0onJ^nl3oi^fj`GoXKSY0_nW^^L2ojNeh`Ko[KOQ0onb^Ml2
ok6ef`Go][OJ00?o][?FokVfe_ni]]H01?ni]]H00onl^MKo_KKCokffd`03okffd`?o_kWD0oo1^=43
ol>kd`?oa;[A0oo6_]<4olRnd@03olW2doo;`m;obl?B00?obl?B1Oo>b=D3om3;e@03olo=eooBdMSo
d]7H00;od]7H0ooDe]X01?oBemcodm_Nom?Kg_oCfmh3omCQh004om;Ph_oBiNGod^GUom;Ui@?od>_W
0_o>l>X00oo;k>coa_3_olK`k`02olK`k`;o_o?a00?o_nkbokS_mOnhkoD00on^koL3oj?^n0;oZ>Wj
00CoWnOlo`000?nOiocoY>;l8_ooool00ol0003oooooooooo`08ooooo`007oooool00ol0003ooooo
ooooo`0?ooooo`?o0000?oooool6ofbWm0OoJjOd0omZY_@7ofVVm0GoJ:Kd00?oJJKdofVUm?mYYO@0
1OmYYO@3ofVVm0CoJjKd0om/Y_@4ofnWl`?oLZSc1?nQdoT4ogV]m0CoO[3c1?n4/_<2oh^elP?oSK;_
1OnC]>d5oi^fj`;oXKSY0_nQ/nD5ojNeh`Co[KOQ00?o[K;Mok6efona]M/01?na]M/3okJgfP?o][?F
1?ni]]H00onj/];o_KKCokffd`05okffd`03oknie?o1^=7o`KSA00?o`KSA00?o`k_ColBjdOo4^]40
0oo4^]400oo6_]?ob;kAolRnd@03olRnd@Gobl?B0_o>aM83olk8e@Cod<_E00CodloFom;Af?oBdMSo
d]7H1?oDe]X3om?KgP?oe>7P0ooEin<01?oBiNGod>_Wom3[ioo@jnL2olk`jP?ob?G/00Coa_3_okoc
lOnolo7o_o?a0_nfm?82ojWcl`03ojk_monSk_SoXnkh00;oXnkh0_nFj_T2oioWo003ooooool0003o
oooo02;ooooo00?o0000ooooooooool02?ooool001oooooo0_l0000=ooooo`?o0000@oooool6ofbW
m0OoJjOd0_mZYo@00omZY_CoJJKdofVVm005ofVVm0KoJ:Kd1_mXYO@01?mYYOCoJJKdofVVm?mYY_@4
of^Vm0?oK:Kd1?m_Yo<3og:Xl`03oj7CnOmfZ_?oMZ[c00;oMZ[c1?mjZo84oh2]l@CoQZo`1?n=/^l5
oi>dk@;oVkK[0_nK/NL5oj6ci@GoYkGS00?o[KOQojfbgOn]/]d00_n]/]d6ok6ef`03okJgf_nf/mKo
][?F00;o][?F0oni]]H3okZbdPGo_KKC00?o_[C@ol6hdOo1^=400oo1^=400oo2]looa;[AolBjd@03
olBjd@03olJjcoo8_]7ob;kA00?ob;kA0_o:_m03ol_3dPCoc/GB00?oc/SEom3;eOo@bmD00_o@bmD3
om??eP03om;Af?oDe][oe=KJ00;oe=KJ0_oFfm`01?oCfmkoe>7PomCQh?oDhN03omGWh`?oe>kU00?o
d>_Wolk`j_o>l>X00oo8mN`2okohk@03okoclOnfm?;o]_Cb00?oZO?c0onJl?800onSk_SoU^[ioiKZ
n@06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool001oooooo00?o0000
ooooooooool02Oooool3o`0004Oooooo1_m/Yo@7of^Wm0?oJZOd1_mYY_@7ofRVm0OoJ:Gd1?mYYO@2
ofZUl`?oK:Kc00?oK:KdofnWlom_Yo<00_m_Yo<4og:Xl`CoMZ[c1?mjZo84oh2]l@CoQZo`1?n=/^l2
oi>dk@;oU;3Z1OnK/NL5oj6ci@;oYkGS0onW/=l5ojfbg@Co/KGK00?o/K3GokJce_nf/mH01?nf/mH0
0oni]]Ko^[;BokZbdP02okZbdP?o_KKC1?nn]=03ol6hd@?o`[O?0oo4^]43olJjc`?ob;kA1?o:_m00
0oo;`m;oc/GBolk5dP02olk5dP;od<SB0oo@bmD4om??eP04omKDeooDe][oe=KJomCFfP?oe]_L0_oH
h]h01?oDhN3oeNOSomGWhooEin<3omC^i@;odOCW00Coc_3ZolSek?o8mNcob?G/0_non>d2ok;hk0;o
XOGY00GoZO?coi[`l_nJl?;oV_3bohSYl00:ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool02?ooool001oooooo00?o0000ooooooooool01_ooool3o`0004_ooooo1om/Yo@6of^Wm0?o
JZOd1_mYY_@4ofRVm0[oJ:Gd1?mYYO@2ofZUl`CoK:Kc1?m_Y_<3og:WlPCoMZSb1?mkZO44oh6[k`Co
Qjc^1?n=[^`5oiB`jPGoVk7W0_nQ/nD2oj6^h@KoYk3O1On]/]d00ona]M_o/K3Gok6`e`02ok6`e`Co
][?F00?o]ZoBokZbd_nj/]801?nj/]800onm]]?o_[C@okjdd004okjdd003ol6hdOo2]loo`[O?00?o
`[O?00?oa;[AolJjcoo6^/l00oo6^/l00oo8_]7ob[o@olZod002olZod0;ocL7?0oo>aM84om38dP03
om3;eOoCcmKodloF00;odloF0ooFe=L01?oDe][oe]_LomKKg?oFfm`3omSRgP;of>SP00CoeNOSomC^
iOoDk^Goe>kU0_oAm>L3ol[ij004olSek?non>go/_S/ok;hk0;oXOGY0on;kN@?ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool02?ooool001oooooo0ol00003ooooo`?o0000Coooool7
ofbWm0KoJjOd0omZYo@4ofVWm0KoJ:Kd3OmXYO@3ofVUl`CoK:Kc1?m_Y_<3og:WlPCoMZSb1?mkZO44
oh6[k`CoQjc^1?n=[^`5oiB`jP;oVk7W0_nJ[N@5oj6^h@KoYk3O0_n]/]d2ojb]f0Ko/K3G00?o][?F
okJ_d_nf[m800_nf[m84okZbdP03okZ`conn]=3o_[C@00Co_[C@00?o_k;=ol:gcoo2]ll00oo2]ll0
0oo4]/coa[[?olJjc`03olJjc`;obK_=0oo:_m04olg1c`03olk5d_o@b=;od<SB00?od<SB00CodlgC
om??e_oCcmKodloF1?oFe=L3omKKg0?of>;N0ooHj>02omS`hP03omC^iOoAm>OodOCW00?ob_WX00Co
__cWojcih_n/nN;oTo7I0omdh/`00on;kNCoooooooooo`0@ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02?ooool001kooooo0_l00002ooooo`?o0000Doooool4offWm0KoK:Od0om[
Yo@3ofZWm0CoJJOd0omXY_@3ofNVm0?oIjGd0omVYO@7ofRUm0CoJJGc1?m/YO<2ofjUlP?oLJGa00?o
LZObogJXl_mfZ?800_mfZ?84og^Yl@CoPJ__1?n7[>h4ohf^k0;oU;3Z0_nDZnH5oiZ]i0GoXJkQ0onW
/=l2ojJ[fPGo[:gH1?na/=L00ona[=;o]ZoBokJ_dP04okJ_dP03okZbd_nj/<oo^[3?00;o^[3?0onn
]=04oknbc@?o`[O?0oo4]/`3olJjc`CobK_=00?ob[o@olg1coo=`Ll00oo=`Ll5om38dP?odlgC00?o
dloFomKDeooFe=L00_oFe=L2omSJf@04omKKg?oHh]kof>;NomSRgP?of>SP0ooHl>801?oDmnCodOCW
ol[ij?o:nNP2okkli`;o[?WR00?oTo7IogCRc?mdh/`05_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Sooooo000Dooooo`Co000000?o410@ooooooooool00oooool4o`0005Oooooo
1?m]Yo@6ofbWm0?oJjOd1?mZYoD2ofVWm@?oJ:Ke00CoJ:KdofNVm?mWY_CoIjKd0omWYO@4ofJUm0?o
IZCd0_mWY?@00omXYOCoJJGcofVUl`02ofVUl`CoK:Gc0_m^YO84og6Ul@CoMZK`0omkYnl4oh2Xk@Co
QZW[1?n=Z^T5oiB[iPGoVZgT0_nQ[^42oj2Yg@KoYZ_J1On/[MP00ona/=Oo/JcBok6/dP02ok6/dPCo
]ZoB00?o]Z_>okZ`conj/<l01?nj/<l00onn]=3o_k;=oknbc@04oknbc@03ol:gcoo4]/coa;K<00?o
a;K<00?oa[[?olVkcOo9^ld00oo9^ld5olg1c`;od<G?0oo@b=84om?=d`04omOBe?oFe=Ooe]CGomKD
e`?of=[I0_oKh]/01?oHh]kof>SPomSXh?oHj>03omS`hP03omCgi?o<o>?oc?cS00;o^ogM00Go__cW
ojcih_n/nN;oElZVo`00000Hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool001Kooooo00?o0000ooooooooool01Oooool2o`0005_ooooo1_m]Z?@2ofbXm004ofbWm?m[YoCo
JjOdof^Wm0CoJZOe0_mYYoD4ofRVm@CoIjKe00?oIZGeofNUm?mVYO@00omVYO@3ofJTm0?oIjCd1?mX
Y?<3ofZTl`?oK:Cb1?maYO44ogJVl0?oNjO_1?n0Z>d4ohJYj`CoSJ[Y1OnDZnH2oiZ]i0;oVZSP1OnP
ZMd5ojJ[fPCo[:gH00?o[:SCok6/d_na[=800ona[=83okJ_dP?o]Z_>1?nj/<l00onk[L_o_k;=oknb
c@05oknbc@Koa;K<1Oo9^ld2olbmc0?ocL7?1?o@aLl00oo@b=;odlgCom?=d`02om?=d`?oem;D00Co
e]CGomSJfOoHf]Wof=[I0ooKh]/2omcYg@05omSXh?oHl>;of?3RomS`h_oDmn@00_o<o><2ok_mg@;o
X_KA00?oElZVooooooooool06_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0FOooool6offXm0?oK:Sd
1?m[Z?D3ofZWm@;oJ:Oe1?mXY_D4ofNVm@;oIZGe1?mUYO@3ofFTm0;oIJ?d00?oIjCdofRTlomXY?<0
0_mXY?<3ofZTl`CoK:Cb0om`Y?43ogBTk`?oNJC^00?oNjO_oh2XkOn0Z>d00_n0Z>d4ohJYj`CoSJ[Y
0_nDZnH2oi:Wh`GoVZSP1OnPZMd5ojJ[fP03ojb]f?n/Z=?o[:SC00;o[:SC1Ona[=800onf[m;o]Z_>
okJ[cP02okJ[cP?o^[3?0onk[L/5oknbc@;o`K3:1?o4]/`2olJfb`?obK_=1?o<_L`00oo=`Lood<G?
om35c`03om35c`04omC9cooCcM?odlgCom?=d`Coem;D0_oJfMH01?oHf]Wofn;Kom_RfooKh]/3omcY
g@;og?;N00Cof?3RomCgi?o<o>?oc?cS0_nkoMd00onRm]7oooooooooo`0Nooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool001Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Iooooo`?oKZSd0om]Z?@2ofbXm@03ofbXm?m[Z?GoJjSe00;oJjSe0omZYoD3ofRW
m@?oIjOe0omVY_D3ofBUm@CoIJGd0omUY?@4ofFSm0;oIZ?c0omWX_800omZY??oK:CbofbTlP02ofbT
lP?oL:Ca0omdY>l4ogVTkP?oOjG/1?n5YNT4ohbViPGoTZOS1?nJZ>06oj2Yg@;oYZ_J0_nVY]H5ojbX
d`Co/JcB00?o/JO>okJ[c_nfZlh01?nfZlh00onj/<oo^jg;ok^]b`03ok^]b`?o_k;=0oo1/<X3olBf
c0Coa[K;00?obK_=olbmc?o<_L`00oo<_L`5om35c`?oe<W?00?odlgComOBe?oGd]@00_oGd]@3om[I
eP?ofn;K0ooLjMd2omcbgP;of?[N0_o>om/00onho<ooU>biofK?VP0Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool001Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Iooooo`?oKZSd0om]Z?@3ofbXm@CoJjSe0omZZ?D3ofRWm@?oIjOe0omVY_D4ofBUm@?o
HjCe0_mSXo@00omUY?CoIJ?dofFSm002ofFSm0;oIZ?c1?mWX_83ofZRl@?oKJ7`00CoL:CaogBTkomd
Y>ooM:C_1?miY>h3ognUk0CoQJGY1?n<Y^H5oi:Wh`CoVZSP0onPZMd2oijTf@GoYZKF1On/Z=<00ona
[=;o/JO>ok6WcP02ok6WcPCo]Z_>00?o]jS:ok^]bonk[L/01Onk[L/00ono//go`K3:ol6`bP03ol6`
bP03olBfc?o6]/_oa[K;00?oa[K;1Oo<_L`2olo0c0?od<G?1?oDbLl01?oHd=3oem;DomOBe?oGd]@3
om[IeP;ogN7G00Cofn;KomcYgOoLjMgog>WM0_oLl]h2omSjgP;oc_oK00?o^?c?ofK?V_mVciX08ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo000Fooooo`03o`000?oooooo
oooo00[ooooo0_l0001Jooooo`CoKjSd00?oKZWdoffXm?m/Z?D00_m/Z?D4of^Xm@?oJZSe0omXYoD4
ofJWmP03ofBVm_mVY_GoI:Ge00?oI:Ge0omSY?D3of>Sm0?oHZ?d0omSX_<4ofNRlP?oJZ;a1?m]XO03
og6Qk`CoMZ7]0_mlXNX00omoYNcoQJGYohFUj@02ohFUj@CoS:KV0_nBYn<2oi6Rh0GoV:?L1OnNY=T5
ojJVeP;o[:SC0_n/Xlh6ok6WcP03okJ[c_ngZ<[o]jS:00;o]jS:1Onk[L/00onmZ/Oo`K3:ol6`bP03
ol6`bP03olB`aoo6]/_oa[K;00?oa[K;0_o9]lT3olbmc0Cocl3<00?od<G?omC9cooDbLl00_oDbLl3
omS@d004omOBe?oJfMKof]WFom[IeP?ogN7G0_oPjMT00ooLjMgog?;NomcbgP02omSjgP;oc_oK00?o
^?c?o`000?ooool09Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo000F
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool4ofnXm0;oKZWd1?m]ZOD3
ofbYm@?oJZSf0_mXZ?H00omXYoGoIZOfofJWmP02ofJWmP;oI:Kf1?mSYOD3of6Tm@;oGj?e00CoHj?d
of:Sm?mRXoCoHZ?d1?mSX_<2ofBQlP?oIZ3a00?oJZ;aoffQl?m]XO000_m]XO03og6Qk`CoMZ7]0oml
XNX4oh>Qi`CoRJ7T1?nAX^05oiRSg0CoWZCI1?nVY]H00onUX=3o[:?>ojbScP03ojbScPCo/JO>00?o
/J;8okNXb_ngZ<X01?ngZ<X3ok^]b`?o_J[70oo1/<X3olB`a`?oa[K;1?o9]lT00oo<_Lcocl3<olo0
c003olo0c004omC5c?oDbLooe<W?omC9c`Cof=3@0_oLem801?oJfMKogN7GomgQeooMhML3on3Yf@;o
h??J00Gog?_IomSjg_o>om_oc_oKo`00000Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01oooool001Cooooo00?oEEEEofIVI_l000003oooool00ol0003oooooooooo`1Hooooo`?o
LJWd0om`ZO@4offYm@?oK:We0omZZ?H3ofRXmPCoIZOf0_mSY_H4of>Um@?oHJCe0omOXoD2oenRm003
of:Sm?mSX_?oHj;c00;oHj;c0_mTXO84ofJPl@?oJ9o`0om]W^h00omaXNooMZ7]ogJQk@02ogJQk@?o
O:7Z1?n3XNL4ohVQi0CoTJ;P1OnHXm`4oijTf@03ojJVe_nUX=3oYJ3@00;oYJ3@1?n/Xlh3ok6WcP?o
/J;81_ngZ<X00onk[L_o_J[7okfZa`03okfZa`03ol6`b_o4/<Ooa;3700?oa;3700?oa[K;olVgbOo9
]lT00oo9]lT5olo0c0?oe<G<00?oe<W?omS@d?oHd=000_oHd=03omcGdP?ogN7G0ooPjMT2on3cfP;o
g?_I00?od?oAok;g_?ooool0:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo05Sooooo0omaZO@3og2Ym0CoKZ[e0om/Z_H2ofZYmP04ofZX
m_mXZ?KoJ:SfofRXmPCoIZOf0_mSY_H4of6UmP;oGZCf00CoHJCeoenSmOmOXoGoGj?e0omOX_@4oejP
l`;oGiob1?mVX?43ofROl0?oKIk^1?maWN`3ogRMj@03ogbQj_n3XNOoPj7W00;oPj7W1?n9XN@4oi6R
h0;oV:?L0_nFWMT4oifNe0GoYJ3@1On/Xlh00onaYlko/J;8ok6Rb002ok6Rb0Go]jS:00?o^:C5okfZ
aonmZ/L01?nmZ/L6olB`a`KobKO900Coc[[7olo0c?o?`<cocl3<1?oDaL`01?oIc<gof=3@omS@d?oH
d=04omcGdP03on3OdooMhMOoh>WI00;oh>WI0_oPlmX2omckf@03om3odOnbmkcooooo02cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`00:?ooool2o`0005[ooooo00?oLZ[d
og6Ym?m`ZO@00_m`ZO@4ofjZm@?oK:[f0omZZOH3ofRYmPCoIJSf0_mRYoH4of6UmP?oGZCf0omLX_D2
oe^Qm003oenRm?mNX??oGZ3c00;oGZ3c0omOWo82of2Ml@?oHic`00CoJ9o`offNk_m]W^koKIk^1?ma
WN`3ogRMj@CoOYcU1?n6W>44ohjLg@GoUYgI1?nMW]@4ojFPd0Co[:?>00?o[9g8ok6Rb?naX/P00ona
X/P3okNXbPCo^:C51?nmZ/L2ol2Za0Coa;370_o7/LD4olVgb@?oc[[700?ocl3<omC5c?oDaL`00ooD
aL`2omW<c@03omS@d?oLem;og=OB00;og=OB0_oPgm<2on?Xe003on3YfOoPlm[oh??J00;og?_I00?o
d?oAojoaZ_ooool0;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo000Z
ooooo`03o`000?oooooooooo05Sooooo0_mbZ_@4og6[m0?oKj_e1?m]ZoH00om[ZoKoJZWfofRYmP02
ofRYmPCoIJSf0omRYoH3oenVmP;oFjCf00CoGZCfoebRmOmLX_GoG:;e0omKXO@3oeVOl`?oFIgc00?o
Giobof2MlOmPWO400omSW?03ofNKkP03offNk_maWNcoLIg/00;oLIg/0omhWNT4ogjLi@CoQYcQ1?n>
W=d4oiJMf@CoWIkD1OnUX=000on/Xlko[9g8ojbMb002ojbMb0Go/J;800?o]jS:okRTaOnhY<D00onh
Y<D3okfZa`?o`:[40oo4/<L3olNaa@?obKO91?o>^/L5omC5c0?ofLc=00Cog]?>omcGd_oLem;og=OB
0_oPgm<3on?Xe0;oiO;E0_oQo=800ooColOo[o6Zooooo`0`ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01_ooool002_ooooo00?o0000ooooooooool0F?ooool2ogB[m0CoLJ_d0om_
ZoD4off[mP;oJj_f1?mXZ_L3ofBYm`;oHJSg00CoHZOfoenVm_mOY_KoGjKf0omKY?H4oeRRmP03oeFP
mOmKXOCoFIoc00;oFIoc1?mIWO<2oeVKl@?oHic`1?mWVnh3of^Ij`?oLYWX00?oN9gYogjLiOmnW>D0
0_mnW>D3ohJLh@CoSYcM1OnFWMT4oifNe0;oYJ3@0_nSVL/5ojbMb0Co/J;800?o/ik3okRTaOnhY<D0
1OnhY<D00onmZ/Oo`:[4ol2Za003ol2Za003olB`aoo7/LGoak7500?oak7500?obKO9oljjaoo>^/L0
0oo>^/L01?oC`<Ooe<G<omC5c?oDaL`4omW<c@;og]?>00?og=OBon3OdooPgm<00ooSj=@3onGbe@;o
hOcB00?o[o6Zooooooooool0<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Ko
oooo000/ooooo`03o`000?oooooooooo05Sooooo0_mdZo@4og>/m@?oLJcf1?m_[?H2ofb/m`CoJ:[g
0omTZOL3of6Xm`CoG:Kg00?oF:Cgoe^Tm_mHX_H00omHX_H2oeFPm@;oDigd00?oFIocoeVMlomIWO<0
0_mIWO<3oeVKl@03oe^Il?mSW?3oIi_^00?oIi_^0om[VN/3og:Ij0CoNIST0on0Uml00on6W>7oSYcM
ohjLg@02ohjLg@;oUYgI0_nBUmD4oiZGc`GoXiW;1On/WLP00onaX/So/ik3ok>N``02ok>N``Go^:C5
00?o^Z?1ol2Za?o0Z/@01?o0Z/@6olNaa@Goc[[70ooC`<L00ooDaLcofLc=omW<c@02omW<c@?og]?>
00?ohmc?on3OdooSj=@00_oSj=@3onGbe@;ohOcB00?o[o6Zooooooooool0<_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Kooooo000]ooooo`03o`000?oooooooooo05Oooooo0omg
[?@4og>/m@?oLJcf1?m_[?H3ofb/m`?oJ:_g1?mTZ_P00omOZOSoHJSgoebVm`03oebVm`;oF:Cg1?mC
X_H2odnOm@?oDigd0omAV_<3oe2Hl@03oeVKlOmKVO3oFiW`00?oGiO^0omSU>/01?m[VN_oLYWXog:I
j?mbVNP4ogVHi0?oP9OO1?n9UmX5oi:Ge@CoVYO?1?nSVL/4ojbMb003ojbI`oncW/?o/ik300Co/ik3
0onhY<D3okZS`@Co`:[40_o3ZL04olNaa@;obkC30oo>^/L4om?0a`04om[8b?oIc<gofLc=omW<c@Co
g]?>00Cohmc?onOVd?oWi]3ohnSD0ooUl]D2on7ldP03oj_YU_oooooooooo03Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`06ooooo`00;_ooool2o`0005Sooooo1?mg[?@3ogF]m@Co
Ljgf0om`[OL4off]m`03ofV]n?mXZoOoI:[h00?oI:[h0omOZOP3oeZWm`;oE:Cg1?mCX_H3odnOm@03
od^Km?mCWOCoDI[c00;oDI[c0om@V?43oe6El0?oGiO^0omSU>/3ofVCi`04og:Ij?miV>CoNISTogVH
i0CoP9OO1?n9UmX4oi:Ge@CoVYO?1OnSVL/00on/WLSo[9W3ojbI``02ojbI``Ko/ik300?o^:C5okZS
`OnjXl400_njXl43ol2Za0?o`jW00oo7/LD4ol^d``03oljjaooC`<Oodl3700?odl370_oJb<P00ooI
c<gog]?>omkCcP02omkCcP;ohmc?0_oWi]02onWac`04onGbeOoQo=;ohOcBoj_YUSOooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`06ooooo`00<?ooool00ol0003oooooooooo`1Foooo
o`CoMjcd0ome[OD4og>]mP?oL:gg1?m][OL2ofV]n0CoI:ch0omNZ_P2oeRXn004oeZWmomDY?OoE:Cg
oeBTm`?oCj7f0_m8WOD00om?WoGoBi_dod^Km002odNHlP04oe6Jlom@V?7oD9Saoe2Hl@?oDIG`0_mC
T^d01?mOUnkoHiC[of>DjomSU>/3ofVCi`?oLI7S00?oNISToh2Ggon0Uml00_n0Uml3ohVGfPCoTYOE
1OnJUll2oj>Ib`;oXYC61On/VL<5ok>N``03ok>I_OnjXl7o^Z?100Co^Z?100?o`:[4ol>Y`?o3ZL00
0oo3ZL000oo7/LGobkC3ol^d``03ol^d``Godl370ooJb<P01?oOd<Wog]?>omkCc_oNdlh2on?Lc`?o
inK@0_oYlLl2onKkb`03omSm_?oooooooooo03Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`05ooooo`00<Oooool00ol0003oooooooooo`1Fooooo`CoNZgc0omh[_D4ogJ_mP?oLZog
1?m_[oP2ofZ_n@CoI:ch0omNZ_P3oeRXn0CoDJGg00?oBJ7fodnQm_m8WOD00_m8WOD2od:Il`?oAiSb
0_m5U?401?m@V?7oDIG`oe6El?mAUO02oe>Bk@?oEXo[00CoHiC[ofVCiomYTnOoJI?W0omaTN<4ogV@
g@?oPhoG00?oRIOJoi:GeOnBUmD00_nBUmD2oiZGc`;oUY3;1OnRU<H4ojbI``?o/ik31?ncVKd5okZS
`@Ko`jW01_o;]<<01?oB^/?odl37om?0aooC`<L4om[8b0;ogm3900?og]?>on?LcooSg<l00ooWi]02
onWac`;oi__;00?of?flooooooooool0>Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Gooooo000booooo`03o`000?oooooooooo05Kooooo1?mj[O<3ogR^m@CoMZof0omb[oL4ofn_
n0?oJZoi0omT[_T3oej/n@;oEZWi00?oF:Shoe6UmomAYOL00_mAYOL2odVQmP;o@9cd00KoB9geod:I
lom2VO?o@YWcocbDlOm7V?83odFDl@;o@i3_00?oDIG`oe>BkOmCT^d00omFSn/3oef=i`04ofVCioma
TN?oLI7Sog6Ah`CoNI3M0on3SmL4ohb?d@GoUY3;1?nRU<H5ojbI``03ok>N`oncVKgo/iVm00?o/iVm
1?njXl42okbO^`Go`jW000?ob:bnol^d`oo;]<<00_o;]<<3om:j``03om?0aooJb<Sof/S800;of/S8
0ooOd<T2onCIbP03on?LcooWi]3oinK@00;ojO7?0_oVnl/00ooHoKcoooooooooo`0kooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01Oooool003?ooooo0_l0001Hooooo`?oOJkc0omk
[o@4ogR`mP?oMK7g1?ma/OP3ofban@;oIK3j00CoI:kioej/nOmN[?WoGZci1?mFZOT3odfVn0;o@j7f
0om0W?@2ocNGlP03od:IlollU?7o?9Ca00;o=Xo_00CoAICaod>@kom3T>oo@i3_0_m4S>d3oeJ?j`?o
GHgW0omTR^801?maTN?oNI3MogV@gOmiT=d4oh>?e`CoS8oA1?nFT</4oj:DaPCo[9W300?oZi6kok>I
_OncVKd01?ncVKd3okZS`@?o_9nk1?o3ZL02olR/_P?obkC31?oB^/<01?oJa<Cof/S8om[8b?oJb<P4
omo@b@;oi=W:00CojN?;onOVd?oYlLoojO7?0_oVnl/2omSm_3gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`05ooooo`00=Oooool00ol0003oooooooooo`1Fooooo`?oOJkc0omk[o@4
ogR`mP?oMK7g1?ma/OP3ofban@CoIK3j1?mN[_X2oeF/n@;oBZOh00KoCJKhod>Qm_m3XOKo@j7focRK
lom0W?@3ocNGlP;o;Y3_0olfSnl2oc:9k@03od>@kom4S>goA8c]00;oAXSZ00CoEXo[oef=iomMSNOo
GHgW0omTR^82off8g@03ogV@gOn3SmOoPhoG00;oPhoG1?n<Sm44oiJ@b`GoXYC600?o[9W3oj^A^on[
TK/00_n[TK/6ok>I_@03okZS`OnlWk_o_9nk00;o_9nk0oo3ZL04olR/_P03ol^d`ooB^/?od[[300?o
d[[30_oJa<@00ooJb<Sogm39omo@b@02omo@b@?oi=W:00?ojN?;ong^bOo]k/T00_o/n<D2omkl]3oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`00=_ooool00ol0003ooooo
ooooo`1Fooooo`?oP;3c1?mn/O@4ogbbmPCoN;?h0omc/oT3ofjcnP?oIk?k1?mO/O/2oeB^nPCoBZOh
0olnX_D01?l_V_7o>9_cob^DkolgUo82obj@k`;o9HW/00Ko=Xo_oc:9kOlbRNgo<XW]oc24j_m4S>d2
odJ8jP;oC8GV00?oGHgWofB:h_mTR^800_mTR^83off8g@CoPhoG0on<Sm45oiJ@b`?oXYC600?oX8^m
oj^A^on[TK/00on[TK/6ok>I_@Ko_9nk00?o`jW0olR/__o8[;h00oo8[;h5om:j``?of/C400Coh<c5
omo@bOoOd<Wogm390ooTfLX2onWSb`;okNk90_o/n<D2omkl]43ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`00=oooool00ol0003oooooooooo`1Fooooo`?oP;3c1?mn/O@2
ogbbmP;oOkCf1?ml]OP3ogNfn@;oLKKk00CoK[?jofNcnomW/o_oIk?k1?mO/O/3oeB^nP?oAjWh0_li
Xo@00olnX_Go;i[aobnJl@02oanAj`03ob^DkolNRn_o9HW/00;o9HW/0_lLPNP00olbRNgo<8CZoc24
jP02odJ8jP?oC8GV0omTR^83off8g@CoNXSF0on4Qlh00on<Sm7oUY3;oiJ@b`02oiJ@b`03oj:Da_nP
RkgoX8^m00;oX8^m1On[TK/4ok>I_@;o/i2b1OnlWk/6olR/_P04om2c__oB^/?od[[3om:j``Cof/C4
0_oPc<D01?oOd<Woi=W:onCIb_oTfLX2onWSb`;okNk90_o/n<D2omkl]4;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`00>?ooool2o`0005Oooooo0on4/O85oh:cm0?oOkCf
1?ml]OP3ogNfn@CoLKKk0omZ]_`4of6do0?oEK7k00?oAZchodNYn?liXo@00oliXo@01?lVVNko7i7[
oanAjolOTN/2o`f5h`03oaj;jolURNco787X00;o787X00Co57SToc24j_l_O^Oo;gkW0_m<QNH3oe>1
h@04ofB:h_m]R=goKHSMoff8g@CoNXSF0on4Qlh4oi:7a@GoX8^m1On[TK/3ok>I_@?o/i2b1?nlWk/2
ol:R^0Cob:bn0oo@/kh00ooB^/?of/C4om[4a002om[4a0?oh<c50_oUe<D00ooTfL[ojN?;onWSb`02
ong^b@;ok?S50_oNo;A3ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
03[ooooo00?o0000ooooooooool0EOooool3ohBalP;oP[?d0on6]O@3oh>fmPCoP;Sh0omk^OX4ogFj
n`CoKKWl1?mS^?d3oeNen`03odJ`n?m6[?So=:Cc00?o=:Cc00?o7iWZoa:>iOlOTN/00ol=QN<01?l0
N=[o0WKNo`9fg_lLPNP2oaAhi0;o;gkW00?o<GWTodb5i_mCPN400_mCPN42oeanf`03off8gOmjR=Ko
NXSF00;oNXSF1?n4Qlh4oi:7a@GoX8^m1On[TK/00oncVKgo/i2bok>@/P02ok>@/P?o_9nk0oo2X[P3
olR/_PCod;>n1?oJa<@4on3<a@;oiMC50_o[g/D00ooYhl_okNk9ong^b@02oncha@03omkl]?oooooo
oooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`00>oooool00ol0
003oooooooooo`1Eooooo`CoR;?b1?n6]O@3oh>fmPCoP;Sh0omk^OX4ogFjn`;oKKWl0omb_Od3ofNl
o@;oF[[l00CoEkGkodJ`n?m6/?SoA[3h1?lbYo401_lIVNGo1X[Moa:>iOl0O]Wo3HGSo`1hfP?o0WKN
00Co06WGoaAhi?l@L>3o;gkW0_laNN@3oe>1h@?oG7kK0omjR=H4ohB7cPCoTXO51OnPRkd4oj^A^`03
ojV4[OncT;;o/i2b00Co/i2b00?o_9nkol:R^?o2X[P00oo2X[P00oo8[;kod;>nom2c_P03om2c_P04
omZo_ooJa<Cof/C4om[4a0?oh<c50ooUe<D2on_Na@05oo3Ya?o]k/Wok?S5onchaOoXnJh0Aoooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo000looooo`03o`000?oooooooooo
05Gooooo0_n8/o83ohbdl@?oR[Oc0on8^OH5ohBjn0?oOkcj1?mj_O`4og:mo@?oIkcm1?mJ^_`3odRd
n0Co<Z[_00So59[Po`27e?l6R]go07K<o`1nfOl0K<[o06S?o`9fgP;o06WG0_l@L>02oc5ii003ocMd
gomCPN7oG7kK00;oG7kK0om/O]<01?mjR=KoQ8O>ohB7c_n4Qlh4oi:7a@GoX8^m0on[TK/2ojV4[@Ko
/i2b1_o2X[P5om2c_P?of[no00Cof/C4on3<aOoPc<Goh<c50ooUe<D3on_Na@03oo3Ya?oalkoolO>o
00;oj?V^Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo000mooooo`;o
0000E_ooool5ohbdl@?oR[Oc0on8^OH2ohBjn0?oRKgh1?n5_oX4ogo1o0CoMl7n0om]`Oh4oenoo@;o
CKWh0omC`?T00olj]^ko=:o^oaFNg003oaFNg009o`1fc?l0GkGo06S?o`1G`_l0JMOo05g@oa1`h?l;
Im_o<GWT00;o=gCO0omLO]/3ofand`?oMGW900?oQ8O>oi:7aOnBQlD00_nBQlD5oj2;_@03oj^A^onY
Q:goZHB]00;oZHB]1OncT;800onmU:go`Z:hol:R^003ol:R^004olf/^?o@/kkod;>nom2c_PCof[no
00CohLS0on3<aOoPc<Goh<c50_oUe<D3on_Na@;ol>W40_oalkl00ooXnJkoooooooooo`17ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool003oooooo00?o0000ooooooooool0
E?ooool2ohbdl@?oT;K`0on?^?85ohbkm@?oRKgh1?n5_oX2ogo1o0?oQLCl1?mna_h3ogC6o`;oI/Gn
1?m_boh3oeg7nP;oA;k_1?mBb?42oc6gf`;o05O20_l0GM02o`]Wf`;o=gCO00?o?foIoeanfom/O]<0
0om/O]<3ogEib@?oRWNi00CoTXO5oj2;_OnPRkgoX8^m0_nLO:l5ojV4[@Co/i2b0_nmU:d4ol:R^0;o
cJbh0oo@/kh4omZo_`;ohLS000Coh<c5onGDaOoUe<GoiMC50_o[g/D2oo3Ya0;olO>o00?oj?V^okkV
Poooool0BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0010ooooo`03
o`000?oooooooooo05Cooooo1On@]_03ohnhlP;oS;_e0onA_O@4ohjom`CoR/;j0_n5a?`2ohc7o0Go
QL[n0omlbol2ofo;oPCoN]7o0_mYco/2ogOGo@?oQ]km0_meg?L2ooooo`04o`1G`_l0A[Ko05g@o`1>
a`;o35oG00?o=gCOocm_fOloKmT00om/O]<4ogEib@?oRWNi1OnLO:l5ojV4[@?o/i2b0onmU:d3ol:R
^0CocJbh00?od;>nomZo_ooJ_kl00_oJ_kl3on78`0;oi]3000CoiMC5on_NaOo[g/Gojmk50_o`jL@0
0ooalkooj?V^onSi[P1<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
047ooooo00?o0000ooooooooool0E?ooool2oi2fl0?oUKO_1?nC^_84oi6mm0;oS[og0_nD`_H5oi35
n@?oS<Ol0_n5b_h4ohg>o@;oQM3o0on>e?l2ohGGo`CoTMco0_n6g_d7ooooo`;o04Jf00Go04k7o`aO
eol<GmOo35oGocm_f@02oda/dP03ofandomeNLWoMGW900;oMGW91?n:MkT5oial[`GoZHB]0_ncT;84
okfD[@;o`Z:h1?o=[;P4omZo_`CohLS00_oVd<02oncI`003on_NaOo`jLCol>W400;olO>o00?oj?V^
omC[Qoooool0Boooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo0012oooo
o`;o0000EOooool5oiFgk`;oTk[b0_nH_?44oiJol`CoU<;f0_n@aOT3oiK7n0CoT/_k0_n=c_d4oiGA
o0;oS]Co0onHf?d2oi7Lo`gooooo00Co04Jfo`0cZOl<GmOo35oG0_l=Em43oda/dP?oMGW91?n:MkT5
oial[`GoZHB]00?o/i2bokfD[OnmU:d00onmU:d00oo2X[SocJbholf/^003olf/^004ombm^_oJ_koo
f[noomZo_`?ohLS00ooVd<02oncI`0;olN>n00Col>W4oo7c_ooamJcoe>^7C_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo0014ooooo`03o`000?oooooooooo05?ooooo0_nE
]nl3oiVikPCoV;ca1?nF_o<2oiC2mP?oVLCe1?nFaoP2oi;;n`?oVLgj0_nEdO`4oicCn`;oV=Sm4_oo
ool00ol0<jWo046oo`aOe`02o`eGd@;oC6cB0_lmE/<2ogEib@?oRWNi1OnLO:l5ojV4[@Ko_IB]1Oo=
[;P3ombm^P04omZo_ooQb<3ohLS0on78`0?oi]300oo/fL02oo7S_P03ooC/^_oamJcolOF/053ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`00AOooool00ol0003ooooooooo
o`1Dooooo`CoVKW^0_nH_?42oifmk`GoVl7b0_nIa?D2oik6m0GoW<Wg0_nIcOX3oj3?n0;oW=?k6?oo
ool01?l0@Koo3EOAo`eGdOl=Em42oda/dP;o?EK300?oMGW9ohYg^On:MkT00_n:MkT4oial[`GoZHB]
1_nmU:d01?o?Xj_ocJbholf/^?o=[;P4ombm^P04on?6^ooQb<3ohLS0on78`0?oi]300_o/fL03oo7S
_P03ooC/^_oamJcoe>^7057ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`00A_ooool00ol0003oooooooooo`1Dooooo`CoWK[]1?nM_Nl2oi_1lP?oX<;a1?nNa_@2oic9m`Co
X/_e0_nPcoPLooooo`05o`0QW?l=Em7o3EOAo`];bOm<K=800olmE/<4ohYg^@CoW7b_1?nYQ:d2ok67
Z@Co_IB]0_o?Xj/3olf/^0Cog;fj0_oSa[/01?oQb<3oi]30onK@`?oVd<03oncI`0;olN>n00?om>bj
oo7e[?oamJ`0D_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0017oooo
o`03o`000?oooooooooo05Cooooo1?nM^^d2oifmk`;oXKk^1OnP`_42oik6m0?oXlOb0_nRboDQoooo
o`05o`0QW?l0<KKo3EOAo`];bOm<K=800olmE/<3ohYg^@GoW7b_0_nYQ:d3ok67Z@Co_IB]0oo?Xj/0
0oo=[;Sog;fjombm^P02ombm^P?ohlJk00?oilflonK@`?oVd<000oo/fL03oo7S_P03ooC/^_oamJco
_M5I05?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`00B?ooool2o`00
05Kooooo1?nR^n/3oj6nkP;oX<;a1?nU`nl2oj?7lRKooooo00?o036fo`];bOl;BlT00olmE/<2og5V
]P;oRWNi1?nLO:l00onYQ:go/HNYok67Z@02ok67Z@?o_IB]1?o?Xj/4ombm^PCohlJk0_oWcK`00ooV
d<3ok=W0oncI`003oo7S_P03ooC/^_oamJcoe>^705Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`00B_ooool00ol0003oooooooooo`1Dooooo`;oX[_[0_nV_>T4ojG0k0;o
YL?_:oooool00ol0<KKo2d_9o`];b@02oceF``CoLFJf0_nLO:l2oi]i[0Go/HNY0onmU:d4olnSZ`04
onNmZooL_K[og;fjombm^P?ohlJk0ooWcK`2oncD_003oncI`?oahkkolN>n00;om>bj00?olOF/okgA
FOooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo001;ooooo`03
o`000?oooooooooo05Cooooo1?nV_>T2ojG0k2oooooo00?o01NRo`];bOlmE/<00_lmE/<3og5V]PCo
VgV/1_naQjT00onmU:gocj>[olnSZ`02olnSZ`?oikf[00?og;fjon?6^ooSa[/00_oSa[/3onO=_0;o
k=Bl0_oafkX01Ooahkkom>bjooC/^_ocl9go_M5I05Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`00C?ooool00ol0003oooooooooo`1Dooooo`;oY[cY<oooool01?l05j;o
2d_9oceF`olmE/<3og5V]PGoVgV/1OnaQjT00onmU:gocj>[olnSZ`02olnSZ`?oikf[1?oSa[/3onO=
_0?ok=Bl0_oafkX2ooGS]`03ooS^[OnmdEWooooo05Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`00COooool2o`0005Cooooo00?o0000ooooooooool0<oooool00ol05j;o
00JHoceF``04og5V]PCoVgV/1OnaQjT5olnSZ`?oikf[00?oklV/on?6^ooSa[/01?oWcK`2oncD_0?o
lM^j0_oehkL00oocl9go_M5Iooooo`1Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool004oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0dooooo`03o`0G
X_lmE/?oLFJf00?oLFJf1?nKNJ`5ok67Z@04ol>HZoo?Xj_ocj>[olnSZ`?oikf[0oo_bJ`01?oSa[_o
ilflonO=_?oWcK`3oncD_0;olM^j0_oehkL00oohkZgolo2Mooooo`1Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool0053ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0eooooo`03o`06V?lmE/?oLFJf00;oLFJf1?nKNJ`4ok67Z@;o`iR[0oo?Xj/3onNmZ`?o
klV/00?okLR^onO=_?oWcK`00oo/e;`3oo7K^P;omN>g00?on>j]okgAFOooool0F_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo001Aooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0=Oooool00ol007_o00JHog5V]P02og5V]PCoVgV/1?naQjT2ol>HZ`;ocj>[
1?oW_J/3ono9[0;okLR^00?oilfloncD_?o/e;`00ooafkX2ooGS]`03ooS^[Oocl9goomB>05cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`00D_ooool2o`0004oooooo00?o
0000ooooooooool0=_ooool01?l01YSo;4>gog5V]_maI[H5oi]i[0;o/HNY1?o3V:/01?o?Xj_oikf[
onNmZooW_J/3ono9[0?okLR^0_o_bjh00oo/e;colM^joo7K^P02ooGS]`;on>j]0_ooe8iMooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool005Cooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0gooooo`04o`06V?l/@kOoLFJfog5V]PCoVgV/00?o/HNYol>HZoo3
V:/00oo3V:/01?o?Xj_oikf[onNmZooW_J/3ono9[0?okLR^0_o_bjh2oo7=[003oo7K^_oehkOomN>g
00;on>j]00?oomB>ooooooooool0G?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
007ooooo001Eooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0=oooool01?l01YSo
;4>goba3]omaI[H4oi]i[003ok67ZOo3V:_o`iR[00?o`iR[0ooW_J/3ono9[0?okLR^0oo_bjh2oo7=
[0;om<nY0_ohdj@00oobaZ?oomB>ooooo`1Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00Oooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0hooooo`?o
;4>g0_nKNJ`2oif2]@Ko`iR[00?oi;naonNmZooW_J/00oo_bJ`3ong8[P;okl^^0ooacJ`2ooC?Z@;o
n=>T00?ol/JSoooDS_ooool0Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo007o
oooo001Gooooo`;o0000B_ooool00ol0003oooooooooo`0hooooo`03o`06V?l/@kOo;4>g00CoWH:e
1Oo3V:/3onBo/@04onNmZoo_bJcoklV/ono9[0;okLR^0oo_bjh2oo7=[0;om<nY0_ohdj@00oobaZ?o
omB>oooDSP1Qooooo`05o`000?ooooooooooooooool000000oooool005Wooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0iooooo`;o;4>g1OnMP[D4ol>HZ`?oi;na00?ol=:dono9[?o_
bJ`00oo]b:h3ono;[P;olLf/0_odcjT2ooSCY003oo;6Xoooe8koomB>067ooooo00Go0000oooooooo
ooooooooo`000003ooooo`00F_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03[o
oooo0ol/@kL4oif2]@?o`iR[1?oT_k42oo3B]004ono9[?o]b:kokLR^ong8[P;okl^^0ooacJ`2ooC?
Z@;on=>T00?ol/JSoooDS_ooe8h0H_ooool01?l0003oooooooooool00003ooooo`00Foooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo03_ooooo0_l/@kL4oif2]@?o`iR[0ooT_k43oo3B
]003on[<]_o]b:kokLR^00?okl^^0_oacJ`2ooC?Z@;on=>T0_obaZ<00oooe8koooooooooo`1Roooo
o`03o`000?oooooo000000?ooooo001Looooo`;o0000A?ooool00ol0003oooooooooo`0looooo`03
oba3]onMP[GoWH:e00;oWH:e0oo3V:/3onBo/@?ol=:d0_oZc;H00oo]b:kokl^^ono;[P03oo7=[0;o
m<nY0_ohdj@2oo;6X`03oooDS_oooooooooo06;ooooo00Co0000oooooooooooo00000_ooool005ko
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0looooo`03oba3]onMP[GoWH:e00?o
WH:e00Co`iR[onBo/OoT_k7oi;na0oo`d[@3on[<]P03onW9]_o_bjkokl^^00;olLf/0oodcjT2ooSC
Y003oo;6Xoooe8koomB>06Gooooo00?o0000ooooool000000_ooool005oooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0mooooo`03oba3]onMP[GoWH:e00;oWH:e00Co`iR[onBo/OoT
_k7oi;na0oo`d[@3on[<]P;ojLVf00?okl^^oo7=[?oacJ`00_odcjT2ooSCY0;ol/JS0_ooe8iVoooo
o`;o00000_ooool0063ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0nooooo`;o
WH:e0_nV/^44onBo/@;ol=:d0ooZc;H3onW9]P;oj/Zd00?olLf/ooC?ZOodcjT00_ohdj@2oo;6X`;o
omB>IOooool3o`0000;ooooo001Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
?_ooool5ojJbh@;oi;na0oo`d[@3on[<]P?ojLVf0_oZb[@2onc:/P03ooC?ZOohdjCon=>T00;ol/JS
0_ooe8iQooooo`Co00001Oooool006;ooooo0_l0000nooooo`03o`000?oooooooooo03oooooo1OnV
/^400ooT_k7ol=:doo3B]004on[<]P;ojLVf0ooZb[@2onc:/P;ok/^^0oobaZ<00oooe8kooooooooo
o`1Mooooo`?o00002Oooool006Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`10
ooooo`;oY[;Q1?nMeo`01?o`d[Coj/bfon[<]_oZc;H3onW9]P;oj/Zd0oo/b[82onk;[P04omb^Z?ob
aZ?oomB>oooDSU_ooooo1?l0000<ooooo`00IOooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo04;ooooo0_nMeo`4ojC9l`;oj/bf0ooYbKH2on[:]0?ok<Zb0_o^bjh2omb^Z003oooDS_of
bIkooooo05Kooooo1?l0000@ooooo`00I_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo04?ooooo1_nTbO<00ooZc;KojLVfonW9]P03on[:]0;ok<Zb0_o^bjh3omb^Z0;om/VNDoooool4
o`0001Cooooo001Wooooo`;o0000>Oooool00ol0003oooooooooo`14ooooo`?oY<Wc0onUaO02onW9
]P;oj/Zd0oo/b[82onk;[P?og:jX0_ofbIi?ooooo`Co00006?ooool006Wooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`15ooooo`KoYLG`00?ojLVfon[:]?oZb[@00oo/b[82onk;[P?o
g:jX00?om/VNooooooooool0Boooool3o`0001cooooo001Zooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0A_ooool3ojG5l0?oY<Ka0_oZb[@2onc:/P;ok/^^0ooL[ZP2ooK9WTWooooo
1?l0000Oooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Oooooo1_nT
a_43onc:/P;ok/^^0ooL[ZP2ooK9WTGooooo1?l0000Sooooo`00K?ooool2o`0003Cooooo00?o0000
ooooooooool0B?ooool3ojC6l@?oY<Sc0_o/b[82onk;[P?og:jX0_ofbIi1ooooo`Co00009oooool0
06kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`19ooooo`KoY<Sc0_o^bjh4omb^
Z003ooK9W_oooooooooo03cooooo1?l0000[ooooo`00Koooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo04[ooooo0onTb?<2oj?<mP;ok/^^0ooL[ZP2ooK9WS_ooooo0ol0000_ooooo`00
L?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04_ooooo1OnSc?H01?o^bjkog:jX
omb^Z?oL[ZP2ooK9WSOooooo1?l0000booooo`00LOooool2o`0002oooooo00?o0000ooooooooool0
C?ooool2oj?<mP;oXiG71?oL[ZP00oofbIko0000ooooo`0booooo`Co0000=_ooool007?ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`1<ooooo`GoXiG70ooL[ZP00oofbIkooooooooo
o`0^ooooo`Co0000>_ooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1=
ooooo`GoXiG70_oL[ZP00oofbIkoooooooooo`0Zooooo`Co0000?_ooool007Gooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1>ooooo`GoXiG70_ofbIhYooooo`?o0000@_ooool007Ko
oooo0_l0000Yooooo`03o`000?oooooooooo053ooooo0_nSULL3oi[JoBKooooo1?l00015ooooo`00
N?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo053ooooo1?nJf_dSooooo`Co0000
BOooool007Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Aooooo`03oi[JoOoo
oooooooo01oooooo1?l0001=ooooo`00N_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo073ooooo0ol0001Aooooo`00Noooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06cooooo1?l0001Dooooo`00O?ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005So
oooo001nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0005cooooo
001oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool4o`00063ooooo0020
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool3o`0006Cooooo0021oooo
o`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000Ioooool008?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Eooooo`Co0000Joooool008Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`Co0000Koooool008Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1=ooooo`Co0000Loooool008Kooooo0_l0000Iooooo`03o`000?oooooo
oooo04[ooooo0ol0001gooooo`00R?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Kooooo1?l0001jooooo`00ROooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;o
oooo1?l0001nooooo`00R_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo
1?l00022ooooo`00Roooool2o`0001Cooooo00?o0000ooooooooool0>oooool3o`0008Kooooo002=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4o`0008Wooooo002>oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<oooool4o`0008gooooo002?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool4o`00097ooooo002@ooooo`;o0000
3oooool00ol0003oooooooooo`0[ooooo`Co0000UOooool009;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Xooooo`?o0000VOooool009?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`Co0000W?ooool009Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`Co0000X?ooool009Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`Co0000Y?ooool009Kooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo
1?l0002Xooooo`00V?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0
002/ooooo`00VOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002_
ooooo`00V_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002coooo
o`00Voooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;Oooooo002Mooooo`04o`00
0?ooooooooooo`0000Sooooo1?l0002kooooo`00W_ooool00ol0003oooooo`000005ooooo`?o0000
_oooool009oooooo0_l000000ooooooo0000o`000002o`000<;ooooo002Pooooo`;o0000a_ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.0894212, 0.00543257, \
0.00364432, 0.00364432}}],

Cell["Fig. 6.10 Exercise (15).", "Caption",
  CellTags->"Fig. 6.10"],

Cell[TextData[{
  "(16)",
  StyleBox[" A wire with square cross section is defined by ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              StyleBox[\(\(-1\) < x < 1, \(-1\) < y < 1\),
                FontWeight->"Plain"], TraditionalForm]]]]], 
        TraditionalForm]]],
  ". ",
  StyleBox["It is held at fixed temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T\_o\),
          FontWeight->"Plain"], TraditionalForm]]],
  StyleBox[", and is embedded in insulation with thermal diffusivitiy ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Chi]",
          FontWeight->"Plain"], TraditionalForm]]],
  ", ",
  StyleBox["also in the shape of a square  ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(-2\) < x < 2, \(-2\) < y < 2\),
          FontWeight->"Plain"], TraditionalForm]]],
  ". ",
  StyleBox["The surface of the insulation is at temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T\_1\),
          FontWeight->"Plain"], TraditionalForm]]],
  ". ",
  StyleBox["Find and plot as a surface plot the equilibrium temperature ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(T(x, y)\),
          FontWeight->"Plain"], TraditionalForm]]],
  " ",
  StyleBox["in the insulator, using simultaneous overrelaxation.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " The bottom a cubic box has a pyramidal cusp. The box walls are defined by \
the equations ",
  Cell[BoxData[
      \(TraditionalForm\`z = 1, y = 0, y = 1, x = 0, x = 1, 
      z = x\ \((for\ x < 1/2)\), \ z = y\ \((for\ y < 1/2)\), 
      z = 1 - x\ \((for\ x > 1/2)\), z = 1 - y\ \ \((for\ y > 1/2)\)\)]],
  " .  The potential on the pyramidal cusp is held fixed at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(V\_0\), "=", 
            RowBox[{"2", " ", 
              StyleBox["V",
                FontSlant->"Plain"]}]}], ","}], TraditionalForm]]],
  " but the potential on the other box walls is zero. Using the direct method \
in three dimensions on a 10-by-10-by-10 grid, solve for the potential \
everywhere inside the box. Plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 1/2, z)\)]],
  " as a contour plot."
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " It is easy to convince oneself that it is not possible to find any \
rectangular grid that will fit the  grounded triangular enclosure shown in \
Fig. ",
  ButtonBox["6.11",
    ButtonData:>"Fig. 6.11",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1, b\  = \ 1, \ c = \@3\)]],
  ". One can either content oneself with an order-",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " approximation to the solution using the methods discussed in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ", or else attempt to find a better way of matching the boundary \
conditions. One way to do so is as follows. Choose the grid so that the \
bottom and left sides fall on the grid. This requires that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "=", \(b/M\_y\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(a/P\)}], 
        TraditionalForm]]],
  "  for integers ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y\)]],
  ". With these choices, the grid in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " must run out to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(x\_j\), "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]}], ",", "  ", 
          RowBox[{"j", Cell[TextData[{
              "=0,1,2,...",
              Cell[BoxData[
                  \(TraditionalForm\`M\_x\)]],
              " "
            }]]}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(M\_x\), "=", 
          RowBox[{"Ceiling", "[", 
            RowBox[{"c", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], "]"}]}], TraditionalForm]]],
  " . However, the right side of the triangle does not fall on the grid."
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  "\tSince we wish to set the potential on the right side of the triangle \
equal to zero, we will use the following averaging technique. The equation \
for the triangle's right edge is ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y) = \(-\((c - a)\)\) y/b\  + \ c\)]],
  ". For each value of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_k\)]],
  " on the grid, this edge cuts between grid points ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j + 1\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(j\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " is given by Eq. ",
  ButtonBox["(6.2.37)",
    ButtonData:>"(6.2.37)",
    ButtonStyle->"Hyperlink"],
  ". The zero of potential should fall at ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_R\)(y\_k)\)]],
  ", not at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j + 1\)\)]],
  ". If we assume that the potential varies linearly between the grid points, \
this implies that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", " ", "=", " ", 
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                "2"], \(\[Phi]\_\(\(j\)\(\ \)\(k\)\(\ \)\)\)}], "+", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "1"], 
              " ", \(\[Phi]\_\(j + 1\ k\)\)}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j = g(k)\)]],
  ", and where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"], " ", "=", 
          " ", \(x\_\(j + 1\) - \(x\_R\)(y\_k)\)}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "1"], 
          "=", \(\(x\_R\)(y\_k) - x\_j\)}], TraditionalForm]]],
  " (see the figure)."
}], "Text"],

Cell[TextData[{
  "\tTherefore the interior points are defined by ",
  Cell[BoxData[
      \(TraditionalForm\`0 < k < M\_y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < j \[LessEqual] \ g(k)\)]],
  ", with the points ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(g(k) + 1\ k\)\)]],
  "defined in terms of the interior points by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\[Phi]\_\(g(k) + 1\ k\)\),
              "TraditionalForm"], "=", 
            RowBox[{
              RowBox[{"-", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "1"]}], 
              RowBox[{\(\[Phi]\_\(\(g(k)\)\ k\)\), "/", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Implement this procedure and solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  "using the direct method, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/\[Epsilon]\_o = x\)]],
  " and taking  ",
  Cell[BoxData[
      \(TraditionalForm\`M\_y = \(P = 10\)\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35156 
%%ImageSize: 1280 450 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000744048 0.00837054 0.000744048 [
[ 0 0 0 0 ]
[ 1 .35156 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .35156 L
0 .35156 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .00837 translate
.95238 .33482 scale
3840 string
1280 450 8 [1280 0 0 450 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E
0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E
0B0C0E0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E0B0C0E0B0C0EFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E0B0C0E
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
0B0C0E0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0B0C0E0B0C0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0B0C0E0B0C0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{321.875, 113.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000SB000`400?l00000o`00003ooooooonC
ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`002_oooooo0?ooogd0oooo3?oo
ool000[oooooo`3ooomm0?ooo`cooooo000:ooooool0ooooO@3oool<ooooo`002_oooom80?ooo`80
ZZZZo`3ooolc0?ooo`cooooo000:ooooodH0oooo00H0eMGE030`<010@400P820071`L03Zj^[o0?oo
oc40oooo3?ooool000[oooooAP3oool00`0i>CT0@4100?ooo`020?ooo`0308j>SP3oool0oooo0?l0
oooo;`3oool<ooooo`002_oooom60?ooo`030000002_[jl0oooo0?l0oooo=03oool<ooooo`002_oo
oom60?ooo`0301`L702o_kl0oooo0?l0oooo=03oool<ooooo`002_oooom60?ooo`04075aL@2ZZZX0
oooo0?ooo`80ZZZZo`3ooola0?ooo`cooooo000:ooooodL0oooo00D0L71`0>[ZjP3oool0<30`09FE
U@3o0?oooc40oooo3?ooool000[oooooB03oool00`36a/H0ZZZZ0=GEe@3o0?oooc80oooo3?ooool0
00[oooooo`3ooomm0?ooo`cooooo000:oooooa<0oooo00<0_kno0820P03oool0G`3oool00`2ZZZX0
[jn_0?ooo`3o0?ooo`D0oooo3?ooool000[ooooo403oool00`3Shn<0P82000000002000000030>?S
h`3oool0oooo05d0oooo0`0000000`1ZJVX0a/K60?ooo`3o0?ooo`80oooo3?ooool000[ooooo3P3o
ool00`2EUID0>CTi000000040000000308j>SP3oool0oooo05`0oooo00<0ZZZZ0000000000000`00
00000`0L71`0P8200>?Sh`3o0?ooo`cooooo000:ooooo`X0oooo00<0j^[Z09FEU@1@D50020000000
0`1EEED0oooo0?ooo`1L0?ooo`0305EEE@000000000000H0000000<0@410092@T03De=@0o03oool<
ooooo`002_ooool80?ooo`030:ZZZP10@400000000X0000000<0>CTi0:ZZZP2ZZZX0G02ZZZX00`0i
>CT00000000000090000000302/[:`2>SXh0hn?S0?T0oooo3?ooool000[ooooo1`3oool00`2ZZZX0
LG5a0000001g0000000303Ti>@2ZZZX0j^[Z0?P0oooo3?ooool000[ooooo2@3oool0103_knl0ZZZZ
05EEE@0@41080000000305EEE@3oool0oooo05`0oooo00<0EEEE0000000000001`0000000`0`<300
UIFE0=oOg`3k0?ooo`cooooo000:ooooo``0oooo00<0j^[Z08j>SP0E5AD01P0000000`2>SXh0oooo
0?ooo`1L0?ooo`030:ZZZP000000000000@0000000<05ADE075aL@3Shn<0a`3oool00`1aLG40hn?S
0?ooo`0d0?ooo`cooooo000:ooooo`l0oooo00<0_kno06][J`0P82000`0000000`3EeMD0oooo0?oo
o`1L0?ooo`070=GEe@00000000000000000@4100EEEE0:ZZZP390?ooo`030820P0000000ZZZZ03D0
oooo3?ooool000[ooooo4P3oool00`36a/H0LG5a06YZJP1P0?ooo`03075aL@1ZJVX0ZZZZ0</0oooo
00<0hn?S01DE5@1aLG40=P3oool<ooooo`002_oooooo0?oood@0oooo00<0EEEE01DE5@3Shn<0=P3o
ool<ooooo`002_oooooo0?oood<0oooo00<0UIFE0000002@T900=`3oool<ooooo`002_oooooo0?oo
od80oooo00<0j^[Z0000000i>CT0>03oool<ooooo`002_oooooo0?oood80oooo00<0JVYZ00000036
a/H0>03oool<ooooo`002_oooooo0?oood40oooo00<0_kno0000002EUID0>@3oool<ooooo`002_oo
oolY0?ooo`070:ZZZP000000>CTi0=GEe@0L71`0>CTi0>[ZjP3o0?oooa40oooo00<071`L0410@03o
ool0>@3oool<ooooo`002_oooolY0?ooo`0700000020P800oooo06YZJP000000oooo0>[ZjP3o0?oo
oa00oooo00<0LG5a0000002ZZZX0>P3oool<ooooo`002_oooolY0?ooo`050410@02_[jl0oooo0;no
_`000000o`3ooolA0?ooo`030;no_`000000EEEE03/0oooo3?ooool000[ooooo:P3oool01020P800
a/K60;no_`00003o0?oooa40oooo00<0:b/[01`L703oool0>`3oool<ooooo`002_ooool[0?ooo`03
0>?Sh`20P80000000?l0oooo403oool00`2>SXh000000<K6aP0l0?ooo`cooooo000:ooooobT0oooo
00D0JVYZ092@T03oool0_kno01DE5@3o0?ooo`l0oooo00<0gmoO01DE5@1PH600?@3oool<ooooo`00
2_oooolY0?ooo`050>?Sh`20P800ZZZZ05EEE@2ZZZX0o`3oool?0?ooo`0305EEE@000000j^[Z03d0
oooo3?ooool000[ooooo4`3oool00`2o_kl0L71`0410@00g0?ooo`040=oOg`10@400P8200<o?cnX0
oooo00<0ZZZZ0000002ZZZX0?P3oool<ooooo`002_ooool@0?ooo`030<K6aP1ZJVX0000000<00000
00<0ZZZZ0?ooo`3oool0=03oool01`2o_kl0000000000000000071`L0820P03Shn<0iP3oool00`3S
hn<071`L05EEE@0o0?ooo`cooooo000:ooooo`h0oooo00<0UIFE01`L700000001@0000000`1aLG40
oooo0?ooo`0d0?ooo`030:ZZZP000000000000@0000000<0>CTi0:ZZZP3oool0h`3oool00`1EEED0
00000;no_`0o0?ooo`cooooo000:ooooo`X0oooo00<0e=CD09FEU@1@D5002@0000000`1EEED0oooo
0?ooo`0d0?ooo`030820P0000000000000H0000000@05ADE05EEE@2PX:00j^[Zg`3oool00`2`/;00
000006YZJP100?ooo`cooooo000:ooooo`L0oooo00<0hn?S08j>SP0[:b/0300000000`0L71`0EEEE
05EEE@0d05EEE@0301DE5@000000000000X0000000<0@4100:ZZZP3oool0g03oool00`0[:b/0>CTi
0?ooo`100?ooo`cooooo000:ooooo`T0oooo00<0P82003Ti>@0000002P0000000`0L71`0EEEE05EE
E@0d05EEE@0301DE5@000000000000T0000000<0>CTi0:ZZZP3oool0g03oool00`2>SXh000000<K6
aP110?ooo`cooooo000:ooooo`/0oooo00<0j^[Z092@T00[:b/0200000000`1EEED0oooo0?ooo`0d
0?ooo`03051@D0000000000000H0000000<0@4100820P03Ogml0gP3oool00`2o_kl00000071`L012
0?ooo`cooooo000:ooooo`h0oooo00<0eMGE05EEE@0000001@0000000`2ZZZX0oooo0?ooo`0d0?oo
o`030820P0000000000000@0000000<0EEEE0=GEe@3oool0h03oool201`L70030>[ZjP3oool0oooo
0400oooo3?ooool000[ooooo4@3oool00`2o_kl0LG5a00000002000000030>?Sh`3oool0oooo03@0
oooo00H0eMGE0000000000000000075aL@2o_koS0?ooo`0309FEU@000000SXj>04<0oooo3?ooool0
00[ooooo4`3oool00`3Zj^X0T92@09FEU@0h0?ooo`80UIFE00<0gmoO0?ooo`3oool0hP3oool00`3Z
j^X0410@05EEE@140?ooo`cooooo000:ooooool0oooo=P3oool00`0i>CT05ADE0?ooo`140?ooo`co
oooo000:ooooo`/0oooo00D0a/K601DE5@000000:b/[0>?Sh`070?ooo`050>[ZjP0i>CT0000001`L
701aLG40203oool01020P80000000000001EEED80?ooo`050<K6aP0L71`0000001`L702o_kl0203o
ool0101EEED0000001DE5@1aLG480?ooo`0508j>SP0E5AD0000003Ti>@3Zj^X01`3oool01@3EeMD0
71`L0000000E5AD0ZZZZ00P0oooo00@0LG5a000000000000JVYZ203oool01@2>SXh071`L0000000i
>CT0hn?S00L0oooo00D0hn?S0410@0000000000009FEU@080?ooo`05075aL@000000000005EEE@3Z
j^X0Z03oool00`2o_kl0000009FEU@150?ooo`cooooo000:ooooo`X0oooo00<0_kno000000000000
0P0000000`0E5AD0ZZZZ0;no_`050;no_`03030`<000000000000080000000<0T92@0;no_`2o_kl0
102o_kl00`20P800000000000002000000030410@02o_kl0_kno00@0_kno00<0[jn_000000000000
0P0000000`0@4100eMGE0?ooo`050?ooo`030410@000000000000080000000<0UIFE0?ooo`3oool0
103oool00`2EUID000000000000200000003030`<03oool0oooo00@0oooo00<0j^[Z020P80000000
0`0000000`2`/;00oooo0?ooo`040?ooo`030410@000000000000080000000<0UIFE0?ooo`3oool0
103oool00`2`/;000000000000020000000301DE5@3Ogml0oooo00@0oooo00<0j^[Z02/[:`000000
0`0000000`2EUID0oooo0?ooo`040?ooo`03071`L000000000000080000000<0L71`0?ooo`3oool0
203oool00`2o_kl0oooo0?ooo`2K0?ooo`03030`<00[:b/0kno_04D0oooo3?ooool000[ooooo2P3o
ool00`1EEED000000000001>000000H0EEEE1@0000000`0L71`0EEEE05EEE@0405EEE@0302/[:`00
0000000000<0000000<0@41005EEE@1EEED00`1EEED00`0i>CT00000000000030000000501`L701E
EED0EEEE075aL@2o_kl00P3oool00`0[:b/00000000000020000000301DE5@3oool0oooo00P0oooo
00<05ADE0?ooo`3oool0VP3oool00`1aLG4000000>?Sh`160?ooo`cooooo000:ooooo`X0oooo00<0
EEEE0000000000000`0000000`2EUID0oooo0?ooo`030?ooo`030=GEe@000000000000<0000000<0
D51@0?ooo`3oool0103oool00`0[:b/0000000000003000000030;no_`3oool0oooo00<0oooo00<0
P8200000000000000`0000000`1oOgl0_kno0;no_`030;no_`030:ZZZP000000000000<0000000<0
5ADE0;no_`2o_kl0102o_kl00`0[:b/00000000000030000000309FEU@2o_kl0_kno00<0_kno00<0
Ogmo0000000000000`0000000`1PH600P8200820P0040820P0D0000000<05ADE0820P020P8001020
P8000`10@40000000000000300000003051@D020P800P82000<0P82000<0EEEE0000000000000`00
00001@0[:b/0P82001DE5@000000clo?0080oooo00<0820P0000000000000P0000000`0@4100oooo
0?ooo`070?ooo`030;no_`000000UIFE09X0oooo00<0_kno00000020P800A`3oool<ooooo`002_oo
ool:0?ooo`030:ZZZP000000000000<0000000<0SXj>0?ooo`3oool0103oool00`0[:b/000000000
00020000000309FEU@3oool0oooo00@0oooo00<0SXj>0000000000000P0000000`0L71`0oooo0?oo
o`040?ooo`030;no_`000000000000<0000000<0a/K60?ooo`3oool0103oool00`0i>CT000000000
000200000003075aL@3oool0oooo00@0oooo00<0SXj>0000000000000P0000000`0E5AD0oooo0?oo
o`040?ooo`030>?Sh`0E5AD0000000<0000000<0UIFE0?ooo`3oool0103oool00`0i>CT000000000
000200000003075aL@3oool0oooo00@0oooo00<0ZZZZ0000000000000`0000000`3EeMD0oooo0?oo
o`030?ooo`030>?Sh`0L71`0000000<0000000@0LG5a0=GEe@000000SXj>0`3oool00`1ZJVX00000
000000020000000305EEE@3oool0oooo00L0oooo00<0EEEE0000000i>CT0V@3oool0103Zj^X071`L
01`L703Zj^Y70?ooo`cooooo000:ooooo`/0oooo00L0ZZZZ01DE5@000000:b/[05EEE@000000_kno
00D0oooo00D0eMGE01`L700000000000075aL@080?ooo`0506YZJP00000000000410@03Shn<01`3o
ool01@2ZZZX071`L0000000L71`0ZZZZ00L0oooo00D0hn?S0410@00000000000075aL@080?ooo`05
08j>SP000000000001`L703EeMD01`3oool01@2o_kl071`L0000000E5AD0SXj>00L0oooo00D0hn?S
05EEE@000000000005EEE@080?ooo`0508j>SP000000000001`L7036a/H01`3oool02036a/H0@410
000000000000P8200?ooo`1EEED071`L103oool01P3Zj^X0EEEE000000000000>CTi0>[ZjPP0oooo
00D0hn?S00000000000000000>?Sh`2H0?ooo`030820P0000000ZZZZ04P0oooo3?ooool000[ooooo
303oool01`3?cll0_kno0=oOg`3oool0P820010@402o_kl01@3oool00`3Zj^X0_kno0=CDe00:0?oo
o`80_kno00<0kno_0?ooo`3oool01`3oool00`3De=@0_kno0=CDe0090?ooo`030>o_k`2o_kl0clo?
00X0oooo00<0clo?0;no_`3Zj^X02@3oool00`3De=@0_kno0<o?c`0:0?ooo`80_kno2P3oool00`3D
e=@0_kno0>[ZjP090?ooo`070=oOg`2o_kl0_kno0?ooo`2ZZZX0410@0=GEe@060?ooo`80_kno2P3o
ool01@20P8000000000000000000P82009L0oooo00<0j^[Z010@401ZJVX0B@3oool<ooooo`002_oo
oolA0?ooo`030820P0000000ZZZZ06X0oooo00<0j^[Z01`L701ZJVX04`3oool40000000301`L703o
ool0oooo09D0oooo00<0>CTi01DE5@3oool0B@3oool<ooooo`002_oooolB0?ooo`0305EEE@000000
UIFE06T0oooo00<0P8200000003Zj^X04P3oool00`2ZZZX0000000000003000000030;no_`3oool0
oooo09<0oooo00<0SXj>0000002EUID0BP3oool<ooooo`002_oooolC0?ooo`030:ZZZP0@4100P820
06L0oooo00<0j^[Z010@402ZZZX04`3oool00`1`L70000000000000300000003071`L03oool0oooo
0980oooo00<0clo?00000010@400B`3oool<ooooo`002_oooolD0?ooo`030;no_`000000EEEE06H0
oooo00<0>CTi0410@03oool04`3oool00`0[:b/00000000000030000000302/[:`3oool0oooo05P0
oooo00<0EEEE0820P03oool02`3oool0103Shn<0JVYZ05EEE@2EUIDX0?ooo`0305EEE@0L71`0hn?S
04/0oooo3?ooool000[ooooo5@3oool0102ZZZX0000006YZJP1EEED200000003075aL@3oool0oooo
00H0oooo00D0P820000000000000:b/[0>?Sh`070?ooo`050<K6aP0L71`000000000002o_kl0203o
ool0101ZJVX000000000001aLG480?ooo`050:ZZZP000000000001`L702o_kl01`3oool01@3EeMD0
71`L000000000000ZZZZ00P0oooo00@0SXj>000000000000EEEE203oool01@2ZZZX000000000000L
71`0ZZZZ00L0oooo00D0hn?S0410@0000000000006YZJP0C0?ooo`030>?Sh`000000000000D00000
00<0hn?S0?ooo`3oool0E`3oool00`1aLG40ZZZZ08j>SP0:0?ooo`030>?Sh`000000EEEE0080ZZZZ
00<0LG5a0>?Sh`3oool00P3oool00`2o_kl0a/K60?ooo`070?ooo`0308j>SP3Zj^X0oooo01D0oooo
00<0a/K60000002>SXh0C03oool<ooooo`002_oooolF0?ooo`030;no_`000000000000<0000000<0
H61P0?ooo`3oool0103oool00`2EUID00000000000020000000302/[:`3oool0oooo00@0oooo00<0
gmoO01DE5@0000000`0000000`3EeMD0oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0
:b/[0?ooo`3oool0103oool00`2EUID000000000000200000003020P803oool0oooo00D0oooo00<0
<30`0000000000000P0000000`2PX:00oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0
:b/[0?ooo`3oool0103oool00`2`/;00000000000003000000030=oOg`3oool0oooo00@0oooo00<0
@4100000000000000P0000000`20P800oooo0?ooo`0@0?ooo`0306YZJP000000000000D0000000<0
P8200?ooo`3oool0F03oool00`2o_kl05ADE0?ooo`090?ooo`030=GEe@0E5AD0oooo00<0oooo00D0
ZZZZ0?ooo`3oool0eMGE092@T00:0?ooo`03071`L03Zj^X0oooo01<0oooo00<0j^[Z01DE5@10@400
5`3oool00`3Zj^X0_kno0?ooo`0<0?ooo`030=CDe02o_kl0gmoO02@0oooo3?ooool000[ooooo5`3o
ool5000000030410@03oool0oooo00@0oooo00<071`L0000000000000`0000000`2ZZZX0oooo0?oo
o`030?ooo`0309FEU@000000000000<0000000<0EEEE0?ooo`3oool0103oool6000000H0oooo00<0
71`L0000000000000`0000000`2ZZZX0oooo0?ooo`030?ooo`030<K6aP000000000000<0000000<0
@4100?ooo`3oool0103oool6000000H0oooo00<0EEEE0000000000000`0000000`20P800oooo0?oo
o`030?ooo`030<K6aP000000000000@000004P3oool80000000301`L703oool0oooo05P0oooo00<0
_kno0000003oool02P3oool00`36a/H0UIFE0:ZZZP020:ZZZP0703Ti>@3oool0oooo01`L703Zj^X0
oooo0>?Sh`020:ZZZP080=GEe@36a/H0ZZZZ0:ZZZP36a/H0oooo0;no_`1aLG4D0?ooo`0303Ti>@00
0000eMGE01L0oooo00<0ZZZZ06YZJP0i>CT02`3oool00`1ZJVX0000005EEE@0205EEE@030>?Sh`3o
ool0oooo0080oooo00<0ZZZZ0?ooo`3oool01P3oool00`2o_kl0oooo0?ooo`0B0?ooo`cooooo000:
oooooaL0oooo1@0000000`10@400oooo0?ooo`040?ooo`0301`L70000000000000<0000000<0ZZZZ
0?ooo`3oool00`3oool00`2EUID00000000000030000000305EEE@3oool0oooo00@0oooo1P000006
0?ooo`0301`L70000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`36a/H0000000000003
000000030410@03oool0oooo00@0oooo1P0000060?ooo`0305EEE@000000000000<0000000<0P820
0?ooo`3oool00`3oool00`36a/H000000000000400000140oooo00<0eMGE0000000000001`000000
0`36a/H0oooo0?ooo`1G0?ooo`030;no_`000000oooo00X0oooo00T0LG5a000000000000000003Ti
>@2ZZZX0oooo08j>SP1EEED00`3oool01P1ZJVX0>CTi0?ooo`3Shn<0000006YZJP<0oooo00<00000
0>[ZjP3oool04@3oool00`2o_kl00000075aL@0J0?ooo`0305EEE@2ZZZX0oooo00T0oooo00<00000
0>?Sh`3oool00P3oool01P36a/H0j^[Z0?ooo`3oool0LG5a0>?Sh`P0oooo00<0j^[Z075aL@3oool0
4P3oool<ooooo`002_oooolG0?ooo`03051@D000000000000080000000<0L71`0?ooo`3oool0103o
ool00`2EUID0000000000002000000030410@03oool0oooo00@0oooo00<0gmoO01DE5@0000000P00
00000`0@4100eMGE0?ooo`050?ooo`0306YZJP00000000000080000000<0@4100?ooo`3oool0103o
ool00`2EUID000000000000200000003030`<03oool0oooo00D0oooo00<0<30`0000000000000P00
00000`2`/;00oooo0?ooo`040?ooo`0306YZJP00000000000080000000<0@4100?ooo`3oool0103o
ool00`2`/;000000000000020000000301DE5@3Ogml0oooo00@0oooo00<0j^[Z0000000000000`00
00000`2EUID0oooo0?ooo`0@0?ooo`090>[ZjP2PX:00P82005EEE@000000@41006][J`2PX:00e=CD
05X0oooo00@0_kno0000003oool0gmoO1`20P800103Ogml0oooo0;no_`2@T9050?ooo`030410@02E
UID0oooo0080oooo00D0P82005EEE@3_knl0:b/[0410@0040?ooo`030410@02_[jl0oooo0140oooo
00<0<30`02/[:`3Zj^X06P3oool00`1EEED0P8200?ooo`090?ooo`03092@T03EeMD0oooo0080oooo
00D0e=CD0;no_`3oool0T92@0:ZZZP0:0?ooo`030;no_`1EEED0oooo0140oooo3?ooool000[ooooo
5`3oool01P3Zj^X0EEEE00000000000071`L0410@0L0oooo00D0JVYZ000000000000:b/[0>?Sh`07
0?ooo`050<K6aP0L71`000000000002ZZZX0203oool0101ZJVX000000000001aLG480?ooo`0508j>
SP000000000001`L702o_kl01`3oool01@3EeMD071`L000000000000SXj>00P0oooo00@0SXj>0000
00000000EEEE203oool01@2>SXh000000000000L71`0ZZZZ00H0oooo00<0EEEE00000010@4000P00
00000`1ZJVX0oooo0?ooo`0E0?ooo`030000003oool0oooo05`0oooo00@0_kno0000003oool0j^[Z
1`2ZZZX01`3Zj^X0oooo0?ooo`1EEED0SXj>0820P02ZZZX00P3oool00`000000ZZZZ0?ooo`020?oo
o`040820P01EEED0EEEE05EEE@D0oooo00<0EEEE0820P03oool0403oool00`1aLG4000000>?Sh`0K
0?ooo`0305EEE@20P800oooo00T0oooo00<0_kno01`L700000000P000000100L71`0j^[Z0?ooo`10
@4020?ooo`080>[ZjP1EEED000000:ZZZP3Shn<0:b/[01`L702>SXh20?ooo`0303Ti>@3EeMD0oooo
00<0oooo00<0P8200:ZZZP3oool0103oool01P2ZZZX0@41001`L702ZZZX0j^[Z0?ooo`cooooo000:
oooooa/0oooo00@0j^[Z0410@00E5AD0_kno1`3oool00`3Zj^X0oooo0?ooo`090?ooo`030>o_k`3o
ool0oooo01H0oooo00<0j^[Z0?ooo`3oool02@3oool00`3Zj^X0oooo0?ooo`0F0?ooo`030>o_k`3o
ool0oooo00D0oooo00D0_kno0000002ZZZX0oooo0>[ZjP0I0?ooo`030000003oool0oooo05`0oooo
00<0_kno0000003oool02P3oool02@20P800D51@0?ooo`3oool000000=GEe@3oool000000:ZZZP03
0?ooo`040820P00[:b/0<30`0>[ZjPD0oooo00<0EEEE0820P03oool03`3oool00`3?cll000000820
P00L0?ooo`0405EEE@20P800oooo0=CDe0H0_kno00@0e=CD0?ooo`2`/;00EEEE0P2o_kl01@3De=@0
oooo0?ooo`2ZZZX0H61P00<0oooo00H0ZZZZ0000003oool0ZZZZ010@403Zj^X30?ooo`80P820103o
ool00`20P800ZZZZ0?ooo`050?ooo`030820P01EEED0oooo0080oooo3?ooool000[ooooo7@3oool0
0`1EEED000000;no_`1H0?ooo`0302/[:`1EEED0oooo01/0oooo00<000000?ooo`3oool0G03oool0
102o_kl000000?ooo`3Zj^X70:ZZZP0;0>[ZjP3oool0EEEE0820P03oool0j^[Z0000002ZZZX0oooo
01`L702ZZZX00`3oool01020P800EEEE0:ZZZP3Shn<50?ooo`0305EEE@2EUID0oooo00l0oooo00<0
@41001`L703Zj^X0703oool0101EEED0P8200?ooo`2>SXh605EEE@0708j>SP3oool0oooo08j>SP1a
LG40UIFE0<K6aP020?ooo`0305EEE@20P800oooo0080oooo00D0ZZZZ0000002o_kl000000;no_`04
0?ooo`030:ZZZP10@400oooo00<0oooo00<0P8200:ZZZP3oool01@3oool00`20P800EEEE0?ooo`02
0?ooo`cooooo000:oooooah0oooo00<0EEEE01DE5@3Shn<0EP3oool00`2>SXh05ADE0>?Sh`0L0?oo
o`030000003oool0oooo05`0oooo00@0P8200000003oool0eMGE1`1EEED02`3EeMD0oooo0<K6aP1Z
JVX0oooo0:ZZZP000000EEEE0?ooo`1EEED0LG5a00<0oooo00D0P82005EEE@3oool0a/K60:ZZZP04
0?ooo`0301`L702o_kl0oooo00h0oooo00<0ZZZZ0000002ZZZX07@3oool00`1EEED0P8200?ooo`09
0?ooo`090=GEe@000000hn?S0?ooo`0i>CT0a/K60?ooo`1EEED0P82000<0oooo00@0ZZZZ00000010
@400LG5a1@3oool0102ZZZX0@4100?ooo`2>SXh205EEE@0502/[:`0i>CT0EEEE05EEE@2>SXh00`3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:oooooal0oooo00<0H61P01DE5@3?cll0E03oool0
0`3Ogml05ADE0820P00M0?ooo`030000003oool0oooo05`0oooo00<0gmoO09FEU@3oool02`3oool2
0;no_`060:n_[`3Zj^X0oooo0?ooo`3EeMD0:b/[0`3oool02P20P800EEEE0?ooo`3De=@0P8200:2P
X03Zj^X0oooo0=oOg`0[:b/?0?ooo`030>[ZjP0E5AD0D51@01h0oooo00<0EEEE0820P03oool02@3o
ool01020P800@4100?ooo`3oool205EEE@030?ooo`1EEED0P82000<0oooo00@0ZZZZ0000001`L700
j^[Z1@3oool0102ZZZX0@4100?ooo`3De=@20;no_`05061PH01oOgl0_kno0;no_`3De=@00`3oool0
0`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob00oooo00<0EEEE01DE5@2ZZZX0D`3oool00`1E
EED071`L0?ooo`0M0?ooo`030000003oool0oooo0740oooo00H0SXj>0;no_`3oool0oooo0820P01E
EED60?ooo`0306YZJP3Shn<0oooo00h0oooo00<0>CTi0000003EeMD07P3oool0101EEED0P8200?oo
o`1EEED60000000405EEE@3oool0ZZZZ05EEE@80oooo00D0000005EEE@3Zj^X0ZZZZ06YZJP030?oo
o`050:ZZZP000000oooo0<K6aP3EeMD0103oool00`2>SXh0P8200?ooo`030?ooo`030820P02ZZZX0
oooo00D0oooo00<0P82005EEE@3oool00P3oool<ooooo`002_oooolQ0?ooo`0406YZJP000000ZZZZ
0?ooo`80ZZZZ00<0eMGE0?ooo`3oool01`3oool00`3Shn<0ZZZZ0<K6aP0:0?ooo`80ZZZZ2P3oool0
0`2o_kl0ZZZZ0<K6aP090?ooo`030>?Sh`2ZZZX0_kno00X0oooo00<0_kno0:ZZZP3Zj^X02@3oool0
0`36a/H0ZZZZ0<K6aP030?ooo`030<K6aP000000a/K600<0oooo00<0j^[Z0:ZZZP2ZZZX0603oool0
0`000000oooo0?ooo`1M0?ooo`030<K6aP3oool0oooo0180oooo00D0P8200?ooo`3oool0P82005EE
E@050?ooo`030>?Sh`2EUID0oooo00h0oooo00<0ZZZZ0000001aLG407P3oool00`3EeMD0EEEE0820
P00;0?ooo`08075aL@2>SXh0P820075aL@2ZZZX0j^[Z0>?Sh`10@4030?ooo`070:ZZZP000000oooo
0>?Sh`10@400LG5a0<K6aP020?ooo`0305EEE@2ZZZX0oooo00<0oooo00<0P8200:ZZZP3oool01@3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob80oooo00<0P8200000000`<3000`000000
0`1[Jf/0oooo0?ooo`050?ooo`050820P000000000000000000`<3001`3oool01P3Zj^X0820P0000
000000005ADE0:ZZZPL0oooo00D0EEEE0000000000000000051@D0070?ooo`060:2PX00000000000
0000000E5AD0gmoO1P3oool01P3Zj^X0:b/[000000000000410@0:ZZZPL0oooo00T0EEEE00000000
000000000410@03Ogml0j^[Z02/[:`1PH6000`3oool01P2o_kl0410@000000000000410@0=GEeAH0
oooo00<000000?ooo`3oool0G03oool00`3Ogml0EEEE0?ooo`0C0?ooo`050>o_k`3De=@0j^[Z092@
T020P8001@3oool00`2o_kl0oooo0?ooo`0>0?ooo`03020P8010@400oooo03<0oooo00H0L71`0>[Z
jP3oool0oooo0:ZZZP0000060?ooo`030=GEe@10@400oooo00@0oooo00<0`<300=GEe@3oool01@3o
ool00`20P800EEEE0?ooo`020?ooo`cooooo000:ooooob<0oooo00<0EEEE0000000000000`000000
0`2ZZZX0oooo0?ooo`030?ooo`030;no_`000000000000<0000000<0ZZZZ0?ooo`3oool0103oool0
0`1EEED0000000000003000000H0oooo00<0LG5a0000000000000`0000000`2ZZZX0oooo0?ooo`04
0?ooo`D0000000<0P8200?ooo`3oool0103oool00`1EEED0000000000003000000H0oooo00<0UIFE
0000000000000`0000001020P800EEEE0000003Zj^X30?ooo`D0000000<0EEEE0?ooo`3oool0503o
ool00`000000oooo0?ooo`2<0?ooo`03075aL@000000hn?S03@0oooo00H0j^[Z05EEE@3oool0oooo
0:ZZZP0000060?ooo`0305EEE@3Shn<0oooo00/0oooo00<0ZZZZ05EEE@1EEED00`3oool<ooooo`00
2_oooolS0?ooo`0305EEE@000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`2EUID00000
000000030000000305EEE@3oool0oooo00@0oooo00<071`L0000000000000`0000000`2o_kl0oooo
0?ooo`030?ooo`0305EEE@000000000000<0000000<0ZZZZ0?ooo`3oool00`3oool00`36a/H00000
00000003000000030410@03oool0oooo00@0oooo00<071`L0000000000000`0000000`2ZZZX0oooo
0?ooo`030?ooo`030820P0000000000000<0000000<0EEEE0000002>SXh00`3oool00`36a/H00000
00000004000001H0oooo00<000000?ooo`3oool0R`3oool00`36a/H0000006YZJP0Q0?ooo`03075a
L@2EUID0oooo0180oooo00D0hn?S08j>SP3Zj^X0EEEE000000050?ooo`030:ZZZP3Shn<0oooo00d0
oooo00<0P820075aL@3oool00P3oool<ooooo`002_oooolS0?ooo`0306YZJP000000000000<00000
00<0ZZZZ0?ooo`3oool00`3oool00`2_[jl0000000000003000000030820P03oool0oooo00@0oooo
00<0@4100000000000000`0000000`3Ogml0oooo0?ooo`030?ooo`0306YZJP000000000000<00000
00<0ZZZZ0?ooo`3oool00`3oool00`3Zj^X000000000000300000003061PH03oool0oooo00@0oooo
00<0@4100000000000000`0000000`3EeMD0oooo0?ooo`030?ooo`03092@T0000000000000@00000
00<0@4100?ooo`3oool00P3oool00`3Zj^X00000000000030000000302/[:`3oool0oooo01@0oooo
00<000000?ooo`3oool0RP3oool0103_knl05ADE01DE5@3_knlQ0?ooo`030>[ZjP3_knl0oooo01H0
oooo00<0e=CD0?ooo`3oool0603oool<ooooo`002_oooolT0?ooo`0501DE5@00000000000000000L
71`01`3oool01@0i>CT00000000000000000:b/[00L0oooo00<0hn?S0000000000000P0000000`2>
SXh0oooo0?ooo`050?ooo`0501`L70000000000000000010@4001`3oool00`1ZJVX0000000000002
000000030>[ZjP3oool0oooo00@0oooo00<0hn?S0000000000000P0000000`2>SXh0oooo0?ooo`05
0?ooo`0301`L7000000000000080000000<05ADE0>?Sh`3oool0103oool00`2>SXh0000000000002
000000030>?Sh`3oool0oooo01@0oooo00<000000?ooo`3oool0RP3oool00`20P80000000<K6aP1F
0?ooo`cooooo000:ooooob@0oooo00L0kno_0820P020P800T92@01DE5@10@400kno_00H0oooo00@0
UIFE071`L020P800gmoO203oool0103?cll0P820071`L02o_kl90?ooo`04092@T020P800UIFE0>o_
k`P0oooo00@0UIFE06][J`20P800e=CD203oool0103Zj^X0P82006][J`2`/;090?ooo`0509FEU@20
P800Jf][00000020P8001`3oool0102`/;00Jf][0820P02o_klG0?ooo`030000003oool0oooo08T0
oooo00<0eMGE010@401ZJVX0E`3oool<ooooo`002_oooolX0?ooo`030>?Sh`0L71`0@41004H0oooo
0P0L71`S0?ooo`030000003oool0oooo06/0oooo00<0i>CT08F6Q`2BTi@03@3oool00`11@T<0Ti>D
0=OGe`0;0?ooo`0301`L700[:b/0oooo00P0oooo00<0bLW:075aLP39bLT01@3oool00`1gN7T0QHJ7
0<W9bP140?ooo`cooooo000:ooooobT0oooo00@0hn?S01DE5@0L71`0j^[Z@`3oool00`2EUID00000
0<K6aP0S0?ooo`030000003oool0oooo05l0oooo00D0P820000000000000@4100>?Sh`050?ooo`04
0<W9bP0d=CH02``>01lP8Ph0oooo00D0i>CT00/<3P0;30h0@D930<;2``080?ooo`030:ZZZP000000
ZZZZ00L0oooo00@0QHJ700/<3P0;30h0G5eN1`3oool0100d=CH02``>02HW:@2JVY]20?ooo`cooooo
000:ooooobX0oooo00@0kno_0410@00`<300j^[Z@@3oool00`3Zj^X0820P0820P00T0?ooo`030000
003oool0oooo05h0oooo00<0UIFE0000000000000P0000001P0[:b/0oooo0?ooo`32`/<0MWMh01lP
8P<02``>00<0U9FF0?ooo`3oool03@3oool01`1aLG802``>00/<3P0;30h0=3Df075bL`3AdM80103o
ool00`3Zj^X0820P0410@0040?ooo`030>_[j`2^[Zl0IfQY00@02``>00<0dM;B0?ooo`3oool01@3o
ool01`2DUIH02``>00/<3P0;30h07b0R05aMGP2c/k@01P3oool01P3EeMD0@410000000000000L71`
0>[ZjS<0oooo3?ooool000[ooooo;03oool00`10@40071`L0>?Sh`100?ooo`0305EEE@0[:b/0oooo
02@0oooo00<000000?ooo`3oool0103oool01@3Shn<0EEEE03Ti>@1EEED0JVYZ05D0oooo00L0>CTi
000000000000000000410@051@H0B4U:00L02``>00<0`/;30?ooo`3oool03@3oool00`2^[Zl02``>
00/<3P0500/<3P0:05aMGP2JVY/0oooo05EEE@0E5AD0hn?S0?ooo`3Ti>@0Ti>D04Q9BPL02``>203o
ool00`32`/<02``>00/<3P0500/<3P0604Q9BP2CTi@0i>CT0?ooo`3Shn<071`L100000000`1aLG40
oooo0?ooo`0a0?ooo`cooooo000:ooooob`0oooo00@0j^[Z01`L700L71`0j^[Z?P3oool00`36a/H0
00000:ZZZP0U0?ooo`030000003oool0oooo00@0oooo00H0ZZZZ0410@03oool0oooo0;no_`0i>CUD
0?ooo`0401`L700000000@4200H720X02``>00<0@D5105EEE@1EEED03P1EEED:00/<3P0400H72021
PH40bLW:03@e=PT02``>00<02@T;05EEE@1EEED01`1EEED:00/<3P0305aMGP2?Shl0000000@00000
00<071`L0?ooo`3oool0<@3oool<ooooo`002_ooool]0?ooo`050>[ZjP10@400<30`0:ZZZP20P800
0P10@4000`2`/;00oooo0?ooo`060?ooo`050;2`/010@400@4100820P03Zj^X01`3oool01@3De=@0
H61P0410@01EEED0clo?00L0oooo00D0kno_0820P010@400@41009FEU@080?ooo`050;no_`1@D500
@410071`L03Zj^X01P3oool01P3_knl05ADE00000010@400EEEE0;no_b<0oooo00<000000?ooo`3o
ool0103oool00`2ZZZX0@4100?ooo`020?ooo`030410@02EUID0oooo0580oooo00D0P82000000003
0`@01PH700T:300900/<3P03069RHP20P800P82000d0P82000<0EeMH00/<3P0;30h01`0;30h01P08
2@/0<34b0=7AdP32`/<0MWMh03@e=PP02``>00<02@X<0820P020P8001P20P8000`1RHV802``>00/<
3P0700/<3P0303@e=P1fMgP0PX:300D0000000<05ADE0?ooo`3oool0<@3oool<ooooo`002_ooool_
0?ooo`0306YZJP000000000000<0000000<0SXj>0?ooo`3oool0103oool00`2ZZZX0000000000002
0000000303Ti>@3oool0oooo00@0oooo00<0hn?S01`L700000000`0000000`3Shn<0oooo0?ooo`04
0?ooo`0306YZJP00000000000080000000<0JVYZ0?ooo`3oool0103oool00`2ZZZX0000000000002
0000000303Ti>@3oool0oooo00@0oooo00<0JVYZ0000000000000`0000000`2ZZZX0oooo0?ooo`0P
0?ooo`030000003oool0oooo00@0oooo00<0ZZZZ0410@03oool00P3oool205EEEE@0oooo00L0JVYZ
000000000000:b/[0<S8b025QXL09RLY00H02``>00<0[Zj_0?ooo`3oool03@3oool00`2^[Zl02``>
00/<3P0400/<3P050452@`2CTi@0EUIF00000036a/H0103oool00`3Ti>@0LG5b00/<3P0600/<3P03
0>_[j`3oool0oooo00D0oooo00<0`/;300/<3P0;30h0100;30h00`0V9bT0QHJ70>CTi0030?ooo`03
05EEE@00000000000080000000<0ZZZZ0?ooo`3oool0<@3oool<ooooo`002_ooool_0?ooo`030;no
_`000000000000<0000000<0EEEE0?ooo`3oool0103oool00`1EEED0000000000003000000030>[Z
jP3oool0oooo00<0oooo00<0ZZZZ0000000000000`0000000`2>SXh0oooo0?ooo`040?ooo`D00000
00<0@4100?ooo`3oool0103oool00`1EEED0000000000003000000030>?Sh`3oool0oooo0080oooo
00<0hn?S01DE5@000000100000000`1ZJVX0oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo
00<0ZZZZ0410@03oool00P3oool00`0L71`0EEEE0?ooo`1E0?ooo`030>?Sh`3oool0oooo0080oooo
00<0bLW:05aMGP0;30h00`0;30h00`1aLG<0oooo0?ooo`0=0?ooo`030452A00;30h02``>00802``>
00H0G5eN0=OGe`3oool0hn?S0000001aLG480?ooo`030:j^[`18BDX02``>00<02``>00<0[Zj_0?oo
o`3oool01@3oool00`1aLG<02``>00/<3P0200/<3P030452@`2^[Zl0oooo00D0oooo00D0hn?S0410
@0000000000006YZJP0d0?ooo`cooooo000:ooooobl0oooo00<0_kno0000000000000`0000000`10
@400oooo0?ooo`040?ooo`0301DE5@000000000000<0000000<0_kno0?ooo`3oool00`3oool00`1Z
JVX00000000000030000000305EEE@3oool0oooo00@0oooo1@0000000`0`<300oooo0?ooo`040?oo
o`0301DE5@000000000000<0000000<0ZZZZ0?ooo`3oool00P3oool00`10@400410@000000040000
00030410@03oool0oooo0200oooo00<000000?ooo`3oool0103oool01`2ZZZX0820P0=CDe03oool0
X:2P0000002o_kl0G@3oool01P3[jn/0[Zj_06MXJ@0O82806Q/M0=KGe`d0oooo00D0[Zj_00/<3P0Z
:b`0LG9c0;>c]0040?ooo`0302/[:`0`<300oooo00X0oooo00D0jn_[0:BTY@1LGEh02``>03Tj>`06
0?ooo`060>_[j`0J6ad07b0R05aMGP2TY:D0jn_[2P3oool00`3Zj^X0oooo0?ooo`0d0?ooo`cooooo
000:ooooobl0oooo00<0eMGE0000000000000`0000000`1EEED0oooo0?ooo`040?ooo`03075aL@00
0000000000<000001P3oool00`36a/H0000000000003000000030:ZZZP3oool0oooo00@0oooo00<0
5ADE0000000000000P0000000`10@400oooo0?ooo`040?ooo`03075aL@000000000000<00000103o
ool00`2EUID000000:ZZZP05000000030820P03oool0oooo0200oooo00<000000?ooo`3oool0103o
ool01P2ZZZX0@410075aL@0000005ADE0:ZZZV80oooo00<0`/;309:CU03oool0303oool00`1gN7T0
bLW:0?ooo`050?ooo`03075aL@000000ZZZZ00l0oooo00<0VYZK0<W9b@3oool0103oool01@2BTi@0
`/;30?ooo`3oool0JVYZ00@0EEEE?P3oool<ooooo`002_ooool`0?ooo`0308j>SP0L71`000000080
000000<0SXj>0?ooo`3oool0103oool00`3Shn<0:b/[00000002000000030:ZZZP3oool0oooo00D0
oooo00D0LG5a000000000000000005EEE@070?ooo`060:ZZZP0L71`000000000000L71`0_kno1P3o
ool00`3Shn<0>CTi00000002000000030:ZZZP3oool0oooo0080oooo00@0:b/[075aL@3oool0LG5a
0`0000000`0i>CT0j^[Z0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<0ZZZZ0410@03oool0
L@3oool01@3Shn<0SXj>05EEE@2>SXh0hn?S00D0oooo00<0eMGE0000000i>CT06`3oool01P2o_kl0
>CTi05EEE@1EEED0>CTi0;no_cd0oooo3?ooool000[ooooo<@3oool01P3Zj^X0_kno0;no_`2PX:00
00000820P0H0oooo00@0kno_0;no_`2_[jl0j^[Z2@3oool00`3?cll0ZZZZ0;no_`090?ooo`030>[Z
jP2o_kl0_kno00X0oooo00<0_kno0:ZZZP3Ogml0103oool00`1ZJVX0820P0>[ZjP020?ooo`030=CD
e02_[jl0_kno02@0oooo00<000000?ooo`3oool0103oool00`2ZZZX0@4100?ooo`1c0?ooo`030000
003oool0oooo00D0oooo00<0@41001DE5@3Zj^X0703oool20=CDe080oooo00<0gmoO0?ooo`3oool0
>`3oool<ooooo`002_oooole0?ooo`030:ZZZP000000P8200340oooo00<0a/K60000002ZZZX0:P3o
ool00`000000oooo0?ooo`030?ooo`030>[ZjP1EEED0@41007@0oooo00<000000?ooo`3oool0103o
ool00`2ZZZX000000<K6aP0N0?ooo`030<K6aP2o_kl0oooo03h0oooo3?ooool000[ooooo=P3oool0
0`2o_kl0410@0820P00_0?ooo`030>o_k`0E5AD0@41002/0oooo00<000000?ooo`3oool01@3oool0
0`3Ogml0oooo0?ooo`1O0?ooo`030<o?c`2o_kl0_kno00D0_kno00<0clo?0;no_`2o_kl00P3oool3
0;no_`<0oooo00<000000?ooo`3oool00`3oool00`3EeMD05ADE051@D00<0?ooo`0309FEU@10@400
P82000<0P82000/0H61P00000010@400gmoO06][J`3Zj^X0oooo0;no_`000000P8200>[ZjP030?oo
o`03092@T02o_kl0oooo03d0oooo3?ooool000[ooooo=`3oool0102o_kl0000003Ti>@3Zj^X]0?oo
o`0306YZJP0L71`0hn?S02/0oooo00<000000?ooo`3oool0I`3oool00`20P800LG5a0:ZZZP030:ZZ
ZP05075aL@000000P8200>?Sh`2ZZZX00P3oool00`2>SXh05ADE0>?Sh`030?ooo`030000003oool0
oooo00<0oooo00<071`L0000003Zj^X03@3oool00`1EEED0oooo0?ooo`020?ooo`0909FEU@000000
a/K60?ooo`3Shn<0a/K60?ooo`1aLG40EEEE0080oooo00D0j^[Z0?ooo`3oool0_kno01`L700n0?oo
o`cooooo000:ooooocP0oooo00<0a/K601`L7010@400;03oool00`3Shn<05ADE08j>SP0/0?ooo`03
0000003oool0oooo06L0oooo00<0eMGE05EEE@3oool00`3oool02@1aLG4000000=GEe@3oool0a/K6
0>[ZjP3oool071`L09FEU@040?ooo`030000003oool0oooo0080oooo00<0ZZZZ0000002>SXh03P3o
ool00`1ZJVX0hn?S0?ooo`020?ooo`030410@00L71`0oooo0080oooo00@0a/K60;no_`000000eMGE
0P3oool01@2EUID0oooo0?ooo`20P800000003h0oooo3?ooool000[ooooo>@3oool01@3Zj^X0<30`
0410@03Zj^X0oooo0080_kno00<0j^[Z0?ooo`3oool01`3oool00`3Ogml0_kno0=CDe00:0?ooo`80
_kno2P3oool0103?cll0_kno0=oOg`3oool20410@0H0oooo00<0j^[Z0;no_`3De=@0903oool00`00
0000oooo0?ooo`1X0?ooo`070410@03EeMD0oooo0?ooo`3_knl0000002/[:`030?ooo`030;no_`1E
EED0:b/[00<0oooo00<0j^[Z0?ooo`0000000`3oool00`3Zj^X0820P0410@00?0?ooo`070;no_`20
P800oooo0?ooo`3EeMD0000009FEU@040?ooo`03030`<01ZJVX0oooo0080oooo00D0X:2P02/[:`10
@40000000820P00n0?ooo`cooooo000:ooooocX0oooo00@0j^[Z01`L700L71`0EEEE0`0000000`2Z
ZZX0oooo0?ooo`050?ooo`050:ZZZP00000000000000001EEED01`3oool01P3EeMD071`L00000000
000071`L0>[ZjPL0oooo00L0LG5a000000000000000003Ti>@000000eMGE00D0oooo00D0ZZZZ0000
00000000000001`L700S0?ooo`030000003oool0oooo06P0oooo00L0a/K6075aL@3oool0oooo09FE
U@000000ZZZZ00<0oooo00<0ZZZZ0000003Shn<0103oool00`2>SXh05ADE0?ooo`020?ooo`0305EE
E@0E5AD0hn?S0100oooo00D071`L0>[ZjP3oool0LG5a01DE5@040?ooo`0308j>SP0[:b/0a/K600@0
oooo00<0hn?S0:ZZZP3EeMD0?`3oool<ooooo`002_oooolk0?ooo`030>?Sh`0L71`0000000@00000
00<0eMGE0?ooo`3oool00`3oool00`36a/H0000000000003000000030<K6aP3oool0oooo00@0oooo
00<0EEEE0000000000000P0000000`1EEED0oooo0?ooo`040?ooo`030:ZZZP000000000000<00000
00<0LG5a0?ooo`3oool00`3oool00`3EeMD00000000000030000000309FEU@3oool0oooo0200oooo
00<000000?ooo`3oool0J@3oool01@0L71`0j^[Z0?ooo`1EEED071`L00@0oooo00<0:b/[05EEE@3o
ool01@3oool01P3Zj^X0oooo0?ooo`3EeMD000000820P140oooo00D0SXj>0:ZZZP3oool0000006YZ
JP030?ooo`040>?Sh`000000ZZZZ0:ZZZTH0oooo3?ooool000[ooooo1P3oool00`3_knl0e=CD0?oo
o`0c0?ooo`0305EEE@000000000000<0000000<0[jn_0?ooo`3oool00`3oool00`20P80000000000
00030000000306YZJP3oool0oooo00@0oooo00<0820P0000000000000P0000000`0@4100oooo0?oo
o`040?ooo`0305EEE@000000000000<0000000<0UIFE0?ooo`3oool00`3oool00`2PX:0000000000
000300000003051@D03oool0oooo0200oooo00<000000?ooo`3oool0J@3oool01@2EUID0X:2P0>[Z
jP000000UIFE00<0oooo00@0JVYZ0410@03oool0ZZZZ203oool00`10@4005ADE0>o_k`0A0?ooo`05
0>[ZjP1PH600P8200000002o_kl00P3oool01`3Ogml0EEEE0410@03?cll0e=CD0820P03De=@0A03o
ool<ooooo`002_ooool70?ooo`80ZZZZ<`3oool00`1EEED0000000000003000000030;no_`3oool0
oooo00<0oooo00<0SXj>0000000000000`0000000`1aLG40oooo0?ooo`040?ooo`0302/[:`000000
00000080000000<05ADE0?ooo`3oool0103oool00`1EEED0000000000003000000030:ZZZP3oool0
oooo00<0oooo00<0ZZZZ0000000000000`0000000`1EEED0oooo0?ooo`0P0?ooo`030000003oool0
oooo06X0oooo00<0EEEE075aL@0E5AD00`3oool01`2>SXh0EEEE06YZJP3oool0SXj>0820P03Shn<0
1@3oool00`2>SXh000000<K6aP0C0?ooo`0306YZJP00000071`L04h0oooo3?ooool000[ooooo203o
ool00`1EEED0eMGE0?ooo`0a0?ooo`030:ZZZP000000000000<0000000<0eMGE0?ooo`3oool00`3o
ool00`3Shn<0000000000003000000030<K6aP3oool0oooo00@0oooo00<0JVYZ0000000000000P00
00000`1EEED0oooo0?ooo`040?ooo`030:ZZZP000000000000<0000000<0a/K60?ooo`3oool00`3o
ool00`3Zj^X00000000000030000000309FEU@3oool0oooo0200oooo00<000000?ooo`3oool0AP3o
ool00`2o_kl0oooo0?ooo`0Q0?ooo`0306YZJP000000EEEE00h0oooo00<0hn?S0000001EEED0503o
ool00`2ZZZX0000008j>SP1>0?ooo`cooooo000:ooooo`0:0>[ZjP1@D500EEEE0;no_`2PX:00EEEE
0<o?c`3oool0eMGE061PH3<0oooo00<0[jn_0000000000000P0E5AD00`3?cll0oooo0?ooo`040?oo
o`050=CDe00`<300000001DE5@2`/;001`3oool01P3_knl0P820000000000000P8200>o_k`L0oooo
00D0_kno020P80000000@4100=CDe0070?ooo`050=CDe010@400000001DE5@2EUID08`3oool00`00
0000oooo0?ooo`160?ooo`030<o?c`20P800oooo0240oooo00<0_kno0000002_[jl03P3oool00`10
@40000000=oOg`0E0?ooo`0302/[:`3Zj^X0oooo04d0oooo3?ooool000[ooooo00L0EEEE0410@03o
ool0a/K601DE5@2ZZZX0j^[Z0080oooo00<05ADE0?ooo`3oool0=@3oool00`1EEED000000:ZZZP0N
0?ooo`030>?Sh`0E5AD0SXj>02d0oooo00D0hn?S0820P01EEED0EEEE0000000205EEE@030820P036
a/H0oooo04@0oooo0P2>SXhR0?ooo`0303Ti>@3oool0oooo00`0oooo00<0UIFE0000002>SXh0IP3o
ool<ooooo`002_ooool01P1aLG40P8200?ooo`3oool0@4100:ZZZP<0oooo00<0@4100<K6aP3oool0
=P3oool00`20P80000000:ZZZP0M0?ooo`0305EEE@0[:b/0oooo02`0oooo00<0_kno000000000000
1`0000000`36a/H0oooo0?ooo`0j0?ooo`050<K6aP0i>CT0@41005EEE@1aLG400`3oool00`3Shn<0
71`L0?ooo`0`0?ooo`0301DE5@0i>CT0oooo06H0oooo3?ooool000[ooooo00H0oooo0820P02o_kl0
oooo0410@02ZZZX30?ooo`030410@02ZZZX0oooo03L0oooo00<0P8200000002PX:006`3oool00`2Z
ZZX000000;no_`0^0?ooo`0301DE5@000000000000D0000000<0:b/[0?ooo`3oool0>`3oool205EE
E@80oooo00<0_kno051@D03oool00P3oool00`0[:b/0_kno0?ooo`0^0?ooo`0305EEE@0@4100j^[Z
06L0oooo3?ooool000[ooooo0`3oool00`2ZZZX0:b/[0:ZZZP030?ooo`030410@02ZZZX0oooo03P0
oooo00<0ZZZZ0000002ZZZX06@3oool00`3Zj^X0000005EEE@0_0?ooo`0308j>SP000000000000D0
000000<0SXj>0?ooo`3oool0>`3oool205EEE@<0oooo00H0@4100>?Sh`3oool0oooo05EEE@20P80^
0?ooo`030:ZZZP000000UIFE06P0oooo3?ooool000[ooooo00H0_kno051@D03oool0oooo0410@02o
_kl30?ooo`03030`<03Zj^X0oooo03T0oooo00<0X:2P00000020P800603oool00`1@D500:b/[0>[Z
jP0`0?ooo`03010@40000000000000<0000000<0410@0>[ZjP3oool0?03oool205EEE@<0oooo00H0
@4100:ZZZP3oool0oooo05EEE@20P80]0?ooo`040=oOg`0E5AD0:b/[0>o_kfP0oooo3?ooool000[o
oooo00D0oooo0820P02ZZZX0SXj>05EEE@040?ooo`0302/[:`3oool0oooo03X0oooo00D0a/K601DE
5@1EEED0oooo0=GEe@020:ZZZPT0oooo00@0hn?S0:ZZZP2EUID0hn?S1@3oool01`36a/H000000>?S
h`3oool0_kno08j>SP2o_kl0;@3oool00`10@4000000000000030000000305EEE@3oool0oooo03`0
oooo0P1EEED30?ooo`0600000036a/H0oooo0?ooo`1EEED0P820;@3oool00`1EEED000000>?Sh`1Y
0?ooo`cooooo000:ooooo`P0oooo00<0SXj>09FEU@3oool0?03oool00`2o_kl0000001`L70030000
000302/[:`3Shn<0oooo00D0oooo00<0eMGE0000000000000P0000000`2ZZZX0oooo0?ooo`020?oo
o`0401`L701EEED0oooo05EEE@<0000000<0EEEE0?ooo`3oool0:P3oool00`20P800000000000003
0000000309FEU@3oool0oooo03`0oooo00H0EEEE01`L703EeMD0oooo05EEE@0E5AD30?ooo`0303Ti
>@2o_kl0oooo02/0oooo00<0hn?S0000002>SXh0JP3oool<ooooo`002_ooool70?ooo`030>[ZjP1E
EED0oooo03h0oooo00<0UIFE0000000000000`0000000`1ZJVX0oooo0?ooo`040?ooo`03051@D000
000000000080000000P0@4100?ooo`3oool0oooo05EEE@0E5AD0gmoO0;no_`D0000000<0ZZZZ0?oo
o`3oool0:@3oool00`2o_kl0000000000003000000030=oOg`3oool0oooo03`0oooo0P1EEED01020
P800@41005EEE@3?cll20?ooo`030>[ZjP0E5AD0kno_02/0oooo00<0kno_02/[:`0`<300J`3oool<
ooooo`002_ooool60?ooo`030>[ZjP2>SXh0oooo03l0oooo00<0ZZZZ0000000000000`0000000`1E
EED0oooo0?ooo`040?ooo`H000000P3oool01@2o_kl0000008j>SP3oool0EEEE00D0000000<0EEEE
0?ooo`3oool0:P3oool01@0L71`00000000000000000>CTi03l0oooo0P1EEED60?ooo`03075aL@2Z
ZZX0oooo02/0oooo00<0P8200000002o_kl0J`3oool<ooooo`002_oooom80?ooo`030:ZZZP000000
000000<0000000<0EEEE0?ooo`3oool0103oool00`10@4000000000000020000000502/[:`3oool0
oooo0410@00i>CT00P3oool00`2ZZZX00000000000030000000308j>SP3oool0oooo02X0oooo00D0
LG5a000000000000000008j>SP0o0?ooo`80EEEE1@3oool00`3Zj^X0EEEE0?ooo`0/0?ooo`0301DE
5@1EEED0oooo06/0oooo3?ooool000[oooooB@3oool00`1EEED0000000000002000000030:ZZZP3o
ool0oooo00@0oooo00<0/;2`0000000000000P0000001@2@T900oooo0:ZZZP0@4100j^[Z00<0oooo
00H0:b/[00000000000000000410@03Zj^X/0?ooo`050>[ZjP0E5AD000000000003Zj^X0?P3oool0
0`3Ogml0EEEE05EEE@050?ooo`030:n_[`3oool0oooo02/0oooo00<0EEEE010@403Zj^X0K03oool<
ooooo`002_oooom:0?ooo`060:ZZZP1EEED0EEEE0410@00L71`0hn?S1P3oool0203Shn<0EEEE05EE
E@36a/H0oooo0>?Sh`000000P8201@3oool00`20P800EEEE09FEU@0_0?ooo`03075aL@000000LG5a
07@0oooo00<0SXj>0000002EUID0K@3oool<ooooo`002_oooom=0?ooo`040>[ZjP0L71`071`L0>[Z
jPX0oooo00<0>CTi01`L703Zj^X0=`3oool00`36a/H000000<K6aP1c0?ooo`030>[ZjP00000071`L
06h0oooo3?ooool000[oooooCP3oool0103Zj^X0@410020P802o_kl80?ooo`030:2PX0000000_kno
03T0oooo00<0@4100?ooo`3oool0LP3oool00`1`L70000000=GEe@1^0?ooo`cooooo000:oooooe00
oooo00<0P8200000002o_kl01`3oool00`0E5AD0LG5a0?ooo`0i0?ooo`030>[ZjP3oool0oooo0740
oooo00<0a/K60000002>SXh0K`3oool<ooooo`002_oooomA0?ooo`0305EEE@0E5AD0hn?S00D0oooo
00<0LG5a01DE5@3oool0[P3oool00`0L71`0:b/[0?ooo`1_0?ooo`cooooo000:oooooe80oooo00<0
H61P01DE5@2o_kl00`3oool00`3?cll000000:2PX02^0?ooo`0306YZJP000000_kno0700oooo3?oo
ool000[oooooD`3oool01`1EEED000000:ZZZP3Shn<0EEEE02/[:`0L71`0[P3oool00`2o_kl00000
05EEE@1a0?ooo`cooooo000:oooooe@0oooo00<0UIFE010@400000000`0000000`1@D500oooo0?oo
o`2[0?ooo`03030`<00[:b/0j^[Z0740oooo3?ooool000[oooooE@3oool00`10@400000000000003
00000:`0oooo00<0SXj>0000003Shn<0LP3oool<ooooo`002_oooomE0?ooo`030410@00000000000
00<00000Z`3oool00`3Shn<0000005EEE@1c0?ooo`cooooo000:oooooeD0oooo00<0L71`00000000
00000P0000000`0@4100oooo0?ooo`2X0?ooo`040>o_k`0[:b/05ADE0=oOgg<0oooo3?ooool000[o
ooooE@3oool00`3Zj^X0>CTi00000002000000030;no_`3oool0oooo0:P0oooo00<0UIFE0000002Z
ZZX05P3oool02@3Zj^X0SXj>05EEE@20P800hn?S0?ooo`2ZZZX0EEEE0:ZZZP060?ooo`030<K6aP3E
eMD0oooo04`0oooo3?ooool000[oooooE`3oool20:ZZZP030>?Sh`3oool0oooo0:T0oooo00<05ADE
03Ti>@3oool0603oool01P000000_kno0?ooo`3Zj^X00000075aL@@0oooo00H0a/K60>[ZjP2ZZZX0
000001DE5@3Shn<40?ooo`030;no_`3oool0oooo04D0oooo3?ooool000[oooooo`3oool50?ooo`03
05EEE@0@4100j^[Z01T0oooo00D000000;no_`3Zj^X0<30`0820P0040?ooo`070:2PX02o_kl0oooo
0?ooo`2o_kl0gmoO06][J`040?ooo`030<o?c`20P800oooo04D0oooo3?ooool000[oooooo`3oool4
0?ooo`030:ZZZP000000UIFE01X0oooo00@000000;no_`1EEED0@410103oool00`3Shn<0JVYZ0?oo
o`040?ooo`030>?Sh`36a/H0oooo00<0oooo00<0SXj>0:ZZZP3oool0A03oool<ooooo`002_oooooo
0?ooo`@0oooo00<0:b/[01`L703oool00P3oool01`1ZJVX0a/K60?ooo`3Zj^X0>CTi0000002ZZZX0
203oool03P3Shn<0JVYZ0>?Sh`3oool0eMGE0000000L71`0eMGE0?ooo`000000P8200:ZZZP2EUID0
SXj>0`3oool00`1aLG40ZZZZ0?ooo`040?ooo`030<K6aP1EEED0oooo00<0oooo00<0hn?S05EEE@3o
ool0A03oool<ooooo`002_oooooo0?ooo`<0oooo00<0UIFE0000003EeMD0103oool01`2ZZZX0oooo
0=oOg`000000ZZZZ0?ooo`3De=@01P2o_kl0203?cll0oooo0=oOg`3De=@0oooo0:2PX00E5AD0j^[Z
0P3oool01P000000_kno0?ooo`3oool0:b/[0820P080oooo00<000000=oOg`3oool0103oool202/[
:`030>o_k`3oool0oooo0080oooo00<0820P0?ooo`3oool0@`3oool<ooooo`002_oooooo0?ooo`80
oooo00<0a/K60000001ZJVX01@3oool0103Shn<0a/K605EEE@1aLG420?ooo`0308j>SP1EEED0EEEE
00@0EEEE00L0P8200?ooo`3oool0a/K60>?Sh`0E5AD0a/K600<0oooo00@000000;no_`3oool0oooo
0P1EEED00`3oool0ZZZZ000000050?ooo`040;no_`000000hn?S0:ZZZP@0oooo00<0@4100:ZZZP3o
ool0@`3oool<ooooo`002_oooooo0?ooo`80oooo00<071`L0000003Zj^X01P3oool00`2ZZZX05ADE
0>?Sh`0=0?ooo`0305EEE@10@400oooo00<0oooo00T000000;no_`3oool0j^[Z00000036a/H0oooo
0:ZZZP0000001@3oool0101ZJVX0EEEE0?ooo`2o_kl40?ooo`030410@02ZZZX0oooo04<0oooo3?oo
ool000[oooooo`3oool10?ooo`03092@T0000000ZZZZ00H0oooo00<0j^[Z01DE5@1`L7003@3oool0
0`2ZZZX000000;2`/0020?ooo`070>o_k`2ZZZX0P8200:n_[`2o_kl0X:2P0>[ZjP020?ooo`030:ZZ
ZP000000oooo00<0oooo00D0j^[Z010@403EeMD0oooo0;no_`040?ooo`030410@02ZZZX0oooo04<0
oooo3?ooool000[oooooo`3oool00`3Shn<05ADE05EEE@070?ooo`80>CTi00D0j^[Z0<K6aP3oool0
oooo05EEE@06000000060410@03oool0j^[Z0000002>SXh0_kno303oool00`000000j^[Z0?ooo`02
0?ooo`03075aL@1EEED0oooo0080oooo00D0SXj>0?ooo`3oool0oooo02/[:`150?ooo`cooooo000:
ooooool0oooo00<0@410020P803Zj^X01P3oool01`2@T900@4100820P03_knl0P8200:ZZZP3_knl0
203oool01`3Zj^X0L71`0410@02o_kl0gmoO06][J`2o_kl02P3oool03`1EEED0[jn_0?ooo`3oool0
_kno0410@01`L700j^[Z0?ooo`3Ogml0Jf][0>[ZjP3oool0j^[Z0410@0150?ooo`cooooo000:oooo
ooh0oooo00<0SXj>0000002ZZZX09`3oool00`3Shn<0P8200?ooo`0:0?ooo`03075aL@2o_kl0oooo
04@0oooo3?ooool000[oooooo@3oool00`3Zj^X0000001`L700Y0?ooo`030820P03Shn<0oooo00P0
oooo00<0j^[Z05EEE@3oool0A@3oool<ooooo`002_ooooon0?ooo`030:ZZZP3EeMD0oooo02T0oooo
00<0ZZZZ0>o_k`3oool01`3oool00`2_[jl0oooo0?ooo`150?ooo`cooooo000:ooooool0ooooO@3o
ool<ooooo`00oooooonCooooo`00oooooonCooooo`00oooooonCooooo`00\
\>"],
  ImageRangeCache->{{{0, 401.312}, {140.375, 0}} -> {-35.4076, -11.2524, \
4.20749, 4.20749}}],

Cell[TextData[{
  "Fig. 6.11  (a) Triangular domain together with a possible choice of grid. \
The rightmost point in each row has  index ",
  Cell[BoxData[
      \(TraditionalForm\`j = g(k) + 1\)]],
  ".   (b)  Points ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(k)\  + 1\)]],
  " at the end of row ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "."
}], "Caption",
  CellTags->"Fig. 6.11"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  " Solve for the potential created by a rectangular lattice of ions and \
electrons, with charges ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-e\)\)]],
  " respectively. (Actually, in  this two dimensional problem these are \
charged rods, not point charges, and ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is charge per unit length.) The positive \"ions\" are at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((i, \ 2  j)\)\(,\)\)\)]],
  " and the \"electrons\" are at positions ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1/2, \ 2  j + 1/2)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are integers. In the rectangular domain defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)/4 < x < 3/4, \ 0 < y < 2\)]],
  ",solve for the potential using a FFT,  and  take a sufficiently fine grid \
to determine the potential at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2, \ y = 3/4\)]],
  " to three significant figures."
}], "Text"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " The following charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, y, z)\)]],
  ", defined in a cube,  is periodically-replicated throughout space. Find \
the potential at the center of the cube to three significant figures using \
the FFT method."
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, y, 
          z)\  = \(\(A\ x\ y\ z\^2\ \((1 - x)\) \((1 - 
                y\^2)\) \((1 - z)\)\^2\)\(-\)\(A\/720\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1; \ 0 < y < 1; \ 0 < z < 1\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 Numerical Eigenmode Methods", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:39", "c:28"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["6.3.1 Introduction", "Subsubtitle",
  CellTags->"c:29"],

Cell[TextData[{
  "\tIn Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ", solutions to PDEs such as the wave, heat, and Schr\[ODoubleDot]dinger \
equations were developed using eigenmode expansions. However, such solutions \
were useful only for cases where the eigenmodes and eigenvalues could be \
determined analytically. In this section we show how the eigenmodes can be \
evaluated numerically. This provides us with certain advantages over the \
Galerkin and grid methods. In those methods, we had to step forward ",
  StyleBox["in time, laboriously calculating the solution at each ", "NE2"],
  "time step",
  StyleBox[". However, with knowledge of the eigenmodes and eigenvalues", 
    "NE2"],
  ",",
  StyleBox[" we c", "NE2"],
  "an use the general solution of the equations to bypass numerical time \
integration.  Once we have the eigenmodes, all we need do is evaluate some \
inner products over the initial conditions and source functions (if any), and \
we are done."
}], "Text"],

Cell["\<\
\t  Furthermore, for a given system we need evaluate the eigenmodes \
and eigenvalues only once. Once we have them, we can solve the problem for \
any given initial conditions or source functions. \
\>", "Text"],

Cell["\<\
\tHere we consider three numerical methods for determining the \
eigenmodes: a technique based on the finite-differenced PDE; a technique  \
based on the Galerkin method; and a  semi-analytic technique for 1D systems, \
based on the shooting method combined with WKB analysis.   This last method \
has excellent accuracy for the eigenvalues, but is rather difficult to \
implement, since the WKB eigenvalues first have to be evaluated in order to \
provide initial guesses in the shooting method. Also,  turning points, if \
any, have to be found in the process.  The grid and Galerkin eigenmode \
methods are, generally speaking, easier to program than the WKB-shooting \
method, but  are usually not as accurate, especially for high-order modes. \
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.2 Grid-Method Eigenmodes", "Subsubtitle",
  CellTags->{"i:42", "c:30"}],

Cell[CellGroupData[{

Cell["General Theory", "Section",
  CellTags->"c:31"],

Cell["\tConsider the following 1D eigenvalue problem:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.1)"],

Cell[TextData[{
  "with homogeneous boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ". We will finite-difference the equation, so as to obtain a matrix \
eigenvalue problem of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{
                RowBox[{
                  StyleBox["L",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "\[CenterDot]", 
                  StyleBox[
                    SubscriptBox["\[Psi]", 
                      StyleBox["n",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], "=", 
                RowBox[{\(\[Lambda]\_n\), 
                  StyleBox[
                    SubscriptBox["\[Psi]", 
                      StyleBox["n",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}]}],
              "TraditionalForm"], ","}]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox["\[Psi]", 
            StyleBox["n",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " are discretized forms of the operator and eigenfunction respectively. We \
will then apply the intrinsic functions ",
  StyleBox["Eigenvalues",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Eigenvectors",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " in order to determine numerical approximations to the eigenvalues and \
eigenfunctions."
}], "Text"],

Cell[TextData[{
  "\tWe will discretize this ODE  on a uniform grid. For Dirichlet boundary \
conditions at both ends, we take ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{"a", "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", "j"}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  ... , M\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(\((b - a)\)/M\)}], 
        TraditionalForm]]],
  ". For von Neumann  conditions at both ends, as discussed in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"],
  ", we take ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", 
          RowBox[{"a", "+", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", \((j - 1/2)\)}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2,  .. , M, \)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "=", \(\((b - a)\)/\((M - 1)\)\)}], 
        TraditionalForm]]],
  ". On either of these grids Eq. ",
  ButtonBox["(6.3.1)",
    ButtonData:>"(6.3.1)",
    ButtonStyle->"Hyperlink"],
  " becomes a matrix equation for the interior points in the domain,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(k = 0\)\%M L\_\(j\ k\)\ \
\((\[Psi]\_n)\)\_\(\(\ \)\(k\)\) = \
\(\(\[Lambda]\_n\)(\[Psi]\_n)\)\_j\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, 3,  ... , M - 1, \)]]
}], "NE3",
  CellTags->"(6.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(j\ k\)\)]],
  " is the difference form of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_k = \(\[Psi]\_n\)(x\_k)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "th element of the difference form of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th eigenmode."
}], "Text"],

Cell[TextData[{
  "\t For the end points, we must supplement  Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  " with homogeneous boundary conditions. For Dirichlet conditions, we have \
",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \(\((\[Psi]\_n)\)\_M = 0\)\)]],
  ".  For ",
  "von Neumann ",
  " boundary conditions, we need to set the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " equal to zero at the end points. According to Eq. ",
  ButtonBox["(6.2.20)",
    ButtonData:>"(6.2.20)",
    ButtonStyle->"Hyperlink"],
  ", we take ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \((\[Psi]\_n)\)\_1\)]],
  ". Similarly on the right side, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_\(M - 1\) = \((\[Psi]\_n)\)\_M\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor Dirichlet boundary conditions, setting ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \(\((\[Psi]\_n)\)\_M = 0\)\)]],
  " in the sum of Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  "  results in the following closed set of equations for the interior \
points:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(k = 1\)\%\(M - 1\)L\_\(j\ k\)\ \
\((\[Psi]\_n)\)\_\(\(\ \)\(k\)\) = \
\(\(\[Lambda]\_n\)(\[Psi]\_n)\)\_j\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, 3,  ... , M - 1. \)]]
}], "NE3",
  CellTags->"(6.3.3)"],

Cell["This matrix eigenvalue problem is shown schematically below:", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{GridBox[{
                    {\(L\_\(1\ 1\)\)},
                    {\(L\_\(2\ 1\)\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ 1\)\)}
                    }], GridBox[{
                    {\(L\_12\)},
                    {\(L\_22\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ 2\)\)}
                    }], GridBox[{
                    {"..."},
                    {"..."},
                    {"\[VerticalEllipsis]"},
                    {"..."}
                    }], GridBox[{
                    {\(L\_\(1\ M - 1\)\)},
                    {\(L\_\(2\ M - 1\)\)},
                    {"\[VerticalEllipsis]"},
                    {\(L\_\(M - 1\ \ M - 1\)\)}
                    }]}], ")"}], 
            RowBox[{"(", GridBox[{
                  {\(\((\[Psi]\_n)\)\_1\)},
                  {\(\((\[Psi]\_n)\)\_2\)},
                  {"\[VerticalEllipsis]"},
                  {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
                  }], ")"}]}], "=", 
          RowBox[{\(\[Lambda]\_\(\(n\)\(\ \)\)\), "(", GridBox[{
                {\(\((\[Psi]\_n)\)\_1\)},
                {\(\((\[Psi]\_n)\)\_2\)},
                {"\[VerticalEllipsis]"},
                {\(\(\ \)\(\((\[Psi]\_n)\)\_\(M - 1\)\)\)}
                }], ")"}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(6.3.4)"],

Cell[TextData[{
  "For ",
  "von Neumann ",
  " conditions, we set  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0 = \((\[Psi]\_n)\)\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_M = \((\[Psi]\_n)\)\_\(M - 1\)\)]],
  " in the sum in Eq. ",
  ButtonBox["(6.3.2)",
    ButtonData:>"(6.3.2)",
    ButtonStyle->"Hyperlink"],
  ". The resulting equations have the following form:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{GridBox[{
                  {\(L\_\(1\ 1\) + L\_\(1\ 0\)\), \(L\_\(1\ 2\)\), "..."},
                  {\(L\_\(2\ 1\) + L\_\(2\ 0\)\), \(L\_\(2\ 2\)\), "..."},
                  {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                    "\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ 1\) + 
                      L\_\(M - 1\ \ 0\)\), \(L\_\(M - 1\ \ 2\)\), "..."}
                  }], GridBox[{
                  {\(L\_\(1\ M - 2\)\)},
                  {\(L\_\(2\ M - 2\)\)},
                  {"\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ M - 2\)\)}
                  }], GridBox[{
                  {\(L\_\(1\ M - 1\) + L\_\(1\ M\)\)},
                  {\(L\_\(2\ M - 1\) + L\_\(2\ M\)\)},
                  {"\[VerticalEllipsis]"},
                  {\(L\_\(M - 1\ \ M - 1\) + L\_\(M - 1\ M\)\)}
                  }]}], ")"}], 
          RowBox[{"(", GridBox[{
                {\(\((\[Psi]\_n)\)\_1\)},
                {\(\((\[Psi]\_n)\)\_2\)},
                {"\[VerticalEllipsis]"},
                {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
                }], ")"}]}], "=", 
        RowBox[{\(\[Lambda]\_\(\(n\)\(\ \)\)\), "(", GridBox[{
              {\(\((\[Psi]\_n)\)\_1\)},
              {\(\((\[Psi]\_n)\)\_2\)},
              {"\[VerticalEllipsis]"},
              {\(\((\[Psi]\_n)\)\_\(M - 1\)\)}
              }], ")"}]}], TraditionalForm]]]], "NE3",
  CellTags->"(6.3.5)"],

Cell[TextData[{
  "The first and last columns of the matrix have been modified to allow for \
the contributions of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n)\)\_M\)]],
  " to each equation. "
}], "Text"],

Cell[TextData[{
  "\tWe can now extract the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and determine the eigenvalues and eigenvectors numerically. Two examples \
are considered below."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: 1D Heat Equation with Mixed Boundary Conditions", "Section",
  CellTags->"c:32"],

Cell["\<\
\tAs an example of this method, consider the operator appearing in \
the heat equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Chi] \[PartialD]\^2\/\[PartialD]x\^2\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "We will solve for the eigenmodes of this operator on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, b]\)\)]],
  ", with a Dirichlet condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = 0\)]],
  ",  and a ",
  "von Neumann ",
  " condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[Prime]\)(b) = 0\)]],
  ". This operator has eigenfunctions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = 
        sin[\ \((n\  + \ 1/2)\)\ \[Pi]\ x/b]\)]],
  ", and eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \ \(-\[Chi]\ [\((n\  + \ 1/2)\)\ \
\[Pi]\ /b]\^\(\(\ \)\(2\)\)\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor this problem, the grid is chosen as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\_j\), "=", " ", 
          RowBox[{"j", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "=", \(b/\((M - 1/2)\)\)}], ","}], 
        TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  " falls halfway between the ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1  st\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "th points, as discussed previously in Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
\t  We can use a centered-difference scheme for the second \
derivative at the interior points, to obtain\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(L\)\(\ \)\)\_\(j\ k\)\), "=", " ", 
          RowBox[{"\[Chi]", "  ", 
            
            RowBox[{\((\[Delta]\_\(j + 1  k\) - \ 
                  2  \[Delta]\_\(j\ k\)\  + \[Delta]\_\(j - 1, k\))\), "/", 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"], " "}]}]}], 
        TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, \(\(...\)\(.\)\(\ \)\(M\)\) - 1\)]]
}], "NE3",
  CellTags->{"(2.4.49)", "(6.3.6)"}],

Cell[TextData[{
  " We then modify the  last column of the matrix equation to set the \
derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " equal to zero at ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ",  according to Eq. ",
  ButtonBox["(6.3.5)",
    ButtonData:>"(6.3.5)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tBelow, we construct ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\_\(j\ k\)\)\(\ \)\)\)]],
  " (called",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox["lmat",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " in the module)."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(creatematrix[M_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({L}\), ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(L[j_, 
                k_] = \[Chi] \((KroneckerDelta[j + 1, k]\  + \ 
                      KroneckerDelta[j - 1, k]\  - 
                      2\ KroneckerDelta[j, k])\)/\[CapitalDelta]x\^2\), "  ", 
            ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                modify\ the\ rightmost\ column\ to\ acccount\ for\ von\ \
Neumann\ \(\(conditions\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(L[j_, M - 1]\  = \ 
              L[j, M - 1]\  + \ L[j, M]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(lmat\  = \ 
              Table[L[j, k], {j, 1, M - 1}, {k, 1, M - 1}]\), ";"}]}], 
        "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.132"],

Cell[TextData[{
  "Here is the form of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", keeping only six columns so as to show the structure:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(creatematrix[6];\)\), "\n", 
    \(MatrixForm[lmat]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.133"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(\(2\ \[Chi]\)\/\[CapitalDelta]x\^2\)\), \(\[Chi]\/\
\[CapitalDelta]x\^2\), "0", "0", "0"},
            {\(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\), "0", "0"},
            {
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\), "0"},
            {"0", 
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\(2\ \[Chi]\)\/\
\[CapitalDelta]x\^2\)\), \(\[Chi]\/\[CapitalDelta]x\^2\)},
            {"0", "0", 
              "0", \(\[Chi]\/\[CapitalDelta]x\^2\), \(-\(\[Chi]\/\
\[CapitalDelta]x\^2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now determine the eigenvalues and eigenvectors, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 100\)]],
  " points, and taking ",
  Cell[BoxData[
      \(TraditionalForm\`b = \[Pi]/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(b = Pi/2; \[Chi] = 1; 
    M = 100; \[CapitalDelta]x\  = \ 
      b/\((M - 1/2)\);\[IndentingNewLine]\), "\n", 
    \(\(creatematrix[100];\)\), "\n", 
    \(\[Lambda]\  = \ Eigenvalues[lmat // N]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.134"],

Cell[BoxData[
    \({\(-16045.68110597134`\), \(-16033.68608979855`\), \
\(-16013.70768205545`\), \(-15985.76579765333`\), \(-15949.88828967033`\), \
\(-15906.110921586554`\), \(-15854.477331634647`\), \(-15795.038989299937`\), \
\(-15727.855144014742`\), \(-15652.99276609707`\), \(-15570.526479993336`\), \
\(-15480.538489890992`\), \(-15383.11849777559`\), \(-15278.363614013977`\), \
\(-15166.378260552377`\), \(-15047.274066826614`\), \(-14921.169758487165`\), \
\(-14788.191039051075`\), \(-14648.470464597882`\), \(-14502.14731163479`\), \
\(-14349.367438262812`\), \(-14190.283138782399`\), \(-14025.052991882885`\), \
\(-13853.84170256815`\), \(-13676.819937974778`\), \(-13494.16415724763`\), \
\(-13306.056435641134`\), \(-13112.68428302317`\), \(-12914.240456960799`\), \
\(-12710.922770575555`\), \(-12502.933895358949`\), \(-12290.481159144985`\), \
\(-12073.776339441549`\), \(-11853.035452325665`\), \(-11628.478537114303`\), \
\(-11400.32943702403`\), \(-11168.815576039618`\), \(-10934.16773221247`\), \
\(-10696.619807616444`\), \(-10456.408595188888`\), \(-10213.773542690356`\), \
\(-9968.956514017875`\), \(-9722.201548109859`\), \(-9473.754615682703`\), \
\(-9223.86337404173`\), \(-8972.776920211207`\), \(-8720.745542628805`\), \
\(-8468.020471652802`\), \(-8214.853629130137`\), \(-7961.497377275222`\), \
\(-7708.2042671098125`\), \(-7455.226786714602`\), \(-7202.817109543798`\), \
\(-6951.226843052867`\), \(-6700.7067778909395`\), \(-6451.506637907241`\), \
\(-6203.874831220785`\), \(-5958.058202601891`\), \(-5714.301787411913`\), \
\(-5472.848567346623`\), \(-5233.939228226848`\), \(-4997.811920077521`\), \
\(-4764.702019734624`\), \(-4534.841896216433`\), \(-4308.460679092955`\), \
\(-4085.7840300846938`\), \(-3867.0339181180702`\), \(-3652.4283980620144`\), \
\(-3442.181393366048`\), \(-3236.5024828168703`\), \(-3035.596691625533`\), \
\(-2839.6642870539117`\), \(-2648.900578783973`\), \(-2463.495724228773`\), \
\(-2283.6345389794506`\), \(-2109.496312577035`\), \(-1941.2546297926847`\), \
\(-1779.0771975946732`\), \(-1623.1256779743921`\), \(-1473.5555267981708`\), \
\(-1330.5158388455052`\), \(-1194.1491991881287`\), \(-1064.5915410580958`\), \
\(-941.9720103466162`\), \(-826.4128368685833`\), \(-718.0292125212661`\), \
\(-616.9291764585001`\), \(-523.2135073949208`\), \(-436.9756231475416`\), \
\(-358.3014875148625`\), \(-287.26952458625425`\), \(-223.9505405671418`\), \
\(-168.4076531978349`\), \(-120.6962288363958`\), \(-80.86382726823345`\), \
\(-48.950154297493334`\), \(-24.987022167441065`\), \(-8.99831784932892`\), \
\(-0.999979231329795`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the eigenvalues are negative. In cell ",
  "6.",
  "135, we plot these eigenvalues in order of increasing absolute value and \
compare them with the exact eigenvalues, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\  = \ \(\(-\((2  n - 1)\)\^2\) = \(-1\)\), \
\(-9\), \(-25\), \(-49\),  ... \)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda]1\  = \ 
        Table[\(Reverse[\[Lambda]]\)[\([n]\)], {n, 1, 
            Length[\[Lambda]]}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(ListPlot[\[Lambda]1, DisplayFunction \[Rule] Identity];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Plot[\(-\((2  n - 1)\)^2\), {n, 1, 80}, 
        DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[%, %%, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<n\>", \*"\"\<\!\(\[Lambda]\_n\)\>\""}];\)\)}], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 6.135"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00962001 0.603319 2.32825e-05 [
[.21621 .59082 -6 -9 ]
[.21621 .59082 6 0 ]
[.40861 .59082 -6 -9 ]
[.40861 .59082 6 0 ]
[.60101 .59082 -6 -9 ]
[.60101 .59082 6 0 ]
[.79341 .59082 -6 -9 ]
[.79341 .59082 6 0 ]
[.98581 .59082 -9 -9 ]
[.98581 .59082 9 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 10 6 ]
[.01131 .02126 -36 -4.5 ]
[.01131 .02126 0 4.5 ]
[.01131 .13767 -36 -4.5 ]
[.01131 .13767 0 4.5 ]
[.01131 .25408 -36 -4.5 ]
[.01131 .25408 0 4.5 ]
[.01131 .37049 -36 -4.5 ]
[.01131 .37049 0 4.5 ]
[.01131 .48691 -30 -4.5 ]
[.01131 .48691 0 4.5 ]
[.02381 .64303 -7.625 0 ]
[.02381 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .60332 m
.21621 .60957 L
s
[(20)] .21621 .59082 0 1 Mshowa
.40861 .60332 m
.40861 .60957 L
s
[(40)] .40861 .59082 0 1 Mshowa
.60101 .60332 m
.60101 .60957 L
s
[(60)] .60101 .59082 0 1 Mshowa
.79341 .60332 m
.79341 .60957 L
s
[(80)] .79341 .59082 0 1 Mshowa
.98581 .60332 m
.98581 .60957 L
s
[(100)] .98581 .59082 0 1 Mshowa
.125 Mabswid
.07191 .60332 m
.07191 .60707 L
s
.12001 .60332 m
.12001 .60707 L
s
.16811 .60332 m
.16811 .60707 L
s
.26431 .60332 m
.26431 .60707 L
s
.31241 .60332 m
.31241 .60707 L
s
.36051 .60332 m
.36051 .60707 L
s
.45671 .60332 m
.45671 .60707 L
s
.50481 .60332 m
.50481 .60707 L
s
.55291 .60332 m
.55291 .60707 L
s
.64911 .60332 m
.64911 .60707 L
s
.69721 .60332 m
.69721 .60707 L
s
.74531 .60332 m
.74531 .60707 L
s
.84151 .60332 m
.84151 .60707 L
s
.88961 .60332 m
.88961 .60707 L
s
.93771 .60332 m
.93771 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02126 m
.03006 .02126 L
s
[(-25000)] .01131 .02126 1 0 Mshowa
.02381 .13767 m
.03006 .13767 L
s
[(-20000)] .01131 .13767 1 0 Mshowa
.02381 .25408 m
.03006 .25408 L
s
[(-15000)] .01131 .25408 1 0 Mshowa
.02381 .37049 m
.03006 .37049 L
s
[(-10000)] .01131 .37049 1 0 Mshowa
.02381 .48691 m
.03006 .48691 L
s
[(-5000)] .01131 .48691 1 0 Mshowa
.125 Mabswid
.02381 .04454 m
.02756 .04454 L
s
.02381 .06782 m
.02756 .06782 L
s
.02381 .0911 m
.02756 .0911 L
s
.02381 .11439 m
.02756 .11439 L
s
.02381 .16095 m
.02756 .16095 L
s
.02381 .18423 m
.02756 .18423 L
s
.02381 .20752 m
.02756 .20752 L
s
.02381 .2308 m
.02756 .2308 L
s
.02381 .27736 m
.02756 .27736 L
s
.02381 .30065 m
.02756 .30065 L
s
.02381 .32393 m
.02756 .32393 L
s
.02381 .34721 m
.02756 .34721 L
s
.02381 .39378 m
.02756 .39378 L
s
.02381 .41706 m
.02756 .41706 L
s
.02381 .44034 m
.02756 .44034 L
s
.02381 .46362 m
.02756 .46362 L
s
.02381 .51019 m
.02756 .51019 L
s
.02381 .53347 m
.02756 .53347 L
s
.02381 .55675 m
.02756 .55675 L
s
.02381 .58004 m
.02756 .58004 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .6033 m
.03522 .60328 L
.03714 .60325 L
.04059 .60317 L
.0447 .60306 L
.04844 .60292 L
.05657 .60253 L
.06426 .60204 L
.08038 .60062 L
.09788 .59849 L
.13049 .59288 L
.16189 .58544 L
.19209 .57643 L
.22423 .56481 L
.25517 .55167 L
.28807 .53558 L
.31976 .51802 L
.35023 .49923 L
.38267 .47718 L
.41389 .45394 L
.44707 .42711 L
.47905 .39915 L
.50981 .37031 L
.54253 .33755 L
.57404 .30395 L
.60434 .26977 L
.6366 .23134 L
.66765 .19238 L
.70065 .14884 L
.73245 .10481 L
.76303 .06054 L
.79341 .01472 L
s
.008 w
.03343 .6033 Mdot
.04305 .60311 Mdot
.05267 .60274 Mdot
.06229 .60218 Mdot
.07191 .60144 Mdot
.08153 .60051 Mdot
.09115 .5994 Mdot
.10077 .5981 Mdot
.11039 .59663 Mdot
.12001 .59498 Mdot
.12963 .59315 Mdot
.13925 .59114 Mdot
.14887 .58896 Mdot
.15849 .5866 Mdot
.16811 .58408 Mdot
.17773 .58139 Mdot
.18735 .57853 Mdot
.19697 .57552 Mdot
.20659 .57234 Mdot
.21621 .56901 Mdot
.22583 .56553 Mdot
.23545 .5619 Mdot
.24507 .55812 Mdot
.25469 .5542 Mdot
.26431 .55015 Mdot
.27393 .54596 Mdot
.28355 .54165 Mdot
.29317 .5372 Mdot
.30279 .53264 Mdot
.31241 .52797 Mdot
.32203 .52318 Mdot
.33165 .51828 Mdot
.34127 .51328 Mdot
.35089 .50819 Mdot
.36051 .50301 Mdot
.37013 .49774 Mdot
.37975 .49238 Mdot
.38937 .48696 Mdot
.39899 .48146 Mdot
.40861 .4759 Mdot
.41823 .47028 Mdot
.42785 .4646 Mdot
.43747 .45888 Mdot
.44709 .45311 Mdot
.45671 .44731 Mdot
.46633 .44148 Mdot
.47595 .43562 Mdot
.48557 .42974 Mdot
.49519 .42385 Mdot
.50481 .41796 Mdot
.51443 .41206 Mdot
.52405 .40616 Mdot
.53367 .40028 Mdot
.54329 .39441 Mdot
.55291 .38856 Mdot
.56253 .38275 Mdot
.57215 .37696 Mdot
.58177 .37122 Mdot
.59139 .36552 Mdot
.60101 .35987 Mdot
.61063 .35428 Mdot
.62025 .34874 Mdot
.62987 .34328 Mdot
.63949 .33789 Mdot
.64911 .33258 Mdot
.65873 .32735 Mdot
.66835 .32221 Mdot
.67797 .31717 Mdot
.68759 .31222 Mdot
.69721 .30738 Mdot
.70683 .30264 Mdot
.71645 .29802 Mdot
.72607 .29352 Mdot
.73569 .28914 Mdot
.74531 .28489 Mdot
.75493 .28077 Mdot
.76455 .27678 Mdot
.77417 .27293 Mdot
.78379 .26923 Mdot
.79341 .26567 Mdot
.80303 .26227 Mdot
.81265 .25901 Mdot
.82227 .25592 Mdot
.83189 .25298 Mdot
.84151 .25021 Mdot
.85113 .2476 Mdot
.86075 .24516 Mdot
.87037 .24289 Mdot
.87999 .2408 Mdot
.88961 .23888 Mdot
.89923 .23714 Mdot
.90885 .23557 Mdot
.91847 .23419 Mdot
.92809 .23299 Mdot
.93771 .23197 Mdot
.94733 .23113 Mdot
.95695 .23048 Mdot
.96657 .23002 Mdot
.97619 .22974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo
000`ooooo`03o`000?oooooooooo0?oooooo=_ooool0033ooooo00?o0000ooooooooool0oooooolf
ooooo`00<?ooool00ol0003oooooooooo`3oooooocKooooo0006ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
h_ooool00ol0003oooooooooo`1@ooooo`001_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0>;ooooo
00?o0000ooooooooool0D?ooool000Co00000oooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oo
oooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`03ooooo`?o0000hOooool00ol0003oooooooooo`1Aoooo
o`002?ooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0h?ooool00ol0003oooooooooo`1Booooo`002Oooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`3Pooooo`03o`000?oooooooooo05;ooooo000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo05?ooooo0006ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0E?ooool000Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`3Nooooo`03o`000?oooooooooo05Cooooo000`ooooo`03o`000?oooooooooo0=gooooo00?o
0000ooooooooool0EOooool0033ooooo0_l0003Nooooo`03o`000?oooooooooo05Gooooo000`oooo
o`03o`000?oooooooooo0=cooooo00?o0000ooooooooool0E_ooool0033ooooo00?o0000oooooooo
ool0foooool00ol0003oooooooooo`1Gooooo`00<?ooool00ol0003oooooooooo`3Kooooo`03o`00
0?oooooooooo05Oooooo000`ooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0F?oo
ool0033ooooo00?o0000ooooooooool0fOooool00ol0003oooooooooo`1Iooooo`00<?ooool00ol0
003oooooooooo`3Iooooo`03o`000?oooooooooo05Wooooo000`ooooo`;o0000fOooool00ol0003o
ooooooooo`1Jooooo`00<?ooool00ol0003oooooooooo`3Gooooo`03o`000?oooooooooo05_ooooo
000`ooooo`03o`000?oooooooooo0=Oooooo00?o0000ooooooooool0Foooool0033ooooo00?o0000
ooooooooool0e_ooool00ol0003oooooooooo`1Looooo`00<?ooool00ol0003oooooooooo`3Eoooo
o`03o`000?oooooooooo05gooooo000`ooooo`03o`000?oooooooooo0=Cooooo00?o0000oooooooo
ool0G_ooool0033ooooo00?o0000ooooooooool0e?ooool00ol0003oooooooooo`1Nooooo`00<?oo
ool2o`000=Cooooo00?o0000ooooooooool0Goooool0033ooooo00?o0000ooooooooool0d_ooool0
0ol0003oooooooooo`1Pooooo`00<?ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo
063ooooo000`ooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool0HOooool0033ooooo
00?o0000ooooooooool0d?ooool00ol0003oooooooooo`1Rooooo`00<?ooool00ol0003ooooooooo
o`3@ooooo`03o`000?oooooooooo06;ooooo000`ooooo`03o`000?oooooooooo0<oooooo00?o0000
ooooooooool0Hoooool0033ooooo0_l0003?ooooo`03o`000?oooooooooo06Cooooo000`ooooo`03
o`000?oooooooooo0<kooooo00?o0000ooooooooool0I?ooool0033ooooo00?o0000ooooooooool0
cOooool00ol0003oooooooooo`1Uooooo`00<?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo06Kooooo0006ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`1Woooo
o`001_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0Ioooool000Co00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`3:ooooo`03o`000?oo
oooooooo06Sooooo0008ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000005ooooo`?o0000bOooool00ol0003oooooooooo`1Yoooo
o`002Oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo06Wooooo
000:ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0J_ooool0
00Kooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo
06_ooooo0006ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0aoooool00ol0003o
ooooooooo`1[ooooo`00<?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo06cooooo
000`ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0KOooool0033ooooo0_l00035
ooooo`03o`000?oooooooooo06kooooo000`ooooo`03o`000?oooooooooo0<Cooooo00?o0000oooo
ooooool0K_ooool0033ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`1_ooooo`00
<?ooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo073ooooo000`ooooo`03o`000?oo
oooooooo0<7ooooo00?o0000ooooooooool0LOooool0033ooooo00?o0000ooooooooool0`?ooool0
0ol0003oooooooooo`1booooo`00<?ooool2o`000<7ooooo00?o0000ooooooooool0L_ooool0033o
oooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`1cooooo`00<?ooool00ol0003ooooo
ooooo`2nooooo`03o`000?oooooooooo07Cooooo000`ooooo`03o`000?oooooooooo0;gooooo00?o
0000ooooooooool0MOooool0033ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`1e
ooooo`00<?ooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo07Kooooo000`ooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooooooool0Moooool0033ooooo0_l0002kooooo`03o`00
0?oooooooooo07Sooooo000`ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0NOoo
ool0033ooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`1jooooo`00<?ooool00ol0
003oooooooooo`2gooooo`03o`000?oooooooooo07_ooooo000`ooooo`03o`000?oooooooooo0;Ko
oooo00?o0000ooooooooool0O?ooool0033ooooo00?o0000ooooooooool0]Oooool00ol0003ooooo
ooooo`1mooooo`00<?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo07kooooo000`
ooooo`;o0000]?ooool00ol0003oooooooooo`1Fooooo`;o000000Coooooo`000?l0003ooooo0_l0
00001?oooooo0000o`000?ooool2o`0001_ooooo000`ooooo`03o`000?oooooooooo0;?ooooo00?o
0000ooooooooool0C_ooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo
0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000001_ooooo000`ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool0BOooool2o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l0000Zooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo04Oooooo0_l000001?oooooo0000o`000?ooool2o`0003;ooooo000`ooooo`03o`00
0?oooooooooo0;3ooooo00?o0000ooooooooool0@_ooool2o`000004ooooool0003o0000ooooo`;o
0000>?ooool000Oooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000Wo<S8bomgMgOoo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo0;3ooooo00?o0000oooooooo
ool0@?ooool4o`000003ooooool0003o000003_ooooo0009ooooo`03o`000?oooooooooo00Kooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool0?_ooool2o`000003ooooool0003o0000043ooooo0004o`0000Gooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool3o`00
0:kooooo00?o0000ooooooooool0>Oooool2o`000004ooooool0003o0000ooooo`;o0000@oooool0
00Wooooo00?o0000ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool0=oooool2o`000004oooo
ool0003o0000ooooo`;o0000A_ooool000Wooooo00?o0000ooooooooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`0dooooo`;o000000?oooooo`000?l00000C?ooool000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo0:cooooo00?o0000ooooooooool0<_ooool2o`000003ooooool0003o000004oo
oooo0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo037ooooo1?l0001B
ooooo`001oooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo03;ooooo0_l0001Dooooo`00<?oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02oooooo0_l0001Gooooo`00<?ooool2
o`000:[ooooo00?o0000ooooooooool0;Oooool2o`000003ooooool0003o000005Oooooo000`oooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0:oooool2o`000003ooooool0003o0000
05[ooooo000`ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool0:Oooool2o`000003
ooooool0003o000005gooooo000`ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
9oooool2o`000003ooooool0003o0000063ooooo000`ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool0:?ooool2o`0006?ooooo000`ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool09_ooool2o`0006Kooooo000`ooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool09Oooool4o`0006Kooooo000`ooooo`;o0000Xoooool00ol0003oooooooooo`0Sooooo`;o
000000?oooooo`000?l00000J?ooool0033ooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`0Tooooo`;o0000Joooool0033ooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`0Qooooo`;o0000K_ooool0033ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0O
ooooo`;o000000?oooooo`000?l00000K_ooool0033ooooo00?o0000ooooooooool0Woooool00ol0
003oooooooooo`0Pooooo`;o0000LOooool0033ooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0Nooooo`;o0000M?ooool0033ooooo00?o0000ooooooooool0WOooool00ol0003ooooo
ooooo`0Looooo`;o000000?oooooo`000?l00000M?ooool0033ooooo0_l0002Mooooo`03o`000?oo
oooooooo01gooooo0_l0001gooooo`00<?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooo
oooo01_ooooo0_l0001jooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
01[ooooo1?l0001jooooo`00<?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo01_o
oooo0_l0001looooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Wooooo
0_l0001oooooo`00<?ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01Oooooo0_l0
00000ooooooo0000o`00001oooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo
oooo01Sooooo0_l00022ooooo`00<?ooool2o`0009Kooooo00?o0000ooooooooool05_ooool2o`00
08Gooooo000`ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool05oooool2o`0008Go
oooo000`ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool05Oooool2o`0008Sooooo
000`ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool04oooool2o`000003ooooool0
003o000008Sooooo0007ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0TOooool00ol0003ooooooooo
o`0Dooooo`;o0000Roooool000Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`0Booooo`;o0000S_ooool000Co00001Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`2?ooooo`03o`000?oooooooooo01?ooooo0_l0002>ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool3
o`0008gooooo0_l0000Cooooo`;o0000TOooool000Wooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`0Aooooo`Co0000TOooool000Wooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`0Booooo`;o0000Toooool000Wooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0@ooooo`;o0000U_ooool000Oo
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Aooooo`;o0000
U_ooool0033ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0?ooooo`;o0000VOoo
ool0033ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0@ooooo`;o0000VOooool0
033ooooo0_l00027ooooo`03o`000?oooooooooo00kooooo0_l0002Looooo`00<?ooool00ol0003o
ooooooooo`24ooooo`;o00003_ooool2o`000003ooooool0003o000009cooooo000`ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool03_ooool2o`0009oooooo000`ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool03?ooool2o`000:;ooooo000`ooooo`03o`000?oooooo
oooo087ooooo00?o0000ooooooooool03Oooool2o`000:;ooooo000`ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool02oooool2o`000:Gooooo000`ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool03?ooool2o`000:Gooooo000`ooooo`;o0000Ooooool00ol0003ooooo
ooooo`0;ooooo`;o0000Yoooool0033ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`09ooooo`;o000000?oooooo`000?l00000Yoooool0033ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`0:ooooo`;o0000Z_ooool0033ooooo00?o0000ooooooooool0N_ooool2o`00
00[ooooo0_l0002]ooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00[o
oooo0_l0002]ooooo`00<?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Sooooo
0_l0002`ooooo`00<?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Wooooo0_l0
002`ooooo`00<?ooool2o`0007Kooooo0_l00009ooooo`;o0000/oooool0033ooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?l00000/oooool0033o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`;o0000]_ooool0033ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`05ooooo`;o0000^Oooool0033ooooo00?o
0000ooooooooool0L?ooool2o`0000Sooooo0_l0002iooooo`00<?ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Kooooo0_l0002kooooo`00<?ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Oooooo0_l0002kooooo`00<?ooool2o`0006gooooo0_l00007ooooo`;o
0000__ooool0033ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`04ooooo`;o0000
00?oooooo`000?l00000__ooool0033ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`05ooooo`;o0000`Oooool0033ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`03
ooooo`;o0000a?ooool000oooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo06Oooooo0_l00006ooooo`;o0000a?ooool001;ooooo
00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo06Gooooo
0_l00005ooooo`;o0000aoooool000Kooooo1_l00007ooooo`04o`000?oooooooooooa0@40?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@
413oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00_ooool2o`00
0003ooooool0003o00000<Oooooo000Booooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo0ol0001Rooooo`;o00001Oooool2o`000<[ooooo000?ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1Poooo
o`;o00001?ooool2o`000<gooooo000?ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`02ooooo`Co0000cOoo
ool000oooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`1Mooooo`;o00001Oooool2o`000<oooooo000?ooooo`Co00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;ooooo0_l0003B
ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00001Oooool2o`000=;ooooo000`ooooo`;o
0000F_ooool00ol0003oooooooooo`02ooooo`;o0000eOooool0033ooooo00?o0000ooooooooool0
Eoooool2o`0000;ooooo0_l000000ooooooo0000o`00003Eooooo`00<?ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo00;ooooo0_l0003Hooooo`00<?ooool00ol0003oooooooooo`1D
ooooo`;o00000_ooool2o`000=_ooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l000001?oo
oooo0000o`000?ooool2o`000=_ooooo000`ooooo`03o`000?oooooooooo053ooooo1?l000000ooo
oooo0000o`00003Nooooo`00<?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00;o
0000hOooool0033ooooo0_l0001>ooooo`;o000000?oooooo`000?l00000hoooool0033ooooo00?o
0000ooooooooool0Boooool4o`000003ooooool0003o00000>?ooooo000`ooooo`03o`000?oooooo
oooo04Wooooo0ol000000ooooooo0000o`00003Vooooo`00<?ooool00ol0003oooooooooo`17oooo
o`;o000000?oooooo`000?l00000jOooool0033ooooo00?o0000ooooooooool0AOooool4o`000>co
oooo000`ooooo`03o`000?oooooooooo04?ooooo0ol000000ooooooo0000o`00003/ooooo`00<?oo
ool00ol0003oooooooooo`11ooooo`;o000000?oooooo`000?l00000koooool0033ooooo0_l0000o
ooooo`Go0000l_ooool0033ooooo00?o0000ooooooooool0;oooool5o`0000?ooooo00Cok^k^oc8b
<_l0003o<S8b1Ol0000[ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/
ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^013ooooo000`ooooo`03o`000?oooooooooo02oooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`03ogMgMonHV9Sooooo00?o0000;oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0;?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool01OmgMgOoV9RHoooooonH
V9SoMgMg02_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`00<?ooool00ol0003oooooooooo`0`ooooo`03oiRH
V?lQ8B7ok^k^00Cooooo1?l000000ol@413oooooooooo`0[ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@02cooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?oooooooooo
ooooool@4100;?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooo
oa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41004?ooool0033ooooo00?o0000ooooooooool0<Oooool00onHV9So
8B4Qonk^kP04o`000004ooooool0003o0000o`0002gooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000002cooooo00Go0000oiRHV?ooooooV9RHob4Q8@03ooooo`05o`00
0?ooooooooooooooool00000;?ooool01Olb<S;oV9RHoooooonHV9So<S8b00?ooooo00Go0000oooo
ooooooooooooo`00000[ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000004?ooool0033ooooo00?o0000ooooooooool0<Ooo
ool4o`000003ooooool0003o000000?ooooo00?o0000ooooooooool0:oooool01?oMgMgoEEEEoooo
ool00004ooooo`05o`000?ooooooooooooooool00000;?ooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`00000/ooooo`05olc<c?l0003o0000o`000?o<c<`00ooo
ool01Ol0003ooooooooooooooooo000002_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000@ooooo`00<?ooool00ol0003o
ooooooooo`0]ooooo`Go000000?oooooo`000?l000000_ooool01Ol@413ooooooooooooooooo410@
02kooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@02cooooo00?oEEEE
ohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`05oa0@4?ooooooooooooooool@4100:oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@013ooooo000`oooo
o`;o0000:oooool8o`000003oiRHV?l@413ooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0^
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`03omgMgOl@
413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`05o`000?nj^[[ooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`00<?ooool0
0ol0003oooooooooo`0Wooooo`Go00000oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0_ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0]ooooo`04olc<c?m4A4Co0000oa0@40?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Wooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0@ooooo`00<?ooool00ol0003oooooooooo`0Tooooo`Go0000ooooool=ooooo`00
<?ooool00ol0003oooooooooo`0Oooooo`Go000000?oooooo`000?l00000ooooool?ooooo`00<?oo
ool00ol0003oooooooooo`0Iooooo`So000000?oooooo`000?l00000ooooool8ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00Oooool0033ooooo00?o0000ooooooooool04ooo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?l00000ooooool?ooooo`05o`000?oo
ooooooooooooool000001?ooool0033ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0
003o000000_o0000oooooolEooooo`05o`000?ooooooooooooooool000001?ooool002Woooooool0
000/o`0000_ooooo00Go0000ooooooooooooooooo`000004ooooo`00<?ooool01Ol0003oooooo`00
0?l0003ooooo00;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00kooooo00Go0000ohN7QoooooooZJVYo`000004ooooo`00<?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Oooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo0?oooooo=_oo
ool0033ooooo00?o0000ooooooooool0oooooolfooooo`00<?ooool00ol0003oooooooooo`3ooooo
ocKooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo000aoooo
o`04o`000?ooooooooooo`000?oooooo=?ooool0037ooooo00Co0000oooooooooooo0000oooooold
ooooo`00:_ooool01_l0003oQhN7oooooooooooogMgMoc8b<P;o00000_ooool00ol0003ooooooooo
o`3ooooooc;ooooo000Zooooo`07onk^k_lb<S;oV9RHoooooom4A4CoMgMgooooo`03o`000?oooooo
=Oooool002_ooooo00Gok^k^ob4Q8OnHV9So0000omgMg@3oooooocWooooo000/ooooo`03olc<c?l@
413o00000?oooooo>_ooool002gooooo00?oQhN7o`000?ooool0ooooooliooooo`00;Oooool00oo^
k^ko0000ooooo`3oooooocWooooo000]ooooo`03ohN7QomEEEGooooo0?oooooo>Oooool002cooooo
00?o0000odA4A?o^k^h0ooooooljooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-17.0273, -27004.8, \
0.436874, 180.511}}]
}, Open  ]],

Cell["\<\
The numerical eigenvalues track the exact eigenvalues reasonably \
well  for the lowest-order modes, but fail for the high-order modes. This is \
to be expected, given that the high-order modes vary rapidly and are not well \
approximated by our finite-difference equations.\
\>", "Text"],

Cell["\<\
\tBelow,  we take a closer look at the error in the eigenvalues, \
examining the difference between the  numerical and the exact eigenvalues : \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(error\  = 
      Table[\[Lambda]1[\([n]\)]\  + \ \((2  n - 1)\)^2, {n, 1, 
          10}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.136"],

Cell[BoxData[
    \({0.000020768670204951434`, 0.0016821506710797962`, 
      0.01297783255893492`, 0.049845702506665646`, 0.13617273176654976`, 
      0.3037711636041962`, 0.5923468021651104`, 1.0494594328582139`, 
      1.7304754137457508`, 2.698512485137485`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe error in the lowest eigenvalues is quite small.  By varying ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " (increasing or decreasing it by a factor of 2, say), one can easily \
convince oneself that the error in the eigenvalues scales as ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  ", as expected from the second-order accuracy of the differenced \
derivatives. "
}], "Text"],

Cell[TextData[{
  "\tWe now determine the first few eigenfunctions associated with these \
eigenvalues, and compare them with the exact eigenfunctions. First we \
evaluate the eigenvectors of ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Psi]vec = Eigenvectors[lmat // N];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.137"],

Cell[TextData[{
  "These eigenvectors only involve the interior points in the domain. To \
properly define the eigenfunctions that are based on these eigenvectors, we \
need to include boundary points. One way to do so is to define a function ",
  StyleBox["\[Psi]val",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that equals the eigenvectors at the interior points, but also is defined \
at the boundary points:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 100;\)\), "\n", 
    \(\[Psi]val[n_, j_]\  := \ \[Psi]vec[\([n, j]\)]\  /; \ 
        1 \[LessEqual] \ j \[LessEqual] \ M - 1\), "\n", 
    \(\(\[Psi]val[n_, 0]\  = \ 0;\)\), "\n", 
    \(\(\[Psi]val[n_, M]\  := \ \[Psi]vec[\([n, M - 1]\)];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.138"],

Cell[TextData[{
  "We can then interpolate these discrete eigenvectors in order to construct \
approximate eigenfunctions defined on ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, b]\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][n_]\  := \ \(\[Psi][n]\  = \ 
        Interpolation[
          Table[{j\ \ \[CapitalDelta]x, \[Psi]val[M - n, j]}, {j, 0, 
              M}]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.139"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.140",
    ButtonData:>"Cell 6.140",
    ButtonStyle->"Hyperlink"],
  ", we plot the eigenfunctions and compare them with the exact \
eigenfunctions, ",
  Cell[BoxData[
      \(TraditionalForm\`sin[\((2  n - 1)\)\ x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Table[
        Plot[{\(\[Psi][n]\)[x]/\(\[Psi][n]\)[
                b], \((\(-1\))\)^\((n - 1)\)\ Sin[\((2  n - 1)\)\ x\ ]}, {x, 
            0, Pi/2}, AxesLabel \[Rule] {"\<x\>", "\<\[Psi]\>"}, 
          PlotLabel \[Rule] \ "\<n= \>" <> ToString[n], 
          PlotStyle \[Rule] {{Red, Dashing[{0.05, 0.05}]}, Blue}], {n, 1, 30, 
          6}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.140"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.0147151 0.588604 [
[.17539 .00222 -12 -9 ]
[.17539 .00222 12 0 ]
[.32696 .00222 -9 -9 ]
[.32696 .00222 9 0 ]
[.47854 .00222 -12 -9 ]
[.47854 .00222 12 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -12 -9 ]
[.78169 .00222 12 0 ]
[.93327 .00222 -9 -9 ]
[.93327 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(0.25)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(0.5)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(0.75)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(1)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(1.25)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(1.5)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .01472 m
.06244 .0522 L
.10458 .0929 L
.14415 .13078 L
.18221 .16675 L
.22272 .20437 L
.26171 .23979 L
.30316 .27641 L
.34309 .31054 L
.3815 .34217 L
.42237 .37437 L
.46172 .40383 L
.49955 .43061 L
.53984 .45735 L
.57861 .48124 L
.61984 .50455 L
.65954 .52486 L
.69774 .54233 L
.73838 .55862 L
.77751 .572 L
.81909 .58367 L
.85916 .59239 L
.87754 .59554 L
.89771 .59839 L
.91765 .60058 L
.92854 .6015 L
.93871 .60219 L
.94354 .60247 L
.94878 .60272 L
.95341 .6029 L
.95832 .60306 L
.96273 .60317 L
.96524 .60322 L
.9676 .60326 L
.96976 .60329 L
.97173 .6033 L
.97277 .60331 L
.97391 .60331 L
.97509 .60332 L
.97619 .60332 L
s
0 0 1 r
[ ] 0 setdash
.02381 .01472 m
.06244 .0522 L
.10458 .0929 L
.14415 .13078 L
.18221 .16675 L
.22272 .20437 L
.26171 .23979 L
.30316 .27641 L
.34309 .31054 L
.3815 .34217 L
.42237 .37437 L
.46172 .40383 L
.49955 .43061 L
.53984 .45735 L
.57861 .48124 L
.61984 .50455 L
.65954 .52486 L
.69774 .54233 L
.73838 .55862 L
.77751 .572 L
.81909 .58367 L
.85916 .59239 L
.87754 .59554 L
.89771 .59839 L
.91765 .60058 L
.92854 .6015 L
.93871 .60219 L
.94354 .60247 L
.94878 .60272 L
.95341 .6029 L
.95832 .60306 L
.96273 .60317 L
.96524 .60322 L
.9676 .60326 L
.96976 .60329 L
.97173 .6033 L
.97277 .60331 L
.97391 .60331 L
.97509 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00@Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Wooooo`00@Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02Kooooo0011ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool09Oooool0047ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Vooooo`00@Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Wooooo`00@Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0011ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:Oooool0047ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000:?ooool00?ooooooJOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooooc?ooooo0_l00002oooo
o`;o00003?ooool0027ooooo00?o0000ooooooooool0oooooolcooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM3?ooool0027ooooo00?o0000ooooooooool0ooooooldooooo`04omgMgOl0003o410@
olc<c0gooooo000Jooooo`Oo000000?o003oo`000?l00000ool0000Yo`0000_ooooo00Cok^k^ob4Q
8Ol@413ok^k^3Oooool0027ooooo00?o0000o`00ooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00Co8B4QogMgMomgMgOo<S8b3Oooool0027ooooo00?o0000oooo
ool00?l0;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool07Oooool2o`0000;ooooo0_l0000<ooooo`008Oooool01?l0003oooooooooool00?oooooo
odCooooo000Qooooo`05o`000?ooooooooooooooool00?l0oooooom3ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo0?oooooo@?ooool0027ooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`3oooooocoooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0oooooolnooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo0?oooooo?Oooool0027ooooo0ol00006ooooo`03o`00oooooooooooo0?oooooo??ooool0027o
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`3ooooooc_ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool0ooooooljooooo`008Oooool00ol0003ooooooooo
o`09ooooo`;o003oooooooljooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooo
oooo0?oooooo=oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`3ooooo
ocKooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0ooooooleooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo0?oooooo=?ooool0027ooooo00?o
0000ooooooooool03oooool00ol00?ooooooooooo`3ooooooc?ooooo000Qooooo`?o00004?ooool0
0ol00?ooooooooooo`3ooooooc;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o003ooooo
ooooool0oooooolaooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo0?oo
oooo<?ooool0027ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`3ooooooboooooo
000Qooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool0ooooool^ooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo0?oooooo;Oooool0027ooooo00?o0000oooo
ooooool05_ooool00ol00?ooooooooooo`3oooooobcooooo000Qooooo`03o`000?oooooooooo01Oo
oooo00?o003oooooooooool0ooooool[ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`00
oooooooooooo0?oooooo:_ooool0027ooooo0ol0000Iooooo`03o`00oooooooooooo0?oooooo:Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`3oooooobSooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o003oooooooooool0oooooolWooooo`008Oooool00ol0003o
ooooooooo`0Looooo`03o`00oooooooooooo0?oooooo9_ooool0027ooooo00?o0000ooooooooool0
7Oooool00ol00?ooooooooooo`3oooooobGooooo000Qooooo`03o`000?oooooooooo01kooooo00?o
003oooooooooool0oooooolTooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooo
oooo0?oooooo8oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Gooooo00?o0000ooooooooool08?ooool00ol00?ooooooooooo`3oooooob;ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0oooooolQooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002;ooooo0_l0
0?ooooooob7ooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP05ooooo`03o`000?oooooooooo02Cooooo00?o003oooooooooool0oooooolNooooo`001oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooooooo
o`0Uooooo`03o`00oooooooooooo0?oooooo7Oooool000Oooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol00?oooooooooo
o`3ooooooacooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`3ooooooa_ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool0:?ooool2o`00oooooooo6oooool0027ooooo00?o0000ooooooooool0
:Oooool00ooo003o003oooooo`3ooooooaWooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o
003oooooooooool0oooooolGooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`00oooooooo
oooo0?oooooo5_ooool0027ooooo0ol0000]ooooo`03o`00oooooooooooo0?oooooo5Oooool0027o
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`3ooooooaCooooo000Qooooo`03o`00
0?oooooooooo02kooooo00?oo`00o`00ooooool0oooooolDooooo`008Oooool00ol0003ooooooooo
o`0_ooooo`03ool00?l00?oooooo0?oooooo4oooool0027ooooo00?o0000ooooooooool0<?ooool0
0ooo003o003oooooo`3ooooooa;ooooo000Qooooo`03o`000?oooooooooo037ooooo00?oo`00o`00
ooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0booooo`03ool00?l00?oooooo0?oo
oooo4?ooool0027ooooo00?o0000ooooooooool0<oooool00ooo003o003oooooo`3oooooo`oooooo
000Qooooo`03o`000?oooooooooo03Cooooo00?oo`00o`00ooooool0ooooool>ooooo`008Oooool3
o`0003Kooooo00?o003oooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0goooo
o`03o`00oooooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool0>?ooool00ol00?oo
ooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`0jooooo`;o003oooooool9ooooo`008Oooool0
0ol0003oooooooooo`0looooo`03o`00oooooooooooo0?oooooo1_ooool0027ooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oooooooooo03ko
oooo00?o003oooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0oooooo`03o`00
oooooooooooo0?oooooo0oooool0027ooooo0ol00010ooooo`03o`00oooooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooooooo`3oooooo`7ooooo000Qoooo
o`03o`000?oooooooooo04;ooooo00?o003oooooooooool0ooooool0027ooooo00?o0000oooooooo
ool0@oooool00ol00?ooooooooooo`3nooooo`008Oooool00ol0003oooooooooo`14ooooo`03o`00
oooooooooooo0?gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool0o?oo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0A_ooool2o`00oocooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`18ooooo`03o`00oooooooooooo0?Wooooo0007ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Gooooo00?o0000ooooooooool0BOooool00ol00?ooooooooooo`3hooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool3o`0004[ooooo
00?o003oooooooooool0moooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgM
gOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0Boooool00ol00?ooooooooooo`3fooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`1<ooooo`;o003om_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0C_ooool00ol00?ooooooooooo`3cooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003o
ooooooooo`1?ooooo`03o`00oooooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo053ooooo
00?o003oooooooooool0lOooool0027ooooo00?o0000ooooooooool0DOooool00ol00?oooooooooo
o`3`ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo0>oooooo000Qoooo
o`03o`000?oooooooooo05?ooooo0_l00?o_ooooo`008Oooool3o`0005Gooooo00?o003ooooooooo
ool0k?ooool0027ooooo00?o0000ooooooooool0E_ooool00ol00?ooooooooooo`3[ooooo`008Ooo
ool00ol0003oooooooooo`1Fooooo`03ool00?l00?oooooo0>_ooooo000Qooooo`03o`000?oooooo
oooo05Sooooo00?o003oooooooooool0jOooool0027ooooo00?o0000ooooooooool0FOooool2o`00
onWooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00o`00ooooool0ioooool0027ooooo
00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`3Uooooo`008Oooool00ol0003ooooooooo
o`1Mooooo`03o`00oooooooooooo0>Cooooo000Qooooo`03o`000?oooooooooo05kooooo00?o003o
ooooooooool0hoooool0027ooooo0ol0001Oooooo`;o003ohoooool0027ooooo00?o0000oooooooo
ool0H?ooool00ooo003o003oooooo`3Qooooo`008Oooool00ol0003oooooooooo`1Qooooo`03ool0
0?l00?oooooo0>3ooooo000Qooooo`03o`000?oooooooooo06;ooooo00?oo`00o`00ooooool0gooo
ool0027ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`3Mooooo`008Oooool00ol0
003oooooooooo`1Uooooo`03o`00oooooooooooo0=cooooo000Qooooo`03o`000?oooooooooo06Ko
oooo00?o003oooooooooool0foooool0027ooooo00?o0000ooooooooool0Ioooool00ol00?oooooo
ooooo`3Jooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`00oooooooooooo0=Wooooo000Q
ooooo`?o0000JOooool00ol00?ooooooooooo`3Hooooo`008Oooool00ol0003oooooooooo`1Zoooo
o`;o003of?ooool0027ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`3Eooooo`00
8Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo0=Cooooo000Qooooo`03o`000?oo
oooooooo06kooooo0_l00?oDooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`00oooooooo
oooo0=7ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool0d?oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00Gooooo00?o0000ooooooooool0L_ooool00ol00?ooo`00ooooo`3?ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo07?ooooo0_l00?o?ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o0000MOooool00ol00?ooooooooooo`3<oooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005
ooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool0boooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0Moooool2
o`00ol_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007
ooooo`03o`000?oooooooooo07Wooooo00?o003oooooooooool0b?ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0N_oo
ool00ol00?ooooooooooo`37ooooo`008Oooool00ol0003oooooooooo`1kooooo`;o003oaoooool0
027ooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`34ooooo`008Oooool00ol0003o
ooooooooo`1nooooo`03o`00oooooooooooo0<?ooooo000Qooooo`03o`000?oooooooooo07oooooo
0_l00?o3ooooo`008Oooool3o`00087ooooo00?o003oooooooooool0`?ooool0027ooooo00?o0000
ooooooooool0P_ooool00ol00?ooooooooooo`2oooooo`008Oooool00ol0003oooooooooo`23oooo
o`;o003o_oooool0027ooooo00?o0000ooooooooool0QOooool00ol00?ooooooooooo`2looooo`00
8Oooool00ol0003oooooooooo`26ooooo`03o`00oooo003ooooo0;_ooooo000Qooooo`03o`000?oo
oooooooo08Oooooo0_l00?nkooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`00oooooooo
oooo0;Sooooo000Qooooo`03o`000?oooooooooo08[ooooo0_l00?nhooooo`008Oooool00ol0003o
ooooooooo`2<ooooo`03o`00oooooooooooo0;Gooooo000Qooooo`?o0000SOooool00ol00?oooooo
ooooo`2dooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o003o]?ooool0027ooooo00?o0000
ooooooooool0T?ooool00ol00?ooo`00ooooo`2aooooo`008Oooool00ol0003oooooooooo`2Aoooo
o`;o003o/Oooool0027ooooo00?o0000ooooooooool0Toooool2o`00ojoooooo000Qooooo`03o`00
0?oooooooooo09Gooooo00?o003oooooooooool0[?ooool0027ooooo00?o0000ooooooooool0U_oo
ool2o`00ojcooooo000Qooooo`03o`000?oooooooooo09Sooooo0_l00?nZooooo`008Oooool00ol0
003oooooooooo`2Jooooo`03o`00oooooooooooo0:Oooooo000Qooooo`?o0000Voooool2o`00ojOo
oooo000Qooooo`03o`000?oooooooooo09gooooo00?o003oooooooooool0Y?ooool0027ooooo00?o
0000ooooooooool0W_ooool2o`00ojCooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00
o`00ool00?l0X_ooool0027ooooo00?o0000ooooooooool0XOooool00ooo003o003oooooo`2Poooo
o`008Oooool00ol0003oooooooooo`2Sooooo`;o003oWoooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool0Y?ooool00ooo003o003oooooo`2Mooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`2V
ooooo`;o003oW?ooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`2Xooooo`;o003oV_ooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000:[ooooo
0_l00?nHooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c005ooooo`03o`000?oooooooooo0:_ooooo00?oo`00o`00ool00?l0U_ooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0
003oooooooooo`2]ooooo`03ool00?l00?oooooo09Cooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0[oooool2
o`00oi?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Gooooo00?o0000ooooooooool0/Oooool2o`00oi7ooooo000Qooooo`03o`000?oooooo
oooo0;?ooooo0_l00?n?ooooo`008Oooool00ol0003oooooooooo`2eooooo`;o003oSOooool0027o
oooo00?o0000ooooooooool0]oooool00ol00?ooooooooooo`2:ooooo`008Oooool00ol0003ooooo
ooooo`2hooooo`;o003oR_ooool0027ooooo0ol0002jooooo`;o003oR?ooool0027ooooo00?o0000
ooooooooool0_?ooool00ol00?ooo`00ooooo`25ooooo`008Oooool00ol0003oooooooooo`2moooo
o`;o003oQOooool0027ooooo00?o0000ooooooooool0_oooool2o`00oh?ooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0ol00?n0ooooo`008Oooool00ol0003oooooooooo`33ooooo`03ool00?l0
0?oo003o07kooooo000Qooooo`03o`000?oooooooooo0<Kooooo0_l00?mlooooo`008Oooool00ol0
003oooooooooo`38ooooo`?o003oNOooool0027ooooo0ol0003;ooooo`;o003oMoooool0027ooooo
00?o0000ooooooooool0cOooool3o`00ogCooooo000Qooooo`03o`000?oooooooooo0=3ooooo0_l0
0?mbooooo`008Oooool00ol0003oooooooooo`3Booooo`;o003oL?ooool0027ooooo00?o0000oooo
ooooool0e?ooool3o`00ofgooooo000Qooooo`03o`000?oooooooooo0=Oooooo0ol00?mZooooo`00
8Oooool00ol0003oooooooooo`3Jooooo`?o003oIoooool0027ooooo00?o0000ooooooooool0gOoo
ool3o`00ofCooooo000Qooooo`03o`000?oooooooooo0>3ooooo0ol00?mQooooo`008Oooool3o`00
0>?ooooo0ol00?mNooooo`008Oooool00ol0003oooooooooo`3Vooooo`Go003oFOooool0027ooooo
00?o0000ooooooooool0joooool4o`00oeGooooo000Qooooo`03o`000?oooooooooo0>oooooo1?l0
0?mAooooo`008Oooool00ol0003oooooooooo`3cooooo`Co003oCOooool0027ooooo00?o0000oooo
ooooool0m_ooool00ooo003o003oo`00o`02o`00odWooooo000Qooooo`03o`000?oooooooooo0?_o
oooo1Ol00?m4ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool1ooooo`Ko003o?_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooo`Oooooo1_l00?lhooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000ooooool=
oooooaCo003o9?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo1?l000000ol@413o
ooooooooo`2Uooooo`00YOooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03
o`000?oooooooooo0:Oooooo000Pooooo`03okZj^_lb<S;ooooo08;ooooo00Go0000oooooooooooo
ooooo`00000Dooooo`03o`000?oooooooooo0:Oooooo000Qooooo`03o`000?oooooooooo087ooooo
00Go0000ooooooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`2Wooooo`00
7oooool01OnHV9So410@o`000?l0003oZJVY087ooooo00Go0000ohN7QoooooooZJVYo`00000Doooo
o`03o`000?oooooooooo0:Oooooo000Oooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[ZjOoooool0
0ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01;ooooo00?o0000ooooooooool0Yoooool0
01oooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@412Iooooo`03o`000?oooooooooo0:Oooooo000O
ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEEEOmVIVKo00000:Wooooo
000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo000Oooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_ooool00omVIVKoQhN7
ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.184028, -0.0840035, \
0.00677079, 0.00697441}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309014 0.294305 [
[.17539 .29651 -12 -9 ]
[.17539 .29651 12 0 ]
[.32696 .29651 -9 -9 ]
[.32696 .29651 9 0 ]
[.47854 .29651 -12 -9 ]
[.47854 .29651 12 0 ]
[.63011 .29651 -3 -9 ]
[.63011 .29651 3 0 ]
[.78169 .29651 -12 -9 ]
[.78169 .29651 12 0 ]
[.93327 .29651 -9 -9 ]
[.93327 .29651 9 0 ]
[1.025 .30901 0 -6 ]
[1.025 .30901 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30901 m
.17539 .31526 L
s
[(0.25)] .17539 .29651 0 1 Mshowa
.32696 .30901 m
.32696 .31526 L
s
[(0.5)] .32696 .29651 0 1 Mshowa
.47854 .30901 m
.47854 .31526 L
s
[(0.75)] .47854 .29651 0 1 Mshowa
.63011 .30901 m
.63011 .31526 L
s
[(1)] .63011 .29651 0 1 Mshowa
.78169 .30901 m
.78169 .31526 L
s
[(1.25)] .78169 .29651 0 1 Mshowa
.93327 .30901 m
.93327 .31526 L
s
[(1.5)] .93327 .29651 0 1 Mshowa
.125 Mabswid
.05412 .30901 m
.05412 .31276 L
s
.08444 .30901 m
.08444 .31276 L
s
.11476 .30901 m
.11476 .31276 L
s
.14507 .30901 m
.14507 .31276 L
s
.2057 .30901 m
.2057 .31276 L
s
.23602 .30901 m
.23602 .31276 L
s
.26633 .30901 m
.26633 .31276 L
s
.29665 .30901 m
.29665 .31276 L
s
.35728 .30901 m
.35728 .31276 L
s
.38759 .30901 m
.38759 .31276 L
s
.41791 .30901 m
.41791 .31276 L
s
.44822 .30901 m
.44822 .31276 L
s
.50885 .30901 m
.50885 .31276 L
s
.53917 .30901 m
.53917 .31276 L
s
.56948 .30901 m
.56948 .31276 L
s
.5998 .30901 m
.5998 .31276 L
s
.66043 .30901 m
.66043 .31276 L
s
.69074 .30901 m
.69074 .31276 L
s
.72106 .30901 m
.72106 .31276 L
s
.75138 .30901 m
.75138 .31276 L
s
.81201 .30901 m
.81201 .31276 L
s
.84232 .30901 m
.84232 .31276 L
s
.87264 .30901 m
.87264 .31276 L
s
.90295 .30901 m
.90295 .31276 L
s
.96358 .30901 m
.96358 .31276 L
s
.9939 .30901 m
.9939 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
gsave
1.025 .30901 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33844 m
.02756 .33844 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30901 m
.04262 .4245 L
.06244 .52586 L
.06747 .546 L
.07286 .56451 L
.07751 .57778 L
.08255 .58915 L
.08564 .59449 L
.08848 .59832 L
.0912 .60097 L
.09258 .60193 L
.09335 .60235 L
.09409 .60269 L
.09474 .60292 L
.09545 .60311 L
.0967 .60328 L
.0974 .60328 L
.09815 .60321 L
.09886 .60308 L
.0995 .60289 L
.10076 .60238 L
.10147 .60199 L
.10212 .60157 L
.10458 .59948 L
.10704 .59659 L
.10928 .59327 L
.11432 .5834 L
.11898 .57141 L
.1234 .55761 L
.14407 .4661 L
.1824 .23372 L
.20178 .12527 L
.21282 .0765 L
.21787 .05838 L
.22318 .04247 L
.22789 .03126 L
.23038 .02647 L
.23304 .02224 L
.23549 .01916 L
.23772 .01707 L
.23879 .0163 L
.23996 .01563 L
.24106 .01517 L
.24208 .01489 L
.24325 .01474 L
.24451 .01479 L
.2457 .01504 L
.24679 .01543 L
.24806 .01609 L
.24945 .01706 L
Mistroke
.25197 .01947 L
.2546 .0229 L
.25741 .02756 L
.26245 .03846 L
.26782 .05357 L
.27276 .07043 L
.2839 .11797 L
.30408 .22944 L
.32454 .35733 L
.34362 .4688 L
.35306 .5152 L
.36198 .55138 L
.36692 .56765 L
.37227 .58203 L
.37464 .58724 L
.37714 .592 L
.37929 .59542 L
.38164 .59845 L
.38403 .60079 L
.38534 .60175 L
.38655 .60244 L
.38769 .6029 L
.38872 .60316 L
.38991 .60329 L
.39104 .60323 L
.39227 .60297 L
.39357 .60248 L
.39468 .60188 L
.3959 .60103 L
.39861 .59841 L
.40115 .59508 L
.40577 .58687 L
.40998 .57699 L
.41945 .54697 L
.42934 .50516 L
.43851 .45856 L
.45926 .33492 L
.47949 .20933 L
.4894 .15318 L
.49849 .10776 L
.50715 .07158 L
.51664 .04137 L
.52157 .02993 L
.52617 .02211 L
.52871 .01897 L
.53102 .01685 L
.5323 .016 L
.53298 .01564 L
.53369 .01532 L
.535 .01492 L
Mistroke
.53621 .01475 L
.53742 .01478 L
.53874 .01504 L
.53998 .01549 L
.54113 .0161 L
.54228 .01689 L
.54331 .01775 L
.54563 .02021 L
.54814 .02365 L
.55085 .0283 L
.55576 .03915 L
.5653 .0686 L
.57407 .10456 L
.61357 .33224 L
.63345 .45143 L
.65157 .53835 L
.65637 .5561 L
.66159 .57241 L
.66611 .58387 L
.67109 .5935 L
.67381 .59741 L
.67636 .60018 L
.67777 .60133 L
.67906 .60215 L
.67979 .60252 L
.68047 .6028 L
.68118 .60303 L
.68196 .60319 L
.68327 .60329 L
.68451 .60317 L
.68562 .60288 L
.68682 .60238 L
.68813 .60161 L
.68952 .60055 L
.69201 .598 L
.69454 .59456 L
.69695 .59051 L
.70146 .58091 L
.70631 .56774 L
.7116 .55022 L
.72992 .46733 L
.77063 .22064 L
.78948 .11738 L
.80009 .07195 L
.80984 .04095 L
.81482 .02953 L
.81768 .0244 L
.82029 .02067 L
.82304 .01771 L
.82456 .01651 L
Mistroke
.82525 .01606 L
.82599 .01565 L
.82662 .01536 L
.82731 .01511 L
.82854 .01482 L
.82923 .01475 L
.82997 .01474 L
.83066 .01481 L
.8313 .01492 L
.83255 .0153 L
.83324 .0156 L
.83387 .01593 L
.83625 .01766 L
.83759 .01896 L
.83903 .02064 L
.84165 .0244 L
.84678 .0343 L
.85149 .04637 L
.86122 .07955 L
.87031 .11955 L
.89097 .23435 L
.92986 .46966 L
.94003 .51918 L
.94539 .54143 L
.95109 .5617 L
.95606 .57629 L
.96154 .5889 L
.96394 .5932 L
.96653 .59699 L
.96897 .59977 L
.97121 .60162 L
.97244 .60235 L
.97359 .60285 L
.97485 .60319 L
.97555 .60329 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30901 m
.04262 .42451 L
.06244 .52587 L
.06747 .54603 L
.07286 .56454 L
.07751 .5778 L
.08255 .58918 L
.08564 .59452 L
.08848 .59834 L
.0912 .60099 L
.09258 .60195 L
.09335 .60238 L
.09409 .60272 L
.09474 .60295 L
.09545 .60314 L
.0967 .60331 L
.0974 .60331 L
.09815 .60324 L
.09886 .6031 L
.0995 .60292 L
.10076 .6024 L
.10147 .60201 L
.10212 .6016 L
.10458 .59951 L
.10704 .59662 L
.10928 .59329 L
.11432 .58343 L
.11898 .57143 L
.1234 .55764 L
.14407 .46612 L
.1824 .23371 L
.20178 .12525 L
.21282 .07648 L
.21787 .05835 L
.22318 .04245 L
.22789 .03123 L
.23038 .02644 L
.23304 .02221 L
.23549 .01914 L
.23772 .01704 L
.23879 .01626 L
.23996 .0156 L
.24106 .01514 L
.24208 .01486 L
.24325 .01472 L
.24451 .01477 L
.2457 .01501 L
.24679 .0154 L
.24806 .01606 L
.24945 .01703 L
Mistroke
.25197 .01945 L
.2546 .02288 L
.25741 .02753 L
.26245 .03844 L
.26782 .05354 L
.27276 .07041 L
.2839 .11795 L
.30408 .22943 L
.32454 .35733 L
.34362 .46881 L
.35306 .51522 L
.36198 .5514 L
.36692 .56767 L
.37227 .58206 L
.37464 .58727 L
.37714 .59202 L
.37929 .59544 L
.38164 .59848 L
.38403 .60083 L
.38534 .60178 L
.38655 .60246 L
.38769 .60292 L
.38872 .60319 L
.38991 .60332 L
.39104 .60326 L
.39227 .603 L
.39357 .60251 L
.39468 .60191 L
.3959 .60106 L
.39861 .59844 L
.40115 .59511 L
.40577 .58689 L
.40998 .57701 L
.41945 .54699 L
.42934 .50518 L
.43851 .45858 L
.45926 .33492 L
.47949 .20932 L
.4894 .15316 L
.49849 .10774 L
.50715 .07155 L
.51664 .04134 L
.52157 .02991 L
.52617 .02208 L
.52871 .01894 L
.53102 .01683 L
.5323 .01598 L
.53298 .01561 L
.53369 .01529 L
.535 .01489 L
Mistroke
.53621 .01472 L
.53742 .01475 L
.53874 .01501 L
.53998 .01547 L
.54113 .01608 L
.54228 .01686 L
.54331 .01772 L
.54563 .02017 L
.54814 .02362 L
.55085 .02828 L
.55576 .03912 L
.5653 .06858 L
.57407 .10454 L
.61357 .33224 L
.63345 .45145 L
.65157 .53837 L
.65637 .55612 L
.66159 .57244 L
.66611 .58389 L
.67109 .59353 L
.67381 .59744 L
.67636 .60021 L
.67777 .60136 L
.67906 .60219 L
.67979 .60255 L
.68047 .60283 L
.68118 .60306 L
.68196 .60322 L
.68327 .60332 L
.68451 .60319 L
.68562 .60291 L
.68682 .60241 L
.68813 .60164 L
.68952 .60058 L
.69201 .59802 L
.69454 .59458 L
.69695 .59053 L
.70146 .58094 L
.70631 .56777 L
.7116 .55024 L
.72992 .46735 L
.77063 .22064 L
.78948 .11737 L
.80009 .07193 L
.80984 .04092 L
.81482 .0295 L
.81768 .02438 L
.82029 .02065 L
.82304 .01768 L
.82456 .01648 L
Mistroke
.82525 .01603 L
.82599 .01563 L
.82662 .01534 L
.82731 .01508 L
.82854 .0148 L
.82923 .01472 L
.82997 .01472 L
.83066 .01478 L
.8313 .01489 L
.83255 .01527 L
.83324 .01557 L
.83387 .0159 L
.83625 .01763 L
.83759 .01894 L
.83903 .02062 L
.84165 .02437 L
.84678 .03428 L
.85149 .04634 L
.86122 .07952 L
.87031 .11953 L
.89097 .23434 L
.92986 .46967 L
.94003 .5192 L
.94539 .54145 L
.95109 .56172 L
.95606 .57632 L
.96154 .58892 L
.96394 .59323 L
.96653 .59703 L
.96897 .5998 L
.97121 .60164 L
.97244 .60237 L
.97359 .60286 L
.97485 .6032 L
.97555 .60329 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol00011ooooo`?o003oF?ooool4o`00oeSooooo
0ol00?m9ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo0ol0
0?l2ooooo`03o`00oooooooooooo05Cooooo0_l00?l2ooooo`;o003oE_ooool01Ol00?oooooooooo
oooooooo003o04Sooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0AOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0D_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo057ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo053o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0@oooool0027ooooo00?o0000ooooooooool0?Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`1?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0@oooool0027ooooo00?o
0000ooooooooool0?Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04gooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool0@oooool0027ooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`1=
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0@_ooool0027ooooo0ol0000loooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo04gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`12oooo
o`008Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0Boooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04cooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0kooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo04_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`11ooooo`008Ooo
ool00ol0003oooooooooo`0kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0BOoo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04_ooooo00?o003oooooooooool02ooo
ool00ol00?ooo`00ooooo`11ooooo`008Oooool00ol0003oooooooooo`0kooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo04[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`10ooooo`008Oooool00ol0
003oooooooooo`0jooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`10ooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`00oooooooooooo00go
oooo00?oo`00o`00ooooool0B?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`10ooooo`008Oooool00ol0003ooooo
ooooo`0iooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0Aoooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool0A_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0oooooo`008Oooool3o`0003Wooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00oooooo00?o003o
ool00?ooool0Aoooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo03oooooo000Qoooo
o`03o`000?oooooooooo03Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`16oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo03kooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool0A_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo03kooooo000Qooooo`03o`00
0?oooooooooo03Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`14ooooo`03ool0
0?l00?oooooo017ooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo03kooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0AOoo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo03kooooo000Qooooo`03o`000?oooooo
oooo03Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo03gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0@oooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo03gooooo000Qooooo`03o`000?oooooooooo03Oo
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo03go
oooo000Qooooo`03o`000?oooooooooo03Oooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`13ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo03gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o
003oooooooooool04oooool00ooo003o003oooooo`12ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool0@_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03cooooo000Q
ooooo`?o0000=_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo047ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool0??ooool0027ooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo047ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`11oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0??ooool0027ooooo00?o0000oooooooo
ool0=_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo047ooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool0??ooool0027ooooo00?o0000ooooooooool0=_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo043ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`10ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool0??ooool0027ooooo00?o0000ooooooooool0=_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool05_oo
ool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool0??oo
ool0027ooooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo03oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool0>oooool0027ooooo00?o0000ooooooooool0=Oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0oooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0>oooool0027o
oooo00?o0000ooooooooool0=Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo03oo
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool0>oooool0027ooooo00?o0000ooooooooool0=Oooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool05_ooool00ol00?ooo`00
ooooo`0nooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>oooool0027ooooo0ol0
000eooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0?Oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo03gooooo00?o003oooooooooool06Oooool00ol00?oooooooooo
o`0jooooo`008Oooool00ol0003oooooooooo`0dooooo`03ool00?l00?oooooo01Wooooo00?o003o
ooooooooool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0doooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool0?Oooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo03gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0joooo
o`008Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0dooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool0??ooool00ooo003o003oooooo`0Iooooo`03o`00
oooo003ooooo03gooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0jooooo`008Ooo
ool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0>ooo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooo003ooooo03gooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0cooooo`03ool0
0?l00?oooooo01_ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00
oooooooooooo03_ooooo00?o003oooooooooool06_ooool00ooo003o003oooooo`0jooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03_ooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool0>Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo03_ooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0iooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0003?ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0jooooo`03ool00?l00?oooooo01_ooooo00?o003oool00?ooool0
>oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03Wooooo0007ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03[ooooo00?o003ooooooooo
ool06oooool00ol00?ooo`00ooooo`0kooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool0>Oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo03[o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03ool00?l00?oooooo01co
oooo00?o003oooooooooool0>Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo03Wooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool0>?ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03Wo
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0hooooo`008Oooool00ol0003ooooo
ooooo`0booooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0>?ooool00ooo003o003o
ooooo`0Mooooo`03o`00oooooooooooo03Wooooo00?o003oooooooooool07Oooool00ol00?oooooo
ooooo`0hooooo`008Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool0>?ooool00ooo003o003oooooo`0Mooooo`03o`00oooooooooooo03Wooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0b
ooooo`03o`00oooooooooooo01gooooo00?oo`00o`00ooooool0>?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo03Sooooo00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0h
ooooo`008Oooool00ol0003oooooooooo`0booooo`03o`00oooooooooooo01gooooo00?oo`00o`00
ooooool0>?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo03Oooooo00?oo`00o`00
ooooool07_ooool00ol00?ooooooooooo`0hooooo`008Oooool3o`00037ooooo00?o003ooooooooo
ool07_ooool00ooo003o003oooooo`0hooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`00
0?oooooooooo037ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00
oooooooooooo01kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo03Oooooo000Qooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0=ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo037ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo03Oooooo000Qooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool07oooool00ooo
003o003oooooo`0fooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo000Qooooo`03o`000?oooooooooo033o
oooo00?oo`00o`00ooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool0=_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oo
oooo000Qooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`0eooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ooo003o003o
ooooo`0Qooooo`03o`00oooooooooooo03Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool0=Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03Kooooo000Q
ooooo`03o`000?oooooooooo033ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0e
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo03Kooooo000Qooooo`?o0000<?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo03Gooooo00?o003oooooooooool08?ooool00ooo003o003oooooo`0eoooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool0=_ooool0027ooooo00?o0000oooooooo
ool0;oooool00ooo003o003oooooo`0Sooooo`03o`00oooooooooooo03?ooooo00?o003ooooooooo
ool08Oooool00ooo003o003oooooo`0eooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo03?ooooo00?o003oooooooooool08Oooool00ooo003o003oooooo`0eooooo`03o`00
oooooooooooo027ooooo00?o003oool00?ooool0=_ooool0027ooooo00?o0000ooooooooool0;ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0=Ooo
ool0027ooooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo03;ooooo00?oo`00o`00ooooool08oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;oooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo03;ooooo00?oo`00o`00ooooool08oooool00ol0
0?ooooooooooo`0cooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0=Oooool0027o
oooo00?o0000ooooooooool0;oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool08oooool00ooo003o003oooooo`0cooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool08oooool00ooo003o003o
ooooo`0cooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0=Oooool0027ooooo00?o
0000ooooooooool0;_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?o
003oool00?ooool0=Oooool0027ooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo033ooooo00?oo`00o`00ooooool09Oooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0=?ooool0027ooooo0ol0000^oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ooo003o003oooooo`0Uoooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0doooo
o`008Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool0<?ooool00ooo003o003oooooo`0Uooooo`03ool00?l00?oooooo037ooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0Uooooo`03ool0
0?l00?oooooo037ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0dooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool09Ooo
ool00ol00?ooo`00ooooo`0dooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool09Oooool00ol00?ooo`00ooooo`0dooooo`008Oooool00ol0
003oooooooooo`0Nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00?o003o
o`000?l000000ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool01oo^k^ko<S8bo`00
0?lb<S;ok^k^ooooool00?l00oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@03ooooool00?oooooo00?ooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo00?o003oooooooooool01?oo
ool4o`000003oa0@4?oooooooooo01cooooo1?l000001ol@413oooooooooooooooooo`00o`00oolQ
8B401?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`03o`00ool0003o0000
00;o000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0P
ooooo`008Oooool00ol0003oooooooooo`0Nooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@?ooooo00Ko003ooiRHV?lQ8B7ok^k^oooooom4A4@7ooooo`03ogMgMolb<S;ooooo01Cooooo
00OoMgMgoiRHV?ooooooV9RHogMgMooooooo003o00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?oo`00o`00ooooool00oooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo01Oooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o003oob4Q8OlQ8B401?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool05?ooool01?l00?oooooooooo
ool00006ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0Nooooo`05oa0@4?ooooooooooooooool@41002_ooool01Ol00?oooooooiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool04oooool01ol@413ooooooooooooooooo410@ooooool00?l03_ooool0
0ol0003oooooooooo`0Cooooo`05oa0@4?ooooooooooooooool@41001oooool00ol00?oooooooooo
o`03ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool05oooool00ol00?oooooooooo
o`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool04oooool01?l00?oooooooooo
ool0000Aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01kooooo00Go
0000ooooooooooooooooo`00000:ooooo`06o`00oooooooooooooiRHV?lQ8B7ok^k^1oooool00omg
MgOo<S8booooo`0Dooooo`07o`000?ooooooooooooooool0003oooooo`00o`0=ooooo`03ogMgMolb
<S;ooooo01Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00oooooooooooo00Cooooo
00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`0Hooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Dooooo`04o`00ooooooooooooo`00013o
oooo00?oMgMgoc8b<_ooool07oooool0027ooooo0ol0000Nooooo`05o`000?ooooooooooooooool0
00002_ooool01_l00?ooooooooooooooooooMgMgofIVIPCooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Eooooo`08o`000?ooooooooooooooool0003oooooo`00oooo0009ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o003oooooooooool01?oo
ool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool00ol00?oooooo
ooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`07ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`04
o`00ooooooooooooo`0000gooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Pooooo`008Oooool00ol0
003oooooooooo`0Nooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol00?ooooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool02?l@413ooooooooooooo
oooo410@ooooool00?ooo`002Oooool00ol0003oooooooooo`0Gooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol00?ooooooooooo`04ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooo
ooooool06oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool00ooo003o003oooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05oooool01?l00?ooooooooooool0000=ooooo`03o`000?oooooooooo02;ooooo000Qoooo
o`03o`000?oooooooooo01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`07o`00oooooooo
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo01Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`02ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool05oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00Go003ooooooooooooooooooa0@4003ooooo`03oc8b<_oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00_ooool00ooo003o003oooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`0Hooooo`03o`00oooooooo000000gooooo00?o
0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool07_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Wooooo00Oo003ooooooonHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Fooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol00?ooooooooooo`07ooooo`Co00005_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co003ooooooooooooooooo1Ol00004ooooo`Co00006ooo
ool00ol00?ooooooooooo`02ooooo`03oeEEEOmVIVKo0000023ooooo00?oEEEEofIVI_l000001?oo
ool00ol00?ooooooooooo`05ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0001Oooooo
00?o003oofIVI_l000003Oooool4o`00027ooooo000Qooooo`03o`000?oooooooooo02cooooo00?o
003oooooooooool0:Oooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool0;?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool0:Oooool00ol00?ooo`00ooooo`0/
ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`0Y
ooooo`03o`00oooooooooooo03;ooooo000Qooooo`03o`000?oooooooooo02cooooo00?o003ooooo
ooooool0:Oooool00ol00?ooo`00ooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool0;?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo02Sooooo0_l00002oooo
o`;o00001?ooool0027ooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`0Zooooo`03
o`00oooo003ooooo02cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0/ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool0:?ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Cooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0:oooool00ol0
0?ooooooooooo`0[ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0:oooool00ooo
003o003oooooo`0[ooooo`03o`00oooooooooooo02Sooooo00CogMgMo`000?l@413oc<c<1Oooool0
01[ooooo1ol000000ol00?oo0000o`00000[o`000003o`00ool0003o000002_o000000?o003oo`00
0?l00000:ol000000ol00?oo0000o`00000[o`000003o`00ool0003o000002[o000000?o003oo`00
0?l00000:ol000000ol00?oo0000o`00000Lo`0000cooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0
027ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo0000
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool00?l01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00?l0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?l00?oooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0<ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`00
oooooooooooo02_ooooo00?o003oooooool00000:oooool01?l00?ooooooooooool0000Yooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo02Cooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool07_ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0
:_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0
:oooool00ol00?ooooooooooo`0aooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0aooooo`008Oooool0
0ol0003o003oooooo`0Zooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0:_ooool0
0ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0;?ooool0
0ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooooooooooo
02gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo
02Sooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o
003oooooo`0Zooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0:?ooool00ol00?oo
o`00ooooo`0^ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`0`ooooo`008Oooool00ol0003o003oooooo`0Zooooo`03o`00oooooooooooo02gooooo
00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo02Sooooo
00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0`ooooo`008Oooool00ol0003o003oo`00
000Zooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0:?ooool00ol00?oooooooooo
o`0^ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0;Oooool00ol00?oooooooooo
o`0`ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooo003ooooo02kooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo02Sooooo00?o003o
ooooooooool0;Oooool00ol00?ooo`00ooooo`0`ooooo`008Oooool00ol0003oooooo`00o`0Yoooo
o`03o`00oooooooooooo02kooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0^oooo
o`03ool00?l00?oooooo02Oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0_oooo
o`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooooooooooo02kooooo00?o003ooooooooo
ool09oooool00ol00?ooooooooooo`0_ooooo`03ool00?l00?oooooo02Oooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02Kooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0_ooooo`008Ooo
ool00ol0003oooooo`00o`0Yooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool09_oo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooo`00o`0Yooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool0;oooool00ol00?ooo`00ooooo`0_ooooo`008Oooool01?l0
003oooooooooool00?lXooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0;oooool0
0ol00?ooo`00ooooo`0_ooooo`008Oooool01?l0003oooooooooool00?lWooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0`ooooo`03ool00?l00?oo
oooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooo`00ooooo`0_ooooo`008Oooool3o`00
0003o`00oooooooooooo02Gooooo00?o003oooooooooool0<?ooool00ol00?ooo`00ooooo`0Voooo
o`03o`00oooooooooooo033ooooo00?oo`00o`00ooooool09Oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo02kooooo000Qooooo`04o`000?ooooooooooo`00obOooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo02kooooo000Qooooo`04
o`000?ooooooooooo`00obOooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo02kooooo000Qooooo`05o`000?ooooooooooo`00oooo00009_ooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`0Sooooo`03ool00?l00?oooooo03;ooooo00?o003oooooooooool0;_ooool0027o
oooo00Go0000ooooooooooooooooo`00o`0Vooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?oo`00o`00
ooooool0<_ooool00ol00?ooooooooooo`0^ooooo`008Oooool01Ol0003ooooooooooooooooo003o
02Gooooo00?o003oooooooooool0<_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo
03?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
02kooooo000Qooooo`05o`000?ooooooooooooooool00?l09Oooool00ol00?ooooooooooo`0boooo
o`03o`00oooo003ooooo02Cooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo03?ooooo00?o003oooooooooool0;Oooool0027ooooo00Go0000oooooooo
ooooooooo`00o`0Uooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0<oooool00ol0
0?ooooooooooo`0]ooooo`008Oooool01_l0003ooooooooooooooooo003oool002Cooooo00?o003o
ooooooooool0<oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo03Cooooo00?o003o
ooooooooool08Oooool00ooo003o003oooooo`0dooooo`03o`00oooooooooooo02gooooo000Qoooo
o`?o000000?oooooo`00oooo00009?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Qooooo`03ool00?l00?oooooo
03Cooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo03?ooooo00?o003oool00?ooool08_ooool00ol00?oo
ooooooooo`0dooooo`03o`00oooooooooooo027ooooo00?oo`00o`00ooooool0=?ooool00ol00?oo
ooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool0=?ooool00ol00?ooo`00ooooo`0Rooooo`03o`00oooooooooooo03Cooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02gooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0dooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0=Oooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool0;?ooool0027ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03Gooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo01oooooo00?oo`00
o`00ooooool0=_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Poooo
o`03o`00oooooooooooo03Kooooo00?o003oooooooooool07oooool00ooo003o003oooooo`0foooo
o`03o`00oooooooooooo02cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oool00?oo
ool08Oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool0=_ooool00ol00?ooooooooooo`0Oooooo`03ool00?l00?oooooo03Kooooo00?o003ooooooooo
ool0;?ooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo03Gooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0fooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0/ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0=_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03Kooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0fooooo`03o`00oooo003ooooo02cooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool0=_ooool00ooo003o003oooooo`0Oooooo`03o`00oooooooo
oooo03Oooooo00?o003oooooooooool0:oooool0027ooooo0ol00003ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo
02_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`0gooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0>?ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool0:oooool0027ooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo03Oooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0[ooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0=oooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`0gooooo`03o`00oooo003ooooo02_ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool07Oooool00ol00?ooo`00ooooo`0hooooo`03o`00oooooooooooo01kooooo00?o003o
ooooooooool0>?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo03Sooooo00?o003o
ool00?ooool0:oooool0027ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo03Wooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0ioooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool0>Oooool00ol00?ooooooooooo`0Zoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool0>Oooool00ol00?ooooooooooo`0Looooo`03ool00?l00?oooooo03[ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Looooo`03ool00?l00?oooooo03[ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooooooooooo02[ooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool0>_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03Wooooo00?o003o
ool00?ooool0:_ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol00005ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0>Oooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0iooooo`03o`00oooo003ooooo02[ooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0jooooo`03o`00oooo003ooooo01_ooooo00?o003oooooooooool0>_oo
ool00ol00?ooo`00ooooo`0Zooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo03_ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo02Wooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooo
oooooooo03_ooooo00?o003oooooooooool0:Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`0Jooooo`03o`00oooo003ooooo03cooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo02Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0k
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0??ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo03cooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0looooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool0??ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool0?Oooool00ol00?ooooooooooo`0Iooooo`03
o`00oooooooooooo03gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0looooo`03
o`00oooooooooooo02Wooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
6Oooool00ol00?ooooooooooo`0mooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool0
?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03gooooo00?o003oooooooooool0
:?ooool0027ooooo0ol00006ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool0?Ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0mooooo`03o`00oooooooooooo02Sooooo000Qooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0mooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool0?_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo003o
oooo03kooooo00?o003oooooooooool0:?ooool0027ooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo03kooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0nooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0?_ooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo03ko
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0nooooo`03o`00oooooooooooo02So
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`0oooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0?oooool00ol00?oooooo
ooooo`0Fooooo`03o`00oooooooooooo03oooooo00?o003oooooooooool09oooool0027ooooo00?o
0000ooooooooool01oooool00ol00?ooo`00ooooo`0Fooooo`03ool00?l00?oooooo043ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0?oooool00ol00?ooooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool0@?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`10
ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0@?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo043ooooo00?o003ooooo
ooooool09oooool0027ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo047ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`10ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool0@?ooool00ol00?ooo`00ooooo`0Wooooo`00
8Oooool3o`0000Sooooo00?o003oooooooooool05?ooool00ooo003o003oooooo`12ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool0@Oooool00ol00?ooo`00ooooo`0Eooooo`03o`00
oooooooooooo047ooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool02?oo
ool00ol00?ooo`00ooooo`0Dooooo`03ool00?l00?oooooo04;ooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0@_oo
ool00ol00?ooooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo
oooo01?ooooo00?oo`00o`00ooooool0@_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo04;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo02Kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool09_ooool0027o
oooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo01;ooooo00?oo`00o`00ooooool0A?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo04?ooooo00?o003oool00?ooool04_ooool00ol00?oooooo
ooooo`14ooooo`03o`00oooooooooooo02Gooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o
003oooooooooool04Oooool00ooo003o003oooooo`14ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04Cooooo00?o
003oooooooooool09Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0A
ooooo`03ool00?l00?oooooo04Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0T
ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool0AOooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo04Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo02Cooooo000Qooooo`?o
00002oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo04Gooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool0AOooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool0A_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo04Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`16ooooo`03o`00
oooo003ooooo02Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ooo003o003oooooo`17ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0A_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool08ooo
ool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03ool00?l00?oo
oooo04Oooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`17ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0Aoooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`18ooooo`03o`00oooo003ooooo02?ooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool08_ooool0027ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool03?ooool00ooo003o003o
ooooo`19ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool0BOooool00ol00?oooooo
ooooo`0Rooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04[ooooo00?o
003oooooooooool02oooool00ol00?ooo`00ooooo`1:ooooo`03o`00oooooooooooo02;ooooo000Q
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1:
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool08_ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo04_ooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`1<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool0Boooool00ol00?ooooooooooo`0Qooooo`008Oooool3o`0000kooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool0C?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04_ooooo00?o003ooooooooo
ool08Oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo04cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`1<ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0C?ooool00ol00?ooooooooooo`0Qooooo`008Ooo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0COoo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooo
oooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo04gooooo00?o003oooooooooool08?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`1>ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo053o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo01oo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0DOooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo05;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1Aooooo`03o`00
oooooooooooo01kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Dooo
ool00ol00?ooooooooooo`0Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo0_l00?l2ooooo`;o003oE_ooool00ol00?ooooooooooo`02o`00oeKooooo0_l00?l2
ooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool07?ooool001[ooooo00?o0000oooo
ooooool01?ooool3o`0001?ooooo0ol00?mIooooo`?o003oF?ooool3o`00oeWooooo0_l00?lLoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@ooooo`03o`00
0?o^k^kooooo0:Cooooo002Yooooo`05o`000?ooooooooooooooool000000_ooool6o`0000_ooooo
00?oEEEEojVYZOooool0Y?ooool0023ooooo00?o^[Zjoc8b<_ooool0Q_ooool01Ol0003ooooooooo
oooooooo000001?ooooo00?oZJVYoeEEEOooool0Y?ooool0027ooooo00?o0000ooooooooool0QOoo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03ob4Q8Ooooooooooo0:?ooooo
000Oooooo`05oiRHV?l@413o0000o`000?nYZJT0QOooool01Ol0003oQhN7oooooonYZJWo000001Co
oooo00?oEEEEolc<c?ooool0Xoooool001oooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[Z3oooo
o`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool04_ooool00onYZJWoMgMgooooo`2Soooo
o`007oooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@49[ooooo00Go410@oooooooooooooooooc8b
<P2Tooooo`007oooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`0VOooool5o`000:Cooooo
000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo000Oooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_ooool00omVIVKoQhN7
ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.0861, \
0.0066032, 0.0136034}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.03279 .4154 L
.04262 .51486 L
.04758 .55308 L
.0503 .56996 L
.05288 .58292 L
.05528 .59204 L
.05664 .59599 L
.05789 .59888 L
.05894 .60072 L
.0601 .60214 L
.06131 .60292 L
.06244 .60296 L
.0631 .60265 L
.06379 .60208 L
.06504 .60046 L
.06581 .5991 L
.06653 .59756 L
.06788 .59403 L
.07036 .58529 L
.07305 .57251 L
.0781 .53981 L
.08274 .50098 L
.10458 .25385 L
.11366 .15205 L
.11867 .10442 L
.1234 .06743 L
.12608 .05044 L
.12899 .03544 L
.13028 .03019 L
.13164 .02545 L
.13282 .02206 L
.13409 .01914 L
.13537 .01698 L
.13654 .01569 L
.13766 .01508 L
.13883 .01512 L
.14013 .01609 L
.14133 .01772 L
.14265 .02031 L
.14407 .024 L
.14666 .03319 L
.1494 .04638 L
.15431 .07841 L
.1596 .12322 L
.16541 .18266 L
.18557 .41985 L
.19034 .47089 L
.19554 .5195 L
.20013 .55423 L
Mistroke
.20265 .56971 L
.20501 .58179 L
.20644 .58777 L
.20799 .59308 L
.20927 .59664 L
.21 .59831 L
.21068 .59965 L
.21137 .60079 L
.21201 .60162 L
.21269 .6023 L
.21341 .60277 L
.21471 .60298 L
.21593 .60234 L
.21714 .60093 L
.21841 .59867 L
.21951 .59611 L
.22071 .59264 L
.22339 .5825 L
.2259 .5699 L
.23062 .53875 L
.23576 .49506 L
.24613 .38398 L
.26464 .16664 L
.26995 .11426 L
.27495 .07333 L
.27943 .04505 L
.28196 .03292 L
.28429 .02458 L
.2855 .02128 L
.2868 .0185 L
.28803 .01663 L
.28915 .01554 L
.29046 .01505 L
.2912 .01514 L
.29189 .01548 L
.29315 .01683 L
.29378 .0178 L
.29448 .01911 L
.29588 .02239 L
.29716 .02621 L
.30004 .03761 L
.30258 .0509 L
.30526 .06805 L
.31479 .15082 L
.32497 .26559 L
.34333 .47706 L
.3483 .52265 L
.35356 .56101 L
.35631 .57652 L
.35776 .58341 L
Mistroke
.35933 .58968 L
.36077 .5943 L
.36208 .59767 L
.3634 .60023 L
.36465 .60189 L
.36592 .6028 L
.36707 .60294 L
.36771 .60275 L
.3684 .60231 L
.36965 .60076 L
.37083 .59862 L
.37207 .59565 L
.37429 .58851 L
.37688 .5773 L
.3793 .56399 L
.3848 .52453 L
.39526 .42124 L
.40517 .3041 L
.41399 .19983 L
.41901 .14607 L
.42373 .10187 L
.42877 .06332 L
.43339 .03718 L
.4358 .02737 L
.43701 .02357 L
.43833 .02022 L
.43966 .01768 L
.44041 .01663 L
.44109 .01592 L
.44241 .01515 L
.44365 .01521 L
.44472 .01586 L
.44589 .01732 L
.44711 .01959 L
.44825 .02237 L
.4503 .02887 L
.4525 .038 L
.4575 .0671 L
.46208 .10266 L
.48272 .33048 L
.49277 .44667 L
.50186 .53222 L
.50645 .56414 L
.50887 .5774 L
.51141 .58858 L
.51365 .59571 L
.51491 .59866 L
.5161 .60072 L
.51718 .60203 L
.51817 .60272 L
Mistroke
.51932 .60293 L
.5204 .60254 L
.52153 .60152 L
.52278 .59951 L
.52409 .59661 L
.52531 .59315 L
.5275 .58523 L
.52985 .57428 L
.53522 .53997 L
.54012 .49882 L
.56071 .266 L
.57073 .15283 L
.57982 .07247 L
.58439 .04406 L
.58696 .03201 L
.58819 .02733 L
.58933 .0237 L
.59042 .02086 L
.59141 .01877 L
.59251 .01699 L
.59369 .01574 L
.59482 .01517 L
.59606 .01525 L
.59722 .01601 L
.5983 .01732 L
.59942 .01941 L
.60064 .02235 L
.60284 .02945 L
.60545 .04077 L
.60785 .05385 L
.61279 .08883 L
.618 .13527 L
.63796 .36471 L
.64666 .46255 L
.65124 .50684 L
.6561 .5462 L
.65859 .5627 L
.66134 .57784 L
.66384 .58871 L
.66618 .59613 L
.66741 .59891 L
.66857 .60087 L
.66962 .60208 L
.67077 .60279 L
.67201 .60284 L
.67332 .60208 L
.67457 .60059 L
.6757 .59846 L
.67701 .59519 L
.6784 .59084 L
Mistroke
.68088 .58085 L
.68356 .56701 L
.68649 .54807 L
.69664 .45787 L
.71782 .21043 L
.72268 .15719 L
.72784 .10753 L
.73263 .06943 L
.73711 .04231 L
.7393 .0322 L
.74167 .02378 L
.74295 .02048 L
.74365 .01902 L
.74429 .01786 L
.74544 .01632 L
.7467 .01535 L
.74735 .01515 L
.74806 .01517 L
.74934 .01582 L
.75059 .01722 L
.75174 .01924 L
.75299 .02223 L
.75435 .02638 L
.75712 .0374 L
.75959 .05013 L
.76184 .06415 L
.76691 .10329 L
.77606 .19507 L
.78607 .31334 L
.79672 .43787 L
.80581 .52564 L
.8083 .54495 L
.81099 .56282 L
.81351 .57679 L
.81586 .58728 L
.8181 .59494 L
.81935 .59805 L
.8205 .6002 L
.82175 .60185 L
.82246 .60244 L
.82311 .60277 L
.82431 .60284 L
.82558 .60216 L
.82679 .60078 L
.82809 .59847 L
.82933 .59541 L
.83045 .59198 L
.8332 .58112 L
.83582 .56765 L
.84036 .53707 L
Mistroke
.84458 .50156 L
.85414 .40148 L
.87295 .17978 L
.8781 .12705 L
.88354 .08023 L
.88818 .04932 L
.89082 .03594 L
.89328 .02627 L
.89461 .02222 L
.89531 .02048 L
.89606 .01892 L
.89671 .01778 L
.89742 .01676 L
.89869 .01556 L
.89991 .01514 L
.90123 .0155 L
.90248 .01661 L
.90362 .01829 L
.90426 .01952 L
.90495 .02112 L
.9062 .02461 L
.90902 .03521 L
.91199 .0503 L
.9147 .06737 L
.92508 .15867 L
.93487 .27003 L
.95356 .48402 L
.9581 .52489 L
.96298 .56046 L
.96578 .57623 L
.96834 .58764 L
.96957 .59206 L
.97091 .59608 L
.97217 .59907 L
.97334 .60115 L
.97407 .60209 L
.97472 .60272 L
.97548 .60317 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.03279 .41547 L
.04262 .51505 L
.04758 .55343 L
.0503 .57029 L
.05288 .58319 L
.05528 .59242 L
.05664 .59641 L
.05789 .59929 L
.05894 .60112 L
.0601 .6025 L
.06131 .60323 L
.06244 .60325 L
.0631 .60296 L
.06379 .60243 L
.06504 .60086 L
.06581 .59951 L
.06653 .59798 L
.06788 .59443 L
.07036 .58561 L
.07305 .57281 L
.0781 .54013 L
.08274 .50119 L
.10458 .25377 L
.11366 .15183 L
.11867 .10421 L
.1234 .06708 L
.12608 .05009 L
.12899 .0352 L
.13028 .02987 L
.13164 .02507 L
.13282 .02165 L
.13409 .01872 L
.13537 .01658 L
.13654 .01532 L
.13766 .01476 L
.13883 .01485 L
.14013 .01575 L
.14133 .01733 L
.14265 .0199 L
.14407 .02359 L
.14666 .03286 L
.1494 .04609 L
.15431 .07808 L
.1596 .123 L
.16541 .1825 L
.18557 .41997 L
.19034 .47113 L
.19554 .51971 L
.20013 .55458 L
Mistroke
.20265 .57006 L
.20501 .58207 L
.20644 .58806 L
.20799 .59344 L
.20927 .59705 L
.21 .59873 L
.21068 .60007 L
.21137 .6012 L
.21201 .60202 L
.21269 .60268 L
.21341 .60313 L
.21471 .60327 L
.21593 .60264 L
.21714 .60129 L
.21841 .59906 L
.21951 .59653 L
.22071 .59305 L
.22339 .58282 L
.2259 .57018 L
.23062 .53908 L
.23576 .49527 L
.24613 .38407 L
.26464 .16646 L
.26995 .11401 L
.27495 .07302 L
.27943 .04469 L
.28196 .03266 L
.28429 .02423 L
.2855 .02088 L
.2868 .01808 L
.28803 .01621 L
.28915 .01516 L
.29046 .01472 L
.2912 .01485 L
.29189 .01521 L
.29315 .0165 L
.29378 .01744 L
.29448 .01872 L
.29588 .02198 L
.29716 .02581 L
.30004 .0373 L
.30258 .05061 L
.30526 .06771 L
.31479 .1506 L
.32497 .26553 L
.34333 .4773 L
.3483 .52287 L
.35356 .56138 L
.35631 .57687 L
.35776 .58371 L
Mistroke
.35933 .58996 L
.36077 .59465 L
.36208 .59807 L
.3634 .60065 L
.36465 .60231 L
.36592 .60318 L
.36707 .60328 L
.36771 .60305 L
.3684 .60257 L
.36965 .60109 L
.37083 .599 L
.37207 .59605 L
.37429 .5889 L
.37688 .5776 L
.3793 .56428 L
.3848 .52482 L
.39526 .42138 L
.40517 .30411 L
.41399 .1997 L
.41901 .14585 L
.42373 .10162 L
.42877 .06298 L
.43339 .03685 L
.4358 .02709 L
.43702 .02319 L
.43833 .01983 L
.43965 .01729 L
.44087 .0157 L
.44162 .0151 L
.44233 .01478 L
.44296 .01472 L
.44365 .01487 L
.4448 .01566 L
.44587 .01699 L
.44705 .0191 L
.44831 .02213 L
.45089 .0307 L
.45324 .04128 L
.45778 .06866 L
.46208 .1024 L
.48216 .32371 L
.4909 .42642 L
.50034 .52004 L
.50564 .55949 L
.50796 .57312 L
.51051 .58527 L
.51167 .58981 L
.51292 .59397 L
.51399 .59695 L
.51516 .59955 L
Mistroke
.51648 .60167 L
.51773 .60289 L
.51895 .60332 L
.52007 .60306 L
.52127 .60208 L
.52257 .60022 L
.5238 .5977 L
.52492 .59475 L
.52765 .58498 L
.53026 .57244 L
.53542 .53876 L
.54106 .49019 L
.56237 .24611 L
.57243 .13554 L
.57685 .09537 L
.58169 .05944 L
.58396 .04596 L
.5864 .03406 L
.58774 .02867 L
.58897 .0245 L
.59013 .02122 L
.59137 .01846 L
.592 .01733 L
.5927 .01632 L
.59394 .01514 L
.59463 .01481 L
.59538 .01472 L
.59609 .0149 L
.59674 .01528 L
.59792 .01652 L
.59922 .01867 L
.60057 .02181 L
.60183 .02553 L
.6043 .03504 L
.60664 .04663 L
.61101 .07476 L
.62081 .16371 L
.63912 .37856 L
.64953 .49123 L
.65461 .53537 L
.65926 .56707 L
.66161 .57955 L
.66418 .59026 L
.66535 .59412 L
.6666 .5975 L
.66777 .59998 L
.66884 .60164 L
.66949 .60238 L
.67017 .60292 L
.67139 .60332 L
Mistroke
.6727 .60291 L
.67345 .6023 L
.67414 .60148 L
.6754 .59938 L
.67655 .59678 L
.67913 .5886 L
.68182 .5767 L
.68431 .56276 L
.68994 .52166 L
.70017 .41973 L
.70994 .30401 L
.72045 .18082 L
.72529 .13086 L
.73038 .08597 L
.73473 .05532 L
.73701 .04244 L
.73948 .03115 L
.74081 .02625 L
.74203 .02249 L
.74318 .01963 L
.74444 .01723 L
.74558 .01576 L
.74663 .01496 L
.74775 .01472 L
.74895 .01516 L
.75025 .01645 L
.75098 .01754 L
.75166 .0188 L
.75291 .0217 L
.75424 .02561 L
.75653 .03436 L
.75906 .04688 L
.76358 .07616 L
.76845 .11674 L
.77727 .20857 L
.79688 .4398 L
.80226 .49455 L
.808 .543 L
.81079 .56194 L
.81343 .57677 L
.81579 .58739 L
.81703 .5919 L
.81836 .59593 L
.81965 .59899 L
.82082 .60108 L
.822 .6025 L
.82312 .6032 L
.82442 .60323 L
.82562 .6025 L
.82694 .60086 L
Mistroke
.82768 .59957 L
.82835 .59817 L
.83097 .59057 L
.83245 .58484 L
.83381 .57866 L
.83894 .54785 L
.84335 .51285 L
.84818 .46678 L
.85794 .35689 L
.8688 .22641 L
.87909 .11746 L
.88357 .07969 L
.88833 .04814 L
.89081 .03559 L
.89213 .03009 L
.89355 .02507 L
.89485 .02133 L
.89604 .01864 L
.89718 .01671 L
.89837 .01538 L
.89963 .01475 L
.90081 .01488 L
.90188 .0156 L
.90303 .01701 L
.90429 .0193 L
.90562 .02258 L
.908 .0306 L
.91021 .0404 L
.91227 .05158 L
.91696 .08381 L
.92676 .17645 L
.93729 .29925 L
.94684 .41285 L
.95188 .46745 L
.95725 .51802 L
.96241 .55705 L
.96708 .58279 L
.96934 .59164 L
.97052 .59532 L
.97177 .59845 L
.97287 .60057 L
.97408 .6022 L
.97517 .60306 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000Qooooo`;o003o;Oooool2o`00obkooooo
0_l00?l]ooooo`;o003o;_ooool2o`00obgooooo0ol00?lcooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo023ooooo00?o003oooooool00?l0;Oooool00ol00?ooooooo`00
o`0/ooooo`04o`00oooooooo003oo`00obcooooo00?o003oooooool00?l0;?ooool01?l00?ooo`00
o`00ool00?l/ooooo`03o`00oooooooo003o03?ooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07oooool01Ol00?oooooooooooooooooo003o02_ooooo00Co003ooooooooo
oooo003o;?ooool01?l00?ooooooooooool00?l[ooooo`04o`00ooooooooooooo`00obcooooo00Co
003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o03;ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07oooool01Ol00?oooooooooooooooooo003o02_o
oooo00Go003oooooooooooooo`00o`00o`0Zooooo`05o`00ooooooooooooooooool00?l0:oooool0
1Ol00?oooooooooooooooooo003o02_ooooo00Co003ooooooooooooo003o:oooool01Ol00?oooooo
oooooooooooo003o03;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool01Ol00?oooooooooooooooooo003o02_ooooo00Go003oooooooooooooooooo`00o`0Zoooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo02Sooooo00Go003oooooooooooooooooo`00o`0[ooooo`05o`00oooooooo
ooooooooool00?l0<_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0O
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0:?ooool01_l00?oooooooooooooo
ooooo`00o`00ob[ooooo00Go003oooooooooooooooooo`00o`0booooo`008Oooool00ol0003ooooo
ooooo`0Nooooo`03o`00oooo003ooooo00?ooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0:?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo02Oooooo00?oo`00o`00ooooool00_ooool00ol00?oooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`0N
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0W
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0_
ooooo`008Oooool3o`0001gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooo`00ooooo`04oooo
o`03o`00oooooooooooo02oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oool00?oo
ool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo003ooooo02Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02oooooo000Qooooo`03o`00
0?oooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0Vooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?oo
ool00ol00?ooo`00ooooo`0Uooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02kooooo000Qooooo`03o`000?oooooo
oooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooo003ooooo02kooooo000Qooooo`03o`000?oooooooooo01go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo02Co
oooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08oooool00ooo003o003oooooo`06ooooo`03o`00oooo003ooooo02ko
oooo000Qooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02?ooooo00?oo`00o`00ooooool01_ooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooo003ooooo02kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o
o`00o`00ooooool01_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo02kooooo000Q
ooooo`?o00007Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool0;Oooool0027ooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Soooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Soooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000oooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool0;Oooool0027ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0;Oooool0027ooooo00?o0000ooooooooool07?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_oo
ool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oool00?ooool0;Ooo
ool0027ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo00Oooooo00?o003oool00?ooool0;Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0;Oooool0027o
oooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023o
oooo00?oo`00o`00ooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00So
oooo00?o003oool00?ooool0;Oooool0027ooooo00?o0000ooooooooool06oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0;Oooool0027ooooo00?o
0000ooooooooool06oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o
003oool00?ooool0;Oooool0027ooooo0ol0000Kooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0/oooo
o`008Oooool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo027ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo023ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`09ooooo`03ool0
0?l00?oooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Qooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03ool0
0?l00?oooooo023ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Ooo
ool00ol00?ooo`00ooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`00oooo003o
oooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`0Jooooo`03o`00oooo003ooooo00_ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol0
0?ooo`00ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0/ooooo`008Oooool3o`0001[ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?oo`00
o`00ooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02_ooooo000Qoooo
o`03o`000?oooooooooo01[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<oooo
o`03o`00oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oool00?oo
ool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07Oooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo02_ooooo000Qooooo`03o`00
0?oooooooooo01Wooooo00?o003oool00?ooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooo003ooooo01kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<ooooo`03o`00
oooooooooooo02_ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01kooooo00?oo`00o`00ooooool03?oo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07Ooo
ool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo02_ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo01gooooo00?oo`00o`00ooooool03?ooool00ooo003o003oooooo`0Nooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo02_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03ool00?l00?oooooo00cooooo
00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`0[ooooo`001Ol00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Wooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07Oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo02_ooooo
0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`?o0000
6Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool0
:oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Zooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Zooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ooo003o003oooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Zooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo00ko
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02[o
oooo000Qooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool03Oooool00ooo003o003o
ooooo`0Looooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo01cooooo00?oo`00o`00ooooool03_ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02[ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03ool00?l00?oooooo00kooooo00?o
003oooooooooool06oooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o
o`00o`00ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo02[ooooo000Q
ooooo`03o`000?oooooooooo01Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool06oooool00ooo003o003oooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooo003ooooo02[ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool06oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?oo`00o`00
ooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo02[ooooo000Qooooo`?o
00006?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool06oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oool00?oo
ool0:_ooool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00kooooo00?o003oool00?ooool0:_ooool0027ooooo00?o0000ooooooooool06?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?oo`00o`00ooooool03ooo
ool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:Ooo
ool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01[ooooo00?oo`00o`00ooooool03oooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01[ooooo00?oo`00o`00ooooool03oooool00ooo003o003oooooo`0Kooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol0
0?ooooooooooo`0?ooooo`03ool00?l00?oooooo01[ooooo00?oo`00o`00ooooool03oooool00ol0
0?ooo`00ooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ooo
003o003oooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:Oooool0027o
oooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wo
oooo00?oo`00o`00ooooool03oooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool03oooool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool04?ooool00ol00?oooooo
ooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ooo003o003o
ooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:Oooool0027ooooo00?o
0000ooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o
o`00o`00ooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool06oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:Oooool0027ooooo0ol0000Hoooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool06Oooool00ooo003o003oooooo`0@oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ooo003o003oooooo`0Koooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Yoooo
o`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l00?oooooo017ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ooo003o003oooooo`0Kooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool0
0?l00?oooooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooo003ooooo01Wooooo00?o003oooooooooool04?ooool00ooo003o003oooooo`0Kooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?l00?oooooo017ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04?oo
ool00ooo003o003oooooo`0Jooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003o
oooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooo
oooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oo
oooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0
003oooooooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013o
oooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo003ooooo01Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0I
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo01Oooooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`0X
ooooo`008Oooool3o`0001Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aoooo
o`03ool00?l00?oooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo02Sooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Sooooo000Qooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00
oooooooooooo01Oooooo00?oo`00o`00ooooool04_ooool00ooo003o003oooooo`0Hooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Booooo`03ool0
0?l00?oooooo02Sooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05ooo
ool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?oo`00o`00ooooool04_oo
ool00ooo003o003oooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooo
oooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool04_ooool00ooo003o003oooooo`0Hooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo02Oooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool01?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42ooooo`03o`00oooooooo000000Co00001?ooool0
1Om4A4Co0000o`000?lb<S;ogMgM00[ooooo00?o003oooooooooool02?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o003oob4Q8Oooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00ko
oooo00?o003oool00?ooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B43oooo
o`05o`00ooooooooooooo`000?o^k^h01Oooool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00?o
003oooooooooool04Oooool2o`000003o`00ool0003o410@01Oooooo00?o003oooooooooool01?oo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B43ooooo`03o`00ool0003o000000?o00001?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00_ooooo00?o003oooooooooool02?ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B400ol00?ooooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oM
gMd08?ooool0027ooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Oo003ooooooonHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool02Oooool00ol00?ooooooooooo`08ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol00?oo8B4Qooooo`07ooooo`03ogMgMolb<S;ooooo00gooooo00?o
003oooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`05o`00
oooooooooooooeEEEOnYZJT02?ooool00omgMgOo<S8booooo`0:ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo0_lQ8B44ooooo`05o`00oolQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0:oooo
o`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01?ooool2ob4Q8@03o`00oooooooooooo
00Gooooo00?oMgMgoc8b<_ooool07oooool0027ooooo00?o0000ooooooooool05_ooool00ol00?oo
ooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41002Oooool01_l00?oooooooooooonHV9So
8B4Qonk^kPWooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00cooooo
00?o003oooooooooool01?ooool01Ol@413ooooooooooooooooo410@00[ooooo00Go003ooooooooo
ooooZJVYoeEEE@09ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool02_ooool01?l0
0?ooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool07_ooool0
027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05ooooo`05o`000?oooooooooo
ooooool000002Oooool01ol00?ooooooooooooooooooV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`09ooooo`03o`00oooooooooooo00Sooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`00oooooooooooo00Oooooo00?oMgMgoc8b<_ooool03Oooool00ol00?ooooooooooo`04ooooo`05
o`000?ooooooooooooooool000002_ooool01Ol00?oooooooooooooooooo8B4Q00Sooooo00?oMgMg
oc8b<_ooool02_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00
o`00ooooool01oooool00ol0003oooooooooo`0:ooooo`05o`00ooooooooV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03ogMgMolb<S;ooooo01oooooo000Qooooo`?o00005_ooool0
0ol00?ooooooooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool00ol00?oooooooooo
o`02ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00:ooooo`03o`00
oooooooooooo00Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00oooooooooooo00Co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00>ooooo`03o`00oooooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`00oooooooooooooeEEEOo<c<`01?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00[ooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03ool0
0?l00?oooooo00Oooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooomgMgOoIVIV00Co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`00oooooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08?ooool0
027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05ooooo`05oa0@4?oooooooooo
ooooool@41002Oooool00ooo003o003oooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go003oooooooooooooZJVYogMgM`04ooooo`03
o`000?oooooooooo00cooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03
ool00?l00?oooooo00Oooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo0000
00Cooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09oooo
o`07ool00?l00?oo0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00cooooo00?o
003oooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o003oooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`00oooooooooooooooooolb<S801?ooool00ol0003oooooooooo`0<oooo
o`03ool00?l00?oooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00Go003ookZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`07ooooo`05o`00oooooooo
ooooooooool000009?ooool0027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`05
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02Oooool01ooo003o003ooiRHV?l@413o0000ob4Q8Oo<
c<`01?ooool4o`0000[ooooo00?oo`00o`00ooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o003oooooooooool00oooool4o`0000kooooo00?o003oool00?ooool01Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o003oo`000?l000000_l00004ooooo`Co00002oooool0
0ooo003o003oooooo`0Booooo`03oeEEEOmVIVKo003o01Sooooo00?o003oooooooooool01Oooool0
0omEEEGoIVIVo`00000<ooooo`05o`00ool@413o0000ob4Q8Oo<c<`01?ooool4o`0000cooooo00?o
003oooooooooool02?ooool00omEEEGoIVIVo`000009ooooo`04o`00ooooooooooooooooo`Co0000
8Oooool0027ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0Cooooo`03ool00?l0
0?oooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool05Oooool0
0ooo003o003oooooo`0Dooooo`03ool00?l00?oooooo01Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool09_ooool0
027ooooo00?o0000ooooooooool05Oooool00ooo003o003oooooo`0Dooooo`03ool00?l00?oooooo
01Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool07?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo003o
003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Looooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool0027ooooo00?o0000oooo
ooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?oo`00o`00
ooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool07Oooool01?oMgMgo0000oa0@4?o<c<`5ooooo`006_ooool7o`000003o`00ool0003o0000
01Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
01Co000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
01Go000000?o003oo`000?l000005Ol000000ol00?oo0000o`00000Do`000003ool00?l00?oo0000
01Go000000?oo`00o`00ool000005Ol000000ol00?oo0000o`00000Eo`000003o`00ool0003o0000
017o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00Ko0000ooooooooooooooooool00?l00?l3ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo000000Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`00o`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo000000Sooooo00?o0000oooooooo
ool01oooool00ol0003o003oooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool01Ooo003o003ooooooooooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0
003oo`00o`00o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01?l0
0?ooooooooooool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00?l01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00Co8B4QogMgMomgMgOo<S8b1Ooo
ool0027ooooo00?o003oool00?ooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?oo`00o`00ooooool05Oooool00ol00?ooo`00ooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o0000ool00?l00?l05_ooool00ol00?ooooooooooo`0Dooooo`03o`000?l00?oo
oooo01Gooooo00?oo`00o`00ooooool05?ooool00ol0003oo`00o`00o`0Fooooo`03o`00oooooooo
oooo01?ooooo00?o0000ooooool00?l07_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0
0?ooo`00ooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo
003o003oooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05Oooool00ooo
003o003oooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ooo
003o003oooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Vooooo`008Oooool00ol00?ooooooooooo`0Dooooo`03ool00?l00?oooooo01Ko
oooo00?o003oooooooooool05?ooool00ooo003o003oooooo`0Fooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool05Oooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool05?ooool00ooo003o003oooooo`0Eooooo`03ool00?l00?oooooo01Go
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol00?oooooo
ooooo`0Dooooo`03ool00?l00?oooooo01Kooooo00?oo`00o`00ooooool05Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Gooooo00?o
o`00o`00ooooool05?ooool00ol00?ooooooooooo`0Eooooo`03ool00?l00?oooooo01Gooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0D
ooooo`03ool00?l00?oooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0U
ooooo`008Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00
ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oo`00000Dooooo`03
ool00?l00?oooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03
o`00oooo003ooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`00
8Oooool00ol0003o003oooooo`0Dooooo`03ool00?l00?oooooo01Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool0
5?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
003ooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01Kooooo00?oo`00o`00ooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`008Oooool0
0ol0003o003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo01?ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`0Cooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003o
003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Uooooo`008Oooool00ol0003o003oooooo`0Dooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool05oooool00ooo003o003oooooo`0Uooooo`008Oooool00ol0003o003ooooo
o`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0Aooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool05oooool00ooo003o003ooooo
o`0Uooooo`008Oooool00ol0003oooooo`00o`0Dooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo017ooooo00?o003o
ool00?ooool06Oooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo01Sooooo00?oo`00
o`00ooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?oo`00
o`00ooooool06?ooool00ooo003o003oooooo`0Uooooo`008Oooool2o`000003o`00oooooooooooo
01;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo
017ooooo00?oo`00o`00ooooool06?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0Hooooo`03ool00?l00?oooooo
02Gooooo000Qooooo`03o`000?oooooo003o01Cooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?oo
o`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ooo003o
003oooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ooo003o
003oooooo`0Hooooo`03ool00?l00?oooooo02Gooooo000Qooooo`03o`000?oooooo003o01Cooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool06?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool04Oooool00ooo003o003oooooo`0Hooooo`03ool00?l00?oooooo02Gooooo
000Qooooo`03o`000?oooooo003o01Cooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooo`00oooo
o`0Iooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04Oooool00ol00?ooo`00ooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qoooo
o`03o`000?oooooo003o01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003ooooooooo
ool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00oooo
ool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`00
0?oooooo003o01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo02Cooooo000Qooooo`03o`000?oooooo003o01?ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_oo
ool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo01[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo02Cooooo000Qooooo`;o000000?o003o
ool00?ooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo013ooooo00?oo`00
o`00ooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?oo`00
o`00ooooool09?ooool0027ooooo00Co0000oooooooooooo003o4_ooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01Wooooo00?oo`00o`00ooooool09?ooool0027ooooo00Co0000oooo
oooooooo003o4_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooo003ooooo017ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Wooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4_ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooo003ooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ooo003o003oooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?oo`00
o`00ooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool06oooool00ol00?ooo`00ooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027ooooo00Co0000oooo
oooooooo003o4Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?oo`00
o`00ooooool06oooool00ol00?ooo`00ooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08oooool0027ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06_ooool00ooo003o003oooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027ooooo0ol000000ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Sooooo`008Oooool01?l0003oooooooooool00?lAooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Sooooo`008Oooool01Ol0003o
oooooooooooooooo003o00oooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooo003ooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo02?ooooo000Qooooo`05o`000?ooooooooooooooool00?l03oooool00ooo
003o003oooooo`0Looooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oool00?ooool03oooool00ol0
0?ooooooooooo`0Kooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08oooool0027o
oooo00Go0000ooooooooooooooooo`00o`0?ooooo`03ool00?l00?oooooo01cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool07?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00oooooooooooo01cooooo00?oo`00o`00
ooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Rooooo`008Oooool01Ol0003ooooooooooooooooo003o
00oooooo00?oo`00o`00ooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooo003ooooo
00kooooo00?o003oooooooooool07?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
02;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`05o`000?ooooooooooooooool00?l04?ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0Mooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool08_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`05o`000?oo
ooooooooooooool00?l03oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool08_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Rooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`000003ooooool00?oooooo00ko
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;o
oooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00Go0000ooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`0Rooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo003o00oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo003ooooo02;ooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool07_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03?ooool00ooo003o003oooooo`0N
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oool00?ooool08_ooool0027ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o003oool0
0?ooool03?ooool00ooo003o003oooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oool0
0?ooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01kooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07Oooool00ol00?ooo`00ooooo`0Rooooo`008Oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooo`00ooooo`0<ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`0Oooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03
o`00oooo003ooooo02;ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo003ooooo00cooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
8Oooool0027ooooo0ol00002ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07_oo
ool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00[ooooo00?o003oool00?ooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooo003ooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oo
oooo00?o003oool00?ooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027o
oooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oool00?ooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00
ooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o
003oool00?ooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo00_ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooo`00ooooo`0;
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo01oooooo00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo00[ooooo00?o003oool0
0?ooool08?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool07oooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool08?ooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Qooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`00
8Oooool3o`0000?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Wooooo00?o003oool00?ooool08Oooool00ol00?ooo`00ooooo`09ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool08?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooo003ooooo00Wooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo027ooooo00?o003oool00?ooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol0
0?ooo`00ooooo`09ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool0027o
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool08Oooool00ol00?ooo`00ooooo`09ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo003ooooo00Wo
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooo003ooooo00Sooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oool00?ooool02?ooool00ooo003o003o
ooooo`0Rooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool08?ooool0027ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0P
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oool0
0?ooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08_ooool00ol00?ooo`00ooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01oooooo000Qooooo`?o
00001?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo003ooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02;ooooo00?o003oool00?oo
ool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo01oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02?ooooo00?o003oool00?ooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool07ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oo
oooo02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool09?ooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo02Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo003ooooo00Ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Co
oooo00?o003oool00?ooool07oooool0027ooooo00?o0000ooooooooool01_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooo`00
ooooo`0Oooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo01kooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ooo003o003oooooo`0V
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Gooooo00?o003oool00?ooool07_ooool0027ooooo00?o0000oooo
ooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0Vooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo02Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o003oool0
0?ooool09_ooool00ol00?ooo`00ooooo`0Nooooo`008Oooool3o`0000Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00oooo
ool09_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool00oooool00ooo003o003oooooo`0Vooooo`03ool00?l00?oooooo00Cooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo003ooooo02Kooooo00?o003oool00?oo
ool07_ooool0027ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`03ooooo`03ool0
0?l00?oooooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Mooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01gooooo000Qooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00;ooooo00?o003oool00?ooool0:?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool07Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0
0?ooo`00ooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ooo
003o003oooooo`0Xooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Xooooo`06o`00oooooooooooooooooooo003o003o:Oooool00ooo003o003ooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0:_oo
ool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Xooooo`05o`00ooooooooooooooooool00?l0:_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo02Sooooo00Go003oooooooooooooooooo`00o`0[ooooo`03
o`00oooooooooooo01cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`00ooooooooooooooooool00?l0:oooool01Ol00?oooooooooooooooooo003o
02_ooooo00Co003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o02_ooooo00Co
003ooooooooooooo003o:oooool01Ol00?oooooooooooooooooo003o02_ooooo00?o003ooooooooo
ool07?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`00
ooooooooooooo`00ob_ooooo0_l00?l00ooooooo003oo`00o`0[ooooo`04o`00ooooooooooooo`00
ob_ooooo00Go003oooooooooooooooooo`00o`0[ooooo`04o`00ooooooooooooo`00ob_ooooo0_l0
0?l2ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool07?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`00oooo003o003oo`00obcooooo00?o
003oooooool00?l0;?ooool3o`00obgooooo00?o003oooooool00?l0;?ooool4o`00obcooooo00?o
003oool00?l00?l0;Oooool00ol00?ooooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`04
ooooo`?o00002Oooool2o`00obgooooo0_l00?l^ooooo`;o003o;_ooool00ol00?ooooooooooo`0/
ooooo`;o003o;_ooool2o`00obgooooo0_l00?lLooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`0?ooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o
<S8bolc<c:3ooooo002Uooooo`05o`000?ooooooooooooooool000000_ooool6o`0000cooooo00?o
0000ooooooooool00_ooool01Ol@413o^[ZjoooooomgMgOo<S8b0:3ooooo000Pooooo`03okZj^_lb
<S;ooooo08;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0W_ooool0027ooooo00?o0000ooooooooool0POooool01Ol0003ooooooooo
oooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool0
Woooool001oooooo00GoV9RHoa0@4?l0003o0000ojVYZ@21ooooo`05o`000?n7QhOoooooojVYZOl0
00005?ooool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o^[Zj0:3ooooo000Oooooo`06o`00
0?nYZJWoEEEEoiRHV?mEEEGo^[ZjOoooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`2Oooooo`007oooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@49Wooooo00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj
^[[o00000:3ooooo000Oooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEE
EOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Pooooo`007oooool01oo^k^ko0000
ooooool0003oooooofIVI_n7QhL0oooooom3ooooo`007oooool01?mVIVKoV9RHoooooolb<S82okZj
^P03o`000?oooooooooo0?oooooo@Oooool002;ooooo00?oIVIVohN7Qoooool0oooooom4ooooo`00
8_ooool00onYZJWoA4A4ooooo`3oooooodCooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08611, \
0.0066032, 0.0136036}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.02846 .39194 L
.03279 .46181 L
.03793 .53095 L
.04037 .55688 L
.04262 .57625 L
.04376 .58386 L
.04498 .59034 L
.0462 .59538 L
.04689 .59758 L
.04754 .5992 L
.04871 .60105 L
.04978 .60152 L
.05102 .6006 L
.0522 .59826 L
.05343 .59378 L
.05474 .58711 L
.0571 .57093 L
.0599 .54513 L
.06244 .51593 L
.08269 .18138 L
.08823 .10121 L
.09102 .0689 L
.09263 .054 L
.09409 .04243 L
.09534 .03408 L
.09671 .0267 L
.09746 .02343 L
.09815 .0209 L
.09885 .01883 L
.09951 .01735 L
.10068 .01602 L
.10197 .01675 L
.10323 .01912 L
.10393 .02115 L
.10458 .02346 L
.10691 .03521 L
.10822 .04407 L
.10941 .05351 L
.1139 .10226 L
.11915 .17757 L
.1241 .26154 L
.13408 .43515 L
.13954 .51482 L
.14221 .54551 L
.14465 .56844 L
.14577 .57725 L
.147 .58548 L
.14818 .59197 L
.14924 .59608 L
Mistroke
.15048 .59938 L
.1518 .60117 L
.15303 .60124 L
.15418 .59992 L
.15545 .59689 L
.1561 .59473 L
.1568 .59189 L
.15805 .5855 L
.15922 .57765 L
.16185 .55525 L
.16466 .52471 L
.17432 .37847 L
.18311 .22345 L
.18794 .14591 L
.19058 .10926 L
.19305 .07927 L
.19533 .056 L
.19742 .03945 L
.19853 .03256 L
.19974 .02639 L
.20096 .02164 L
.20224 .01824 L
.20291 .01712 L
.20364 .01643 L
.20433 .01628 L
.20497 .01658 L
.20617 .01859 L
.20745 .02278 L
.20882 .02911 L
.21009 .03669 L
.213 .05961 L
.21553 .08564 L
.21783 .11472 L
.22301 .19238 L
.23225 .35389 L
.23731 .43955 L
.24207 .50924 L
.24474 .54136 L
.24719 .56492 L
.24991 .58479 L
.25134 .59242 L
.25213 .59575 L
.25285 .59824 L
.25404 .60091 L
.25531 .60171 L
.25649 .60095 L
.25761 .59892 L
.25891 .59498 L
.26011 .58985 L
.26143 .58259 L
Mistroke
.26282 .57307 L
.26535 .55011 L
.26774 .52314 L
.27224 .46145 L
.28237 .28824 L
.28732 .20252 L
.29198 .13001 L
.29616 .0778 L
.29831 .0562 L
.30068 .03724 L
.30194 .02963 L
.30311 .02432 L
.30435 .0202 L
.30504 .01858 L
.30568 .01752 L
.30681 .01664 L
.30804 .01716 L
.3092 .01907 L
.31027 .02207 L
.31149 .02718 L
.31263 .03369 L
.31523 .05319 L
.31777 .07799 L
.3205 .1105 L
.33889 .41728 L
.34352 .48854 L
.34847 .54953 L
.34994 .56347 L
.35132 .57449 L
.35266 .58351 L
.3539 .59029 L
.35508 .59534 L
.35632 .59918 L
.35757 .60144 L
.35828 .60201 L
.35895 .60199 L
.36025 .59999 L
.36099 .59809 L
.36168 .59582 L
.36293 .59045 L
.36427 .58305 L
.36682 .56423 L
.36912 .5418 L
.37476 .46791 L
.38005 .38187 L
.38985 .20967 L
.3952 .12651 L
.39781 .0924 L
.40018 .06659 L
.40223 .04818 L
Mistroke
.40445 .03249 L
.40566 .0259 L
.40679 .0212 L
.40787 .01846 L
.40901 .01687 L
.41015 .01661 L
.41138 .01782 L
.41254 .02037 L
.41361 .0239 L
.41485 .02944 L
.4162 .03724 L
.41867 .05726 L
.42398 .11783 L
.42899 .19327 L
.43834 .35672 L
.44323 .43977 L
.44841 .51437 L
.45111 .54585 L
.45255 .56012 L
.45408 .57341 L
.4555 .58315 L
.45678 .59013 L
.45808 .59549 L
.45931 .59903 L
.46044 .60095 L
.46167 .60155 L
.46283 .6007 L
.46389 .5987 L
.46507 .59457 L
.46636 .58831 L
.46895 .57079 L
.47152 .54744 L
.47426 .51616 L
.47921 .44492 L
.48879 .27946 L
.49762 .13432 L
.5026 .07168 L
.5051 .04877 L
.50652 .03834 L
.50786 .03018 L
.5093 .02336 L
.51062 .01895 L
.51136 .01727 L
.51204 .01626 L
.5128 .01609 L
.51359 .01656 L
.51429 .01751 L
.51504 .0191 L
.51576 .02112 L
.51641 .02343 L
Mistroke
.51765 .02898 L
.51896 .03646 L
.52136 .0544 L
.52393 .08057 L
.52857 .14084 L
.53911 .318 L
.5493 .4869 L
.5521 .52356 L
.55506 .55565 L
.55759 .57711 L
.55903 .58666 L
.55973 .59057 L
.56038 .59345 L
.56156 .59748 L
.56285 .60027 L
.5641 .60137 L
.5648 .60128 L
.56544 .60077 L
.56658 .59882 L
.56782 .5952 L
.56899 .59036 L
.57007 .58431 L
.57249 .56618 L
.57515 .54021 L
.58051 .47063 L
.59135 .2867 L
.59668 .19437 L
.60162 .11984 L
.60609 .06644 L
.60835 .04607 L
.60965 .03694 L
.61084 .02999 L
.61206 .02436 L
.61334 .01999 L
.61462 .01726 L
.61535 .01646 L
.61602 .01621 L
.61725 .01697 L
.61837 .01968 L
.61967 .02441 L
.62089 .03041 L
.62313 .04515 L
.62559 .06669 L
.63058 .12727 L
.63953 .2726 L
.64494 .36893 L
.65009 .45428 L
.6551 .52444 L
.65754 .55117 L
.65975 .57085 L
Mistroke
.66087 .57909 L
.66207 .58668 L
.66311 .59212 L
.66425 .59684 L
.66546 .6002 L
.66674 .60158 L
.66793 .60133 L
.66904 .5998 L
.67035 .59637 L
.6716 .59154 L
.67271 .5859 L
.67393 .57838 L
.67665 .55545 L
.67917 .52813 L
.68929 .37544 L
.70005 .18782 L
.70462 .11912 L
.70942 .06305 L
.71194 .04134 L
.71337 .03189 L
.71469 .02541 L
.71592 .02101 L
.71703 .01831 L
.71831 .01675 L
.71953 .01682 L
.72058 .0181 L
.72174 .02083 L
.72296 .02539 L
.72409 .03143 L
.72612 .04534 L
.7283 .06449 L
.73327 .12318 L
.73781 .19242 L
.74702 .35338 L
.75208 .43923 L
.75684 .50856 L
.75955 .54143 L
.76249 .5693 L
.76378 .57887 L
.76515 .58724 L
.76632 .59295 L
.7676 .59767 L
.7689 .60077 L
.77009 .60207 L
.77075 .60194 L
.77146 .60111 L
.77276 .59824 L
.77398 .59401 L
.77526 .58791 L
.77758 .57298 L
Mistroke
.78009 .55106 L
.78248 .52407 L
.78698 .46222 L
.79709 .28964 L
.80203 .20403 L
.80668 .13153 L
.81086 .07868 L
.81302 .05718 L
.81539 .03827 L
.81656 .03086 L
.81781 .02442 L
.8185 .02168 L
.81913 .01983 L
.82037 .01742 L
.8215 .01659 L
.82273 .01716 L
.82389 .0191 L
.82496 .02211 L
.82617 .0269 L
.82731 .03274 L
.82856 .041 L
.82991 .05188 L
.83517 .10925 L
.83984 .1773 L
.84476 .26054 L
.85355 .41486 L
.85846 .49053 L
.86309 .54727 L
.86565 .57123 L
.86709 .58158 L
.86842 .58911 L
.86955 .59409 L
.87078 .59813 L
.87207 .60071 L
.87328 .6016 L
.87441 .60107 L
.87565 .59897 L
.87682 .5949 L
.8779 .58985 L
.87995 .57719 L
.88213 .55942 L
.88712 .5028 L
.89164 .43551 L
.90101 .27265 L
.90613 .18522 L
.91091 .11429 L
.91361 .08063 L
.91608 .05607 L
.91882 .03533 L
.92033 .02693 L
Mistroke
.92101 .02388 L
.92176 .02105 L
.92296 .01769 L
.92424 .01618 L
.92542 .01661 L
.92654 .01833 L
.92784 .02195 L
.92904 .02677 L
.93035 .03367 L
.93173 .04272 L
.93431 .06498 L
.93674 .09191 L
.94129 .1538 L
.95149 .32771 L
.95614 .40851 L
.96106 .4857 L
.96525 .53869 L
.96748 .56109 L
.96987 .58028 L
.97158 .59067 L
.97314 .59755 L
.97389 .59994 L
.9747 .60183 L
.97548 .60292 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.02846 .39136 L
.03279 .46229 L
.03793 .53242 L
.04037 .55833 L
.04262 .57737 L
.04374 .58502 L
.04498 .59194 L
.04622 .59727 L
.04754 .60111 L
.0487 .60292 L
.04995 .60323 L
.05112 .60197 L
.0522 .59949 L
.0535 .59481 L
.05471 .58885 L
.05745 .56977 L
.05987 .54688 L
.06244 .5168 L
.07287 .35237 L
.07835 .25439 L
.08414 .15767 L
.08922 .08794 L
.0921 .05737 L
.09348 .04542 L
.09479 .03582 L
.09597 .02863 L
.09726 .02247 L
.09843 .01841 L
.09951 .01597 L
.10068 .01478 L
.10197 .0152 L
.10262 .0161 L
.10332 .01757 L
.10458 .02159 L
.10584 .02732 L
.10719 .0353 L
.10963 .0543 L
.11252 .08414 L
.11515 .11734 L
.12627 .30009 L
.1313 .38933 L
.13662 .47548 L
.14116 .53555 L
.14375 .56223 L
.14616 .58151 L
.14735 .58884 L
.14864 .59516 L
.14986 .59949 L
.15099 .60206 L
Mistroke
.15212 .60323 L
.15313 .60311 L
.15431 .60155 L
.15541 .59872 L
.15662 .5941 L
.1579 .58754 L
.16019 .5716 L
.16265 .54876 L
.16535 .51754 L
.17611 .34735 L
.18614 .17266 L
.19117 .10032 L
.19381 .06966 L
.19662 .04396 L
.1978 .03544 L
.19907 .02786 L
.1998 .02428 L
.20047 .02149 L
.20178 .0174 L
.20288 .01538 L
.2041 .01472 L
.20536 .01574 L
.20654 .01826 L
.2077 .02223 L
.20896 .02815 L
.21125 .0431 L
.21347 .06262 L
.21552 .08461 L
.2251 .22705 L
.23417 .38787 L
.23917 .46934 L
.24391 .53303 L
.24658 .56105 L
.24799 .57318 L
.24949 .58393 L
.25075 .59117 L
.25141 .59435 L
.25213 .59724 L
.2534 .60097 L
.25458 .60289 L
.25579 .60326 L
.25648 .60276 L
.25712 .60183 L
.25841 .5986 L
.25913 .59601 L
.25979 .59317 L
.26224 .57855 L
.26456 .55919 L
.26918 .50619 L
.27427 .43004 L
Mistroke
.28455 .24946 L
.28914 .1721 L
.29407 .10098 L
.29646 .07294 L
.29873 .05094 L
.30077 .03539 L
.30185 .02884 L
.30299 .02325 L
.30363 .02074 L
.30433 .01848 L
.30555 .01579 L
.30624 .01499 L
.30698 .01472 L
.30768 .015 L
.30831 .01573 L
.30955 .0184 L
.31024 .02064 L
.31089 .02316 L
.31332 .03669 L
.31548 .0537 L
.31786 .07759 L
.32268 .14024 L
.33363 .32586 L
.33842 .40985 L
.34366 .49164 L
.34602 .52292 L
.34855 .5514 L
.35073 .57142 L
.35309 .58785 L
.35449 .59484 L
.35577 .59945 L
.357 .6022 L
.3583 .60331 L
.35946 .60274 L
.36055 .60087 L
.36174 .59734 L
.36302 .59184 L
.36441 .58393 L
.3657 .57484 L
.36862 .54827 L
.37392 .48127 L
.38388 .31418 L
.38898 .22383 L
.39449 .13571 L
.39702 .10119 L
.39969 .07016 L
.40199 .0484 L
.40326 .03861 L
.40446 .03084 L
.40561 .02477 L
Mistroke
.40687 .01977 L
.40801 .01669 L
.40906 .01511 L
.41005 .01473 L
.41114 .01554 L
.41228 .01779 L
.41335 .02117 L
.4146 .0267 L
.4158 .0335 L
.41804 .05018 L
.42045 .07352 L
.42308 .10481 L
.43405 .2804 L
.43944 .37644 L
.44439 .45868 L
.44882 .52085 L
.45116 .54781 L
.45367 .57129 L
.45499 .58119 L
.4562 .58867 L
.45741 .59468 L
.45856 .59893 L
.45984 .602 L
.46103 .60325 L
.46233 .60283 L
.46299 .60192 L
.46372 .60036 L
.46489 .59661 L
.46618 .59082 L
.46753 .58291 L
.46878 .57389 L
.47342 .52747 L
.47848 .4572 L
.48389 .36682 L
.49375 .19341 L
.49807 .12677 L
.50283 .0682 L
.5054 .04475 L
.50781 .02866 L
.50913 .02234 L
.51034 .0182 L
.51101 .0166 L
.51174 .01541 L
.51243 .01482 L
.51307 .01474 L
.51377 .01516 L
.51452 .01621 L
.51524 .01778 L
.51589 .0197 L
.51713 .02462 L
Mistroke
.51845 .03159 L
.52118 .05173 L
.52417 .08197 L
.52921 .14923 L
.5346 .23765 L
.54432 .40951 L
.54927 .48718 L
.55451 .55187 L
.55725 .57613 L
.55881 .58665 L
.56027 .59424 L
.56092 .5969 L
.56161 .59921 L
.56283 .60206 L
.56415 .6033 L
.5649 .60315 L
.56559 .60248 L
.56685 .5999 L
.56756 .59768 L
.56822 .59516 L
.56942 .58933 L
.5707 .58153 L
.5729 .56413 L
.57533 .5397 L
.5807 .46858 L
.58572 .38656 L
.59615 .20266 L
.60128 .12326 L
.60354 .09365 L
.60604 .06571 L
.60811 .04679 L
.61034 .03107 L
.61157 .0246 L
.6127 .02007 L
.61378 .01702 L
.61492 .01517 L
.61607 .01475 L
.61731 .01591 L
.61847 .01853 L
.61953 .02219 L
.62078 .02803 L
.62213 .03619 L
.62458 .05573 L
.62946 .1108 L
.63403 .1783 L
.64443 .36008 L
.64962 .4479 L
.65456 .51865 L
.65728 .54991 L
.65872 .5638 L
Mistroke
.66025 .57644 L
.66167 .58605 L
.66295 .59298 L
.66424 .59818 L
.66546 .60144 L
.66662 .60306 L
.66787 .60315 L
.66904 .60167 L
.67012 .59902 L
.67137 .59432 L
.67274 .58731 L
.67523 .56964 L
.67783 .54478 L
.68059 .51191 L
.68554 .43918 L
.69518 .27084 L
.70402 .12642 L
.70858 .06998 L
.71088 .04834 L
.71339 .03054 L
.71472 .02376 L
.71592 .01921 L
.71659 .01736 L
.71731 .01591 L
.71863 .01473 L
.71986 .01534 L
.72116 .01778 L
.72227 .02133 L
.72349 .02676 L
.72472 .03374 L
.72587 .04179 L
.72805 .06045 L
.73294 .11778 L
.74178 .25978 L
.75139 .42867 L
.75667 .50758 L
.75925 .53925 L
.76163 .56332 L
.76389 .58127 L
.76502 .58836 L
.76627 .59459 L
.76752 .59919 L
.76823 .60103 L
.76887 .60224 L
.77011 .6033 L
.77128 .60276 L
.77234 .60097 L
.77346 .59775 L
.77442 .59393 L
.77548 .58859 L
Mistroke
.77783 .57259 L
.78003 .55266 L
.78498 .49245 L
.7904 .40789 L
.80026 .2336 L
.8049 .15704 L
.80986 .08889 L
.81226 .06267 L
.81453 .0428 L
.81657 .0293 L
.81772 .02358 L
.81878 .01955 L
.82004 .01633 L
.82123 .01486 L
.8223 .01488 L
.82347 .01633 L
.82473 .01958 L
.82537 .02188 L
.82608 .02493 L
.8285 .03932 L
.83075 .05802 L
.83318 .08348 L
.83758 .14172 L
.84744 .30819 L
.85266 .40035 L
.85824 .48851 L
.86103 .52546 L
.86367 .55463 L
.86604 .57542 L
.86726 .58401 L
.86861 .59169 L
.86987 .59714 L
.87105 .60071 L
.87229 .60283 L
.87299 .60329 L
.87363 .60323 L
.87476 .60203 L
.876 .59911 L
.87717 .59483 L
.87826 .58956 L
.88102 .57068 L
.88362 .54613 L
.88847 .48491 L
.89935 .30213 L
.90913 .13801 L
.91405 .07479 L
.91685 .04796 L
.9181 .03837 L
.91945 .02973 L
.9207 .02349 L
Mistroke
.92185 .01918 L
.92295 .01641 L
.92412 .0149 L
.92516 .01483 L
.92614 .01584 L
.92722 .01815 L
.92837 .02204 L
.92954 .02738 L
.93081 .03484 L
.93336 .05479 L
.93793 .10543 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`;o003o7_ooool2o`00oakooooo
0_l00?lOooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool07Oooool2o`00oakooooo
0_l00?lNooooo`;o003o7oooool00ol00?ooooooooooo`0Zooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo0_l00?lNooooo`;o003o7_ooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooo003o003o01gooooo0ol00?lNooooo`;o003o7Oooool3o`00oakooooo0_l0
0?lNooooo`;o003o;?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`04o`00oooo003oooooo`00oagooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00
o`0Mooooo`03o`00oooooooo003o01kooooo0ol00?lMooooo`03o`00oooooooo003o02_ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool0
0?lLooooo`04o`00ooooooooooooo`00oagooooo00?o003oooooool00?l07Oooool00ol00?oooooo
o`00o`0Mooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l07Oooool01?l00?oooooo
o`00oooo000Looooo`04o`00ooooooooooooo`00oacooooo00Co003oool00?oooooo003o:oooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`04o`00oooooooooooo
o`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooo`00ooooool00?lMooooo`03o`00
oooooooo003o01gooooo00Co003oooooool00?ooo`007?ooool01?l00?ooooooool00?l00?lLoooo
o`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?oooooooooo
ool00?l[ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00Co
003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00
oacooooo00Co003oool00?oooooo003o7Oooool01?l00?ooooooooooool00?lLooooo`04o`00oooo
ooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lLoooo
o`04o`00ooooooooooooo`00ob_ooooo000Qooooo`03o`000?oooooooooo01Cooooo00Co003ooooo
oooooooo003o7?ooool01?l00?ooooooooooool00?lLooooo`05o`00ooooooooooooooooool00?l0
6oooool01Ol00?oooooooooooooooooo003o01cooooo00Co003ooooooooooooo003o7?ooool01?l0
0?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Go003ooooooooooooooooo
o`00o`0Kooooo`05o`00ooooooooooooool00?l00?l0:_ooool0027ooooo00?o0000ooooooooool0
5?ooool01?l00?ooooooooooool00?lLooooo`05o`00ooooooooooooooooool00?l06oooool01Ol0
0?oooooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00oooo
ooooooooooooool00?l07?ooool01?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00
oacooooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00ooooooooooooool00?l00?l0:_oo
ool0027ooooo00?o0000ooooooooool04oooool01Ooo003o003ooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`0Kooooo`05o`00ooooooooooooooooool00?l06oooool01Ol00?oo
oooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`06o`00oooooooo
ooooooooool00?ooo`006oooool01Ol00?oooooooooooooooooo003o01[ooooo00?o003oool00?oo
ool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l0:_ooool0027o
oooo0ol0000Cooooo`05o`00ooooooooooooooooool00?l06oooool00ol00?ooo`00ooooo`02oooo
o`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Ioooo
o`05o`00ooooooooooooooooool00?l06oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01Sooooo00Ko003oooooooooooooooooo`00oooo000Jooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo01Sooooo
00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooo`00oooo
o`02ooooo`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool06Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01Sooooo00Ko003oooooooooooooooooo`00oooo000Jooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`00
8Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool0
6Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool0
0ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool05oooool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo
01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`0Booooo`03ool00?l00?oooooo00?ooooo00?o003oooooooooool05oooool00ol00?oo
o`00ooooo`03ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l00?oooooo00?ooooo
00?o003oooooooooool05oooool00ol00?ooo`00ooooo`03ooooo`03ool00?l00?oooooo01Sooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`03ooooo`03ool00?l00?oooooo01Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ooo003o003ooooo
o`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Xooooo`008Oooool3o`0001?ooooo00?o003oooooooooool00_ooool00ooo003o003oooooo`0G
ooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool06?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03ool00?l00?oooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03
o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
5_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oo
oooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Oooooo000Qooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0Fooooo`03o`00oooo003ooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
02Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?oo
o`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooo003ooooo01Kooooo00?o003oooooooooool01?ooool00ooo003o
003oooooo`0Fooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oo
o`00ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool01Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo02Kooooo000Qooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo003ooooo00Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo
00?oo`00o`00ooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Kooooo
000Qooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooo`00oooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo02Kooooo000Qooooo`?o00004_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09_ooool0027ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00
ooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool09_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo00Gooooo00?oo`00o`00ooooool05Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooo003ooooo00Kooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Cooooo00?o003oool00?ooool0
1_ooool00ol00?ooo`00ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool0
5Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
9_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool05?ooool00ooo003o003oooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00?o003oool00?ooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Gooooo00?oo`00o`00ooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09_ooool0027ooooo00?o0000ooooooooool04Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oool00?ooool01oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool0
027ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Kooooo00?o003oool00?ooool09_ooool0027ooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool0027ooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool09Oooool0027ooooo0ol0000Aooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00Kooooo00?oo`00o`00ooooool04oooool00ol00?ooo`00ooooo`07ooooo`03
o`00oooooooooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Uooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo01Cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
1oooool00ooo003o003oooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool01oooool00ooo003o003oooooo`0Dooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool04_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo
003ooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Uooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
1oooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4_ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oool00?ooool01oooool00ol00?ooo`00
ooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool04oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oool00?ooool01oooool00ol00?ooo`00
ooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool09Oooool000Go00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooo`00
ooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooo003ooooo01?ooooo00?oo`00o`00ooooool02?ooool00ol00?oooooo
ooooo`0Uooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool3o`00013ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooo003ooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Oooooo00?o003oool00?ooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02Gooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool09?ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooo`00ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool09?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o
003oooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo
00?o003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Tooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo01;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003o
ool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?oo`00
o`00ooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooo003ooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Toooo
o`008Oooool3o`0000oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0Booooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Sooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Booooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00Wooooo00?o003oool00?ooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooo`00ooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oool00?ooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oool00?ooool04_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Aooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
013ooooo00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oo
o`00ooooo`0Aooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool02_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo
00?o003oool00?ooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo017ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool04?ooool00ooo003o003oooooo`0:ooooo`03ool00?l00?oooooo02Cooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool02_ooool00ol00?oooooooooo
o`0@ooooo`03ool00?l00?oooooo00[ooooo00?o003oool00?ooool04Oooool00ol00?oooooooooo
o`09ooooo`03ool00?l00?oooooo017ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ooo003o003ooooo
o`0:ooooo`03ool00?l00?oooooo02Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003o
ool00?ooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00[ooooo00?o003o
ool00?ooool04Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo017ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool04?ooool00ooo003o003oooooo`0:ooooo`03ool00?l00?oooooo02Cooooo000Qoooo
o`?o00003oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00
ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00[ooooo00?oo`00o`00
ooooool09?ooool0027ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0
3oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
4?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool0
4Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
8oooool0027ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooo`00ooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool0
0ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0
027ooooo00?o0000ooooooooool03_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?oo
o`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo
00?o0000ooooooooool03_ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool08oooool0027ooooo00?o0000
ooooooooool03_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool02_ooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool08oooool0027ooooo0ol0000>ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo013ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03
ool00?l00?oooooo00oooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0:ooooo`03
ool00?l00?oooooo013ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00oooooo00?oo`00o`00ooooool0
3?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooo
oooooooo00_ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`0;ooooo`03ool00?l0
0?oooooo00oooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`0<ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool03oooool0
0ol00?ooooooooooo`0;ooooo`03ool00?l00?oooooo00oooooo00?oo`00o`00ooooool03?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00_ooooo00Oo003oool00?o^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`03o`00ool0
003o000000;o00001?ooool01om4A4Co0000o`000?lb<S;ogMgMool00?l00?l04?ooool02?oo003o
003oooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@03o`00oooooooooooo00;ooooo00Go
A4A4o`000?l0003o<S8bomgMg@08ooooo`03o`00oooooooooooo00[ooooo00Gok^k^o`00ool0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o003oooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo1?l000000ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00[ooooo0_l000000ol00?oo0000oa0@4004oooo
o`;o8B4Q1?ooool4o`000003o`00oooooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`00oooooooooooo00kooooo00Go0000o`00ool0003o0000oa0@4004ooooo`;o8B4Q1Ooo
ool01Ol00?oo0000o`000?lb<S;ogMgM023ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
003oooooooooool03?ooool01_l00?ooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
o`00oolQ8B7ok^k^oooooom4A4@01oooool01?mgMgOo<S8booooool00?l@ooooo`08ool00?l00?oo
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q00?o003oooooooooool01Oooool00omgMgOo
<S8booooo`06ooooo`03o`00oooooooooooo00_ooooo00GoMgMgo`00ooooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGo003oooooo`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
oooo003o00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00ool0
003ooooo00Gooooo0_lQ8B45ooooo`05o`00ooooooooooooogMgMolb<S808?ooool0027ooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00ool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01?l00?ooV9RHob4Q8Oo^k^h9ooooo`03o`000?oooooo003o013ooooo
00Coo`00o`00oooooooo410@0oooool00ol@413oooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`05oa0@4?l00?oooooooooo
ool@41003Oooool00onYZJWo003oooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`04oiRHV?lQ8B7ok^k^o`00o`Sooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00ool0003ooooo00cooooo00Go
003oooooooooooooooooo`00000Pooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00oooo
ooooV9RHob4Q8Oo^k^h01oooool01?mgMgOo<S8booooool00?lAooooo`03o`00oooooooo000000?o
oooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03ogMgMolb<S;ooooo00Ko
oooo00?o003oooooooooool02oooool01Ol0003o003ooooooooooooo000000kooooo00?o003ooooo
ooooool01_ooool00omgMgOo<S8booooo`03ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool02Oooool01?l0003oooooooooool00?l@ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00onHV9So8B4Qo`00o`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooo`00000=ooooo`05o`00ooooooooooooogMgMolb<S808?oo
ool0027ooooo0ol0000>ooooo`03o`00oooooooooooo00cooooo00?o003oo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`00ooooooooooooogMgMomVIVH01?ooool01ol0003o8B4Qo`00
0?lb<S;oc<c<ooooool00?l04?ooool01?l00?ooooooooooool00003ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooooooool00_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00?o003o
ooooooooool02oooool01Ol0003o003ooooooooooooo000000kooooo00?o003oolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`09ooooo`04o`000?ooooooooooo`00oa3ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0=ooooo`03ogMgMol00?oooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`00oooooooooooo00kooooo00?o003oooooool000003Oooool01Ol00?oo8B4Qo`000?lb<S;o
c<c<023ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool03?ooool00ol0
0?oo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go003oooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool03_ooool01?l00?ooooooooooool@
4103ooooo`03oa0@4?oooooooooo00Gooooo00?o003oool00?ooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo00_ooooo00Go410@o`00oooooooooooooa0@400=ooooo`03o`00
oonYZJWoMgMg00Cooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Wooooo00Co0000oooooooooooo003o4?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00kooooo00?o003oooooool000003Oooool00ol00?ooooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00Ko003oogMgMonHV9So
oooooiRHV?mgMgL;ooooo`05o`00oonj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00kooooo00So003oooooooooooooMgMgoiRHV?ooooooV9RHogMgM`Oo
oooo00?o003oool00?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00_o
oooo00GoMgMgo`00ooooooooV9RHogMgM`0;ooooo`05oa0@4?oooooo003ooooooolb<S801?ooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Oooool0
1?l0003oooooooooool00?l@ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02_oo
ool01Ol0003o^[ZjoooooonHV9So003o00Cooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooo000000gooooo00?o003oooooooooool08_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`06o`00oooo003o<S8bo`000?lb<S;o
k^k^2oooool01Ol00?oo410@o`000?lQ8B7oc<c<00Cooooo1?l00002ooooo`03o`00oooooooooooo
00kooooo00So003oooooooooooook^k^oc8b<_l0003o<S8bonk^kPOooooo00?o003oool00?ooool0
0_ooool4o`0000Sooooo00?o003oooooooooool02oooool01Oo^k^ko003oo`000?lb<S;ok^k^00_o
oooo0_l000000ol00?oo0000o`000004ooooo`Co00001Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Oooooo00?oEEEEofIVI_l000000_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00[ooooo00?oEEEEofIVI_l00?l03?ooool01OnHV9So410@o`000?lQ8B7o003o
00Cooooo1?l00006ooooo`03ool00?l00?oooooo00kooooo00?o003oofIVI_l000003Oooool01?l0
0?oo0000o`000?l0000Qooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo
00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo
00kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool03_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool03Oooool00ol00?oo
ooooooooo`0=ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03?ooool00ooo003o
ooooo`00o`0Sooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00cooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00cooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo
00?o003oool00?ooool03Oooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo00kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo
00?o003oooooooooool03?ooool00ooo003oooooo`00o`0Iooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooo`00oooo
o`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03?ooool00ol00?ooo`00oooo
o`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?ooo`00oooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0<ooooo`03ool00?oooooo003o01Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3?ooool00ooo003oooooo`00o`0Jooooo`04omgMgOl0003o410@olc<c0Gooooo000Jooooo`Oo0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00oooo003o000000ko0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000>o`000003o`00ool0003o000000go0000
00?o003oo`000?l000003Ol000000ol00?oo0000o`00000=o`000003o`00ool0003o000000co0000
00?oo`00o`000?l00?l03_l0000<ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00009ooooo`05
o`000?ooooooooooo`00oooo00001?ooool00ol0003oooooooooo`07ooooo`03o`000?l00?oooooo
00Kooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo003o
00Oooooo00?o0000ooooooooool01Oooool00ol00?oo0000ooooo`07ooooo`03o`000?oooooooooo
00?ooooo00Go003oooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`00o`Kooooo00?o
0000ooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Co
003ooooooooooooo00002Oooool01?l0003oooooooooool00?l5ooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool01_ooool00ol0003oooooooooo`04ooooo`04ool00?l00?ooooooo`00
00Sooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool00?l01_ooool00ol0003oooooooooo`06ooooo`03o`00ool0003ooooo
00Oooooo00?o0000ooooooooool00_ooool00ooo003oooooo`00o`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
003o003oooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02oooool00ol0
003oooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool01?l0
003oooooooooool00?l?ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
1?l0003oooooooooool00?l?ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?oo`00o`00ooooool06?oo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`0Rooooo`008Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool03Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ooo
003o003oooooo`0Rooooo`008Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00co
oooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo00go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00go
oooo00?oo`00o`00ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool03Oooool00ooo003o003oooooo`0Rooooo`008Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol00?oooooo
ooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool03Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool03_ooool00ooo003o003o
ooooo`0Rooooo`008Oooool00ol0003o003oooooo`0=ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
o`00o`00ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00gooooo00?o
o`00o`00ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o
003oool00?ooool03_ooool00ooo003o003oooooo`0Rooooo`008Oooool00ol0003o003oooooo`0=
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`0<
ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ooo003oooooo`00o`0R
ooooo`008Oooool00ol0003o003oo`00000=ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00
ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool03_ooool00ooo003oooooo`00o`0Rooooo`008Oooool00ol0003o003oooooo`0=ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03
ool00?l00?oooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool00ooo003oooooo`00o`0Rooooo`00
8Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3_ooool00ooo003oooooo`00o`0Rooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l0
0?oooooo00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool0
0ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool03?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo
00oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o
003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o
003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`0Pooooo`008Oooool00ol0003o003oooooo`0<ooooo`03ool00?l00?oooooo00oooooo
00?o003oooooooooool02oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo
00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003ooooo
o`0<ooooo`03ool00?l00?oooooo00oooooo00?o003oooooooooool02oooool00ooo003o003ooooo
o`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o003ooooo
o`0?ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0Pooooo`008Oooool00ol0003o003oo`00000<ooooo`03ool00?l00?oooooo00oooooo00?o003o
ooooooooool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool02_ooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003o003oool0000=oooo
o`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0?oooo
o`03ool00?l00?oooooo00cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`0?oooo
o`03ool00?l00?oooooo00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Poooo
o`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00oooo
ool02oooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool02_ooool00ooo003o003oooooo`0?ooooo`03ool00?l00?oooooo00_ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00
oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ooo003o003oooooo`0@ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`0@ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Ooo
ool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_oo
ool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooo
oooo00oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03oooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0
003oooooo`00o`0<ooooo`03o`00oooooooooooo00oooooo00?oo`00o`00ooooool02oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`0<ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003ooooo
o`00o`0<ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool02_ooool00ol00?ooo`00
ooooo`0Aooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Oooooo`008Oooool2o`000003o`00oooooooooooo00[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0@ooooo`03ool00?oooooo003o027ooooo000Qooooo`03o`000?oooooo
003o00cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo003o
oooo017ooooo00?o003oooooooooool02Oooool00ooo003o003oooooo`0Aooooo`03o`00oooooooo
oooo00Wooooo00?oo`00o`00ooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0@ooooo`03ool00?oooooo
003o027ooooo000Qooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02Oooool00ooo
003o003oooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0@ooooo`03ool00?oooooo003o027ooooo000Qooooo`03o`000?oooooo003o00co
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo003ooooo017o
oooo00?o003oooooooooool02Oooool00ooo003o003oooooo`0Aooooo`03o`00oooooooooooo00Wo
oooo00?oo`00o`00ooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo023o
oooo000Qooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooo003ooooo017ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool04_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Aooooo`03ool00?l00?oooooo023ooooo000Qooooo`03o`000?oooooo003o00cooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o
o`00o`00ooooool04Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?l00?oooooo023ooooo000Q
ooooo`03o`000?oooooo003o00_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0:
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0A
ooooo`03ool00?l00?oooooo023ooooo000Qooooo`03o`000?oooooo003o00_ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool04Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Aooooo`03ool00?oooooo003o023ooooo000Qooooo`03
o`000?oooooo003o00_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ooo003o003oooooo`0:ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?ooo`00ooooo`0Booooo`03
ool00?oooooo003o023ooooo000Qooooo`03o`000?oooooo003o00_ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4Oooool00ooo003o003oooooo`0:ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Booooo`03ool00?oooooo003o023ooooo000Qooooo`;o000000?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
o`00o`00ooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool0027ooooo00Co0000
oooooooooooo003o2_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool0027ooooo00Co0000
oooooooooooo003o2_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o
o`00ooooool00?l08?ooool0027ooooo00Co0000oooooooooooo003o2Oooool00ooo003o003ooooo
o`0Cooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03ool00?l00?oooooo01;ooooo00?o003oooooooooool02?ooool00ooo003o003ooooo
o`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01;ooooo00?oo`00ooooool00?l08?ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00Co0000oooooooooooo003o2Oooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo01;o
oooo00?o003oooooooooool02?ooool00ooo003o003oooooo`0Cooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;o
oooo00?oo`00ooooool00?l08?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`04o`000?ooooooooooo`00o`Wooooo00?oo`00o`00
ooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool02?ooool00ooo003o003oooooo`0Booooo`03o`00oooooooooooo00Sooooo00?oo`00o`00
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01kooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`00o`Wooooo00?oo`00o`00ooooool04oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01;ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo01kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`?o000000?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool07_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool01?l0003oooooooooool00?l9ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ooo003o003oooooo`0Cooooo`03ool0
0?l00?oooooo00Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Mooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00?l9ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00ooooool01oooool00ooo003o
003oooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Mooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool00?l9ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool01oooool00ooo003o003oooooo`0Cooooo`03ool00?l00?oooooo00Sooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`04o`000?ooooooooooo`00o`Wooooo00?o003oooooooooool04oooool0
0ooo003o003oooooo`07ooooo`03ool00?l00?oooooo01?ooooo00?oo`00o`00ooooool02?ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01;ooooo00?oo`00o`00ooooool01oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01gooooo000Qooooo`04o`000?oooooooooo
o`00o`Wooooo00?o003oooooooooool04oooool00ooo003o003oooooo`07ooooo`03ool00?l00?oo
oooo01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo01gooooo000Qooooo`04o`000?ooooooooooo`00o`Wooooo00?o003oooooooooool04oooool0
0ooo003o003oooooo`07ooooo`03ool00?l00?oooooo01Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01gooooo000Qooooo`05o`000?oooooooooo
o`00oooo00002?ooool00ol00?ooooooooooo`0Cooooo`03ool00?l00?oooooo00Oooooo00?oo`00
o`00ooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo01?ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0Dooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Mooooo`008Oooool3o`00
0003ooooool00?oooooo00Oooooo00?o003oooooooooool04oooool00ooo003o003oooooo`08oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01gooooo000Qooooo`05o`000?ooooooooooooooool00?l02?ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool07Oooool0027o
oooo00Go0000ooooooooooooooooo`00o`08ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?oo`00o`00
ooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`0Mooooo`008Oooool01Ol0003ooooooooooooooooo003o
00Sooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo
01Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`03ool00?oooooo003o
01oooooo000Qooooo`05o`000?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?o003oool00?ooool01oooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00Gooooo00?o003oool00?ooool05?ooool00ol00?ooooooooooo`06oooo
o`03ool00?l00?oooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Cooooo00?oo`00ooooool00?l07oooool0027ooooo00Go0000oooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol0
0?ooo`00ooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?oo`00o`00ooooool05Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05?ooool01?oo
003oooooooooool00?lNooooo`008Oooool01Ol0003ooooooooooooooooo003o00Oooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo003ooooo00Kooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool01_ooool00ooo003o003oooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Dooooo`04ool00?ooooooooooo`00oakooooo000Q
ooooo`05o`000?ooooooooooooooool00?l01oooool00ol00?ooooooooooo`0Eooooo`03ool00?l0
0?oooooo00Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Cooooo00Coo`00oooooooooooo003o7_ooool0027ooooo00Go0000oooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo01Gooooo00?oo`00o`00ooooool01_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05?ooool01?oo003ooooo
ooooool00?lNooooo`008Oooool3o`000003ooooool00?oooooo00Kooooo00?o003oool00?ooool0
5_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Dooooo`04ool00?ooooooooooo`00oakooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01Gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooo003ooooo01Gooooo00Coo`00oooooooooooo003o7_ooool0027ooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
5Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool0
5_ooool00ooo003oooooo`00o`0Nooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo00Cooooo00?oo`00o`00ooooool05_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
003ooooo00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03ool00?oo
oooo003o01kooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool01?ooool0
0ooo003o003oooooo`0Fooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oool00?ooool01Oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?oo`00ooooool00?l07_ooool0
027ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`04ooooo`03ool00?l00?oooooo
01Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo003ooooo
00Gooooo00?o003oooooooooool05Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool05_ooool00ooo003oooooo`00o`0Nooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03ool00?l00?oooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oo
o`00ooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool05_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01Gooooo00?o003oool00?ooool01Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooo003ooooo00Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Fooooo`03ool00?oooooo003o01kooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo01Kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo
00?oo`00ooooool00?l07_ooool0027ooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ooo003oooooo`00
o`0Nooooo`008Oooool3o`0000;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01Kooooo00Coo`00oooooooooooo003o7Oooool0027ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool05oooool00ooo003oooooo`00o`0Mooooo`008Oooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool01?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Joooo
o`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool05_ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oooooo01[ooooo00?o003ooooooooo
ool06oooool0027ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Fooooo`03ool0
0?l00?oooooo00?ooooo00?oo`00o`00ooooool06_ooool00ol00?ooooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Kooooo00?oo`00o`00ooooool00ooo
ool00ooo003o003oooooo`0Jooooo`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?o003oool00?ooool06?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oo
oooo01Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo
oooo00;ooooo00?oo`00o`00ooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol0
0?ooo`00ooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool06?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01Wooooo00Go003oooooooooooooooooo`00o`0K
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0K
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool00_ooool00ooo003o003oooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool06Oooool01Ol00?oooooooooooooooooo003o01_ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01_ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Sooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Iooooo`05o`00oooooooooooo
ooooool00?l06oooool01_l00?ooooooooooooooooooo`00o`00oa[ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
6oooool0027ooooo0ol00003ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06?oo
ool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool06Ooo
ool01Ol00?oooooooooooooooooo003o01_ooooo00Go003oooooooooooooooooo`00o`0Kooooo`06
o`00oooooooooooooooooooo003o003o6_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Hooooo`03ool00?l00?oooooo00;ooooo00?o003oooooooooool06?ooool00ol0
0?ooo`00ooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oool00?ooool00_ooool00ol0
0?ooooooooooo`0Iooooo`05o`00ooooooooooooooooool00?l06oooool01Ol00?oooooooooooooo
oooo003o01_ooooo00Ko003oooooooooooooooooool00?l00?lJooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool06?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool00oooool01Ol00?ooo`00
oooooooooooo003o01_ooooo00Koo`00o`00ooooooooooooo`00oooo000Kooooo`05o`00oooooooo
ooooooooool00?l06oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go003ooooooooooooo
ooooo`00o`0Kooooo`05o`00ooooooooooooooooool00?l07?ooool01?l00?ooooooooooool00?lK
ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o01cooooo
00?o003oooooooooool06oooool0027ooooo00?o0000ooooooooool01?ooool01?l00?oooooooooo
ool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Go003oooooooooooooooooo`00o`0Koooo
o`05o`00ooooooooooooooooool00?l06oooool01Ol00?oooooooooooooooooo003o01_ooooo00Go
003oooooooooooooooooo`00o`0Looooo`04o`00ooooooooooooo`00oa_ooooo00Go003ooooooooo
ooooooooo`00o`0Looooo`04o`00ooooooooooooo`00oakooooo00?o003oooooooooool06_ooool0
027ooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?lLooooo`04o`00oooooooo
ooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01Ol00?oooooooooooooooooo003o01_o
oooo00Go003oooooooooooooooooo`00o`0Kooooo`05o`00oooo003oooooooooool00?l07?ooool0
1?l00?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo
003o7_ooool00ol00?ooooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`04ooooo`04o`00
ooooooooooooo`00oacooooo00Co003ooooooooooooo003o7?ooool01?l00?ooooooooooool00?lL
ooooo`04o`00ooooooooooooo`00oacooooo00Go003oool00?ooooooooooo`00o`0Kooooo`05o`00
oooo003oooooooooool00?l07?ooool01?l00?ooooooooooool00?lLooooo`04o`00oooooooooooo
o`00oacooooo00Co003ooooooooooooo003o7_ooool00ol00?ooooooooooo`0Jooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool0
0?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003oool00?oooooo003o7Oooool00ol00?oo
ooooo`00o`0Mooooo`04o`00ooooooooo`00o`00oacooooo00?o003oooooool00?l07Oooool01?l0
0?ooooooooooool00?lLooooo`04o`00ooooooooooooo`00oacooooo00Co003ooooooooooooo003o
7Oooool00ooo003o003oooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00Co003ooooooooooooo003o7?ooool00ol00?ooo`00o`00o`0Nooooo`03o`00
oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00o`0Mooooo`03o`00
oooooooo003o01gooooo00?o003oooooool00?l07Oooool00ol00?ooooooo`00o`0Nooooo`;o003o
7_ooool00ooo003o003oooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo0_l00?lNooooo`;o003o7_ooool2o`00oakooooo00?o003oool00?l00?l07_oo
ool2o`00oagooooo0ol00?lNooooo`;o003o7_ooool2o`00oakooooo0_l00?lNooooo`03ool00?l0
0?oooooo01_ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`;o003o7_ooool2
o`00oakooooo0_l00?lOooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool07Oooool2
o`00oakooooo00?o003oooooooooool07Oooool2o`00oakooooo0_l00?lOooooo`03o`00oooooooo
oooo01[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Y?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oo
oooo1?l000001ol@413oooooooooool@413o0000odA4A?o<c<`0XOooool00:Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`03oiRHV?l@413o
gMgM0:3ooooo000Pooooo`03okZj^_lb<S;ooooo08;ooooo00Go0000ooooooooooooooooo`00000D
ooooo`03o`000?oooooooooo00Gooooo00?oQhN7oeEEEOooool0Woooool0027ooooo00?o0000oooo
ooooool0POooool01Ol0003ooooooooooooooooo000000;ooooo1_l0000<ooooo`03o`000?oooooo
oooo00;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00002Pooooo`007oooool01OnHV9So410@o`000?l0
003oZJVY087ooooo00Go0000ohN7QoooooooZJVYo`00000Dooooo`03o`000?oooooooooo00;ooooo
00Go8B4QohN7QoooooooV9RHo`00002Pooooo`007oooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj
^Woooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0Booooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00002Pooooo`007oooool01_lb<S;ok^k^oiRHV?mEEEGo
gMgMoa0@49Wooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE0:3ooooo
000Oooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Fooooo`03oeEEEOmVIVKo000000Co
oooo00Goc<c<oa0@4?l0003o<S8bonk^kP2Pooooo`007oooool01oo^k^ko0000ooooool0003ooooo
ofIVI_n7QhL0oooooom3ooooo`007oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooo
oooo0?oooooo@Oooool002;ooooo00?oIVIVohN7Qoooool0oooooom4ooooo`008_ooool00onYZJWo
A4A4ooooo`3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08612, \
0.0066032, 0.0136036}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.309017 0.294302 [
[.17539 .29652 -12 -9 ]
[.17539 .29652 12 0 ]
[.32696 .29652 -9 -9 ]
[.32696 .29652 9 0 ]
[.47854 .29652 -12 -9 ]
[.47854 .29652 12 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -12 -9 ]
[.78169 .29652 12 0 ]
[.93327 .29652 -9 -9 ]
[.93327 .29652 9 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.25)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(0.5)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(0.75)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(1)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(1.25)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(1.5)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .30902 m
.02846 .4191 L
.03279 .50266 L
.03523 .53992 L
.03754 .56765 L
.03881 .57959 L
.03948 .58486 L
.0402 .58965 L
.04146 .59605 L
.04262 .59954 L
.04384 .59915 L
.04496 .59597 L
.04626 .58964 L
.04749 .58106 L
.04967 .56004 L
.05205 .52914 L
.05466 .48411 L
.05744 .42771 L
.06244 .31468 L
.06791 .19038 L
.07079 .13195 L
.07382 .08224 L
.07649 .04959 L
.078 .03573 L
.07872 .03036 L
.07941 .02608 L
.0807 .02017 L
.08189 .01842 L
.08316 .02026 L
.08388 .02253 L
.08454 .02541 L
.08569 .03209 L
.08693 .04165 L
.08916 .06493 L
.09182 .10328 L
.09426 .14813 L
.10458 .37885 L
.10932 .47979 L
.11192 .5242 L
.11438 .55762 L
.11668 .58096 L
.11797 .59046 L
.11916 .59673 L
.12017 .59902 L
.12127 .59882 L
.12242 .59636 L
.1235 .59202 L
.12478 .5844 L
.12618 .57312 L
.12741 .56067 L
Mistroke
.12872 .54493 L
.13119 .50591 L
.13348 .46281 L
.1442 .2221 L
.14922 .11971 L
.15175 .08008 L
.15452 .04642 L
.15597 .03338 L
.15677 .02768 L
.15752 .02328 L
.15822 .02075 L
.15899 .0195 L
.15968 .01926 L
.16032 .01977 L
.16155 .02271 L
.16225 .02552 L
.16291 .02888 L
.16423 .03777 L
.16566 .05044 L
.16811 .08051 L
.17079 .1254 L
.17619 .23694 L
.18584 .45566 L
.18838 .50298 L
.19114 .54511 L
.19241 .56107 L
.19374 .57538 L
.1949 .58548 L
.19614 .59376 L
.19734 .59736 L
.19844 .59845 L
.19955 .59746 L
.20059 .59463 L
.20181 .58906 L
.20294 .58175 L
.20417 .5714 L
.20549 .55776 L
.20796 .52199 L
.21062 .47451 L
.21545 .37263 L
.22115 .24009 L
.22645 .12938 L
.22883 .08996 L
.23107 .05927 L
.23231 .0454 L
.23296 .03906 L
.23366 .03309 L
.23488 .02532 L
.23601 .02153 L
.23725 .01988 L
Mistroke
.23794 .0201 L
.23858 .02101 L
.23981 .02471 L
.24099 .03056 L
.24235 .04014 L
.24361 .05169 L
.24499 .06872 L
.24647 .09048 L
.25746 .31846 L
.26227 .42829 L
.26501 .48266 L
.26756 .52593 L
.26998 .55941 L
.27122 .57332 L
.27187 .57968 L
.27257 .58566 L
.27331 .59012 L
.27399 .59325 L
.27463 .59547 L
.27533 .59711 L
.27663 .59792 L
.27785 .5961 L
.27851 .59411 L
.27922 .59113 L
.27996 .58713 L
.28065 .5826 L
.28189 .57252 L
.28321 .5576 L
.28624 .51276 L
.28899 .46254 L
.29949 .22638 L
.30409 .13164 L
.30654 .09041 L
.30788 .07084 L
.30916 .05461 L
.31037 .04157 L
.31168 .03118 L
.31288 .0251 L
.31398 .02162 L
.31513 .02018 L
.31617 .02078 L
.31736 .02371 L
.31849 .02864 L
.31969 .03625 L
.32096 .04753 L
.32205 .06028 L
.32324 .07626 L
.32836 .16529 L
.33925 .41169 L
.34175 .4633 L
Mistroke
.3444 .51152 L
.34686 .54886 L
.34797 .56299 L
.34916 .57608 L
.35036 .58519 L
.35146 .59132 L
.35275 .59598 L
.35398 .5978 L
.35528 .59698 L
.35649 .59368 L
.35781 .58726 L
.35855 .58239 L
.35922 .57656 L
.36157 .54902 L
.36411 .51044 L
.36873 .42211 L
.3787 .19404 L
.38144 .13928 L
.38437 .08878 L
.38579 .06814 L
.38714 .05126 L
.38834 .03975 L
.38966 .03057 L
.39089 .02457 L
.39204 .02122 L
.39331 .0201 L
.39402 .02066 L
.39468 .02192 L
.39592 .02631 L
.39662 .02996 L
.39727 .03438 L
.3986 .04703 L
.40001 .06359 L
.40503 .14389 L
.40959 .24054 L
.41491 .36457 L
.42055 .48315 L
.42286 .52352 L
.42536 .55928 L
.42679 .5742 L
.42809 .58436 L
.4294 .59179 L
.43065 .59621 L
.43186 .59803 L
.43296 .59756 L
.43422 .59446 L
.43541 .58901 L
.43652 .58004 L
.43753 .57003 L
.43982 .54169 L
Mistroke
.44469 .45929 L
.44983 .34585 L
.45499 .22624 L
.45987 .12651 L
.46256 .08143 L
.46399 .06153 L
.46549 .04572 L
.46676 .03535 L
.46743 .0309 L
.46816 .02692 L
.46943 .02202 L
.47062 .01987 L
.47186 .02019 L
.47301 .02285 L
.47427 .02938 L
.47498 .03484 L
.47562 .04051 L
.47833 .07143 L
.48089 .10989 L
.49029 .30943 L
.4945 .40579 L
.49903 .4969 L
.50162 .53968 L
.50399 .56837 L
.50513 .57861 L
.50637 .58741 L
.50755 .59345 L
.50863 .59701 L
.50979 .59862 L
.51087 .59805 L
.51207 .59488 L
.51335 .58677 L
.51463 .576 L
.51597 .56188 L
.51837 .53013 L
.52329 .44153 L
.52868 .31995 L
.53323 .21564 L
.53563 .16478 L
.53817 .11616 L
.54039 .07967 L
.54157 .06422 L
.54283 .05032 L
.54399 .03972 L
.54506 .03188 L
.54612 .02583 L
.54714 .02182 L
.54837 .01927 L
.54968 .01945 L
.55092 .02348 L
Mistroke
.55204 .03029 L
.55336 .04101 L
.5548 .05571 L
.55739 .08987 L
.56225 .17843 L
.56672 .27865 L
.57198 .39972 L
.5769 .49956 L
.57937 .53982 L
.58203 .57064 L
.58354 .58344 L
.58428 .58842 L
.58497 .59222 L
.58626 .59722 L
.58693 .59872 L
.58765 .59945 L
.58879 .59831 L
.59004 .59285 L
.59134 .58433 L
.59254 .57395 L
.59471 .54977 L
.59703 .5167 L
.60232 .41355 L
.60713 .30346 L
.61164 .20104 L
.61402 .1515 L
.61654 .1048 L
.61874 .07214 L
.6199 .05803 L
.62115 .0451 L
.6223 .03535 L
.62335 .02828 L
.62441 .02299 L
.62541 .01972 L
.62666 .01808 L
.62737 .01928 L
.62801 .0214 L
.6292 .02719 L
.63046 .03586 L
.63264 .05681 L
.63503 .08773 L
.63759 .13054 L
.64033 .18578 L
.64526 .29722 L
.64991 .40362 L
.65245 .45772 L
.65483 .50334 L
.65702 .53772 L
.65903 .5627 L
.66126 .58344 L
Mistroke
.66249 .59152 L
.66367 .59686 L
.66489 .59991 L
.66619 .59844 L
.66743 .59397 L
.66854 .5877 L
.66986 .5777 L
.67128 .56385 L
.67387 .53113 L
.67667 .48322 L
.67964 .42269 L
.68495 .30197 L
.68958 .19674 L
.69455 .10062 L
.6974 .06125 L
.69875 .0466 L
.7 .03551 L
.70125 .0269 L
.70191 .0234 L
.70261 .02051 L
.70379 .01825 L
.70509 .02005 L
.7063 .02436 L
.70743 .03059 L
.70867 .03981 L
.71 .05231 L
.7127 .08593 L
.71517 .12786 L
.72442 .32975 L
.72956 .44497 L
.73227 .49805 L
.73514 .54226 L
.73764 .57177 L
.73907 .58433 L
.73975 .5892 L
.7404 .59311 L
.74163 .59847 L
.74275 .59931 L
.74395 .59766 L
.74526 .59304 L
.74591 .5897 L
.7466 .58543 L
.74782 .57592 L
.74925 .56187 L
.75059 .54601 L
.75298 .5091 L
.7556 .45983 L
.76496 .24959 L
.77016 .13801 L
.77272 .09459 L
Mistroke
.77509 .06198 L
.77638 .04748 L
.77781 .03446 L
.7785 .02934 L
.77924 .02472 L
.78003 .02097 L
.78076 .01956 L
.78208 .01942 L
.78274 .02048 L
.78346 .02248 L
.78475 .02817 L
.78594 .03587 L
.78722 .04663 L
.78857 .06078 L
.791 .09485 L
.79648 .20004 L
.80642 .42638 L
.81069 .50876 L
.81309 .54485 L
.81527 .57097 L
.81651 .58251 L
.81716 .5876 L
.81786 .59223 L
.81913 .59713 L
.82031 .59855 L
.82158 .59739 L
.82278 .59382 L
.82385 .58859 L
.82501 .58084 L
.8274 .55821 L
.82873 .54047 L
.82995 .52159 L
.83455 .43492 L
.84501 .19761 L
.85021 .099 L
.85314 .05806 L
.85454 .04287 L
.85585 .03144 L
.85699 .02455 L
.85821 .02087 L
.85891 .01994 L
.85957 .01982 L
.86082 .0216 L
.86213 .02626 L
.86334 .0331 L
.86467 .04335 L
.86609 .05738 L
.8758 .23445 L
.88606 .46572 L
.88865 .51207 L
Mistroke
.89143 .55294 L
.89302 .57156 L
.89447 .58507 L
.89517 .58977 L
.89593 .59332 L
.89665 .59576 L
.89732 .59724 L
.89855 .59798 L
.8997 .59637 L
.90097 .59204 L
.90168 .58843 L
.90234 .5844 L
.90358 .57482 L
.90494 .56073 L
.90767 .52156 L
.91763 .31498 L
.92253 .20237 L
.92704 .11423 L
.92952 .07548 L
.93083 .05824 L
.93224 .04258 L
.93298 .03565 L
.93366 .03096 L
.93434 .0272 L
.93498 .02443 L
.93569 .02214 L
.93647 .02063 L
.93715 .02014 L
.93788 .02047 L
.93916 .02322 L
.93988 .02596 L
.94054 .02925 L
.94176 .03719 L
.94305 .04877 L
.94421 .06266 L
.94528 .07741 L
.94773 .11662 L
.97619 .60332 L
Mfstroke
0 0 1 r
[ ] 0 setdash
.02381 .30902 m
.02846 .41696 L
.03279 .50427 L
.03523 .54366 L
.03754 .57253 L
.03881 .58462 L
.03948 .58982 L
.0402 .59443 L
.04146 .60024 L
.04262 .60294 L
.04384 .60298 L
.04496 .60049 L
.04626 .59464 L
.04749 .58619 L
.04862 .57599 L
.04967 .56453 L
.05205 .53187 L
.05708 .43771 L
.06244 .31466 L
.06791 .18832 L
.07079 .12976 L
.07382 .0784 L
.07649 .04469 L
.078 .0309 L
.07872 .02574 L
.07941 .02176 L
.0807 .01664 L
.08189 .01477 L
.08316 .01575 L
.08388 .01768 L
.08454 .02035 L
.08569 .02689 L
.08693 .03664 L
.08916 .06111 L
.09182 .10064 L
.09426 .14536 L
.10458 .38025 L
.10932 .48181 L
.11192 .52778 L
.11438 .56234 L
.1155 .57478 L
.11668 .5856 L
.11797 .59458 L
.11916 .60011 L
.12023 .60276 L
.12123 .60326 L
.12233 .60161 L
.1235 .59727 L
.12417 .59366 L
.12488 .58889 L
Mistroke
.12616 .57803 L
.12905 .54304 L
.13182 .49768 L
.13432 .44845 L
.1442 .22058 L
.14909 .11932 L
.15156 .0786 L
.15297 .05924 L
.15425 .04444 L
.15536 .03399 L
.15656 .02513 L
.15783 .01867 L
.15903 .01538 L
.16016 .0148 L
.16135 .01683 L
.16237 .02072 L
.16349 .02725 L
.16481 .03788 L
.16619 .05237 L
.16867 .0861 L
.17424 .19202 L
.17953 .3144 L
.18432 .42522 L
.18892 .51542 L
.19151 .55451 L
.19389 .58106 L
.19511 .59077 L
.19581 .59512 L
.19645 .5983 L
.19712 .60081 L
.19784 .60255 L
.19915 .60316 L
.20037 .60077 L
.20105 .59817 L
.20169 .59496 L
.20286 .58712 L
.2041 .57607 L
.20627 .55045 L
.20861 .51456 L
.21284 .43205 L
.22248 .20856 L
.2271 .11461 L
.22969 .073 L
.23204 .04404 L
.23337 .03178 L
.23408 .02662 L
.23482 .02214 L
.23548 .01908 L
.23619 .01664 L
.23746 .01474 L
Mistroke
.23871 .01588 L
.23942 .01785 L
.24006 .02047 L
.24131 .02779 L
.2425 .0374 L
.24503 .06611 L
.24773 .10782 L
.25259 .20524 L
.25832 .33925 L
.26359 .45754 L
.26618 .5071 L
.2686 .54558 L
.27112 .57612 L
.27246 .58787 L
.27315 .59271 L
.27389 .59687 L
.27463 .60003 L
.27532 .60202 L
.27606 .60315 L
.27688 .60317 L
.27758 .60216 L
.27834 .60001 L
.27905 .59698 L
.27971 .59336 L
.28095 .58437 L
.2823 .57142 L
.28502 .53602 L
.29007 .44292 L
.29547 .31963 L
.3002 .20931 L
.30519 .1085 L
.30773 .06878 L
.30908 .05173 L
.31053 .03682 L
.31121 .03107 L
.31186 .0264 L
.31307 .01972 L
.31421 .01598 L
.31545 .01472 L
.3162 .0154 L
.31691 .01704 L
.31755 .01933 L
.31824 .02267 L
.31899 .02735 L
.31979 .03341 L
.32121 .04707 L
.32376 .08006 L
.32655 .12726 L
.33711 .36378 L
.3421 .47292 L
Mistroke
.34429 .51346 L
.34671 .55067 L
.34905 .57793 L
.35033 .58885 L
.35153 .59636 L
.35285 .60149 L
.35405 .60329 L
.35472 .60309 L
.35544 .6019 L
.35677 .59715 L
.35802 .58963 L
.35915 .58032 L
.3617 .55132 L
.36405 .51531 L
.36627 .47452 L
.37645 .24327 L
.38201 .12516 L
.38473 .07953 L
.38592 .06294 L
.38721 .04746 L
.38844 .03536 L
.38958 .02656 L
.39067 .02039 L
.39182 .01628 L
.39304 .01472 L
.39418 .01583 L
.39543 .01989 L
.39613 .02348 L
.39677 .02758 L
.39804 .03784 L
.39922 .04993 L
.40189 .08588 L
.40728 .18763 L
.41614 .39345 L
.4208 .49134 L
.42336 .5348 L
.42575 .56683 L
.427 .57988 L
.42835 .5908 L
.42912 .59552 L
.42985 .59899 L
.4305 .60124 L
.43122 .60277 L
.43248 .60307 L
.43319 .60189 L
.43383 .6 L
.43508 .59406 L
.43626 .58581 L
.43747 .57473 L
.43875 .56028 L
Mistroke
.44104 .52785 L
.44619 .42943 L
.45592 .2041 L
.46016 .11771 L
.4624 .0806 L
.46478 .04939 L
.46598 .03714 L
.46731 .02662 L
.46852 .01988 L
.46966 .01607 L
.47082 .01472 L
.47188 .01575 L
.47305 .01937 L
.47428 .02595 L
.47549 .03524 L
.47679 .04808 L
.47914 .07834 L
.48445 .17531 L
.494 .39602 L
.49819 .48448 L
.50041 .52384 L
.50279 .55838 L
.50414 .57389 L
.50537 .58532 L
.5066 .59405 L
.50778 .59971 L
.50909 .60294 L
.5103 .60299 L
.51094 .60189 L
.51164 .59979 L
.51237 .59661 L
.51305 .5927 L
.51441 .58242 L
.51584 .56803 L
.5184 .53383 L
.52417 .42446 L
.53391 .1987 L
.53671 .1402 L
.53936 .09281 L
.54174 .05862 L
.54308 .04344 L
.54433 .03201 L
.54547 .02404 L
.5467 .01816 L
.54739 .01609 L
.54806 .01499 L
.5493 .0152 L
.55061 .01863 L
.55182 .02471 L
.55252 .02945 L
Mistroke
.55316 .03452 L
.55458 .04848 L
.55692 .07885 L
.55945 .12091 L
.56404 .21571 L
.56862 .32306 L
.57353 .43562 L
.57571 .48023 L
.57808 .52268 L
.58017 .55367 L
.58239 .57894 L
.58362 .58923 L
.58427 .59359 L
.58498 .59739 L
.58621 .60181 L
.58737 .60331 L
.58852 .60225 L
.58973 .59839 L
.59077 .59289 L
.5919 .5846 L
.59327 .5715 L
.59451 .55681 L
.59731 .515 L
.60234 .41513 L
.60766 .29093 L
.6133 .16354 L
.61562 .1184 L
.61811 .0774 L
.61954 .05802 L
.62084 .04323 L
.62216 .03134 L
.6234 .02295 L
.62461 .01756 L
.62571 .01509 L
.62698 .01511 L
.62817 .01793 L
.62927 .02297 L
.63029 .02962 L
.63141 .03909 L
.63258 .05145 L
.63506 .08482 L
.63736 .12398 L
.64259 .23422 L
.64772 .35506 L
.65328 .47685 L
.65583 .52278 L
.65854 .56156 L
.65965 .57411 L
.66085 .58522 L
.66216 .59443 L
Mistroke
.66339 .60015 L
.66405 .60202 L
.66474 .60311 L
.666 .60272 L
.66677 .60098 L
.66749 .59831 L
.66815 .59507 L
.66885 .59067 L
.67016 .58004 L
.67155 .56548 L
.67404 .53148 L
.67869 .44532 L
.68379 .32934 L
.68835 .2221 L
.69332 .11912 L
.6956 .08122 L
.69802 .04937 L
.69901 .0391 L
.70008 .02997 L
.70126 .02236 L
.70236 .01756 L
.7036 .01494 L
.7043 .01476 L
.70495 .01544 L
.70627 .01929 L
.70701 .02289 L
.70768 .02704 L
.70888 .03656 L
.71018 .04978 L
.71255 .08103 L
.71739 .16914 L
.72185 .26951 L
.72706 .39203 L
.72993 .45469 L
.73265 .50704 L
.73518 .54707 L
.73651 .5643 L
.73793 .5794 L
.73925 .5902 L
.74044 .59725 L
.74163 .60164 L
.74276 .60328 L
.74385 .60255 L
.74504 .59914 L
.74629 .59269 L
.74745 .58408 L
.74954 .56265 L
.75177 .53176 L
.75686 .43616 L
.76151 .33005 L
Mistroke
.76658 .21118 L
.76926 .15386 L
.7721 .10099 L
.77458 .06372 L
.7759 .04784 L
.77732 .03404 L
.77862 .02457 L
.77981 .01863 L
.78094 .01547 L
.78214 .01481 L
.78338 .01702 L
.78407 .01955 L
.78472 .0227 L
.7859 .0305 L
.78715 .04151 L
.78931 .06698 L
.7917 .10348 L
.8019 .32417 L
.80648 .42945 L
.809 .48133 L
.8114 .52398 L
.81362 .55641 L
.81479 .57038 L
.81604 .58267 L
.81719 .59157 L
.81824 .59751 L
.81929 .6014 L
.82027 .60315 L
.82144 .60279 L
.8227 .5995 L
.82388 .59367 L
.82495 .58611 L
.82622 .57456 L
.82759 .55889 L
.83008 .52277 L
.83545 .4178 L
.84041 .30242 L
.84505 .19525 L
.84939 .10889 L
.85175 .07155 L
.85392 .04493 L
.85515 .03332 L
.85632 .02482 L
.85756 .01862 L
.85826 .01638 L
.8589 .01514 L
.86019 .01508 L
.86084 .01625 L
.86155 .01846 L
.86281 .0247 L
Mistroke
.86398 .03319 L
.86537 .04638 L
.86663 .06129 L
.86947 .10395 L
.87458 .20594 L
.87942 .31888 L
.88374 .41892 L
.88833 .51042 L
.89073 .54792 L
.892 .56429 L
.89337 .57891 L
.89462 .5894 L
.89577 .59649 L
.89687 .60095 L
.89803 .60315 L
.89926 .60268 L
.89996 .60112 L
.9006 .59886 L
.90178 .59269 L
.90303 .58335 L
.90519 .56064 L
.90757 .52682 L
.91284 .42565 L
.91777 .31172 L
.92231 .20594 L
.92662 .118 L
.929 .07876 L
.93025 .06137 L
.93159 .04567 L
.93283 .03388 L
.93395 .02556 L
.93507 .01954 L
.93613 .01606 L
.9373 .01472 L
.93855 .01617 L
.93973 .02028 L
.9408 .02631 L
.94206 .03609 L
.94343 .04992 L
.94592 .08303 L
.95129 .18319 L
.95625 .29698 L
.96048 .39633 L
.96504 .49168 L
.96765 .53596 L
.96879 .55227 L
.97004 .56772 L
.97115 .57921 L
.97233 .58909 L
.97357 .59676 L
Mistroke
.97473 .60128 L
.9755 .60286 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000oooooo
1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0000@ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool2o`00oaKooooo0_l00?lGooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`;o003o5oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo01Gooooo0_l00?lFooooo`;o003o:?ooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`;o003o5_ooool2o`00oaKooooo0ol0
0?lFooooo`;o003o5_ooool2o`00oaOooooo0_l00?lFooooo`;o003o5_ooool2o`00oaKooooo0_l0
0?lFooooo`03o`00oooooooo003o01Kooooo0_l00?lFooooo`;o003o:?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`;o003o5_ooool00ol00?ooo`00o`00o`0E
ooooo`03o`00oooo003o003o01Kooooo0_l00?lFooooo`;o003o5_ooool00ol00?ooooooo`00o`0F
ooooo`;o003o5_ooool2o`00oaKooooo0_l00?lFooooo`03o`00oooooooo003o01Kooooo0_l00?lF
ooooo`;o003o:?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?oooo
o`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l00?lFoooo
o`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?ooo`00o`00o`0Foooo
o`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oool0
0?l00?l05_ooool2o`00obSooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool0
0?l05Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o003ooooo
ool00?l05Oooool00ol00?ooooooo`00o`0Fooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eoooo
o`03o`00oooooooo003o01Gooooo00?o003oool00?l00?l05_ooool00ol00?ooooooo`00o`0Woooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo00kooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooo`00ooooool00?lEooooo`03o`00oooooooo003o01Gooooo00Co003o
oooooooooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o
003oooooool00?l05Oooool01?l00?ooo`00ooooool00?lEooooo`03o`00oooooooo003o01Gooooo
00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00
obOooooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l0
0?ooo`00ooooool00?lEooooo`04o`00ooooooooo`00o`00oaCooooo00Co003ooooooooooooo003o
5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooo
oooooooo003o5?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o
003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00obOo
oooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l00?oo
o`00ooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?oo
ool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooo003o003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00
obOooooo000Qooooo`03o`000?oooooooooo00kooooo00Co003ooooooooooooo003o5?ooool01?l0
0?ooo`00ooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?oooooooooo
ool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o
5Oooool01?l00?ooooooool00?l00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooo
oooooooo003o9oooool0027ooooo0ol0000>ooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooool00?l00?l05?ooool0
1?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lWooooo`008Oooool00ol0003oooooooooo`0>ooooo`04o`00oooooooo
ooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?ooo`00oooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0C
ooooo`05o`00ooooooooooooool00?l00?l04oooool01Ooo003o003ooooooooooooo003o01Cooooo
00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooo003o003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooo`00
o`00o`0Vooooo`008Oooool00ol0003oooooooooo`0>ooooo`04o`00ooooooooooooo`00oaCooooo
00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0Cooooo`05o`00oooo
ooooooooool00?l00?l04oooool01Ooo003o003ooooooooooooo003o01Cooooo00Co003ooooooooo
oooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00
o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooo`00o`00o`0Vooooo`00
8Oooool00ol0003oooooooooo`0>ooooo`05o`00ooooooooooooool00?l00?l04oooool01Ol00?oo
oooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooooooo
ooooooooool00?l05?ooool01Ol00?oooooooooooooo003o003o01?ooooo00Go003ooooooooooooo
o`00o`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo
003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ooo003o003ooooooooooooo003o01Cooooo00Go003oooooooooooooo`00o`00o`0Voooo
o`008Oooool00ol0003oooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`06o`00oooo
ooooooooooooool00?ooo`004_ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooo`00o`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
1Ol00?ooo`00oooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l04oooool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo013o
oooo00Ko003oool00?ooooooooooool00?l00?lVooooo`008Oooool00ol0003oooooooooo`0>oooo
o`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`0Cooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol0
0?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo003o01Cooooo
00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool00ol0
0?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooo003ooooo00;o
oooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05
o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool00ol00?oooooo
ooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooo003ooooo00;ooooo00?o
003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003oooooooooooooooooool00?l00?lB
ooooo`06o`00oooooooooooooooooooo003o003o4_ooool01Ol00?oooooooooooooooooo003o01Co
oooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_ooool0
0ol00?ooooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oool00?ooool00_oo
ool00ooo003o003oooooo`0Aooooo`06o`00oooooooooooooooooooo003o003o4_ooool01Ol00?oo
oooooooooooooooo003o01?ooooo00?o003oool00?ooool00_ooool00ol00?ooooooooooo`0Aoooo
o`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Tooooo`008Oooool3o`00
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03ool00?l00?oooooo017ooooo00Ko003o
ooooooooooooooooool00?l00?lBooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003ooooooooooooo
ooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo017ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko003ooooo
ooooooooooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo013ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04?ooool00ol00?ooo`00ooooo`02ooooo`03o`00oooooooooooo017ooooo00Ko
003oooooooooooooooooo`00oooo000Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`00
0?oooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooooooooooooooo003o01?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?oo`00o`00ooooool00_ooool00ol00?ooo`00ooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Co
oooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool00ooo003o003o
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04Oooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
0_ooool00ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool0
4?ooool00ooo003o003oooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo00gooooo00?o003oooooooooool00_ooool00ooo003o003oooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?oo`00o`00ooooool04?ooool00ooo003o003oooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oool00?ooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
003ooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00_ooool0
0ooo003o003oooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Cooooo000Qooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?oo`00o`00ooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Cooooo000Qooooo`?o00003Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09?ooool0027ooooo00?o
0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool09?ooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool08oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0
3?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
8oooool0027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool0
027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool08oooool0027ooooo0ol0000<ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ooo003o003oooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>
ooooo`03ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0S
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ooo003o003oooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ooo003o003oooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03
ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Sooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooo`00ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Sooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ooo
003o003oooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oool00?ooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool08oooool000Go
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo
003o003oooooo`0>ooooo`03ool00?l00?oooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooo`00ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ooo
003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0Sooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool00oooool3o`0000_ooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oool00?ooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo00kooooo00?oo`00o`00ooooool01Oooool00ol00?ooo`00ooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03ool00?l00?oooooo02?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool02oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooo`00ooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Cooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooo003ooooo00Gooooo00?oo`00o`00ooooool08oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00Kooooo00?o003oooooooooool08_ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03ool00?l00?oooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo003ooooo00Kooooo00?o003o
ooooooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oool00?ooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool0
0ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?oo`00o`00ooooool03Oooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo
00cooooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool00ooo003o
003oooooo`06ooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`008Oooool00ol0003ooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00cooooo00?o003oool00?ooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Rooooo`008Oooool3o`0000_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooo`00ooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03
o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?ooo`00ooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool0
3?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oo
oooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?ooo`00ooooo`07ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo
00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oool00?ooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?ooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?oo`00o`00ooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oool00?ooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?oo`00o`00ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03ool00?l00?oooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo027ooooo
000Qooooo`?o00002oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
o`00o`00ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool0
2_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
8Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oool00?ooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08Oooool0
027ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00ooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool08Oooool0027ooooo
00?o0000ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo003ooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03ool00?l00?oooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo
00?o003oooooooooool08Oooool0027ooooo0ol0000:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ooo003o003oooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
o`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
o`00o`00ooooool02?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ooo003o003oooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Q
ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ooo003o003oooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool0
0?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool0
0?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oool00?ooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool0
2?ooool00ol00?ooo`00ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oool00?ooool0
2oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;o003o00Gooooo
0_lQ8B43ooooo`03o`00ool0003o000000?o00001?ooool01Om4A4Co0000o`000?l00?oogMgM00[o
oooo00?o003oooooooooool02?ooool01Oo^k^ko<S8bo`00oolb<S;ok^k^00Gooooo0_lQ8B400ooo
oooo003oooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00oooo
003ooooo00;o8B4Q1_ooool00ol00?ooo`00ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
0_ooool4o`000003oa0@4?oooooo003o00cooooo00?o003oool00?ooool02?ooool00ol00?ooo`00
ooooo`02ooooo`Co000000?o410@ooooooooool00_ooool00ol00?oo8B4Qooooo`03ooooo`Co0000
00?o003oool00?ooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`04ooooo`Co000000?o410@ooooool00?l00_ooool2ob4Q8@Go
oooo00GoA4A4o`00ool0003o<S8bomgMg@0Pooooo`008Oooool00ol0003oooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool01OmgMgOoV9RHoooooonHV9So003o
00Gooooo0_lQ8B43ooooo`06o`00oonHV9So8B4Qonk^k_ooooooA4A41oooool00ol00?oo<S8boooo
o`09ooooo`03o`00oooooooooooo00Sooooo00GoMgMgoiRHV?l00?ooV9RHogMgM`05ooooo`;o8B4Q
00?oooooo`00ooooool01Oooool00omgMgOo<S8booooo`03ooooo`03ool00?l00?oooooo00Sooooo
00?o003oooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o003oool00?oo
ool00_lQ8B46ooooo`03o`00oooo003ooooo00Oooooo00GoMgMgoc8b<_ooooooooooo`00o`0:oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool01Ol0003ooooooooooooooooo
003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o003oob4Q8OlQ8B401?ooool01_nHV9So8B4Qonk^k_oooooo003oool000Kooooo
00?oMgMgoc8b<_ooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo
00Go0000ooooooooooooooooo`00o`02ooooo`;o8B4Q1oooool00ol00?ooMgMgoc8b<P0Pooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1_ooool01Ol@413ooooooooooooooooo003o00[ooooo00Go003ooooooonHV9So8B4Qonk^kP08oooo
o`03o`00ool0003ooooo00Wooooo00?o003oooooooooool02?ooool01Ol@413oooooo`00oooooooo
410@00Sooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00oooool01Ol@413ooooooooooooooooo410@00;ooooo00?o
003oool00?ooool02?ooool00ol00?ooo`00ooooo`08ooooo`04o`000?ooooooooooo`00o`[ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`05o`000?ooooooooooooooool0
0?l03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00Cooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^o`00oooo00001oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool01Ol0
003ooooooooooooooooo003o00_ooooo00?o003oooooool000008?ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00Go0000oooo
ooooooooooooo`00o`0:ooooo`06o`00oooooooooooooiRHV?lQ8B7ok^k^1oooool00ol00?oo<S8b
ooooo`09ooooo`03o`00oooooooooooo00Sooooo00Go0000ooooool00?ooooooo`000008ooooo`03
o`00oooooooooooo00Cooooo00?oMgMgoc8b<_ooool00oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00oooooooooooo
00Sooooo00?o003oool00?ooool01oooool01OmgMgOo<S8boooooooooooo003o00[ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`05o`000?ooooooooooooooool00?l03?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`06ooooo`04oiRHV?lQ8B7o003oool000Kooooo00?oMgMgoc8b<_ooool0
0_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00o`0;ooooo`03o`00oomgMgOo<S8b023ooooo000Qooooo`?o00002_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00Go0000ooooooooooooooooo`00o`0:ooooo`06
o`00oooooooooooooooooomgMgOoIVIV1?ooool01Ol0003o8B4Qo`000?l00?ooc<c<00[ooooo00?o
003oooooooooool02?ooool01Ol0003oooooo`00oooooooo000000Sooooo00Wo003ooooooooooooo
ooooo`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00oooooooooooo00Sooooo00?o
003oool00?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Sooooo00?o003oool00?ooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?oMgMgo`00oooo00000oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06oooo
o`05o`000?ooooooooooooooool00?l02Oooool01Ol0003o8B4Qo`00oolb<S;oc<c<023ooooo000Q
ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06
ooooo`05oa0@4?ooooooooooooooool00?l02_ooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo003o2oooool00ol00?ooooooooooo`08ooooo`05oa0@
4?oooooo003oooooool@41002?ooool01Ol00?oooooooooooooooooo000000Sooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41000_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooo003oMgMg00Cooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool0
1Ol0003ooooooooooooooooo003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00oooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooo`00oooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`05o`000?ooooooooooooooool00?l02Oooool00ol0003oooooo`00o`0Rooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooo003ooooo00Wooooo00?o003oooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9So003o00[ooooo00Koo`00o`00oonj^[[ooooooiRHV?l@4104oooo
o`04o`000?ooooooooooo`00o`_ooooo00?o003oooooooooool02?ooool01OmgMgOoV9RHo`00oonH
V9SoMgMg00Sooooo00Go003oooooooooooooooooo`000008ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o003ooooooooo
ool01_ooool01Ol@413oooooooooool00?oo<S8b00Cooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool01Ol0
003ooooooooooooooooo003o00cooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01?ooool01Ol0003o^[ZjoooooonH
V9So003o00Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00o`09ooooo`03o`000?oooooo003o02;ooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o003oool00?ooool02Oooool00ol00?oooooooooo
o`06ooooo`05onk^k_lb<S;o0000oc8b<_l00?l02_ooool01_oo003o003ooa0@4?l0003o8B4Qolc<
c0Cooooo0ol000000ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00Gok^k^oc8b
<_l00?oo<S8bonk^kP08ooooo`04o`00ooooooooooooooooo`Co00001Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`00
oooooooooooo00Kooooo0ol000000ol00?oo0000ooooo`03ooooo`Co00000oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00omEEEGoIVIV
o`000003ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooo`00
ooooo`02ooooo`03oeEEEOmVIVKo000000Gooooo00?o003oooooooooool01?ooool01_nHV9So410@
o`000?lQ8B7oc<c<o`00o`?ooooo1?l00004ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01?ooool00omEEEGoIVIVo`000003ooooo`03o`00oooooooooooo00Oooooo0_l000000ol0
0?oo0000ooooo`0Pooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Pooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Pooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo01Kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Gooooo`04omgMgOl0003o410@olc<c0Gooooo000Jooooo`Oo000000?o
003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
o`00o`00ool000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000[o000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002?l000000ooo003o003oo`000009o`000003o`00ool0003o000000[o000000?o
003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o000000Wo000000?o
003oo`000?l000002ol0000<ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00oooo
oooooooo00Oooooo00?o0000ooooool00?l01_ooool00ol0003oooooooooo`03ooooo`05o`00oooo
ooooooooooooool000001oooool00ol00?oo0000ooooo`08ooooo`03o`000?l00?oooooo00Kooooo
00Go0000ooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00?ooooo00Coo`00o`00oooo
oooo00002?ooool00ol00?oo0000ooooo`07ooooo`03o`000?oooooo003o00Oooooo00?o0000oooo
ooooool00_ooool01Ol00?oooooooooooooooooo000000Oooooo00?o003oo`000?ooool02?ooool0
0ol0003o003oooooo`06ooooo`05o`000?ooooooooooooooool00?l01Oooool00ol0003ooooooooo
o`03ooooo`04o`00ooooooooooooo`0000Wooooo00?o003oooooooooool01_ooool01?l0003ooooo
ool00?l00?l6ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`000006oooo
o`04o`00ooooooooooooo`0000Sooooo00?o0000o`00ooooool01oooool01?l0003oooooooooool0
0?l5ooooo`03o`000?oooooooooo00?ooooo00Go003oooooooooooooooooo`000007ooooo`03o`00
ool0003ooooo00Oooooo00Co0000oooooooooooo003o1_ooool00ol0003oooooooooo`02ooooo`05
o`00ooooooooooooooooool000001oooool00ol00?ooooooo`000008ooooo`03o`000?oooooooooo
00cooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
003o003oooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`000?oooooo003o00cooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00Go0000ooooooooooooooooo`00o`0;
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ooo003o003oooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`05o`00ooooooooooooooooool000001oooool00ol00?ooooooooooo`0Fooooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0:ooooo`03ool00?l00?oooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
023ooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
o`00ooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooo`00ooooo`0:ooooo`03ool00?l00?oooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo
000Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo023ooooo000Qooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo003ooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo023ooooo000Qoooo
o`03o`000?l00?oo000000Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooo003ooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03ool00?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo023ooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00oooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00oooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo003ooooo023ooooo000Qooooo`03o`00
0?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool0
0?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooo003ooooo023ooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`08ooooo`03ool00?l00?oo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01oooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ooo
003o003oooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oool00?ooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?oo`00o`00ooooool02_ooool00ooo
003o003oooooo`08ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Wo
oooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oool00?ooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03ool00?l00?oooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oo
oooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o003oooooooooool02_ooool00ooo003o003o
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?oo`00o`00ooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`07ooooo`03ool00?l00?oooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Wooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo000Q
ooooo`03o`000?l00?oo000000Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?oo`00o`00
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03
o`000?l00?oooooo00Sooooo00?oo`00o`00ooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooo`00ooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03
o`00oooo003ooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?oo`00o`00ooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool0
2oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool0
1oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?l0
0?oooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?oo`00o`00ooooool02oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l0
0?oooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`08ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo
003ooooo01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ooo003o003oooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool0
0ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?l00?oooooo
00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooo`00ooooo`07ooooo`03ool00?l00?oooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo
01oooooo000Qooooo`03o`000?l00?oooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
o`00ooooo`07ooooo`03ool00?l00?oooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o
003oooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
o`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool01oooool00ooo003o
003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo000Qooooo`03o`000?oooooo003o00Sooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooo`00ooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?oo`00o`00ooooool01oooool00ooo003o003oooooo`0<ooooo`03o`00oooo003ooooo01oooooo
000Qooooo`;o000000?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
003ooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03ool00?l0
0?oooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ooo003o003oooooo`06ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooo003ooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0
027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ooo003o003oooooo`06ooooo`03o`00oooo003ooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ooo003o
003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo
00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ooo003o003ooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooo`00oooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000
ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooo`00ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ooo003o003oooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooo`00ooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo00?o0000ooooool0
0?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ooo003o003oooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooo`00ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool07oooool0027ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooo`00ooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07oooool0027ooooo0_l000000ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Oooooo`008Oooool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo003ooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`08oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooo003ooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Ooooo
o`008Oooool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo003ooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003oooooo`00o`08ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooo003ooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooool0000Oooooo`008Ooo
ool00ol0003oooooo`00o`08ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03Ooo
ool00ol00?ooooooool0000Oooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooo`00o`08ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?oo`00o`00ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooo`00ooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol00?ooo`00ooooo`0Nooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03ool00?l00?oooooo00Gooooo
00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oool00?ooool03Oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00kooooo
00?o003oool00?ooool07_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool00?l02?ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ooo003o003oooooo`0=ooooo`03ool0
0?l00?oooooo00Gooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oool00?ooool07_ooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l000000ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooo`00ooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooo`00ooooo`0Nooooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooo003o00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooo003ooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooo003ooooo01kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`00o`Kooooo00?o003oool00?ooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ooo
003o003oooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooo003ooooo01kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00o`Kooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?oo`00
o`00ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo003ooooo01kooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oool00?ooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo00Co0000oooooooooooo003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03Oooool00ooo003o003oooooo`05ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oool00?ooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003ooooooooo00007_ooool0027ooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo00Co0000oooooooooooo003o1_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooo
003ooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003ooooooooo00007_ooool0027ooooo00Co0000oooooooooooo003o1_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ooo003o003oooooo`04ooooo`03o`00oooo003ooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?oo`00o`00ooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo00007_oo
ool0027ooooo0ol000000ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03ool00?l00?oooooo00Cooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooool0000Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ooo003o003oooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooool0000N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooool0000Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oool00?ooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ool00?ooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03ool00?l00?oooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l6ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Nooooo`008Oooool01?l0003oooooooooool00?l6
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oool00?ooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03ool00?l00?oooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0N
ooooo`008Oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ool00?ooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Nooooo`008Oooool3o`000003o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooo`00ooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
01kooooo000Qooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo01gooooo000Qooooo`04o`000?ooooooooooo`00
o`Gooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooo`00ooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
01gooooo000Qooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooo003ooooo013ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooo003ooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooo`00ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo01gooooo000Qooooo`05o`000?oooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oool0
0?ooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oool0
0?ooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooo`00ooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00oooooo00?o003oool00?ooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool01_l00?ooooooooooooooooooo`00o`00oa7ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`0Mooooo`008Oooool01Ol0003ooooooooooooo
oooo003o00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`06o`00oooo
oooooooooooooooo003o003o4Oooool00ol00?ooo`00ooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01go
oooo000Qooooo`05o`000?ooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o
01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oool00?ooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo003ooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00Ko003oooooooooooooooooool00?l00?lAooooo`03o`00oooo003ooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool07Oooool0027ooooo00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooo
ooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooo`00ooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo013ooooo
00?o003oool00?ooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Mooooo`008Oooool3o`000003ooooool0
0?oooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ooo003o003oooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo00;ooooo
00?oo`00o`00ooooool04Oooool01_l00?oooooooooooooooooo003oool001;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00ooooooooo`0001gooooo000Qooooo`05
o`000?ooooooooooooooool00?l01?ooool00ol00?ooooooooooo`0@ooooo`03ool00?l00?oooooo
00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool01Ol00?oooooooooooooooooo003o01;ooooo00?oo`00o`00ooooool00_oo
ool00ooo003o003oooooo`0Aooooo`06o`00ooooooooooooooooool00?ooo`004_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo00007Oooool0027ooooo
00Go0000ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo013ooooo00?oo`00o`00oooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooo003ooooo00;ooooo00?o003oooooooooool04Oooool01_l0
0?ooooooooooooooooooo`00o`00oa;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`05o`00ooooooooooooooooool00?l04_ooool00ooo003o003oooooo`02ooooo`03o`00
oooooooooooo017ooooo00Ko003oooooooooooooooooo`00oooo000Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooool0000Mooooo`008Oooool01Ol0003o
oooooooooooooooo003o00?ooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo
003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`06o`00oooooooooooooooooooo003o
003o4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Booooo`03ool00?l0
0?oooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00ooooooooo`0001gooooo
000Qooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Booooo`05o`00
ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
1Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01;o
oooo00?oo`00o`00ooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
oooo00007Oooool0027ooooo00Ko0000ooooooooooooooooool00?l00?l2ooooo`03o`00oooooooo
oooo01;ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo
003o01?ooooo00Ko003oool00?ooooooooooool00?l00?lCooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooool0000M
ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01_l00?ooo`00oooooooo
ooooo`00o`00oa?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooooooooooooooo
ool00?l04oooool01Ol00?ooo`00oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooo003ooooo01cooooo000Qooooo`03o`000?oooooooooo
00;ooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00oooo
ooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooool0
0?l00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00
o`0Cooooo`05o`00oooo003oooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01?o
oooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooo003oooooooooool00?l04oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oool00?ooool07?ooool0
027ooooo00?o0000ooooooooool00_ooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooo
ooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCo
oooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo
003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
o`0001cooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lDooooo`05ool00?l00?ooooooooooool00?l05?ooool01?l00?oooooo
ooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0C
ooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`05o`00
ooooooooooooool00?l00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oool0
0?ooooooooooo`00o`0Cooooo`06o`00oooooooooooooooooooo003o003o4oooool00ol00?oooooo
ool0000Looooo`008Oooool3o`0000;ooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooo
ooooool00?lDooooo`05ool00?l00?ooooooooooool00?l05?ooool01?l00?ooooooooooool00?lD
ooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
oooo003oooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooooooo
o`00oaCooooo00Co003ooooooooooooo003o5?ooool01Ol00?ooo`00oooooooooooo003o01Cooooo
00Co003ooooooooooooo003o5?ooool00ol00?ooooooool0000Looooo`008Oooool00ol0003ooooo
ooooo`02ooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01Ooo
003o003ooooooooo003o003o01Cooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooooooo
ool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?ooo`00oooooooooooo003o
01Cooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo
ooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDoooo
o`03o`00ooooooooo`0001cooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooo`00o`00oaCooooo00Co
003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo003oooooo`00
oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003oool00?oooooo003o5Oooool01?l00?ooooooooooool00?lDoooo
o`04o`00ooooooooooooo`00oaCooooo00?o003ooooooooo00007?ooool0027ooooo00?o0000oooo
ooooool00_ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00?o
003oooooool00?l05Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCo
oooo00Co003oool00?oooooo003o5Oooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooo
ooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01?l00?ooo`00ooooool00?lEooooo`04
o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool00ol00?ooo`00ooooo`0K
ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`00ooooooooo`00o`00oaCooooo00Co003o
ool00?oooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooo`00o`00oaCooooo
00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Go
oooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo
003o01Gooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooool00?l00?lEooooo`03o`00
oooo003ooooo01_ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l05_oo
ool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Ooo
ool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l0
5Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l0
5Oooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooo`00o`00oaGooooo00?o003oool00?oo
ool06oooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0_l00?lFooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?oooooo
o`00o`0Fooooo`03o`00oooo003o003o01Gooooo00?o003oooooool00?l05Oooool00ol00?oooooo
o`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o003oool00?l00?l05Oooool00ol00?oooooo
o`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o003oool00?l00?l05Oooool00ol00?oooooo
ooooo`0Kooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0
0?lFooooo`03o`00oooooooo003o01Gooooo00?o003oool00?l00?l05Oooool00ol00?ooooooo`00
o`0Fooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l0
0?lFooooo`;o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l0
0?lFooooo`03o`00oooooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool2o`00oaKooooo0_l00?lGooooo`;o003o5_ooool2o`00oaKooooo0_l00?lF
ooooo`;o003o5oooool2o`00oaKooooo0_l00?lFooooo`;o003o5oooool2o`00oaKooooo0_l00?lF
ooooo`;o003o5_ooool00ol00?ooooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o00000oooool2o`00oaOooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05Oooool2o`00oaOooooo00?o003ooooo
ooooool06_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Tooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
3_ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@2Oooooo`00YOooool01Ol0003ooooo
oooooooooooo000000;ooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`2Nooooo`008?ooool00onj^[[o<S8booooo`22ooooo`05o`000?oooooooooooooo
ool000004_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo09gooooo000Qooooo`03
o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo09kooooo000Oooooo`05oiRHV?l@413o0000o`00
0?nYZJT0POooool01Ol0003oQhN7oooooonYZJWo000001Cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<09oooooo000Oooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj
Ooooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Qooooo`007oooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@49Ko
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo0:7ooooo000Oooooo`07
okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c02Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`000:3ooooo000Oooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`3ooooood?ooooo
000Oooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool0oooooom1ooooo`008_oo
ool00omVIVKoQhN7ooooo`3oooooodCooooo000Rooooo`03ojVYZOm4A4Cooooo0?ooooooA?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.179101, -1.08612, \
0.0066032, 0.0136036}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The match between the approximate (dashed) and exact (solid) eigenmodes is \
very accurate for the lowest modes, but begins to break down for the \
higher-order modes with variation approaching the scale of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can now use these eigenvalues and eigenvectors to solve any \
initial-value problem that has the above boundary conditions, using the \
general solution of the heat equation. For instance, if we choose ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0)\  = \ x\^3\ \((\[Pi] - x)\)\^3\)]],
  ",  we can determine the subsequent temperature evolution as shown in Cell \
",
  ButtonBox["6.141",
    ButtonData:>"Cell 6.141",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ initial\ condition\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(T0[x_]\  = \ x^3 \((Pi - x)\)^3;\), "\[IndentingNewLine]", 
        StyleBox[\( (*\ 
            determine\ the\ Fourier\ coefficients\ as\ inner\ products\ over\ \
the\ initial\ condition*) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\[IndentingNewLine]", \(A[n_]\  := \ \(A[n]\  = \ 
              NIntegrate[T0[x]\ \(\[Psi][n]\)[x], {x, 0, Pi/2}, 
                  MaxRecursion \[Rule] 20]/
                NIntegrate[\((\(\[Psi][n]\)[x])\)^2, {x, 0, Pi/2}, 
                  MaxRecursion \[Rule] 20]\);\), "\n", 
        "\[IndentingNewLine]", \(T[x_, t_]\  = \ 
            Sum[A[n]\ Exp[\[Lambda]1[\([n]\)]\ t]\ \(\[Psi][n]\)[x], {n, 1, 
                8}];\), "\n", 
        "\[IndentingNewLine]", \(Table[
            Plot[T[x, t], {x, 0, Pi/2}, PlotRange \[Rule] {0, 15}, 
              AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
              PlotLabel -> "\<T[x,\>" <> ToString[t] <> "\<]\>"], {t, 0, 
              1,  .05}];\)}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.141"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02846 1e-05 L
.03279 3e-05 L
.03754 5e-05 L
.0402 6e-05 L
.04262 8e-05 L
.0475 .00012 L
.05281 .00019 L
.05782 .00027 L
.06244 .00037 L
.07218 .00066 L
.07771 .00088 L
.0829 .00113 L
.09334 .00177 L
.10458 .00268 L
.11468 .00372 L
.12571 .00513 L
.1458 .0085 L
.16548 .01288 L
.18645 .01883 L
.22803 .03474 L
.2681 .05539 L
.30665 .0801 L
.34765 .1113 L
.38714 .14567 L
.42511 .18215 L
.46554 .22388 L
.50444 .26601 L
.54581 .31192 L
.58565 .35625 L
.62398 .39811 L
.66476 .44085 L
.70403 .47935 L
.74178 .51314 L
.78198 .54489 L
.82067 .57071 L
.86181 .59251 L
.88234 .60106 L
.90143 .60755 L
.91986 .61246 L
.9293 .61444 L
.93954 .61619 L
.94431 .61686 L
.94935 .61747 L
.95402 .61794 L
s
.95402 .61794 m
.95519 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`00?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool003gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Zooooo`00?Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00[ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02gooooo000mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;Oooool003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000;?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooDoooool2o`0000;ooooo0_l0000@ooooo`00oooooomCooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4?ooool00?ooooooE?ooool01?oMgMgo0000oa0@4?o<c<`Aooooo`005oooooooo`00
037o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^hAooooo`007_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo3Ol00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02oooool01?lQ8B7oMgMgogMgMolb<S8Aooooo`007_ooool00ol0003oooooooooo`0Loooo
o`Co00002oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool07Oooool2o`0000;ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Pooooo`Ko
0000oooooolRooooo`007_ooool00ol0003oooooooooo`0Vooooo`Go0000oooooolMooooo`007_oo
ool00ol0003oooooooooo`0[ooooo`?o0000oooooolJooooo`007_ooool2o`0002oooooo0ol0003o
oooooaOooooo000Nooooo`03o`000?oooooooooo037ooooo0ol0003ooooooaCooooo000Nooooo`03
o`000?oooooooooo03Cooooo0_l0003ooooooa;ooooo000Nooooo`03o`000?oooooooooo03Kooooo
0_l0003ooooooa3ooooo000Nooooo`03o`000?oooooooooo03Sooooo0ol0003oooooo`gooooo000N
ooooo`03o`000?oooooooooo03_ooooo0_l0003oooooo`_ooooo000Nooooo`03o`000?oooooooooo
03gooooo0_l0003oooooo`Wooooo000Nooooo`;o0000@?ooool2o`000?oooooo1oooool001kooooo
00?o0000ooooooooool0@Oooool2o`000?oooooo1Oooool001kooooo00?o0000ooooooooool0@ooo
ool2o`000?oooooo0oooool001kooooo00?o0000ooooooooool0AOooool2o`000?oooooo0Oooool0
01kooooo00?o0000ooooooooool0Aoooool2o`000?kooooo000Nooooo`03o`000?oooooooooo04Wo
oooo0_l0003looooo`007_ooool2o`0004cooooo00?o0000ooooooooool0nOooool001kooooo00?o
0000ooooooooool0C?ooool2o`000?Wooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0003g
ooooo`007_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0?Cooooo000Cooooo`Go
00001_ooool00ol0003oooooooooo`1Aooooo`;o0000m?ooool001?ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A006ooooo`03o`000?oooooooooo05?ooooo0_l0003booooo`005?ooool00onHV9So8B4Q
onk^kP07ooooo`?o0000EOooool00ol0003oooooooooo`3_ooooo`005Oooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0k_ooool001Kooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`1Gooooo`;o0000k_ooool001Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo0>_ooooo000Cooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
0>[ooooo000Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo0>Wooooo000Nooooo`;o0000GOooool2o`000>Wooooo000Nooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0i_ooool001kooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`3Uooooo`007_ooool00ol0003oooooooooo`1Pooooo`;o0000iOooool0
01kooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`3Rooooo`007_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo0>7ooooo000Nooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0h?ooool001kooooo0_l0001Vooooo`03o`000?oooooooooo0=oooooo000N
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0g_ooool001kooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`3Mooooo`007_ooool00ol0003oooooooooo`1Xooooo`03
o`000?oooooooooo0=cooooo000Nooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
foooool001kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3Jooooo`007_ooool2
o`0006cooooo0_l0003Jooooo`007_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
0=Oooooo000Nooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0e_ooool001kooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`3Eooooo`005Oooool2o`000003oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`3Dooooo`005_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0doooool0
01?ooooo1Ol00006ooooo`?o0000L_ooool00ol0003oooooooooo`3Booooo`004oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0dOooool001?o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo
0=3ooooo000Dooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`3?ooooo`005?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool0c_ooool001Gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`1gooooo`03o`000?oooooooooo0<gooooo000Nooooo`;o0000N?ooool00ol0003oooooooooo`3=
ooooo`007_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0<cooooo000Nooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool0boooool001kooooo00?o0000ooooooooool0
N_ooool00ol0003oooooooooo`3:ooooo`007_ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo0<Wooooo000Nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0b?ooool0
01kooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`37ooooo`007_ooool2o`0007oo
oooo00?o0000ooooooooool0a_ooool001kooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`35ooooo`007_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo0<Cooooo000N
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0`oooool001kooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`32ooooo`007_ooool00ol0003oooooooooo`23ooooo`03
o`000?oooooooooo0<7ooooo000Nooooo`;o0000Q?ooool00ol0003oooooooooo`31ooooo`007_oo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0<3ooooo000Nooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0_oooool001kooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooooooo`2nooooo`004oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`2mooooo`004oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`2looooo`004oooool01Ol0003o
oooooooooooooooo000000Kooooo0ol00029ooooo`03o`000?oooooooooo0;_ooooo000Cooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
0;[ooooo000Cooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2;oooo
o`03o`000?oooooooooo0;Wooooo000Cooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`2hooooo`004oooool00ooMgMgo410@oiRHV008ooooo`03o`00
0?oooooooooo08gooooo00?o0000ooooooooool0]oooool001Cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo0;Kooooo000Nooooo`;o0000T?oo
ool00ol0003oooooooooo`2eooooo`007_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo0;Gooooo000Nooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0]?ooool001ko
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`2cooooo`007_ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo0;;ooooo000Nooooo`03o`000?oooooooooo09?ooooo00?o
0000ooooooooool0/Oooool001kooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`2`
ooooo`007_ooool2o`0009Kooooo00?o0000ooooooooool0[oooool001kooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooooooo`2^ooooo`007_ooool00ol0003oooooooooo`2Gooooo`03o`00
0?oooooooooo0:gooooo000Nooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool0[?oo
ool001kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`2[ooooo`007_ooool00ol0
003oooooooooo`2Jooooo`03o`000?oooooooooo0:[ooooo000Nooooo`;o0000W?ooool00ol0003o
ooooooooo`2Yooooo`007_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo0:Sooooo
000Nooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0Z?ooool001kooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`2Wooooo`004oooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`2Vooooo`004oooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`2U
ooooo`004oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Pooooo`03o`000?oooooo
oooo0:Cooooo000Cooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`2Q
ooooo`03o`000?oooooooooo0:?ooooo000Cooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo0:;ooooo000Cooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo0:7ooooo000Coooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo0:3ooooo000Cooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo09oooooo000Nooooo`;o0000Yoooool00ol0003oooooooooo`2Noooo
o`007_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo09gooooo000Nooooo`03o`00
0?oooooooooo0:Sooooo00?o0000ooooooooool0W?ooool001kooooo00?o0000ooooooooool0Z?oo
ool00ol0003oooooooooo`2Looooo`007_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo
oooo09_ooooo000Nooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0V_ooool001ko
oooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`2Iooooo`007_ooool2o`000:gooooo
00?o0000ooooooooool0V?ooool001kooooo00?o0000ooooooooool0[Oooool00ol0003ooooooooo
o`2Gooooo`007_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo09Kooooo000Noooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0U_ooool001kooooo00?o0000oooooooo
ool0[oooool00ol0003oooooooooo`2Eooooo`007_ooool00ol0003oooooooooo`2`ooooo`03o`00
0?oooooooooo09Cooooo000Nooooo`;o0000/_ooool00ol0003oooooooooo`2Cooooo`007_ooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo09;ooooo000Nooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool0TOooool001kooooo00?o0000ooooooooool0]?ooool00ol0003o
ooooooooo`2@ooooo`003?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0Soooool000kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0]_ooool0
0ol0003oooooooooo`2>ooooo`003_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool3o`000;Oooooo00?o0000ooooooooool0SOooool000kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0^?ooool0
0ol0003oooooooooo`2<ooooo`003_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo08_ooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool0R_ooool000kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`29
ooooo`003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`2looooo`03o`000?oooooooooo08Sooooo000Nooooo`;o0000__ooool00ol0
003oooooooooo`27ooooo`007_ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo08Ko
oooo000Nooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0QOooool001kooooo00?o
0000ooooooooool0`?ooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003oooooooooo`31
ooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oooooooooo0<;ooooo00?o0000oooo
ooooool0P_ooool001kooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`21ooooo`00
7_ooool2o`000<Gooooo00?o0000ooooooooool0P?ooool001kooooo00?o0000ooooooooool0aOoo
ool00ol0003oooooooooo`1oooooo`007_ooool00ol0003oooooooooo`36ooooo`03o`000?oooooo
oooo07kooooo000Nooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool0OOooool001ko
oooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`1looooo`007_ooool00ol0003ooooo
ooooo`39ooooo`03o`000?oooooooooo07_ooooo000Nooooo`;o0000boooool00ol0003ooooooooo
o`1jooooo`007_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo07Wooooo000Noooo
o`03o`000?oooooooooo0<cooooo0_l0001iooooo`007_ooool00ol0003oooooooooo`3>ooooo`03
o`000?oooooooooo07Kooooo000<ooooo`Co000000?o410@ooooooooool01Ol00006ooooo`03o`00
0?oooooooooo0<oooooo00?o0000ooooooooool0MOooool000kooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0d?ooool00ol0003ooooo
ooooo`1dooooo`003_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
003Aooooo`03o`000?oooooooooo07?ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3Booooo`03o`000?oooooooooo07;ooooo000>oooo
o`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3Coooo
o`03o`000?oooooooooo077ooooo000>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3Dooooo`03o`000?oooooooooo073ooooo000>ooooo`03o`00
0?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0=Go
oooo00?o0000ooooooooool0Koooool000cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`1^ooooo`00
7_ooool2o`000=Sooooo0_l0001^ooooo`007_ooool00ol0003oooooooooo`3Iooooo`03o`000?oo
oooooooo06_ooooo000Nooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0J_ooool0
01kooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`1Yooooo`007_ooool00ol0003o
ooooooooo`3Looooo`03o`000?oooooooooo06Sooooo000Nooooo`03o`000?oooooooooo0=gooooo
0_l0001Xooooo`007_ooool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo06Gooooo000N
ooooo`;o0000hOooool00ol0003oooooooooo`1Tooooo`007_ooool00ol0003oooooooooo`3Qoooo
o`03o`000?oooooooooo06?ooooo000Nooooo`03o`000?oooooooooo0>;ooooo00?o0000oooooooo
ool0H_ooool001kooooo00?o0000ooooooooool0hoooool2o`0006;ooooo000Nooooo`03o`000?oo
oooooooo0>Gooooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`3Wooooo`03o`000?oooooo
oooo05gooooo000Nooooo`;o0000jOooool2o`0005gooooo000Nooooo`03o`000?oooooooooo0>[o
oooo0_l0001Kooooo`007_ooool00ol0003oooooooooo`3/ooooo`03o`000?oooooooooo05Sooooo
000Nooooo`03o`000?oooooooooo0>gooooo0_l0001Hooooo`003?ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0>oooooo0_l0001F
ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0lOooool2o`0005Cooooo000>ooooo`03o`000?oooooooooo00;ooooo1Ol00006ooooo`?o
0000loooool2o`0005;ooooo000>ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`3eooooo`;o0000D?ooool000kooooo00?o0000ooooooooool0
0_ooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?Oooooo00?o0000oooooooo
ool0COooool000kooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`000007ooooo`03o`00
0?oooooooooo0?Sooooo0_l0001=ooooo`003_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0n_ooool2o`0004_ooooo000<ooooo`03oeEEEOmVIVKo
000000Kooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3looooo`;o0000BOooool0
01kooooo0_l0003oooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0ooooool1ooooo`;o
0000AOooool001kooooo00?o0000ooooooooool0ooooool3ooooo`?o0000@_ooool001kooooo00?o
0000ooooooooool0ooooool6ooooo`?o0000?oooool001kooooo00?o0000ooooooooool0ooooool9
ooooo`Co0000>oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`Co0000=oooool001ko
oooo00?o0000ooooooooool0oooooolAooooo`Ko0000<Oooool001kooooo00?o0000ooooooooool0
oooooolGooooo`?o0000;_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Cooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
002Vooooo`00Y?ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`2T
ooooo`00VOooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`2Tooooo`00Voooool00ol0003oooooooooo`06ooooo`0:o`000?oo
ooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0Y?ooool009_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0:Cooooo002Kooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`2Tooooo`00Voooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0Y?ooool009Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Wooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo0:Cooooo002H
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`2Tooooo`00V?oo
ool7o`0000Gooooo0_l0000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool2o`000:Kooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.167107, -1.20328, \
0.00679425, 0.0999796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .02149 L
.10458 .0449 L
.14415 .06681 L
.18221 .08777 L
.22272 .10994 L
.26171 .13106 L
.30316 .15323 L
.34309 .17422 L
.3815 .19401 L
.42237 .21452 L
.46172 .23364 L
.49955 .25133 L
.53984 .26931 L
.57861 .28567 L
.61984 .3019 L
.65954 .31628 L
.69774 .32882 L
.73838 .34068 L
.77751 .35053 L
.81909 .35922 L
.85916 .36575 L
.89771 .37029 L
.91765 .37194 L
.92769 .37259 L
.93871 .37317 L
.94818 .37354 L
.9568 .37379 L
.96157 .37389 L
.96409 .37393 L
.96676 .37397 L
.96909 .37399 L
.97041 .374 L
.97166 .37401 L
.9728 .37401 L
.97384 .37402 L
.97498 .37402 L
.97619 .37402 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`00?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool003gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Zooooo`00?Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00[ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02gooooo000mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;Oooool003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000;?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooDoooool2o`0000;ooooo0_l0000@ooooo`00oooooomCooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4?ooool00?ooooooE?ooool01?oMgMgo0000oa0@4?o<c<`Aooooo`005oooooooo`00
037o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^hAooooo`007_ooool01?l0003oooooo`000?l00005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool01?lQ8B7oMgMgogMgMolb
<S8Aooooo`007_ooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01gooooo0_l00002ooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool00_ooool2o`000?ooooooA?ooool001kooooo00?o0000oooo
ooooool01?ooool2o`000?oooooo@_ooool001kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooocoooooo000Nooooo`;o00002?ooool2o`000?oooooo?oooool001kooooo00?o
0000ooooooooool02Oooool2o`000?oooooo?Oooool001kooooo00?o0000ooooooooool02oooool2
o`000?oooooo>oooool001kooooo00?o0000ooooooooool03Oooool2o`000?oooooo>Oooool001ko
oooo00?o0000ooooooooool03oooool2o`000?oooooo=oooool001kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`3oooooocCooooo000Nooooo`03o`000?oooooooooo01;ooooo0_l0
003oooooocCooooo000Nooooo`;o00005Oooool2o`000?oooooo<_ooool001kooooo00?o0000oooo
ooooool05_ooool2o`000?oooooo<?ooool001kooooo00?o0000ooooooooool06?ooool2o`000?oo
oooo;_ooool001kooooo00?o0000ooooooooool06_ooool2o`000?oooooo;?ooool001kooooo00?o
0000ooooooooool07?ooool2o`000?oooooo:_ooool001kooooo00?o0000ooooooooool07_ooool2
o`000?oooooo:?ooool001kooooo0_l0000Qooooo`;o0000oooooolVooooo`007_ooool00ol0003o
ooooooooo`0Rooooo`;o0000oooooolTooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo0?oooooo8Oooool001kooooo00?o0000ooooooooool09Oooool2o`000?oooooo8Ooo
ool001?ooooo1Ol00006ooooo`03o`000?oooooooooo02Oooooo0_l0003ooooooaoooooo000Coooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo0?oooooo7?ooool001Cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`0002[ooooo0_l0003ooooo
oacooooo000Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`3ooooooaWooooo000Fooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
;Oooool2o`000?oooooo6Oooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0_ooooo`;o0000oooooolGooooo`004oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0<Oooool2o`000?oooooo5Oooool001?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo03?ooooo0_l0003ooooooa?ooooo000Nooooo`;o0000=_ooool0
0ol0003oooooooooo`3ooooooa3ooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l0003ooooo
oa3ooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0003oooooo`kooooo000Nooooo`03o`00
0?oooooooooo03[ooooo0_l0003oooooo`cooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0
003oooooo`[ooooo000Nooooo`03o`000?oooooooooo03kooooo0_l0003oooooo`Sooooo000Noooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0ooooool5ooooo`007_ooool2o`0004;o
oooo0_l0003oooooo`Gooooo000Nooooo`03o`000?oooooooooo04?ooooo0_l0003oooooo`?ooooo
000Nooooo`03o`000?oooooooooo04Gooooo0_l0003oooooo`7ooooo000Nooooo`03o`000?oooooo
oooo04Oooooo0_l0003nooooo`007_ooool00ol0003oooooooooo`19ooooo`;o0000o?ooool001ko
oooo00?o0000ooooooooool0Boooool2o`000?[ooooo000Nooooo`;o0000C_ooool00ol0003ooooo
ooooo`3gooooo`007_ooool00ol0003oooooooooo`1>ooooo`;o0000moooool001kooooo00?o0000
ooooooooool0D?ooool2o`000?Gooooo000Nooooo`03o`000?oooooooooo05;ooooo0_l0003coooo
o`005Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool2o`000?7o
oooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool2o`000>oooooo
000Cooooo`Go00001_ooool3o`0005Sooooo0_l0003]ooooo`004oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo05[ooooo0_l0003[ooooo`004oooool01?oMgMgoEEEEooooool0
0007ooooo`03o`000?oooooooooo05cooooo0_l0003Yooooo`005?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo05kooooo0_l0003Wooooo`005?ooool00oo^k^koA4A4o`000007oooo
o`03o`000?oooooooooo063ooooo0_l0003Uooooo`005Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo06;ooooo0_l0003Sooooo`007_ooool2o`0006Gooooo0_l0003Qooooo`007_oo
ool00ol0003oooooooooo`1Vooooo`;o0000goooool001kooooo00?o0000ooooooooool0J?ooool2
o`000=gooooo000Nooooo`03o`000?oooooooooo06[ooooo0_l0003Kooooo`007_ooool00ol0003o
ooooooooo`1/ooooo`;o0000fOooool001kooooo00?o0000ooooooooool0K_ooool2o`000=Oooooo
000Nooooo`03o`000?oooooooooo073ooooo0_l0003Eooooo`007_ooool2o`0007?ooooo0_l0003C
ooooo`007_ooool00ol0003oooooooooo`1dooooo`;o0000dOooool001kooooo00?o0000oooooooo
ool0M_ooool2o`000<oooooo000Nooooo`03o`000?oooooooooo07Sooooo0_l0003=ooooo`007_oo
ool00ol0003oooooooooo`1jooooo`;o0000boooool001kooooo00?o0000ooooooooool0O?ooool2
o`000<Wooooo000Nooooo`;o0000Ooooool2o`000<Oooooo000Nooooo`03o`000?oooooooooo083o
oooo0_l00035ooooo`007_ooool00ol0003oooooooooo`22ooooo`;o0000`oooool001kooooo00?o
0000ooooooooool0Q?ooool3o`000<3ooooo000Cooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`27ooooo`;o0000__ooool001?ooooo00GoEEEEogMgMoooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo08Wooooo0_l0002looooo`004oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol0002;ooooo`?o0000^Oooool001?ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo08kooooo0_l0002gooooo`004oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0T?ooool2o`000;Gooooo000Cooooo`03oeEEEOn7QhOo
oooo00Sooooo00?o0000ooooooooool0T_ooool2o`000;?ooooo000Cooooo`03omgMgOl@413oV9RH
00Sooooo00?o0000ooooooooool0U?ooool2o`000;7ooooo000Dooooo`04olc<c?m4A4Co0000oa0@
40Kooooo00?o0000ooooooooool0U_ooool2o`000:oooooo000Nooooo`;o0000VOooool2o`000:go
oooo000Nooooo`03o`000?oooooooooo09[ooooo0_l0002[ooooo`007_ooool00ol0003ooooooooo
o`2Looooo`?o0000Z?ooool001kooooo00?o0000ooooooooool0Woooool2o`000:Kooooo000Noooo
o`03o`000?oooooooooo0:7ooooo0_l0002Tooooo`007_ooool00ol0003oooooooooo`2Sooooo`?o
0000XOooool001kooooo00?o0000ooooooooool0Y_ooool2o`0009oooooo000Nooooo`;o0000ZOoo
ool3o`0009cooooo000Nooooo`03o`000?oooooooooo0:_ooooo0_l0002Jooooo`007_ooool00ol0
003oooooooooo`2]ooooo`;o0000V?ooool001kooooo00?o0000ooooooooool0[oooool3o`0009Go
oooo000Nooooo`03o`000?oooooooooo0;;ooooo0ol0002Booooo`007_ooool00ol0003ooooooooo
o`2eooooo`?o0000Soooool001kooooo0_l0002iooooo`?o0000S?ooool001kooooo00?o0000oooo
ooooool0^oooool3o`0008Wooooo000Nooooo`03o`000?oooooooooo0;kooooo0ol00026ooooo`00
7_ooool00ol0003oooooooooo`31ooooo`?o0000Poooool001?ooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0<Cooooo0ol00020ooooo`004oooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool0aoooool3o`0007gooooo000Cooooo`05o`000?oo
ooooooooooooool000001_ooool3o`000<[ooooo0ol0001jooooo`004oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo00?o0000ooooooooool0cOooool3o`0007Oooooo000Cooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3@ooooo`?o0000M?ooool001?ooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0=?ooooo0ol0001aooooo`004ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0e_ooool3o`0006kooooo
000Cooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3Iooooo`Co0000
J_ooool001kooooo0_l0003Nooooo`Co0000I_ooool001kooooo00?o0000ooooooooool0hOooool5
o`00067ooooo000Nooooo`03o`000?oooooooooo0>Kooooo1ol0001Jooooo`007_ooool00ol0003o
ooooooooo`3]ooooo`Ko0000E?ooool001kooooo00?o0000ooooooooool0loooool6o`0004kooooo
000Nooooo`03o`000?oooooooooo0?Wooooo1_l00018ooooo`007_ooool00ol0003oooooooooo`3o
ooooo`Go0000@oooool001kooooo0_l0003oooooo`Kooooo4_l0000aooooo`007_ooool00ol0003o
ooooooooo`3ooooooaOooooo2Ol0000Xooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo0?ooooooB?ooool000kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooom8ooooo`003_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool3o`000?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooodSooooo
000>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool4o`000003oa0@4?oooooooooo
00Go00001_ooool00ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00;o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooB?ooool000ko
oooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`?o0000oooooom8ooooo`00
3_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
oooooom8ooooo`003_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`02oooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3oooooodSooooo000<oooo
o`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000<ooooo`Co0000
00?o410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`02ooooo`Go00001_ooool3
o`000?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01?m4A4CogMgMooooool00007
ooooo`03o`000?oooooooooo0?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01?oM
gMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?ooooooB?ooool000kooooo00?o0000oooo
ooooool00oooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?ooooooB?ooool000ko
oooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000cooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`06ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool009cooooo0_l0000;ooooo`03o`000?nj^[[ooooo01_o
oooo0_l0002Oooooo`00W?ooool00ol0003oooooooooo`0:ooooo`;o<S8b7Oooool00ol0003ooooo
ooooo`2Mooooo`00T_ooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00?o0000oooo
ooooool0WOooool009Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`03o`00
0?oooooooooo09gooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool01?oMgMgo0000oa0@4?o<c<`:ooooo`05oa0@4?ooooooooooooooool@41003oooool01Ol0003o
oooooooooooooooo000009oooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05o`000?ooooooooooooooool000003_ooool0
0onYZJWo410@ooooo`02ooooo`03o`000?oooooooooo09gooooo002Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P03ooooo`03o`000?oooooooooo09gooooo002A
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj
^_lQ8B7ooooo00;ooooo00?o0000ooooooooool0WOooool0097ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool00ol0003oooooooooo`2Moooo
o`00TOooool7o`0000Cooooo0_l0000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnY
ZJWo410@o`000?l@413oZJVY00;ooooo0_l0002Oooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.167107, -1.20328, \
0.00679425, 0.0999796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .0171 L
.10458 .03566 L
.14415 .05295 L
.18221 .06938 L
.22272 .08658 L
.26171 .10279 L
.30316 .11958 L
.34309 .13524 L
.3815 .14977 L
.42237 .1646 L
.46172 .17818 L
.49955 .19056 L
.53984 .20293 L
.57861 .21401 L
.61984 .22483 L
.65954 .23428 L
.69774 .24241 L
.73838 .25002 L
.77751 .25626 L
.81909 .26172 L
.85916 .2658 L
.87754 .26728 L
.89771 .26861 L
.91765 .26964 L
.92854 .27007 L
.93871 .27039 L
.94354 .27052 L
.94878 .27064 L
.95341 .27073 L
.95832 .2708 L
.96273 .27085 L
.96524 .27088 L
.9676 .27089 L
.96976 .27091 L
.97173 .27091 L
.97277 .27092 L
.97391 .27092 L
.97509 .27092 L
.97619 .27092 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`00?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool003gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Zooooo`00?Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00[ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02gooooo000mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;Oooool003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000;?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooDoooool2o`0000;ooooo0_l0000@ooooo`00oooooomCooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4?ooool00?ooooooE?ooool01?oMgMgo0000oa0@4?o<c<`Aooooo`005oooooooo`00
037o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^hAooooo`007_ooool00ol0003oooooo`000002o`00
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`04ob4Q8OmgMgOoMgMg
oc8b<Q7ooooo000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Wooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo00Cooooo0_l0003ooooood;ooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0ol0003oooooocoooooo000Nooooo`03o`000?oooooooooo00Wooooo0_l0
003oooooocgooooo000Nooooo`;o00003?ooool2o`000?oooooo>oooool001kooooo00?o0000oooo
ooooool03Oooool2o`000?oooooo>Oooool001kooooo00?o0000ooooooooool03oooool3o`000?oo
oooo=_ooool001kooooo00?o0000ooooooooool04_ooool2o`000?oooooo=?ooool001kooooo00?o
0000ooooooooool05?ooool2o`000?oooooo<_ooool001kooooo00?o0000ooooooooool05_ooool2
o`000?oooooo<?ooool001kooooo00?o0000ooooooooool06?ooool3o`000?oooooo;Oooool001ko
oooo0_l0000Looooo`;o0000ooooool[ooooo`007_ooool00ol0003oooooooooo`0Mooooo`;o0000
oooooolYooooo`007_ooool00ol0003oooooooooo`0Oooooo`?o0000oooooolVooooo`007_ooool0
0ol0003oooooooooo`0Rooooo`;o0000oooooolTooooo`007_ooool00ol0003oooooooooo`0Toooo
o`;o0000oooooolRooooo`007_ooool00ol0003oooooooooo`0Vooooo`?o0000oooooolOooooo`00
7_ooool2o`0002[ooooo0_l0003ooooooagooooo000Nooooo`03o`000?oooooooooo02_ooooo0_l0
003ooooooa_ooooo000Nooooo`03o`000?oooooooooo02gooooo0_l0003ooooooaWooooo000Noooo
o`03o`000?oooooooooo02oooooo0ol0003ooooooaKooooo000Cooooo`Go00001_ooool00ol0003o
ooooooooo`0booooo`?o0000oooooolCooooo`004oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool0=Oooool2o`000?oooooo4Oooool001Cooooo00?oV9RHob4Q8Oo^k^h0
1oooool3o`0003Oooooo0ol0003oooooo`kooooo000Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o
0000ooooooooool0>_ooool2o`000?oooooo3?ooool001Kooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`0looooo`;o0000ooooool:ooooo`005oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03kooooo0ol0003oooooo`Oooooo000Cooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`11ooooo`;o0000ooooool5ooooo`004oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0@oooool2o`000?oooooo0oooool001ko
oooo0_l00016ooooo`;o0000ooooool1ooooo`007_ooool00ol0003oooooooooo`17ooooo`?o0000
oOooool001kooooo00?o0000ooooooooool0B_ooool3o`000?[ooooo000Nooooo`03o`000?oooooo
oooo04gooooo0_l0003hooooo`007_ooool00ol0003oooooooooo`1?ooooo`?o0000mOooool001ko
oooo00?o0000ooooooooool0D_ooool2o`000??ooooo000Nooooo`03o`000?oooooooooo05Cooooo
0ol0003`ooooo`007_ooool2o`0005Sooooo0_l0003^ooooo`007_ooool00ol0003oooooooooo`1I
ooooo`;o0000k?ooool001kooooo00?o0000ooooooooool0Foooool3o`000>Wooooo000Nooooo`03
o`000?oooooooooo05kooooo0_l0003Wooooo`007_ooool00ol0003oooooooooo`1Pooooo`?o0000
i?ooool001kooooo00?o0000ooooooooool0Hoooool2o`000>;ooooo000Nooooo`;o0000I_ooool2
o`000>3ooooo000Nooooo`03o`000?oooooooooo06Oooooo0ol0003Mooooo`007_ooool00ol0003o
ooooooooo`1Zooooo`?o0000f_ooool001kooooo00?o0000ooooooooool0KOooool3o`000=Oooooo
000Eooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`?o0000e?oo
ool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1cooooo`?o0000dOooool0
01?ooooo1Ol00006ooooo`?o0000M_ooool3o`000<kooooo000Cooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool0NOooool3o`000<_ooooo000Cooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool0O?ooool3o`000<Sooooo000Dooooo`03ogMgMoo<c<co000000Oo
oooo00?o0000ooooooooool0Ooooool3o`000<Gooooo000Dooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool0P_ooool3o`000<;ooooo000Eooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0QOooool3o`000;oooooo000Nooooo`;o0000ROooool3o`000;cooooo000Noooo
o`03o`000?oooooooooo08_ooooo0ol0002iooooo`007_ooool00ol0003oooooooooo`2>ooooo`?o
0000]_ooool001kooooo00?o0000ooooooooool0TOooool3o`000;?ooooo000Nooooo`03o`000?oo
oooooooo09Cooooo0ol0002`ooooo`007_ooool00ol0003oooooooooo`2Gooooo`?o0000[Oooool0
01kooooo00?o0000ooooooooool0V_ooool3o`000:[ooooo000Nooooo`;o0000W_ooool4o`000:Ko
oooo000Nooooo`03o`000?oooooooooo0:7ooooo1?l0002Rooooo`007_ooool00ol0003ooooooooo
o`2Uooooo`Co0000W_ooool001kooooo00?o0000ooooooooool0ZOooool4o`0009[ooooo000Noooo
o`03o`000?oooooooooo0:gooooo1?l0002Fooooo`007_ooool00ol0003oooooooooo`2aooooo`Co
0000T_ooool001kooooo0_l0002fooooo`Co0000S_ooool001kooooo00?o0000ooooooooool0^Ooo
ool4o`0008[ooooo000Nooooo`03o`000?oooooooooo0;gooooo1?l00026ooooo`007_ooool00ol0
003oooooooooo`31ooooo`Co0000P_ooool001?ooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0<Gooooo1?l0001nooooo`004oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0bOooool5o`0007Wooooo000Cooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000<kooooo1_l0001cooooo`004oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0e?ooool6o`0006gooooo000Cooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`3Jooooo`Ko0000Ioooool001?ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`3Pooooo`Ko0000HOooool001?ooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`3Vooooo`Oo0000F_ooool001Cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`3]ooooo`Wo0000DOooool001kooooo0_l0003gooooo`ko0000@ooo
ool001kooooo00?o0000ooooooooool0ooooool5oooooa_o0000:?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Cooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3oooooodSooooo000Cooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`3oooooodSooooo000Cooooo`05o`000?ooooooooooooooool000001_ooool3
o`000?ooooooB?ooool001?ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001?ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001?ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001?ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000<ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0oooooom8
ooooo`003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`?o0000oooooom8ooooo`003_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooodSooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodSooooo000<oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o0000
oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0
003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000<ooooo`Co0000
00?o410@ooooooooool01Ol00006ooooo`03o`000?oooooooooo0?ooooooB?ooool000kooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
oooooom8ooooo`003_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
003oooooodSooooo000>ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool0
0ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`00
0?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?oo
ooooB?ooool000cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool000cooooo1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00;o
oooo1Ol00006ooooo`?o0000oooooom8ooooo`003_ooool00ol0003oooooooooo`02ooooo`04odA4
A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooom8ooooo`00
3_ooool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
oooooom8ooooo`003_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0oooooom8ooooo`003?ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W?ooool2o`0000_ooooo00?o
0000okZj^_ooool06oooool2o`0009oooooo002Looooo`03o`000?oooooooooo00[ooooo0_lb<S8M
ooooo`03o`000?oooooooooo09gooooo002Booooo`05oa0@4?l0003o0000o`000?l@41001Oooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
0oooool00ol0003oooooooooo`2Mooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00?ooooo00?o0000ooooooooool0WOooool009Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0[ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2Mooooo`00U?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@03oooo
o`03o`000?oooooooooo09gooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool000002oooool0
1Ol0003oEEEEo`000?l@413oc<c<00?ooooo00?o0000ooooooooool0WOooool0097ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
1Oooool00ol0003oooooooooo`2Mooooo`00TOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P01Oooool00ol0003oooooooooo`2Mooooo`00TOooool7o`0000Cooooo
0_l0000Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4102oooo
o`;o0000Woooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.167107, -1.20328, \
0.00679425, 0.0999796}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0 0.0412023 [
[.17539 -0.0125 -12 -9 ]
[.17539 -0.0125 12 0 ]
[.32696 -0.0125 -9 -9 ]
[.32696 -0.0125 9 0 ]
[.47854 -0.0125 -12 -9 ]
[.47854 -0.0125 12 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -12 -9 ]
[.78169 -0.0125 12 0 ]
[.93327 -0.0125 -9 -9 ]
[.93327 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .0824 -6 -4.5 ]
[.01131 .0824 0 4.5 ]
[.01131 .16481 -6 -4.5 ]
[.01131 .16481 0 4.5 ]
[.01131 .24721 -6 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .32962 -6 -4.5 ]
[.01131 .32962 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .49443 -12 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .57683 -12 -4.5 ]
[.01131 .57683 0 4.5 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.25)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(0.5)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(0.75)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(1)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(1.25)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(1.5)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .0824 m
.03006 .0824 L
s
[(2)] .01131 .0824 1 0 Mshowa
.02381 .16481 m
.03006 .16481 L
s
[(4)] .01131 .16481 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(6)] .01131 .24721 1 0 Mshowa
.02381 .32962 m
.03006 .32962 L
s
[(8)] .01131 .32962 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(10)] .01131 .41202 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(12)] .01131 .49443 1 0 Mshowa
.02381 .57683 m
.03006 .57683 L
s
[(14)] .01131 .57683 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01274 L
.10458 .02658 L
.14415 .03946 L
.18221 .05169 L
.22272 .06449 L
.26171 .07653 L
.30316 .08899 L
.34309 .1006 L
.3815 .11136 L
.42237 .12232 L
.46172 .13235 L
.49955 .14146 L
.53984 .15057 L
.57861 .1587 L
.61984 .16664 L
.65954 .17355 L
.69774 .17951 L
.73838 .18506 L
.77751 .18962 L
.81909 .19359 L
.85916 .19656 L
.87754 .19764 L
.89771 .19861 L
.91765 .19936 L
.92854 .19967 L
.93871 .19991 L
.94354 .2 L
.94878 .20009 L
.95341 .20015 L
.95832 .2002 L
.96273 .20024 L
.96524 .20026 L
.9676 .20027 L
.96976 .20028 L
.97173 .20028 L
.97277 .20029 L
.97391 .20029 L
.97509 .20029 L
.97619 .20029 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd07Oooool4o`000003oa0@4?oooooooooo01_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`00?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`0Fooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo02[ooooo000mooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool003gooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo01Kooooo00?o0000oooo
ooooool03_ooool00omgMgOo<S8booooo`0Zooooo`00?Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00[ooooo`00?Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02gooooo000mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool05_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0;Oooool003gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00007_ooool00omEEEGoIVIVo`00
000Oooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
5_ooool00omEEEGoIVIVo`00000=ooooo`Co0000;?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooDoooool2o`0000;ooooo0_l0000@ooooo`00oooooomCooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4?ooool00?ooooooE?ooool01?oMgMgo0000oa0@4?o<c<`Aooooo`005oooooooo`00
037o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^hAooooo`007_ooool00ol0003oooooooooo`03o`00
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`04ob4Q8OmgMgOoMgMg
oc8b<Q7ooooo000Nooooo`03o`000?oooooooooo00?ooooo0ol0000Uooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Mooooo`;o00000_ooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo00Kooooo0ol0003oooooocoooooo000Nooooo`03o`00
0?oooooooooo00Wooooo0ol0003ooooooccooooo000Nooooo`03o`000?oooooooooo00cooooo0ol0
003oooooocWooooo000Nooooo`;o00004?ooool3o`000?oooooo=_ooool001kooooo00?o0000oooo
ooooool04_ooool3o`000?oooooo<oooool001kooooo00?o0000ooooooooool05Oooool4o`000?oo
oooo;oooool001kooooo00?o0000ooooooooool06Oooool3o`000?oooooo;?ooool001kooooo00?o
0000ooooooooool07?ooool3o`000?oooooo:Oooool001kooooo00?o0000ooooooooool07oooool3
o`000?oooooo9_ooool001kooooo00?o0000ooooooooool08_ooool2o`000?oooooo9?ooool001ko
oooo0_l0000Uooooo`?o0000oooooolQooooo`007_ooool00ol0003oooooooooo`0Wooooo`?o0000
oooooolNooooo`007_ooool00ol0003oooooooooo`0Zooooo`?o0000oooooolKooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`?o0000oooooolHooooo`007_ooool00ol0003oooooooooo`0`oooo
o`?o0000oooooolEooooo`007_ooool00ol0003oooooooooo`0cooooo`?o0000oooooolBooooo`00
7_ooool2o`0003Oooooo0ol0003oooooo`oooooo000Nooooo`03o`000?oooooooooo03Wooooo1?l0
003oooooo`_ooooo000Nooooo`03o`000?oooooooooo03gooooo1?l0003oooooo`Oooooo000Noooo
o`03o`000?oooooooooo047ooooo0ol0003oooooo`Cooooo000Cooooo`Go00001_ooool00ol0003o
ooooooooo`14ooooo`Co0000ooooool001?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo04Sooooo0ol0003looooo`005?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000
Boooool3o`000?Wooooo000Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0C_oo
ool3o`000?Kooooo000Fooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0DOooool4
o`000?;ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0EOooool3o`00
0>oooooo000Cooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`1Hoooo
o`?o0000k?ooool001?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
05_ooooo0ol0003Yooooo`007_ooool2o`0005oooooo0ol0003Vooooo`007_ooool00ol0003ooooo
ooooo`1Qooooo`Co0000h_ooool001kooooo00?o0000ooooooooool0IOooool4o`000=kooooo000N
ooooo`03o`000?oooooooooo06Wooooo1?l0003Jooooo`007_ooool00ol0003oooooooooo`1]oooo
o`Co0000e_ooool001kooooo00?o0000ooooooooool0LOooool4o`000=;ooooo000Nooooo`03o`00
0?oooooooooo07Gooooo1?l0003>ooooo`007_ooool2o`0007[ooooo1?l0003:ooooo`007_ooool0
0ol0003oooooooooo`1mooooo`Co0000a_ooool001kooooo00?o0000ooooooooool0POooool4o`00
0<;ooooo000Nooooo`03o`000?oooooooooo08Gooooo1?l0002nooooo`007_ooool00ol0003ooooo
ooooo`29ooooo`Co0000^_ooool001kooooo00?o0000ooooooooool0SOooool4o`000;Kooooo000N
ooooo`;o0000T_ooool4o`000;;ooooo000Nooooo`03o`000?oooooooooo09Gooooo1?l0002^oooo
o`007_ooool00ol0003oooooooooo`2Iooooo`Go0000ZOooool001kooooo00?o0000ooooooooool0
W_ooool6o`000:?ooooo000Eooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`2Tooooo`Go0000W_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Y
ooooo`Co0000V_ooool001?ooooo1Ol00006ooooo`?o0000[Oooool4o`0009Kooooo000Cooooo`04
odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0/Oooool5o`00097ooooo000Cooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0]_ooool6o`0008_ooooo000Dooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0_?ooool6o`0008Gooooo000Dooooo`03onk^
k_m4A4Co000000Oooooo00?o0000ooooooooool0`_ooool6o`0007oooooo000Eooooo`03ogMgMol0
003ooooo00Kooooo00?o0000ooooooooool0b?ooool9o`0007Kooooo000Nooooo`;o0000d_ooool9
o`0006gooooo000Nooooo`03o`000?oooooooooo0=[ooooo1_l0001Wooooo`007_ooool00ol0003o
ooooooooo`3Pooooo`[o0000GOooool001kooooo00?o0000ooooooooool0j_ooool<o`00057ooooo
000Nooooo`03o`000?oooooooooo0?Kooooo5?l0000mooooo`007_ooool00ol0003oooooooooo`3o
ooooo`_ooooo5Ol0000Xooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`;o
0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`05
o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool001?ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0oooooom8ooooo`005?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`;o0000oooooom9ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Coooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3oooooodSooooo000Coooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3oooooodSooooo000Coooo
o`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool001?ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00Goc<c<o`00
0?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool001?ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000<ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPKooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodSooooo000>oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000oooooom8
ooooo`003_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB?ooool000kooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooom8
ooooo`003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`3oooooodSooooo000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003ooooo
odWooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`;o0000oooooom9ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000<ooooo`Co000000?o410@ooooooooool01Ol00006ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000kooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0003oooooodSooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3oooooodSooooo000>oooo
o`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooo
odSooooo000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000>ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_oooooo
V9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooB?ooool000cooooo00?oEEEEofIVI_l00000
1?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0_l0003oooooodWooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool2o`000?ooooooBOooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000cooooo1?l000000ol@413oooooooooo`02
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`3oooooodSooooo000>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
odSooooo000>ooooo`03o`000?oooooooooo00;ooooo1Ol00006ooooo`?o0000oooooom8ooooo`00
3_ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool0oooooom8ooooo`003_ooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003oooooooooo`03ooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`003_ooool00ol0003ooooooooo
o`03ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool0
0omEEEGoIVIVo`000006ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool2o`000?ooooooBOooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00W?ooool2o`0000_ooooo00?o0000okZj^_ooool06oooool2o`0009oooooo002L
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8Mooooo`03o`000?oooooooooo09gooooo002Boooo
o`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2
o`0000;ooooo00?oQhN7o`000?nj^[X01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`04oa0@4?l0003oA4A4olc<c0Cooooo00?o0000ooooooooool0WOooool009Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM0_ooool00oo<c<co0000oa0@4004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oV9RHoa0@4?oMgMd00oooool00ol0003oooooooooo`2Mooooo`00U?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oQhN7oeEEEOooool00_ooool00ol0003oooooooooo`2M
ooooo`00U?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q
8Ol@413ok^k^2_ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000003ooooo`03o`000?oooooooooo09gooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool0
00002oooool01OlQ8B7oQhN7oooooonHV9So000000?ooooo00?o0000ooooooooool0WOooool0097o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo09gooooo002Aooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE00?ooooo00?o0000oooooooo
ool0WOooool0097ooooo1ol00004ooooo`;o00004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Goc<c<oa0@4?l0003o<S8bonk^kP02ooooo`;o0000Woooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.167107, -1.20328, \
0.00679425, 0.0999796}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "As expected, the solution rapidly relaxes to the form of the lowest \
eigenmode, which decays away at rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_1\)]],
  ". Since the decay rate and the eigenfunction are both well approximated by \
our numerics, the solution is very accurate. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: 2D Drumhead Eigenmodes", "Section",
  CellTags->{"i:47", "c:33"}],

Cell[TextData[{
  "It is also possible to determine eigenmodes for 2D or 3D problems using \
the grid method. However, difficulties arise in taking proper account of the \
boundary conditions. Fortunately, with help from ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " these difficulties can be overcome."
}], "Text"],

Cell["\<\
\tAs an example, consider the eigenmodes of a 2D drumhead, which \
satisfy \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\^\(\(2\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\( \[Psi]\_\(m\ n\)\)(x, 
            y)\)\  = \(\[Lambda]\_\(m\ n\)\) \(\(\[Psi]\_\(m\ n\)\)(x, 
            y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "subject to the boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(m\ n\) = 0\)]],
  "  on some given boundary.  In this example, we will take the boundary to \
be a triangular box given by the equations ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  "(see Cell ",
  ButtonBox["6.144",
    ButtonData:>"Cell 6.144",
    ButtonStyle->"Hyperlink"],
  ").  Eigenmodes and eigenvalues for this problem can be determined \
analytically, and are of the form "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Psi]\_\(m\ n\)\)(x, 
          y) = \(sin(m\ \[VeryThinSpace]\[Pi]\ x)\) \(sin(
              n\ \[Pi]\ y)\) - \(sin(n\ \[Pi]\ x)\) \(sin(
              m\ \[Pi]\ y)\)\)\(,\)\)\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(m\ n\) = \ \(\(\[Pi]\^2\)(
            m\^2 + n\^2)\)\ c\^2\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 1, 2,  ... , \ \ \ \ m = 1, 2,  ... , 
      n - 1\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(6.3.7)"],

Cell[TextData[{
  "\tWe first centered-difference the Laplacian operator on a rectangular \
grid, chosen so that grid points lie on the boundary, just as in Eq. ",
  ButtonBox["(6.2.35)",
    ButtonData:>"(6.2.35)",
    ButtonStyle->"Hyperlink"],
  ". In this example we take ",
  Cell[BoxData[
      \(TraditionalForm\`M\_x = \(M\_y = 20\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_x = \(L\_y = \(c = 1\)\)\)]],
  ": "
}], "Text"],

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(M\_x = 20; \ M\_y = 20;\), "\n", 
    \(L\_x = \ 1. ; L\_y = \ 1. ;\), "\n", 
    \(\(c = 1;\)\), "\n", 
    \(\[CapitalDelta]x = L\_x/M\_x; \[CapitalDelta]y = L\_y/M\_y;\), "\n", 
    \(x0\  = \ 0; \ y0 = 0;\), "\n", 
    \(\(x[j_]\  = \ x0\  + \ j\ \[CapitalDelta]x;\)\), "\n", 
    \(\(y[k_]\  = y0\  + \ k\ \[CapitalDelta]y;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.142"],

Cell["\<\
The homogeneous boundary conditions are specified by the following \
statements: \
\>", "Text"],

Cell[BoxData[{
    \(\[Psi][j_, k_]\  := \ \ 0 /; \ 
        j \[LessEqual] \ f[k]\), "\[IndentingNewLine]", 
    \(\[Psi][j_, k_]\  := 
      0\  /; \ j \[GreaterEqual] \ g[k]\), "\[IndentingNewLine]", 
    \(\(\[Psi][j_, 0]\  := 0;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][j_, M\_y]\  := \ 0;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(g[k_]\  = \ M\_x;\)\), "\n", 
    \(\(f[k_]\  = \ \ k;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.143"],

Cell[TextData[{
  "The triangular shape of this boundary is shown in Cell ",
  ButtonBox["6.144",
    ButtonData:>"Cell 6.144",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[
        Join[Table[{x[f[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[g[k]], \ y[k]}, {k, 0, M\_y}], 
          Table[{x[j], \ y[0]}, {j, 0, M\_x}]], AspectRatio \[Rule] 1, 
        AxesOrigin \[Rule] {\(- .2\), \(- .2\)}, 
        PlotRange \[Rule] {{\(- .2\), 1.2}, {\(- .2\), 1.2}}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.144"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.714286 0.142857 0.714286 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -9 -9 ]
[.28571 -0.0125 9 0 ]
[.42857 -0.0125 -9 -9 ]
[.42857 -0.0125 9 0 ]
[.57143 -0.0125 -9 -9 ]
[.57143 -0.0125 9 0 ]
[.71429 -0.0125 -9 -9 ]
[.71429 -0.0125 9 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[-0.0125 .14286 -6 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -18 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -18 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -18 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -18 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(0.2)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(0.4)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(0.6)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(0.8)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(1)] .85714 -0.0125 0 1 Mshowa
.125 Mabswid
.03571 0 m
.03571 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.10714 0 m
.10714 .00375 L
s
.17857 0 m
.17857 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.25 0 m
.25 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.39286 0 m
.39286 .00375 L
s
.46429 0 m
.46429 .00375 L
s
.5 0 m
.5 .00375 L
s
.53571 0 m
.53571 .00375 L
s
.60714 0 m
.60714 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.75 0 m
.75 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82143 0 m
.82143 .00375 L
s
.89286 0 m
.89286 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.96429 0 m
.96429 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(0)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0.2)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(0.4)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(0.6)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(0.8)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(1)] -0.0125 .85714 1 0 Mshowa
.125 Mabswid
0 .03571 m
.00375 .03571 L
s
0 .07143 m
.00375 .07143 L
s
0 .10714 m
.00375 .10714 L
s
0 .17857 m
.00375 .17857 L
s
0 .21429 m
.00375 .21429 L
s
0 .25 m
.00375 .25 L
s
0 .32143 m
.00375 .32143 L
s
0 .35714 m
.00375 .35714 L
s
0 .39286 m
.00375 .39286 L
s
0 .46429 m
.00375 .46429 L
s
0 .5 m
.00375 .5 L
s
0 .53571 m
.00375 .53571 L
s
0 .60714 m
.00375 .60714 L
s
0 .64286 m
.00375 .64286 L
s
0 .67857 m
.00375 .67857 L
s
0 .75 m
.00375 .75 L
s
0 .78571 m
.00375 .78571 L
s
0 .82143 m
.00375 .82143 L
s
0 .89286 m
.00375 .89286 L
s
0 .92857 m
.00375 .92857 L
s
0 .96429 m
.00375 .96429 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.14286 .14286 Mdot
.17857 .17857 Mdot
.21429 .21429 Mdot
.25 .25 Mdot
.28571 .28571 Mdot
.32143 .32143 Mdot
.35714 .35714 Mdot
.39286 .39286 Mdot
.42857 .42857 Mdot
.46429 .46429 Mdot
.5 .5 Mdot
.53571 .53571 Mdot
.57143 .57143 Mdot
.60714 .60714 Mdot
.64286 .64286 Mdot
.67857 .67857 Mdot
.71429 .71429 Mdot
.75 .75 Mdot
.78571 .78571 Mdot
.82143 .82143 Mdot
.85714 .85714 Mdot
.85714 .14286 Mdot
.85714 .17857 Mdot
.85714 .21429 Mdot
.85714 .25 Mdot
.85714 .28571 Mdot
.85714 .32143 Mdot
.85714 .35714 Mdot
.85714 .39286 Mdot
.85714 .42857 Mdot
.85714 .46429 Mdot
.85714 .5 Mdot
.85714 .53571 Mdot
.85714 .57143 Mdot
.85714 .60714 Mdot
.85714 .64286 Mdot
.85714 .67857 Mdot
.85714 .71429 Mdot
.85714 .75 Mdot
.85714 .78571 Mdot
.85714 .82143 Mdot
.85714 .85714 Mdot
.14286 .14286 Mdot
.17857 .14286 Mdot
.21429 .14286 Mdot
.25 .14286 Mdot
.28571 .14286 Mdot
.32143 .14286 Mdot
.35714 .14286 Mdot
.39286 .14286 Mdot
.42857 .14286 Mdot
.46429 .14286 Mdot
.5 .14286 Mdot
.53571 .14286 Mdot
.57143 .14286 Mdot
.60714 .14286 Mdot
.64286 .14286 Mdot
.67857 .14286 Mdot
.71429 .14286 Mdot
.75 .14286 Mdot
.78571 .14286 Mdot
.82143 .14286 Mdot
.85714 .14286 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0001_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
02?ooooo1?l000000ol@413oooooooooo`0/ooooo`00Aoooool01OmgMgOoV9RHoooooonHV9SoMgMg
02;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0Uooooo`03o`000?oooooooooo02kooooo0017ooooo`05oa0@4?oooooo
ooooooooool@41008_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`0^ooooo`00Aooo
ool01Ol0003ooooooooooooooooo000002;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^01_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
6oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0Uoooo
o`03o`000?oooooooooo02kooooo0017ooooo`05o`000?ooooooooooooooool000008_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool06_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00006oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c00Kooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<02Gooooo00?o0000ooooooooool0;_ooool004Oooooo00Go410@
oooooooooooooooooa0@400Rooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Kooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Mooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@02Gooooo00?o0000ooooooooool0;_oo
ool004Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413o
V9RH01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
9Oooool00ol0003oooooooooo`0^ooooo`00Aoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Sooooo`03oeEEEOmVIVKo0000033ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo000Joooooooo0000Col0000001[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool001[ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;_ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003ooooo
odgooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool2o`000?ooooooCOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
ooooC?ooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000;?ooool2o`0000[o
oooo0_l0000:ooooo`;o00002Oooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[o
oooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l00009ooooo`;o00002_ooool2o`0000[o
oooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o00002Oooool2o`0000[o
oooo0_l0000:ooooo`;o0000<?ooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02cooooo0_l0000:ooooo`;o00002_ooool2o`0000Wooooo0_l0000:ooooo`;o
00002_ooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o
00002Oooool2o`0000[ooooo0_l0000:ooooo`;o00002_ooool2o`0000[ooooo0_l0000:ooooo`;o
00002_ooool2o`0000Wooooo0_l0000:ooooo`;o00002_ooool2o`00033ooooo000?ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooodcooooo000?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`;o0000>Oooool2o`000=oooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`0h
ooooo`;o0000goooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l00015oooo
o`;o0000doooool2o`00033ooooo000Jooooo`03o`000?oooooooooo04Cooooo0_l0003Cooooo`;o
0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0Coooool2o`000<Sooooo0_l0000`ooooo`006_ooool2o`00053ooooo
0_l00038ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5oooo
o`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0?ooooooC?ooool000?ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07oooo
o`?o0000Foooool2o`000;cooooo0_l0000`ooooo`000oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Foooool2o`000;cooooo0_l0000`ooooo`00
0oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
oooooom<ooooo`000oooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb<S;ok^k^
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool2o`0006Sooooo0_l0002`ooooo`;o0000<?ooool001[ooooo00?o0000
ooooooooool0Ioooool2o`000;3ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`;o0000M?ooool2o`000:Cooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`1cooooo`;o
0000Y?ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l00020ooooo`;o0000
V?ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0002Hooooo`;o0000<?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`0000Co<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413oooooooooo`09ooooo`Go
00001_ooool00ol0003oooooooooo`3oooooodcooooo0003ooooo`03o`000?oooooooooo00Wooooo
00CoA4A4omgMgOoooooo00001oooool3o`0008_ooooo0_l0002<ooooo`;o0000<?ooool000?ooooo
00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo08_o
oooo0_l0002<ooooo`;o0000<?ooool000?ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<
o`000007ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000oc8b
<_o^k^h=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`;o0000V?ooool2o`00
083ooooo0_l0000`ooooo`006_ooool00ol0003oooooooooo`2Gooooo`;o0000P?ooool2o`00033o
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0002Tooooo`;o0000M?ooool2o`00033ooooo
000Jooooo`03o`000?oooooooooo0:?ooooo0_l0001dooooo`;o0000<?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_oo
ool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0[_oo
ool2o`0006Wooooo0_l0000`ooooo`006_ooool2o`000:oooooo0_l0001Yooooo`;o0000<?ooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooC?ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0002jooooo`;o0000GOooool2o`00033ooooo0003ooooo`03o`000?oooooooooo00Wo
oooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0;[ooooo0_l0001Moooo
o`;o0000<?ooool000?ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0oooooom<ooooo`000oooool00ol@413oooooooooo`09ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oc8b
<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`;o0000aoooool2o`00057ooooo0_l0000`ooooo`006_oo
ool00ol0003oooooooooo`36ooooo`;o0000DOooool2o`00033ooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo0_l0003Cooooo`;o0000AOooool2o`00033ooooo000Jooooo`03o`000?oooooooooo
0=;ooooo0_l00015ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000=oo
oooo0_l0000iooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0g_ooool2o`0003Wooooo
0_l0000`ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool0oooooom<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?ooooooC?ooool000?ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom<ooooo`000oooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
1_ooool3o`000>[ooooo0_l0000]ooooo`;o0000<?ooool000?ooooo00?o0000ooooooooool02Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0j_ooool2o`0002gooooo
0_l0000`ooooo`000oooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`3oooooodcooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`05o`00
0?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3oooooodcooooo00001?lb<S;o0000
oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0
003gooooo`;o00008Oooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?Kooooo0_l0000Q
ooooo`;o0000<?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0ooooool2ooooo`;o00005_ooool2o`00033ooooo000Joooo
o`;o0000ooooool3ooooo`;o00005_ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000oooo
ooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool0
0ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0ooooool>ooooo`;o00002_ooool2o`00033ooooo000Jooooo`;o0000
ooooool?ooooo`;o00002_ooool2o`00033ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`004?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom<ooooo`004_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooC?ooool001;ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo6_ooool2o`00033ooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolJooooo`;o0000<?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodcooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooom<ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
C?ooool0013ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3o
ooooodcooooo000Jooooo`;o0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo0_l0003oooooodgooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool2o`000?ooooooCOooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.312289, -0.288593, \
0.00526565, 0.00526565}}]
}, Open  ]],

Cell[TextData[{
  "\tNext, we create the equations for the interior points, using the same \
finite difference procedure as in Sec. ",
  ButtonBox["6.2",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  ". Here however, we finite-difference the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^2\) \[Del]\^2\(\( \[Psi]\_\(m\ n\)\)(x, 
              y)\)\  = 0\)]],
  " in order to obtain linear equations that can eventually be put into the \
matrix form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["\[CenterDot]",
              FontWeight->"Bold"], 
            StyleBox["\[Psi]",
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  ". All we care about is  the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "; the ",
  "right-hand",
  " side of this matrix equation is not important. After we determine ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", we can evaluate the eigenvalues and eigenvectors of this matrix using \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions ",
  StyleBox["Eigenvalues",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Eigenvectors",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell["\tThe equations for the interior points are", "Text"],

Cell[BoxData[
    \(eqns\  = \ 
      Flatten[Table[
          Table[c^2\ \((\(\[Psi][j + 1, k] - 2  \[Psi][j, k]\  + \ \[Psi][j - \
1, k]\)\/\[CapitalDelta]x\^2 + \(\[Psi][j, k + 1] - 2  \[Psi][j, k]\  + \ \
\[Psi][j, k - 1]\)\/\[CapitalDelta]y\^2)\) \[Equal] 0, {j, f[k] + 1, 
              g[k] - 1}], {k, 1, M\_y - 1}]]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.145"],

Cell[TextData[{
  "Since we have already defined the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " on the boundaries, these ",
  "boundary-value",
  "s are used whenever they are encountered in the above equations. The \
variables in these equations are"
}], "Text"],

Cell[BoxData[
    \(\(vars\  = \ 
        Flatten[Table[
            Table[\[Psi][j, k], {j, f[k] + 1, g[k] - 1}], {k, 1, 
              M\_y - 1}]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.146"],

Cell[TextData[{
  "Now we must turn these algebraic equations into a matrix equation of the \
form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["\[CenterDot]",
              FontWeight->"Bold"], 
            StyleBox["\[Psi]",
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  ". To do so, we use a function ",
  StyleBox["LinearEquationstoMatrices",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available in the  add-on  package",
  StyleBox[" LinearAlgebra`",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
    \(\(\(<< LinearAlgebra`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(matrixsystem\  = \ 
        LinearEquationsToMatrices[eqns, vars];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.147"],

Cell[TextData[{
  "The result is a list of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", \({0, 0, 0, \(\(...\)\(.\)\)}\)}], 
          "}"}], TraditionalForm]]],
  ". The first element is the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", whose rows and columns correspond to the variables in the list ",
  Cell[BoxData[
      \(TraditionalForm\`vars\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The second element of ",
  Cell[BoxData[
      \(TraditionalForm\`matrixsystem\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the vector on the ",
  "right-hand",
  " side of the matrix equation (in this case the zero vector). Thus, we \
define"
}], "Text"],

Cell[BoxData[
    \(\(lmat\  = \ matrixsystem[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.148"],

Cell["The eigenvalues follow immediately:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda] = Eigenvalues[lmat]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.149"],

Cell[BoxData[
    \({\(-3150.995885512237`\), \(-3102.955891826802`\), \
\(-3073.650432386822`\), \(-3037.364267976061`\), \(-3008.058808536083`\), \
\(-2960.0188148506477`\), \(-2955.836097425349`\), \(-2926.5306379853637`\), \
\(-2878.4906442999322`\), \(-2860.3788743100877`\), \(-2831.0734148701004`\), \
\(-2812.8990204491965`\), \(-2783.033421184671`\), \(-2753.3430722677426`\), \
\(-2724.037612827754`\), \(-2717.4417973339287`\), \(-2675.9976191423325`\), \
\(-2637.3642679760706`\), \(-2635.9136267832173`\), \(-2610.405995291594`\), \
\(-2608.0588085360787`\), \(-2560.018814850652`\), \(-2528.8778247408754`\), \
\(-2515.2982445082916`\), \(-2494.4271909999106`\), \(-2485.9927850682984`\), \
\(-2437.9527913828724`\), \(-2433.420601625616`\), \(-2412.899020449196`\), \
\(-2390.1506724761107`\), \(-2372.3611675321463`\), \(-2360.8452130361247`\), \
\(-2317.441797333936`\), \(-2312.805219350694`\), \(-2290.832996981424`\), \
\(-2265.003100443925`\), \(-2247.2135954999553`\), \(-2235.6976410039383`\), \
\(-2210.405995291591`\), \(-2195.375773866164`\), \(-2187.65764731851`\), \
\(-2165.6854249492394`\), \(-2142.9370769761526`\), \(-2122.066023467776`\), \
\(-2113.6316175361612`\), \(-2088.339971823824`\), \(-2070.2282018339743`\), \
\(-2065.591623850736`\), \(-2040.53785291705`\), \(-2026.9582726844753`\), \
\(-2000.000000000001`\), \(-1997.6528132444844`\), \(-1972.3611675321424`\), \
\(-1963.1923997916367`\), \(-1949.6128195590575`\), \(-1945.0806298017924`\), \
\(-1919.9224706421328`\), \(-1918.471829449278`\), \(-1890.6170112021423`\), \
\(-1884.0211957083209`\), \(-1847.2135954999576`\), \(-1842.5770175167136`\), \
\(-1838.044827759451`\), \(-1824.4652475268688`\), \(-1823.0146063340178`\), \
\(-1802.4930251575988`\), \(-1795.1597880868817`\), \(-1776.9853936659797`\), \
\(-1747.1197944014584`\), \(-1742.9370769761485`\), \(-1725.1475720321835`\), \
\(-1722.0660234677728`\), \(-1715.978804291681`\), \(-1713.6316175361649`\), \
\(-1707.0358020423414`\), \(-1695.4572231152586`\), \(-1681.528170550721`\), \
\(-1677.3454531254176`\), \(-1665.5916238507368`\), \(-1648.0399936854283`\), \
\(-1629.305459439987`\), \(-1600.0000000000025`\), \(-1600.0000000000005`\), \
\(-1600.`\), \(-1600.`\), \(-1599.9999999999995`\), \(-1599.9999999999993`\), \
\(-1599.999999999999`\), \(-1599.9999999999989`\), \(-1599.9999999999968`\), \
\(-1570.6945405600125`\), \(-1551.960006314571`\), \(-1534.4083761492634`\), \
\(-1522.6545468745853`\), \(-1518.4718294492804`\), \(-1504.5427768847396`\), \
\(-1492.9641979576593`\), \(-1486.368382463835`\), \(-1484.0211957083222`\), \
\(-1477.9339765322263`\), \(-1474.8524279678145`\), \(-1457.0629230238449`\), \
\(-1452.8802055985457`\), \(-1423.0146063340205`\), \(-1404.8402119131106`\), \
\(-1397.506974842398`\), \(-1376.9853936659777`\), \(-1375.5347524731249`\), \
\(-1361.9551722405474`\), \(-1357.4229824832823`\), \(-1352.7864045000415`\), \
\(-1315.9788042916787`\), \(-1309.3829887978534`\), \(-1281.5281705507173`\), \
\(-1280.0775293578693`\), \(-1254.9193701982053`\), \(-1250.3871804409432`\), \
\(-1236.8076002083624`\), \(-1227.6388324678574`\), \(-1202.3471867555143`\), \
\(-1199.9999999999998`\), \(-1173.0417273155301`\), \(-1159.4621470829447`\), \
\(-1134.4083761492634`\), \(-1129.771798166018`\), \(-1111.6600281761782`\), \
\(-1086.3683824638329`\), \(-1077.9339765322288`\), \(-1057.0629230238483`\), \
\(-1034.3145750507633`\), \(-1012.3423526814927`\), \(-1004.624226133837`\), \
\(-989.5940047084016`\), \(-964.3023589960624`\), \(-952.786404500042`\), \
\(-934.9968995560774`\), \(-909.1670030185775`\), \(-887.1947806493048`\), \
\(-882.558202666063`\), \(-839.1547869638765`\), \(-827.6388324678577`\), \
\(-809.8493275238912`\), \(-787.100979550806`\), \(-766.5793983743852`\), \
\(-762.0472086171186`\), \(-714.0072149316888`\), \(-705.5728090000819`\), \
\(-684.7017554917005`\), \(-671.1221752591231`\), \(-639.9811851493481`\), \
\(-591.94119146392`\), \(-589.5940047084054`\), \(-564.0863732167835`\), \
\(-562.635732023935`\), \(-524.0023808576668`\), \(-482.5582026660586`\), \
\(-475.96238717223355`\), \(-446.6569277322501`\), \(-416.9665788153239`\), \
\(-387.10097955080437`\), \(-368.9265851298974`\), \(-339.6211256899086`\), \
\(-321.5093557000698`\), \(-273.46936201464405`\), \(-244.1639025746556`\), \
\(-239.98118514935072`\), \(-191.94119146392322`\), \(-162.63573202392985`\), \
\(-126.34956761318972`\), \(-97.04410817319877`\), \
\(-49.0041144877689`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
There are 171 eigenvalues, one for each interior grid point. This \
number can be found using\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nvalues\  = \ Length[\[Lambda]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.150"],

Cell[BoxData[
    \(171\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The lowest eigenvalue is not far off from the exact value ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(1, 2\) = \(\(-5\) \[Pi]\^2 = \(-49.3\) ... \
\)\)]],
  ", given by Eq. ",
  ButtonBox["(6.3.7)",
    ButtonData:>"(6.3.7)",
    ButtonStyle->"Hyperlink"],
  ". This is reasonable agreement, considering the coarseness of our 20-by-20 \
grid.  The next eigenvalue is not too different from the next eigenvalue, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\(1, 3\) = \(\(-10\)\ \[Pi]\^2 = \
\(-98.7\) ... \)\)]],
  ". Higher precision can be achieved by using a finer grid, but it must be \
remembered that the rank of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " (and the number of eigenvalues) is of order  ",
  Cell[BoxData[
      \(TraditionalForm\`\(M\_x\) M\_y\)]],
  ", so calculating the large number of eigenvectors and eigenvalues \
associated with a fine grid can be quite time-consuming. "
}], "Text"],

Cell["\<\
\tNext, we determine the eigenvectors associated with these \
eigenvalues: \
\>", "Text"],

Cell[BoxData[
    \(\(\[Psi]vec\  = \ Eigenvectors[lmat];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.151"],

Cell[TextData[{
  "Each element of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " is itself a vector whose elements correspond to the values ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\((\[Psi]\_\(m\ n\))\)\_\(j\ k\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " of the ",
  Cell[BoxData[
      \(TraditionalForm\`\((m, \ n)\)\)]],
  "'th eigenmode at the ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  "'th grid point, with the  order of the elements specified by the order of \
the variables in the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["vars",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ",",
  " defined above.  For example, the lowest eigenmode is "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]vec[\([nvalues]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.152"],

Cell[BoxData[
    \({\(-0.0003541631311616608`\), \(-0.0013732638980802566`\), \
\(-0.003285761465169663`\), \(-0.006207354718420297`\), \
\(-0.010122198265037236`\), \(-0.01487780173496886`\), \
\(-0.020194275464535758`\), \(-0.025687157418653198`\), \
\(-0.030901699437497137`\), \(-0.03535533905932906`\), \
\(-0.03858424976471559`\), \(-0.04018942987966648`\), \(-0.03987780173496598`\
\), \(-0.037494247726464154`\), \(-0.03304136493510003`\), \
\(-0.026684892042779528`\), \(-0.01874413743134372`\), \
\(-0.00966818164067706`\), \(-0.0016848920427803761`\), \
\(-0.005159887666630935`\), \(-0.0106609943402542`\), \
\(-0.018163563200138996`\), \(-0.02737204946143541`\), \(-0.0377381362373661`\
\), \(-0.04850571376505711`\), \(-0.05877852522925138`\), \
\(-0.06760401432756018`\), \(-0.07406526263763046`\), \(-0.07737204946143048`\
\), \(-0.07694208842938145`\), \(-0.07246439321524`\), \
\(-0.06393841289587622`\), \(-0.05168489204277945`\), \(-0.03632712640026811`\
\), \(-0.018744137431343677`\), \(-0.004375763503420244`\), \
\(-0.01180709030781743`\), \(-0.022273787407413755`\), \
\(-0.035355339059333364`\), \(-0.05025719638660801`\), \(-0.0658765872983221`\
\), \(-0.08090169943749935`\), \(-0.09393474323917834`\), \
\(-0.1036269804721625`\), \(-0.10881254497414149`\), \
\(-0.10862791203008611`\), \(-0.10260519025572301`\), \(-0.09072988812609663`\
\), \(-0.07345720591481346`\), \(-0.051684892042779505`\), \
\(-0.026684892042779466`\), \(-0.008471325967150632`\), \
\(-0.02104038899189054`\), \(-0.03718693027433204`\), \(-0.05590169943750073`\
\), \(-0.07577118003904702`\), \(-0.0951056516295204`\), \
\(-0.11209830643931216`\), \(-0.1250000000000011`\), \
\(-0.13229258190384194`\), \(-0.13284378786687578`\), \
\(-0.1260283764256422`\), \(-0.11180339887498873`\), \
\(-0.09072988812609618`\), \(-0.06393841289587594`\), \(-0.03304136493509972`\
\), \(-0.013651848241101076`\), \(-0.03189451213707201`\), \
\(-0.05354295785177455`\), \(-0.07691803283707734`\), \
\(-0.1000000000000034`\), \(-0.12061963528195672`\), \
\(-0.13666834540726075`\), \(-0.14630679270060443`\), \(-0.14815155063388954`\
\), \(-0.14142135623730817`\), \(-0.12602837642564244`\), \
\(-0.10260519025572264`\), \(-0.07246439321523955`\), \(-0.03749424772646393`\
\), \(-0.019288906370338692`\), \(-0.042898023903992555`\), \
\(-0.0689347432391786`\), \(-0.09510565162951787`\), \(-0.118934743239176`\), \
\(-0.13800367553350462`\), \(-0.1501906058078307`\), \
\(-0.15388417685876132`\), \(-0.14815155063388927`\), \
\(-0.1328437878668747`\), \(-0.10862791203008516`\), \
\(-0.07694208842938068`\), \(-0.03987780173496539`\), \(-0.02457003896795254`\
\), \(-0.05237204946143125`\), \(-0.08090169943749553`\), \
\(-0.10743928107606156`\), \(-0.12931413789080992`\), \(-0.14416788403346692`\
\), \(-0.15019060580782995`\), \(-0.14630679270060348`\), \
\(-0.13229258190384055`\), \(-0.10881254497413946`\), \
\(-0.077372049461429`\), \(-0.04018942987966546`\), \
\(-0.02866560143168147`\), \(-0.05877852522924715`\), \(-0.08744412666092753`\
\), \(-0.11180339887498818`\), \(-0.12931413789080964`\), \
\(-0.1380036755335031`\), \(-0.1366683454072588`\), \
\(-0.12499999999999808`\), \(-0.10362698047215946`\), \
\(-0.0740652626376277`\), \(-0.038584249764714126`\), \
\(-0.030901699437494552`\), \(-0.061042496477976896`\), \
\(-0.08744412666092721`\), \(-0.10743928107605974`\), \(-0.11893474323917363`\
\), \(-0.12061963528195288`\), \(-0.11209830643930753`\), \
\(-0.09393474323917371`\), \(-0.06760401432755628`\), \(-0.03535533905932667`\
\), \(-0.03090169943749431`\), \(-0.05877852522924621`\), \
\(-0.08090169943749342`\), \(-0.09510565162951379`\), \(-0.09999999999999813`\
\), \(-0.09510565162951358`\), \(-0.08090169943749308`\), \
\(-0.058778525229246176`\), \(-0.030901699437494084`\), \
\(-0.02866560143168055`\), \(-0.052372049461428954`\), \
\(-0.06893474323917402`\), \(-0.07691803283707113`\), \
\(-0.0757711800390395`\), \(-0.06587658729831468`\), \
\(-0.04850571376505092`\), \(-0.025687157418649794`\), \
\(-0.02457003896795093`\), \(-0.042898023903988905`\), \
\(-0.05354295785176887`\), \(-0.05590169943749319`\), \(-0.05025719638660039`\
\), \(-0.0377381362373597`\), \(-0.020194275464532032`\), \
\(-0.01928890637033646`\), \(-0.03189451213706751`\), \
\(-0.0371869302743255`\), \(-0.03535533905932623`\), \(-0.027372049461429074`\
\), \(-0.014877801734965307`\), \(-0.013651848241098627`\), \
\(-0.021040388991885917`\), \(-0.02227378740740774`\), \
\(-0.018163563200133362`\), \(-0.010122198265033822`\), \
\(-0.008471325967148145`\), \(-0.011807090307813331`\), \
\(-0.010660994340250238`\), \(-0.006207354718417717`\), \
\(-0.004375763503418604`\), \(-0.0051598876666287714`\), \
\(-0.0032857614651681144`\), \(-0.0016848920427794851`\), \
\(-0.0013732638980794188`\), \(-0.00035416313116159813`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to create a plottable eigenmode, we must associate the elements \
in ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " with their correct grid locations. This can be done as follows. Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " be a parameter denoting a given eigenfunction. We usually think of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Alpha]\)\(\ \)\)\)]],
  "as the pair ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((m, n)\)\(,\)\)\)]],
  " but here it is simply a counter, with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \ 1\)]],
  " corresponding to the lowest frequency eigenmode, \[Alpha]=2 being the \
next mode, etc.  Then we equate the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(j, k)\)]],
  " (the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  " at grid point ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  " ) with the corresponding value in the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Psi]vec",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " using nested ",
  StyleBox["Do",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statements to run over the interior grid points in the correct order:"
}], "Text"],

Cell[BoxData[
    \(\(\[Psi]val[\[Alpha]_] := \(\[Psi]val[\[Alpha]]\  = \ \ \((n0 = 
              0; \[IndentingNewLine]Do[
              Do[n0 = n0 + 1; \[Psi][j, 
                    k] = \[Psi]vec[\([nvalues - \[Alpha] + 1, n0]\)], {j, 
                  f[k] + 1, g[k] - 1}], {k, 1, 
                M\_y - 1}]; \[IndentingNewLine]a = 
              Table[Table[{x[j], y[k], \[Psi][j, k]}, {j, 0, M\_x}], {k, 0, 
                  M\_y}]; \[IndentingNewLine]Interpolation[
              Flatten[a, 1]])\)\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.153"],

Cell[TextData[{
  "The counter ",
  Cell[BoxData[
      \(TraditionalForm\`n0\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " keeps track of the position that the ",
  Cell[BoxData[
      \(TraditionalForm\`\((j, k)\)\)]],
  "th grid point occupies in the list ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]vec[\([\[Alpha]]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".  We then form a table of position-function values called ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", on the entire rectangle containing the domain of interest, and \
interpolate this to create the eigenfunction ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]val[\[Alpha]]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ". We use double equal signs so that this procedure is performed only once \
for each eigenmode. In Cell ",
  ButtonBox["6.154",
    ButtonData:>"Cell 6.154",
    ButtonStyle->"Hyperlink"],
  ", we plot the eigenfunctions for the lowest three modes."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      ParametricPlot3D[
        Evaluate[{Min[x + y, 1], 
            y, \(\[Psi]val[\[Alpha]]\)[Min[x + y, 1], y]}], {x, 0, 1}, {y, 0, 
          1}, BoxRatios \[Rule] {1, 1, 1/2}, PlotRange \[Rule] All, 
        PlotPoints \[Rule] 30, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel \[Rule] \ "\<triangular drumhead eigenmodes \[Alpha]=\>" <> 
            ToString[\[Alpha]]], {\[Alpha], 1, 3}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.154"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.03186 .27111 -30 -2.72586 ]
[.03186 .27111 0 6.27414 ]
[.01831 .35604 -24 -2.79832 ]
[.01831 .35604 0 6.20168 ]
[.00398 .44587 -30 -2.87539 ]
[.00398 .44587 0 6.12461 ]
[-0.01121 .54103 -6 -2.95752 ]
[-0.01121 .54103 0 6.04248 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04408 .26629 m
.05018 .26389 L
s
[(-0.15)] .03186 .27111 1 -0.39425 Mshowa
.03059 .3514 m
.03673 .34908 L
s
[(-0.1)] .01831 .35604 1 -0.37815 Mshowa
.01632 .44141 m
.0225 .43918 L
s
[(-0.05)] .00398 .44587 1 -0.36103 Mshowa
.00121 .53677 m
.00742 .53464 L
s
[(0)] -0.01121 .54103 1 -0.34277 Mshowa
.125 Mabswid
.04144 .28294 m
.04511 .28151 L
s
.03877 .29977 m
.04244 .29835 L
s
.03607 .31679 m
.03975 .31537 L
s
.03335 .334 m
.03703 .33259 L
s
.0278 .36899 m
.03149 .36761 L
s
.02498 .38679 m
.02867 .38542 L
s
.02213 .40479 m
.02582 .40343 L
s
.01924 .42299 m
.02294 .42165 L
s
.01337 .46004 m
.01708 .45871 L
s
.01039 .47889 m
.0141 .47757 L
s
.00736 .49795 m
.01108 .49665 L
s
.00431 .51725 m
.00803 .51596 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.94761 .68972 m .96955 .6839 L .97747 .69446 L closepath p .645 .766 .937 r
F P
0 g
s
.96955 .6839 m .94761 .68972 L .91754 .68476 L p .648 .76 .931 r
F P
0 g
s
.91754 .68476 m .93943 .67881 L .96955 .6839 L p .648 .76 .931 r
F P
0 g
s
.93943 .67881 m .91754 .68476 L .88728 .67981 L p .655 .753 .922 r
F P
0 g
s
.93943 .67881 m .96153 .67318 L .96955 .6839 L closepath p .639 .764 .938 r
F P
0 g
s
.88728 .67981 m .9091 .67351 L .93943 .67881 L p .655 .753 .922 r
F P
0 g
s
.9091 .67351 m .88728 .67981 L .85684 .67487 L p .678 .721 .882 r
F P
0 g
s
.96153 .67318 m .93943 .67881 L .9091 .67351 L p .649 .749 .923 r
F P
0 g
s
.64189 .33991 m .62119 .35312 L .58954 .33492 L p .684 .539 .683 r
F P
0 g
s
.58954 .33492 m .61002 .31618 L .64189 .33991 L p .684 .539 .683 r
F P
0 g
s
.56916 .36095 m .58954 .33492 L .62119 .35312 L p .716 .554 .669 r
F P
0 g
s
.61002 .31618 m .58954 .33492 L .55803 .32473 L p .721 .57 .684 r
F P
0 g
s
.58954 .33492 m .56916 .36095 L .53756 .35499 L p .745 .581 .671 r
F P
0 g
s
.53756 .35499 m .55803 .32473 L .58954 .33492 L p .745 .581 .671 r
F P
0 g
s
.66303 .33485 m .64189 .33991 L .61002 .31618 L p .64 .519 .7 r
F P
0 g
s
.61002 .31618 m .63077 .3053 L .66303 .33485 L p .64 .519 .7 r
F P
0 g
s
.63077 .3053 m .61002 .31618 L .57846 .30091 L p .684 .554 .701 r
F P
0 g
s
.55803 .32473 m .57846 .30091 L .61002 .31618 L p .721 .57 .684 r
F P
0 g
s
.57846 .30091 m .599 .28435 L .63077 .3053 L p .684 .554 .701 r
F P
0 g
s
.599 .28435 m .57846 .30091 L .54695 .29477 L p .731 .597 .708 r
F P
0 g
s
.57846 .30091 m .55803 .32473 L .5264 .32282 L p .758 .608 .691 r
F P
0 g
s
.5264 .32282 m .54695 .29477 L .57846 .30091 L p .758 .608 .691 r
F P
0 g
s
.85684 .67487 m .87847 .66718 L .9091 .67351 L p .678 .721 .882 r
F P
0 g
s
.87847 .66718 m .85684 .67487 L .82614 .66912 L p .689 .706 .86 r
F P
0 g
s
.67426 .37082 m .65317 .37846 L .62119 .35312 L p .649 .514 .685 r
F P
0 g
s
.62119 .35312 m .64189 .33991 L .67426 .37082 L p .649 .514 .685 r
F P
0 g
s
.60075 .37415 m .62119 .35312 L .65317 .37846 L p .687 .532 .67 r
F P
0 g
s
.62119 .35312 m .60075 .37415 L .56916 .36095 L p .716 .554 .669 r
F P
0 g
s
.65197 .30259 m .63077 .3053 L .599 .28435 L p .632 .531 .722 r
F P
0 g
s
.599 .28435 m .61981 .27559 L .65197 .30259 L p .632 .531 .722 r
F P
0 g
s
.61981 .27559 m .599 .28435 L .56746 .27308 L p .688 .581 .729 r
F P
0 g
s
.54695 .29477 m .56746 .27308 L .599 .28435 L p .731 .597 .708 r
F P
0 g
s
.9091 .67351 m .9311 .66747 L .96153 .67318 L p .649 .749 .923 r
F P
0 g
s
.9311 .66747 m .9091 .67351 L .87847 .66718 L p .654 .734 .908 r
F P
0 g
s
.65317 .37846 m .6325 .39412 L .60075 .37415 L p .687 .532 .67 r
F P
0 g
s
.5804 .40243 m .60075 .37415 L .6325 .39412 L p .715 .545 .659 r
F P
0 g
s
.60075 .37415 m .5804 .40243 L .54874 .39342 L p .738 .565 .659 r
F P
0 g
s
.54874 .39342 m .56916 .36095 L .60075 .37415 L p .738 .565 .659 r
F P
0 g
s
.9311 .66747 m .95339 .66232 L .96153 .67318 L closepath p .627 .758 .941 r
F P
0 g
s
.55803 .32473 m .53756 .35499 L .5057 .3563 L p .776 .613 .678 r
F P
0 g
s
.5057 .3563 m .5264 .32282 L .55803 .32473 L p .776 .613 .678 r
F P
0 g
s
.56916 .36095 m .54874 .39342 L .51692 .39071 L p .762 .588 .662 r
F P
0 g
s
.51692 .39071 m .53756 .35499 L .56916 .36095 L p .762 .588 .662 r
F P
0 g
s
.56746 .27308 m .58808 .25852 L .61981 .27559 L p .688 .581 .729 r
F P
0 g
s
.58808 .25852 m .56746 .27308 L .53586 .27192 L p .748 .642 .743 r
F P
0 g
s
.56746 .27308 m .54695 .29477 L .51521 .29779 L p .779 .65 .72 r
F P
0 g
s
.51521 .29779 m .53586 .27192 L .56746 .27308 L p .779 .65 .72 r
F P
0 g
s
.69595 .37136 m .67426 .37082 L .64189 .33991 L p .596 .489 .703 r
F P
0 g
s
.64189 .33991 m .66303 .33485 L .69595 .37136 L p .596 .489 .703 r
F P
0 g
s
.6848 .33808 m .66303 .33485 L .63077 .3053 L p .576 .489 .719 r
F P
0 g
s
.63077 .3053 m .65197 .30259 L .6848 .33808 L p .576 .489 .719 r
F P
0 g
s
.68562 .40946 m .66459 .41978 L .6325 .39412 L p .659 .514 .676 r
F P
0 g
s
.6325 .39412 m .65317 .37846 L .68562 .40946 L p .659 .514 .676 r
F P
0 g
s
.61209 .41749 m .6325 .39412 L .66459 .41978 L p .692 .53 .663 r
F P
0 g
s
.6325 .39412 m .61209 .41749 L .5804 .40243 L p .715 .545 .659 r
F P
0 g
s
.54695 .29477 m .5264 .32282 L .49441 .32898 L p .798 .653 .702 r
F P
0 g
s
.49441 .32898 m .51521 .29779 L .54695 .29477 L p .798 .653 .702 r
F P
0 g
s
.82614 .66912 m .84764 .66041 L .87847 .66718 L p .689 .706 .86 r
F P
0 g
s
.84764 .66041 m .82614 .66912 L .79531 .66418 L p .708 .676 .817 r
F P
0 g
s
.70723 .4071 m .68562 .40946 L .65317 .37846 L p .614 .494 .693 r
F P
0 g
s
.65317 .37846 m .67426 .37082 L .70723 .4071 L p .614 .494 .693 r
F P
0 g
s
.87847 .66718 m .90041 .66093 L .9311 .66747 L p .654 .734 .908 r
F P
0 g
s
.90041 .66093 m .87847 .66718 L .84764 .66041 L p .674 .693 .859 r
F P
0 g
s
.64107 .27493 m .61981 .27559 L .58808 .25852 L p .624 .554 .755 r
F P
0 g
s
.58808 .25852 m .60897 .2516 L .64107 .27493 L p .624 .554 .755 r
F P
0 g
s
.60897 .2516 m .58808 .25852 L .55648 .25222 L p .697 .626 .773 r
F P
0 g
s
.53586 .27192 m .55648 .25222 L .58808 .25852 L p .748 .642 .743 r
F P
0 g
s
.66459 .41978 m .64396 .43792 L .61209 .41749 L p .692 .53 .663 r
F P
0 g
s
.59177 .44796 m .61209 .41749 L .64396 .43792 L p .716 .542 .653 r
F P
0 g
s
.61209 .41749 m .59177 .44796 L .56 .43705 L p .734 .556 .65 r
F P
0 g
s
.56 .43705 m .5804 .40243 L .61209 .41749 L p .734 .556 .65 r
F P
0 g
s
.6738 .30821 m .65197 .30259 L .61981 .27559 L p .554 .494 .743 r
F P
0 g
s
.61981 .27559 m .64107 .27493 L .6738 .30821 L p .554 .494 .743 r
F P
0 g
s
.5804 .40243 m .56 .43705 L .52814 .43129 L p .753 .572 .651 r
F P
0 g
s
.52814 .43129 m .54874 .39342 L .5804 .40243 L p .753 .572 .651 r
F P
0 g
s
.95339 .66232 m .9311 .66747 L .90041 .66093 L p .63 .744 .93 r
F P
0 g
s
.53756 .35499 m .51692 .39071 L .48475 .3941 L p .787 .617 .669 r
F P
0 g
s
.48475 .3941 m .5057 .3563 L .53756 .35499 L p .787 .617 .669 r
F P
0 g
s
.69709 .44965 m .67612 .46264 L .64396 .43792 L p .67 .519 .671 r
F P
0 g
s
.64396 .43792 m .66459 .41978 L .69709 .44965 L p .67 .519 .671 r
F P
0 g
s
.62357 .46355 m .64396 .43792 L .67612 .46264 L p .699 .533 .659 r
F P
0 g
s
.64396 .43792 m .62357 .46355 L .59177 .44796 L p .716 .542 .653 r
F P
0 g
s
.7186 .44433 m .69709 .44965 L .66459 .41978 L p .631 .501 .687 r
F P
0 g
s
.66459 .41978 m .68562 .40946 L .7186 .44433 L p .631 .501 .687 r
F P
0 g
s
.5264 .32282 m .5057 .3563 L .47338 .36445 L p .809 .653 .689 r
F P
0 g
s
.47338 .36445 m .49441 .32898 L .5264 .32282 L p .809 .653 .689 r
F P
0 g
s
.84764 .66041 m .86937 .65263 L .90041 .66093 L p .674 .693 .859 r
F P
0 g
s
.86937 .65263 m .84764 .66041 L .81659 .65296 L p .693 .651 .804 r
F P
0 g
s
.79531 .66418 m .81659 .65296 L .84764 .66041 L p .708 .676 .817 r
F P
0 g
s
.54874 .39342 m .52814 .43129 L .49602 .4307 L p .772 .593 .656 r
F P
0 g
s
.49602 .4307 m .51692 .39071 L .54874 .39342 L p .772 .593 .656 r
F P
0 g
s
.81659 .65296 m .79531 .66418 L .7643 .65927 L p .721 .631 .757 r
F P
0 g
s
.7184 .37994 m .69595 .37136 L .66303 .33485 L p .519 .454 .723 r
F P
0 g
s
.66303 .33485 m .6848 .33808 L .7184 .37994 L p .519 .454 .723 r
F P
0 g
s
.55648 .25222 m .57721 .23943 L .60897 .2516 L p .697 .626 .773 r
F P
0 g
s
.57721 .23943 m .55648 .25222 L .52468 .25673 L p .774 .716 .798 r
F P
0 g
s
.55648 .25222 m .53586 .27192 L .50388 .2805 L p .81 .718 .763 r
F P
0 g
s
.50388 .2805 m .52468 .25673 L .55648 .25222 L p .81 .718 .763 r
F P
0 g
s
.53586 .27192 m .51521 .29779 L .48295 .30937 L p .83 .714 .737 r
F P
0 g
s
.48295 .30937 m .50388 .2805 L .53586 .27192 L p .83 .714 .737 r
F P
0 g
s
.72956 .41256 m .70723 .4071 L .67426 .37082 L p .55 .465 .713 r
F P
0 g
s
.67426 .37082 m .69595 .37136 L .72956 .41256 L p .55 .465 .713 r
F P
0 g
s
.90041 .66093 m .92264 .65575 L .95339 .66232 L p .63 .744 .93 r
F P
0 g
s
.92264 .65575 m .90041 .66093 L .86937 .65263 L p .638 .709 .898 r
F P
0 g
s
.67612 .46264 m .65553 .48316 L .62357 .46355 L p .699 .533 .659 r
F P
0 g
s
.60326 .4959 m .62357 .46355 L .65553 .48316 L p .721 .544 .65 r
F P
0 g
s
.62357 .46355 m .60326 .4959 L .57137 .48445 L p .734 .552 .646 r
F P
0 g
s
.57137 .48445 m .59177 .44796 L .62357 .46355 L p .734 .552 .646 r
F P
0 g
s
.59177 .44796 m .57137 .48445 L .53942 .47693 L p .749 .563 .645 r
F P
0 g
s
.53942 .47693 m .56 .43705 L .59177 .44796 L p .749 .563 .645 r
F P
0 g
s
.66296 .28255 m .64107 .27493 L .60897 .2516 L p .526 .508 .779 r
F P
0 g
s
.60897 .2516 m .6303 .25263 L .66296 .28255 L p .526 .508 .779 r
F P
0 g
s
.6303 .25263 m .60897 .2516 L .57721 .23943 L p .615 .595 .806 r
F P
0 g
s
.70735 .3495 m .6848 .33808 L .65197 .30259 L p .483 .445 .739 r
F P
0 g
s
.65197 .30259 m .6738 .30821 L .70735 .3495 L p .483 .445 .739 r
F P
0 g
s
.73001 .48197 m .70861 .49019 L .67612 .46264 L p .647 .512 .684 r
F P
0 g
s
.67612 .46264 m .69709 .44965 L .73001 .48197 L p .647 .512 .684 r
F P
0 g
s
.65553 .48316 m .67612 .46264 L .70861 .49019 L p .681 .527 .669 r
F P
0 g
s
.7408 .44652 m .7186 .44433 L .68562 .40946 L p .577 .479 .706 r
F P
0 g
s
.68562 .40946 m .70723 .4071 L .7408 .44652 L p .577 .479 .706 r
F P
0 g
s
.70861 .49019 m .68771 .50572 L .65553 .48316 L p .681 .527 .669 r
F P
0 g
s
.63517 .51089 m .65553 .48316 L .68771 .50572 L p .707 .539 .658 r
F P
0 g
s
.65553 .48316 m .63517 .51089 L .60326 .4959 L p .721 .544 .65 r
F P
0 g
s
.92264 .65575 m .94514 .6513 L .95339 .66232 L closepath p .61 .751 .945 r
F P
0 g
s
.81659 .65296 m .83803 .64245 L .86937 .65263 L p .693 .651 .804 r
F P
0 g
s
.83803 .64245 m .81659 .65296 L .78523 .64359 L p .7 .626 .77 r
F P
0 g
s
.7643 .65927 m .78523 .64359 L .81659 .65296 L p .721 .631 .757 r
F P
0 g
s
.57721 .23943 m .59821 .23404 L .6303 .25263 L p .615 .595 .806 r
F P
0 g
s
.59821 .23404 m .57721 .23943 L .54546 .23887 L p .71 .703 .842 r
F P
0 g
s
.52468 .25673 m .54546 .23887 L .57721 .23943 L p .774 .716 .798 r
F P
0 g
s
.56 .43705 m .53942 .47693 L .50727 .47315 L p .763 .578 .647 r
F P
0 g
s
.50727 .47315 m .52814 .43129 L .56 .43705 L p .763 .578 .647 r
F P
0 g
s
.51521 .29779 m .49441 .32898 L .4618 .3424 L p .839 .708 .718 r
F P
0 g
s
.4618 .3424 m .48295 .30937 L .51521 .29779 L p .839 .708 .718 r
F P
0 g
s
.86937 .65263 m .8915 .6472 L .92264 .65575 L p .638 .709 .898 r
F P
0 g
s
.8915 .6472 m .86937 .65263 L .83803 .64245 L p .651 .666 .851 r
F P
0 g
s
.78523 .64359 m .7643 .65927 L .73294 .65194 L p .728 .63 .749 r
F P
0 g
s
.75206 .4809 m .73001 .48197 L .69709 .44965 L p .602 .494 .703 r
F P
0 g
s
.69709 .44965 m .7186 .44433 L .75206 .4809 L p .602 .494 .703 r
F P
0 g
s
.69643 .32207 m .6738 .30821 L .64107 .27493 L p .438 .438 .761 r
F P
0 g
s
.64107 .27493 m .66296 .28255 L .69643 .32207 L p .438 .438 .761 r
F P
0 g
s
.74139 .519 m .72011 .52991 L .68771 .50572 L p .664 .525 .684 r
F P
0 g
s
.68771 .50572 m .70861 .49019 L .74139 .519 L p .664 .525 .684 r
F P
0 g
s
.66717 .52833 m .68771 .50572 L .72011 .52991 L p .694 .538 .67 r
F P
0 g
s
.68771 .50572 m .66717 .52833 L .63517 .51089 L p .707 .539 .658 r
F P
0 g
s
.51692 .39071 m .49602 .4307 L .4635 .43487 L p .793 .618 .664 r
F P
0 g
s
.4635 .43487 m .48475 .3941 L .51692 .39071 L p .793 .618 .664 r
F P
0 g
s
.78523 .64359 m .80646 .63082 L .83803 .64245 L p .7 .626 .77 r
F P
0 g
s
.80646 .63082 m .78523 .64359 L .7538 .6348 L p .711 .597 .727 r
F P
0 g
s
.73294 .65194 m .7538 .6348 L .78523 .64359 L p .728 .63 .749 r
F P
0 g
s
.5057 .3563 m .48475 .3941 L .45206 .40296 L p .814 .651 .681 r
F P
0 g
s
.45206 .40296 m .47338 .36445 L .5057 .3563 L p .814 .651 .681 r
F P
0 g
s
.61487 .54545 m .63517 .51089 L .66717 .52833 L p .728 .549 .649 r
F P
0 g
s
.63517 .51089 m .61487 .54545 L .5829 .53599 L p .738 .551 .64 r
F P
0 g
s
.5829 .53599 m .60326 .4959 L .63517 .51089 L p .738 .551 .64 r
F P
0 g
s
.83803 .64245 m .85998 .63605 L .8915 .6472 L p .651 .666 .851 r
F P
0 g
s
.85998 .63605 m .83803 .64245 L .80646 .63082 L p .667 .625 .798 r
F P
0 g
s
.94514 .6513 m .92264 .65575 L .8915 .6472 L p .601 .731 .936 r
F P
0 g
s
.60326 .4959 m .5829 .53599 L .5508 .52622 L p .748 .56 .641 r
F P
0 g
s
.5508 .52622 m .57137 .48445 L .60326 .4959 L p .748 .56 .641 r
F P
0 g
s
.76328 .5148 m .74139 .519 L .70861 .49019 L p .625 .51 .703 r
F P
0 g
s
.70861 .49019 m .73001 .48197 L .76328 .5148 L p .625 .51 .703 r
F P
0 g
s
.72011 .52991 m .69928 .54756 L .66717 .52833 L p .694 .538 .67 r
F P
0 g
s
.64683 .55786 m .66717 .52833 L .69928 .54756 L p .718 .549 .66 r
F P
0 g
s
.66717 .52833 m .64683 .55786 L .61487 .54545 L p .728 .549 .649 r
F P
0 g
s
.7538 .6348 m .73294 .65194 L .70155 .64713 L p .736 .613 .72 r
F P
0 g
s
.52814 .43129 m .50727 .47315 L .47482 .47335 L p .778 .596 .653 r
F P
0 g
s
.47482 .47335 m .49602 .4307 L .52814 .43129 L p .778 .596 .653 r
F P
0 g
s
.80646 .63082 m .82813 .62219 L .85998 .63605 L p .667 .625 .798 r
F P
0 g
s
.82813 .62219 m .80646 .63082 L .77468 .61747 L p .679 .593 .752 r
F P
0 g
s
.7538 .6348 m .77468 .61747 L .80646 .63082 L p .711 .597 .727 r
F P
0 g
s
.75268 .55443 m .73151 .56766 L .69928 .54756 L p .681 .541 .688 r
F P
0 g
s
.69928 .54756 m .72011 .52991 L .75268 .55443 L p .681 .541 .688 r
F P
0 g
s
.67884 .57319 m .69928 .54756 L .73151 .56766 L p .71 .55 .67 r
F P
0 g
s
.69928 .54756 m .67884 .57319 L .64683 .55786 L p .718 .549 .66 r
F P
0 g
s
.77468 .61747 m .7538 .6348 L .72223 .62587 L p .72 .574 .69 r
F P
0 g
s
.70155 .64713 m .72223 .62587 L .7538 .6348 L p .736 .613 .72 r
F P
0 g
s
.57137 .48445 m .5508 .52622 L .51856 .52069 L p .758 .57 .642 r
F P
0 g
s
.51856 .52069 m .53942 .47693 L .57137 .48445 L p .758 .57 .642 r
F P
0 g
s
.77439 .54741 m .75268 .55443 L .72011 .52991 L p .646 .529 .706 r
F P
0 g
s
.72011 .52991 m .74139 .519 L .77439 .54741 L p .646 .529 .706 r
F P
0 g
s
.75276 .42535 m .72956 .41256 L .69595 .37136 L p .457 .425 .734 r
F P
0 g
s
.69595 .37136 m .7184 .37994 L .75276 .42535 L p .457 .425 .734 r
F P
0 g
s
.49441 .32898 m .47338 .36445 L .44039 .37843 L p .843 .701 .706 r
F P
0 g
s
.44039 .37843 m .4618 .3424 L .49441 .32898 L p .843 .701 .706 r
F P
0 g
s
.77468 .61747 m .79602 .60574 L .82813 .62219 L p .679 .593 .752 r
F P
0 g
s
.79602 .60574 m .77468 .61747 L .74274 .6024 L p .688 .573 .721 r
F P
0 g
s
.72223 .62587 m .74274 .6024 L .77468 .61747 L p .72 .574 .69 r
F P
0 g
s
.65226 .26177 m .6303 .25263 L .59821 .23404 L p .486 .535 .833 r
F P
0 g
s
.59821 .23404 m .61964 .23632 L .65226 .26177 L p .486 .535 .833 r
F P
0 g
s
.61964 .23632 m .59821 .23404 L .56634 .2276 L p .599 .666 .886 r
F P
0 g
s
.54546 .23887 m .56634 .2276 L .59821 .23404 L p .71 .703 .842 r
F P
0 g
s
.76381 .45573 m .7408 .44652 L .70723 .4071 L p .5 .447 .73 r
F P
0 g
s
.70723 .4071 m .72956 .41256 L .76381 .45573 L p .5 .447 .73 r
F P
0 g
s
.8915 .6472 m .91399 .6433 L .94514 .6513 L p .601 .731 .936 r
F P
0 g
s
.91399 .6433 m .8915 .6472 L .85998 .63605 L p .611 .683 .894 r
F P
0 g
s
.54546 .23887 m .52468 .25673 L .49234 .27128 L p .849 .825 .824 r
F P
0 g
s
.52468 .25673 m .50388 .2805 L .47123 .29781 L p .871 .808 .785 r
F P
0 g
s
.47123 .29781 m .49234 .27128 L .52468 .25673 L p .871 .808 .785 r
F P
0 g
s
.74274 .6024 m .76379 .58734 L .79602 .60574 L p .688 .573 .721 r
F P
0 g
s
.76379 .58734 m .74274 .6024 L .7108 .58772 L p .7 .559 .692 r
F P
0 g
s
.74274 .6024 m .72223 .62587 L .6904 .6145 L p .726 .57 .678 r
F P
0 g
s
.6904 .6145 m .7108 .58772 L .74274 .6024 L p .726 .57 .678 r
F P
0 g
s
.78533 .57795 m .76379 .58734 L .73151 .56766 L p .668 .55 .712 r
F P
0 g
s
.73151 .56766 m .75268 .55443 L .78533 .57795 L p .668 .55 .712 r
F P
0 g
s
.7108 .58772 m .73151 .56766 L .76379 .58734 L p .7 .559 .692 r
F P
0 g
s
.73151 .56766 m .7108 .58772 L .67884 .57319 L p .71 .55 .67 r
F P
0 g
s
.74176 .3961 m .7184 .37994 L .6848 .33808 L p .406 .402 .741 r
F P
0 g
s
.6848 .33808 m .70735 .3495 L .74176 .3961 L p .406 .402 .741 r
F P
0 g
s
.56634 .2276 m .54546 .23887 L .51332 .24955 L p .803 .836 .876 r
F P
0 g
s
.49234 .27128 m .51332 .24955 L .54546 .23887 L p .849 .825 .824 r
F P
0 g
s
.7108 .58772 m .6904 .6145 L .65858 .60549 L p .733 .562 .661 r
F P
0 g
s
.65858 .60549 m .67884 .57319 L .7108 .58772 L p .733 .562 .661 r
F P
0 g
s
.77486 .48646 m .75206 .4809 L .7186 .44433 L p .537 .47 .728 r
F P
0 g
s
.7186 .44433 m .7408 .44652 L .77486 .48646 L p .537 .47 .728 r
F P
0 g
s
.68566 .29836 m .66296 .28255 L .6303 .25263 L p .379 .434 .792 r
F P
0 g
s
.6303 .25263 m .65226 .26177 L .68566 .29836 L p .379 .434 .792 r
F P
0 g
s
.67884 .57319 m .65858 .60549 L .62666 .59775 L p .737 .551 .641 r
F P
0 g
s
.62666 .59775 m .64683 .55786 L .67884 .57319 L p .737 .551 .641 r
F P
0 g
s
.64683 .55786 m .62666 .59775 L .59453 .58741 L p .745 .557 .641 r
F P
0 g
s
.59453 .58741 m .61487 .54545 L .64683 .55786 L p .745 .557 .641 r
F P
0 g
s
.81792 .59923 m .79602 .60574 L .76379 .58734 L p .654 .567 .745 r
F P
0 g
s
.76379 .58734 m .78533 .57795 L .81792 .59923 L p .654 .567 .745 r
F P
0 g
s
.78586 .51682 m .76328 .5148 L .73001 .48197 L p .571 .493 .728 r
F P
0 g
s
.73001 .48197 m .75206 .4809 L .78586 .51682 L p .571 .493 .728 r
F P
0 g
s
.85998 .63605 m .88237 .63217 L .91399 .6433 L p .611 .683 .894 r
F P
0 g
s
.88237 .63217 m .85998 .63605 L .82813 .62219 L p .625 .634 .839 r
F P
0 g
s
.72223 .62587 m .70155 .64713 L .67 .6436 L p .738 .58 .677 r
F P
0 g
s
.67 .6436 m .6904 .6145 L .72223 .62587 L p .738 .58 .677 r
F P
0 g
s
.50388 .2805 m .48295 .30937 L .44993 .32829 L p .879 .79 .758 r
F P
0 g
s
.44993 .32829 m .47123 .29781 L .50388 .2805 L p .879 .79 .758 r
F P
0 g
s
.79674 .54613 m .77439 .54741 L .74139 .519 L p .601 .516 .731 r
F P
0 g
s
.74139 .519 m .76328 .5148 L .79674 .54613 L p .601 .516 .731 r
F P
0 g
s
.85031 .61746 m .82813 .62219 L .79602 .60574 L p .639 .595 .788 r
F P
0 g
s
.79602 .60574 m .81792 .59923 L .85031 .61746 L p .639 .595 .788 r
F P
0 g
s
.80744 .57376 m .78533 .57795 L .75268 .55443 L p .628 .541 .736 r
F P
0 g
s
.75268 .55443 m .77439 .54741 L .80744 .57376 L p .628 .541 .736 r
F P
0 g
s
.91399 .6433 m .93677 .64013 L .94514 .6513 L closepath p .578 .736 .95 r
F P
0 g
s
.73084 .36867 m .70735 .3495 L .6738 .30821 L p .346 .378 .751 r
F P
0 g
s
.6738 .30821 m .69643 .32207 L .73084 .36867 L p .346 .378 .751 r
F P
0 g
s
.53942 .47693 m .51856 .52069 L .48606 .51942 L p .769 .578 .641 r
F P
0 g
s
.48606 .51942 m .50727 .47315 L .53942 .47693 L p .769 .578 .641 r
F P
0 g
s
.82813 .62219 m .85031 .61746 L .88237 .63217 L p .625 .634 .839 r
F P
0 g
s
.61487 .54545 m .59453 .58741 L .56233 .58048 L p .753 .563 .639 r
F P
0 g
s
.56233 .58048 m .5829 .53599 L .61487 .54545 L p .753 .563 .639 r
F P
0 g
s
.6904 .6145 m .67 .6436 L .63803 .63424 L p .746 .591 .684 r
F P
0 g
s
.63803 .63424 m .65858 .60549 L .6904 .6145 L p .746 .591 .684 r
F P
0 g
s
.56634 .2276 m .58747 .22337 L .61964 .23632 L p .599 .666 .886 r
F P
0 g
s
.58747 .22337 m .56634 .2276 L .53429 .23335 L p .711 .829 .938 r
F P
0 g
s
.51332 .24955 m .53429 .23335 L .56634 .2276 L p .803 .836 .876 r
F P
0 g
s
.48475 .3941 m .4635 .43487 L .43045 .44315 L p .814 .648 .677 r
F P
0 g
s
.43045 .44315 m .45206 .40296 L .48475 .3941 L p .814 .648 .677 r
F P
0 g
s
.49602 .4307 m .47482 .47335 L .44194 .47716 L p .794 .617 .662 r
F P
0 g
s
.44194 .47716 m .4635 .43487 L .49602 .4307 L p .794 .617 .662 r
F P
0 g
s
.84037 .5968 m .81792 .59923 L .78533 .57795 L p .61 .563 .777 r
F P
0 g
s
.78533 .57795 m .80744 .57376 L .84037 .5968 L p .61 .563 .777 r
F P
0 g
s
.93677 .64013 m .91399 .6433 L .88237 .63217 L p .561 .709 .94 r
F P
0 g
s
.5829 .53599 m .56233 .58048 L .52995 .57637 L p .754 .556 .629 r
F P
0 g
s
.52995 .57637 m .5508 .52622 L .5829 .53599 L p .754 .556 .629 r
F P
0 g
s
.48295 .30937 m .4618 .3424 L .42839 .36165 L p .88 .774 .74 r
F P
0 g
s
.42839 .36165 m .44993 .32829 L .48295 .30937 L p .88 .774 .74 r
F P
0 g
s
.65858 .60549 m .63803 .63424 L .60604 .62935 L p .752 .591 .676 r
F P
0 g
s
.60604 .62935 m .62666 .59775 L .65858 .60549 L p .752 .591 .676 r
F P
0 g
s
.47338 .36445 m .45206 .40296 L .4187 .41624 L p .841 .693 .699 r
F P
0 g
s
.4187 .41624 m .44039 .37843 L .47338 .36445 L p .841 .693 .699 r
F P
0 g
s
.72003 .34376 m .69643 .32207 L .66296 .28255 L p .27 .351 .763 r
F P
0 g
s
.66296 .28255 m .68566 .29836 L .72003 .34376 L p .27 .351 .763 r
F P
0 g
s
.83018 .57421 m .80744 .57376 L .77439 .54741 L p .576 .532 .769 r
F P
0 g
s
.77439 .54741 m .79674 .54613 L .83018 .57421 L p .576 .532 .769 r
F P
0 g
s
.87299 .61568 m .85031 .61746 L .81792 .59923 L p .591 .6 .829 r
F P
0 g
s
.81792 .59923 m .84037 .5968 L .87299 .61568 L p .591 .6 .829 r
F P
0 g
s
.88237 .63217 m .90516 .63002 L .93677 .64013 L p .561 .709 .94 r
F P
0 g
s
.90516 .63002 m .88237 .63217 L .85031 .61746 L p .573 .651 .889 r
F P
0 g
s
.50727 .47315 m .48606 .51942 L .45327 .51786 L p .78 .596 .65 r
F P
0 g
s
.45327 .51786 m .47482 .47335 L .50727 .47315 L p .78 .596 .65 r
F P
0 g
s
.85031 .61746 m .87299 .61568 L .90516 .63002 L p .573 .651 .889 r
F P
0 g
s
.5508 .52622 m .52995 .57637 L .49735 .56968 L p .764 .569 .635 r
F P
0 g
s
.49735 .56968 m .51856 .52069 L .5508 .52622 L p .764 .569 .635 r
F P
0 g
s
.81978 .54995 m .79674 .54613 L .76328 .5148 L p .537 .501 .763 r
F P
0 g
s
.76328 .5148 m .78586 .51682 L .81978 .54995 L p .537 .501 .763 r
F P
0 g
s
.80921 .52438 m .78586 .51682 L .75206 .4809 L p .493 .469 .759 r
F P
0 g
s
.75206 .4809 m .77486 .48646 L .80921 .52438 L p .493 .469 .759 r
F P
0 g
s
.61964 .23632 m .64168 .24645 L .67503 .27894 L p .294 .434 .832 r
F P
0 g
s
.65226 .26177 m .61964 .23632 L p .63948 .25159 L .294 .434 .832 r
F P
0 g
s
.61964 .23632 m .58747 .22337 L p .60508 .23087 L .417 .58 .906 r
F P
0 g
s
.64168 .24645 m .61964 .23632 L p .60929 .23244 L .417 .58 .906 r
F P
0 g
s
.61513 .23515 m .64168 .24645 L .60929 .23244 L .417 .58 .906 r
F
.60903 .22645 m .64168 .24645 L p .6228 .23841 L F P
0 g
s
.67503 .27894 m .64168 .24645 L p .66309 .26796 L .047 .287 .778 r
F P
0 g
s
.67503 .27894 m .65449 .26345 L p .64417 .2553 L .294 .434 .832 r
F P
0 g
s
.63948 .25159 m .64961 .25939 L .64417 .2553 L .294 .434 .832 r
F
.64961 .25939 m .67503 .27894 L .64417 .2553 L F
.64168 .24645 m .66451 .26435 L .6801 .28231 L p .047 .287 .778 r
F P
0 g
s
.65226 .26177 m .67503 .27894 L .70933 .32197 L p .173 .322 .775 r
F P
0 g
s
.70933 .32197 m .67503 .27894 L p .69972 .30983 L 0 .176 .707 r
F P
0 g
s
.69876 .3038 m .7236 .33583 L .73912 .3589 L p 0 .023 .594 r
F P
0 g
s
.73413 .35285 m .71512 .32918 L p .70587 .31756 L 0 .176 .707 r
F P
0 g
s
.71117 .32414 m .73413 .35285 L .70587 .31756 L 0 .176 .707 r
F
.67503 .27894 m .69876 .3038 L .73413 .35285 L p F P
0 g
s
.70933 .32197 m .73413 .35285 L .77063 .40801 L p 0 .078 .639 r
F P
0 g
s
.73413 .35285 m .69876 .3038 L p .72618 .34238 L 0 .023 .594 r
F P
0 g
s
.77063 .40801 m .73413 .35285 L p .77294 .41112 L 0 0 .507 r
F P
0 g
s
.77294 .41112 m .78936 .43576 L .78547 .43009 L 0 0 .507 r
F
.78547 .43009 m .77063 .40801 L p .77294 .41112 L F P
0 g
s
.8183 .48204 m .79166 .44828 L .75541 .39497 L p 0 .046 .614 r
F P
0 g
s
.75541 .39497 m .78114 .4275 L .8183 .48204 L p 0 .046 .614 r
F P
0 g
s
.80808 .46495 m .78114 .4275 L .74473 .3727 L p 0 0 .557 r
F P
0 g
s
.74473 .3727 m .77063 .40801 L .80808 .46495 L p 0 0 .557 r
F P
0 g
s
.73413 .35285 m .76015 .39016 L .7978 .44843 L p 0 0 .507 r
F P
0 g
s
.76015 .39016 m .74135 .36322 L p .73383 .35289 L 0 .023 .594 r
F P
0 g
s
.72618 .34238 m .73986 .36162 L .73383 .35289 L 0 .023 .594 r
F
.73986 .36162 m .76015 .39016 L .73383 .35289 L F
.73912 .3589 m .75603 .38404 L p .74041 .36107 L F P
0 g
s
.75603 .38404 m .76015 .39016 L p .74041 .36107 L 0 .023 .594 r
F P
0 g
s
.74535 .36935 m .74041 .36107 L .76015 .39016 L 0 .023 .594 r
F
.74135 .36322 m .73413 .35285 L p .72618 .34238 L F P
0 g
s
.73537 .35424 m .73912 .3589 L .74535 .36935 L 0 .023 .594 r
F
.69876 .3038 m .73912 .3589 L .72881 .34607 L F
.76015 .39016 m .7236 .33583 L p .75549 .38419 L 0 0 .466 r
F P
0 g
s
.75549 .38419 m .77427 .41266 L .7669 .40093 L 0 0 .466 r
F
.75549 .38419 m .7669 .40093 L .76015 .39016 L F
.76403 .39621 m .76015 .39016 L p .77427 .41266 L F P
0 g
s
.7236 .33583 m .74968 .37421 L .76639 .40006 L p 0 0 .466 r
F P
0 g
s
.7236 .33583 m .76639 .40006 L .75679 .38615 L 0 0 .466 r
F
.72881 .34607 m .73537 .35424 L .74535 .36935 L 0 .023 .594 r
F
.66743 .27207 m .69876 .3038 L .67816 .28222 L .047 .287 .778 r
F
.6727 .27762 m .69876 .3038 L .66743 .27207 L F
.6801 .28231 m .69876 .3038 L p .67966 .28462 L F P
0 g
s
.67816 .28222 m .67503 .27894 L p .66309 .26796 L .047 .287 .778 r
F P
0 g
s
.67444 .27806 m .6801 .28231 L .67966 .28462 L .047 .287 .778 r
F
.66309 .26796 m .6727 .27762 L .66743 .27207 L F
.64168 .24645 m .6801 .28231 L .66925 .27415 L F
.7236 .33583 m .69876 .3038 L .68407 .28689 L p 0 .122 .672 r
F P
0 g
s
.68407 .28689 m .66451 .26435 L p .68658 .29105 L 0 .122 .672 r
F P
0 g
s
.68658 .29105 m .68754 .2922 L .68713 .29159 L 0 .122 .672 r
F
.68658 .29105 m .68713 .29159 L .68407 .28689 L F
.66451 .26435 m .64168 .24645 L .62567 .23665 L p .161 .43 .866 r
F P
0 g
s
.63717 .24567 m .66451 .26435 L .62567 .23665 L .161 .43 .866 r
F
.63117 .23699 m .64674 .24976 L p .63845 .24464 L F P
0 g
s
.62567 .23665 m .60903 .22645 L p .62798 .2394 L .161 .43 .866 r
F P
0 g
s
.62798 .2394 m .63717 .24567 L .63171 .24139 L .161 .43 .866 r
F
.62798 .2394 m .63171 .24139 L .62567 .23665 L F
.60903 .22645 m .63794 .24416 L .63845 .24464 L F
.60903 .22645 m .62955 .23622 L p .63794 .24416 L F P
0 g
s
.62955 .23622 m .63117 .23699 L p .63845 .24464 L .161 .43 .866 r
F P
0 g
s
.60903 .22645 m .64674 .24976 L .63565 .24464 L .161 .43 .866 r
F
.60508 .23087 m .61513 .23515 L .60929 .23244 L .417 .58 .906 r
F
.58747 .22337 m .60736 .22621 L p .6228 .23841 L F P
0 g
s
.60736 .22621 m .60903 .22645 L p .6228 .23841 L .417 .58 .906 r
F P
0 g
s
.53429 .23335 m .55537 .22333 L .58747 .22337 L p .711 .829 .938 r
F P
0 g
s
.60903 .22645 m .58747 .22337 L .55537 .22333 L p .538 .771 .984 r
F P
0 g
s
.57669 .21989 m .60903 .22645 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.63117 .23699 m .60903 .22645 L .57669 .21989 L p .267 .622 .96 r
F P
0 g
s
.5984 .22327 m .63117 .23699 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.57669 .21989 m .59749 .22313 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.59749 .22313 m .5984 .22327 L p .61246 .23112 L .267 .622 .96 r
F P
0 g
s
.64674 .24976 m .66451 .26435 L p .63565 .24464 L .161 .43 .866 r
F P
0 g
s
.68754 .2922 m .69179 .29689 L .68407 .28689 L 0 .122 .672 r
F
.69723 .30393 m .7236 .33583 L .68407 .28689 L F
.66451 .26435 m .68618 .28745 L p .69981 .30617 L F P
0 g
s
.68754 .2922 m .69723 .30393 L .69179 .29689 L 0 .122 .672 r
F
.66451 .26435 m .69981 .30617 L .69418 .30023 L F
.68618 .28745 m .68828 .28969 L p .7052 .31356 L F P
0 g
s
.66451 .26435 m .63117 .23699 L p .65155 .2558 L 0 .242 .756 r
F P
0 g
s
.68828 .28969 m .66637 .26634 L p .65475 .25807 L 0 .242 .756 r
F P
0 g
s
.65978 .26339 m .68828 .28969 L .65475 .25807 L 0 .242 .756 r
F
.66637 .26634 m .66451 .26435 L p .65155 .2558 L F P
0 g
s
.65407 .25492 m .68828 .28969 L p .66949 .27235 L 0 .242 .756 r
F P
0 g
s
.66012 .2637 m .6654 .26785 L .66949 .27235 L 0 .242 .756 r
F
.6526 .25377 m .65407 .25492 L p .66949 .27235 L F P
0 g
s
.68828 .28969 m .71059 .32009 L p .7052 .31356 L 0 .122 .672 r
F P
0 g
s
.71374 .32294 m .7236 .33583 L p .71745 .32838 L 0 .122 .672 r
F P
0 g
s
.7236 .33583 m .68828 .28969 L p .71346 .32435 L 0 0 .548 r
F P
0 g
s
.74968 .37421 m .72858 .34315 L p .7179 .32988 L 0 0 .548 r
F P
0 g
s
.72392 .33875 m .74968 .37421 L .7179 .32988 L 0 0 .548 r
F
.72858 .34315 m .7236 .33583 L p .71346 .32435 L F P
0 g
s
.71346 .32435 m .72392 .33875 L .7179 .32988 L 0 0 .548 r
F
.68828 .28969 m .71249 .32112 L p .72752 .34316 L F P
0 g
s
.72078 .33443 m .72752 .34316 L .73362 .3521 L 0 0 .548 r
F
.68828 .28969 m .72752 .34316 L .72078 .33443 L F
.71249 .32112 m .71315 .32197 L p .73362 .3521 L F P
0 g
s
.71315 .32197 m .74968 .37421 L p .73362 .3521 L 0 0 .548 r
F P
0 g
s
.78746 .43266 m .76403 .39621 L p .77427 .41266 L 0 0 .466 r
F P
0 g
s
.76639 .40006 m .78746 .43266 L p .75679 .38615 L 0 0 .466 r
F P
0 g
s
.77063 .40801 m .74473 .3727 L .70933 .32197 L p 0 .078 .639 r
F P
0 g
s
.74968 .37421 m .71315 .32197 L p .7414 .36432 L 0 0 .435 r
F P
0 g
s
.8183 .48204 m .8138 .47544 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.84605 .51902 m .83453 .50366 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.83453 .50366 m .8183 .48204 L p .83304 .50143 L 0 0 .449 r
F P
0 g
s
.80203 .45694 m .84605 .51902 L .8138 .47544 L 0 0 .449 r
F
.77533 .41502 m .79171 .43937 L .79576 .44551 L 0 0 .402 r
F
.7731 .41168 m .7978 .44843 L p .77533 .41502 L F P
0 g
s
.80808 .46495 m .77796 .41916 L p .80333 .45693 L 0 0 .402 r
F P
0 g
s
.80333 .45693 m .81111 .46896 L .80808 .46495 L 0 0 .402 r
F
.80808 .46495 m .81394 .47329 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.7978 .44843 m .76435 .39667 L p .79459 .44353 L .607 .181 0 r
F P
0 g
s
.79576 .44551 m .7978 .44843 L .80048 .45252 L 0 0 .402 r
F
.80117 .45358 m .8109 .46803 L .81424 .47309 L F
.79576 .44551 m .80048 .45252 L .80117 .45358 L F
.80048 .45252 m .8109 .46803 L .80117 .45358 L F
.76217 .39328 m .7944 .44323 L .76435 .39667 L .607 .181 0 r
F
.80203 .45694 m .81394 .47329 L .81759 .47888 L 0 0 .449 r
F
.81394 .47329 m .82102 .48338 L p .81759 .47888 L F P
0 g
s
.82102 .48338 m .84605 .51902 L p .82432 .48837 L 0 0 .449 r
F P
0 g
s
.81759 .47888 m .82102 .48338 L .82432 .48837 L 0 0 .449 r
F
.80808 .46495 m .83621 .50588 L .84605 .51902 L closepath p .618 .169 0 r
F P
0 g
s
.83621 .50588 m .81556 .47583 L p .81378 .47247 L 0 0 .402 r
F P
0 g
s
.81556 .47583 m .80808 .46495 L p .81111 .46896 L 0 0 .402 r
F P
0 g
s
.81378 .47247 m .81556 .47583 L .81111 .46896 L 0 0 .402 r
F
.79171 .43937 m .7978 .44843 L .79576 .44551 L F
.77533 .41502 m .80506 .45939 L .77796 .41916 L F
.80506 .45939 m .83621 .50588 L .80717 .46263 L F
.80506 .45939 m .80717 .46263 L .77796 .41916 L F
.7978 .44843 m .79149 .43905 L p .78936 .43576 L 0 0 .507 r
F P
0 g
s
.78746 .43266 m .82622 .49254 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.76015 .39016 m .76127 .39191 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.76127 .39191 m .78746 .43266 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.7944 .44323 m .82622 .49254 L .79459 .44353 L .607 .181 0 r
F
.7944 .44323 m .79459 .44353 L .76435 .39667 L F
.79459 .44353 m .80031 .45239 L .7978 .44843 L F
.7978 .44843 m .8109 .46803 L p .80048 .45252 L 0 0 .402 r
F P
0 g
s
.8109 .46803 m .83621 .50588 L p .81424 .47309 L 0 0 .402 r
F P
0 g
s
.82622 .49254 m .80361 .45745 L p .80031 .45239 L .607 .181 0 r
F P
0 g
s
.80361 .45745 m .7978 .44843 L p .80031 .45239 L .607 .181 0 r
F P
0 g
s
.76435 .39667 m .76015 .39016 L p .76217 .39328 L .607 .181 0 r
F P
0 g
s
.80333 .45693 m .81378 .47247 L .81111 .46896 L 0 0 .402 r
F
.78114 .4275 m .80808 .46495 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.77706 .41779 m .79365 .44381 L p .77227 .40994 L .622 .195 0 r
F P
0 g
s
.76125 .39247 m .77017 .40675 L .77227 .40994 L .622 .195 0 r
F
.77017 .40675 m .77706 .41779 L .77227 .40994 L F
.77063 .40801 m .7731 .41168 L p .77533 .41502 L 0 0 .402 r
F P
0 g
s
.77796 .41916 m .77063 .40801 L p .77533 .41502 L 0 0 .402 r
F P
0 g
s
.8138 .47544 m .78114 .4275 L p .80203 .45694 L 0 0 .449 r
F P
0 g
s
.7414 .36432 m .75289 .38155 L .74604 .37067 L 0 0 .435 r
F
.75606 .38437 m .74968 .37421 L p .7414 .36432 L F P
0 g
s
.75289 .38155 m .77706 .41779 L .74604 .37067 L 0 0 .435 r
F
.71315 .32197 m .73923 .36043 L .76108 .39356 L p F P
0 g
s
.71315 .32197 m .76108 .39356 L .7499 .37706 L 0 0 .435 r
F
.73923 .36043 m .7666 .40394 L .79223 .44405 L p .623 .195 0 r
F P
0 g
s
.79223 .44405 m .80576 .46523 L p .78198 .42776 L .623 .195 0 r
F P
0 g
s
.73923 .36043 m .79223 .44405 L .78198 .42776 L .623 .195 0 r
F
.77706 .41779 m .75606 .38437 L p .74604 .37067 L 0 0 .435 r
F P
0 g
s
.69418 .30023 m .69981 .30617 L .7052 .31356 L 0 .122 .672 r
F
.71315 .32197 m .68828 .28969 L .67013 .27125 L p 0 .072 .621 r
F P
0 g
s
.68352 .28834 m .71315 .32197 L .67013 .27125 L 0 .072 .621 r
F
.68553 .29063 m .69093 .29634 L .69477 .30111 L F
.67013 .27125 m .65407 .25492 L p .68352 .28834 L F P
0 g
s
.65407 .25492 m .67788 .27991 L .69731 .30308 L p 0 .072 .621 r
F P
0 g
s
.65407 .25492 m .69731 .30308 L .68553 .29063 L 0 .072 .621 r
F
.69731 .30308 m .71315 .32197 L p .69477 .30111 L F P
0 g
s
.69093 .29634 m .69731 .30308 L .69477 .30111 L 0 .072 .621 r
F
.71315 .32197 m .67788 .27991 L p .7015 .31091 L 0 0 .504 r
F P
0 g
s
.73923 .36043 m .71651 .32692 L p .70397 .31354 L 0 0 .504 r
F P
0 g
s
.70868 .32034 m .73923 .36043 L .70397 .31354 L 0 0 .504 r
F
.71651 .32692 m .71315 .32197 L p .7015 .31091 L F P
0 g
s
.7015 .31091 m .70868 .32034 L .70397 .31354 L 0 0 .504 r
F
.67788 .27991 m .70377 .31288 L .71855 .33308 L F
.67788 .27991 m .71855 .33308 L .71273 .32564 L F
.67788 .27991 m .70275 .3115 L .70377 .31288 L p F P
0 g
s
.71512 .32918 m .70933 .32197 L p .69972 .30983 L 0 .176 .707 r
F P
0 g
s
.71273 .32564 m .71855 .33308 L .72227 .33816 L 0 0 .504 r
F
.70377 .31288 m .73923 .36043 L p .72227 .33816 L F P
0 g
s
.73923 .36043 m .70275 .3115 L p .72873 .34912 L 0 0 .419 r
F P
0 g
s
.72873 .34912 m .73441 .35734 L .73046 .35124 L 0 0 .419 r
F
.74354 .36728 m .73923 .36043 L p .72873 .34912 L F P
0 g
s
.73441 .35734 m .7666 .40394 L .73046 .35124 L 0 0 .419 r
F
.70275 .3115 m .72879 .34895 L .75409 .38575 L p F P
0 g
s
.70275 .3115 m .75409 .38575 L .74262 .36922 L 0 0 .419 r
F
.74473 .3727 m .72003 .34376 L .68566 .29836 L p .047 .229 .728 r
F P
0 g
s
.68566 .29836 m .70933 .32197 L .74473 .3727 L p .047 .229 .728 r
F P
0 g
s
.78114 .4275 m .75541 .39497 L .72003 .34376 L p 0 .14 .68 r
F P
0 g
s
.72003 .34376 m .74473 .3727 L .78114 .4275 L p 0 .14 .68 r
F P
0 g
s
.72879 .34895 m .75608 .39119 L .78597 .43698 L p .611 .181 0 r
F P
0 g
s
.78597 .43698 m .79529 .45125 L p .77588 .42139 L .611 .181 0 r
F P
0 g
s
.72879 .34895 m .78597 .43698 L .77588 .42139 L .611 .181 0 r
F
.7666 .40394 m .74354 .36728 L p .73046 .35124 L 0 0 .419 r
F P
0 g
s
.65155 .2558 m .65978 .26339 L .65475 .25807 L 0 .242 .756 r
F
.63117 .23699 m .6526 .25377 L p .6654 .26785 L F P
0 g
s
.63117 .23699 m .6654 .26785 L .66012 .2637 L 0 .242 .756 r
F
.63117 .23699 m .61307 .22941 L p .62176 .23482 L 0 .4 .84 r
F P
0 g
s
.61307 .22941 m .5984 .22327 L p .62467 .23821 L 0 .4 .84 r
F P
0 g
s
.62467 .23821 m .65407 .25492 L .61307 .22941 L 0 .4 .84 r
F
.5984 .22327 m .61979 .23321 L p .62037 .23362 L F P
0 g
s
.65407 .25492 m .63117 .23699 L p .62176 .23482 L 0 .4 .84 r
F P
0 g
s
.61664 .23364 m .62037 .23362 L .63539 .2443 L 0 .4 .84 r
F
.5984 .22327 m .62037 .23362 L .61664 .23364 L F
.61979 .23321 m .62067 .23361 L p .63539 .2443 L F P
0 g
s
.55537 .22333 m .57605 .21999 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.57605 .21999 m .57669 .21989 L p .5904 .22537 L .538 .771 .984 r
F P
0 g
s
.53429 .23335 m .51332 .24955 L .50144 .25706 L p .853 .966 .873 r
F P
0 g
s
.50144 .25706 m .48047 .27032 L p .50883 .25084 L .853 .966 .873 r
F P
0 g
s
.50883 .25084 m .53429 .23335 L .50144 .25706 L .853 .966 .873 r
F
.50169 .25055 m .5229 .23586 L .5298 .23319 L p .761 .975 .921 r
F P
0 g
s
.48047 .27032 m .50169 .25055 L .53429 .23335 L p .853 .966 .873 r
F P
0 g
s
.55537 .22333 m .53429 .23335 L .52174 .23997 L p .761 .975 .921 r
F P
0 g
s
.52174 .23997 m .5199 .24095 L p .55537 .22333 L .761 .975 .921 r
F P
0 g
s
.52876 .23682 m .55537 .22333 L .5199 .24095 L .761 .975 .921 r
F
.5199 .24095 m .50169 .25055 L p .52876 .23682 L F P
0 g
s
.5298 .23319 m .55537 .22333 L p .52052 .241 L .761 .975 .921 r
F P
0 g
s
.50169 .25055 m .5298 .23319 L .52052 .241 L .761 .975 .921 r
F
.57669 .21989 m .55537 .22333 L .5229 .23586 L p .584 .93 .951 r
F P
0 g
s
.5229 .23586 m .54422 .2268 L .55542 .22441 L p .584 .93 .951 r
F P
0 g
s
.55542 .22441 m .57669 .21989 L p .54481 .22935 L .584 .93 .951 r
F P
0 g
s
.5229 .23586 m .55542 .22441 L .54481 .22935 L .584 .93 .951 r
F
.5984 .22327 m .57669 .21989 L .54422 .2268 L p .303 .783 .916 r
F P
0 g
s
.54422 .2268 m .56576 .22375 L .5984 .22327 L p .303 .783 .916 r
F P
0 g
s
.62067 .23361 m .5984 .22327 L .56576 .22375 L p 0 .549 .802 r
F P
0 g
s
.58768 .22693 m .62067 .23361 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.56576 .22375 m .58737 .22689 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.58737 .22689 m .58768 .22693 L p .60197 .23025 L 0 .549 .802 r
F P
0 g
s
.62067 .23361 m .65407 .25492 L p .63539 .2443 L 0 .4 .84 r
F P
0 g
s
.64688 .25483 m .67788 .27991 L .64503 .25151 L 0 .186 .682 r
F
.64249 .25042 m .64503 .25151 L .63461 .24251 L F
.64688 .25483 m .64503 .25151 L .64249 .25042 L F
.63461 .24251 m .62067 .23361 L p .64688 .25483 L F P
0 g
s
.62067 .23361 m .65598 .26131 L .65894 .26418 L 0 .186 .682 r
F
.62067 .23361 m .65894 .26418 L .65109 .25824 L F
.64366 .25084 m .65598 .26131 L p .64153 .24997 L F P
0 g
s
.62067 .23361 m .64366 .25084 L p .64153 .24997 L 0 .186 .682 r
F P
0 g
s
.64366 .25084 m .62067 .23361 L .61847 .23317 L p 0 .311 .659 r
F P
0 g
s
.61847 .23317 m .58768 .22693 L p .60538 .23449 L 0 .311 .659 r
F P
0 g
s
.60538 .23449 m .64366 .25084 L .61847 .23317 L 0 .311 .659 r
F
.58768 .22693 m .6098 .23631 L p .62496 .24285 L F P
0 g
s
.6098 .23631 m .61012 .23645 L p .62496 .24285 L 0 .311 .659 r
F P
0 g
s
.57679 .23738 m .61012 .23645 L p .59118 .23593 L .25 0 0 r
F P
0 g
s
.55462 .23492 m .57679 .23738 L p .59118 .23593 L .25 0 0 r
F P
0 g
s
.61012 .23645 m .64366 .25084 L p .62496 .24285 L 0 .311 .659 r
F P
0 g
s
.65109 .25824 m .65894 .26418 L .66141 .26658 L 0 .186 .682 r
F
.65598 .26131 m .67788 .27991 L p .66141 .26658 L F P
0 g
s
.66925 .27415 m .67444 .27806 L .67966 .28462 L .047 .287 .778 r
F
.70275 .3115 m .67788 .27991 L .65691 .2621 L p 0 .033 .553 r
F P
0 g
s
.66452 .27226 m .66998 .27787 L .66626 .27337 L 0 .033 .553 r
F
.66998 .27787 m .70275 .3115 L .65691 .2621 L F
.65691 .2621 m .64366 .25084 L p .66452 .27226 L F P
0 g
s
.66452 .27226 m .66626 .27337 L .65691 .2621 L 0 .033 .553 r
F
.64366 .25084 m .6672 .27432 L p .68161 .2897 L F P
0 g
s
.64366 .25084 m .68161 .2897 L .67695 .28502 L 0 .033 .553 r
F
.6672 .27432 m .66751 .27463 L p .68424 .2925 L F P
0 g
s
.70933 .32197 m .68566 .29836 L .65226 .26177 L p .173 .322 .775 r
F P
0 g
s
.63322 .25221 m .66751 .27463 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.61012 .23645 m .633 .25206 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.633 .25206 m .63322 .25221 L p .64873 .26214 L .432 0 0 r
F P
0 g
s
.67695 .28502 m .68161 .2897 L .68424 .2925 L 0 .033 .553 r
F
.66751 .27463 m .70275 .3115 L p .68424 .2925 L F P
0 g
s
.69972 .30983 m .71117 .32414 L .70587 .31756 L 0 .176 .707 r
F
.70275 .3115 m .66751 .27463 L p .68996 .30186 L 0 0 .468 r
F P
0 g
s
.68996 .30186 m .69401 .30677 L .69113 .30286 L 0 0 .468 r
F
.69401 .30677 m .72879 .34895 L .69113 .30286 L F
.70486 .31454 m .70275 .3115 L p .68996 .30186 L F P
0 g
s
.66751 .27463 m .69471 .3074 L .70897 .32489 L 0 0 .468 r
F
.66751 .27463 m .70897 .32489 L .70461 .31963 L F
.66751 .27463 m .69236 .30453 L .69471 .3074 L p F P
0 g
s
.69236 .30453 m .71832 .33985 L .74608 .37761 L p .57 .124 0 r
F P
0 g
s
.74608 .37761 m .75608 .39119 L p .73498 .3625 L .57 .124 0 r
F P
0 g
s
.69236 .30453 m .74608 .37761 L .73498 .3625 L .57 .124 0 r
F
.72879 .34895 m .70486 .31454 L p .69113 .30286 L 0 0 .468 r
F P
0 g
s
.63322 .25221 m .65712 .27391 L .65752 .27426 L p .518 0 0 r
F P
0 g
s
.65752 .27426 m .69236 .30453 L p .67367 .288 L .518 0 0 r
F P
0 g
s
.63322 .25221 m .65752 .27426 L .67367 .288 L .518 0 0 r
F
.70461 .31963 m .70897 .32489 L .71113 .32754 L 0 0 .468 r
F
.67788 .27991 m .65407 .25492 L .63461 .24251 L p 0 .186 .682 r
F P
0 g
s
.69471 .3074 m .72879 .34895 L p .71113 .32754 L 0 0 .468 r
F P
0 g
s
.75409 .38575 m .7666 .40394 L p .74262 .36922 L 0 0 .419 r
F P
0 g
s
.76108 .39356 m .77706 .41779 L p .7499 .37706 L 0 0 .435 r
F P
0 g
s
.79365 .44381 m .81607 .47899 L p .78651 .43234 L .622 .195 0 r
F P
0 g
s
.76125 .39247 m .79365 .44381 L .78651 .43234 L .622 .195 0 r
F
.74968 .37421 m .75826 .38786 L p .76125 .39247 L F P
0 g
s
.75826 .38786 m .77706 .41779 L p .76125 .39247 L .622 .195 0 r
F P
0 g
s
.79149 .43905 m .78547 .43009 L p .78936 .43576 L 0 0 .507 r
F P
0 g
s
.65449 .26345 m .65226 .26177 L p .63948 .25159 L .294 .434 .832 r
F P
0 g
s
.79851 .49798 m .77486 .48646 L .7408 .44652 L p .443 .436 .756 r
F P
0 g
s
.7408 .44652 m .76381 .45573 L .79851 .49798 L p .443 .436 .756 r
F P
0 g
s
.62666 .59775 m .60604 .62935 L .57389 .62863 L p .75 .565 .646 r
F P
0 g
s
.57389 .62863 m .59453 .58741 L .62666 .59775 L p .75 .565 .646 r
F P
0 g
s
.78774 .47127 m .76381 .45573 L .72956 .41256 L p .386 .401 .753 r
F P
0 g
s
.72956 .41256 m .75276 .42535 L .78774 .47127 L p .386 .401 .753 r
F P
0 g
s
.77694 .44481 m .75276 .42535 L .7184 .37994 L p .319 .363 .75 r
F P
0 g
s
.7184 .37994 m .74176 .3961 L .77694 .44481 L p .319 .363 .75 r
F P
0 g
s
.86338 .59774 m .84037 .5968 L .80744 .57376 L p .55 .563 .82 r
F P
0 g
s
.80744 .57376 m .83018 .57421 L .86338 .59774 L p .55 .563 .82 r
F P
0 g
s
.90516 .63002 m .92829 .6288 L .93677 .64013 L closepath p .528 .711 .956 r
F P
0 g
s
.59453 .58741 m .57389 .62863 L .5414 .61767 L p .757 .583 .661 r
F P
0 g
s
.5414 .61767 m .56233 .58048 L .59453 .58741 L p .757 .583 .661 r
F P
0 g
s
.4618 .3424 m .44039 .37843 L .40661 .39679 L p .875 .758 .729 r
F P
0 g
s
.40661 .39679 m .42839 .36165 L .4618 .3424 L p .875 .758 .729 r
F P
0 g
s
.51332 .24955 m .49234 .27128 L .45915 .29449 L p .897 .938 .832 r
F P
0 g
s
.45915 .29449 m .48047 .27032 L .51332 .24955 L p .897 .938 .832 r
F P
0 g
s
.51856 .52069 m .49735 .56968 L .46451 .56581 L p .775 .587 .645 r
F P
0 g
s
.46451 .56581 m .48606 .51942 L .51856 .52069 L p .775 .587 .645 r
F P
0 g
s
.4635 .43487 m .44194 .47716 L .40856 .48349 L p .81 .645 .677 r
F P
0 g
s
.40856 .48349 m .43045 .44315 L .4635 .43487 L p .81 .645 .677 r
F P
0 g
s
.76615 .41919 m .74176 .3961 L .70735 .3495 L p .242 .322 .747 r
F P
0 g
s
.70735 .3495 m .73084 .36867 L .76615 .41919 L p .242 .322 .747 r
F P
0 g
s
.49234 .27128 m .47123 .29781 L .43766 .32229 L p .914 .907 .801 r
F P
0 g
s
.43766 .32229 m .45915 .29449 L .49234 .27128 L p .914 .907 .801 r
F P
0 g
s
.89613 .61593 m .87299 .61568 L .84037 .5968 L p .522 .612 .883 r
F P
0 g
s
.84037 .5968 m .86338 .59774 L .89613 .61593 L p .522 .612 .883 r
F P
0 g
s
.92829 .6288 m .90516 .63002 L .87299 .61568 L p .501 .675 .943 r
F P
0 g
s
.47482 .47335 m .45327 .51786 L .42009 .51931 L p .792 .617 .663 r
F P
0 g
s
.42009 .51931 m .44194 .47716 L .47482 .47335 L p .792 .617 .663 r
F P
0 g
s
.85356 .57845 m .83018 .57421 L .79674 .54613 L p .5 .523 .812 r
F P
0 g
s
.79674 .54613 m .81978 .54995 L .85356 .57845 L p .5 .523 .812 r
F P
0 g
s
.45206 .40296 m .43045 .44315 L .39676 .45449 L p .835 .685 .696 r
F P
0 g
s
.39676 .45449 m .4187 .41624 L .45206 .40296 L p .835 .685 .696 r
F P
0 g
s
.87299 .61568 m .89613 .61593 L .92829 .6288 L p .501 .675 .943 r
F P
0 g
s
.56233 .58048 m .5414 .61767 L .50877 .61238 L p .766 .597 .669 r
F P
0 g
s
.50877 .61238 m .52995 .57637 L .56233 .58048 L p .766 .597 .669 r
F P
0 g
s
.47123 .29781 m .44993 .32829 L .41597 .35278 L p .918 .878 .78 r
F P
0 g
s
.41597 .35278 m .43766 .32229 L .47123 .29781 L p .918 .878 .78 r
F P
0 g
s
.75541 .39497 m .73084 .36867 L .69643 .32207 L p .151 .277 .74 r
F P
0 g
s
.69643 .32207 m .72003 .34376 L .75541 .39497 L p .151 .277 .74 r
F P
0 g
s
.84354 .55797 m .81978 .54995 L .78586 .51682 L p .442 .48 .803 r
F P
0 g
s
.78586 .51682 m .80921 .52438 L .84354 .55797 L p .442 .48 .803 r
F P
0 g
s
.48606 .51942 m .46451 .56581 L .43132 .5654 L p .774 .585 .643 r
F P
0 g
s
.43132 .5654 m .45327 .51786 L .48606 .51942 L p .774 .585 .643 r
F P
0 g
s
.83336 .53655 m .80921 .52438 L .77486 .48646 L p .374 .433 .794 r
F P
0 g
s
.77486 .48646 m .79851 .49798 L .83336 .53655 L p .374 .433 .794 r
F P
0 g
s
.88693 .60103 m .86338 .59774 L .83018 .57421 L p .457 .564 .875 r
F P
0 g
s
.83018 .57421 m .85356 .57845 L .88693 .60103 L p .457 .564 .875 r
F P
0 g
s
.44039 .37843 m .4187 .41624 L .38459 .43251 L p .867 .744 .724 r
F P
0 g
s
.38459 .43251 m .40661 .39679 L .44039 .37843 L p .867 .744 .724 r
F P
0 g
s
.52995 .57637 m .50877 .61238 L .47585 .61279 L p .76 .575 .647 r
F P
0 g
s
.47585 .61279 m .49735 .56968 L .52995 .57637 L p .76 .575 .647 r
F P
0 g
s
.82305 .5145 m .79851 .49798 L .76381 .45573 L p .297 .382 .781 r
F P
0 g
s
.76381 .45573 m .78774 .47127 L .82305 .5145 L p .297 .382 .781 r
F P
0 g
s
.89613 .61593 m .91967 .6173 L .92829 .6288 L closepath p .454 .672 .957 r
F P
0 g
s
.44993 .32829 m .42839 .36165 L .39406 .38496 L p .914 .85 .767 r
F P
0 g
s
.39406 .38496 m .41597 .35278 L .44993 .32829 L p .914 .85 .767 r
F P
0 g
s
.91967 .6173 m .89613 .61593 L .86338 .59774 L p .417 .626 .939 r
F P
0 g
s
.86338 .59774 m .88693 .60103 L .91967 .6173 L p .417 .626 .939 r
F P
0 g
s
.44194 .47716 m .42009 .51931 L .38641 .52377 L p .802 .635 .675 r
F P
0 g
s
.38641 .52377 m .40856 .48349 L .44194 .47716 L p .802 .635 .675 r
F P
0 g
s
.43045 .44315 m .40856 .48349 L .37462 .49172 L p .827 .678 .698 r
F P
0 g
s
.37462 .49172 m .39676 .45449 L .43045 .44315 L p .827 .678 .698 r
F P
0 g
s
.81264 .49218 m .78774 .47127 L .75276 .42535 L p .209 .326 .765 r
F P
0 g
s
.75276 .42535 m .77694 .44481 L .81264 .49218 L p .209 .326 .765 r
F P
0 g
s
.87755 .58536 m .85356 .57845 L .81978 .54995 L p .377 .508 .863 r
F P
0 g
s
.81978 .54995 m .84354 .55797 L .87755 .58536 L p .377 .508 .863 r
F P
0 g
s
.49735 .56968 m .47585 .61279 L .44285 .6029 L p .767 .597 .667 r
F P
0 g
s
.44285 .6029 m .46451 .56581 L .49735 .56968 L p .767 .597 .667 r
F P
0 g
s
.45327 .51786 m .43132 .5654 L .39792 .56239 L p .784 .605 .658 r
F P
0 g
s
.39792 .56239 m .42009 .51931 L .45327 .51786 L p .784 .605 .658 r
F P
0 g
s
.80217 .46997 m .77694 .44481 L .74176 .3961 L p .113 .266 .743 r
F P
0 g
s
.74176 .3961 m .76615 .41919 L .80217 .46997 L p .113 .266 .743 r
F P
0 g
s
.4187 .41624 m .39676 .45449 L .3624 .46761 L p .856 .73 .723 r
F P
0 g
s
.3624 .46761 m .38459 .43251 L .4187 .41624 L p .856 .73 .723 r
F P
0 g
s
.42839 .36165 m .40661 .39679 L .37196 .41779 L p .903 .826 .76 r
F P
0 g
s
.37196 .41779 m .39406 .38496 L .42839 .36165 L p .903 .826 .76 r
F P
0 g
s
.868 .569 m .84354 .55797 L .80921 .52438 L p .283 .442 .843 r
F P
0 g
s
.80921 .52438 m .83336 .53655 L .868 .569 L p .283 .442 .843 r
F P
0 g
s
.50169 .25055 m .48047 .27032 L .47482 .27515 L p .763 .986 .752 r
F P
0 g
s
.47482 .27515 m .44659 .29932 L p .47796 .27155 L .763 .986 .752 r
F P
0 g
s
.47796 .27155 m .50169 .25055 L .47482 .27515 L .763 .986 .752 r
F
.44659 .29932 m .46817 .27755 L .50169 .25055 L p F P
0 g
s
.5229 .23586 m .50169 .25055 L .48922 .26059 L p .619 .936 .713 r
F P
0 g
s
.48922 .26059 m .46817 .27755 L p .49653 .25595 L .619 .936 .713 r
F P
0 g
s
.49653 .25595 m .5229 .23586 L .48922 .26059 L .619 .936 .713 r
F
.48967 .2597 m .5229 .23586 L p .48177 .26719 L F P
0 g
s
.54422 .2268 m .5229 .23586 L .50721 .24711 L p .422 .835 .653 r
F P
0 g
s
.50721 .24711 m .48967 .2597 L p .51623 .24368 L .422 .835 .653 r
F P
0 g
s
.51623 .24368 m .54422 .2268 L .50721 .24711 L .422 .835 .653 r
F
.48967 .2597 m .51118 .24633 L .51779 .24242 L p F P
0 g
s
.51779 .24242 m .54422 .2268 L p .50829 .24846 L .422 .835 .653 r
F P
0 g
s
.48967 .2597 m .51779 .24242 L .50829 .24846 L .422 .835 .653 r
F
.51118 .24633 m .53279 .23797 L .54471 .23283 L p 0 0 0 r
F P
0 g
s
.54471 .23283 m .56576 .22375 L p .53354 .23708 L 0 0 0 r
F P
0 g
s
.51118 .24633 m .54471 .23283 L .53354 .23708 L 0 0 0 r
F
.46817 .27755 m .48473 .26379 L p .48177 .26719 L .619 .936 .713 r
F P
0 g
s
.48473 .26379 m .48967 .2597 L p .48177 .26719 L .619 .936 .713 r
F P
0 g
s
.91094 .60564 m .88693 .60103 L .85356 .57845 L p .307 .557 .924 r
F P
0 g
s
.85356 .57845 m .87755 .58536 L .91094 .60564 L p .307 .557 .924 r
F P
0 g
s
.48047 .27032 m .45915 .29449 L .42488 .32431 L p .853 .997 .774 r
F P
0 g
s
.42488 .32431 m .44659 .29932 L .48047 .27032 L p .853 .997 .774 r
F P
0 g
s
.46451 .56581 m .44285 .6029 L .40957 .59721 L p .778 .629 .695 r
F P
0 g
s
.40957 .59721 m .43132 .5654 L .46451 .56581 L p .778 .629 .695 r
F P
0 g
s
.79166 .44828 m .76615 .41919 L .73084 .36867 L p .009 .203 .715 r
F P
0 g
s
.73084 .36867 m .75541 .39497 L .79166 .44828 L p .009 .203 .715 r
F P
0 g
s
.45915 .29449 m .43766 .32229 L .40301 .3517 L p .901 .984 .784 r
F P
0 g
s
.40301 .3517 m .42488 .32431 L .45915 .29449 L p .901 .984 .784 r
F P
0 g
s
.88693 .60103 m .91094 .60564 L .91967 .6173 L closepath p .351 .613 .948 r
F P
0 g
s
.8583 .55207 m .83336 .53655 L .79851 .49798 L p .176 .367 .815 r
F P
0 g
s
.79851 .49798 m .82305 .5145 L .8583 .55207 L p .176 .367 .815 r
F P
0 g
s
.42009 .51931 m .39792 .56239 L .36417 .56068 L p .796 .638 .685 r
F P
0 g
s
.36417 .56068 m .38641 .52377 L .42009 .51931 L p .796 .638 .685 r
F P
0 g
s
.40856 .48349 m .38641 .52377 L .35234 .52748 L p .813 .665 .699 r
F P
0 g
s
.35234 .52748 m .37462 .49172 L .40856 .48349 L p .813 .665 .699 r
F P
0 g
s
.40661 .39679 m .38459 .43251 L .34971 .4502 L p .889 .803 .758 r
F P
0 g
s
.34971 .4502 m .37196 .41779 L .40661 .39679 L p .889 .803 .758 r
F P
0 g
s
.43766 .32229 m .41597 .35278 L .38097 .38063 L p .921 .959 .789 r
F P
0 g
s
.38097 .38063 m .40301 .3517 L .43766 .32229 L p .921 .959 .789 r
F P
0 g
s
.90208 .59381 m .87755 .58536 L .84354 .55797 L p .173 .468 .889 r
F P
0 g
s
.84354 .55797 m .868 .569 L .90208 .59381 L p .173 .468 .889 r
F P
0 g
s
.39676 .45449 m .37462 .49172 L .34012 .50093 L p .841 .716 .726 r
F P
0 g
s
.34012 .50093 m .3624 .46761 L .39676 .45449 L p .841 .716 .726 r
F P
0 g
s
.56576 .22375 m .54422 .2268 L .51118 .24633 L p 0 0 0 r
F P
0 g
s
.84846 .53472 m .82305 .5145 L .78774 .47127 L p .06 .286 .775 r
F P
0 g
s
.78774 .47127 m .81264 .49218 L .84846 .53472 L p .06 .286 .775 r
F P
0 g
s
.43132 .5654 m .40957 .59721 L .37587 .59605 L p .769 .61 .682 r
F P
0 g
s
.37587 .59605 m .39792 .56239 L .43132 .5654 L p .769 .61 .682 r
F P
0 g
s
.41597 .35278 m .39406 .38496 L .35877 .41019 L p .924 .93 .793 r
F P
0 g
s
.35877 .41019 m .38097 .38063 L .41597 .35278 L p .924 .93 .793 r
F P
0 g
s
.87755 .58536 m .90208 .59381 L .91094 .60564 L closepath p .219 .529 .921 r
F P
0 g
s
.8385 .51713 m .81264 .49218 L .77694 .44481 L p 0 .202 .727 r
F P
0 g
s
.77694 .44481 m .80217 .46997 L .8385 .51713 L p 0 .202 .727 r
F P
0 g
s
.38641 .52377 m .36417 .56068 L .32997 .56141 L p .795 .646 .697 r
F P
0 g
s
.32997 .56141 m .35234 .52748 L .38641 .52377 L p .795 .646 .697 r
F P
0 g
s
.89308 .5818 m .868 .569 L .83336 .53655 L p .023 .36 .832 r
F P
0 g
s
.83336 .53655 m .8583 .55207 L .89308 .5818 L p .023 .36 .832 r
F P
0 g
s
.38459 .43251 m .3624 .46761 L .32739 .48119 L p .871 .782 .76 r
F P
0 g
s
.32739 .48119 m .34971 .4502 L .38459 .43251 L p .871 .782 .76 r
F P
0 g
s
.39792 .56239 m .37587 .59605 L .34218 .58898 L p .773 .636 .71 r
F P
0 g
s
.34218 .58898 m .36417 .56068 L .39792 .56239 L p .773 .636 .71 r
F P
0 g
s
.37462 .49172 m .35234 .52748 L .31784 .5314 L p .823 .704 .733 r
F P
0 g
s
.31784 .5314 m .34012 .50093 L .37462 .49172 L p .823 .704 .733 r
F P
0 g
s
.58768 .22693 m .56576 .22375 L .53279 .23797 L p .052 0 0 r
F P
0 g
s
.82845 .4995 m .80217 .46997 L .76615 .41919 L p 0 .121 .672 r
F P
0 g
s
.76615 .41919 m .79166 .44828 L .82845 .4995 L p 0 .121 .672 r
F P
0 g
s
.39406 .38496 m .37196 .41779 L .33647 .43948 L p .915 .899 .797 r
F P
0 g
s
.33647 .43948 m .35877 .41019 L .39406 .38496 L p .915 .899 .797 r
F P
0 g
s
.88396 .56962 m .8583 .55207 L .82305 .5145 L p 0 .244 .756 r
F P
0 g
s
.82305 .5145 m .84846 .53472 L .88396 .56962 L p 0 .244 .756 r
F P
0 g
s
.868 .569 m .89308 .5818 L .90208 .59381 L closepath p .062 .421 .867 r
F P
0 g
s
.3624 .46761 m .34012 .50093 L .30509 .50981 L p .85 .763 .765 r
F P
0 g
s
.30509 .50981 m .32739 .48119 L .3624 .46761 L p .85 .763 .765 r
F P
0 g
s
.36417 .56068 m .34218 .58898 L .30821 .5832 L p .781 .692 .766 r
F P
0 g
s
.30821 .5832 m .32997 .56141 L .36417 .56068 L p .781 .692 .766 r
F P
0 g
s
.46817 .27755 m .44659 .29932 L .41151 .3339 L p .52 .832 .518 r
F P
0 g
s
.41151 .3339 m .43347 .31189 L .46817 .27755 L p .52 .832 .518 r
F P
0 g
s
.44659 .29932 m .42488 .32431 L .38944 .35795 L p .665 .921 .617 r
F P
0 g
s
.38944 .35795 m .41151 .3339 L .44659 .29932 L p .665 .921 .617 r
F P
0 g
s
.48967 .2597 m .46817 .27755 L .43347 .31189 L p 0 0 0 r
F P
0 g
s
.51118 .24633 m .48967 .2597 L .45534 .2926 L p 0 0 0 r
F P
0 g
s
.43347 .31189 m .45534 .2926 L .48967 .2597 L p 0 0 0 r
F P
0 g
s
.35234 .52748 m .32997 .56141 L .29558 .55967 L p .798 .677 .73 r
F P
0 g
s
.29558 .55967 m .31784 .5314 L .35234 .52748 L p .798 .677 .73 r
F P
0 g
s
.37196 .41779 m .34971 .4502 L .31411 .46763 L p .898 .869 .801 r
F P
0 g
s
.31411 .46763 m .33647 .43948 L .37196 .41779 L p .898 .869 .801 r
F P
0 g
s
.42488 .32431 m .40301 .3517 L .36725 .38332 L p .777 .977 .701 r
F P
0 g
s
.36725 .38332 m .38944 .35795 L .42488 .32431 L p .777 .977 .701 r
F P
0 g
s
.53279 .23797 m .51118 .24633 L .47716 .27663 L p 0 0 0 r
F P
0 g
s
.45534 .2926 m .47716 .27663 L .51118 .24633 L p 0 0 0 r
F P
0 g
s
.87469 .55725 m .84846 .53472 L .81264 .49218 L p 0 .132 .67 r
F P
0 g
s
.81264 .49218 m .8385 .51713 L .87469 .55725 L p 0 .132 .67 r
F P
0 g
s
.34012 .50093 m .31784 .5314 L .28287 .53578 L p .825 .739 .769 r
F P
0 g
s
.28287 .53578 m .30509 .50981 L .34012 .50093 L p .825 .739 .769 r
F P
0 g
s
.61012 .23645 m .58768 .22693 L .55462 .23492 L p .25 0 0 r
F P
0 g
s
.53279 .23797 m .55462 .23492 L .58768 .22693 L p .052 0 0 r
F P
0 g
s
.40301 .3517 m .38097 .38063 L .34495 .40924 L p .848 .996 .764 r
F P
0 g
s
.34495 .40924 m .36725 .38332 L .40301 .3517 L p .848 .996 .764 r
F P
0 g
s
.32997 .56141 m .30821 .5832 L .27382 .58001 L p .767 .681 .768 r
F P
0 g
s
.27382 .58001 m .29558 .55967 L .32997 .56141 L p .767 .681 .768 r
F P
0 g
s
.8583 .55207 m .88396 .56962 L .89308 .5818 L closepath p 0 .296 .787 r
F P
0 g
s
.34971 .4502 m .32739 .48119 L .2918 .49386 L p .876 .84 .807 r
F P
0 g
s
.2918 .49386 m .31411 .46763 L .34971 .4502 L p .876 .84 .807 r
F P
0 g
s
.55462 .23492 m .53279 .23797 L .49902 .26446 L p .111 0 0 r
F P
0 g
s
.47716 .27663 m .49902 .26446 L .53279 .23797 L p 0 0 0 r
F P
0 g
s
.31784 .5314 m .29558 .55967 L .26089 .55782 L p .8 .729 .785 r
F P
0 g
s
.26089 .55782 m .28287 .53578 L .31784 .5314 L p .8 .729 .785 r
F P
0 g
s
.38097 .38063 m .35877 .41019 L .3226 .43497 L p .884 .988 .806 r
F P
0 g
s
.3226 .43497 m .34495 .40924 L .38097 .38063 L p .884 .988 .806 r
F P
0 g
s
.86529 .5447 m .8385 .51713 L .80217 .46997 L p 0 .033 .585 r
F P
0 g
s
.80217 .46997 m .82845 .4995 L .86529 .5447 L p 0 .033 .585 r
F P
0 g
s
.32739 .48119 m .30509 .50981 L .26961 .51748 L p .849 .813 .815 r
F P
0 g
s
.26961 .51748 m .2918 .49386 L .32739 .48119 L p .849 .813 .815 r
F P
0 g
s
.29558 .55967 m .27382 .58001 L .23936 .57433 L p .757 .711 .809 r
F P
0 g
s
.23936 .57433 m .26089 .55782 L .29558 .55967 L p .757 .711 .809 r
F P
0 g
s
.35877 .41019 m .33647 .43948 L .30023 .45981 L p .892 .963 .833 r
F P
0 g
s
.30023 .45981 m .3226 .43497 L .35877 .41019 L p .892 .963 .833 r
F P
0 g
s
.84846 .53472 m .87469 .55725 L .88396 .56962 L closepath p 0 .169 .69 r
F P
0 g
s
.30509 .50981 m .28287 .53578 L .24759 .53847 L p .818 .781 .818 r
F P
0 g
s
.24759 .53847 m .26961 .51748 L .30509 .50981 L p .818 .781 .818 r
F P
0 g
s
.57679 .23738 m .55462 .23492 L .52098 .25653 L p .235 0 0 r
F P
0 g
s
.49902 .26446 m .52098 .25653 L .55462 .23492 L p .111 0 0 r
F P
0 g
s
.85574 .53196 m .82845 .4995 L .79166 .44828 L p 0 0 .51 r
F P
0 g
s
.79166 .44828 m .8183 .48204 L .85574 .53196 L p 0 0 .51 r
F P
0 g
s
.66751 .27463 m .64366 .25084 L .61012 .23645 L p .432 0 0 r
F P
0 g
s
.26089 .55782 m .23936 .57433 L .20466 .56868 L p .734 .77 .881 r
F P
0 g
s
.28287 .53578 m .26089 .55782 L .22583 .55659 L p .785 .751 .822 r
F P
0 g
s
.22583 .55659 m .24759 .53847 L .28287 .53578 L p .785 .751 .822 r
F P
0 g
s
.33647 .43948 m .31411 .46763 L .27793 .48312 L p .88 .93 .85 r
F P
0 g
s
.27793 .48312 m .30023 .45981 L .33647 .43948 L p .88 .93 .85 r
F P
0 g
s
.63322 .25221 m .61012 .23645 L .57679 .23738 L p .4 0 0 r
F P
0 g
s
.20466 .56868 m .22583 .55659 L .26089 .55782 L p .734 .77 .881 r
F P
0 g
s
.31411 .46763 m .2918 .49386 L .25575 .50437 L p .857 .893 .861 r
F P
0 g
s
.25575 .50437 m .27793 .48312 L .31411 .46763 L p .857 .893 .861 r
F P
0 g
s
.22583 .55659 m .20466 .56868 L .16964 .56386 L p .71 .761 .892 r
F P
0 g
s
.45534 .2926 m .43347 .31189 L .39745 .35046 L p 0 0 0 r
F P
0 g
s
.38944 .35795 m .35283 .39236 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.41151 .3339 m .40443 .34162 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.40443 .34162 m .38944 .35795 L p .39086 .35447 L 0 0 0 r
F P
0 g
s
.37517 .37089 m .41151 .3339 L p .37098 .37428 L 0 0 0 r
F P
0 g
s
.35283 .39236 m .37517 .37089 L p .37098 .37428 L 0 0 0 r
F P
0 g
s
.33045 .41426 m .35283 .39236 L .38944 .35795 L p .553 .862 .562 r
F P
0 g
s
.35283 .39236 m .33045 .41426 L .29284 .44168 L p 0 0 0 r
F P
0 g
s
.29284 .44168 m .31523 .42431 L .35283 .39236 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .35283 .39236 L .31523 .42431 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .33768 .40681 L p .3794 .36748 L 0 0 0 r
F P
0 g
s
.38944 .35795 m .36725 .38332 L .33045 .41426 L p .553 .862 .562 r
F P
0 g
s
.39745 .35046 m .37517 .37089 L p .3794 .36748 L 0 0 0 r
F P
0 g
s
.33768 .40681 m .37517 .37089 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.31523 .42431 m .32609 .41585 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.32609 .41585 m .33768 .40681 L p .3476 .39546 L 0 0 0 r
F P
0 g
s
.43347 .31189 m .41151 .3339 L .37517 .37089 L p 0 0 0 r
F P
0 g
s
.37517 .37089 m .39745 .35046 L .43347 .31189 L p 0 0 0 r
F P
0 g
s
.47716 .27663 m .45534 .2926 L .41968 .33162 L p 0 0 0 r
F P
0 g
s
.39745 .35046 m .41968 .33162 L .45534 .2926 L p 0 0 0 r
F P
0 g
s
.8385 .51713 m .86529 .5447 L .87469 .55725 L closepath p 0 .054 .591 r
F P
0 g
s
.2918 .49386 m .26961 .51748 L .23377 .52321 L p .827 .856 .868 r
F P
0 g
s
.23377 .52321 m .25575 .50437 L .2918 .49386 L p .827 .856 .868 r
F P
0 g
s
.49902 .26446 m .47716 .27663 L .44188 .31492 L p .088 0 0 r
F P
0 g
s
.41968 .33162 m .44188 .31492 L .47716 .27663 L p 0 0 0 r
F P
0 g
s
.24759 .53847 m .22583 .55659 L .19062 .55339 L p .758 .78 .872 r
F P
0 g
s
.16964 .56386 m .19062 .55339 L .22583 .55659 L p .71 .761 .892 r
F P
0 g
s
.26961 .51748 m .24759 .53847 L .21206 .53942 L p .793 .822 .875 r
F P
0 g
s
.21206 .53942 m .23377 .52321 L .26961 .51748 L p .793 .822 .875 r
F P
0 g
s
.19062 .55339 m .21206 .53942 L .24759 .53847 L p .758 .78 .872 r
F P
0 g
s
.57679 .23738 m .59943 .24542 L .63322 .25221 L p .4 0 0 r
F P
0 g
s
.59943 .24542 m .57679 .23738 L .54314 .25311 L p .341 0 0 r
F P
0 g
s
.52098 .25653 m .54314 .25311 L .57679 .23738 L p .235 0 0 r
F P
0 g
s
.19062 .55339 m .16964 .56386 L .13445 .5582 L p .682 .773 .92 r
F P
0 g
s
.36725 .38332 m .34495 .40924 L .30806 .43601 L p .681 .951 .692 r
F P
0 g
s
.30806 .43601 m .33045 .41426 L .36725 .38332 L p .681 .951 .692 r
F P
0 g
s
.52098 .25653 m .49902 .26446 L .46407 .30083 L p .17 0 0 r
F P
0 g
s
.44188 .31492 m .46407 .30083 L .49902 .26446 L p .088 0 0 r
F P
0 g
s
.34495 .40924 m .3226 .43497 L .28571 .45708 L p .771 .994 .794 r
F P
0 g
s
.28571 .45708 m .30806 .43601 L .34495 .40924 L p .771 .994 .794 r
F P
0 g
s
.21206 .53942 m .19062 .55339 L .1552 .5495 L p .716 .805 .92 r
F P
0 g
s
.13445 .5582 m .1552 .5495 L .19062 .55339 L p .682 .773 .92 r
F P
0 g
s
.82845 .4995 m .85574 .53196 L .86529 .5447 L closepath p 0 0 .5 r
F P
0 g
s
.1552 .5495 m .13445 .5582 L .09901 .55254 L p .655 .782 .942 r
F P
0 g
s
.3226 .43497 m .30023 .45981 L .26344 .47699 L p .815 .995 .86 r
F P
0 g
s
.26344 .47699 m .28571 .45708 L .3226 .43497 L p .815 .995 .86 r
F P
0 g
s
.23377 .52321 m .21206 .53942 L .17629 .53891 L p .75 .839 .919 r
F P
0 g
s
.1552 .5495 m .17629 .53891 L .21206 .53942 L p .716 .805 .92 r
F P
0 g
s
.54314 .25311 m .52098 .25653 L .48632 .28975 L p .242 0 .004 r
F P
0 g
s
.46407 .30083 m .48632 .28975 L .52098 .25653 L p .17 0 0 r
F P
0 g
s
.30023 .45981 m .27793 .48312 L .24131 .49533 L p .823 .967 .897 r
F P
0 g
s
.24131 .49533 m .26344 .47699 L .30023 .45981 L p .823 .967 .897 r
F P
0 g
s
.69236 .30453 m .66751 .27463 L .63322 .25221 L p .518 0 0 r
F P
0 g
s
.65712 .27391 m .63322 .25221 L .59943 .24542 L p .5 0 0 r
F P
0 g
s
.25575 .50437 m .23377 .52321 L .1977 .52636 L p .781 .881 .919 r
F P
0 g
s
.17629 .53891 m .1977 .52636 L .23377 .52321 L p .75 .839 .919 r
F P
0 g
s
.27793 .48312 m .25575 .50437 L .21938 .51184 L p .808 .925 .913 r
F P
0 g
s
.21938 .51184 m .24131 .49533 L .27793 .48312 L p .808 .925 .913 r
F P
0 g
s
.1977 .52636 m .21938 .51184 L .25575 .50437 L p .781 .881 .919 r
F P
0 g
s
.09901 .55254 m .11955 .54515 L .1552 .5495 L p .655 .782 .942 r
F P
0 g
s
.11955 .54515 m .09901 .55254 L .06332 .54689 L p .649 .769 .936 r
F P
0 g
s
.17629 .53891 m .1552 .5495 L .11955 .54515 L p .68 .8 .939 r
F P
0 g
s
.59943 .24542 m .62268 .25894 L .65712 .27391 L p .5 0 0 r
F P
0 g
s
.62268 .25894 m .59943 .24542 L .56562 .25433 L p .43 0 0 r
F P
0 g
s
.54314 .25311 m .56562 .25433 L .59943 .24542 L p .341 0 0 r
F P
0 g
s
.8183 .48204 m .84605 .51902 L .85574 .53196 L closepath p 0 0 .425 r
F P
0 g
s
.1977 .52636 m .17629 .53891 L .14038 .53649 L p .7 .834 .947 r
F P
0 g
s
.11955 .54515 m .14038 .53649 L .17629 .53891 L p .68 .8 .939 r
F P
0 g
s
.06332 .54689 m .08375 .53974 L .11955 .54515 L p .649 .769 .936 r
F P
0 g
s
.08375 .53974 m .06332 .54689 L .02741 .541 L p .643 .768 .939 r
F P
0 g
s
.56562 .25433 m .54314 .25311 L .50869 .28202 L p .306 0 .005 r
F P
0 g
s
.48632 .28975 m .50869 .28202 L .54314 .25311 L p .242 0 .004 r
F P
0 g
s
.14038 .53649 m .11955 .54515 L .08375 .53974 L p .655 .785 .943 r
F P
0 g
s
.21938 .51184 m .1977 .52636 L .16148 .52673 L p .719 .878 .955 r
F P
0 g
s
.14038 .53649 m .16148 .52673 L .1977 .52636 L p .7 .834 .947 r
F P
0 g
s
.02741 .541 m .04773 .53409 L .08375 .53974 L p .643 .768 .939 r
F P
0 g
s
.24131 .49533 m .21938 .51184 L .18284 .51575 L p .735 .925 .955 r
F P
0 g
s
.16148 .52673 m .18284 .51575 L .21938 .51184 L p .719 .878 .955 r
F P
0 g
s
.16148 .52673 m .14038 .53649 L .10438 .53224 L p .657 .815 .96 r
F P
0 g
s
.08375 .53974 m .10438 .53224 L .14038 .53649 L p .655 .785 .943 r
F P
0 g
s
.10438 .53224 m .08375 .53974 L .04773 .53409 L p .642 .778 .946 r
F P
0 g
s
.41968 .33162 m .39745 .35046 L .36016 .38959 L p .041 0 0 r
F P
0 g
s
.33768 .40681 m .36016 .38959 L .39745 .35046 L p 0 0 0 r
F P
0 g
s
.44188 .31492 m .41968 .33162 L .38265 .37307 L p .116 0 .005 r
F P
0 g
s
.36016 .38959 m .38265 .37307 L .41968 .33162 L p .041 0 0 r
F P
0 g
s
.26344 .47699 m .24131 .49533 L .20446 .50337 L p .733 .966 .936 r
F P
0 g
s
.18284 .51575 m .20446 .50337 L .24131 .49533 L p .735 .925 .955 r
F P
0 g
s
.33045 .41426 m .30806 .43601 L .27053 .45857 L p .472 .845 .611 r
F P
0 g
s
.27053 .45857 m .29284 .44168 L .33045 .41426 L p .472 .845 .611 r
F P
0 g
s
.30806 .43601 m .28571 .45708 L .24833 .47464 L p .607 .944 .769 r
F P
0 g
s
.24833 .47464 m .27053 .45857 L .30806 .43601 L p .607 .944 .769 r
F P
0 g
s
.28571 .45708 m .26344 .47699 L .2263 .48963 L p .695 .982 .88 r
F P
0 g
s
.20446 .50337 m .2263 .48963 L .26344 .47699 L p .733 .966 .936 r
F P
0 g
s
.2263 .48963 m .24833 .47464 L .28571 .45708 L p .695 .982 .88 r
F P
0 g
s
.81607 .47899 m .78746 .43266 L .74968 .37421 L p .622 .195 0 r
F P
0 g
s
.46407 .30083 m .44188 .31492 L .40516 .35763 L p .177 0 .052 r
F P
0 g
s
.38265 .37307 m .40516 .35763 L .44188 .31492 L p .116 0 .005 r
F P
0 g
s
.18284 .51575 m .16148 .52673 L .1252 .52445 L p .664 .851 .971 r
F P
0 g
s
.10438 .53224 m .1252 .52445 L .16148 .52673 L p .657 .815 .96 r
F P
0 g
s
.56562 .25433 m .58853 .26025 L .62268 .25894 L p .43 0 0 r
F P
0 g
s
.58853 .26025 m .56562 .25433 L .53125 .27784 L p .362 0 0 r
F P
0 g
s
.50869 .28202 m .53125 .27784 L .56562 .25433 L p .306 0 .005 r
F P
0 g
s
.04773 .53409 m .06821 .52713 L .10438 .53224 L p .642 .778 .946 r
F P
0 g
s
.1252 .52445 m .10438 .53224 L .06821 .52713 L p .64 .791 .954 r
F P
0 g
s
.48632 .28975 m .46407 .30083 L .4277 .34366 L p .226 0 .083 r
F P
0 g
s
.40516 .35763 m .4277 .34366 L .46407 .30083 L p .177 0 .052 r
F P
0 g
s
.71832 .33985 m .69236 .30453 L .65712 .27391 L p .554 .056 0 r
F P
0 g
s
.65712 .27391 m .68195 .3011 L .71832 .33985 L p .554 .056 0 r
F P
0 g
s
.68195 .3011 m .65712 .27391 L .62268 .25894 L p .549 0 0 r
F P
0 g
s
.62268 .25894 m .64665 .27764 L .68195 .3011 L p .549 0 0 r
F P
0 g
s
.64665 .27764 m .62268 .25894 L .58853 .26025 L p .497 0 0 r
F P
0 g
s
.20446 .50337 m .18284 .51575 L .14626 .516 L p .665 .893 .979 r
F P
0 g
s
.1252 .52445 m .14626 .516 L .18284 .51575 L p .664 .851 .971 r
F P
0 g
s
.50869 .28202 m .48632 .28975 L .4503 .3315 L p .267 0 .099 r
F P
0 g
s
.4277 .34366 m .4503 .3315 L .48632 .28975 L p .226 0 .083 r
F P
0 g
s
.06821 .52713 m .08886 .5201 L .1252 .52445 L p .64 .791 .954 r
F P
0 g
s
.7978 .44843 m .82622 .49254 L .83621 .50588 L closepath p .653 .207 0 r
F P
0 g
s
.14626 .516 m .1252 .52445 L .08886 .5201 L p .636 .814 .968 r
F P
0 g
s
.2263 .48963 m .20446 .50337 L .16754 .5068 L p .645 .932 .97 r
F P
0 g
s
.14626 .516 m .16754 .5068 L .20446 .50337 L p .665 .893 .979 r
F P
0 g
s
.75608 .39119 m .72879 .34895 L .69236 .30453 L p .57 .124 0 r
F P
0 g
s
.80576 .46523 m .77706 .41779 L .73923 .36043 L p .623 .195 0 r
F P
0 g
s
.24833 .47464 m .2263 .48963 L .18904 .49688 L p .584 .942 .913 r
F P
0 g
s
.16754 .5068 m .18904 .49688 L .2263 .48963 L p .645 .932 .97 r
F P
0 g
s
.53125 .27784 m .50869 .28202 L .47299 .32144 L p .302 0 .102 r
F P
0 g
s
.4503 .3315 m .47299 .32144 L .50869 .28202 L p .267 0 .099 r
F P
0 g
s
.16754 .5068 m .14626 .516 L .10968 .51302 L p .623 .846 .985 r
F P
0 g
s
.08886 .5201 m .10968 .51302 L .14626 .516 L p .636 .814 .968 r
F P
0 g
s
.58853 .26025 m .61196 .27076 L .64665 .27764 L p .497 0 0 r
F P
0 g
s
.61196 .27076 m .58853 .26025 L .5541 .27733 L p .411 0 0 r
F P
0 g
s
.53125 .27784 m .5541 .27733 L .58853 .26025 L p .362 0 0 r
F P
0 g
s
.27053 .45857 m .24833 .47464 L .21075 .48624 L p .463 .883 .779 r
F P
0 g
s
.18904 .49688 m .21075 .48624 L .24833 .47464 L p .584 .942 .913 r
F P
0 g
s
.29284 .44168 m .27053 .45857 L .23469 .47405 L p 0 0 0 r
F P
0 g
s
.23469 .47405 m .23407 .47432 L p .23551 .47352 L 0 0 0 r
F P
0 g
s
.23551 .47352 m .29284 .44168 L .23469 .47405 L 0 0 0 r
F
.23684 .47262 m .29284 .44168 L .23407 .47432 L F
.23407 .47432 m .23265 .47493 L p .23684 .47262 L F P
0 g
s
.23265 .47493 m .25472 .46305 L .29284 .44168 L p 0 0 0 r
F P
0 g
s
.31523 .42431 m .29284 .44168 L .25472 .46305 L p 0 0 0 r
F P
0 g
s
.25472 .46305 m .27694 .4507 L .31358 .42545 L p 0 0 0 r
F P
0 g
s
.31358 .42545 m .31523 .42431 L p .31038 .42741 L 0 0 0 r
F P
0 g
s
.25472 .46305 m .31358 .42545 L .31038 .42741 L 0 0 0 r
F
.33768 .40681 m .31523 .42431 L .27694 .4507 L p F P
0 g
s
.27694 .4507 m .2993 .43808 L .33525 .40879 L p 0 0 0 r
F P
0 g
s
.33525 .40879 m .33768 .40681 L p .33221 .41077 L 0 0 0 r
F P
0 g
s
.27694 .4507 m .33525 .40879 L .33221 .41077 L 0 0 0 r
F
.21075 .48624 m .23265 .47493 L .27053 .45857 L p .463 .883 .779 r
F P
0 g
s
.78746 .43266 m .81607 .47899 L .82622 .49254 L closepath p .675 .231 0 r
F P
0 g
s
.18904 .49688 m .16754 .5068 L .13068 .50588 L p .592 .881 .992 r
F P
0 g
s
.10968 .51302 m .13068 .50588 L .16754 .5068 L p .623 .846 .985 r
F P
0 g
s
.5541 .27733 m .53125 .27784 L .49582 .3137 L p .331 0 .091 r
F P
0 g
s
.47299 .32144 m .49582 .3137 L .53125 .27784 L p .302 0 .102 r
F P
0 g
s
.36016 .38959 m .33768 .40681 L .2993 .43808 L p .091 0 0 r
F P
0 g
s
.79529 .45125 m .7666 .40394 L .72879 .34895 L p .611 .181 0 r
F P
0 g
s
.38265 .37307 m .36016 .38959 L .32178 .42534 L p .161 0 .005 r
F P
0 g
s
.2993 .43808 m .32178 .42534 L .36016 .38959 L p .091 0 0 r
F P
0 g
s
.21075 .48624 m .18904 .49688 L .15185 .49868 L p .521 .897 .962 r
F P
0 g
s
.13068 .50588 m .15185 .49868 L .18904 .49688 L p .592 .881 .992 r
F P
0 g
s
.7078 .33315 m .68195 .3011 L .64665 .27764 L p .552 .018 0 r
F P
0 g
s
.64665 .27764 m .67146 .30111 L .7078 .33315 L p .552 .018 0 r
F P
0 g
s
.67146 .30111 m .64665 .27764 L .61196 .27076 L p .53 0 0 r
F P
0 g
s
.40516 .35763 m .38265 .37307 L .34437 .41272 L p .213 0 .067 r
F P
0 g
s
.32178 .42534 m .34437 .41272 L .38265 .37307 L p .161 0 .005 r
F P
0 g
s
.75608 .39119 m .71832 .33985 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.78465 .43704 m .75964 .39691 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.75964 .39691 m .75608 .39119 L p .74484 .37871 L 0 0 .402 r
F P
0 g
s
.68195 .3011 m .7078 .33315 L .71364 .34035 L p .557 .09 0 r
F P
0 g
s
.71832 .33985 m .74547 .37958 L .78465 .43704 L p 0 0 .402 r
F P
0 g
s
.71364 .34035 m .74547 .37958 L p .72791 .35789 L .557 .09 0 r
F P
0 g
s
.68195 .3011 m .71364 .34035 L .72791 .35789 L .557 .09 0 r
F
.74547 .37958 m .71832 .33985 L .68195 .3011 L p F P
0 g
s
.4277 .34366 m .40516 .35763 L .36707 .40041 L p .251 0 .11 r
F P
0 g
s
.34437 .41272 m .36707 .40041 L .40516 .35763 L p .213 0 .067 r
F P
0 g
s
.23265 .47493 m .21075 .48624 L .1732 .49142 L p .386 .848 .847 r
F P
0 g
s
.15185 .49868 m .1732 .49142 L .21075 .48624 L p .521 .897 .962 r
F P
0 g
s
.77706 .41779 m .80576 .46523 L .81607 .47899 L closepath p .684 .241 0 r
F P
0 g
s
.61196 .27076 m .63604 .28558 L .67146 .30111 L p .53 0 0 r
F P
0 g
s
.63604 .28558 m .61196 .27076 L .57731 .2805 L p .451 0 0 r
F P
0 g
s
.5541 .27733 m .57731 .2805 L .61196 .27076 L p .411 0 0 r
F P
0 g
s
.57731 .2805 m .5541 .27733 L .51884 .30845 L p .355 0 .06 r
F P
0 g
s
.49582 .3137 m .51884 .30845 L .5541 .27733 L p .331 0 .091 r
F P
0 g
s
.4503 .3315 m .4277 .34366 L .38986 .38863 L p .28 0 .138 r
F P
0 g
s
.36707 .40041 m .38986 .38863 L .4277 .34366 L p .251 0 .11 r
F P
0 g
s
.25472 .46305 m .23265 .47493 L .19473 .4841 L p 0 0 0 r
F P
0 g
s
.1732 .49142 m .19473 .4841 L .23265 .47493 L p .386 .848 .847 r
F P
0 g
s
.47299 .32144 m .4503 .3315 L .41276 .37758 L p .302 0 .154 r
F P
0 g
s
.38986 .38863 m .41276 .37758 L .4503 .3315 L p .28 0 .138 r
F P
0 g
s
.19473 .4841 m .21644 .47671 L .25472 .46305 L p 0 0 0 r
F P
0 g
s
.27694 .4507 m .25472 .46305 L .21644 .47671 L p 0 0 0 r
F P
0 g
s
.21644 .47671 m .23834 .46926 L .27694 .4507 L p 0 0 0 r
F P
0 g
s
.2993 .43808 m .27694 .4507 L .23834 .46926 L p .11 0 0 r
F P
0 g
s
.7666 .40394 m .79529 .45125 L .80576 .46523 L closepath p .682 .239 0 r
F P
0 g
s
.49582 .3137 m .47299 .32144 L .43579 .36745 L p .318 0 .159 r
F P
0 g
s
.41276 .37758 m .43579 .36745 L .47299 .32144 L p .302 0 .154 r
F P
0 g
s
.57731 .2805 m .60099 .28725 L .63604 .28558 L p .451 0 0 r
F P
0 g
s
.60099 .28725 m .57731 .2805 L .54211 .30573 L p .373 0 .002 r
F P
0 g
s
.51884 .30845 m .54211 .30573 L .57731 .2805 L p .355 0 .06 r
F P
0 g
s
.32178 .42534 m .2993 .43808 L .26043 .46175 L p .198 0 0 r
F P
0 g
s
.23834 .46926 m .26043 .46175 L .2993 .43808 L p .11 0 0 r
F P
0 g
s
.63604 .28558 m .66085 .30433 L .66314 .30587 L p .513 0 0 r
F P
0 g
s
.74547 .37958 m .7078 .33315 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.77384 .42261 m .74783 .38317 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.74783 .38317 m .74547 .37958 L p .7328 .36701 L 0 0 .457 r
F P
0 g
s
.7078 .33315 m .73476 .3691 L .77384 .42261 L p 0 0 .457 r
F P
0 g
s
.73476 .3691 m .70888 .33458 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.7078 .33315 m .67146 .30111 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.70888 .33458 m .7078 .33315 L p .69381 .32512 L 0 0 .483 r
F P
0 g
s
.67146 .30111 m .69384 .32514 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.69384 .32514 m .6972 .32874 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.6972 .32874 m .70201 .33391 L p .69384 .32514 L 0 0 .483 r
F P
0 g
s
.70201 .33391 m .73476 .3691 L p .71635 .34933 L 0 0 .483 r
F P
0 g
s
.67146 .30111 m .70201 .33391 L .71635 .34933 L 0 0 .483 r
F
.66314 .30587 m .6972 .32874 L p .67802 .31521 L .513 0 0 r
F P
0 g
s
.63604 .28558 m .66314 .30587 L .67802 .31521 L .513 0 0 r
F
.6972 .32874 m .67146 .30111 L .63604 .28558 L p F P
0 g
s
.66085 .30433 m .63604 .28558 L .60099 .28725 L p .465 0 0 r
F P
0 g
s
.51884 .30845 m .49582 .3137 L .45895 .35837 L p .33 0 .153 r
F P
0 g
s
.43579 .36745 m .45895 .35837 L .49582 .3137 L p .318 0 .159 r
F P
0 g
s
.34437 .41272 m .32178 .42534 L .2827 .45418 L p .256 0 .03 r
F P
0 g
s
.26043 .46175 m .2827 .45418 L .32178 .42534 L p .198 0 0 r
F P
0 g
s
.36707 .40041 m .34437 .41272 L .30517 .44654 L p .294 0 .095 r
F P
0 g
s
.2827 .45418 m .30517 .44654 L .34437 .41272 L p .256 0 .03 r
F P
0 g
s
.75608 .39119 m .78465 .43704 L .79529 .45125 L closepath p .668 .223 0 r
F P
0 g
s
.54211 .30573 m .51884 .30845 L .48229 .35049 L p .336 0 .135 r
F P
0 g
s
.45895 .35837 m .48229 .35049 L .51884 .30845 L p .33 0 .153 r
F P
0 g
s
.60099 .28725 m .62521 .29734 L .66085 .30433 L p .465 0 0 r
F P
0 g
s
.62521 .29734 m .60099 .28725 L .56571 .30556 L p .379 0 0 r
F P
0 g
s
.54211 .30573 m .56571 .30556 L .60099 .28725 L p .373 0 .002 r
F P
0 g
s
.38986 .38863 m .36707 .40041 L .32783 .43883 L p .319 0 .139 r
F P
0 g
s
.30517 .44654 m .32783 .43883 L .36707 .40041 L p .294 0 .095 r
F P
0 g
s
.41276 .37758 m .38986 .38863 L .35069 .43105 L p .335 0 .168 r
F P
0 g
s
.32783 .43883 m .35069 .43105 L .38986 .38863 L p .319 0 .139 r
F P
0 g
s
.56571 .30556 m .54211 .30573 L .50582 .34387 L p .334 0 .098 r
F P
0 g
s
.48229 .35049 m .50582 .34387 L .54211 .30573 L p .336 0 .135 r
F P
0 g
s
.43579 .36745 m .41276 .37758 L .37375 .42321 L p .345 0 .185 r
F P
0 g
s
.35069 .43105 m .37375 .42321 L .41276 .37758 L p .335 0 .168 r
F P
0 g
s
.74547 .37958 m .77384 .42261 L .78465 .43704 L closepath p .638 .191 0 r
F P
0 g
s
.73476 .3691 m .6972 .32874 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.76285 .40794 m .7363 .37123 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.7363 .37123 m .73476 .3691 L p .72105 .35752 L 0 0 .538 r
F P
0 g
s
.6972 .32874 m .72393 .35969 L .76285 .40794 L p 0 0 .538 r
F P
0 g
s
.6972 .32874 m .66085 .30433 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.72393 .35969 m .69768 .3293 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.69768 .3293 m .6972 .32874 L p .68245 .32329 L 0 .074 .562 r
F P
0 g
s
.62521 .29734 m .65005 .31042 L .6518 .31119 L p .422 0 0 r
F P
0 g
s
.66085 .30433 m .68647 .32646 L .69025 .32981 L p 0 .074 .562 r
F P
0 g
s
.66085 .30433 m .69025 .32981 L .70485 .34294 L 0 .074 .562 r
F
.6518 .31119 m .68647 .32646 L p .66681 .31712 L .422 0 0 r
F P
0 g
s
.62521 .29734 m .6518 .31119 L .66681 .31712 L .422 0 0 r
F
.69025 .32981 m .72393 .35969 L p .70485 .34294 L 0 .074 .562 r
F P
0 g
s
.68647 .32646 m .66085 .30433 L .62521 .29734 L p .422 0 0 r
F P
0 g
s
.45895 .35837 m .43579 .36745 L .39701 .4153 L p .349 0 .193 r
F P
0 g
s
.37375 .42321 m .39701 .4153 L .43579 .36745 L p .345 0 .185 r
F P
0 g
s
.65005 .31042 m .62521 .29734 L .58968 .30785 L p .357 0 0 r
F P
0 g
s
.56571 .30556 m .58968 .30785 L .62521 .29734 L p .379 0 0 r
F P
0 g
s
.58968 .30785 m .56571 .30556 L .52959 .33854 L p .323 0 .034 r
F P
0 g
s
.50582 .34387 m .52959 .33854 L .56571 .30556 L p .334 0 .098 r
F P
0 g
s
.48229 .35049 m .45895 .35837 L .42048 .40732 L p .349 0 .191 r
F P
0 g
s
.39701 .4153 m .42048 .40732 L .45895 .35837 L p .349 0 .193 r
F P
0 g
s
.73476 .3691 m .76285 .40794 L .77384 .42261 L closepath p .586 .137 0 r
F P
0 g
s
.50582 .34387 m .48229 .35049 L .44415 .39927 L p .342 0 .18 r
F P
0 g
s
.42048 .40732 m .44415 .39927 L .48229 .35049 L p .349 0 .191 r
F P
0 g
s
.58968 .30785 m .61409 .31239 L .65005 .31042 L p .357 0 0 r
F P
0 g
s
.61409 .31239 m .58968 .30785 L .55362 .33451 L p .29 0 0 r
F P
0 g
s
.52959 .33854 m .55362 .33451 L .58968 .30785 L p .323 0 .034 r
F P
0 g
s
.72393 .35969 m .68647 .32646 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.72393 .35969 m .75168 .39302 L .76285 .40794 L closepath p 0 0 .489 r
F P
0 g
s
.75168 .39302 m .72483 .36078 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.72483 .36078 m .72393 .35969 L p .70939 .34986 L 0 .112 .649 r
F P
0 g
s
.68647 .32646 m .71295 .35124 L .75168 .39302 L p 0 .112 .649 r
F P
0 g
s
.68647 .32646 m .65005 .31042 L p .67101 .32402 L 0 .234 .681 r
F P
0 g
s
.71295 .35124 m .68647 .32646 L p .67101 .32402 L 0 .234 .681 r
F P
0 g
s
.61409 .31239 m .639 .31894 L .64003 .31914 L p .262 0 0 r
F P
0 g
s
.65005 .31042 m .67557 .32604 L .67844 .32798 L p 0 .234 .681 r
F P
0 g
s
.65005 .31042 m .67844 .32798 L .69334 .33851 L 0 .234 .681 r
F
.64003 .31914 m .67557 .32604 L p .65539 .32156 L .262 0 0 r
F P
0 g
s
.61409 .31239 m .64003 .31914 L .65539 .32156 L .262 0 0 r
F
.67844 .32798 m .71295 .35124 L p .69334 .33851 L 0 .234 .681 r
F P
0 g
s
.67557 .32604 m .65005 .31042 L .61409 .31239 L p .262 0 0 r
F P
0 g
s
.52959 .33854 m .50582 .34387 L .46804 .39114 L p .329 0 .155 r
F P
0 g
s
.44415 .39927 m .46804 .39114 L .50582 .34387 L p .342 0 .18 r
F P
0 g
s
.639 .31894 m .61409 .31239 L .57795 .3317 L p .21 0 0 r
F P
0 g
s
.55362 .33451 m .57795 .3317 L .61409 .31239 L p .29 0 0 r
F P
0 g
s
.55362 .33451 m .52959 .33854 L .49214 .38295 L p .304 0 .113 r
F P
0 g
s
.46804 .39114 m .49214 .38295 L .52959 .33854 L p .329 0 .155 r
F P
0 g
s
.71295 .35124 m .74032 .37787 L .75168 .39302 L closepath p 0 .075 .609 r
F P
0 g
s
.71295 .35124 m .67557 .32604 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.74032 .37787 m .71336 .35163 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.71336 .35163 m .71295 .35124 L p .69771 .34376 L 0 .281 .779 r
F P
0 g
s
.67557 .32604 m .7018 .3436 L .74032 .37787 L p 0 .281 .779 r
F P
0 g
s
.7018 .3436 m .67557 .32604 L .639 .31894 L p 0 .46 .832 r
F P
0 g
s
.639 .31894 m .66445 .32715 L .66641 .32802 L p 0 .46 .832 r
F P
0 g
s
.66641 .32802 m .7018 .3436 L p .68169 .3357 L 0 .46 .832 r
F P
0 g
s
.639 .31894 m .66641 .32802 L .68169 .3357 L 0 .46 .832 r
F
.57795 .3317 m .55362 .33451 L .51645 .37468 L p .262 0 .041 r
F P
0 g
s
.49214 .38295 m .51645 .37468 L .55362 .33451 L p .304 0 .113 r
F P
0 g
s
.66445 .32715 m .639 .31894 L .60262 .33001 L p .02 0 0 r
F P
0 g
s
.57795 .3317 m .60262 .33001 L .639 .31894 L p .21 0 0 r
F P
0 g
s
.60262 .33001 m .57795 .3317 L .54098 .36633 L p .184 0 0 r
F P
0 g
s
.51645 .37468 m .54098 .36633 L .57795 .3317 L p .262 0 .041 r
F P
0 g
s
.7018 .3436 m .72878 .36246 L .74032 .37787 L closepath p 0 .253 .755 r
F P
0 g
s
.7018 .3436 m .66445 .32715 L p .68589 .33892 L .156 .477 .897 r
F P
0 g
s
.72878 .36246 m .7018 .3436 L p .68589 .33892 L .156 .477 .897 r
F P
0 g
s
.66445 .32715 m .69046 .33659 L .72878 .36246 L p .156 .477 .897 r
F P
0 g
s
.69046 .33659 m .66445 .32715 L .62765 .32929 L p .264 .712 .959 r
F P
0 g
s
.62765 .32929 m .65306 .32935 L .65399 .32953 L p .264 .712 .959 r
F P
0 g
s
.65399 .32953 m .69046 .33659 L p .66982 .33419 L .264 .712 .959 r
F P
0 g
s
.62765 .32929 m .65399 .32953 L .66982 .33419 L .264 .712 .959 r
F
.60262 .33001 m .62765 .32929 L .66445 .32715 L p .02 0 0 r
F P
0 g
s
.62765 .32929 m .60262 .33001 L .56574 .35791 L p .028 0 0 r
F P
0 g
s
.54098 .36633 m .56574 .35791 L .60262 .33001 L p .184 0 0 r
F P
0 g
s
.65306 .32935 m .62765 .32929 L .59072 .34942 L p .273 .77 .724 r
F P
0 g
s
.56574 .35791 m .59072 .34942 L .62765 .32929 L p .028 0 0 r
F P
0 g
s
.69046 .33659 m .71704 .34679 L .72878 .36246 L closepath p .123 .464 .89 r
F P
0 g
s
.71704 .34679 m .69046 .33659 L .65306 .32935 L p .428 .653 .953 r
F P
0 g
s
.65306 .32935 m .67888 .32995 L .71704 .34679 L p .428 .653 .953 r
F P
0 g
s
.59072 .34942 m .61593 .34084 L .65306 .32935 L p .273 .77 .724 r
F P
0 g
s
.67888 .32995 m .65306 .32935 L .61593 .34084 L p .57 .892 .987 r
F P
0 g
s
.67888 .32995 m .70511 .33085 L .71704 .34679 L closepath p .416 .651 .955 r
F P
0 g
s
.61593 .34084 m .64138 .33219 L .67888 .32995 L p .57 .892 .987 r
F P
0 g
s
.70511 .33085 m .67888 .32995 L .64138 .33219 L p .643 .765 .937 r
F P
0 g
s
.64138 .33219 m .66705 .32346 L .70511 .33085 L p .643 .765 .937 r
F P
0 g
s
.66705 .32346 m .69297 .31464 L .70511 .33085 L closepath p .643 .765 .937 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oooooooooo06kooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003eoooo
o`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`00
0?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003cooooo`03oeEEEOmVIVKo
000007;ooooo003oooooo`Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Looooo`00ooooool8oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0G?ooool00?oooooo0_l00006ooooo`05oa0@4?oooooooooo
ooooool@4100G?ooool00?cooooo0ol000000ooooooo0000ooooo`05ooooo`05o`000?oooooooooo
ooooool00000G?ooool00?[ooooo0_l00004ooooo`;o00001Oooool01Ol0003ooooooooooooooooo
000005cooooo003gooooo`Co00001Oooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooo
ooooool@4100G?ooool00?Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0G?ooool00?;ooooo0ol0000;ooooo`04o`000?oooooooooo
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Looooo`00l?ooool2o`0000kooooo00Go0000
ooooooooooooooooo`00001Sooooo`00kOooool3o`00013ooooo00Go0000ooooooooooooooooo`00
001Sooooo`00joooool2o`0000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo063ooooo003Xooooo`?o00005Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo063ooooo003Vooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05oooooo002Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0G_ooool00:Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
01_ooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Nooooo`00Yoooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEE
EOooool02?ooool00ol0003oooooooooo`0Gooooo`?o00008?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000005oooooo001jooooo`;o00000_ooool2o`0002Oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool05_ooool2o`00
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Looooo`00N_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMgBOooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<
c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`?o00009Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo05cooooo001kooooo`04omgMgOl0003o410@olc<c2Sooooo
00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000oooooooo
ool05?ooool2o`0000;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo05_ooooo001kooooo`04onk^k_lQ8B7o410@onk^kRSooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`0A
ooooo`?o0000:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05[ooooo001koooo
o`04ob4Q8OmgMgOoMgMgoc8b<RSooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000kooooo0_l0000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_oo
ool007[ooooo0_l00002ooooo`;o0000Coooool3o`0002oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Iooooo`00c?ooool3o`000003ooooool0003ooooo02oooooo00?o0000oooo
ooooool01oooool3o`0005[ooooo003:ooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Sooooo0037ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Oooooo0035ooooo`;o0000>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Oooooo0032ooooo`Co0000>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05Kooooo0030ooooo`;o00001?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0EOooool00;gooooo0ol00011ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0EOooool00;_ooooo0_l00014ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0E?ooool00;Sooooo1?l00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooool00000EOooool00;Kooooo0_l00004ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Cooooo`00/oooool3o`0004cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Booooo`00Noooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`0004oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Aooooo`00Noooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo1?l0001@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0DOooool007_ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo01Wooooo0_l00003ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1@ooooo`00Noooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0005Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1?ooooo`00Noooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000FOooool00ol0003oooooooooo`0@ooooo`;o0000DOoo
ool007_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Gooooo1?l0
001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM02[o
oooo001kooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`;o
00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`0Yooooo`00Noooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000?ooooo`?o0000H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Gooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool0:?ooool009gooooo0_l0001Sooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`0Yooooo`00V_ooool4o`0006Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0:_ooool009Sooooo0_l00003ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo
002Eooooo`?o0000J_ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo02co
oooo002Cooooo`;o0000KOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
02_ooooo002@ooooo`Co0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo002>ooooo`;o00001?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0B?ooool008_ooooo0ol0001dooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0B?ooool008Wooooo0_l0001gooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Aoooool008Kooooo0ol000000ooooooo0000ooooo`1fooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0A_ooool008Cooooo0_l0001looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0A_ooool004;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Qooooo`?o0000Ooooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooo000004Oooooo0012ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo01kooooo0_l00022ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool0
04;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool06_ooool3o`000003ooooool0003ooooo087ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`14ooooo`00@_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`0Iooooo`;o0000Qoooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo04?ooooo0012ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05oooool3o`0008Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`13ooooo`00@_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`;o0000S?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo0012ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
5?ooool3o`0000;ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo047ooooo0012ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo1?l0000Aooooo`;o0000TOooool00ol0003oooooooooo`0Mooooo`;o
0000@oooool006gooooo0ol0002Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
@?ooool006_ooooo1?l0002Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08_oo
ool3o`000003oa0@4?oooooooooo01Oooooo001Xooooo`?o0000V?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Cooooo00?o410@okZj^_ooool06?ooool006Gooooo0ol0002Koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool08oooool00onHV9So<S8booooo`0Hoooo
o`00Hoooool2o`0009kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03
omgMgOl0003o^[Zj01Sooooo001Pooooo`?o000000?oooooo`000?ooool0WOooool00ol0003ooooo
ooooo`0Qooooo`;o00009?ooool00omEEEGoMgMgodA4A00Hooooo`00G_ooool2o`0000Gooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00Go
gMgMoa0@4?oooooo8B4QomgMg@0Gooooo`00Foooool3o`000:Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Pooooo`05ofIVI_n7QhOooooooiRHV?mEEED05oooool005Wooooo0_l0
002Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07_ooool00oo^k^ko0000onk^
kP02ooooo`03o`000?oMgMgooooo01Gooooo001Fooooo`?o00000_ooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo01Cooooo000]ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_oo
ool2o`000:gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0jooooo`00;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0002_ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0>Oooool002gooooo00Go410@oooooooooooooooooa0@400Mooooo`;o000000?o
ooooo`000?ooool0/?ooool00ol0003oooooooooo`0Tooooo`?o00002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool002gooooo
00Go0000ooooooooooooooooo`00000Jooooo`?o0000R_ooool9o`0002;ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool06oooool002gooooo00Go0000ooooooooooooooooo`00000Hoooo
o`;o0000R?oooolBo`0001kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Jooooo`00;Oooool01Ol@
413ooooooooooooooooo410@01Gooooo0ol00027ooooo`Oo00001_l=0006o`0000;o08c=0ol0000K
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool06oooool002gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Cooooo`;o00000_ooool00ol0003oooooooooo`22ooooo`So00001Ol=0003o`0000Co?`002_l0
000Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`00;Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^013ooooo0ol00027ooooo`So00001?l=0003o`0000[o?`000_l00002o`1?Z0Go
00005_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo01kooooo0010ooooo`;o0000R?ooool8o`000003
o`d00?l0003o000001Co00001?l0CjP3o`0001Cooooo00?o0000ooooooooool0:Oooool2o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01kooooo000mooooo`Co
0000R?ooool:o`000003oa`00?l0003o?00000Co?0000_l00003oeL000?o00001omV0002o`0000?o
04nX0ol0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000Mooooo`00>oooool2o`0008_ooooo1_l00004oa`000;o
00000oll0003o`0000SoE`000_l00006ofH000Co000000Co04nXo`000?l0003o00004_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000hooooo`?o0000S?ooool6o`0000?o
70000_l00003oc`000;o00002omG0006o`0000CoIP002?l0000@ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<oooool003Kooooo0_l0002=ooooo`Oo00000olL00001?l0003o?000
oc`00?ll0002o`0000WoE`001?l00004ofh000Oo000000?oIP00o`000?m^00001Ol0000?ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0<_ooool003?ooooo0ol00002ooooo`03o`00
0?oooooooooo08Wooooo1_l00003oa`000;o000000?o?000o`000?l000001Ol00004oeL000?o0000
2_m^00000ol0003oO`00ogl00002ogl000Co000000?oKP00o`000?l000000_l0000>ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0<Oooool003;ooooo0_l0002?ooooo`Ko00000olL
0005o`0000KoCP011Ol0000=ofh000;o00001Omo0002o`0000;oKP000ol0000=ooooo`03o`000?oo
oooooooo02gooooo0_l0000booooo`00<_ooool00ol0003oooooo`00002=ooooo`Go00000_lL0004
o`0000;o?@0100?o0000odh00Om>00401Om>00400ol0003oG000oe`00002oe`000?o00001om^0007
o`0000CoO`000ol000001?m^003o0000o`000?l0000<ooooo`03o`000?oooooooooo02gooooo0_l0
000booooo`00<_ooool01?l0003oooooooooool0002:ooooo`[o00001?lm00400ol0003oCP01odh0
0@04odh00@;o00002?mL0007o`0000OoO`000_l00003ogl00003o`000?n4003o000000Co00002ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo000booooo`?o000000?ooooo
o`000?ooool0Q_ooool8o`0000;o:`0000?o0000ocd00Olm00400_lm00400ol0003oCP01odh00@03
odh00@;o00002?mL0002o`0000?oJ@000ol00009ogl000Co000000CoO`00o`000?n4003oQ0001?l0
000:ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool0037ooooo0_l00004
ooooo`03o`000?oooooooooo08?ooooo1_l000001OlF003o0000ob/00?l[003o000000Co?@0100?o
0000odh00Om>00400om>00400ol0003oG000oe`00005oe`000?o00002?mY0003o`0000OoO`000_l0
00001?n<003o0000o`000?l00002oh@000Co00002Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02kooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo087ooooo1Ol00002oaH00004o`000?l[003o:`00o`00
00Co?@0100?o0000odh00Om>00400_m>0042o`0000KoG0000_l0000<ofT000Ko00001Omo00000ol0
003oS000oh`00002o`0000?oQ0000ol00008ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0;Oooool000oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1oooooo`Go00000_lF00001?l0003o:`00ob/00?l00004ocd00@03o`000?m>007o
CP0100;oCP0100?o0000oe`00?mL00001?mL0002o`0000[oJ@001?l00004og<00003o`000?n7003o
000000Co000000?oO`00o`000?n<00000_n<0002o`0000;oQ0000ol00007ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0;Oooool000Oooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1mooooo`Co00000olF00001?l0003o:`00ob/00?l0
0004ocd00@03o`000?m>007oCP0100ko00001OmY0003o`0000WoL`000_l00004ohL000Co000000Oo
S000o`000?n=3P3o0000oh@00?l0003o00R=00;o00001oooool00ol0003oooooooooo`0`ooooo`;o
0000;_ooool000oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07_o
oooo1?l00003oaH00004o`000?l[003o:`00o`0000Co?@011?l00002odd06P03o`000?mD01OoE00G
00;oE00G00?o0000oeX03omJ00l01?mJ00l6o`0000goL`000_l00005ohL000;o000000OoS000o`00
0?n=3P3o0000oh@00?l0003o00R=00;o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo000?ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0000Wooooo00?o0000ooooooooool0
NOooool4o`0000?o5P0000Co0000ob/00?l[003o00000_lm0044o`0000CoC@0J00?o0000oe@05omD
01L00_mD01L00ol0003oFP0?oeX03`06oeX03`03o`000?mO003oG`0000;oG`000ol0000<og<00003
o`000?n7003oQ`0000?oQ`000_l000001On<003o0000ohd>0?l0003oQ00000Co00001Oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo000?ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1gooooo`Co00000olF00000ol0003o:`00ob/00004o`00
0003od@06Ol0003oC@0J00CoC@0J00?o0000oe@05omD01L00_mD01L00ol0003oFP0?oeX03`06oeX0
3`03o`000?mO003oG`0000KoG`003ol00004ohL000Co000000?oS@h0o`000?n400001?l00004oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo1?l00003oaH00003o`000?l[003o0000
00;o00000om401T00ol0003oC@0Jodd06P03odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX0
3omJ00l01OmJ00l2o`0000OoG`000_l00003of4000;o00002_mg0002o`0000?oQ`0000Go0000ohd4
0?l0003o0000ohd>0005o`0000Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Z
ooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`Co00000olF0003
o`000003ocT05Ol0003oA00I00;oA00I00?o0000odd06_m=01X00om=01X00ol0003oE00Goe@05`02
oe@05`03o`000?mJ00ooFP0?00GoFP0?00?o0000oel00?mO00001OmO0002o`0000OoH@000_l00009
ogL000Co000000?oQ`00o`000?n=10000_l00002ohd>00?o00001?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Wooooo000`ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0LOooool4o`0000?o5P000_l00002ocT05@05o`000?m401WoA00Iod@06Ol000001Om=01X0
0ol0003oE00Goe@05`02oe@05`03o`000?mJ00ooFP0?00CoFP0?0_l00007oel00003o`000?mQ003o
H@0000WoH@000_l00008ogL000;o000000CoP`00o`000?l0003o00000_n=10000ol0003oS@h0ohd>
0003o`0000?ooooo00?o0000ooooooooool0=?ooool2o`0002[ooooo000`ooooo`;o00003oooool0
0ol0003oooooooooo`1_ooooo`Co00000olF0002o`0000;o>@0E00Go0000od@06Om401WoA00Io`00
0005odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX03omJ00l01?mJ00l00ol0003oG`00oel0
0005oel000;o00003?mQ0006o`0000KoM`0000?o0000oh<00?n300000_l00002ohd40003o`000?n=
3P3oS@h000?o00000_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo000`
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0KOooool4o`0000;o5P000_l00003
ocT05@05o`000?m401WoA00Iod@06Ol000001Om=01X00ol0003oE00Goe@05`02oe@05`03o`000?mJ
00ooFP0?00CoFP0?00?o0000oel00?mO00001?mO0002o`0000[oH@001?l00004oe/000So000000?o
M`00o`000?n300000_n30002o`000004ohd40?l0003oS@h0ohd>00?o000000?oooooo`000?ooool0
=oooool00ol0003oooooooooo`0Wooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo06_ooooo1?l000001OlF003o0000o`000?l]00go000000;o>@0E00Go0000od@06Om401Wo
A00Io`000005odd06P03o`000?mD01OoE00G00;oE00G00?o0000oeX03omJ00l04?l00005of4000?o
00002_mK0002o`0000CoK0001?l000001_n3003o0000o`00Nol0003oSQL0o`0000;oS@h01?l0000i
ooooo`03o`000?oooooooooo02Kooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0JOooool6o`0000;o;@0=00Co0000ocT05Oli01Go00000om401T00ol0003oC@0Jodd06P03
odd06P03o`000?mD01OoE00G00Ko00001?mF02800ol0003oE@0IoeD06@03oeD06@03o`000?mB00So
DP0800?oDP082?l0000<oe/000;o00001_m/00001_l0003oP`00o`000?l007_o0000ohhG00Ko0000
>Oooool00ol0003oooooooooo`0Vooooo`00;oooool00ol0003oooooooooo`0Cooooo`;o0000J?oo
ool5o`0000?o;@0=00Co0000ocT05Oli01Go00000om401T00ol0003oC@0Jodd06P03odd06PCo0000
0_mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?oE@0I00?o0000oe802?mB00P0
1OmB00P00ol0003oBP00odX00004odX0013o00001Om/00000ol0003oP`00o`000004o`000003ohd>
0?l0003o001g00;o0000>Oooool00ol0003oooooooooo`0Uooooo`00;oooool2o`0001Kooooo00?o
0000ooooooooool0I?ooool4o`0000Co;@0=00Go0000ocT05Oli01Go>@0Eo`000002od@06@04o`00
0?m=01[oC@0Jodd06PCo00001?mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?o
E@0I00?o0000oe802?mB00P01OmB00P00ol0003oBP00odX00005odX000;o00000ole0003o`0000So
@`000ol00002of`000Co000000Oo001ko`000?l0003o0000ohd>0?l0003o001g00;o0000=oooool3
o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^oooo
o`04ooooo`04odA4A?l0003o0000oc8b<P7ogMgM000_ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0H_ooool3o`000003oad00Ol0003o;@0=00;o;@0=00Go0000ocT05Oli01Go>@0E
o`000002od@06@Go00000_mA02P00ol0003oE00Woe@09`02oe@09`03o`000?mF02;oEP0R00CoEP0R
00?o0000oeD06OmE01T00omE01T00ol0003oDP08oe802004oe8020;o00001om:00000ol0003o=@00
ocD00006ocD000?o00001_m30004o`0000;oK0001?l000001?nT`noo0000o`000?n=3P04o`0003So
oooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo0OmgMgL1oc8b<P00;oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo063ooooo0ol000000olM007o0000obd03@02obd03@06o`000?li01Go>@0EocT0
5Ol0003oA00I0ol00005oe40:003o`000?mD02OoE00W00;oE00W00?o0000oeH08_mF02801?mF0280
0ol0003oE@0IoeD06@03oeD06@03o`000?mB00SoDP0800CoDP0800?o0000odX00?m:00001Om:0002
o`0000[o=@002Ol000000om3003o0000o`000003o`0000GoY<?_0_l000001?nA7`3o0000o`000?l0
000iooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo0Ol0000002oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1Nooooo`?o000000?o7@01o`000?l]00d00_l]00d01?l0003o>@0EocT05Oli01D3o`000003odd0
9ol0003oD@0X00CoD@0X00?o0000oe@09omD02L00_mD02L00ol0003oEP0RoeH08P04oeH08P03o`00
0?mE01WoE@0I00?oE@0I00?o0000oe802?mB00P01?mB00P00ol0003oBP00odX00004odX000;o0000
2?le0004o`0000?o1@003?l00006ojC3k`?o000000?o001go`000?l00000>?ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`7o
MgMg0Olb<S8002oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000
00?o7@01o`000?l]00d00_l]00d01?l0003o>@0EocT05Oli01D2o`0000;oC@0W00?o0000oe40:?mA
02P00omA02P00ol0003oE00Woe@09`02oe@09`03o`000?mF02;oEP0R00CoEP0R00?o0000oeD06OmE
01T00omE01T00ol0003oDP08oe802003oe8020;o00001_m:00000ol0003o=@00ocD00004ocD000Co
00001?l50003o`000003o`D00?l0003o000000Co00001OnT`nl6o`000003ojC3kol0003o000000;o
000000?o0021o`000?ooool0=oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`04o`000?lQ8B7o0000oc8b<P7oc<c<000^oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0F_ooool3o`000003oad00Ol0003o;@0=
00;o;@0=00Co0000ocT05Oli01Go>@0E0_l00002odd09`03o`000?mA02SoD@0X00?oD@0X00?o0000
oe@09omD02L00_mD02L00ol0003oEP0RoeH08P04oeH08P03o`000?mE01WoE@0I00?oE@0I00?o0000
oe802?mB00P00omB00P00ol0003oBP00odX00004odX000;o000000?o=@00o`000?l000004ol0000>
ojC3k`So0000>?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00;ooooo000^ooooo`?o00007?ooool0
0ol0003oooooooooo`1Hooooo`?o00000_lM00401?l0003o;@0=obd03Ol00002ocT05@;o00000om=
02L00ol0003oD@0Xoe40:003oe40:003o`000?mD02OoE00W00?oE00W00?o0000oeH08_mF02800omF
02800ol0003oE@0IoeD06@03oeD06@03o`000?mB00SoDP0800?oDP0800?o0000odX00?m:00002?l0
0002obl00003o`000?l7003o1`0000?o1`000ol00004odG5^@?o00002OnT`nl3offWl`?o00001?mZ
Y_@6o`0003Kooooo0ol00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooo
oooooooooooo<S8b00Cooooo00?o0000ooooooooool00_ooool002kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Fooooo`;o000000Co2P00o`000?lM007o00000_l]00d4o`000005
odL08ol0003oC@0Wodd09ol000001OmA02P00ol0003oE00Woe@09`03oe@09`03o`000?mF02;oEP0R
00?oEP0R00?o0000oeD06OmE01T00omE01T00ol0003oDP08oe802007o`0000;o@`0:00?o0000obl0
0?l_00001?l_00001?l0003o1`00o`L00?l70004o`0000?oALFi0ol00006oi7To0Ko00001_m]Yo<3
o`0000;oJZKd00?o0000ohhG0?l000000ol0000hooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00007ooooo000^ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0E?ooool2o`000004o`X00?l0003o7@01o`0000;o;@0=0_l0
0003odL08`05o`000?m=02OoC@0Wodd09ol000001OmA02P00ol0003oE00Woe@09`02oe@09`03o`00
0?mF02;oEP0R00?oEP0R00Co0000oeD06OmE01WoE@0I1_l00002odd07003o`000?m300[o@`0:00?o
@`0:00?o0000obl00?l_00000ol_0002o`000003o`L00?l0003o000000?o00000_m5aKT3o`0000Co
TNCl1?l00004oiQm/`04o`000?n4M;WoQ7BiohAd^@?o000000?o9g[UoffWlom]Yo<00_m]Yo<2o`00
0003ofZVm?l0003oSQL000Co0000>?ooool00ol0003oooooooooo`0Oooooo`00;_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo05;ooooo0_l000001Ol:003o0000oad00Ol0003o;@0=
00;o00001?m702<01Ol0003oC@0Wodd09om=02Oo000000GoD@0X00?o0000oe@09omD02L00_mD02L0
0ol0003oEP0RoeH08P03oeH08PGo00000_mD02L00ol0003oC@0Lodd07002odd07003o`000?m300[o
@`0:00?o@`0:00?o0000obl00?l_00000ol_0004o`000004o`L00?l0003o0000odG5^@?o00000_nA
i?`4ojn9[P04o`000?nVPjooYX>_o`0000KoV7fc00?o0000ohAd^On4M;T00_n4M;T00ol0003oIfJm
o`000002obMji@03o`000?m]Yo?oKJOc00So0000=oooool00ol0003oooooooooo`0Oooooo`00;_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo053ooooo0_l000001?l:003o0000oad0
0OlM0042o`000003od007?l0003oA`0S00;oA`0S00Go0000odd09om=02OoC@0Wo`000005oe40:003
o`000?mD02OoE00W00;oE00W00Co0000oeH08_mF02;oEP0R1?l00005oe@09`03o`000?m=01coC@0L
00;oC@0L00?o0000od<02_m300X00om300X00ol0003o;`00obl00003obl000;o00000_l70006o`00
00Ko[hV^0_l00004ojJ3[`03o`000?nHOK?oV7fc00CoV7fc00?o0000ohAd^On4M;T00_n4M;T00ol0
003oIfJmofMV_@02obMji@;o00000_lOM^<00om]Yo?o0000o`000003o`0003Sooooo00?o0000oooo
ooooool07_ooool002kooooo0ol0000Qooooo`03o`000?oooooooooo04kooooo0_l000001?l:003o
0000oad00OlM0042o`000003od007?l0003oA`0S00;oA`0S00Go0000odd09om=02OoC@0Wo`000005
oe40:003o`000?mD02OoE00W00;oE00W1Ol00002oeL0;P03o`000?mD02OoE00W00?oE00W00?o0000
odd07?m=01`00_m=01`00ol0003o@`0:od<02P03od<02P04o`000?l_003o;`00obl000?o00000_l7
0003o`0000Go]hf[0_l00003ojn9[P03o`000?nVPjooYX>_00GoYX>_00?o0000oiQm/onHOK<01?nH
OK<00ol0003oQ7BiohAd^@02ohAd^@04o`000?mWI[goIfJmofMV_@;o9g[U00?o0000oamfholOM^<0
1_l0000hooooo`03o`000?oooooooooo01gooooo000]ooooo`;o00009?ooool00ol0003ooooooooo
o`1<ooooo`;o000000Go2P00o`000?lM007o7@01o`000002od007005o`000?m702?oA`0SodL08ol0
00000om=02L00ol0003oD@0Xoe40:003oe40:003o`000?mD02OoE00W00Co00001OmG02h00ol0003o
E00Woe@09`03oe@09`03o`000?m=01coC@0L00;oC@0L00?o0000od<02_m300X00om300X00ol0003o
;`00o`000003o`000004o`L00?l0003o0000o`0000[o]hf[00?o0000ojn9[_l000002OnVPjl00ol0
003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00Oo0000ofMV_OmWI[goIfJmo`17aolW
N^Go000000;o7gKS1_l0000fooooo`;o00007oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1:ooooo`;o000000Go2P00o`000?lM007o7@01o`000002od007005o`00
0?m702?oA`0SodL08ol000001?m=02L00ol0003oD@0Xoe40:002oe40:0Co00000_mI03000ol0003o
E`0^oeL0;P03oeL0;P03o`000?mD02OoE00W00?oE00W00?o0000odd07?m=01`00_m=01`00ol0003o
@`0:od<02P03od<02P?o00000_l_0003o`0000go]hf[0ol0000:ojJ3[`03o`000?nHOK?oV7fc00Co
V7fc00?o0000ohAd^On4M;T00_n4M;T00ol0003oIfJmofMV_@02ofMV_@03obMjiOl0003o000000Oo
0000=oooool00ol0003oooooooooo`0Looooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`18ooooo`;o000000?o2P00o`000?lM00400_l00002od007003o`000?m702?oA`0S00;o
A`0S00Go0000odd09om=02OoC@0Wo`000003oe40:0?o00001?mI03000ol0003oE`0^oeL0;P03oeL0
;P03o`000?mD02OoE00W00?oE00W00?o0000odd07?m=01`00_m=01`01?l0003o@`0:od<02_m300X3
o`0000?o;`000_l000000onnU:_o0000okN=Z`0<okN=Z`05o`000?n_R:_o[hR[ojn8Zol000002_nV
Pjl00ol0003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00?o0000ofMV_OmWI[d00_mW
I[d00ol0AlOo9g[Uo`000006o`0003Sooooo00?o0000ooooooooool06oooool000_ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0A_ooool2o`000006o`X00?l0003o7@01o`000?lf017o
00000_m001`01Ol0003oA`0SodL08om702?o000000?oC@0W00?o0000oe40:?l000000_l000000omI
037o0000oeT0<003oeT0<003o`000?mG02koE`0^00?oE`0^00?o0000oe@09omD02L00omD02L00ol0
003oC@0Lodd07002odd07003o`000?m300[o000000;o000000?o@`0:o`000?l_00000ol000001?o3
UZWo0000o`000?l0000<okN=Z`03o`000?n_R:_o[hR[00?o[hR[00?o0000ojJ3[onVPjl02?nVPjl0
0ol0003oV7fcoiQm/`04oiQm/`03o`000?n4M;WoQ7Bi00;oQ7Bi00?o0000ofMV_OmWI[d00_mWI[d2
o`17a`Oo0000=oooool00ol0003oooooooooo`0Kooooo`004oooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo04Cooooo0_l000001_l:003o0000o`000?l0003o=P0Ao`0000;o@00L00Go0000odL08om702?o
A`0So`000003odd09`?o00000omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00Co
E`0^00?o0000oe@09omD02L00omD02L01?l0003oC@0Lodd07?m=01`3o`0000?o@`0:0ol00005ol>F
Z@03o`000?nlT:So000000;o00002?ngSJ/00ol0003o[hR[ojn8Z`05ojn8Z`03o`000?nVPjooYX>_
00SoYX>_00?o0000oiQm/onHOK<01?nHOK<01Ol0003oQ7BiohAd^On4M;Wo000000CoIfJm00Go0000
oceB_ol0AlOo0000o`00M005o`0003Oooooo00?o0000ooooooooool06_ooool001?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo0_l0000Yooooo`03o`000?oo
oooooooo04;ooooo0_l000000ol:003o0000o`000002ocH04@04o`000?m001co@00Lo`0000?oA`0S
00?o0000odd09om=02L00_l00005oeT0<@03o`000?mI033oF@0`00;oF@0`00?o0000oeL0;_mG02h0
1?mG02h00ol0003oE00Woe@09`03oe@09`03o`000?m=01co000000;o00000om300X3o`0000Oo`iJY
00?o0000okb@Z?nlT:P00onlT:P2o`0000Go]hf[00?o0000ojn8Zon_R:/01on_R:/2o`0000WoYX>_
00?o0000oiQm/onHOK<01?nHOK<01Ol0003oQ7BiohAd^On4M;Wo000000CoIfJm0_lmD[l00ol0AlOo
0000o`000004o`0003Oooooo0_l0000Kooooo`004oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`;o0000@Oooool2o`000003
o`X00?l0003o=P0A00;o=P0A00Co0000od007?m001co00000om702<4o`000003oeP0;ol0003oF@0a
00?oF@0a00?o0000oeT0<?mI03000omI03000ol0003oE`0^oeL0;P03oeL0;P03o`000?mD02OoE00W
00?oE00W0ol000000om=01co0000o`000003o`0000Wo`iJY00?o0000okb@Z?nlT:P01_nlT:P3o`00
0003okN=Zol0003o[hR[00_o[hR[00?o0000ojJ3[onVPjl01_nVPjl:o`0000;oQ7Bi00?o0000ofMV
_OmWI[d00_mWI[d2oceB_`Oo0000=_ooool2o`0001_ooooo000Cooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0?Oooool4o`0000?o=P0A00Co0000od007?m001co00000om702<2o`0000?oF00_00?o0000
oeT0<OmI03400omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00?oE`0^00Co0000
oe@09omD02OoE00W0ol00002odd070?o00000_o9WJ/00ol0003o`iJYol>FZ@08ol>FZ@03o`000?nl
T:So_92X00Wo_92X0_l0000=ojn8Z`03o`000?nVPjooYX>_00;oYX>_0ol000000onMO[7o0000ohag
]P05ohag]P03o`000?mdK;_o000000?o00001?mWI[d00olmD[oo0029o`000006o`0003Oooooo00?o
0000ooooooooool06?ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0kooooo`?o000000Go
:@01o`000?lf017o=P0Ao`000003od007004o`000?m702?o0000o`0000CoF00_00?o0000oeT0<OmI
03400omI03400ol0003oF@0`oeT0<002oeT0<003o`000?mG02koE`0^00?oE`0^00?o0000oe@09ol0
00000_l000000omD02Oo0000o`000002o`0000CobIf[00?o0000ol>FZOo3UZT02?o3UZT00ol0003o
_92Xokb@Z00:okb@Z003o`000?ngRjSo000000go[hR[00Co0000ojJ3[ol0003o00001OnMO[400ol0
003oS7Nfohag]P04ohag]P04o`000?mdK;_oM6bkogA/^`;o00000omWI[d00ol0003o?E:oo`00R@05
o`000003ooooool0003ooooo03Gooooo00?o0000ooooooooool06?ooool002cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0iooooo`?o000000Go:@01o`000?lf017o=P0Ao`000003
od0070?o000000?oE@0[o`000?mH02l00_mH02l00ol0003oF@0aoeT0<@03oeT0<@03o`000?mI033o
F@0`00;oF@0`00?o0000oeL0;_mG02h00omG02h3o`0000?oE00W0_l00007olVMZ`03o`000?o3UZWo
`iJY00So`iJY00?o0000okb@Z?nlT:P02OnlT:P01?l0003o]h^XokN;Z?ngRjP2o`0000_o[hR[0_l0
0008oien/@03o`000?n<MkKoS7Nf00CoS7Nf00?o0000ogA/^omdK;/00_mdK;/2o`0000;oIfJm0_lm
D[l7o`0003Oooooo00?o0000ooooooooool05oooool002cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0gooooo`;o00000_lY00401?l0003o=P0AocH04Ol00003od0070;o00000_mE
02/01Ol0003oF00_oeP0;omH02oo000000GoF@0a00?o0000oeT0<?mI03000_mI03001?l0003oE`0^
oeL0;_mG02h4o`0000?oE00W0_l00008olVMZ`03o`000?o3UZWo`iJY00So`iJY00?o0000okb@Z?nl
T:P02OnlT:P00ol0003o]h^XokN;Z004okN;Z0;o00002?n_R:/01?l0003oZ8>]ojR3[OnXPjd8oien
/@03o`000?n<MkKoS7Nf00CoS7Nf00Co0000ogA/^omdK;_oM6bk0_mAG;l01?l0003oIfJmofMV_Olm
D[l8o`0003Oooooo00?o0000ooooooooool05_ooool002cooooo0_l0000aooooo`03o`000?oooooo
oooo03Gooooo0_l00002obT00@04o`000?lf017o=P0Ao`0000?o@00L0_l00002oeD0:`03o`000?mH
02ooF00_00;oF00_00?o0000oeT0<OmI03400omI03400ol0003oF@0`oeT0<002oeT0<004o`000?mG
02ko0000o`0000;oE`0^00?o0000oe@09ol000000ol00008olVMZ`03o`000?o3UZWo`iJY00So`iJY
00?o0000okb@Z?nlT:P02_nlT:P00ol0003o]h^XokN;Z006okN;Z003o`000?n_R:_o[hR[00Co[hR[
00?o0000ojR3[OnXPjd00onXPjd00ol0003oWGjaoien/@05oien/@03o`000?n<MkKoS7Nf00CoS7Nf
00Co0000ogA/^omdK;_oM6bk0_mAG;l3o`000003oceB_ol0003o000000Co000000?oooooo`000?oo
ool0=?ooool3o`0001Oooooo000/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<oooool2o`0000;o:@0100Co0000ocH04Olf017o00000_m001`2o`0000?oE@0[00?o0000oeP0;omH
02l00_mH02l00ol0003oF@0aoeT0<@03oeT0<@03o`000?mI033oF@0`00;oF@0`0ol00003oeL0;P?o
00000_o@YZh00ol0003obIf[olVMZ`07olVMZ`03o`000?o3UZWo`iJY00So`iJY00?o0000okb@Z?nl
T:P02OnlT:P00ol0003o]h^XokN;Z008okN;Z0;o00000on_R:/00ol0003oZ8>]ojR3[@05ojR3[@03
o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH00ol0003oM6bkogA/^`02ogA/^`?o
DEbo0_l000000olmD[oo0S>go`000004o`000003ooooool0003ooooo03Gooooo00?o0000oooooooo
ool05Oooool002_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`?o0000
0_lY00401Ol0003o=P0AocH04Ol0003o@00L00;o000000GoD@0So`000?mE02_oE@0[o`000004oeP0
;`03o`000?mI037oF@0a00?oF@0a00?o0000oeT0<?mI03000ol00003oeL0;P?o00001Oo@YZh01?l0
003obIf[olVMZoo9WJ/Co`0000Wo_92X00?o0000okN;Z?ngRjP02ongRjP00ol0003o[hR[o`000009
ojR3[@03o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH00ol0003oM6bkogA/^`02
ogA/^`CoDEbo0_l000000ol008Wo0000o`000004o`0003Oooooo00?o0000ooooooooool05?ooool0
02_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0^ooooo`?o00000_lY00400ol0
003o=P0AocH04@03o`0000;oD@0S00Go0000oeD0:omE02_oE@0[o`000003oeP0;`03o`000?mI037o
F@0a00?oF@0a1?l000000omI033o0000o`000003o`0000God:J^1ol00005ol^NZ@03o`000?o5UjOo
aINW00SoaINW00?o0000ol2BY_o0TZH00ol00006okb@Z003o`000?ngRjSo]h^X00co]h^X0_l0000:
ojR3[@03o`000?nMO[7oWGja00GoWGja00?o0000ohag]_n<MkH00on<MkH01Ol0003oM6bkogA/^omd
K;_o000000CoDEbo2Ol0000fooooo`03o`000?oooooooooo01Cooooo000[ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0;?ooool3o`0000;o:@0100?o0000ocH04Olf01400_l00003
oe408`05o`000?mE02_oE@0[oeD0:ol000000omH02l00ol0003oF@0aoeT0<@02oeT0<@?o00000_mI
0303o`0000;oek6b00?o0000om2V[_l000001?l00002om2U[@03o`000?o;WZWobijY00KobijY00?o
0000olFGYoo5UjL02?o5UjL00ol0003o`9:Vol2BYP04ol2BYP?o00000_nlT:P00ol0003o]h^XokN;
Z00<okN;Z004o`000?naQjWo/HNYo`0000[oZ8>]00?o0000oien/OnMO[401OnMO[400ol0003oS7Nf
ohag]P03ohag]P05o`000?mdK;_oM6bkogA/^ol000000omAG;l00ol0003o?E:oo`000005o`000003
ooooool0003ooooo03Gooooo00?o0000ooooooooool04oooool002_ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Zooooo`?o00000_lY00401?l0003o=P0Ao`000?l00004oe408`05
o`000?mE02_oE@0[oeD0:ol000001?mH02l00ol0003oF@0ao`000002o`000003oeT0<Ol0003o0000
00;o00000ooG/K84o`0000Kod:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFG
Y`03o`000?o0TZKo`9:V00Oo`9:V0ol0000=okN;Z003o`000?naQjWo/HNY00;o/HNY00?o0000ojR3
[OnXPjd02?nXPjd00ol0003oWGjaoien/@05oien/@03o`000?n<MkKoS7Nf00;oS7Nf00?o0000ogA/
^omdK;/00_mdK;/01_l0003oDEbooe5L_omAG;oo0000oceB_`Ko000000?oooooo`000?ooool0=Ooo
ool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool01?ooool002_ooooo0_l0000h
ooooo`03o`000?oooooooooo02Sooooo0ol00002obT00@Co00001?mA02<01Ol0003oE@0[oeD0:omE
02_o000000CoF00_0ol00003oeT0<@;o00001?oG/K82o`000003omF_/_l0003od:F]00Ood:F]00?o
0000ol^NZOo;WZT01_o;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00Wo`9:V00Co
0000ok^>Y_l0003o00002_ngRjP00ol0003o/HNYok67Z@04ok67Z@03o`000?nXPjgoZ8>]00SoZ8>]
00?o0000oien/OnMO[401OnMO[400ol0003oS7Nfohag]P02ohag]P03o`000?mdK;_oM6bk00;oM6bk
00Co0000oe5L_omAG;ooDEbo0_l000001?l2<kOo0000o`000?nL;P03o`0003Gooooo0_l0000;oooo
o`03o`000?oooooooooo00Kooooo000[ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool2o`000004oaL00?l0003o:@01obT00@;o000000?oB`0Ho`000?mA02<00omA02<01Ol0
003oE@0[oeD0:omE02_o000000;oF00_0ol00003oeT0<@Co00000_oG/K83o`0000;oeJnb00?o0000
om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`000?o5UjOoaINW00SoaINW00?o0000
ol2BY_o0TZH02?o0TZH00ol0003o^hjVok^>YP02ok^>YP;o00001ongRjP00ol0003o/HNYok67Z@06
ok67Z@;o00002OnXPjd00ol0003oWGjaoien/@02oien/@Ko00000_n<MkH01Ol0003oM6bkogA/^omd
K;_o000000?oDEbo0ol000000ol2<kOo0000o`000002o`000003ooooool0003ooooo03Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`00:oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02?ooooo0_l000001?lG003o0000obT00OlY0042o`000003od/06?l0
003oD@0S00?oD@0S00?o0000oeD0:omE02/00_mE02/3o`000003oeP0;ol0003o000000?o00000_oM
_[T01?l0003oek6bo`000?l00005omF_/P03o`000?o@YJgod:F]00Kod:F]00?o0000ol^NZOo;WZT0
1_o;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000ok^>Y_nkSZH0
1OnkSZH2o`0000Co]h^X00?o0000ok67ZOnaQjT02OnaQjT00ol0003oZ8>]ojR3[@06ojR3[@Go0000
0onCN[@00ol0003oOg:jogmb^P04o`0000?oM6bk00Co0000oe5L_omAG;ooDEbo2?l000000ooooooo
0000ooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool002[ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`;o000000?o5`00o`000?lY0040
0_l00002od/06003o`000?mA02?oD@0S00;oD@0S00?o0000oeD0:omE02/00ol00002oeP0;`?o0000
1_oM_[T2o`0000KoeJnb00?o0000om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`00
0?o5UjOoaINW00OoaINW00?o0000ol2BY_o0TZH02Oo0TZH00ol0003o^hjVok^>YP07ok^>YP;o0000
00?o]h^Xo`000?naQjT03?naQjT00ol0003oZ8>]ojR3[@02ojR3[@?o000000?oXH2_o`000?nCN[@0
1_nCN[@00ol0003oOg:jogmb^P02ogmb^P?o00000_mdK;/01ol0003oDEbooe5L_omAG;oo74Bno`00
0?l2<kL00_l000001OnL;P3o0000o`000?oooooo000003Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`00:_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
01oooooo0_l000001?lG003o0000o`000?l00003od/06003o`000?mA02?oD@0S00;oD@0S1?l00000
0omE02_o0000o`000003o`0000KogKji0_l00008omF_/P03o`000?o@YJgod:F]00God:F]00?o0000
ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000
ok^>Y_nkSZH02_nkSZH2o`0000ko/HNY00Co0000ojR3[Ol0003o00001OnQP:l00ol0003oTgZdoi=j
]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o0000of9V`?l000000_l00003oe5L_`04o`000?lL
A;ko0000o`8c]`Co000000?oooooo`000?ooool0=Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo000Zooooo`;o0000?_ooool00ol0003oooooooooo`0Mooooo`;o000000Co
5`00o`000?l0003o00000om;01P01?l0003oD@0Soe408omA02<3o`0000?oE@0[0_l00003on?=`P03
o`000?oM_[WogKji00;ogKji0_l000000ooK^[Wo0000omF_/P06omF_/P03o`000?o@YJgod:F]00Ko
d:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`07olFGY`03o`000?o0TZKo`9:V00So
`9:V00?o0000ok^>Y_nkSZH02onkSZH00ol0003o]hZWo`00000=ok67Z@;o00002?nQP:l00ol0003o
TgZdoi=j]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o0000of9V`?mRI/000_l00003oe5L_`04
o`000?lLA;ko0000o`8c]`Co000000?oooooo`000?ooool0<oooool3o`0000Oooooo00?o0000oooo
ooooool01_ooool002[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`?o
000000Co5`00o`000?l0003o00000om;01P00ol0003oD@0So`000003o`0000?oE@0[0_l00004on?=
`P03o`000?oM_[WogKji00?o00000_oK^[T00ol0003oeJnbomF_/P05omF_/P03o`000?o@YJgod:F]
00Kod:F]00?o0000ol^NZOo;WZT01oo;WZT00ol0003oaINWolFGY`08olFGY`03o`000?o0TZKo`9:V
00So`9:V00?o0000ok^>Y_nkSZH02_nkSZH01?l0003o]hZWokN:YongRZL2o`0000[o/HNY00Co0000
oj^4Zon[Q:_oZhB[2?nQP:l00ol0003oTgZdoi=j]005oi=j]003o`000?moL[[oOg:j00;oOg:j00?o
0000of9V`?mRI/000_l00003oe5L_`04o`000?l07Zco0000o`8c]`Co000000?oooooo`000?ooool0
=?ooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000Sooooo000Zooooo`03o`000?oo
oooooooo03oooooo0_l0000Iooooo`;o000000Go5`00o`000?l0003o@@07o`000003od/060?o0000
0_mA02<00ol0003oE@0[o`000002o`0000Kohlg20ol00005om^j^@03o`000?oE[k;oeJnb00GoeJnb
00?o0000om2U[Oo@YJd01_o@YJd00ol0003obijYol^NZ@07ol^NZ@03o`000?o5UjOoaINW00OoaINW
00?o0000ol2BY_o0TZH02?o0TZH00ol0003o^hjVok^>YP0:ok^>YP03o`000?ngRZOo]hZW00Co]hZW
00?o0000ok67ZOnaQjT01_naQjT00ol0003oZhB[oj^4Z`03oj^4Z`03o`000?nQP:ooXH2_00GoXH2_
00?o0000oi=j]?nCN[@01OnCN[@00ol0003oOg:jogmb^P02ogmb^P04o`000?mRI/3oHVK0of9V`0;o
00000_mAG;l00ol0003o01j/o`000004o`0000;ooooo00?o0000ooooooooool0<Oooool3o`0000oo
oooo000Zooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05Oooool4o`000003od40
1ol0003o000000;oB`0H0ol00003oe408`?o000000?oiMk=o`000?oScL801OoScL82o`0000KofkZi
00?o0000omF_/_oE[k801OoE[k800ol0003od:F]om2U[@06om2U[@03o`000?o;WZWobijY00CobijY
2Ol00005olFGY`03o`000?o0TZKo`9:V00So`9:V00?o0000ok^>Y_nkSZH02_nkSZH00ol0003o]hZW
okN:Y`05okN:Y`03o`000?naQjWo/HNY00Co/HNY00?o0000oj^4Zon[Q:/01On[Q:/00ol0003oXH2_
oj60[`05oj60[`03o`000?nCN[CoTgZd00CoTgZd00?o0000ogmb^_moL[X00omoL[X00ol0003oHVK0
of9V`002ocEC``05o`000?mAG;oo0000oaa4__l07Z`01Ol000000ooooooo0000ooooo`0_ooooo`?o
00000_ooool00ol0003oooooooooo`0=ooooo`00:Oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01;ooooo1Ol000000om100Oo0000od/06004o`0000;oD@0S0ol00003onGNc@03o`00
0?oScL;ohlg200?ohlg20_l00007om^j^@03o`000?oE[k;oeJnb00KoeJnb00?o0000om2U[Oo@YJd0
1_o@YJd00ol0003obijYo`000004o`0000?obifY00?o0000olNHYoo7V:L00oo7V:L:o`0000Go`9:V
00?o0000ok^>Y_nkSZH02_nkSZH00ol0003o]hZWokN:Y`07okN:Y`;o00000onaQjT00ol0003oZhB[
oj^4Z`07oj^4Z`03o`000?nQP:ooXH2_00GoXH2_00?o0000oi=j]?nCN[@01?nCN[@00ol0003oOg:j
ogmb^P03ogmb^P03o`000?mRI/3oHVK000;o=E?300Go0000oe5L_ol0003o74Bno`0N[004o`0000;o
oooo00?o0000ooooooooool0:_ooool3o`0000Gooooo00?o0000ooooooooool03Oooool002Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`Co00000_m100L3o`0000;oB`0H
1?l00005onGNc@03o`000?oScL;ohlg200;ohlg20_l000000ooNb<;o0000om^j^@06om^j^@03o`00
0?oE[k;oeJnb00GoeJnb00?o0000om2U[Oo@YJd01?o@YJd5o`0000OobifY00?o0000olNHYoo7V:L0
2?o7V:L00ol0003o`i>Uol>CY@03ol>CY@Ko00002onkSZH00ol0003o]hZWokN:Y`0:okN:Y`03o`00
0?naQjWo000000_oZhB[00?o0000oj60[onQP:l01OnQP:l00ol0003oTgZdoi=j]004oi=j]003o`00
0?moL[[oOg:j00?oOg:j00?o0000of9V`?mRI/000_leDl<4o`000003o`0N[?l0003o000000;o0000
0_ooool00ol0003oooooooooo`0Vooooo`?o00002?ooool00ol0003oooooooooo`0=ooooo`00:Ooo
ool3o`0004Gooooo00?o0000ooooooooool03_ooool7o`0000;oB`0H1_l00006onGNc@03o`000?oS
cL;ohlg200;o00000_oNb<800ol0003ofkZiom^j^@05om^j^@03o`000?oE[k;oeJnb00KoeJnb00?o
0000om2U[Ol000001?l00002olnU[@03o`000?o;WJWobifY00OobifY00?o0000olNHYoo7V:L01oo7
V:L00ol0003o`i>Uol>CY@08ol>CY@03o`000?noT:Go000000;o00001onkSZH00ol0003o]hZWokN:
Y`0<okN:Y`;o00003?n[Q:/00ol0003oXH2_oj60[`05oj60[`03o`000?nCN[CoTgZd00CoTgZd00?o
0000ogmb^_moL[X00_moL[X01?l0003oHVK0of9V`?mRI/03ocEC``04o`000?lLA;ko01j/o`0N[0Co
00000_ooool00ol0003oooooooooo`0Qooooo`Co00002oooool00ol0003oooooooooo`0=ooooo`00
:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00_ooooo1_l000000om100Oo0000
o`000002o`0000;oi?KE0_l000000ooQk]Wo0000onGNc@04onGNc@04o`000?oScL;ohlg2o`0000?o
g/S200?o0000om^j^OoK^[T01_oK^[T00ol0003oeJnbomF_/P04omF_/PCo00001_o?YJd00ol0003o
bifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00SoaiRW00?o0000ol>CYOo3TjD01oo3TjD00ol0003o
_i2Uokn@Y@03okn@Y@;o00001OnkSZH00ol0003o]hZWokN:Y`0<okN:Y`03o`000?nbR:So000000co
ZhB[00?o0000oj60[onQP:l01OnQP:l00ol0003oTgZdoi=j]004oi=j]003o`000?moL[[oOg:j00;o
Og:j00Co0000of9V`?mRI/3oHVK00oleDl<01?l0003o74Bno`0N[?l07Z`3o`0000;ooooo00?o0000
ooooooooool07_ooool3o`00013ooooo00?o0000ooooooooool03?ooool000Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
2Oooool4o`0000;o@@070ol000001Oo@o]co0000onCfeOoTm]Go000000;ohNkI00?o0000onGNcOoU
g/d01?oUg/d3o`0000Cog/S200?o0000om^j^OoK^[T01OoK^[T00ol0003oeJnbomF_/P02omF_/P?o
000000?odjfbo`000?o?YJd01oo?YJd00ol0003obifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00Oo
aiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@05okn@Y@?o000000?o^hjVo`000?ng
RZL03OngRZL01Ol0003o/XRXok:8Z?nbR:So000000coZhB[00?o0000oj60[onQP:l00_nQP:l<o`00
00?oOg:j00Co0000of9V`?mRI/3o00000oleDl<01?l0003o74Bno`0N[?l07Z`3o`0000;ooooo00?o
0000ooooooooool06_ooool3o`0001?ooooo00?o0000ooooooooool03?ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Kooooo
2?l00003om3ng004o`000?oTm]Go0000o`0000;ohNkI00?o0000onGNcOoUg/d01?oUg/d2o`0000Go
g/S200?o0000om^j^OoK^[T01OoK^[T00ol0003oeJnbomF_/P03o`0000?odjfb00?o0000olnU[Oo?
YJd01_o?YJd00ol0003obifYol^MZ@07ol^MZ@03o`000?o7V:OoaiRW00SoaiRW00?o0000ol>CYOo3
TjD01oo3TjD00ol0003o_i2Uokn@Y@09okn@Y@;o00003OngRZL00ol0003o/XRXok:8Z003ok:8Z0;o
00002_n[Q:/5o`0000CoVWjc00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1o`000002o`000005
ogmb^_l0003oHVK0of9V`?l000000_leDl<00ol0<k[o0000o`000002o`0N[0?o00000_ooool00ol0
003oooooooooo`0Fooooo`?o00005_ooool00ol0003oooooooooo`0<ooooo`001?l00002ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00;ooooo0ol00002
oc8000Co00001?o@o]`3o`0000?ohNkI00?o0000onGNcOoUg/d00ooUg/d2o`0000Kog/S200?o0000
om^j^OoK^[T01_oK^[T3o`0000Kodjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@07
ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@09
okn@Y@04o`000?nkSJGo0000o`0000[o]hZW00?o0000ok:8Z?nbR:P01_nbR:P00ol0003oZhB[oj^4
Z`06oj^4Z`04o`000?nUPjooYH>_o`0000OoVWjc00?o0000ohUh^_n9N;X00on9N;X01?l0003oLFo1
og5_`OmaKl43o`0000;oHVK000Co0000ocEC`oleDl?o03>j0_l000001?l07Zco0000o`000?l00003
ooooo`03o`000?oooooooooo017ooooo1?l0000Iooooo`03o`000?oooooooooo00cooooo0006oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`1;ooooo`Wo000000?oVo74o`000?l000001?o@
o]`2o`0000CohNkI00Co0000onGNcOoUg/goiMk=0ol000000ooPelko0000omk8`P05omk8`P03o`00
0?oK^[WofkZi00CofkZi0_l00008om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT0
1oo;WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U00So`i>U00?o0000okn@YOnoT:D0
2OnoT:D00ol0003o^hfUok^=Y@02ok^=Y@?o00001ongRZL00ol0003o/XRXok:8Z007ok:8Z0;o0000
1On[Q:/00ol0003oYH>_ojF3[`02ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X0
0on9N;X00ol0003oLFo1og5_`@03og5_`@;o000000KoHVK0o`000?leDl?o=E?3o`0c^_l00002o`0N
[0?o00000_ooool00ol0003oooooooooo`0>ooooo`?o00007Oooool00ol0003oooooooooo`0<oooo
o`001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0004[ooooo2?l00002oi_aa0;o00001Oo@
o]`2o`0000CohNkI00?o0000onGNcOoUg/d00_l00003on3GcP03o`000?oNb<;og/S200Cog/S200?o
0000om^j^OoK^[T00_oK^[T3o`000003omNg^Ol0003odjfb00Oodjfb00?o0000olnU[Oo?YJd01Oo?
YJd00ol0003obifYol^MZ@08ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3
TjD00ol0003o_i2Uokn@Y@09okn@Y@03o`000?nkSJGo^hfU00Go^hfU0_l00004okN:Y`03o`000?nb
R:So/XRX00[o/XRX00Go0000oj^4Zon[Q:_oZhB[o`000006ojF3[`03o`000?nJO[?oVWjc00GoVWjc
00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1og5_`@02og5_`@04o`000?m<HLOo0000o`0000?o
=E?300Co03>jo`000?l07Zco01j/0ol00002ooooo`03o`000?oooooooooo00[ooooo0ol0000Poooo
o`03o`000?oooooooooo00cooooo0006ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`16
ooooo`?o000000?oooooo`000?l000000_l00002oi_aa0?o00001Oo@o]`2o`0000GohNkI00Co0000
onGNcOl0003o00001?oPelh00ol0003og/S2omk8`P05omk8`P03o`000?oK^[Wo000000;o00000ooG
]kT00ol0003odjfbom>]/P06om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT01oo;
WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U00Wo`i>U00?o0000okn@YOnoT:D02?no
T:D00ol0003o^hfUok^=Y@08ok^=Y@;o000000?o]hZWo`000?nbR:P03OnbR:P00ol0003oZhB[o`00
0008ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X00on9N;X00ol0003oLFo1og5_
`@02og5_`@04o`000?m<HLOo0000o`0000;o=E?300Co0000o`0c^_l0003o01j/0ol00003ooooo`03
o`000?oooooooooo00Kooooo0ol0000Sooooo`03o`000?oooooooooo00cooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`14ooooo`;o00000_ooool5o`000005oi_aa?l0003o0000
ok7khOl000000oo@o]`4o`0000GohNkI0ol00006on3GcP03o`000?oNb<;og/S200Cog/S20ol00006
omNg^@03o`000?oC[K;odjfb00Godjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@08
ol^MZ@03o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02?o3TjD00ol0003o_i2Uokn@Y@09
okn@Y@03o`000?nkSJGo^hfU00[o^hfU0_l0000>ok:8Z0?o00002OnUPjl00ol0003oVWjcoiYn/`05
oiYn/`03o`000?n9N;[oRGRj00?oRGRj00?o0000og5_`OmaKl400_maKl401?l0003oC677odaQaol0
0002ocEC``04o`000?l0<k[o0000o`0N[0?o00000_ooool00ol0003oooooooooo`03ooooo`?o0000
9oooool00ol0003oooooooooo`0;ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001Oooool00ol0003oooooooooo`11ooooo`?o
00000_ooool5o`000003oi_aa?l0003o000000;o/O_Q00?o0000om3ng?o@o]`00_l00002om;gi@03
o`000?oQk]WohNkI00;ohNkI0_l00008on3GcP03o`000?oNb<;og/S200?og/S20_l00008omNg^@03
o`000?oC[K;odjfb00Kodjfb00?o0000olnU[Oo?YJd01_o?YJd00ol0003obifYol^MZ@07ol^MZ@03
o`000?o7V:OoaiRW00OoaiRW00?o0000ol>CYOo3TjD02Oo3TjD00ol0003o_i2Uokn@Y@08okn@Y@03
o`000?nkSJGo^hfU00_o^hfU00Co0000okR;Y_l0003o00002onbR:P01Ol0003o[XJ[ojj6Zon^QZ_o
000000WoYH>_00?o0000oiYn/onJO[<01OnJO[<00ol0003oRGRjohUh^P03ohUh^P03o`000?maKl7o
LFo100;oLFo100Co0000odaQaom<HLOo00000_leDl<01?l0003o03>jo`000?l07Z`3o`0000;ooooo
1Ol0000Zooooo`03o`000?oooooooooo00_ooooo000Xooooo`03o`000?oooooooooo03kooooo0ol0
0002ooooo`Go000000CoM^;7o`000?l0003o00000onann401?l0003od?kLo`000?l00003om;gi@04
o`000?oQk]WohNkIon7^f@;o000000?ofnCLo`000?oPelh01_oPelh00ol0003og/S2omk8`P02omk8
`P;o000000?ofL?3o`000?oG]kT01_oG]kT00ol0003odjfbom>]/P06om>]/P03o`000?o?YJgocjF]
00KocjF]00?o0000ol^MZOo;WJT02?o;WJT00ol0003oaiRWolNHY`07olNHY`03o`000?o3TjGo`i>U
00So`i>U00?o0000okn@YOnoT:D02OnoT:D00ol0003o^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V
00;o^8^V00?o0000ok:8Z?nbR:P01onbR:P00ol0003o[XJ[ojj6Z`03ojj6Z`03o`000?nUPjooYH>_
00OoYH>_00?o0000oiYn/onJO[<01OnJO[<00ol0003oRGRjohUh^P02ohUh^P03o`000?maKl7oLFo1
00?oLFo100?o0000odaQaom<HLL00_l000000oleDl?o0000o`0c^P08o`0002gooooo00?o0000oooo
ooooool02oooool002Sooooo00?o0000ooooooooool0>oooool3o`0000;ooooo1_l000000omfh/Oo
0000o`000005ok7kh@?o00001?oBmnD00ol0003ohNkIo`000002o`0000;ofnCL00?o0000on3Gc_oP
elh01OoPelh00ol0003og/S2omk8`P03o`0000;ofL?300?o0000omNg^OoG]kT01_oG]kT00ol0003o
djfbom>]/P06om>]/P03o`000?o?YJgocjF]00KocjF]00?o0000ol^MZOo;WJT00_o;WJTFo`0000Go
`i>U00?o0000okn@YOnoT:D02?noT:D00ol0003o^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Co
^8^V0_l00006ok:8Z003o`000?n^QZ_o[XJ[00Go[XJ[00?o0000ojF3[onUPjl01onUPjl00ol0003o
VWjcoiYn/`05oiYn/`03o`000?n9N;[oRGRj00;oRGRj00?o0000og5_`OmaKl400_maKl400ol0003o
C677odaQa`02o`m9aP;o000000Co03>jo`000?l07ZcoWc400_l00003ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool02oooool002Oooooo0_l0000jooooo`?o00000_ooool:o`0000Go
/O_Q0_l00006om;gi@?o00001?oKi=`00ol0003oh=O>on3GcP06on3GcP?o00001?oI`l<00ol0003o
ekNiomNg^@06omNg^@03o`000?oC[K;odjfb00Kodjfb00?o0000olnU[Oo?YJd01?o?YJd8o`0000Go
bYfY00?o0000olNHY_o7V:H01oo7V:H00ol0003oa9>TolBCY004olBCY0Oo00002OnoT:D00ol0003o
^hfUok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Ko^8^V0_l00003ok:8Z003o`000?n^QZ_o[XJ[00Oo
[XJ[0_l00008ojF3[`03o`000?nJO[?oVWjc00GoVWjc00?o0000ohUh^_n9N;X00_n9N;X00ol0003o
LFo1og5_`@02og5_`@03o`000?m<HLOoC67700;o3dW60_l000000ol0<k[o0000o`0N[003o`0000;o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`009oooool00ol0003ooooo
ooooo`0fooooo`?o00000_ooool<o`0000?o/O_Q0ol00007om;gi@;o00001OoKi=`00ol0003oh=O>
on3GcP06on3GcP;o00001_oI`l<00ol0003oekNiomNg^@06omNg^@03o`000?oC[K;odjfb00Kodjfb
00?o0000olnU[Ol000001?l00002olfR[003o`000?o:WJWobYfY00OobYfY00?o0000olNHY_o7V:H0
1oo7V:H00ol0003oa9>TolBCY009olBCY003o`000?o2TJCo`Y6T00?o00001OnoT:D00ol0003o^hfU
ok^=Y@0:ok^=Y@03o`000?nhRjKo^8^V00Wo^8^V00?o0000ok:8Z?l000003?n^QZ/00ol0003oYH>_
ojF3[`06ojF3[`03o`000?nJO[?oVWjc00;oVWjc1_l00002ohUh^P03o`000?maKl7oLFo100;oLFo1
00?o0000odaQaom<HLL00_l?BLH2o`000003o`0c^_l0003o01j/00;o00000oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo03?ooooo0ol0
0003ooooo`Wo00000_nElNT00ol0003o/O_Qok7kh@03o`000003ok_gkol0003od_OU00God_OU0_l0
0006om_Tg003o`000?oPelkoh=O>00Goh=O>0_l00007omW3``03o`000?oG]kWoekNi00KoekNi00?o
0000om>]/_oC[K801?oC[K85o`0000KocJ:/00?o0000olZMZOo:WJT02?o:WJT00ol0003oaiRVolNH
YP07olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@01?o2TJ@3o`0000;o_i2U00?o
0000ok^=YOnkSJD02OnkSJD00ol0003o^8^VokR;YP0;okR;YP;o00003On^QZ/00ol0003oYH>_ojF3
[`04ojF3[`Ko00000onBO[X00ol0003oOWS2ogih`P04o`0000CoLFo100?o0000odaQaom<HLL00_l?
BLH00ol0003o03>jo`0c^P04o`0000?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0;ooooo`009oooool00ol0003oooooooooo`0`ooooo`?o00000oooool9o`0000CoUO7Y00Co0000
ok7khOl0003o00000onkmnl00ol0003od_OUom;gi@02om;gi@Co00001ooKi=`00ol0003oh=O>on3G
cP02on3GcP?o000000?ofM3@o`000?oI`l<01OoI`l<00ol0003oekNiomNg^@06omNg^@04o`000?oC
[K;odjfbom>]/PCo00000_o@Z[800ol0003ocJ:/olfR[006olfR[003o`000?o:WJWobYfY00OobYfY
00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY008olBCY003o`000?o2TJCo`Y6T00Oo`Y6T
1?l00009ok^=Y@03o`000?nhRjKo^8^V00co^8^V00?o0000okB9Z?l000003On^QZ/00ol0003oYH>_
ojF3[`03o`0000CoWh:c1_nBO[X00ol0003oOWS2ogih`P02ogih`P?o00000_maKl401?l0003oC677
odaQaom<HLL2o`m9aP03o`000?l0<k[o03>j00?o00001?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00_ooooo000Wooooo`03o`000?oooooooooo02gooooo0ol00003ooooo`?o0000
00KoH]WHo`000?l0003o0000ohGUm_l00004oiGaj@Co00001Onkmnl00ol0003od_OUom;gi@03o`00
00;oc^cY00?o0000om_Tg?oKi=`01OoKi=`00ol0003oh=O>on3GcP03o`0000?ofM3@00?o0000omW3
`ooI`l<01OoI`l<00ol0003oekNiomNg^@06omNg^@Co00001Oo@Z[800ol0003ocJ:/olfR[006olfR
[003o`000?o:WJWobYfY00SobYfY00?o0000olNHY_o7V:H01oo7V:H00ol0003oa9>TolBCY008olBC
Y003o`000?o2TJCo`Y6T00Wo`Y6T00?o0000okn?Y?noSj@00ol00006ok^=Y@03o`000?nhRjKo^8^V
00_o^8^V00Co0000okB9Z?ndRJSo]8VX0_l0000;ojj6Z`?o00002?nOP[<6oi9n^P03o`000?mnN<;o
OWS200;oOWS200Ko0000oem^bol0003o0000og5_`Ol00003odaQa`;o3dW600?o0000o`0c^_l00000
0ol00003ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool002Oooooo00?o
0000ooooooooool0:_ooool3o`0000;ooooo1Ol00005ohGUmP03o`000?nElNWoUO7Y00Go00001onk
mnl4o`0000Coc^cY00?o0000om_Tg?oKi=`01OoKi=`4o`0000GofM3@00?o0000omW3`ooI`l<01OoI
`l<00ol0003oekNiomNg^@04omNg^@Co00002?o@Z[800ol0003ocJ:/olfR[006olfR[003o`000?o:
WJWobYfY00OobYfY00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY008olBCY003o`000?o2
TJCo`Y6T00So`Y6T00?o0000okn?Y?noSj@01?noSj@3o`0000;o^hfU00?o0000okR;Y_nhRjH02onh
RjH00ol0003o]8VXokB9Z004okB9Z003o`000?n^QZ_o[XJ[00Oo[XJ[00Co0000ojV6[onYQZoo0000
2OnOP[<00ol0003oTWjjoi9n^P03oi9n^P03o`000?mnN<;oOWS200;oOWS200?o0000oem^bomOK//0
0ol00003odaQa`;o3dW60_l000001?l029Go0000o`000?l00003ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool02_ooool002Kooooo00?o0000ooooooooool0:?ooool3o`0000;ooooo
0ol00008ohGUmP;o000000?oUO7Yo`000?l000000_nUk_P2o`0000Go^oO_1?l00006olk/j@03o`00
0?oKi=cofnCL00?ofnCL1?l00007omW@d003o`000?oI`l?ofL?300KofL?300?o0000omNg^OoG]kT0
1?l00002om:d^`03o`000?o@Z[;od:Zb00Kod:Zb00?o0000olfR[?o=XZ`01_o=XZ`00ol0003obYfY
olZMZ@08olZMZ@03o`000?o7V:KoaiRV00OoaiRV00?o0000olBCY?o4Tj@02?o4Tj@00ol0003o`Y6T
ol:AY009ol:AY003o`000?noSjCo_hnT00Oo_hnT0ol0000<okR;YP03o`000?ndRJSo]8VX00Ko]8VX
00?o0000ojj6Zon^QZ/01?n^QZ/2o`0000CoZHJ_00?o0000oin2/onOP[<01onOP[<00ol0003oTWjj
oi9n^P03oi9n^P03o`000?mnN<;oOWS200;oOWS200Co0000oem^bomOK/_oGfk;0_l00002odaQa`06
o`000?l?BLKo026[o`0QZol0003o00RE0_l00004ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02_ooool002Kooooo0_l0000Vooooo`?o00000_ooool?o`0000GoYNkh00Co0000ok_g
konkmnoo^oO_1?l000000onlk?Coc^cYolk/j@06olk/j@03o`000?oKi=cofnCL00Co000000?odm_N
o`000?oId=001ooId=000ol0003ofL?3omW3``06omW3``Co00001OoB];/00ol0003od:Zbom2Z/P07
om2Z/P03o`000?o=XZcocJ:/00KocJ:/00?o0000olZMZOo:WJT01oo:WJT00ol0003oaiRVolNHYP08
olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@00ol0003o_hnTokn?Y009
okn?Y004o`000?nlSJ?o0000o`0000Wo^8^V00?o0000okB9Z?ndRJP02?ndRJP2o`0000?o[XJ[00?o
0000ojV6[onYQZl01OnYQZl00ol0003oWh:coin2/`07oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o
0000ogih`_mnN<800_mnN<800ol0003oGfk;oem^b`02oem^b`;o000000?oC677o`000?l?BLH00_l0
8J/01?l0003o00REo`000?l00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2_ooool002Kooooo00?o0000ooooooooool08_ooool3o`0000?ooooo0_l0000:oiOQo@;o00001onU
k_P00ol0003o^oO_o`000002o`0000;o_>cd0_l00008olk/j@Co00001?oCfmh00ol0003ofM3@omW@
d007omW@d003o`000?oI`l?ofL?300?ofL?31?l00007om:d^`03o`000?o@Z[;od:Zb00Ood:Zb00?o
0000olfR[?o=XZ`01_o=XZ`00ol0003obYfYolZMZ@08olZMZ@03o`000?o7V:KoaiRV00SoaiRV00?o
0000olBCY?o4Tj@01oo4Tj@00ol0003o`Y6Tol:AY009ol:AY003o`000?noSjCo_hnT00So_hnT00?o
0000okb=XonlSJ<00_nlSJ<2o`0000Oo^8^V00?o0000okB9Z?ndRJP02_ndRJP00ol0003o[XJ[o`00
0009ojV6[`03o`000?nOP[?oWh:c00OoWh:c00?o0000oi9n^_nBO[X00onBO[X00ol0003oOWS2ogih
`P02ogih`P0:o`000?mOK/_oGfk;oem^bol0003o;Eg@o`000?m<HLOo0000o`m9aP;o026[1?l00003
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool002Kooooo00?o0000oooo
ooooool08?ooool2o`0000Cooooo0_l00009oiOQo@;o00000onUk_P8o`0000Go_>cd00?o0000olk/
jOo>k>T01?o>k>T5o`0000Kodm_N00?o0000omW@d?oId=001ooId=000ol0003ofL?3omW3``04o`00
00;odkg400?o0000om:d^ooB];/01_oB];/00ol0003od:Zbom2Z/P06om2Z/P03o`000?o=XZcocJ:/
00OocJ:/00?o0000olZMZOo:WJT01oo:WJT00ol0003oaiRVolNHYP08olNHYP03o`000?o4TjCoa9>T
00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@00ol0003o_hnTokn?Y009okn?Y003o`000?nlSJ?o_8fS
00Co_8fS0_l00004okR;YP03o`000?ndRJSo]8VX00co]8VX0_l0000:ojV6[`03o`000?nOP[?oWh:c
00OoWh:c00?o0000oi9n^_nBO[X00onBO[X00ol0003oOWS2ogih`P02ogih`P06o`000?mOK/_oGfk;
oem^bol0003o;Eg@0ol000000ol?BLKo026[o`0QZ`03o`0000Cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0:ooooo`009_ooool00ol0003oooooooooo`0Mooooo`?o00000oooool3
o`0000;oUn7m2Ol000000onUk_So0000o`000002o`0000CoZ^Cj00?o0000okc/m?nlk?@01Onlk?@0
0ol0003oc^cYo`000005o`0000;oan7[2?oCfmh00ol0003ofM3@omW@d007omW@d0Co00001OoC_L@0
0ol0003od[Bkom:d^`06om:d^`03o`000?o@Z[;od:Zb00Ood:Zb00?o0000olfR[?o=XZ`01_o=XZ`0
0ol0003obYfYolZMZ@08olZMZ@03o`000?o7V:KoaiRV00SoaiRV00?o0000olBCY?o4Tj@01oo4Tj@0
0ol0003o`Y6Tol:AY008ol:AY003o`000?noSjCo_hnT00Wo_hnT00?o0000okb=XonlSJ<01onlSJ<2
o`000003okR;Y_l0003o]8VX00ko]8VX00?o0000ok69Zol000002_nYQZl00ol0003oWh:coin2/`07
oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o0000ogih`_mnN<800_mnN<801Ol0003oGfk;oem^bomO
K/_o000000;o;Eg@0_l000000ol?BLKo026[o`0QZ`03o`0000Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0:ooooo`009_ooool00ol0003oooooooooo`0Jooooo`?o00000oooool3
o`0000[oWmSl0_l00009oj[TnP03o`000?nlk?Co_>cd00?o_>cd1_l00006olOQj`03o`000?oCfmko
dm_N00Kodm_N00?o0000omW@d?oId=001?oId=05o`0000Oodkg400?o0000om:d^ooB];/01_oB];/0
0ol0003od:Zbom2Z/P07om2Z/P03o`000?o=XZcocJ:/00OocJ:/00?o0000olZMZOo:WJT01oo:WJT0
0ol0003oaiRVolNHYP08olNHYP03o`000?o4TjCoa9>T00Soa9>T00?o0000ol:AY?o2TJ@02?o2TJ@0
0ol0003o_hnTokn?Y009okn?Y003o`000?nlSJ?o_8fS00Wo_8fS0_l0000>okB9Z005o`000?naRJ_o
/HV[ok69Zol000002_nYQZl00ol0003oWh:coin2/`07oin2/`03o`000?nBO[[oTWjj00?oTWjj00?o
0000ogih`_mnN<800_mnN<801Ol0003oGfk;oem^bomOK/_o000000?o;Eg@00Go0000o`m9a_l08J_o
026[o`08U@02o`0000Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09ooooo`00
9_ooool00ol0003oooooooooo`0Gooooo`?o00000_ooool4o`0000?oWmSl0_l00006oioHo0;o0000
2OnZi?X2o`000003okc/m?l0003o000000?o000000?o^>3do`000?o7hN/02?o7hN/00ol0003odm_N
om?KgP06om?KgP03o`000?oId=3o000000Go00000_oAam400ol0003odkg4om>ma007om>ma003o`00
0?oB];_od[Bk00Kod[Bk00?o0000om2Z/_o@Z[801oo@Z[800ol0003ocJ:/olfR[006olfR[003o`00
0?o:WJWobYfY00SobYfY00?o0000olNHY_o7V:H02?o7V:H00ol0003oa9>TolBCY007olBCY003o`00
0?o2TJCo`Y6T00So`Y6T00?o0000okn?Y?noSj@02OnoSj@00ol0003o_8fSokb=X`0:okb=X`04o`00
0?njS:Ko0000o`0000_o]8VX00?o0000ok69ZonaRJ/00onaRJ/2o`0000WoZHJ_00?o0000oin2/onO
P[<01OnOP[<7o`000003oi9n^_l0003oOWS200?oOWS200Go0000oem^bomOK/_oGfk;o`000003obeM
d0;o00000_l08J/00ol029Go0000ooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02Oooool002Gooooo0_l0000Fooooo`?o00000_ooool3o`0000WoX]3g1_l000000onZi?[o
0000o`00000:o`0000Go^>3d0_l00009olOQj`03o`000?oCfmkodm_N00?odm_N1_l00007om77d@03
o`000?oC_LCodkg400Oodkg400?o0000om:d^ooB];/01_oB];/00ol0003od:Zbom2Z/P07om2Z/P03
o`000?o=XZcocJ:/00OocJ:/00?o0000olZMZOo:WJT00_o:WJT<o`0000GoaiRV00?o0000olBCY?o4
Tj@01oo4Tj@00ol0003o`Y6Tol:AY008ol:AY003o`000?noSjCo_hnT00Wo_hnT00?o0000okb=Xonl
SJ<02OnlSJ<00ol0003o^XbVokZ<YP02okZ<YP;o00002?ndRJP00ol0003o/HV[ok69Z`06ok69Z`03
o`000?nYQZooZHJ_00OoZHJ_00?o0000oin2/onOP[<01?l00003oiV4^`04o`000?n9P<?oRH33ohV0
``Go00000_mnN<801Ol0003oGfk;oem^bomOK/_o000000;o;Eg@00?o0000o`0n`Ol000000_l08J/2
o`0000Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0
003oooooooooo`0Booooo`?o00000_ooool3o`0000coX]3g0ol0000:ojWIn0;o00002?nhh?@00ol0
003oan7[olOQj`08olOQj`03o`000?oCfmko000000Co00000_o;d]l00ol0003odLOAom77d@07om77
d@03o`000?oC_LCodkg400Oodkg400?o0000om:d^ooB];/01ooB];/00ol0003od:Zbom2Z/P07om2Z
/P04o`000?o=XZcocJ:/olfR[0_o00001Oo8VZP00ol0003oaYFTolJEY004olJEY1;o00001oo2TJ@0
0ol0003o_hnTokn?Y00:okn?Y003o`000?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H01?njS:H0
0ol0003o]8VXokB9Z005okB9Z003o`000?naRJ_o/HV[00Oo/HV[0_l00007ojV6[`?o00002?nIQ;/0
0ol0003oRH33ohV0``03ohV0``03o`000?maN/go000000?o00000omOK//01ol0003o;Eg@obeMd?l0
003o03k1o`000?l08J/00ol00004ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2Oooool002Gooooo00?o0000ooooooooool03oooool3o`0000;ooooo0ol00008oj?:m0Oo00000onY
fOP2o`0000KoZMWh0_l00009okSPm003o`000?o7hN_oan7[00;oan7[2Ol00006ol_Bg`03o`000?oA
am7odLOA00OodLOA00?o0000om>ma?oC_L@01ooC_L@00ol0003od[Bkom:d^`07om:d^`03o`000?o@
Z[;od:Zb00;od:Zb2_l00005ol^S[`03o`000?o8VZSob9ZX00Oob9ZX00?o0000olJEY?o6UJ@02Oo6
UJ@00ol0003oaYJUolJFY@07olJFY@04o`000?o3TJ;o`i6Rol>AXPGo00000_o2TJ@00ol0003o_hnT
okn?Y009okn?Y003o`000?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H01_njS:H2o`0000Co]8VX
00?o0000ok69ZonaRJ/02_naRJ/00ol0003oZHJ_ojV6[`02ojV6[`;o00000onUQk@9oiV4^`03o`00
0?n9P<?oRH3300?oRH3300Co0000og5jcOmaN/goLG[=0ol00002oem^b`07o`000?l]GM3o;Eg@o`00
0?l0?/7o0000o`0QZ`02o`0000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`009Oooool00ol0003oooooooooo`0<ooooo`?o00000_ooool3o`0000coXl[d0ol00008ojS@
m@Ko000000?o^>3do`000?l000003Ol00004okoFj`03o`000?o;d]oobm;O00Oobm;O00?o0000om77
dOoAam401ooAam400ol0003odkg4om>ma008om>ma003o`000?oB];_od[Bk00?od[Bk2Ol00005ol^U
/P03o`000?o;Xjoobj>_00Kobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFTolJEY008olJE
Y003o`000?o6UZGoaYJU00OoaYJU00?o0000ol>AX_o3TJ801oo3TJ84o`0000[o_hnT00?o0000okb=
XonlSJ<02OnlSJ<00ol0003o^XbVokZ<YP08okZ<YP;o000000?o]8VXo`000?naRJ/03OnaRJ/01?l0
003oZHJ_o`000?l00006ojF7]003o`000?nIQ;_oVHBk00KoVHBk00?o0000ohV0`on9P<<00on9P<<0
0ol0003oLG[=og5jc@02og5jc@?o000000SoGfk;o`000?l]GM3o;Eg@o`000?l0?/7o0000o`0QZ`;o
00001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo000Uooooo`03o`00
0?oooooooooo00Wooooo0ol00002ooooo`?o00001OnTao85o`0000?oXl[d0_l0000<ojS@m@?o0000
2OnceO82o`0000Wo_mK[0_l00009ol_Bg`03o`000?oAam7odLOA00OodLOA00?o0000om>ma?oC_L@0
2?oC_L@00ol0003od[Bko`000004o`0000?oc:fj00?o0000ol^U/_o;YK801oo;YK800ol0003obj>_
ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Oob9ZX00?o0000olJEY?o6UJ@02Oo6UJ@00ol0003oaYJU
olJFY@07olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ401?l00005okn?Y003o`00
0?nlSJ?o_8fS00Wo_8fS00?o0000okZ<Y_njS:H02onjS:H2o`0000ko/HV[0_l00009ojF7]003o`00
0?nIQ;_oVHBk00KoVHBk00?o0000ohV0`on9P<<00on9P<<00ol0003oLG[=og5jc@02og5jc@03o`00
0?m8LMOo000000;o00000_l]GM001?l0003o03k1o`000?l08J/2o`0000Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`06ooooo`?o0000
0oooool2o`0000goY<Ob0ol00004ojS@m@;o00001_nXd?D2o`0000_o/mGb00?o0000okoFjonoe^/0
2?noe^/00ol0003obm;Ool_Bg`08ol_Bg`03o`000?oAam7odLOA00OodLOA00?o0000om>ma?oC_L@0
0_oC_L@9o`0000Ooc:fj00?o0000ol^U/_o;YK802?o;YK800ol0003obj>_ol^S[`06ol^S[`03o`00
0?o8VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@07olJFY@03o`00
0?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ401Oo1SZ43o`0000;o_hnT00?o0000okb=XonlSJ<0
2?nlSJ<00ol0003o^XbVokZ<YP0<okZ<YP04o`000?ngS:So0000o`0000_o/HV[00Co0000ojj:/?n^
R[3o[XZ`2OnUQk@2o`0000OoVHBk00?o0000ohV0`on9P<<00on9P<<00ol0003oLG[=og5jc@02og5j
c@03o`000?m8LMOoB77G00;o00000_l]GM001?l0003o03k1o`000?l08J/2o`0000Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`08ooooo`009?ooool3o`0000Cooooo0ol00004oooo
o`;o00003OnTao83o`0000SoYlSa1_l00002ok?ElPCo00001OnceO82o`0000[o_mK[00?o0000ol_B
goo;d]l02?o;d]l00ol0003odLOAom77d@02om77d@_o00001_o<^/P00ol0003oc:fjolb]^P06olb]
^P03o`000?o;YK;objFb00SobjFb00?o0000ol^S[oo;Xjl01oo;Xjl00ol0003ob9ZXolRJZ008olRJ
Z003o`000?o6UJCoaYFT00SoaYFT00?o0000olJFYOo6UZD01oo6UZD00ol0003o`i6Rol>AXP08ol>A
XP03o`000?o1SZ7o`HjQ00So`HjQ1?l00009okb=X`03o`000?njS:Ko^XbV00_o^XbV00?o0000okN<
Z?ngS:P00_ngS:P00ol0003o/HV[ok69Z`07ok69Z`03o`000?n^R[3o[XZ`00?o[XZ`00?o0000ojF7
]?nUQk@01onUQk@00ol0003oVHBkoiV4^`05oiV4^`03o`000?n9P<?oRH3300?oRH3300?o0000og5j
cOmaN/d00_maN/d01?l0003oB77GodQaeom8LML2o`000003obeMd?l0003o03k100?o00001Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Tooooo`04o`000?oooooooooo
ooooo`?o00001?ooool3o`0000SoY<C`1ol0000<ojO8l@?o00002?n^c?05o`000003okoFjol0003o
000001Wo00001?o8`=800ol0003oc;[8olbjb009olbjb003o`000?o<[K[oc:fj00Ooc:fj00?o0000
ol^U/_o;YK801oo;YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Sob9ZX00?o0000
olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@08olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000
ol6>XOo1SZ402Oo1SZ400ol0003o`92Sol2@X`03o`0000Go_8fS00?o0000okZ<Y_njS:H02onjS:H0
0ol0003o]hbXokN<Z004okN<Z0;o00001_naRJ/00ol0003o[XZ`ojj:/005ojj:/003o`000?nUQkCo
YHNd00OoYHNd00?o0000oiV4^onIQ;/01OnIQ;/00ol0003oRH33ohV0``03ohV0``03o`000?maN/go
LG[=00;oLG[=00Co0000odQaeom8LMOoB77G0_l000000ol]GM3o0000o`0n`@03o`0000Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`006Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo1?l00005ooooo`;o00003?nTa?03o`0000GoY/C_1Ol00003ojO8l@;o00002on^
c?03o`0000_o]lk[00?o0000ol;7goo2aml02?o2aml00ol0003ob<3BolS0dP08olS0dP03o`000?o<
^/Soc;[800Woc;[800?o0000olb]^_o<[KX01oo<[KX00ol0003objFbol^U/P08ol^U/P03o`000?o;
Xjoobj>_00Oobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFTolJEY008olJEY003o`000?o6
UZGoaYJU00OoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o`HjQol6>X@09ol6>X@03o`000?o0
T:?o`92S00Co`92S0ol00002okb=X`03o`000?njS:Ko^XbV00[o^XbV00?o0000okN<Z?ngS:P01ong
S:P2o`0000?o/HV[00?o0000ojj:/?n^R[001on^R[02o`0000SoYHNd00?o0000oiV4^onIQ;/01OnI
Q;/00ol0003oRH33ohV0``03ohV0``03o`000?maN/goLG[=00;oLG[=00Co0000odQaeom8LMOoB77G
1?l000001?l0?/7o0000o`000?l00004ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02?ooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00002oooool5o`0000?o
Y<C`0_l0000=ojK4k`?o00001?n^c?02o`0000Go[/c`0_l0000<okO>j`;o00002_o2aml00ol0003o
b<3BolS0dP08olS0dP03o`000?o<^/Soc;[800Woc;[800?o0000olb]^_o<[KX01oo<[KX00ol0003o
bjFbol^U/P08ol^U/P03o`000?o;Xjoobj>_00Oobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003o
aYFTolJEY008olJEY003o`000?o6UZGoaYJU00SoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o
`HjQol6>X@09ol6>X@03o`000?o0T:?o`92S00Oo`92S0ol0000;okZ<YP03o`000?ngS:So]hbX00[o
]hbX00?o0000ok69Zol000003?n^R[000ol0003oYHNdojF7]006ojF7]003o`000?nIQ;_oVHBk00;o
VHBk1_l00003ohV0``03o`000?maN/goLG[=00;oLG[=00Ko0000odQaeom8LMOoB77Go`000?l5G=@2
o`000004o`0n`Ol0003o0000o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`08ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool03Ooo
ool3o`0000coY/C_0ol00009ojO8l@Go00000_ngc^/00ol0003o]lk[okO>j`08okO>j`03o`000?o2
amoo`/OO00Wo`/OO00?o0000olS0d_o8`=802?o8`=800ol0003oc;[8olbjb009olbjb003o`000?o<
[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK802?o;YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8
VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@00ol0003oaYJUolJFY@07olJFY@03o`000?o3
TJ;o`i6R00Wo`i6R00?o0000ol6>XOo1SZ402?o1SZ400ol0003o`92Sol2@X`09ol2@X`03o`000?nn
SZCo000000;o00002?njS:H00ol0003o]hbXokN<Z00;okN<Z0;o00003On^R[000ol0003oYHNdojF7
]004ojF7]0Ko00001OnCR<@00omoQLoo0000o`000003o`0000CoLG[=00Go0000odQaeom8LMOoB77G
o`000002o`ELe004o`000?l0?/7o0000o`0000Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`006Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool05Oooool6o`0000goYlSa0_l00005ojk5j`Ko00000ongc^/00ol0003o`/OOol;7g`09ol;7g`03
o`000?o8`=;ob<3B00Sob<3B00?o0000olbjb?o<^/P02_o<^/P00ol0003oc:fjolb]^P07olb]^P03
o`000?o;YK;objFb00SobjFb00?o0000ol^S[oo;Xjl01oo;Xjl00ol0003ob9ZXolRJZ008olRJZ003
o`000?o6UJCoaYFT00WoaYFT00?o0000olJFYOo6UZD01oo6UZD00ol0003o`i6Rol>AXP08ol>AXP03
o`000?o1SZ7o`HjQ00Wo`HjQ00?o0000ol2@Xoo0T:<02?o0T:<00ol0003o_XjTokj>Y003okj>Y0;o
00001OnjS:H00ol0003o]hbXokN<Z00<okN<Z004o`000?neS:_o0000o`0000co[XZ`00?o0000ojF7
]?nUQk@00ol00004oj2:_0SoThS41?moQLl4o`0000;oLG[=00Go0000odQaeom8LMOoB77Go`000002
o`ELe0Co00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo000Ioooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Looooo`Ko00000onWb?42
o`0000go[/G[0ol000000oo2amoo0000o`000003o`0000Go`/OO00?o0000olS0d_o8`=802?o8`=80
0ol0003oc;[8olbjb00:olbjb003o`000?o<[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK801oo;YK80
0ol0003obj>_ol^S[`08ol^S[`03o`000?o8VZSob9ZX00Sob9ZX00?o0000olJEY?o6UJ@02?o6UJ@0
0ol0003oaYJUolJFY@07olJFY@03o`000?o3TJ;o`i6R00Wo`i6R00?o0000ol6>XOo1SZ402?o1SZ40
0ol0003o`92Sol2@X`09ol2@X`03o`000?nnSZCo_XjT00Go_XjT0ol000000onjS:Ko0000okN<Z00=
okN<Z003o`000?neS:_o]Hb[00;o]Hb[00?o0000ojj:/?n^R[002On^R[03o`0000SoX8Zl00?o0000
oi>8a?nCR<@01OnCR<@00ol0003oOhG?ogn5c`03ogn5c`03of22g?l0003o000000;o00000om8LML0
1?l0003o1EcDo`ELe?l5G=@3o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`08ooooo`006Oooool01Ol@413ooooooooooooooooo410@00_ooooo0_l0000Rooooo`?o00003On^
aN/3o`0000So]L;T5_l00006olbjb003o`000?o<[K[oc:fj00Soc:fj00?o0000ol^U/_o;YK802?o;
YK800ol0003obj>_ol^S[`07ol^S[`03o`000?o8VZSob9ZX00Wob9ZX00?o0000olJEY?o6UJ@02?o6
UJ@00ol0003oaYJUolJFY@07olJFY@03o`000?o3TJ;o`i6R00So`i6R00?o0000ol6>XOo1SZ402Oo1
SZ400ol0003o`92Sol2@X`08ol2@X`03o`000?nnSZCo_XjT00Wo_XjT0_l0000=okN<Z003o`000?ne
S:_o]Hb[00Co]Hb[0_l00007ojj:/0;o00000on[S;H00ol0003oX8Zloj2:_006oj2:_0;o00001_nC
R<@2o`0000CoOhG?0omPP]`3o`0000;oB77G00Co0000o`ELe?l5G=Co1EcD0ol00004ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01oooool001Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0=ooooo`03o`000?oooooooooo02Gooooo1Ol00003ojk5j`;o00003?ne`^@2o`0000[o^lGQ
00?o0000ol6fcoo1]/l01_o1]/lQo`0000Gobj>_00?o0000olRJZ?o8VZP02?o8VZP00ol0003oaYFT
olJEY008olJEY003o`000?o6UZGoaYJU00SoaYJU00?o0000ol>AX_o3TJ802?o3TJ800ol0003o`HjQ
ol6>X@08ol6>X@03o`000?o0T:?o`92S00Wo`92S00?o0000okj>Y?nnSZ@02OnnSZ@01?l0003o_8fT
o`000?l0000:okN<Z003o`000?neS:_o]Hb[00Oo]Hb[0_l00004ojj:/003o`000?n[S;KoZhbf00Co
Zhbf00?o0000oj2:_?nPR[`01onPR[`00ol0003oThS4oi>8a005oi>8a003o`000?moQLooOhG?00;o
OhG?00?o0000of22g?mPP]`00_mPP]`2o`000003odQaeol0003o1EcD00;o1EcD0_l00004ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool001Wooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0>ooooo`03o`000?oooooooooo02Wooooo0ol0000=okG2i003o`000?nkaN7o^lGQ00So
^lGQ0_l0000<ol6fc`03o`000?o4[/Coa:k400Woa:k400?o0000olNaa?o7/L@02Oo7/L@00ol0003o
aJ:eolFR]@03olFR]@_o00001Oo8VZP00ol0003oaYFTolJEY008olJEY003o`000?o6UZGoaYJU00Oo
aYJU00?o0000ol>AX_o3TJ802Oo3TJ800ol0003o`HjQol6>X@08ol6>X@03o`000?o0T:?o`92S00So
`92S00?o0000okj>Y?nnSZ@02OnnSZ@00ol0003o_8fTokb=Y002okb=Y0;o00001ongS:P00ol0003o
]Hb[okF<Z`0:okF<Z`04o`000?n^R[3o0000o`0000SoZhbf0_l00008oj2:_0;o00001_nCR<@00ol0
003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L00;oH8;L00Co;7OSo`000?l0003o00000ol5G=@2
o`0000Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`00;Oooool00ol0
003oooooooooo`0^ooooo`Go00000one`^@2o`0000[o^lGQ00?o0000ol6fcoo1]/l02oo1]/l00ol0
003oa:k4olB^a009olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR]Oo5X[D02?o5X[D00ol0
003oa9b^olBL[P04olBL[QGo00001Oo6UZD00ol0003o`i6Rol>AXP08ol>AXP03o`000?o1SZ7o`HjQ
00So`HjQ00?o0000ol2@Xoo0T:<02Oo0T:<00ol0003o_XjTokj>Y009okj>Y003o`000?nlSJCo_8fT
00Co_8fT0_l00004okN<Z003o`000?neS:_o]Hb[00co]Hb[0_l0000;oj^<]P03o`000?nPR[coX8Zl
00OoX8Zl00?o0000oi>8a?nCR<@01?nCR<@00ol0003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L
00;oH8;L00Co0000obaghol0003o00000ol5G=@2o`0000Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`07ooooo`00;_ooool2o`0003?ooooo0ol000000onkaN7o0000o`000003o`00
00Go^lGQ00?o0000ol6fcoo1]/l02oo1]/l00ol0003oa:k4olB^a009olB^a003o`000?o7/LCoak74
00Woak7400?o0000olFR]Oo5X[D02?o5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a
00Soaj6a00?o0000olBHZ_o4V:X00oo4V:X8o`0000So`i6R00?o0000ol6>XOo1SZ402?o1SZ400ol0
003o`92Sol2@X`08ol2@X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@01onlSJ@2o`00
0003okN<Z?l0003o]Hb[00ko]Hb[00?o0000ok>?/Ol000002on[S;H2o`0000SoX8Zl00?o0000oi>8
a?nCR<@01?nCR<@00ol0003oOhG?ogn5c`02ogn5c`03o`000?mPP]coH8;L00;oH8;L0_l000000ol/
Mn?o0000o`000002o`ELe0;o00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo000`ooooo`03o`000?oooooooooo03Wooooo1Ol000000oo1]/oo0000o`00000:ol6fc`03
o`000?o4[/Coa:k400Woa:k400?o0000olNaa?o7/L@02Oo7/L@00ol0003oaJ:eolFR]@08olFR]@03
o`000?o4W:koa9b^00Woa9b^00?o0000olNQ/Oo7XK402?o7XK400ol0003oa9RZolBHZP08olBHZP04
o`000?o2TjGo`Y>Uol:CY@Go00000oo3TJ800ol0003o`HjQol6>X@07ol6>X@03o`000?o0T:?o`92S
00Wo`92S00?o0000okj>Y?nnSZ@02OnnSZ@00ol0003o_8fTokb=Y009okb=Y0;o00003_neS:/01?l0
003o/hnaok>?/OncSk42o`0000_oZhbf00?o0000oj2:_?nPR[`01?nPR[`<o`0000;oOhG?00?o0000
of22g?mPP]`00omPP]`00ol0003o;7OSobagh`02o`000003o`ELe?l0003ooooo00?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`00<Oooool00ol0003oooooooooo`10oooo
o`Ko00000oo1]/l00ol0003oa:k4olB^a009olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR
]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P08olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBH
Z_o4V:X01oo4V:X00ol0003o`Y>Uol:CY@07ol:CY@So00001Oo1SZ400ol0003o`92Sol2@X`08ol2@
X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@02_nlSJ@01?l0003o^hnYo`000?l0000;
okF<Z`03o`000?ncSk7o/hna00Co/hna0_l0000:oj^<]P03o`000?nPR[coX8Zl00?o00001?nLT<H7
ohb@d@03ogB@gol0003o000000;o00001OmPP]`00ol0003o;7OSobagh`04o`0000Cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`07ooooo`00<_ooool00ol0003oooooooooo`15oooo
o`?o000000?oa:k4o`000?l000000ol00005olB^a003o`000?o7/LCoak7400Woak7400?o0000olFR
]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a00Soaj6a00?o0000olBH
Z_o4V:X02?o4V:X00ol0003o`Y>Uol:CY@09ol:CY@03o`000?o4V:_oa9R[00?oa9R[1ol00009ol2@
X`03o`000?nnSZCo_XjT00Wo_XjT00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnYok^?Z@02ok^?
Z@?o00001oneS:/00ol0003o/hnaok>?/@07ok>?/@03o`000?n[S;KoZhbf00OoZhbf0ol00008oib@
aP03o`000?n<T=7oS93A00CoS93A00?o0000ogB@gomdT=l01?l00003of22g003o`000?l/Mn?o;7OS
00Co00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo000cooooo`;o
0000C_ooool8o`0000Soak7400?o0000olFR]Oo5X[D02Oo5X[D00ol0003oa9b^olBL[P09olBL[P03
o`000?o7XK7oaj6a00Soaj6a00?o0000olBHZ_o4V:X02?o4V:X00ol0003o`Y>Uol:CY@09ol:CY@03
o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT00ol00005ol2@X`03o`000?nnSZCo_XjT00[o
_XjT00?o0000okb=Y?nlSJ@02?nlSJ@00ol0003o^hnYok^?Z@06ok^?Z@;o00001?neS:/00ol0003o
/hnaok>?/@09ok>?/@;o00001?n[S;H3o`0000?oYi6n2OnLT<H00ol0003oS93Aohb@d@04ohb@d@;o
00000omdT=l00om>S^co0000o`000003o`0000?o;7OS00?o0000o`m[gOl000001?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05?ooooo
1Ol00002olNaa003o`000?o5X[GoaJ:e00WoaJ:e00?o0000olBL[_o4W:h02Oo4W:h00ol0003oaj6a
olNQ/@09olNQ/@03o`000?o4V:[oa9RZ00Soa9RZ00?o0000ol:CYOo2TjD02Oo2TjD00ol0003oa9R[
olBHZ`07olBHZ`03o`000?o1UJWo`IFY00Co`IFY0ol00002ol2@X`03o`000?nnSZCo_XjT00Wo_XjT
00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnYok^?Z@08ok^?Z@;o000000?o]Hb[o`000?ncSk40
3OncSk401?l0003oZhbfo`000?l00008ojNA_P03o`000?nLT<KoW93600GoW9360_l00006ohb@d@04
o`000?mdT=ooM93OogB@g`;o00000_m>S^`3o`0000;o;7OS0_l00004ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Eoooool5o`0000Wo
aJ:e00?o0000olBL[_o4W:h02?o4W:h00ol0003oaj6aolNQ/@09olNQ/@03o`000?o4V:[oa9RZ00So
a9RZ00?o0000ol:CYOo2TjD02Oo2TjD00ol0003oa9R[olBHZ`08olBHZ`03o`000?o1UJWo`IFY00Oo
`IFY1?l0000:okj>Y003o`000?nlSJCo_8fT00So_8fT00?o0000ok^?ZOnkSjT02onkSjT00ol0003o
/hnaok>?/@0>ok>?/@03o`000?nWTKkoYi6n00WoYi6n0_l00007oib@aP03o`000?n<T=7oS93A00Co
S93A0_l00003ogB@g`;o00000om>S^`3o`000003obaghol0003ooooo00?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`06ooooo`00=oooool00ol0003oooooooooo`1Kooooo`Go0000
0oo5X[D00ol0003oa9b^olBL[P09olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBHZ_o4V:X0
2?o4V:X00ol0003o`Y>Uol:CY@08ol:CY@03o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT0
2Oo1UJT00ol0003o_i2Uokn@Y@04o`0000Go_XjT00?o0000okb=Y?nlSJ@02OnlSJ@00ol0003o^hnY
ok^?Z@0;ok^?Z@03o`000?niTJgo000000;o00002OncSk42o`0000?o/9:h0_l0000:ojNA_P;o0000
1_nLT<H00ol0003oS93Aohb@d@05ohb@d@03o`000?mdT=ooM93O00;oM93O00?o0000odj>k?m>S^`0
0_m>S^`4o`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`00>?oo
ool2o`00063ooooo2Ol00005olBL[P03o`000?o7XK7oaj6a00Woaj6a00?o0000olBHZ_o4V:X02?o4
V:X00ol0003o`Y>Uol:CY@09ol:CY@03o`000?o4V:_oa9R[00Ooa9R[00?o0000ol6EZOo1UJT02Oo1
UJT00ol0003o_i2Uokn@Y@05okn@Y@?o00000_nnSZ@00ol0003o_8fTokb=Y008okb=Y003o`000?nk
SjWo^hnY00_o^hnY00?o0000okVA[OniTJd00oniTJd2o`0000Ko/hna00?o0000ok2B^?n`T[P01On`
T[P00ol0003oYi6nojNA_P09ojNA_P03o`000?nLT<KoW93600CoW93600?o0000ohb@dOn<T=401On<
T=400ol0003oM93OogB@g`02ogB@g`;o00001?m>S^`00ol0003o>8O[o`000004ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01_ooool003[ooooo00?o0000ooooooooool0I_ooool8
o`0000Soaj6a00?o0000olBHZ_o4V:X02Oo4V:X00ol0003o`Y>Uol:CY@08ol:CY@03o`000?o4V:_o
a9R[00Soa9R[00?o0000ol6EZOo1UJT02Oo1UJT00ol0003o_i2Uokn@Y@08okn@Y@Go00001onlSJ@0
0ol0003o^hnYok^?Z@0;ok^?Z@03o`000?niTJgo^I6]00Ko^I6]0ol000000oncSk7o0000o`000009
ok2B^0;o00002OnWTKhEo`000003ogB@gol0003oCXk/00?oCXk/0ol00003ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool003_ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`02ooooo`Go00000oo7XK400ol0003oa9RZolBHZP08olBHZP03o`000?o2TjGo`Y>U
00Wo`Y>U00?o0000olBHZoo4V:/01oo4V:/00ol0003o`IFYol6EZ@09ol6EZ@03o`000?noT:Go_i2U
00[o_i2U00Co0000ol2G[Oo0Ujgo`9N]1Ol00002okb=Y003o`000?nkSjWo^hnY00[o^hnY00?o0000
okVA[OniTJd02_niTJd00ol0003o/9:hok2B^00;ok2B^0;o00001?nWTKh3o`0000?oXiS900?o0000
oiNIe?nGVM@01?nGVM@00ol0003oQIcRohFLhP05ohFLhP03o`000?mZX?3oJZ3`00Oo000000?oCXk/
o`000?l000000oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000loooo
o`;o0000J?ooool00ol0003oooooooooo`07ooooo`Go00002Oo4V:X00ol0003o`Y>Uol:CY@08ol:C
Y@03o`000?o4V:_oa9R[00Soa9R[00?o0000ol6EZOo1UJT02Oo1UJT00ol0003o_i2Uokn@Y@09okn@
Y@03o`000?o0Ujgo`9N]00Oo`9N]1?l0000:ok^?Z@03o`000?niTJgo^I6]00_o^I6]00Co0000okRB
/?l0003o00003?n`T[P01?l0003oYi6no`000?l00008oj>Hb@03o`000?nGVMCoUiWD00CoUiWD0_l0
0006ohFLhP03o`000?mZX?3oJZ3`00;oJZ3`0_l000000omIW?;o0000o`000002o`0000?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`00?_ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00cooooo0ol00005olBHZP03o`000?o2TjGo`Y>U00So`Y>U00?o0000
olBHZoo4V:/02?o4V:/00ol0003o`IFYol6EZ@09ol6EZ@03o`000?noT:Go_i2U00Wo_i2U00?o0000
ol2G[Oo0Ujd02Oo0Ujd00ol0003o_YN_okjG[`03o`0000Ko^hnY00?o0000okVA[OniTJd02oniTJd0
0ol0003o^9:`okRB/002okRB/0;o00002on`T[P00ol0003oXiS9oj>Hb@09oj>Hb@;o00001_nGVM@0
0ol0003oQIcRohFLhP04ohFLhP;o00001?mZX?03o`000003oeVLl_l0003ooooo00?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`00?oooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo00oooooo0ol00002olBHZP03o`000?o2TjGo`Y>U00So`Y>U00?o0000olBH
Zoo4V:/01oo4V:/00ol0003o`IFYol6EZ@0:ol6EZ@03o`000?noT:Go_i2U00Wo_i2U00?o0000ol2G
[Oo0Ujd02?o0Ujd00ol0003o_YN_okjG[`04okjG[`?o00000_nkSjT00ol0003o^I6]okVA[@0;okVA
[@03o`000?nhT[3o^9:`00Go^9:`0_l00005ok2B^0?o00000on]Ul02o`0000[oXiS90_l00005oiNI
e0;o00001_n5W>82o`0000GoJZ3`0ol00003ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01Oooool0043ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Boooooa;o
00001Oo4V:/00ol0003o`IFYol6EZ@0:ol6EZ@03o`000?noT:Go_i2U00So_i2U00?o0000ol2G[Oo0
Ujd02?o0Ujd00ol0003o_YN_okjG[`08okjG[`?o00003?niTJd00ol0003o^9:`okRB/008okRB/0;o
000000?o/9:ho`000?l000002?n]Ul02o`0000[oXiS900?o0000oiNIe?nGVM@01?nGVM@2o`0000Ko
QIcR00?o0000ofZPl?mZX?001?mZX?02o`0000?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`00@Oooool2o`0006?ooooo00?o0000ooooooooool09?ooool6o`0000_o`IFY
00?o0000okn@YOnoT:D02?noT:D00ol0003o`9N]ol2G[@09ol2G[@03o`000?nnUjoo_YN_00Wo_YN_
00?o0000okbD[Ol000000_l00008okVA[@03o`000?nhT[3o^9:`00_o^9:`00?o0000ojfG`?n]Ul00
2_n]Ul02o`0000OoXiS96_l00003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1Oooool004?ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Zooooo`?o00002?o1
UJT00ol0003o_i2Uokn@Y@07okn@Y@03o`000?o0Ujgo`9N]00Wo`9N]00?o0000okjG[onnUjl02Onn
Ujl00ol0003o_9B]okbD[@03okbD[@;o00001OniTJd00ol0003o^9:`okRB/00:okRB/004o`000?nf
V;[o]YRjokJH^P;o00002on]Ul02o`0000;oXiS90ol00004oinReP03o`000?nBY^?oTZKS00GoTZKS
00?o0000oh2/lOn0[?401?n0[?43o`0000?oM:cd00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo0014ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0;Oooool3o`0000Co`IFY00?o0000okn@YOnoT:D02?noT:D00ol0003o`9N]ol2G
[@08ol2G[@03o`000?nnUjoo_YN_00Wo_YN_00?o0000okbD[OnlU:d01_nlU:d3o`000003okVA[Ol0
003o^9:`00_o^9:`00?o0000okJH^_nfV;X01?nfV;X2o`0000_o[IO00_l00009oinReP?o00001_nB
Y^<2o`0000GoP:ca0_l00002ogB/m005o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`05ooooo`00AOooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo033ooooo0ol0
00000oo1UJWo0000okn@Y@08okn@Y@03o`000?o0Ujgo`9N]00So`9N]00?o0000okjG[onnUjl02_nn
Ujl00ol0003o_9B]okbD[@09okbD[@03o`000?nhT[3o^9:`00[o^9:`00?o0000okJH^_nfV;X01onf
V;X2o`0000Go[IO00ol00003ojZOc0;o00002_nOX]H2o`0000KoTZKS0ol00004oh2/l@?o00001?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool0
0ol0003oooooooooo`0cooooo`ko00002?o0Ujd00ol0003o_YN_okjG[`09okjG[`03o`000?nlU:go
_9B]00[o_9B]00?o0000okbL^?nlW;P00ol00006okRB/003o`000?nfV;[o]YRj00[o]YRj0_l00000
0on]Ul3o0000o`000009ojZOc0?o00002?nOX]H2o`0000CoTZKS0_l000000onBY^?o0000o`000004
o`000003oh2/lOl0003ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04
ooooo`00B?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo047ooooo1Ol00002ol2G
[@03o`000?nnUjoo_YN_00[o_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o_9bhokbL^004okbL
^0?o00000_nhT[000ol0003o]YRjokJH^P0=okJH^P03o`000?nZWlcoZYo<00coZYo<0ol00004oinR
eP03o`000?nOX]KoWj;F00Co00001On?]O03o`0000;oQkKd00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0A_ooool4o`0000[o_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o
_9bhokbL^008okbL^0;o00003_nfV;X00ol0003o/j35ok>Pa@02ok>Pa@?o00003?nZWl`4o`0000Go
W:kT0_l00008ohnel0;o000000?oQkKdo`000?ooool00oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Cooooo001:ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
B_ooool4o`0000Go_YN_00?o0000okbD[OnlU:d02OnlU:d00ol0003o_9bhokbL^008okbL^003o`00
0?njXKoo^Z6o00;o^Z6o1?l00006okJH^P;o00002?ncX<D3o`0000?oZYo<1?l00004ojJZf@;o0000
2?nL[^@2o`0000OoSkG`0ol00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool004_ooooo0_l0001Iooooo`03o`000?oooooooooo04kooooo0ol00002okjG[`03o`000?nl
U:go_9B]00So_9B]00?o0000okbL^?nlW;P02?nlW;P00ol0003o^Z6ookZQ_`07okZQ_`?o00000_nf
V;X00ol0003o/j35ok>Pa@0;ok>Pa@?o00002onVZ]T2o`0000OoW:kT0ol00004ohnel004o`000?n?
]O3oSkG`o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`00COoo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05;ooooo1ol00005okbD[@03o`000?nl
W;So_9bh00So_9bh00?o0000okZQ_onjXKl02onjXKl2o`0000go/j3500Co0000ok6VcOnaY/go/JK=
0ol0000:ojJZf@?o00001?nL[^@00ol0003oW:kToib^i004o`0000CoTkcc00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo001>ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0FOooool5o`000003okbL^?l0003o000000;o00001Onl
W;P00ol0003o^Z6ookZQ_`0;okZQ_`03o`000?nhXL7o^:7100;o^:710ol00006ok>Pa@;o00001ona
Y/d3o`0000[oYZ[I1?l00007oiVkk`Ko00000oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo001?ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0Hoooool5
o`0000co^Z6o0_l00008okRQ`@?o00000_ncX<D00ol0003o/JK=ok6Vc@0:ok6Vc@?o00000_nVZ]T3
o`0000GoXkGU0ol0000:oiVkk`;o00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo001@ooooo`;o0000Doooool00ol0003oooooooooo`1Zooooo`?o00001_njXKl00ol0
003o^:71okRQ`@0;okRQ`@;o00004?naY/d2o`0000_oXkGU0ol00003oiVkk`?o00000_nL`?400ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool005;o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1]ooooo`?o00000_njXKl00ol0003o
^:71okRQ`@09okRQ`@?o00001One[M45o`0000?o/JK=0ol00005ojbaf`Go00002?nS]ND4o`0000Go
W<3a00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo001Cooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0L?ooool2o`0000?o^:710_l00005okRQ`@;o
00003One[M43o`0000go[;7K1Ol00007oj6nkPKo00001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo001Dooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
Moooool5o`0000co]JgA0ol00004ok2dg0Go00000on//M/3o`0000KoYk_X1Ol00007oj6nkP;o0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo001Eooooo`;o0000C_oo
ool00ol0003oooooooooo`1oooooo`Go00000_ne[M42o`0000co/;CL0ol0000>ojNkj0Go00001?nP
`_000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool005Oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`24ooooo`;o00003?n`]=`2
o`0000Go[KSQ1Ol00003ojNkj0?o00001_nV_n`6o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`00F?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
08Wooooo1Ol00002ok2dg0;o00003?n]^>43o`0000koY[o/0_l00003ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`2>ooooo`;o00002_n]^>43o`0000KoYl3/1Ol00003ojJok0?o00000_nS`o000ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool005[ooooo
0_l00019ooooo`03o`000?oooooooooo09Gooooo1Ol0000>ojO0k0Go00001?nS`o000ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool005cooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`2Looooo`Go00000onW`>`3o`0000KoYL;^1_l0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool005gooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`2Qooooo`?o00003_nU`^h2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`00G_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo0:Sooooo2?l00003ojG4k`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool005oooooo0_l00014ooooo`03o`000?oooooooooo0:oooooo1_l00004ooooo`03o`000?oooooo
000000Cooooo001Qooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0]?ooool2o`00
00?ooooo00Co0000oooooooooooo00000oooool006;ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`2jooooo`03o`000?oooooo000000?ooooo001Sooooo`;o0000@?ooool00ol0003o
ooooooooo`2kooooo`;o00000oooool006Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`2jooooo`?o00000oooool006Kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`2fooooo`Co00001_ooool006Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2b
ooooo`Co00002_ooool006Sooooo0_l0000kooooo`03o`000?oooooooooo0:kooooo1?l0000>oooo
o`00J_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0:_ooooo0ol0000Booooo`00
Joooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Oooooo1?l0000Eooooo`00K?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:?ooooo1?l0000Iooooo`00KOooool2
o`0003Kooooo00?o0000ooooooooool0Woooool4o`0001gooooo001_ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0Voooool4o`00027ooooo001`ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0V?ooool4o`0002Gooooo001aooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0U?ooool4o`0002Wooooo001booooo`;o0000<?ooool00ol0003ooooooooo
o`2Aooooo`?o0000;Oooool007Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2=
ooooo`Co0000<?ooool007Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`29oooo
o`Co0000=?ooool007Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`25ooooo`Co
0000>?ooool007Oooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo1?l0000looooo`00NOoo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07gooooo1?l00010ooooo`00N_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo1?l00014ooooo`00Noooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo0ol00018ooooo`00O?ooool2o`0002Ko
oooo00?o0000ooooooooool0L_ooool4o`0004_ooooo001nooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0K_ooool4o`0004oooooo001oooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0J_ooool4o`0005?ooooo0020ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0I_ooool4o`0005Oooooo0021ooooo`;o00008Oooool00ol0003oooooooooo`1Roooo
o`Co0000Foooool008?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Nooooo`Co
0000Goooool008Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`?o0000
Hoooool008Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000I_oo
ool008Kooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001Zooooo`00R?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001^ooooo`00ROooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04_ooooo1?l0001booooo`00R_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Oooooo1?l0001fooooo`00Roooool2o`0001Oooooo00?o
0000ooooooooool0@oooool4o`0007[ooooo002=ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@?ooool3o`0007kooooo002>ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0??ooool4o`00087ooooo002?ooooo`;o00004oooool00ol0003oooooooooo`0hooooo`Co
0000QOooool0097ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`Co0000
ROooool009;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000SOoo
ool009?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`Co0000TOooool0
09Cooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo1?l0002Eooooo`00U_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo0ol0002Iooooo`00Uoooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Looooo`00V?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01kooooo1?l0002Pooooo`00VOooool2o`0000Sooooo00?o0000
ooooooooool06_ooool4o`000:Cooooo002Kooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool4o`000:Sooooo002Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:cooooo002Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;3ooooo002Nooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000]?oo
ool00:3ooooo00Co0000oooooooooooo00002Oooool4o`000;Oooooo002Qooooo`03o`000?oooooo
000000Gooooo1?l0002kooooo`00X_ooool2o`000003ooooool0003o000000;o0000_oooool00:?o
oooo0_l00033ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Koooool01OlQ8B7o0000o`000?m4A4CogMgM07Wooooo00Go8B4Qo`000?l0
003oA4A4omgMg@1fooooo`00L_ooool00omgMgOo<S8booooo`1kooooo`03ogMgMolb<S;ooooo07Go
oooo001cooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0M?ooool004Oooooo00Oo
V9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool5o`0000;ooooo00KoV9RHo`000?l0
003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEE
o`000?l@413oc<c<o`0000?ooooo00OoV9RHo`000?l0003oMgMgo`000?l@413ooooo00Go00000ooo
ool02?nHV9So0000o`000?mgMgOo410@o`000?oooooo410@1Ol00005ooooo`06onk^k_mEEEGo0000
o`000?nHV9So00000_l@4105o`0000Cooooo00KoV9RHo`000?l0003oMgMgo`000?l@4102o`0000;o
oooo00Co0000oooooooooooo00000_l@4102o`000007ooooool0003o0000oa0@4?ooooook^k^oeEE
E@02o`000005odA4A?nj^[[ooooooooooonHV9P00_l000000omgMgOo410@o`000002ooooo`07onk^
k_mEEEGo0000o`000?nHV9So0000oa0@4005ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0ooo
ool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o000000;ooooo00Oo
0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2
o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooooooo410@oc8b
<P;o000000?o410@ojVYZOooool00oooool01onHV9So0000o`000?mEEEGok^k^ofIVI_l000002Ooo
ool4o`000003oa0@4?oooooooooo02?ooooo0017ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000olc<c?o^k^koQhN7
o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000?ooooo00Go0000ojVYZOooooooQhN7o`000004ooooo`03o`000?oooooooooo00?ooooo00Go
0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Kooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool02Ol0003ooooo
oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`05o`000?o<c<cok^k^ohN7Qol000000ooo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@4105
ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooooomE
EEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06
o`000?nYZJWooooooooooonj^[[o00001?ooool01_l0003oZJVYoooooon7QhOo<S8bofIVIP;ooooo
1_l00004ooooo`03o`000?oooooooooo02Gooooo0017ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05oa0@4?n7QhOoooooonk^k_l00000
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05oa0@4?n7
QhOoooooonk^k_l000001?ooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooooooooo^
k^ko00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00001oooool01Ol@413oQhN7ooooooo^k^ko000000?ooooo00Ko0000ooooooooooooooooonk^k_l0
0006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00Gok^k^o`000?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@
41001?ooool01_l0003oooooooooooooooooQhN7odA4A0cooooo00?o0000ooooooooool09Oooool0
04Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o^[Zjoa0@4?l000000_l00004ooooo`03o`000?oooooooooo00Ko
oooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`06o`0000;ooooo00?o^[Zjoa0@4?l000000_l00003ooooo`06
o`000?ooooooooooooooooo^k^ko00001_ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooooooooook^k^o`0000;ooooo1_l00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooo
oooooooo00000oooool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h4ooooo`06ob4Q8Oo<c<cooooooooooonHV9So<S8b0_ooool6o`0000Cooooo00?o0000
ooooooooool09Oooool004Oooooo00?o0000ooooooooool01Oooool00ol0003o<S8bomgMg@07oooo
o`03o`000?oooooooooo00Gooooo00?oc<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`06ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oM
gMd01_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00?o0000oc8b<_oMgMd01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00;o
oooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Ooo
ool00oo<c<co0000ooooo`02ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00001_ooool01_mEEEGo
QhN7onk^k_ooooooQhN7oc8b<PGooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOooooo
ojVYZOl000000_ooool02_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOmgMgL2oooo
o`0:ogMgMomEEEGooooooooooomVIVKoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00001?ooool01onYZJWo8B4Q
omgMgOo^k^ko<S8boeEEEOnj^[X02oooool00ol0003oooooooooo`0Uooooo`00AOooool00ol@413o
0000o`000003o`0000?ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`03oa0@4?l0003o0000
00Gooooo00Co<S8bo`000?l0003oV9RH0oooool00ol@413o0000ogMgM`02o`00000=oiRHV?oooooo
ooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?oooooo410@o`000002ooooo`;o00001?ooool0
0ol0003oooooooooo`04ooooo`04oc8b<_l0003o0000oiRHV0?ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B44ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000_ooool2o`000004ojVYZOlQ8B7o0000
ob4Q8@;ooooo00Co410@o`000?oooooooooo0_l000002Ooooooo410@o`000?lQ8B7o0000ogMgMol@
413o0000ojVYZ@02ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kP?ooooo00Co<S8bo`000?l0003oV9RH0oooool01_o^k^koEEEEo`000?l@413oc<c<
o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`03oa0@4?l0003o000000Cooooo
00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l000001om4A4Cok^k^oooo
oooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`00
0?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^ooooooooooook^k^oeEEEOl0003o410@olc<
c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_nYZJWo8B4Qo`000?l0003o
<S8bo`0000Gooooo00KoV9RHo`000?l0003oV9RHokZj^_lb<S8;ooooo`03o`000?oooooooooo02Go
oooo0017ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Gooooo0017ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool08_ooool00omEEEGoIVIVo`00000Wooooo`00FOooool00ol@413oooooooooo`0R
ooooo`03oa0@4?l0003o000001_ooooo0_l0000Jooooo`03oa0@4?l0003ooooo01Wooooo0_l0000A
ooooo`03oa0@4?oooooooooo02kooooo0_l0001>ooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.107559, 0.00346706, \
0.00371147, 0.00371147}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.02581 .30904 -24 -2.75818 ]
[.02581 .30904 0 6.24182 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-0.00308 .49011 -18 -2.91351 ]
[-0.00308 .49011 0 6.08649 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.03805 .30431 m
.04417 .30194 L
s
[(-0.1)] .02581 .30904 1 -0.38707 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.0093 .48575 m
.01549 .48356 L
s
[(0.1)] -0.00308 .49011 1 -0.35255 Mshowa
.125 Mabswid
.03532 .32153 m
.039 .32012 L
s
.03256 .33896 m
.03624 .33756 L
s
.02977 .35658 m
.03345 .35519 L
s
.02694 .3744 m
.03063 .37302 L
s
.0212 .41066 m
.0249 .4093 L
s
.01828 .4291 m
.02198 .42776 L
s
.01532 .44776 m
.01902 .44643 L
s
.01233 .46664 m
.01604 .46532 L
s
.04075 .28727 m
.04442 .28584 L
s
.04342 .27042 m
.04709 .26898 L
s
.00624 .50508 m
.00995 .50378 L
s
.00314 .52464 m
.00686 .52335 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.93078 .5519 m .95177 .54574 L .95949 .55679 L closepath p .659 .753 .919 r
F P
0 g
s
.95177 .54574 m .93078 .5519 L .90184 .5466 L p .662 .742 .909 r
F P
0 g
s
.90184 .5466 m .92278 .54027 L .95177 .54574 L p .662 .742 .909 r
F P
0 g
s
.92278 .54027 m .90184 .5466 L .87275 .5414 L p .672 .729 .892 r
F P
0 g
s
.92278 .54027 m .94395 .53453 L .95177 .54574 L closepath p .649 .748 .922 r
F P
0 g
s
.87275 .5414 m .89359 .53444 L .92278 .54027 L p .672 .729 .892 r
F P
0 g
s
.89359 .53444 m .87275 .5414 L .84348 .53616 L p .695 .682 .833 r
F P
0 g
s
.94395 .53453 m .92278 .54027 L .89359 .53444 L p .663 .723 .894 r
F P
0 g
s
.84348 .53616 m .86405 .52692 L .89359 .53444 L p .695 .682 .833 r
F P
0 g
s
.86405 .52692 m .84348 .53616 L .81393 .52968 L p .704 .666 .81 r
F P
0 g
s
.89359 .53444 m .91463 .52799 L .94395 .53453 L p .663 .723 .894 r
F P
0 g
s
.91463 .52799 m .89359 .53444 L .86405 .52692 L p .666 .699 .871 r
F P
0 g
s
.91463 .52799 m .93603 .52318 L .94395 .53453 L closepath p .628 .739 .927 r
F P
0 g
s
.81393 .52968 m .83434 .51897 L .86405 .52692 L p .704 .666 .81 r
F P
0 g
s
.83434 .51897 m .81393 .52968 L .78434 .52476 L p .72 .636 .764 r
F P
0 g
s
.86405 .52692 m .885 .52012 L .91463 .52799 L p .666 .699 .871 r
F P
0 g
s
.885 .52012 m .86405 .52692 L .83434 .51897 L p .685 .645 .804 r
F P
0 g
s
.93603 .52318 m .91463 .52799 L .885 .52012 L p .633 .715 .906 r
F P
0 g
s
.83434 .51897 m .85498 .50953 L .885 .52012 L p .685 .645 .804 r
F P
0 g
s
.85498 .50953 m .83434 .51897 L .80444 .51031 L p .701 .606 .748 r
F P
0 g
s
.78434 .52476 m .80444 .51031 L .83434 .51897 L p .72 .636 .764 r
F P
0 g
s
.80444 .51031 m .78434 .52476 L .75455 .51953 L p .727 .6 .715 r
F P
0 g
s
.885 .52012 m .90633 .5152 L .93603 .52318 L p .633 .715 .906 r
F P
0 g
s
.90633 .5152 m .885 .52012 L .85498 .50953 L p .642 .664 .856 r
F P
0 g
s
.80444 .51031 m .82466 .49672 L .85498 .50953 L p .701 .606 .748 r
F P
0 g
s
.82466 .49672 m .80444 .51031 L .77427 .49968 L p .708 .591 .722 r
F P
0 g
s
.75455 .51953 m .77427 .49968 L .80444 .51031 L p .727 .6 .715 r
F P
0 g
s
.85498 .50953 m .87616 .50409 L .90633 .5152 L p .642 .664 .856 r
F P
0 g
s
.87616 .50409 m .85498 .50953 L .82466 .49672 L p .656 .615 .796 r
F P
0 g
s
.90633 .5152 m .928 .51167 L .93603 .52318 L closepath p .599 .726 .934 r
F P
0 g
s
.82466 .49672 m .84556 .48943 L .87616 .50409 L p .656 .615 .796 r
F P
0 g
s
.84556 .48943 m .82466 .49672 L .79423 .48305 L p .674 .582 .744 r
F P
0 g
s
.77427 .49968 m .79423 .48305 L .82466 .49672 L p .708 .591 .722 r
F P
0 g
s
.79423 .48305 m .77427 .49968 L .74416 .49127 L p .72 .575 .691 r
F P
0 g
s
.77427 .49968 m .75455 .51953 L .72441 .51154 L p .737 .613 .721 r
F P
0 g
s
.72441 .51154 m .74416 .49127 L .77427 .49968 L p .737 .613 .721 r
F P
0 g
s
.79423 .48305 m .81471 .47204 L .84556 .48943 L p .674 .582 .744 r
F P
0 g
s
.81471 .47204 m .79423 .48305 L .76373 .4689 L p .689 .565 .71 r
F P
0 g
s
.74416 .49127 m .76373 .4689 L .79423 .48305 L p .72 .575 .691 r
F P
0 g
s
.76373 .4689 m .78379 .45339 L .81471 .47204 L p .689 .565 .71 r
F P
0 g
s
.78379 .45339 m .76373 .4689 L .73325 .45543 L p .704 .562 .692 r
F P
0 g
s
.76373 .4689 m .74416 .49127 L .71396 .48352 L p .731 .568 .67 r
F P
0 g
s
.71396 .48352 m .73325 .45543 L .76373 .4689 L p .731 .568 .67 r
F P
0 g
s
.80451 .44502 m .78379 .45339 L .753 .43562 L p .67 .55 .71 r
F P
0 g
s
.753 .43562 m .77325 .42259 L .80451 .44502 L p .67 .55 .71 r
F P
0 g
s
.73325 .45543 m .753 .43562 L .78379 .45339 L p .704 .562 .692 r
F P
0 g
s
.77325 .42259 m .753 .43562 L .72243 .42081 L p .694 .554 .691 r
F P
0 g
s
.753 .43562 m .73325 .45543 L .70295 .44578 L p .723 .567 .678 r
F P
0 g
s
.70295 .44578 m .72243 .42081 L .753 .43562 L p .723 .567 .678 r
F P
0 g
s
.79418 .41668 m .77325 .42259 L .74227 .40246 L p .654 .538 .71 r
F P
0 g
s
.74227 .40246 m .76267 .39148 L .79418 .41668 L p .654 .538 .71 r
F P
0 g
s
.72243 .42081 m .74227 .40246 L .77325 .42259 L p .694 .554 .691 r
F P
0 g
s
.76267 .39148 m .74227 .40246 L .71169 .38753 L p .687 .552 .696 r
F P
0 g
s
.74227 .40246 m .72243 .42081 L .6921 .41081 L p .72 .57 .684 r
F P
0 g
s
.6921 .41081 m .71169 .38753 L .74227 .40246 L p .72 .57 .684 r
F P
0 g
s
.72243 .42081 m .70295 .44578 L .67271 .4398 L p .743 .581 .674 r
F P
0 g
s
.67271 .4398 m .6921 .41081 L .72243 .42081 L p .743 .581 .674 r
F P
0 g
s
.71169 .38753 m .73164 .37069 L .76267 .39148 L p .687 .552 .696 r
F P
0 g
s
.73164 .37069 m .71169 .38753 L .68146 .37985 L p .724 .58 .693 r
F P
0 g
s
.71169 .38753 m .6921 .41081 L .66195 .40716 L p .75 .596 .686 r
F P
0 g
s
.66195 .40716 m .68146 .37985 L .71169 .38753 L p .75 .596 .686 r
F P
0 g
s
.73325 .45543 m .71396 .48352 L .68359 .47511 L p .744 .582 .674 r
F P
0 g
s
.68359 .47511 m .70295 .44578 L .73325 .45543 L p .744 .582 .674 r
F P
0 g
s
.7838 .38823 m .76267 .39148 L .73164 .37069 L p .64 .532 .716 r
F P
0 g
s
.73164 .37069 m .75217 .36169 L .7838 .38823 L p .64 .532 .716 r
F P
0 g
s
.75217 .36169 m .73164 .37069 L .70113 .35743 L p .685 .559 .706 r
F P
0 g
s
.68146 .37985 m .70113 .35743 L .73164 .37069 L p .724 .58 .693 r
F P
0 g
s
.83587 .46706 m .81471 .47204 L .78379 .45339 L p .647 .558 .74 r
F P
0 g
s
.78379 .45339 m .80451 .44502 L .83587 .46706 L p .647 .558 .74 r
F P
0 g
s
.928 .51167 m .90633 .5152 L .87616 .50409 L p .588 .693 .915 r
F P
0 g
s
.74416 .49127 m .72441 .51154 L .69433 .50746 L p .745 .605 .703 r
F P
0 g
s
.69433 .50746 m .71396 .48352 L .74416 .49127 L p .745 .605 .703 r
F P
0 g
s
.70113 .35743 m .72118 .34191 L .75217 .36169 L p .685 .559 .706 r
F P
0 g
s
.72118 .34191 m .70113 .35743 L .67103 .35373 L p .735 .601 .708 r
F P
0 g
s
.70113 .35743 m .68146 .37985 L .65142 .38059 L p .766 .621 .7 r
F P
0 g
s
.65142 .38059 m .67103 .35373 L .70113 .35743 L p .766 .621 .7 r
F P
0 g
s
.82596 .44291 m .80451 .44502 L .77325 .42259 L p .622 .536 .736 r
F P
0 g
s
.77325 .42259 m .79418 .41668 L .82596 .44291 L p .622 .536 .736 r
F P
0 g
s
.86706 .48639 m .84556 .48943 L .81471 .47204 L p .625 .582 .786 r
F P
0 g
s
.81471 .47204 m .83587 .46706 L .86706 .48639 L p .625 .582 .786 r
F P
0 g
s
.6921 .41081 m .67271 .4398 L .64241 .43718 L p .766 .61 .685 r
F P
0 g
s
.64241 .43718 m .66195 .40716 L .6921 .41081 L p .766 .61 .685 r
F P
0 g
s
.87616 .50409 m .89781 .50134 L .928 .51167 L p .588 .693 .915 r
F P
0 g
s
.89781 .50134 m .87616 .50409 L .84556 .48943 L p .603 .63 .85 r
F P
0 g
s
.77349 .36093 m .75217 .36169 L .72118 .34191 L p .629 .534 .728 r
F P
0 g
s
.72118 .34191 m .74184 .33461 L .77349 .36093 L p .629 .534 .728 r
F P
0 g
s
.74184 .33461 m .72118 .34191 L .6908 .33203 L p .689 .576 .723 r
F P
0 g
s
.67103 .35373 m .6908 .33203 L .72118 .34191 L p .735 .601 .708 r
F P
0 g
s
.70295 .44578 m .68359 .47511 L .65329 .47164 L p .758 .593 .673 r
F P
0 g
s
.65329 .47164 m .67271 .4398 L .70295 .44578 L p .758 .593 .673 r
F P
0 g
s
.84556 .48943 m .86706 .48639 L .89781 .50134 L p .603 .63 .85 r
F P
0 g
s
.81591 .41779 m .79418 .41668 L .76267 .39148 L p .596 .518 .738 r
F P
0 g
s
.76267 .39148 m .7838 .38823 L .81591 .41779 L p .596 .518 .738 r
F P
0 g
s
.68146 .37985 m .66195 .40716 L .63179 .41028 L p .785 .638 .698 r
F P
0 g
s
.63179 .41028 m .65142 .38059 L .68146 .37985 L p .785 .638 .698 r
F P
0 g
s
.71396 .48352 m .69433 .50746 L .66405 .50347 L p .747 .59 .681 r
F P
0 g
s
.66405 .50347 m .68359 .47511 L .71396 .48352 L p .747 .59 .681 r
F P
0 g
s
.80581 .39258 m .7838 .38823 L .75217 .36169 L p .57 .505 .744 r
F P
0 g
s
.75217 .36169 m .77349 .36093 L .80581 .39258 L p .57 .505 .744 r
F P
0 g
s
.85772 .46703 m .83587 .46706 L .80451 .44502 L p .589 .55 .779 r
F P
0 g
s
.80451 .44502 m .82596 .44291 L .85772 .46703 L p .589 .55 .779 r
F P
0 g
s
.6908 .33203 m .71096 .31747 L .74184 .33461 L p .689 .576 .723 r
F P
0 g
s
.71096 .31747 m .6908 .33203 L .66083 .33395 L p .756 .638 .73 r
F P
0 g
s
.6908 .33203 m .67103 .35373 L .6411 .36061 L p .793 .664 .721 r
F P
0 g
s
.6411 .36061 m .66083 .33395 L .6908 .33203 L p .793 .664 .721 r
F P
0 g
s
.67103 .35373 m .65142 .38059 L .62134 .39019 L p .817 .686 .719 r
F P
0 g
s
.62134 .39019 m .6411 .36061 L .67103 .35373 L p .817 .686 .719 r
F P
0 g
s
.67271 .4398 m .65329 .47164 L .62279 .46932 L p .77 .609 .679 r
F P
0 g
s
.62279 .46932 m .64241 .43718 L .67271 .4398 L p .77 .609 .679 r
F P
0 g
s
.76332 .33594 m .74184 .33461 L .71096 .31747 L p .621 .544 .746 r
F P
0 g
s
.71096 .31747 m .73174 .31138 L .76332 .33594 L p .621 .544 .746 r
F P
0 g
s
.73174 .31138 m .71096 .31747 L .68073 .31257 L p .702 .607 .748 r
F P
0 g
s
.66083 .33395 m .68073 .31257 L .71096 .31747 L p .756 .638 .73 r
F P
0 g
s
.89781 .50134 m .91985 .50001 L .928 .51167 L closepath p .544 .7 .941 r
F P
0 g
s
.84818 .44643 m .82596 .44291 L .79418 .41668 L p .549 .52 .776 r
F P
0 g
s
.79418 .41668 m .81591 .41779 L .84818 .44643 L p .549 .52 .776 r
F P
0 g
s
.66195 .40716 m .64241 .43718 L .61202 .44013 L p .796 .653 .705 r
F P
0 g
s
.61202 .44013 m .63179 .41028 L .66195 .40716 L p .796 .653 .705 r
F P
0 g
s
.68359 .47511 m .66405 .50347 L .63342 .49527 L p .763 .635 .72 r
F P
0 g
s
.63342 .49527 m .65329 .47164 L .68359 .47511 L p .763 .635 .72 r
F P
0 g
s
.79574 .36829 m .77349 .36093 L .74184 .33461 L p .544 .498 .755 r
F P
0 g
s
.74184 .33461 m .76332 .33594 L .79574 .36829 L p .544 .498 .755 r
F P
0 g
s
.8891 .48639 m .86706 .48639 L .83587 .46706 L p .555 .59 .844 r
F P
0 g
s
.83587 .46706 m .85772 .46703 L .8891 .48639 L p .555 .59 .844 r
F P
0 g
s
.91985 .50001 m .89781 .50134 L .86706 .48639 L p .527 .656 .917 r
F P
0 g
s
.86706 .48639 m .8891 .48639 L .91985 .50001 L p .527 .656 .917 r
F P
0 g
s
.83852 .42512 m .81591 .41779 L .7838 .38823 L p .505 .492 .775 r
F P
0 g
s
.7838 .38823 m .80581 .39258 L .83852 .42512 L p .505 .492 .775 r
F P
0 g
s
.65142 .38059 m .63179 .41028 L .60144 .41979 L p .832 .709 .729 r
F P
0 g
s
.60144 .41979 m .62134 .39019 L .65142 .38059 L p .832 .709 .729 r
F P
0 g
s
.68073 .31257 m .701 .29845 L .73174 .31138 L p .702 .607 .748 r
F P
0 g
s
.701 .29845 m .68073 .31257 L .65083 .32102 L p .788 .694 .76 r
F P
0 g
s
.68073 .31257 m .66083 .33395 L .63093 .34783 L p .832 .726 .747 r
F P
0 g
s
.63093 .34783 m .65083 .32102 L .68073 .31257 L p .832 .726 .747 r
F P
0 g
s
.8802 .47055 m .85772 .46703 L .82596 .44291 L p .494 .546 .838 r
F P
0 g
s
.82596 .44291 m .84818 .44643 L .8802 .47055 L p .494 .546 .838 r
F P
0 g
s
.78578 .34578 m .76332 .33594 L .73174 .31138 L p .519 .497 .772 r
F P
0 g
s
.73174 .31138 m .75334 .3142 L .78578 .34578 L p .519 .497 .772 r
F P
0 g
s
.75334 .3142 m .73174 .31138 L .701 .29845 L p .62 .567 .773 r
F P
0 g
s
.64241 .43718 m .62279 .46932 L .59205 .46732 L p .795 .666 .721 r
F P
0 g
s
.59205 .46732 m .61202 .44013 L .64241 .43718 L p .795 .666 .721 r
F P
0 g
s
.82878 .40373 m .80581 .39258 L .77349 .36093 L p .458 .465 .778 r
F P
0 g
s
.77349 .36093 m .79574 .36829 L .82878 .40373 L p .458 .465 .778 r
F P
0 g
s
.65329 .47164 m .63342 .49527 L .60277 .49196 L p .767 .65 .732 r
F P
0 g
s
.60277 .49196 m .62279 .46932 L .65329 .47164 L p .767 .65 .732 r
F P
0 g
s
.66083 .33395 m .6411 .36061 L .611 .37757 L p .861 .755 .744 r
F P
0 g
s
.611 .37757 m .63093 .34783 L .66083 .33395 L p .861 .755 .744 r
F P
0 g
s
.701 .29845 m .72188 .29295 L .75334 .3142 L p .62 .567 .773 r
F P
0 g
s
.72188 .29295 m .701 .29845 L .67087 .2995 L p .724 .656 .782 r
F P
0 g
s
.65083 .32102 m .67087 .2995 L .701 .29845 L p .788 .694 .76 r
F P
0 g
s
.63179 .41028 m .61202 .44013 L .58135 .44728 L p .833 .725 .746 r
F P
0 g
s
.58135 .44728 m .60144 .41979 L .63179 .41028 L p .833 .725 .746 r
F P
0 g
s
.9116 .48819 m .8891 .48639 L .85772 .46703 L p .439 .603 .915 r
F P
0 g
s
.85772 .46703 m .8802 .47055 L .9116 .48819 L p .439 .603 .915 r
F P
0 g
s
.87114 .454 m .84818 .44643 L .81591 .41779 L p .424 .498 .831 r
F P
0 g
s
.81591 .41779 m .83852 .42512 L .87114 .454 L p .424 .498 .831 r
F P
0 g
s
.8891 .48639 m .9116 .48819 L .91985 .50001 L closepath p .458 .654 .944 r
F P
0 g
s
.81903 .38291 m .79574 .36829 L .76332 .33594 L p .407 .442 .784 r
F P
0 g
s
.76332 .33594 m .78578 .34578 L .81903 .38291 L p .407 .442 .784 r
F P
0 g
s
.6411 .36061 m .62134 .39019 L .59093 .4074 L p .88 .788 .755 r
F P
0 g
s
.59093 .4074 m .611 .37757 L .6411 .36061 L p .88 .788 .755 r
F P
0 g
s
.62279 .46932 m .60277 .49196 L .57188 .4883 L p .767 .662 .747 r
F P
0 g
s
.57188 .4883 m .59205 .46732 L .62279 .46932 L p .767 .662 .747 r
F P
0 g
s
.77595 .32583 m .75334 .3142 L .72188 .29295 L p .496 .507 .797 r
F P
0 g
s
.72188 .29295 m .74358 .29651 L .77595 .32583 L p .496 .507 .797 r
F P
0 g
s
.71225 .27968 m .73403 .28317 L .75043 .29631 L p .48 .529 .831 r
F P
0 g
s
.74358 .29651 m .72188 .29295 L .70686 .28919 L p .627 .606 .81 r
F P
0 g
s
.71783 .29098 m .74358 .29651 L .70686 .28919 L .627 .606 .81 r
F
.69126 .28527 m .71225 .27968 L .74358 .29651 L p F P
0 g
s
.77595 .32583 m .74358 .29651 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.7997 .34541 m .78406 .33251 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.78406 .33251 m .77595 .32583 L p .76957 .31915 L .308 .413 .806 r
F P
0 g
s
.74358 .29651 m .7663 .30903 L .7997 .34541 L p .308 .413 .806 r
F P
0 g
s
.74358 .29651 m .71225 .27968 L p .73423 .29162 L .48 .529 .831 r
F P
0 g
s
.7374 .29331 m .7663 .30903 L .74896 .29948 L .48 .529 .831 r
F
.73423 .29162 m .7411 .29535 L .7374 .29331 L F
.7411 .29535 m .7663 .30903 L .7374 .29331 L F
.73403 .28317 m .75681 .29564 L .77465 .31384 L p .267 .414 .824 r
F P
0 g
s
.73423 .29162 m .74896 .29948 L .74358 .29651 L .48 .529 .831 r
F
.71225 .27968 m .75043 .29631 L .73962 .29454 L F
.75043 .29631 m .7663 .30903 L p .74752 .29884 L F P
0 g
s
.74357 .29519 m .75043 .29631 L .74752 .29884 L .48 .529 .831 r
F
.7663 .30903 m .73403 .28317 L p .75867 .30358 L .267 .414 .824 r
F P
0 g
s
.7997 .34541 m .7663 .30903 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.7663 .30903 m .79017 .32966 L .82457 .37102 L p .033 .269 .767 r
F P
0 g
s
.75681 .29564 m .78072 .31624 L .80092 .33982 L p 0 .256 .763 r
F P
0 g
s
.79017 .32966 m .77332 .3151 L p .76249 .30658 L .267 .414 .824 r
F P
0 g
s
.76682 .31033 m .79017 .32966 L .76249 .30658 L .267 .414 .824 r
F
.76518 .30668 m .77465 .31384 L .7687 .31056 L F
.75867 .30358 m .76682 .31033 L .76249 .30658 L F
.77332 .3151 m .7663 .30903 L p .75867 .30358 L F P
0 g
s
.77465 .31384 m .79017 .32966 L p .76391 .30792 L .267 .414 .824 r
F P
0 g
s
.79017 .32966 m .75681 .29564 L p .78525 .32528 L 0 .256 .763 r
F P
0 g
s
.82457 .37102 m .79017 .32966 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.8505 .40066 m .83928 .38783 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.83928 .38783 m .82457 .37102 L p .82809 .37429 L 0 .108 .659 r
F P
0 g
s
.79017 .32966 m .81517 .35647 L .8505 .40066 L p 0 .108 .659 r
F P
0 g
s
.81517 .35647 m .79917 .33932 L p .78913 .32919 L 0 .256 .763 r
F P
0 g
s
.78525 .32528 m .79354 .33392 L .78913 .32919 L 0 .256 .763 r
F
.79354 .33392 m .81517 .35647 L .78913 .32919 L F
.78072 .31624 m .80577 .34304 L .8282 .37109 L p 0 .106 .658 r
F P
0 g
s
.80092 .33982 m .81517 .35647 L p .8022 .34295 L 0 .256 .763 r
F P
0 g
s
.79637 .33589 m .80092 .33982 L .8022 .34295 L 0 .256 .763 r
F
.79917 .33932 m .79017 .32966 L p .78525 .32528 L F P
0 g
s
.75681 .29564 m .80092 .33982 L .79084 .33111 L 0 .256 .763 r
F
.81517 .35647 m .78072 .31624 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.81517 .35647 m .84127 .38743 L .8505 .40066 L closepath p 0 0 .53 r
F P
0 g
s
.84127 .38743 m .82607 .3694 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.82607 .3694 m .81517 .35647 L p .81301 .3542 L 0 .106 .658 r
F P
0 g
s
.78072 .31624 m .8282 .37109 L .81878 .36098 L 0 .106 .658 r
F
.73403 .28317 m .76518 .30668 L .76391 .30792 L .267 .414 .824 r
F
.71225 .27968 m .69126 .28527 L .66117 .29288 L p .758 .726 .823 r
F P
0 g
s
.66117 .29288 m .68171 .27797 L .71225 .27968 L p .758 .726 .823 r
F P
0 g
s
.73403 .28317 m .71225 .27968 L .68171 .27797 L p .643 .665 .856 r
F P
0 g
s
.70279 .2716 m .73403 .28317 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.75681 .29564 m .73403 .28317 L .71763 .27709 L p .473 .569 .871 r
F P
0 g
s
.71763 .27709 m .70279 .2716 L p .72978 .28361 L .473 .569 .871 r
F P
0 g
s
.72978 .28361 m .75681 .29564 L .71763 .27709 L .473 .569 .871 r
F
.72465 .2742 m .75013 .29267 L p .73784 .2872 L F P
0 g
s
.75399 .29375 m .75681 .29564 L p .7551 .29487 L .473 .569 .871 r
F P
0 g
s
.78072 .31624 m .75681 .29564 L .74065 .28487 L p .242 .431 .848 r
F P
0 g
s
.74065 .28487 m .72465 .2742 L p .74839 .292 L .242 .431 .848 r
F P
0 g
s
.74839 .292 m .75099 .2936 L .74065 .28487 L .242 .431 .848 r
F
.7546 .29666 m .78072 .31624 L .74065 .28487 L F
.72465 .2742 m .74449 .28418 L p .75998 .2998 L F P
0 g
s
.74839 .292 m .7546 .29666 L .75099 .2936 L .242 .431 .848 r
F
.72465 .2742 m .75998 .2998 L .7558 .29756 L F
.74449 .28418 m .74745 .28567 L p .76344 .30328 L F P
0 g
s
.72073 .27374 m .72465 .2742 L p .73784 .2872 L .473 .569 .871 r
F P
0 g
s
.70279 .2716 m .72073 .27374 L p .73784 .2872 L .473 .569 .871 r
F P
0 g
s
.68171 .27797 m .69891 .27278 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.69891 .27278 m .70279 .2716 L p .71482 .28126 L .643 .665 .856 r
F P
0 g
s
.64096 .31499 m .66117 .29288 L .69126 .28527 L p .832 .771 .794 r
F P
0 g
s
.66117 .29288 m .64096 .31499 L .62165 .33328 L p .922 .902 .788 r
F P
0 g
s
.62165 .33328 m .61078 .34359 L p .63001 .32424 L .922 .902 .788 r
F P
0 g
s
.63001 .32424 m .66117 .29288 L .62165 .33328 L .922 .902 .788 r
F
.63112 .31545 m .65155 .29234 L .66572 .28559 L p .877 .864 .823 r
F P
0 g
s
.61078 .34359 m .63112 .31545 L .66117 .29288 L p .922 .902 .788 r
F P
0 g
s
.68171 .27797 m .66117 .29288 L .65401 .29826 L p .877 .864 .823 r
F P
0 g
s
.65155 .29234 m .67225 .27623 L .68787 .27386 L p .8 .816 .864 r
F P
0 g
s
.65401 .29826 m .643 .30653 L p .68171 .27797 L .877 .864 .823 r
F P
0 g
s
.65235 .29973 m .68171 .27797 L .643 .30653 L .877 .864 .823 r
F
.66572 .28559 m .68171 .27797 L p .65333 .299 L F P
0 g
s
.643 .30653 m .63112 .31545 L p .64557 .30475 L .877 .864 .823 r
F P
0 g
s
.64557 .30475 m .65235 .29973 L .64817 .30277 L .877 .864 .823 r
F
.64557 .30475 m .64817 .30277 L .643 .30653 L F
.64557 .30475 m .66572 .28559 L .65333 .299 L F
.63112 .31545 m .64703 .30172 L .64557 .30475 L F
.64703 .30172 m .66572 .28559 L .64557 .30475 L F
.63112 .31545 m .61078 .34359 L .58804 .37176 L p .917 .977 .711 r
F P
0 g
s
.58804 .37176 m .57987 .38189 L p .59452 .36289 L .917 .977 .711 r
F P
0 g
s
.59452 .36289 m .63112 .31545 L .58804 .37176 L .917 .977 .711 r
F
.57987 .38189 m .60059 .35028 L .63112 .31545 L p F P
0 g
s
.65155 .29234 m .63112 .31545 L .61098 .33844 L p .928 .966 .765 r
F P
0 g
s
.61927 .32905 m .65155 .29234 L .61098 .33844 L .928 .966 .765 r
F
.63063 .31613 m .62748 .3178 L .65155 .29234 L F
.62122 .32113 m .63371 .30927 L p .62748 .3178 L F P
0 g
s
.63371 .30927 m .65155 .29234 L p .62748 .3178 L .928 .966 .765 r
F P
0 g
s
.61098 .33844 m .60059 .35028 L p .61927 .32905 L .928 .966 .765 r
F P
0 g
s
.62122 .32113 m .6419 .29672 L .65656 .28682 L p .903 .943 .823 r
F P
0 g
s
.68171 .27797 m .65155 .29234 L p .70279 .2716 L .8 .816 .864 r
F P
0 g
s
.65155 .29234 m .68787 .27386 L .67618 .28238 L .8 .816 .864 r
F
.67225 .27623 m .65155 .29234 L .63255 .31038 L p .903 .943 .823 r
F P
0 g
s
.63255 .31038 m .62122 .32113 L p .63638 .30779 L .903 .943 .823 r
F P
0 g
s
.63638 .30779 m .64187 .30296 L .63865 .30552 L .903 .943 .823 r
F
.63638 .30779 m .63865 .30552 L .63255 .31038 L F
.64187 .30296 m .67225 .27623 L .63255 .31038 L F
.62122 .32113 m .65656 .28682 L .64384 .30122 L F
.60059 .35028 m .6179 .32583 L p .63063 .31613 L .928 .966 .765 r
F P
0 g
s
.6179 .32583 m .62122 .32113 L p .63063 .31613 L .928 .966 .765 r
F P
0 g
s
.62122 .32113 m .60059 .35028 L .57685 .38249 L p .854 .964 .635 r
F P
0 g
s
.57685 .38249 m .56913 .39296 L p .583 .37383 L .854 .964 .635 r
F P
0 g
s
.583 .37383 m .62122 .32113 L .57685 .38249 L .854 .964 .635 r
F
.56913 .39296 m .5902 .3606 L .62122 .32113 L p F P
0 g
s
.6419 .29672 m .62122 .32113 L .61294 .33167 L p .897 .983 .712 r
F P
0 g
s
.61294 .33167 m .60031 .34774 L p .61918 .3246 L .897 .983 .712 r
F P
0 g
s
.61918 .3246 m .6419 .29672 L .61294 .33167 L .897 .983 .712 r
F
.63211 .30456 m .65324 .28503 L .65475 .28426 L p .852 .962 .876 r
F P
0 g
s
.65656 .28682 m .67225 .27623 L p .64384 .30122 L .903 .943 .823 r
F P
0 g
s
.68787 .27386 m .70279 .2716 L p .67618 .28238 L .8 .816 .864 r
F P
0 g
s
.70279 .2716 m .67225 .27623 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.72465 .2742 m .70698 .2721 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.70698 .2721 m .70279 .2716 L p .69188 .27547 L .672 .745 .906 r
F P
0 g
s
.67225 .27623 m .69346 .26843 L .72465 .2742 L p .672 .745 .906 r
F P
0 g
s
.69346 .26843 m .67225 .27623 L .65382 .28867 L p .835 .903 .886 r
F P
0 g
s
.65382 .28867 m .6419 .29672 L p .66409 .28455 L .835 .903 .886 r
F P
0 g
s
.66409 .28455 m .69346 .26843 L .65382 .28867 L .835 .903 .886 r
F
.6628 .27901 m .67899 .27342 L p .66685 .28105 L F P
0 g
s
.67899 .27342 m .69346 .26843 L p .66705 .28292 L .835 .903 .886 r
F P
0 g
s
.6419 .29672 m .67899 .27342 L .66705 .28292 L .835 .903 .886 r
F
.72465 .2742 m .69346 .26843 L p .71479 .27524 L .481 .628 .917 r
F P
0 g
s
.74745 .28567 m .72991 .27685 L p .71644 .27542 L .481 .628 .917 r
F P
0 g
s
.71882 .27653 m .74745 .28567 L .71644 .27542 L .481 .628 .917 r
F
.72991 .27685 m .72465 .2742 L p .71479 .27524 L F P
0 g
s
.71537 .26937 m .74745 .28567 L p .72811 .27949 L .481 .628 .917 r
F P
0 g
s
.74745 .28567 m .77308 .31051 L p .76344 .30328 L .242 .431 .848 r
F P
0 g
s
.7791 .31475 m .78072 .31624 L p .77976 .31552 L .242 .431 .848 r
F P
0 g
s
.78072 .31624 m .74745 .28567 L p .77424 .31202 L 0 .265 .772 r
F P
0 g
s
.80577 .34304 m .78853 .3246 L p .77625 .31379 L 0 .265 .772 r
F P
0 g
s
.77933 .31703 m .80577 .34304 L .77625 .31379 L 0 .265 .772 r
F
.78853 .3246 m .78072 .31624 L p .77424 .31202 L F P
0 g
s
.77134 .30516 m .80577 .34304 L p .79053 .32805 L 0 .265 .772 r
F P
0 g
s
.80577 .34304 m .77134 .30516 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.80577 .34304 m .8319 .374 L .84127 .38743 L closepath p 0 0 .53 r
F P
0 g
s
.8319 .374 m .81448 .35337 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.81448 .35337 m .80577 .34304 L p .8006 .33842 L 0 .13 .677 r
F P
0 g
s
.77134 .30516 m .79634 .33073 L .82162 .3615 L p 0 .13 .677 r
F P
0 g
s
.77134 .30516 m .82162 .3615 L .81202 .3514 L 0 .13 .677 r
F
.74745 .28567 m .7697 .30381 L p .78733 .32433 L 0 .265 .772 r
F P
0 g
s
.77424 .31202 m .77933 .31703 L .77625 .31379 L 0 .265 .772 r
F
.74745 .28567 m .78733 .32433 L .78319 .32082 L F
.7697 .30381 m .77134 .30516 L p .79053 .32805 L F P
0 g
s
.74745 .28567 m .72924 .27642 L p .74432 .28671 L .241 .47 .879 r
F P
0 g
s
.72924 .27642 m .71537 .26937 L p .74293 .28699 L .241 .47 .879 r
F P
0 g
s
.74293 .28699 m .77134 .30516 L .72924 .27642 L .241 .47 .879 r
F
.77134 .30516 m .75372 .29078 L p .74432 .28671 L F P
0 g
s
.75372 .29078 m .74745 .28567 L p .74432 .28671 L .241 .47 .879 r
F P
0 g
s
.71537 .26937 m .73523 .2777 L p .7475 .2885 L .241 .47 .879 r
F P
0 g
s
.73523 .2777 m .73817 .27893 L p .7475 .2885 L .241 .47 .879 r
F P
0 g
s
.71537 .26937 m .7587 .29516 L .74759 .28997 L .241 .47 .879 r
F
.69346 .26843 m .71142 .2692 L p .71516 .2715 L .481 .628 .917 r
F P
0 g
s
.71479 .27524 m .71882 .27653 L .71644 .27542 L .481 .628 .917 r
F
.71479 .27524 m .71516 .2715 L .72811 .27949 L F
.69346 .26843 m .71516 .2715 L .71479 .27524 L F
.71142 .2692 m .71537 .26937 L p .72811 .27949 L F P
0 g
s
.71537 .26937 m .69346 .26843 L .6628 .27901 L p .706 .831 .942 r
F P
0 g
s
.70195 .26933 m .71537 .26937 L p .6949 .27312 L .706 .831 .942 r
F P
0 g
s
.69302 .27292 m .70195 .26933 L .6949 .27312 L .706 .831 .942 r
F
.6628 .27901 m .68414 .26928 L .70195 .26933 L p F P
0 g
s
.6628 .27901 m .70195 .26933 L .69052 .27393 L .706 .831 .942 r
F
.73817 .27893 m .71537 .26937 L .68414 .26928 L p .51 .703 .957 r
F P
0 g
s
.70611 .26794 m .73817 .27893 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.68414 .26928 m .7016 .26821 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.7016 .26821 m .70611 .26794 L p .71807 .27534 L .51 .703 .957 r
F P
0 g
s
.7587 .29516 m .7652 .3003 L p .75416 .29304 L .241 .47 .879 r
F P
0 g
s
.7652 .3003 m .77134 .30516 L p .75416 .29304 L .241 .47 .879 r
F P
0 g
s
.74759 .28997 m .75416 .29304 L .77134 .30516 L .241 .47 .879 r
F
.73817 .27893 m .7587 .29516 L p .7475 .2885 L F P
0 g
s
.77134 .30516 m .73817 .27893 L p .76395 .30189 L 0 .301 .795 r
F P
0 g
s
.79634 .33073 m .77861 .31259 L p .76479 .30251 L 0 .301 .795 r
F P
0 g
s
.76631 .30399 m .79634 .33073 L .76479 .30251 L 0 .301 .795 r
F
.77861 .31259 m .77134 .30516 L p .76395 .30189 L F P
0 g
s
.762 .29627 m .79634 .33073 L p .77971 .31593 L 0 .301 .795 r
F P
0 g
s
.79634 .33073 m .762 .29627 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.79634 .33073 m .82239 .36038 L .8319 .374 L closepath p 0 .006 .554 r
F P
0 g
s
.82239 .36038 m .80386 .33929 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.80386 .33929 m .79634 .33073 L p .78942 .32538 L 0 .18 .714 r
F P
0 g
s
.762 .29627 m .78687 .31948 L .81388 .35059 L p 0 .18 .714 r
F P
0 g
s
.762 .29627 m .81388 .35059 L .80456 .34146 L 0 .18 .714 r
F
.73817 .27893 m .76033 .29506 L p .77799 .31407 L 0 .301 .795 r
F P
0 g
s
.76395 .30189 m .76631 .30399 L .76479 .30251 L 0 .301 .795 r
F
.73817 .27893 m .77799 .31407 L .77526 .31197 L F
.76033 .29506 m .762 .29627 L p .77971 .31593 L F P
0 g
s
.73817 .27893 m .71849 .27218 L p .73434 .28096 L .274 .531 .914 r
F P
0 g
s
.71849 .27218 m .70611 .26794 L p .73179 .28096 L .274 .531 .914 r
F P
0 g
s
.73179 .28096 m .762 .29627 L .71849 .27218 L .274 .531 .914 r
F
.762 .29627 m .74457 .28359 L p .73434 .28096 L F P
0 g
s
.74457 .28359 m .73817 .27893 L p .73434 .28096 L .274 .531 .914 r
F P
0 g
s
.70611 .26794 m .72549 .27382 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.72549 .27382 m .7289 .27485 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.6419 .29672 m .65809 .283 L p .66685 .28105 L .835 .903 .886 r
F P
0 g
s
.65809 .283 m .6628 .27901 L p .66685 .28105 L .835 .903 .886 r
F P
0 g
s
.60851 .33797 m .6419 .29672 L .60031 .34774 L .897 .983 .712 r
F
.6184 .32575 m .61614 .3272 L .6419 .29672 L F
.61115 .33038 m .62342 .31695 L p .61614 .3272 L F P
0 g
s
.62342 .31695 m .6419 .29672 L p .61614 .3272 L .897 .983 .712 r
F P
0 g
s
.6628 .27901 m .6419 .29672 L .63452 .3048 L p .899 .983 .792 r
F P
0 g
s
.64132 .29979 m .6628 .27901 L .63452 .3048 L .899 .983 .792 r
F
.63144 .31021 m .6628 .27901 L .62215 .31834 L F
.63391 .30775 m .65925 .28197 L .66043 .28136 L F
.63452 .3048 m .62215 .31834 L p .64132 .29979 L F P
0 g
s
.647 .29216 m .65925 .28197 L p .63391 .30775 L .899 .983 .792 r
F P
0 g
s
.65925 .28197 m .6628 .27901 L p .66043 .28136 L .899 .983 .792 r
F P
0 g
s
.62215 .31834 m .61115 .33038 L p .62746 .31416 L .899 .983 .792 r
F P
0 g
s
.62746 .31416 m .63144 .31021 L .6293 .31207 L .899 .983 .792 r
F
.62746 .31416 m .6293 .31207 L .62215 .31834 L F
.63211 .30456 m .647 .29216 L p .62863 .31175 L F P
0 g
s
.61115 .33038 m .63211 .30456 L p .62863 .31175 L .899 .983 .792 r
F P
0 g
s
.61115 .33038 m .647 .29216 L .63391 .30775 L .899 .983 .792 r
F
.60031 .34774 m .5902 .3606 L p .60851 .33797 L .897 .983 .712 r
F P
0 g
s
.5902 .3606 m .60525 .3389 L p .6184 .32575 L .897 .983 .712 r
F P
0 g
s
.60525 .3389 m .61115 .33038 L p .6184 .32575 L .897 .983 .712 r
F P
0 g
s
.61115 .33038 m .5902 .3606 L .56554 .39485 L p .812 .945 .592 r
F P
0 g
s
.56554 .39485 m .55807 .40522 L p .57122 .38668 L .812 .945 .592 r
F P
0 g
s
.57122 .38668 m .61115 .33038 L .56554 .39485 L .812 .945 .592 r
F
.55807 .40522 m .57951 .37231 L .61115 .33038 L p F P
0 g
s
.63211 .30456 m .61115 .33038 L .60227 .34216 L p .867 .976 .672 r
F P
0 g
s
.60227 .34216 m .58961 .35894 L p .60844 .33485 L .867 .976 .672 r
F P
0 g
s
.60844 .33485 m .63211 .30456 L .60227 .34216 L .867 .976 .672 r
F
.62209 .31405 m .64347 .29269 L .64463 .29196 L p .857 .986 .848 r
F P
0 g
s
.68414 .26928 m .6628 .27901 L .64359 .29501 L p .852 .962 .876 r
F P
0 g
s
.64359 .29501 m .63211 .30456 L p .65088 .29183 L .852 .962 .876 r
F P
0 g
s
.65088 .29183 m .65221 .29066 L .64359 .29501 L .852 .962 .876 r
F
.6538 .28985 m .68414 .26928 L .64359 .29501 L F
.63211 .30456 m .65475 .28426 L .64388 .29658 L F
.5977 .34889 m .63211 .30456 L .58961 .35894 L .867 .976 .672 r
F
.60441 .34024 m .60333 .34053 L .63211 .30456 L F
.60082 .34119 m .61185 .32828 L p .60333 .34053 L F P
0 g
s
.61185 .32828 m .63211 .30456 L p .60333 .34053 L .867 .976 .672 r
F P
0 g
s
.65324 .28503 m .63211 .30456 L .62396 .3141 L p .884 .991 .757 r
F P
0 g
s
.63073 .30856 m .65324 .28503 L .62396 .3141 L .884 .991 .757 r
F
.62098 .31959 m .65324 .28503 L .61174 .32841 L F
.62396 .3141 m .61174 .32841 L p .63073 .30856 L F P
0 g
s
.63679 .30035 m .65324 .28503 L p .62767 .31243 L .884 .991 .757 r
F P
0 g
s
.65475 .28426 m .66981 .27658 L p .64388 .29658 L .852 .962 .876 r
F P
0 g
s
.66981 .27658 m .68414 .26928 L p .65762 .28727 L .852 .962 .876 r
F P
0 g
s
.65088 .29183 m .6538 .28985 L .65221 .29066 L .852 .962 .876 r
F
.64388 .29658 m .66981 .27658 L .65762 .28727 L F
.70611 .26794 m .68414 .26928 L .65324 .28503 L p .74 .903 .951 r
F P
0 g
s
.65324 .28503 m .67846 .27243 L .66771 .28035 L .74 .903 .951 r
F
.62555 .3143 m .63679 .30035 L .62767 .31243 L .884 .991 .757 r
F
.61174 .32841 m .60082 .34119 L p .61923 .32147 L F P
0 g
s
.61923 .32147 m .62098 .31959 L .62019 .32035 L .884 .991 .757 r
F
.61923 .32147 m .62019 .32035 L .61174 .32841 L F
.62209 .31405 m .63679 .30035 L p .62004 .31937 L F P
0 g
s
.60082 .34119 m .62209 .31405 L p .62004 .31937 L .884 .991 .757 r
F P
0 g
s
.60082 .34119 m .63679 .30035 L .62327 .31714 L .884 .991 .757 r
F
.59135 .35502 m .60082 .34119 L p .60441 .34024 L .867 .976 .672 r
F P
0 g
s
.65324 .28503 m .67474 .27304 L .67846 .27243 L p .74 .903 .951 r
F P
0 g
s
.67474 .27304 m .65324 .28503 L .63337 .30354 L p .857 .986 .848 r
F P
0 g
s
.63337 .30354 m .62209 .31405 L p .6424 .29823 L .857 .986 .848 r
F P
0 g
s
.6424 .29823 m .64297 .29769 L .63337 .30354 L .857 .986 .848 r
F
.64354 .29734 m .67474 .27304 L .63337 .30354 L F
.62209 .31405 m .64463 .29196 L .63349 .30516 L F
.60082 .34119 m .57951 .37231 L .55426 .40577 L p .825 .954 .61 r
F P
0 g
s
.55426 .40577 m .54665 .41586 L p .55923 .39852 L .825 .954 .61 r
F P
0 g
s
.55923 .39852 m .60082 .34119 L .55426 .40577 L .825 .954 .61 r
F
.54665 .41586 m .56847 .38282 L .60082 .34119 L p F P
0 g
s
.60082 .34119 m .59203 .3525 L p .62209 .31405 L .87 .977 .675 r
F P
0 g
s
.59203 .3525 m .57896 .36933 L p .59799 .34494 L .87 .977 .675 r
F P
0 g
s
.59799 .34494 m .62209 .31405 L .59203 .3525 L .87 .977 .675 r
F
.58688 .35921 m .62209 .31405 L .57896 .36933 L F
.58636 .35987 m .58752 .35722 L .62209 .31405 L F
.59014 .35119 m .59753 .3426 L p .58752 .35722 L F P
0 g
s
.59753 .3426 m .62209 .31405 L p .58752 .35722 L .87 .977 .675 r
F P
0 g
s
.64347 .29269 m .62209 .31405 L .6137 .32379 L p .885 .99 .748 r
F P
0 g
s
.62036 .31764 m .64347 .29269 L .6137 .32379 L .885 .99 .748 r
F
.6105 .32886 m .64347 .29269 L .60131 .3382 L F
.6137 .32379 m .60131 .3382 L p .62036 .31764 L F P
0 g
s
.62549 .30989 m .64347 .29269 L p .61338 .3257 L .885 .99 .748 r
F P
0 g
s
.64463 .29196 m .65209 .28727 L p .63349 .30516 L .857 .986 .848 r
F P
0 g
s
.65209 .28727 m .66017 .28219 L p .64522 .29507 L .857 .986 .848 r
F P
0 g
s
.63349 .30516 m .65209 .28727 L .64522 .29507 L .857 .986 .848 r
F
.66017 .28219 m .67474 .27304 L p .64769 .29411 L F P
0 g
s
.6424 .29823 m .64354 .29734 L .64297 .29769 L .857 .986 .848 r
F
.63349 .30516 m .66017 .28219 L .64769 .29411 L F
.67846 .27243 m .69302 .27007 L p .66771 .28035 L .74 .903 .951 r
F P
0 g
s
.69302 .27007 m .70611 .26794 L p .68142 .27592 L .74 .903 .951 r
F P
0 g
s
.66771 .28035 m .69302 .27007 L .68142 .27592 L .74 .903 .951 r
F
.69052 .27393 m .69302 .27292 L .6949 .27312 L .706 .831 .942 r
F
.7289 .27485 m .70611 .26794 L .67474 .27304 L p .559 .78 .981 r
F P
0 g
s
.67474 .27304 m .69155 .26994 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.69155 .26994 m .69679 .26897 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.69679 .26897 m .67474 .27304 L .64347 .29269 L p .771 .946 .935 r
F P
0 g
s
.64347 .29269 m .66515 .27834 L .66901 .2772 L p .771 .946 .935 r
F P
0 g
s
.64347 .29269 m .66901 .2772 L .65797 .28624 L .771 .946 .935 r
F
.61236 .32666 m .62549 .30989 L .61338 .3257 L .885 .99 .748 r
F
.59014 .35119 m .61174 .32305 L .62549 .30989 L p F P
0 g
s
.60131 .3382 m .59014 .35119 L p .6105 .32886 L .885 .99 .748 r
F P
0 g
s
.59014 .35119 m .62549 .30989 L .61152 .32774 L .885 .99 .748 r
F
.66515 .27834 m .64347 .29269 L .62311 .31217 L p .867 .989 .831 r
F P
0 g
s
.62311 .31217 m .61174 .32305 L p .63325 .30504 L .867 .989 .831 r
F P
0 g
s
.63325 .30504 m .66515 .27834 L .62311 .31217 L .867 .989 .831 r
F
.64983 .28885 m .66515 .27834 L p .637 .3019 L F P
0 g
s
.66901 .2772 m .68372 .27284 L p .65797 .28624 L .771 .946 .935 r
F P
0 g
s
.68372 .27284 m .69679 .26897 L p .67193 .28003 L .771 .946 .935 r
F P
0 g
s
.65797 .28624 m .68372 .27284 L .67193 .28003 L .771 .946 .935 r
F
.69679 .26897 m .7289 .27485 L p .70789 .27415 L .559 .78 .981 r
F P
0 g
s
.7289 .27485 m .74681 .28857 L p .74319 .28673 L .274 .531 .914 r
F P
0 g
s
.75349 .29076 m .762 .29627 L p .7561 .29328 L .274 .531 .914 r
F P
0 g
s
.762 .29627 m .7289 .27485 L p .75401 .29418 L .052 .363 .833 r
F P
0 g
s
.78687 .31948 m .76901 .30282 L p .75409 .29423 L .052 .363 .833 r
F P
0 g
s
.75426 .29437 m .78687 .31948 L .75409 .29423 L .052 .363 .833 r
F
.76901 .30282 m .762 .29627 L p .75401 .29418 L F P
0 g
s
.75263 .28918 m .78687 .31948 L p .76906 .30576 L .052 .363 .833 r
F P
0 g
s
.78687 .31948 m .75263 .28918 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.78687 .31948 m .81274 .34656 L .82239 .36038 L closepath p 0 .059 .603 r
F P
0 g
s
.81274 .34656 m .79367 .3266 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.79367 .3266 m .78687 .31948 L p .77882 .31417 L 0 .252 .765 r
F P
0 g
s
.75263 .28918 m .77733 .30905 L .80538 .33876 L p 0 .252 .765 r
F P
0 g
s
.75263 .28918 m .80538 .33876 L .79645 .33101 L 0 .252 .765 r
F
.7289 .27485 m .75052 .2879 L p .76831 .30504 L .052 .363 .833 r
F P
0 g
s
.73297 .28206 m .72043 .2733 L .69679 .26897 L p .342 .61 .949 r
F P
0 g
s
.75401 .29418 m .75426 .29437 L .75409 .29423 L .052 .363 .833 r
F
.7289 .27485 m .76831 .30504 L .76699 .30417 L F
.75052 .2879 m .75263 .28918 L p .76906 .30576 L F P
0 g
s
.75263 .28918 m .7289 .27485 L p .72099 .2734 L .342 .61 .949 r
F P
0 g
s
.71957 .2727 m .75263 .28918 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.75263 .28918 m .71957 .2727 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.77733 .30905 m .75968 .29485 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.75968 .29485 m .75263 .28918 L p .74427 .28824 L .146 .447 .879 r
F P
0 g
s
.71957 .2727 m .74056 .28218 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.74056 .28218 m .74319 .28337 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.69679 .26897 m .71555 .27204 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.71555 .27204 m .71957 .2727 L p .73297 .28206 L .342 .61 .949 r
F P
0 g
s
.71957 .2727 m .69679 .26897 L .67605 .27511 L p .622 .844 .985 r
F P
0 g
s
.67605 .27511 m .66515 .27834 L p .68754 .27602 L .622 .844 .985 r
F P
0 g
s
.68754 .27602 m .71957 .2727 L .67605 .27511 L .622 .844 .985 r
F
.66515 .27834 m .6873 .27135 L .71957 .2727 L p F P
0 g
s
.74319 .28337 m .71957 .2727 L .6873 .27135 L p .435 .692 .973 r
F P
0 g
s
.72254 .27893 m .72224 .27875 L .74319 .28337 L .435 .692 .973 r
F
.71008 .27158 m .73248 .27956 L p .72224 .27875 L F P
0 g
s
.73248 .27956 m .74319 .28337 L p .72224 .27875 L .435 .692 .973 r
F P
0 g
s
.6873 .27135 m .70528 .27153 L p .72254 .27893 L .435 .692 .973 r
F P
0 g
s
.70528 .27153 m .71008 .27158 L p .72254 .27893 L .435 .692 .973 r
F P
0 g
s
.74319 .28337 m .77733 .30905 L p .75858 .29725 L .146 .447 .879 r
F P
0 g
s
.80538 .33876 m .81274 .34656 L p .79645 .33101 L 0 .252 .765 r
F P
0 g
s
.6334 .30014 m .64983 .28885 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.62193 .31452 m .64983 .28885 L .637 .3019 L .867 .989 .831 r
F
.6873 .27135 m .66515 .27834 L .64442 .29257 L p .801 .962 .914 r
F P
0 g
s
.64442 .29257 m .6334 .30014 L p .65511 .28854 L .801 .962 .914 r
F P
0 g
s
.65511 .28854 m .6873 .27135 L .64442 .29257 L .801 .962 .914 r
F
.65852 .28235 m .67389 .27648 L p .64735 .29269 L F P
0 g
s
.67389 .27648 m .6873 .27135 L p .66184 .28495 L .801 .962 .914 r
F P
0 g
s
.64735 .29269 m .67389 .27648 L .66184 .28495 L .801 .962 .914 r
F
.6334 .30014 m .65529 .28359 L .65852 .28235 L p F P
0 g
s
.6334 .30014 m .65852 .28235 L .64735 .29269 L .801 .962 .914 r
F
.71008 .27158 m .6873 .27135 L .65529 .28359 L p .685 .883 .972 r
F P
0 g
s
.65529 .28359 m .67757 .27376 L .69797 .27239 L p .685 .883 .972 r
F P
0 g
s
.69797 .27239 m .71008 .27158 L p .68627 .2768 L .685 .883 .972 r
F P
0 g
s
.65529 .28359 m .69797 .27239 L .68627 .2768 L .685 .883 .972 r
F
.61152 .32774 m .61236 .32666 L .61338 .3257 L .885 .99 .748 r
F
.61174 .32305 m .63253 .30106 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.63253 .30106 m .6334 .30014 L p .62193 .31452 L .867 .989 .831 r
F P
0 g
s
.57896 .36933 m .56847 .38282 L p .58688 .35921 L .87 .977 .675 r
F P
0 g
s
.56847 .38282 m .57549 .37257 L p .58636 .35987 L .87 .977 .675 r
F P
0 g
s
.57549 .37257 m .59014 .35119 L p .58636 .35987 L .87 .977 .675 r
F P
0 g
s
.62327 .31714 m .62555 .3143 L .62767 .31243 L .884 .991 .757 r
F
.58961 .35894 m .57951 .37231 L p .5977 .34889 L .867 .976 .672 r
F P
0 g
s
.57951 .37231 m .59135 .35502 L p .60441 .34024 L .867 .976 .672 r
F P
0 g
s
.76699 .30417 m .76831 .30504 L .76906 .30576 L .052 .363 .833 r
F
.81388 .35059 m .82239 .36038 L p .80456 .34146 L 0 .18 .714 r
F P
0 g
s
.77526 .31197 m .77799 .31407 L .77971 .31593 L 0 .301 .795 r
F
.82162 .3615 m .8319 .374 L p .81202 .3514 L 0 .13 .677 r
F P
0 g
s
.78319 .32082 m .78733 .32433 L .79053 .32805 L 0 .265 .772 r
F
.7558 .29756 m .75998 .2998 L .76344 .30328 L .242 .431 .848 r
F
.8282 .37109 m .84127 .38743 L p .81878 .36098 L 0 .106 .658 r
F P
0 g
s
.79084 .33111 m .79637 .33589 L .8022 .34295 L 0 .256 .763 r
F
.76518 .30668 m .7687 .31056 L .76391 .30792 L .267 .414 .824 r
F
.82457 .37102 m .81058 .35661 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.81058 .35661 m .7997 .34541 L p .79728 .34198 L .033 .269 .767 r
F P
0 g
s
.73962 .29454 m .74357 .29519 L .74752 .29884 L .48 .529 .831 r
F
.70686 .28919 m .69126 .28527 L p .71783 .29098 L .627 .606 .81 r
F P
0 g
s
.67087 .2995 m .69126 .28527 L .72188 .29295 L p .724 .656 .782 r
F P
0 g
s
.86196 .437 m .83852 .42512 L .80581 .39258 L p .344 .446 .822 r
F P
0 g
s
.80581 .39258 m .82878 .40373 L .86196 .437 L p .344 .446 .822 r
F P
0 g
s
.61202 .44013 m .59205 .46732 L .5611 .46986 L p .821 .747 .781 r
F P
0 g
s
.5611 .46986 m .58135 .44728 L .61202 .44013 L p .821 .747 .781 r
F P
0 g
s
.69126 .28527 m .67087 .2995 L .64096 .31499 L p .832 .771 .794 r
F P
0 g
s
.67087 .2995 m .65083 .32102 L .62085 .3423 L p .88 .809 .775 r
F P
0 g
s
.62085 .3423 m .64096 .31499 L .67087 .2995 L p .88 .809 .775 r
F P
0 g
s
.90323 .4762 m .8802 .47055 L .84818 .44643 L p .327 .532 .901 r
F P
0 g
s
.84818 .44643 m .87114 .454 L .90323 .4762 L p .327 .532 .901 r
F P
0 g
s
.62134 .39019 m .60144 .41979 L .57066 .43451 L p .886 .826 .783 r
F P
0 g
s
.57066 .43451 m .59093 .4074 L .62134 .39019 L p .886 .826 .783 r
F P
0 g
s
.80933 .3633 m .78578 .34578 L .75334 .3142 L p .356 .423 .793 r
F P
0 g
s
.75334 .3142 m .77595 .32583 L .80933 .3633 L p .356 .423 .793 r
F P
0 g
s
.65083 .32102 m .63093 .34783 L .6007 .37247 L p .91 .844 .766 r
F P
0 g
s
.6007 .37247 m .62085 .3423 L .65083 .32102 L p .91 .844 .766 r
F P
0 g
s
.85268 .41988 m .82878 .40373 L .79574 .36829 L p .259 .393 .809 r
F P
0 g
s
.79574 .36829 m .81903 .38291 L .85268 .41988 L p .259 .393 .809 r
F P
0 g
s
.59205 .46732 m .57188 .4883 L .54075 .482 L p .757 .822 .903 r
F P
0 g
s
.54075 .482 m .5611 .46986 L .59205 .46732 L p .757 .822 .903 r
F P
0 g
s
.8802 .47055 m .90323 .4762 L .9116 .48819 L closepath p .337 .583 .934 r
F P
0 g
s
.63093 .34783 m .611 .37757 L .5804 .40265 L p .928 .888 .772 r
F P
0 g
s
.5804 .40265 m .6007 .37247 L .63093 .34783 L p .928 .888 .772 r
F P
0 g
s
.60144 .41979 m .58135 .44728 L .55026 .45649 L p .871 .871 .834 r
F P
0 g
s
.55026 .45649 m .57066 .43451 L .60144 .41979 L p .871 .871 .834 r
F P
0 g
s
.89475 .46405 m .87114 .454 L .83852 .42512 L p .196 .444 .87 r
F P
0 g
s
.83852 .42512 m .86196 .437 L .89475 .46405 L p .196 .444 .87 r
F P
0 g
s
.84334 .40297 m .81903 .38291 L .78578 .34578 L p .174 .343 .794 r
F P
0 g
s
.78578 .34578 m .80933 .3633 L .84334 .40297 L p .174 .343 .794 r
F P
0 g
s
.5611 .46986 m .54075 .482 L .50942 .47892 L p .662 .867 .977 r
F P
0 g
s
.58135 .44728 m .5611 .46986 L .5298 .47116 L p .8 .91 .916 r
F P
0 g
s
.5298 .47116 m .55026 .45649 L .58135 .44728 L p .8 .91 .916 r
F P
0 g
s
.611 .37757 m .59093 .4074 L .55992 .43007 L p .923 .938 .794 r
F P
0 g
s
.55992 .43007 m .5804 .40265 L .611 .37757 L p .923 .938 .794 r
F P
0 g
s
.50942 .47892 m .5298 .47116 L .5611 .46986 L p .662 .867 .977 r
F P
0 g
s
.88615 .45172 m .86196 .437 L .82878 .40373 L p .063 .349 .824 r
F P
0 g
s
.82878 .40373 m .85268 .41988 L .88615 .45172 L p .063 .349 .824 r
F P
0 g
s
.87114 .454 m .89475 .46405 L .90323 .4762 L closepath p .184 .485 .899 r
F P
0 g
s
.5298 .47116 m .50942 .47892 L .47789 .47256 L p .062 0 0 r
F P
0 g
s
.64096 .31499 m .62085 .3423 L .59036 .37442 L p .941 .935 .763 r
F P
0 g
s
.59036 .37442 m .61078 .34359 L .64096 .31499 L p .941 .935 .763 r
F P
0 g
s
.83396 .38659 m .80933 .3633 L .77595 .32583 L p .096 .3 .779 r
F P
0 g
s
.77595 .32583 m .7997 .34541 L .83396 .38659 L p .096 .3 .779 r
F P
0 g
s
.59093 .4074 m .57066 .43451 L .53931 .45224 L p .87 .989 .827 r
F P
0 g
s
.53931 .45224 m .55992 .43007 L .59093 .4074 L p .87 .989 .827 r
F P
0 g
s
.87743 .43923 m .85268 .41988 L .81903 .38291 L p 0 .26 .769 r
F P
0 g
s
.81903 .38291 m .84334 .40297 L .87743 .43923 L p 0 .26 .769 r
F P
0 g
s
.47789 .47256 m .49816 .47247 L p .51974 .47143 L .062 0 0 r
F P
0 g
s
.49816 .47247 m .47789 .47256 L .44612 .46877 L p .517 .011 0 r
F P
0 g
s
.44612 .46877 m .46616 .47508 L .49816 .47247 L p .517 .011 0 r
F P
0 g
s
.49816 .47247 m .48197 .47379 L p .48429 .47314 L .41 0 0 r
F P
0 g
s
.49816 .47247 m .5298 .47116 L p .51974 .47143 L .062 0 0 r
F P
0 g
s
.55026 .45649 m .5298 .47116 L .51587 .47174 L p 0 0 0 r
F P
0 g
s
.51587 .47174 m .49816 .47247 L p .52731 .46353 L 0 0 0 r
F P
0 g
s
.52731 .46353 m .55026 .45649 L .51587 .47174 L 0 0 0 r
F
.49816 .47247 m .51867 .46705 L .55026 .45649 L p F P
0 g
s
.51867 .46705 m .53931 .45224 L .5569 .44229 L p .655 .969 .818 r
F P
0 g
s
.5569 .44229 m .57066 .43451 L p .54783 .44881 L .655 .969 .818 r
F P
0 g
s
.51867 .46705 m .5569 .44229 L .54783 .44881 L .655 .969 .818 r
F
.47634 .47353 m .50667 .46889 L .49816 .47247 L .41 0 0 r
F
.51867 .46705 m .50252 .47132 L p .50667 .46889 L F P
0 g
s
.50252 .47132 m .49816 .47247 L p .50667 .46889 L .41 0 0 r
F P
0 g
s
.46616 .47508 m .47634 .47353 L .48429 .47314 L .41 0 0 r
F
.48197 .47379 m .46616 .47508 L p .48429 .47314 L F P
0 g
s
.46616 .47508 m .48657 .47657 L .51867 .46705 L p .41 0 0 r
F P
0 g
s
.53931 .45224 m .51867 .46705 L .50393 .47142 L p .169 0 0 r
F P
0 g
s
.50393 .47142 m .48657 .47657 L p .51507 .46343 L .169 0 0 r
F P
0 g
s
.51507 .46343 m .53931 .45224 L .50393 .47142 L .169 0 0 r
F
.52003 .46314 m .53931 .45224 L p .51507 .46343 L F P
0 g
s
.50899 .46623 m .51326 .46504 L .51507 .46343 L .169 0 0 r
F
.51326 .46504 m .52003 .46314 L .51507 .46343 L F
.48657 .47657 m .50729 .47035 L .52003 .46314 L p F P
0 g
s
.48657 .47657 m .52003 .46314 L .50899 .46623 L .169 0 0 r
F
.55992 .43007 m .53931 .45224 L .52585 .45985 L p 0 0 0 r
F P
0 g
s
.52585 .45985 m .50729 .47035 L p .53781 .44699 L 0 0 0 r
F P
0 g
s
.53781 .44699 m .55992 .43007 L .52585 .45985 L 0 0 0 r
F
.52816 .45535 m .54534 .44167 L p .51738 .46263 L F P
0 g
s
.51738 .46263 m .54534 .44167 L .53576 .44856 L 0 0 0 r
F
.52816 .45535 m .54903 .43291 L .56725 .41534 L p .677 .932 .637 r
F P
0 g
s
.56725 .41534 m .5804 .40265 L p .55851 .42474 L .677 .932 .637 r
F P
0 g
s
.52816 .45535 m .56725 .41534 L .55851 .42474 L .677 .932 .637 r
F
.54534 .44167 m .55992 .43007 L p .53576 .44856 L 0 0 0 r
F P
0 g
s
.50729 .47035 m .52092 .46055 L p .51738 .46263 L 0 0 0 r
F P
0 g
s
.52092 .46055 m .52816 .45535 L p .51738 .46263 L 0 0 0 r
F P
0 g
s
.62085 .3423 m .6007 .37247 L .56978 .40511 L p .931 .969 .743 r
F P
0 g
s
.56978 .40511 m .59036 .37442 L .62085 .3423 L p .931 .969 .743 r
F P
0 g
s
.57066 .43451 m .55026 .45649 L .51867 .46705 L p .655 .969 .818 r
F P
0 g
s
.86196 .437 m .88615 .45172 L .89475 .46405 L closepath p .016 .367 .836 r
F P
0 g
s
.46616 .47508 m .44612 .46877 L .4141 .46529 L p .527 0 0 r
F P
0 g
s
.6007 .37247 m .5804 .40265 L .54903 .43291 L p .866 .987 .715 r
F P
0 g
s
.54903 .43291 m .56978 .40511 L .6007 .37247 L p .866 .987 .715 r
F P
0 g
s
.86858 .42655 m .84334 .40297 L .80933 .3633 L p 0 .186 .719 r
F P
0 g
s
.80933 .3633 m .83396 .38659 L .86858 .42655 L p 0 .186 .719 r
F P
0 g
s
.85268 .41988 m .87743 .43923 L .88615 .45172 L closepath p 0 .245 .755 r
F P
0 g
s
.5804 .40265 m .55992 .43007 L .52816 .45535 L p .677 .932 .637 r
F P
0 g
s
.4141 .46529 m .43392 .47305 L .46616 .47508 L p .527 0 0 r
F P
0 g
s
.43392 .47305 m .4141 .46529 L .38205 .45677 L p .65 .192 .152 r
F P
0 g
s
.38205 .45677 m .40142 .47066 L .43392 .47305 L p .65 .192 .152 r
F P
0 g
s
.40142 .47066 m .38205 .45677 L .34962 .45246 L p .659 .199 .15 r
F P
0 g
s
.85961 .4137 m .83396 .38659 L .7997 .34541 L p 0 .134 .68 r
F P
0 g
s
.7997 .34541 m .82457 .37102 L .85961 .4137 L p 0 .134 .68 r
F P
0 g
s
.48657 .47657 m .46616 .47508 L .43392 .47305 L p .607 .188 .222 r
F P
0 g
s
.61078 .34359 m .59036 .37442 L .55897 .41316 L p .852 .968 .646 r
F P
0 g
s
.55897 .41316 m .57987 .38189 L .61078 .34359 L p .852 .968 .646 r
F P
0 g
s
.84334 .40297 m .86858 .42655 L .87743 .43923 L closepath p 0 .14 .672 r
F P
0 g
s
.34962 .45246 m .3687 .46701 L .40142 .47066 L p .659 .199 .15 r
F P
0 g
s
.3687 .46701 m .34962 .45246 L .31696 .44801 L p .552 0 0 r
F P
0 g
s
.43392 .47305 m .45401 .48421 L .48657 .47657 L p .607 .188 .222 r
F P
0 g
s
.48657 .47657 m .45401 .48421 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.50729 .47035 m .48912 .47581 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.48912 .47581 m .48657 .47657 L p .49481 .47359 L .464 .025 .118 r
F P
0 g
s
.52816 .45535 m .51233 .46672 L p .51656 .4625 L .253 0 0 r
F P
0 g
s
.45401 .48421 m .47462 .48604 L .50729 .47035 L p .464 .025 .118 r
F P
0 g
s
.5025 .47006 m .52816 .45535 L .49158 .47789 L .253 0 0 r
F
.50729 .47035 m .49158 .47789 L p .51656 .4625 L F P
0 g
s
.51233 .46672 m .50729 .47035 L p .51656 .4625 L .253 0 0 r
F P
0 g
s
.49158 .47789 m .47462 .48604 L p .5025 .47006 L .253 0 0 r
F P
0 g
s
.47462 .48604 m .49558 .4792 L .52816 .45535 L p .253 0 0 r
F P
0 g
s
.51673 .46407 m .53379 .44762 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.53379 .44762 m .54903 .43291 L p .52369 .45486 L 0 0 0 r
F P
0 g
s
.50798 .46847 m .53379 .44762 L .52369 .45486 L 0 0 0 r
F
.53748 .44405 m .51673 .46407 L p .55085 .42615 L F P
0 g
s
.51673 .46407 m .5379 .44137 L .53914 .43996 L p 0 0 0 r
F P
0 g
s
.55085 .42615 m .56978 .40511 L .53748 .44405 L 0 0 0 r
F
.53914 .43996 m .56978 .40511 L p .53214 .44694 L F P
0 g
s
.51673 .46407 m .53914 .43996 L .53214 .44694 L 0 0 0 r
F
.50798 .46847 m .51519 .46484 L .49558 .4792 L p F P
0 g
s
.54903 .43291 m .52816 .45535 L p .51825 .46261 L 0 0 0 r
F P
0 g
s
.49558 .4792 m .51369 .46624 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.51369 .46624 m .51673 .46407 L p .50798 .46847 L 0 0 0 r
F P
0 g
s
.56978 .40511 m .54903 .43291 L .53748 .44405 L p 0 0 0 r
F P
0 g
s
.5379 .44137 m .55897 .41316 L .57916 .38824 L p .7 .905 .549 r
F P
0 g
s
.57916 .38824 m .59036 .37442 L p .57167 .39827 L .7 .905 .549 r
F P
0 g
s
.5379 .44137 m .57916 .38824 L .57167 .39827 L .7 .905 .549 r
F
.59036 .37442 m .56978 .40511 L .5379 .44137 L p F P
0 g
s
.45401 .48421 m .43392 .47305 L .40142 .47066 L p .661 .256 .268 r
F P
0 g
s
.31696 .44801 m .33602 .45815 L .3687 .46701 L p .552 0 0 r
F P
0 g
s
.33602 .45815 m .31696 .44801 L .28437 .43947 L p .571 .015 0 r
F P
0 g
s
.83396 .38659 m .85961 .4137 L .86858 .42655 L closepath p 0 .059 .603 r
F P
0 g
s
.28437 .43947 m .30315 .44989 L .33602 .45815 L p .571 .015 0 r
F P
0 g
s
.30315 .44989 m .28437 .43947 L .25138 .43369 L p .38 0 0 r
F P
0 g
s
.40142 .47066 m .4211 .48759 L .45401 .48421 L p .661 .256 .268 r
F P
0 g
s
.4211 .48759 m .40142 .47066 L .3687 .46701 L p .682 .256 .229 r
F P
0 g
s
.25138 .43369 m .27018 .44086 L .30315 .44989 L p .38 0 0 r
F P
0 g
s
.27018 .44086 m .25138 .43369 L .21815 .42815 L p .335 .672 .976 r
F P
0 g
s
.3687 .46701 m .38804 .48502 L .4211 .48759 L p .682 .256 .229 r
F P
0 g
s
.38804 .48502 m .3687 .46701 L .33602 .45815 L p .707 .282 .236 r
F P
0 g
s
.82457 .37102 m .8505 .40066 L .85961 .4137 L closepath p 0 .006 .554 r
F P
0 g
s
.47462 .48604 m .45401 .48421 L .4211 .48759 L p .578 .158 .208 r
F P
0 g
s
.4211 .48759 m .44144 .49665 L .47462 .48604 L p .578 .158 .208 r
F P
0 g
s
.49558 .4792 m .47462 .48604 L .45792 .49138 L p .468 .046 .155 r
F P
0 g
s
.45792 .49138 m .44144 .49665 L p .46841 .48796 L .468 .046 .155 r
F P
0 g
s
.46841 .48796 m .49558 .4792 L .45792 .49138 L .468 .046 .155 r
F
.46229 .49823 m .48351 .49143 L .50037 .47754 L p .297 0 .066 r
F P
0 g
s
.44144 .49665 m .46229 .49823 L .49558 .4792 L p .468 .046 .155 r
F P
0 g
s
.49558 .4792 m .46229 .49823 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.51673 .46407 m .49976 .47622 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.49976 .47622 m .49558 .4792 L p .50571 .47099 L .297 0 .066 r
F P
0 g
s
.50037 .47754 m .51673 .46407 L p .48974 .48101 L .297 0 .066 r
F P
0 g
s
.46229 .49823 m .50037 .47754 L .48974 .48101 L .297 0 .066 r
F
.51673 .46407 m .51495 .46554 L p .52062 .45949 L .049 0 0 r
F P
0 g
s
.51495 .46554 m .50215 .47608 L p .52062 .45949 L .049 0 0 r
F P
0 g
s
.50215 .47608 m .52934 .44925 L .52062 .45949 L .049 0 0 r
F
.5379 .44137 m .52419 .45607 L p .52934 .44925 L F P
0 g
s
.52419 .45607 m .51673 .46407 L p .52934 .44925 L .049 0 0 r
F P
0 g
s
.50215 .47608 m .48351 .49143 L p .5144 .463 L .049 0 0 r
F P
0 g
s
.5144 .463 m .52934 .44925 L .50215 .47608 L .049 0 0 r
F
.48351 .49143 m .50496 .47618 L .5379 .44137 L p F P
0 g
s
.55897 .41316 m .5379 .44137 L .52529 .45469 L p 0 0 0 r
F P
0 g
s
.52529 .45469 m .50496 .47618 L p .53615 .43979 L 0 0 0 r
F P
0 g
s
.53615 .43979 m .53879 .4367 L .53773 .43811 L 0 0 0 r
F
.53615 .43979 m .53773 .43811 L .52529 .45469 L F
.53879 .4367 m .55897 .41316 L .52529 .45469 L F
.50496 .47618 m .52646 .45328 L .52793 .45146 L p F P
0 g
s
.50496 .47618 m .52793 .45146 L .52201 .45666 L 0 0 0 r
F
.50496 .47618 m .54548 .42981 L .53631 .4396 L F
.48351 .49143 m .46229 .49823 L .44527 .50392 L p .463 .04 .15 r
F P
0 g
s
.44527 .50392 m .42849 .50952 L p .45575 .50056 L .463 .04 .15 r
F P
0 g
s
.45575 .50056 m .48351 .49143 L .44527 .50392 L .463 .04 .15 r
F
.44957 .51102 m .47107 .50416 L .48794 .49024 L p .295 0 .063 r
F P
0 g
s
.42849 .50952 m .44957 .51102 L .48351 .49143 L p .463 .04 .15 r
F P
0 g
s
.48351 .49143 m .4668 .50108 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.50496 .47618 m .48617 .48954 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.48617 .48954 m .48351 .49143 L p .49165 .48486 L .295 0 .063 r
F P
0 g
s
.4668 .50108 m .44957 .51102 L p .47798 .49315 L .295 0 .063 r
F P
0 g
s
.47798 .49315 m .50496 .47618 L .4668 .50108 L .295 0 .063 r
F
.48794 .49024 m .50496 .47618 L p .47708 .49372 L F P
0 g
s
.52646 .45328 m .50975 .47108 L p .51507 .46427 L .057 0 0 r
F P
0 g
s
.50184 .47589 m .52646 .45328 L .48946 .48898 L .057 0 0 r
F
.50496 .47618 m .48946 .48898 L p .51507 .46427 L F P
0 g
s
.50975 .47108 m .50496 .47618 L p .51507 .46427 L .057 0 0 r
F P
0 g
s
.50273 .47508 m .50195 .47617 L .52646 .45328 L .057 0 0 r
F
.51069 .46997 m .52646 .45328 L p .50195 .47617 L F P
0 g
s
.52793 .45146 m .54548 .42981 L p .52201 .45666 L 0 0 0 r
F P
0 g
s
.49282 .48889 m .50653 .47292 L p .50195 .47617 L .057 0 0 r
F P
0 g
s
.54548 .42981 m .55897 .41316 L p .53631 .4396 L 0 0 0 r
F P
0 g
s
.55422 .41902 m .52646 .45328 L p .56155 .40637 L 0 0 0 r
F P
0 g
s
.56155 .40637 m .57209 .39228 L .56803 .39836 L 0 0 0 r
F
.56155 .40637 m .56803 .39836 L .55422 .41902 L F
.54787 .42474 m .55231 .41881 L p .55056 .42113 L F P
0 g
s
.52646 .45328 m .54787 .42474 L p .55056 .42113 L 0 0 0 r
F P
0 g
s
.55231 .41881 m .56853 .39708 L p .54672 .42621 L 0 0 0 r
F P
0 g
s
.52646 .45328 m .55231 .41881 L .54672 .42621 L 0 0 0 r
F
.52646 .45328 m .56853 .39708 L .5607 .40751 L F
.52646 .45328 m .49282 .48889 L p .51815 .45938 L F P
0 g
s
.54787 .42474 m .5335 .4439 L p .51815 .45938 L 0 0 0 r
F P
0 g
s
.5335 .4439 m .52646 .45328 L p .51815 .45938 L 0 0 0 r
F P
0 g
s
.44957 .51102 m .48794 .49024 L .47708 .49372 L .295 0 .063 r
F
.48946 .48898 m .47107 .50416 L p .50184 .47589 L .057 0 0 r
F P
0 g
s
.49282 .48889 m .51466 .46595 L .51649 .46368 L p 0 0 0 r
F P
0 g
s
.49282 .48889 m .51649 .46368 L .5089 .47015 L 0 0 0 r
F
.47107 .50416 m .48336 .49554 L p .50273 .47508 L .057 0 0 r
F P
0 g
s
.48336 .49554 m .49282 .48889 L p .50273 .47508 L .057 0 0 r
F P
0 g
s
.44957 .51102 m .42849 .50952 L .39451 .51105 L p .565 .122 .157 r
F P
0 g
s
.39451 .51105 m .41524 .51975 L .44957 .51102 L p .565 .122 .157 r
F P
0 g
s
.47107 .50416 m .44957 .51102 L .43215 .51545 L p .44 0 .088 r
F P
0 g
s
.43215 .51545 m .41524 .51975 L p .44269 .51209 L .44 0 .088 r
F P
0 g
s
.44269 .51209 m .47107 .50416 L .43215 .51545 L .44 0 .088 r
F
.41524 .51975 m .43655 .52104 L .47107 .50416 L p F P
0 g
s
.47107 .50416 m .45364 .51268 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.49282 .48889 m .47143 .50391 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.47143 .50391 m .47107 .50416 L p .47817 .49779 L .247 0 0 r
F P
0 g
s
.45364 .51268 m .43655 .52104 L p .46492 .50483 L .247 0 0 r
F P
0 g
s
.46492 .50483 m .49282 .48889 L .45364 .51268 L .247 0 0 r
F
.47535 .50166 m .49282 .48889 L p .46429 .50519 L F P
0 g
s
.43655 .52104 m .45831 .51412 L .47535 .50166 L p .247 0 0 r
F P
0 g
s
.43655 .52104 m .47535 .50166 L .46429 .50519 L .247 0 0 r
F
.51466 .46595 m .49282 .48889 L .45831 .51412 L p 0 0 0 r
F P
0 g
s
.49481 .48292 m .49214 .48588 L .51466 .46595 L 0 0 0 r
F
.48035 .49895 m .49867 .48133 L p .49214 .48588 L F P
0 g
s
.49867 .48133 m .51466 .46595 L p .49214 .48588 L 0 0 0 r
F P
0 g
s
.53425 .44165 m .54787 .42474 L p .52746 .44853 L 0 0 0 r
F P
0 g
s
.52477 .45167 m .52583 .45054 L .52746 .44853 L 0 0 0 r
F
.52583 .45054 m .53425 .44165 L .52746 .44853 L F
.5089 .47015 m .51619 .46394 L .52657 .45029 L F
.51619 .46394 m .51649 .46368 L .52657 .45029 L F
.51649 .46368 m .53425 .44165 L p .52657 .45029 L F P
0 g
s
.5089 .47015 m .53425 .44165 L .52477 .45167 L 0 0 0 r
F
.51466 .46595 m .54093 .43076 L .5444 .42775 L F
.56913 .39296 m .55469 .41456 L p .54093 .43076 L F P
0 g
s
.55469 .41456 m .54787 .42474 L p .54093 .43076 L 0 0 0 r
F P
0 g
s
.53644 .43729 m .54155 .43037 L p .54033 .43198 L 0 0 0 r
F P
0 g
s
.51466 .46595 m .53644 .43729 L p .54033 .43198 L 0 0 0 r
F P
0 g
s
.54155 .43037 m .56913 .39296 L p .53407 .43995 L 0 0 0 r
F P
0 g
s
.51466 .46595 m .54155 .43037 L .53407 .43995 L 0 0 0 r
F
.53644 .43729 m .55807 .40522 L .58472 .36822 L p .697 .882 .497 r
F P
0 g
s
.58472 .36822 m .5902 .3606 L p .58057 .37435 L .697 .882 .497 r
F P
0 g
s
.53644 .43729 m .58472 .36822 L .58057 .37435 L .697 .882 .497 r
F
.54787 .42474 m .53886 .43592 L p .5444 .42775 L 0 0 0 r
F P
0 g
s
.53886 .43592 m .51466 .46595 L p .5444 .42775 L 0 0 0 r
F P
0 g
s
.53644 .43729 m .51466 .46595 L .49874 .48127 L p 0 0 0 r
F P
0 g
s
.49874 .48127 m .48035 .49895 L p .50197 .4752 L 0 0 0 r
F P
0 g
s
.50197 .4752 m .50612 .47179 L .49874 .48127 L 0 0 0 r
F
.50197 .4752 m .51246 .46366 L .50612 .47179 L F
.51246 .46366 m .53644 .43729 L .49874 .48127 L F
.49681 .48086 m .5036 .4747 L .52025 .45509 L F
.48035 .49895 m .50252 .47624 L .50486 .47355 L p F P
0 g
s
.48035 .49895 m .50486 .47355 L .49681 .48086 L 0 0 0 r
F
.45831 .51412 m .47583 .50207 L p .49481 .48292 L F P
0 g
s
.47583 .50207 m .48035 .49895 L p .49481 .48292 L 0 0 0 r
F P
0 g
s
.41524 .51975 m .39451 .51105 L .36062 .50298 L p .63 .146 .084 r
F P
0 g
s
.36062 .50298 m .38091 .51635 L .41524 .51975 L p .63 .146 .084 r
F P
0 g
s
.43655 .52104 m .41524 .51975 L .40021 .51826 L p .538 .043 .029 r
F P
0 g
s
.40021 .51826 m .38091 .51635 L p .3934 .5174 L .538 .043 .029 r
F P
0 g
s
.3934 .5174 m .43655 .52104 L .40021 .51826 L .538 .043 .029 r
F
.3469 .50178 m .36735 .51369 L .36964 .5144 L p .568 .001 0 r
F P
0 g
s
.38091 .51635 m .36062 .50298 L .32706 .48664 L p .644 .096 0 r
F P
0 g
s
.32706 .48664 m .3469 .50178 L .38091 .51635 L p .644 .096 0 r
F P
0 g
s
.38091 .51635 m .40183 .52434 L .43655 .52104 L p .538 .043 .029 r
F P
0 g
s
.40183 .52434 m .38091 .51635 L .35207 .504 L p .568 .001 0 r
F P
0 g
s
.35207 .504 m .3469 .50178 L p .35183 .50381 L .568 .001 0 r
F P
0 g
s
.35183 .50381 m .40183 .52434 L .35207 .504 L .568 .001 0 r
F
.3469 .50178 m .32706 .48664 L .2939 .46451 L p .449 0 0 r
F P
0 g
s
.2939 .46451 m .3134 .47861 L .3469 .50178 L p .449 0 0 r
F P
0 g
s
.3134 .47861 m .33341 .49141 L .34932 .50185 L p 0 .188 .618 r
F P
0 g
s
.3469 .50178 m .36964 .5144 L .38117 .51585 L .568 .001 0 r
F
.34932 .50185 m .36735 .51369 L p .35019 .50253 L 0 .188 .618 r
F P
0 g
s
.3134 .47861 m .34932 .50185 L .35019 .50253 L 0 .188 .618 r
F
.36964 .5144 m .40183 .52434 L p .38117 .51585 L .568 .001 0 r
F P
0 g
s
.45831 .51412 m .43655 .52104 L .41874 .52273 L p .371 0 0 r
F P
0 g
s
.41874 .52273 m .40183 .52434 L p .42928 .51937 L .371 0 0 r
F P
0 g
s
.42928 .51937 m .45831 .51412 L .41874 .52273 L .371 0 0 r
F
.40183 .52434 m .42334 .52521 L .45831 .51412 L p F P
0 g
s
.48035 .49895 m .45831 .51412 L .44009 .5199 L p .11 0 0 r
F P
0 g
s
.44009 .5199 m .42334 .52521 L p .45143 .51227 L .11 0 0 r
F P
0 g
s
.45143 .51227 m .48035 .49895 L .44009 .5199 L .11 0 0 r
F
.42334 .52521 m .44532 .51822 L .46243 .50881 L p F P
0 g
s
.46243 .50881 m .48035 .49895 L p .45112 .51242 L .11 0 0 r
F P
0 g
s
.42334 .52521 m .46243 .50881 L .45112 .51242 L .11 0 0 r
F
.46242 .50881 m .44532 .51822 L p .47499 .49645 L 0 0 0 r
F P
0 g
s
.47499 .49645 m .50252 .47624 L .46242 .50881 L 0 0 0 r
F
.44532 .51822 m .4675 .50341 L .48082 .49251 L F
.44532 .51822 m .48082 .49251 L .47525 .49626 L F
.4675 .50341 m .46762 .50333 L p .48486 .4892 L F P
0 g
s
.46762 .50333 m .49007 .48119 L .51105 .46094 L p .528 .842 .535 r
F P
0 g
s
.51105 .46094 m .52465 .44781 L p .50081 .47102 L .528 .842 .535 r
F P
0 g
s
.46762 .50333 m .51105 .46094 L .50081 .47102 L .528 .842 .535 r
F
.50252 .47624 m .48035 .49895 L .46242 .50881 L p 0 0 0 r
F P
0 g
s
.47525 .49626 m .48082 .49251 L .48486 .4892 L 0 0 0 r
F
.46762 .50333 m .50252 .47624 L p .48486 .4892 L F P
0 g
s
.5036 .4747 m .50486 .47355 L .52025 .45509 L 0 0 0 r
F
.50252 .47624 m .52465 .44781 L .54681 .41958 L p .571 .82 .446 r
F P
0 g
s
.54681 .41958 m .55807 .40522 L p .5381 .43075 L .571 .82 .446 r
F P
0 g
s
.50252 .47624 m .54681 .41958 L .5381 .43075 L .571 .82 .446 r
F
.50486 .47355 m .53644 .43729 L p .52025 .45509 L 0 0 0 r
F P
0 g
s
.57209 .39228 m .57987 .38189 L .55422 .41902 L 0 0 0 r
F
.56853 .39708 m .57987 .38189 L p .5607 .40751 L F P
0 g
s
.57987 .38189 m .55897 .41316 L .55422 .41902 L p 0 0 0 r
F P
0 g
s
.54787 .42474 m .56913 .39296 L .596 .35651 L p .747 .913 .541 r
F P
0 g
s
.596 .35651 m .60059 .35028 L p .59293 .36111 L .747 .913 .541 r
F P
0 g
s
.54787 .42474 m .596 .35651 L .59293 .36111 L .747 .913 .541 r
F
.60059 .35028 m .57987 .38189 L .54787 .42474 L p F P
0 g
s
.21815 .42815 m .23727 .42946 L .27018 .44086 L p .335 .672 .976 r
F P
0 g
s
.23727 .42946 m .21815 .42815 L .18488 .42094 L p .447 .723 .984 r
F P
0 g
s
.33602 .45815 m .3549 .47878 L .38804 .48502 L p .707 .282 .236 r
F P
0 g
s
.3549 .47878 m .33602 .45815 L .30315 .44989 L p .708 .244 .149 r
F P
0 g
s
.30315 .44989 m .32179 .46851 L .3549 .47878 L p .708 .244 .149 r
F P
0 g
s
.32179 .46851 m .30315 .44989 L .27018 .44086 L p .611 .046 0 r
F P
0 g
s
.18488 .42094 m .20405 .42002 L .23727 .42946 L p .447 .723 .984 r
F P
0 g
s
.20405 .42002 m .18488 .42094 L .15127 .41494 L p .571 .734 .952 r
F P
0 g
s
.27018 .44086 m .28886 .45409 L .32179 .46851 L p .611 .046 0 r
F P
0 g
s
.28886 .45409 m .27018 .44086 L .23727 .42946 L p .373 0 0 r
F P
0 g
s
.44144 .49665 m .4211 .48759 L .38804 .48502 L p .647 .233 .244 r
F P
0 g
s
.15127 .41494 m .17061 .41124 L .20405 .42002 L p .571 .734 .952 r
F P
0 g
s
.17061 .41124 m .15127 .41494 L .11744 .40889 L p .634 .723 .912 r
F P
0 g
s
.23727 .42946 m .25595 .4389 L .28886 .45409 L p .373 0 0 r
F P
0 g
s
.25595 .4389 m .23727 .42946 L .20405 .42002 L p .167 .573 .935 r
F P
0 g
s
.20405 .42002 m .22296 .4242 L .25595 .4389 L p .167 .573 .935 r
F P
0 g
s
.22296 .4242 m .20405 .42002 L .17061 .41124 L p .494 .667 .94 r
F P
0 g
s
.11744 .40889 m .13696 .40282 L .17061 .41124 L p .634 .723 .912 r
F P
0 g
s
.13696 .40282 m .11744 .40889 L .0834 .40269 L p .645 .745 .922 r
F P
0 g
s
.38804 .48502 m .40795 .50053 L .44144 .49665 L p .647 .233 .244 r
F P
0 g
s
.40795 .50053 m .38804 .48502 L .3549 .47878 L p .683 .25 .214 r
F P
0 g
s
.17061 .41124 m .18985 .41036 L .22296 .4242 L p .494 .667 .94 r
F P
0 g
s
.18985 .41036 m .17061 .41124 L .13696 .40282 L p .587 .691 .914 r
F P
0 g
s
.3549 .47878 m .37438 .49696 L .40795 .50053 L p .683 .25 .214 r
F P
0 g
s
.37438 .49696 m .3549 .47878 L .32179 .46851 L p .698 .219 .109 r
F P
0 g
s
.0834 .40269 m .10291 .39608 L .13696 .40282 L p .645 .745 .922 r
F P
0 g
s
.10291 .39608 m .0834 .40269 L .04909 .39682 L p .656 .746 .916 r
F P
0 g
s
.13696 .40282 m .15641 .39878 L .18985 .41036 L p .587 .691 .914 r
F P
0 g
s
.15641 .39878 m .13696 .40282 L .10291 .39608 L p .633 .718 .909 r
F P
0 g
s
.46229 .49823 m .44144 .49665 L .40795 .50053 L p .573 .152 .204 r
F P
0 g
s
.5902 .3606 m .56913 .39296 L .53644 .43729 L p .697 .882 .497 r
F P
0 g
s
.32179 .46851 m .34094 .48629 L .37438 .49696 L p .698 .219 .109 r
F P
0 g
s
.34094 .48629 m .32179 .46851 L .28886 .45409 L p .675 .139 0 r
F P
0 g
s
.28886 .45409 m .30774 .47026 L .34094 .48629 L p .675 .139 0 r
F P
0 g
s
.30774 .47026 m .28886 .45409 L .25595 .4389 L p .448 0 0 r
F P
0 g
s
.25595 .4389 m .27478 .451 L .30774 .47026 L p .448 0 0 r
F P
0 g
s
.27478 .451 m .25595 .4389 L .2313 .42791 L p .119 .488 .901 r
F P
0 g
s
.24188 .43398 m .27478 .451 L .2313 .42791 L .119 .488 .901 r
F
.2313 .42791 m .22296 .4242 L p .24188 .43398 L F P
0 g
s
.22296 .4242 m .24194 .43087 L .27478 .451 L p .119 .488 .901 r
F P
0 g
s
.2939 .46451 m .27478 .451 L .24194 .43087 L p .043 .406 .858 r
F P
0 g
s
.32706 .48664 m .30774 .47026 L .27478 .451 L p .453 0 0 r
F P
0 g
s
.2939 .46451 m .32706 .48664 L p .2803 .45476 L .453 0 0 r
F P
0 g
s
.27478 .451 m .2939 .46451 L p .2803 .45476 L .453 0 0 r
F P
0 g
s
.2939 .46451 m .26104 .44003 L p .30775 .47444 L .033 .369 .838 r
F P
0 g
s
.3134 .47861 m .2939 .46451 L p .30775 .47444 L .033 .369 .838 r
F P
0 g
s
.24194 .43087 m .26104 .44003 L .28986 .4615 L p .043 .406 .858 r
F P
0 g
s
.28986 .4615 m .2939 .46451 L p .28454 .45845 L .043 .406 .858 r
F P
0 g
s
.24194 .43087 m .28986 .4615 L .28454 .45845 L .043 .406 .858 r
F
.04909 .39682 m .0686 .38965 L .10291 .39608 L p .656 .746 .916 r
F P
0 g
s
.24194 .43087 m .22296 .4242 L .18985 .41036 L p .42 .598 .918 r
F P
0 g
s
.10291 .39608 m .12251 .38995 L .15641 .39878 L p .633 .718 .909 r
F P
0 g
s
.12251 .38995 m .10291 .39608 L .0686 .38965 L p .655 .729 .904 r
F P
0 g
s
.18985 .41036 m .20904 .41214 L .24194 .43087 L p .42 .598 .918 r
F P
0 g
s
.20904 .41214 m .18985 .41036 L .15641 .39878 L p .553 .64 .891 r
F P
0 g
s
.15641 .39878 m .17587 .3963 L .20904 .41214 L p .553 .64 .891 r
F P
0 g
s
.17587 .3963 m .15641 .39878 L .12251 .38995 L p .624 .674 .878 r
F P
0 g
s
.0686 .38965 m .08827 .38242 L .12251 .38995 L p .655 .729 .904 r
F P
0 g
s
.40795 .50053 m .42849 .50952 L .46229 .49823 L p .573 .152 .204 r
F P
0 g
s
.42849 .50952 m .40795 .50053 L .37438 .49696 L p .637 .196 .186 r
F P
0 g
s
.12251 .38995 m .14224 .38413 L .17587 .3963 L p .624 .674 .878 r
F P
0 g
s
.14224 .38413 m .12251 .38995 L .08827 .38242 L p .653 .708 .888 r
F P
0 g
s
.26104 .44003 m .24194 .43087 L .20904 .41214 L p .372 .532 .885 r
F P
0 g
s
.20904 .41214 m .22829 .41618 L .26104 .44003 L p .372 .532 .885 r
F P
0 g
s
.22829 .41618 m .20904 .41214 L .17587 .3963 L p .524 .585 .859 r
F P
0 g
s
.08827 .38242 m .10809 .37513 L .14224 .38413 L p .653 .708 .888 r
F P
0 g
s
.17587 .3963 m .19539 .39536 L .22829 .41618 L p .524 .585 .859 r
F P
0 g
s
.19539 .39536 m .17587 .3963 L .14224 .38413 L p .603 .63 .851 r
F P
0 g
s
.37438 .49696 m .39451 .51105 L .42849 .50952 L p .637 .196 .186 r
F P
0 g
s
.39451 .51105 m .37438 .49696 L .34094 .48629 L p .678 .201 .111 r
F P
0 g
s
.14224 .38413 m .16203 .3792 L .19539 .39536 L p .603 .63 .851 r
F P
0 g
s
.16203 .3792 m .14224 .38413 L .10809 .37513 L p .648 .676 .863 r
F P
0 g
s
.34094 .48629 m .36062 .50298 L .39451 .51105 L p .678 .201 .111 r
F P
0 g
s
.36062 .50298 m .34094 .48629 L .30774 .47026 L p .672 .132 0 r
F P
0 g
s
.30774 .47026 m .32706 .48664 L .36062 .50298 L p .672 .132 0 r
F P
0 g
s
.10809 .37513 m .12806 .36779 L .16203 .3792 L p .648 .676 .863 r
F P
0 g
s
.57951 .37231 m .55807 .40522 L .52465 .44781 L p .73 .908 .538 r
F P
0 g
s
.52465 .44781 m .54665 .41586 L .57951 .37231 L p .73 .908 .538 r
F P
0 g
s
.24768 .42203 m .22829 .41618 L .19539 .39536 L p .497 .535 .826 r
F P
0 g
s
.19539 .39536 m .21498 .39599 L .24768 .42203 L p .497 .535 .826 r
F P
0 g
s
.21498 .39599 m .19539 .39536 L .16203 .3792 L p .583 .585 .82 r
F P
0 g
s
.16203 .3792 m .18191 .37518 L .21498 .39599 L p .583 .585 .82 r
F P
0 g
s
.18191 .37518 m .16203 .3792 L .12806 .36779 L p .64 .637 .831 r
F P
0 g
s
.28039 .4507 m .26104 .44003 L .22829 .41618 L p .346 .48 .852 r
F P
0 g
s
.22829 .41618 m .24768 .42203 L .28039 .4507 L p .346 .48 .852 r
F P
0 g
s
.12806 .36779 m .1482 .36038 L .18191 .37518 L p .64 .637 .831 r
F P
0 g
s
.26104 .44003 m .28039 .4507 L .3134 .47861 L p .033 .369 .838 r
F P
0 g
s
.55807 .40522 m .53644 .43729 L .50252 .47624 L p .571 .82 .446 r
F P
0 g
s
.77733 .30905 m .74319 .28337 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.77733 .30905 m .80295 .33253 L .81274 .34656 L closepath p 0 .14 .672 r
F P
0 g
s
.80295 .33253 m .78375 .31494 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.78375 .31494 m .77733 .30905 L p .7685 .30419 L .049 .342 .82 r
F P
0 g
s
.74319 .28337 m .76768 .29919 L .80295 .33253 L p .049 .342 .82 r
F P
0 g
s
.74319 .28337 m .71008 .27158 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.76768 .29919 m .75053 .28811 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.75053 .28811 m .74319 .28337 L p .73464 .28335 L .265 .541 .922 r
F P
0 g
s
.71008 .27158 m .73035 .27731 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.73035 .27731 m .73361 .27823 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.73361 .27823 m .71008 .27158 L .67757 .27376 L p .533 .758 .979 r
F P
0 g
s
.70038 .2705 m .73361 .27823 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.67757 .27376 m .69455 .27134 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.69455 .27134 m .70038 .2705 L p .71172 .27648 L .533 .758 .979 r
F P
0 g
s
.73361 .27823 m .76768 .29919 L p .74803 .28977 L .265 .541 .922 r
F P
0 g
s
.23472 .39776 m .21498 .39599 L .18191 .37518 L p .568 .543 .787 r
F P
0 g
s
.18191 .37518 m .2019 .37187 L .23472 .39776 L p .568 .543 .787 r
F P
0 g
s
.2019 .37187 m .18191 .37518 L .1482 .36038 L p .63 .596 .796 r
F P
0 g
s
.1482 .36038 m .1685 .35292 L .2019 .37187 L p .63 .596 .796 r
F P
0 g
s
.26731 .42889 m .24768 .42203 L .21498 .39599 L p .483 .495 .794 r
F P
0 g
s
.21498 .39599 m .23472 .39776 L .26731 .42889 L p .483 .495 .794 r
F P
0 g
s
.61174 .32305 m .59014 .35119 L .56861 .37622 L p .899 .983 .716 r
F P
0 g
s
.56861 .37622 m .55705 .38966 L p .5762 .36634 L .899 .983 .716 r
F P
0 g
s
.5762 .36634 m .61174 .32305 L .56861 .37622 L .899 .983 .716 r
F
.57907 .35814 m .60101 .32958 L .61231 .31931 L p .902 .986 .767 r
F P
0 g
s
.55705 .38966 m .57907 .35814 L .61174 .32305 L p .899 .983 .716 r
F P
0 g
s
.6334 .30014 m .61174 .32305 L .5986 .33716 L p .902 .986 .767 r
F P
0 g
s
.60101 .32958 m .62296 .30561 L .63846 .29506 L p .881 .98 .83 r
F P
0 g
s
.5986 .33716 m .59093 .3454 L p .6334 .30014 L .902 .986 .767 r
F P
0 g
s
.60003 .33576 m .6334 .30014 L .59093 .3454 L .902 .986 .767 r
F
.59093 .3454 m .57907 .35814 L p .60003 .33576 L F P
0 g
s
.61231 .31931 m .6334 .30014 L p .59806 .33786 L .902 .986 .767 r
F P
0 g
s
.57907 .35814 m .61231 .31931 L .59806 .33786 L .902 .986 .767 r
F
.65529 .28359 m .6334 .30014 L .61281 .31885 L p .881 .98 .83 r
F P
0 g
s
.61281 .31885 m .60101 .32958 L p .62294 .311 L .881 .98 .83 r
F P
0 g
s
.62294 .311 m .65529 .28359 L .61281 .31885 L .881 .98 .83 r
F
.63846 .29506 m .65529 .28359 L p .62528 .30902 L F P
0 g
s
.60101 .32958 m .63846 .29506 L .62528 .30902 L .881 .98 .83 r
F
.67757 .27376 m .65529 .28359 L .6342 .29796 L p .827 .957 .898 r
F P
0 g
s
.6342 .29796 m .62296 .30561 L p .64486 .29284 L .827 .957 .898 r
F P
0 g
s
.64486 .29284 m .67757 .27376 L .6342 .29796 L .827 .957 .898 r
F
.62296 .30561 m .64509 .2873 L .66332 .2797 L p F P
0 g
s
.66332 .2797 m .67757 .27376 L p .65096 .28928 L .827 .957 .898 r
F P
0 g
s
.62296 .30561 m .66332 .2797 L .65096 .28928 L .827 .957 .898 r
F
.70038 .2705 m .67757 .27376 L .64509 .2873 L p .736 .896 .951 r
F P
0 g
s
.64509 .2873 m .66752 .27498 L .68781 .27222 L p .736 .896 .951 r
F P
0 g
s
.68781 .27222 m .70038 .2705 L p .67586 .27795 L .736 .896 .951 r
F P
0 g
s
.64509 .2873 m .68781 .27222 L .67586 .27795 L .736 .896 .951 r
F
.30011 .4616 m .28039 .4507 L .24768 .42203 L p .347 .449 .823 r
F P
0 g
s
.24768 .42203 m .26731 .42889 L .30011 .4616 L p .347 .449 .823 r
F P
0 g
s
.22206 .36908 m .2019 .37187 L .1685 .35292 L p .619 .558 .764 r
F P
0 g
s
.1685 .35292 m .18896 .3454 L .22206 .36908 L p .619 .558 .764 r
F P
0 g
s
.25469 .40013 m .23472 .39776 L .2019 .37187 L p .557 .509 .757 r
F P
0 g
s
.2019 .37187 m .22206 .36908 L .25469 .40013 L p .557 .509 .757 r
F P
0 g
s
.59014 .35119 m .56847 .38282 L .53487 .42222 L p .876 .978 .678 r
F P
0 g
s
.53487 .42222 m .55705 .38966 L .59014 .35119 L p .876 .978 .678 r
F P
0 g
s
.33341 .49141 m .3134 .47861 L .28039 .4507 L p .08 .375 .839 r
F P
0 g
s
.28039 .4507 m .30011 .4616 L .33341 .49141 L p .08 .375 .839 r
F P
0 g
s
.28729 .4358 m .26731 .42889 L .23472 .39776 L p .481 .468 .766 r
F P
0 g
s
.23472 .39776 m .25469 .40013 L .28729 .4358 L p .481 .468 .766 r
F P
0 g
s
.24242 .36654 m .22206 .36908 L .18896 .3454 L p .609 .526 .735 r
F P
0 g
s
.18896 .3454 m .20958 .33782 L .24242 .36654 L p .609 .526 .735 r
F P
0 g
s
.76768 .29919 m .79301 .31829 L .80295 .33253 L closepath p 0 .245 .755 r
F P
0 g
s
.76768 .29919 m .73361 .27823 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.79301 .31829 m .77401 .30396 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.77401 .30396 m .76768 .29919 L p .75831 .29489 L .183 .438 .868 r
F P
0 g
s
.73361 .27823 m .7579 .28957 L .79301 .31829 L p .183 .438 .868 r
F P
0 g
s
.73361 .27823 m .70038 .2705 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.7579 .28957 m .74142 .28188 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.74142 .28188 m .73361 .27823 L p .72498 .27866 L .39 .627 .948 r
F P
0 g
s
.70038 .2705 m .71977 .27262 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.71977 .27262 m .72383 .27307 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.72383 .27307 m .70038 .2705 L .66752 .27498 L p .617 .799 .969 r
F P
0 g
s
.6904 .26853 m .72383 .27307 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.66752 .27498 m .68337 .27051 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.68337 .27051 m .6904 .26853 L p .70049 .27386 L .617 .799 .969 r
F P
0 g
s
.72383 .27307 m .7579 .28957 L p .73725 .28273 L .39 .627 .948 r
F P
0 g
s
.56847 .38282 m .54665 .41586 L .51253 .45348 L p .821 .965 .644 r
F P
0 g
s
.51253 .45348 m .53487 .42222 L .56847 .38282 L p .821 .965 .644 r
F P
0 g
s
.27495 .40245 m .25469 .40013 L .22206 .36908 L p .551 .482 .731 r
F P
0 g
s
.22206 .36908 m .24242 .36654 L .27495 .40245 L p .551 .482 .731 r
F P
0 g
s
.36735 .51369 m .3469 .50178 L .3134 .47861 L p 0 .188 .618 r
F P
0 g
s
.32031 .47126 m .30011 .4616 L .26731 .42889 L p .37 .439 .802 r
F P
0 g
s
.26731 .42889 m .28729 .4358 L .32031 .47126 L p .37 .439 .802 r
F P
0 g
s
.26301 .3639 m .24242 .36654 L .20958 .33782 L p .6 .5 .712 r
F P
0 g
s
.20958 .33782 m .23038 .33017 L .26301 .3639 L p .6 .5 .712 r
F P
0 g
s
.54665 .41586 m .52465 .44781 L .49007 .48119 L p .717 .932 .604 r
F P
0 g
s
.49007 .48119 m .51253 .45348 L .54665 .41586 L p .717 .932 .604 r
F P
0 g
s
.30768 .44165 m .28729 .4358 L .25469 .40013 L p .488 .453 .745 r
F P
0 g
s
.25469 .40013 m .27495 .40245 L .30768 .44165 L p .488 .453 .745 r
F P
0 g
s
.61213 .30747 m .6345 .28808 L .65166 .28127 L p .841 .935 .889 r
F P
0 g
s
.64509 .2873 m .62296 .30561 L .60264 .32167 L p .889 .955 .839 r
F P
0 g
s
.61269 .31338 m .64509 .2873 L .60264 .32167 L .889 .955 .839 r
F
.58987 .33176 m .61213 .30747 L .64509 .2873 L p F P
0 g
s
.66752 .27498 m .64509 .2873 L .62395 .30024 L p .841 .935 .889 r
F P
0 g
s
.62395 .30024 m .61213 .30747 L p .6346 .29429 L .841 .935 .889 r
F P
0 g
s
.6346 .29429 m .66752 .27498 L .62395 .30024 L .841 .935 .889 r
F
.6345 .28808 m .65712 .27388 L .67685 .27071 L p .768 .888 .93 r
F P
0 g
s
.65166 .28127 m .66752 .27498 L p .63897 .29173 L .841 .935 .889 r
F P
0 g
s
.61213 .30747 m .65166 .28127 L .63897 .29173 L .841 .935 .889 r
F
.6904 .26853 m .66752 .27498 L .6345 .28808 L p .768 .888 .93 r
F P
0 g
s
.67685 .27071 m .6904 .26853 L p .66457 .27756 L .768 .888 .93 r
F P
0 g
s
.6345 .28808 m .67685 .27071 L .66457 .27756 L .768 .888 .93 r
F
.60264 .32167 m .58987 .33176 L p .61269 .31338 L .889 .955 .839 r
F P
0 g
s
.62296 .30561 m .60101 .32958 L .56761 .35994 L p .914 .965 .797 r
F P
0 g
s
.56761 .35994 m .58987 .33176 L .62296 .30561 L p .914 .965 .797 r
F P
0 g
s
.29557 .40396 m .27495 .40245 L .24242 .36654 L p .55 .465 .712 r
F P
0 g
s
.24242 .36654 m .26301 .3639 L .29557 .40396 L p .55 .465 .712 r
F P
0 g
s
.28387 .36081 m .26301 .3639 L .23038 .33017 L p .593 .48 .694 r
F P
0 g
s
.23038 .33017 m .25134 .32247 L .28387 .36081 L p .593 .48 .694 r
F P
0 g
s
.52465 .44781 m .50252 .47624 L .46762 .50333 L p .528 .842 .535 r
F P
0 g
s
.60101 .32958 m .57907 .35814 L .54526 .39055 L p .923 .97 .769 r
F P
0 g
s
.54526 .39055 m .56761 .35994 L .60101 .32958 L p .923 .97 .769 r
F P
0 g
s
.35401 .50119 m .33341 .49141 L .30011 .4616 L p .176 .417 .854 r
F P
0 g
s
.30011 .4616 m .32031 .47126 L .35401 .50119 L p .176 .417 .854 r
F P
0 g
s
.7579 .28957 m .78292 .30384 L .79301 .31829 L closepath p .016 .367 .836 r
F P
0 g
s
.7579 .28957 m .72383 .27307 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.78292 .30384 m .7643 .29322 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.7643 .29322 m .7579 .28957 L p .74812 .28571 L .315 .528 .902 r
F P
0 g
s
.72383 .27307 m .74794 .27983 L .78292 .30384 L p .315 .528 .902 r
F P
0 g
s
.74794 .27983 m .72383 .27307 L .6904 .26853 L p .499 .692 .954 r
F P
0 g
s
.71381 .26724 m .74794 .27983 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.6904 .26853 m .70886 .26751 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.70886 .26751 m .71381 .26724 L p .72622 .27556 L .499 .692 .954 r
F P
0 g
s
.57907 .35814 m .55705 .38966 L .52276 .42183 L p .921 .976 .757 r
F P
0 g
s
.52276 .42183 m .54526 .39055 L .57907 .35814 L p .921 .976 .757 r
F P
0 g
s
.30502 .35691 m .28387 .36081 L .25134 .32247 L p .588 .466 .681 r
F P
0 g
s
.25134 .32247 m .27247 .3147 L .30502 .35691 L p .588 .466 .681 r
F P
0 g
s
.33341 .49141 m .35401 .50119 L .36425 .50694 L p 0 .341 .757 r
F P
0 g
s
.42334 .52521 m .40183 .52434 L .38004 .51761 L p .417 0 0 r
F P
0 g
s
.37726 .51573 m .42334 .52521 L .38004 .51761 L .417 0 0 r
F
.38004 .51761 m .36735 .51369 L p .37726 .51573 L F P
0 g
s
.36735 .51369 m .38843 .52053 L .42334 .52521 L p .417 0 0 r
F P
0 g
s
.36425 .50694 m .38843 .52053 L p .36964 .51058 L 0 .341 .757 r
F P
0 g
s
.33341 .49141 m .36425 .50694 L .36964 .51058 L 0 .341 .757 r
F
.34104 .47828 m .32031 .47126 L .28729 .4358 L p .41 .447 .788 r
F P
0 g
s
.28729 .4358 m .30768 .44165 L .34104 .47828 L p .41 .447 .788 r
F P
0 g
s
.38843 .52053 m .36735 .51369 L .33341 .49141 L p 0 .341 .757 r
F P
0 g
s
.31657 .40396 m .29557 .40396 L .26301 .3639 L p .552 .455 .698 r
F P
0 g
s
.26301 .3639 m .28387 .36081 L .31657 .40396 L p .552 .455 .698 r
F P
0 g
s
.32855 .44535 m .30768 .44165 L .27495 .40245 L p .502 .449 .729 r
F P
0 g
s
.27495 .40245 m .29557 .40396 L .32855 .44535 L p .502 .449 .729 r
F P
0 g
s
.55705 .38966 m .53487 .42222 L .50013 .45169 L p .902 .985 .76 r
F P
0 g
s
.50013 .45169 m .52276 .42183 L .55705 .38966 L p .902 .985 .76 r
F P
0 g
s
.71381 .26724 m .6904 .26853 L .65712 .27388 L p .675 .814 .95 r
F P
0 g
s
.32646 .3519 m .30502 .35691 L .27247 .3147 L p .585 .457 .672 r
F P
0 g
s
.27247 .3147 m .29378 .30687 L .32646 .3519 L p .585 .457 .672 r
F P
0 g
s
.37521 .50639 m .35401 .50119 L .32031 .47126 L p .297 .48 .87 r
F P
0 g
s
.32031 .47126 m .34104 .47828 L .37521 .50639 L p .297 .48 .87 r
F P
0 g
s
.53487 .42222 m .51253 .45348 L .47741 .4781 L p .862 .996 .779 r
F P
0 g
s
.47741 .4781 m .50013 .45169 L .53487 .42222 L p .862 .996 .779 r
F P
0 g
s
.35401 .50119 m .37521 .50639 L .38376 .5099 L p .08 .545 .903 r
F P
0 g
s
.40172 .51999 m .44532 .51822 L .40714 .52304 L .126 0 0 r
F
.40714 .52304 m .38843 .52053 L p .40172 .51999 L F P
0 g
s
.38843 .52053 m .4101 .52073 L .44532 .51822 L p .126 0 0 r
F P
0 g
s
.38376 .5099 m .4101 .52073 L p .39152 .51426 L .08 .545 .903 r
F P
0 g
s
.35401 .50119 m .38376 .5099 L .39152 .51426 L .08 .545 .903 r
F
.44532 .51822 m .42334 .52521 L .40714 .52304 L p .126 0 0 r
F P
0 g
s
.33797 .40183 m .31657 .40396 L .28387 .36081 L p .558 .451 .689 r
F P
0 g
s
.28387 .36081 m .30502 .35691 L .33797 .40183 L p .558 .451 .689 r
F P
0 g
s
.74794 .27983 m .77268 .28916 L .78292 .30384 L closepath p .184 .485 .899 r
F P
0 g
s
.74794 .27983 m .71381 .26724 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.77268 .28916 m .75463 .28235 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.75463 .28235 m .74794 .27983 L p .73787 .2762 L .43 .602 .918 r
F P
0 g
s
.71381 .26724 m .73777 .26964 L .77268 .28916 L p .43 .602 .918 r
F P
0 g
s
.65712 .27388 m .68009 .26478 L .71381 .26724 L p .675 .814 .95 r
F P
0 g
s
.73777 .26964 m .71381 .26724 L .68009 .26478 L p .582 .732 .946 r
F P
0 g
s
.7035 .26015 m .73777 .26964 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.68009 .26478 m .69743 .26135 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.69743 .26135 m .7035 .26015 L p .71471 .26769 L .582 .732 .946 r
F P
0 g
s
.6345 .28808 m .61213 .30747 L .57835 .32814 L p .879 .913 .847 r
F P
0 g
s
.61213 .30747 m .58987 .33176 L .5558 .35502 L p .903 .919 .82 r
F P
0 g
s
.5558 .35502 m .57835 .32814 L .61213 .30747 L p .903 .919 .82 r
F P
0 g
s
.34819 .34552 m .32646 .3519 L .29378 .30687 L p .583 .452 .668 r
F P
0 g
s
.29378 .30687 m .31526 .29897 L .34819 .34552 L p .583 .452 .668 r
F P
0 g
s
.65712 .27388 m .6345 .28808 L .60089 .30446 L p .838 .898 .881 r
F P
0 g
s
.57835 .32814 m .60089 .30446 L .6345 .28808 L p .879 .913 .847 r
F P
0 g
s
.36234 .48138 m .34104 .47828 L .30768 .44165 L p .46 .466 .778 r
F P
0 g
s
.30768 .44165 m .32855 .44535 L .36234 .48138 L p .46 .466 .778 r
F P
0 g
s
.34991 .44597 m .32855 .44535 L .29557 .40396 L p .522 .453 .719 r
F P
0 g
s
.29557 .40396 m .31657 .40396 L .34991 .44597 L p .522 .453 .719 r
F P
0 g
s
.58987 .33176 m .56761 .35994 L .53316 .38379 L p .915 .92 .805 r
F P
0 g
s
.53316 .38379 m .5558 .35502 L .58987 .33176 L p .915 .92 .805 r
F P
0 g
s
.51253 .45348 m .49007 .48119 L .45474 .49925 L p .777 .996 .805 r
F P
0 g
s
.45474 .49925 m .47741 .4781 L .51253 .45348 L p .777 .996 .805 r
F P
0 g
s
.4101 .52073 m .38843 .52053 L .35401 .50119 L p .08 .545 .903 r
F P
0 g
s
.68009 .26478 m .65712 .27388 L .62351 .28484 L p .78 .864 .911 r
F P
0 g
s
.60089 .30446 m .62351 .28484 L .65712 .27388 L p .838 .898 .881 r
F P
0 g
s
.46762 .50333 m .44532 .51822 L .4101 .52073 L p .263 .765 .73 r
F P
0 g
s
.56761 .35994 m .54526 .39055 L .51041 .41292 L p .916 .919 .803 r
F P
0 g
s
.51041 .41292 m .53316 .38379 L .56761 .35994 L p .916 .919 .803 r
F P
0 g
s
.49007 .48119 m .46762 .50333 L .43225 .51366 L p .585 .942 .806 r
F P
0 g
s
.43225 .51366 m .45474 .49925 L .49007 .48119 L p .585 .942 .806 r
F P
0 g
s
.35977 .39704 m .33797 .40183 L .30502 .35691 L p .567 .454 .684 r
F P
0 g
s
.30502 .35691 m .32646 .3519 L .35977 .39704 L p .567 .454 .684 r
F P
0 g
s
.37019 .33767 m .34819 .34552 L .31526 .29897 L p .583 .452 .668 r
F P
0 g
s
.31526 .29897 m .33692 .29101 L .37019 .33767 L p .583 .452 .668 r
F P
0 g
s
.4101 .52073 m .43225 .51366 L .46762 .50333 L p .263 .765 .73 r
F P
0 g
s
.7035 .26015 m .68009 .26478 L .64633 .26957 L p .709 .812 .929 r
F P
0 g
s
.62351 .28484 m .64633 .26957 L .68009 .26478 L p .78 .864 .911 r
F P
0 g
s
.39699 .50567 m .37521 .50639 L .34104 .47828 L p .423 .55 .879 r
F P
0 g
s
.34104 .47828 m .36234 .48138 L .39699 .50567 L p .423 .55 .879 r
F P
0 g
s
.54526 .39055 m .52276 .42183 L .48755 .44058 L p .906 .919 .816 r
F P
0 g
s
.48755 .44058 m .51041 .41292 L .54526 .39055 L p .906 .919 .816 r
F P
0 g
s
.37174 .4427 m .34991 .44597 L .31657 .40396 L p .546 .465 .715 r
F P
0 g
s
.31657 .40396 m .33797 .40183 L .37174 .4427 L p .546 .465 .715 r
F P
0 g
s
.38417 .47948 m .36234 .48138 L .32855 .44535 L p .512 .495 .774 r
F P
0 g
s
.32855 .44535 m .34991 .44597 L .38417 .47948 L p .512 .495 .774 r
F P
0 g
s
.39244 .32836 m .37019 .33767 L .33692 .29101 L p .585 .457 .672 r
F P
0 g
s
.33692 .29101 m .35876 .28298 L .39244 .32836 L p .585 .457 .672 r
F P
0 g
s
.73777 .26964 m .76228 .27426 L .77268 .28916 L closepath p .337 .583 .934 r
F P
0 g
s
.76228 .27426 m .73777 .26964 L .7035 .26015 L p .521 .657 .92 r
F P
0 g
s
.43225 .51366 m .4101 .52073 L .37521 .50639 L p .386 .739 .991 r
F P
0 g
s
.38191 .38938 m .35977 .39704 L .32646 .3519 L p .578 .461 .684 r
F P
0 g
s
.32646 .3519 m .34819 .34552 L .38191 .38938 L p .578 .461 .684 r
F P
0 g
s
.37521 .50639 m .39699 .50567 L .43225 .51366 L p .386 .739 .991 r
F P
0 g
s
.52276 .42183 m .50013 .45169 L .46466 .46505 L p .883 .919 .844 r
F P
0 g
s
.46466 .46505 m .48755 .44058 L .52276 .42183 L p .883 .919 .844 r
F P
0 g
s
.62351 .28484 m .60089 .30446 L .56648 .31813 L p .851 .86 .848 r
F P
0 g
s
.60089 .30446 m .57835 .32814 L .54368 .34273 L p .868 .857 .828 r
F P
0 g
s
.54368 .34273 m .56648 .31813 L .60089 .30446 L p .868 .857 .828 r
F P
0 g
s
.7035 .26015 m .72738 .2587 L .76228 .27426 L p .521 .657 .92 r
F P
0 g
s
.72738 .2587 m .7035 .26015 L .66943 .25859 L p .637 .753 .932 r
F P
0 g
s
.64633 .26957 m .66943 .25859 L .7035 .26015 L p .709 .812 .929 r
F P
0 g
s
.64633 .26957 m .62351 .28484 L .58927 .29601 L p .82 .855 .874 r
F P
0 g
s
.56648 .31813 m .58927 .29601 L .62351 .28484 L p .851 .86 .848 r
F P
0 g
s
.57835 .32814 m .5558 .35502 L .52082 .36873 L p .873 .846 .815 r
F P
0 g
s
.52082 .36873 m .54368 .34273 L .57835 .32814 L p .873 .846 .815 r
F P
0 g
s
.4149 .31765 m .39244 .32836 L .35876 .28298 L p .588 .466 .681 r
F P
0 g
s
.35876 .28298 m .38078 .27488 L .4149 .31765 L p .588 .466 .681 r
F P
0 g
s
.39399 .43522 m .37174 .4427 L .33797 .40183 L p .573 .482 .714 r
F P
0 g
s
.33797 .40183 m .35977 .39704 L .39399 .43522 L p .573 .482 .714 r
F P
0 g
s
.45474 .49925 m .43225 .51366 L .39699 .50567 L p .616 .851 .988 r
F P
0 g
s
.50013 .45169 m .47741 .4781 L .44185 .48478 L p .84 .915 .886 r
F P
0 g
s
.44185 .48478 m .46466 .46505 L .50013 .45169 L p .84 .915 .886 r
F P
0 g
s
.66943 .25859 m .64633 .26957 L .61214 .2771 L p .776 .835 .897 r
F P
0 g
s
.58927 .29601 m .61214 .2771 L .64633 .26957 L p .82 .855 .874 r
F P
0 g
s
.40435 .37883 m .38191 .38938 L .34819 .34552 L p .591 .473 .688 r
F P
0 g
s
.34819 .34552 m .37019 .33767 L .40435 .37883 L p .591 .473 .688 r
F P
0 g
s
.41924 .49848 m .39699 .50567 L .36234 .48138 L p .543 .616 .876 r
F P
0 g
s
.36234 .48138 m .38417 .47948 L .41924 .49848 L p .543 .616 .876 r
F P
0 g
s
.5558 .35502 m .53316 .38379 L .49789 .39483 L p .867 .83 .809 r
F P
0 g
s
.49789 .39483 m .52082 .36873 L .5558 .35502 L p .867 .83 .809 r
F P
0 g
s
.40645 .47216 m .38417 .47948 L .34991 .44597 L p .567 .528 .771 r
F P
0 g
s
.34991 .44597 m .37174 .4427 L .40645 .47216 L p .567 .528 .771 r
F P
0 g
s
.47741 .4781 m .45474 .49925 L .41924 .49848 L p .758 .901 .94 r
F P
0 g
s
.41924 .49848 m .44185 .48478 L .47741 .4781 L p .758 .901 .94 r
F P
0 g
s
.39699 .50567 m .41924 .49848 L .45474 .49925 L p .616 .851 .988 r
F P
0 g
s
.66943 .25859 m .6929 .25137 L .72738 .2587 L p .637 .753 .932 r
F P
0 g
s
.6929 .25137 m .66943 .25859 L .63517 .26166 L p .722 .801 .913 r
F P
0 g
s
.61214 .2771 m .63517 .26166 L .66943 .25859 L p .776 .835 .897 r
F P
0 g
s
.43754 .3058 m .4149 .31765 L .38078 .27488 L p .593 .48 .694 r
F P
0 g
s
.38078 .27488 m .40299 .26672 L .43754 .3058 L p .593 .48 .694 r
F P
0 g
s
.53316 .38379 m .51041 .41292 L .47491 .41956 L p .849 .811 .812 r
F P
0 g
s
.47491 .41956 m .49789 .39483 L .53316 .38379 L p .849 .811 .812 r
F P
0 g
s
.72738 .2587 m .75171 .25913 L .76228 .27426 L closepath p .458 .654 .944 r
F P
0 g
s
.75171 .25913 m .72738 .2587 L .6929 .25137 L p .585 .694 .917 r
F P
0 g
s
.42702 .36558 m .40435 .37883 L .37019 .33767 L p .606 .49 .695 r
F P
0 g
s
.37019 .33767 m .39244 .32836 L .42702 .36558 L p .606 .49 .695 r
F P
0 g
s
.41656 .42349 m .39399 .43522 L .35977 .39704 L p .601 .504 .716 r
F P
0 g
s
.35977 .39704 m .38191 .38938 L .41656 .42349 L p .601 .504 .716 r
F P
0 g
s
.51041 .41292 m .48755 .44058 L .45194 .44148 L p .82 .786 .82 r
F P
0 g
s
.45194 .44148 m .47491 .41956 L .51041 .41292 L p .82 .786 .82 r
F P
0 g
s
.44185 .48478 m .41924 .49848 L .38417 .47948 L p .641 .672 .865 r
F P
0 g
s
.38417 .47948 m .40645 .47216 L .44185 .48478 L p .641 .672 .865 r
F P
0 g
s
.42908 .45936 m .40645 .47216 L .37174 .4427 L p .619 .563 .77 r
F P
0 g
s
.37174 .4427 m .39399 .43522 L .42908 .45936 L p .619 .563 .77 r
F P
0 g
s
.46034 .2931 m .43754 .3058 L .40299 .26672 L p .6 .5 .712 r
F P
0 g
s
.40299 .26672 m .42538 .25849 L .46034 .2931 L p .6 .5 .712 r
F P
0 g
s
.61214 .2771 m .58927 .29601 L .55433 .30171 L p .81 .804 .846 r
F P
0 g
s
.58927 .29601 m .56648 .31813 L .53134 .32314 L p .818 .79 .826 r
F P
0 g
s
.53134 .32314 m .55433 .30171 L .58927 .29601 L p .818 .79 .826 r
F P
0 g
s
.6929 .25137 m .71675 .24679 L .75171 .25913 L p .585 .694 .917 r
F P
0 g
s
.71675 .24679 m .6929 .25137 L .65843 .24966 L p .668 .761 .92 r
F P
0 g
s
.63517 .26166 m .65843 .24966 L .6929 .25137 L p .722 .801 .913 r
F P
0 g
s
.56648 .31813 m .54368 .34273 L .50834 .3455 L p .815 .768 .809 r
F P
0 g
s
.50834 .3455 m .53134 .32314 L .56648 .31813 L p .815 .768 .809 r
F P
0 g
s
.48755 .44058 m .46466 .46505 L .42908 .45936 L p .778 .756 .833 r
F P
0 g
s
.42908 .45936 m .45194 .44148 L .48755 .44058 L p .778 .756 .833 r
F P
0 g
s
.44985 .35013 m .42702 .36558 L .39244 .32836 L p .623 .512 .707 r
F P
0 g
s
.39244 .32836 m .4149 .31765 L .44985 .35013 L p .623 .512 .707 r
F P
0 g
s
.63517 .26166 m .61214 .2771 L .57734 .28206 L p .789 .81 .869 r
F P
0 g
s
.55433 .30171 m .57734 .28206 L .61214 .2771 L p .81 .804 .846 r
F P
0 g
s
.43937 .40781 m .41656 .42349 L .38191 .38938 L p .63 .531 .723 r
F P
0 g
s
.38191 .38938 m .40435 .37883 L .43937 .40781 L p .63 .531 .723 r
F P
0 g
s
.46466 .46505 m .44185 .48478 L .40645 .47216 L p .718 .72 .85 r
F P
0 g
s
.40645 .47216 m .42908 .45936 L .46466 .46505 L p .718 .72 .85 r
F P
0 g
s
.54368 .34273 m .52082 .36873 L .48533 .36781 L p .801 .739 .795 r
F P
0 g
s
.48533 .36781 m .50834 .3455 L .54368 .34273 L p .801 .739 .795 r
F P
0 g
s
.65843 .24966 m .63517 .26166 L .60043 .26478 L p .758 .803 .889 r
F P
0 g
s
.57734 .28206 m .60043 .26478 L .63517 .26166 L p .789 .81 .869 r
F P
0 g
s
.52082 .36873 m .49789 .39483 L .46232 .38893 L p .778 .708 .785 r
F P
0 g
s
.46232 .38893 m .48533 .36781 L .52082 .36873 L p .778 .708 .785 r
F P
0 g
s
.45194 .44148 m .42908 .45936 L .39399 .43522 L p .667 .601 .772 r
F P
0 g
s
.39399 .43522 m .41656 .42349 L .45194 .44148 L p .667 .601 .772 r
F P
0 g
s
.71675 .24679 m .74098 .24375 L .75171 .25913 L closepath p .544 .699 .941 r
F P
0 g
s
.47279 .33309 m .44985 .35013 L .4149 .31765 L p .64 .539 .723 r
F P
0 g
s
.4149 .31765 m .43754 .3058 L .47279 .33309 L p .64 .539 .723 r
F P
0 g
s
.48326 .2799 m .46034 .2931 L .42538 .25849 L p .609 .526 .735 r
F P
0 g
s
.42538 .25849 m .44796 .25019 L .48326 .2799 L p .609 .526 .735 r
F P
0 g
s
.46232 .38893 m .43937 .40781 L .40435 .37883 L p .66 .56 .732 r
F P
0 g
s
.40435 .37883 m .42702 .36558 L .46232 .38893 L p .66 .56 .732 r
F P
0 g
s
.49789 .39483 m .47491 .41956 L .43937 .40781 L p .748 .673 .778 r
F P
0 g
s
.43937 .40781 m .46232 .38893 L .49789 .39483 L p .748 .673 .778 r
F P
0 g
s
.65843 .24966 m .682 .24068 L .71675 .24679 L p .668 .761 .92 r
F P
0 g
s
.682 .24068 m .65843 .24966 L .62367 .25007 L p .719 .785 .904 r
F P
0 g
s
.60043 .26478 m .62367 .25007 L .65843 .24966 L p .758 .803 .889 r
F P
0 g
s
.74098 .24375 m .71675 .24679 L .682 .24068 L p .628 .719 .913 r
F P
0 g
s
.47491 .41956 m .45194 .44148 L .41656 .42349 L p .71 .637 .774 r
F P
0 g
s
.41656 .42349 m .43937 .40781 L .47491 .41956 L p .71 .637 .774 r
F P
0 g
s
.48533 .36781 m .46232 .38893 L .42702 .36558 L p .688 .593 .744 r
F P
0 g
s
.42702 .36558 m .44985 .35013 L .48533 .36781 L p .688 .593 .744 r
F P
0 g
s
.4958 .31517 m .47279 .33309 L .43754 .3058 L p .659 .57 .743 r
F P
0 g
s
.43754 .3058 m .46034 .2931 L .4958 .31517 L p .659 .57 .743 r
F P
0 g
s
.57734 .28206 m .55433 .30171 L .51886 .29712 L p .761 .728 .822 r
F P
0 g
s
.55433 .30171 m .53134 .32314 L .4958 .31517 L p .752 .697 .799 r
F P
0 g
s
.4958 .31517 m .51886 .29712 L .55433 .30171 L p .752 .697 .799 r
F P
0 g
s
.53134 .32314 m .50834 .3455 L .47279 .33309 L p .736 .662 .778 r
F P
0 g
s
.47279 .33309 m .4958 .31517 L .53134 .32314 L p .736 .662 .778 r
F P
0 g
s
.60043 .26478 m .57734 .28206 L .54197 .27961 L p .761 .752 .845 r
F P
0 g
s
.51886 .29712 m .54197 .27961 L .57734 .28206 L p .761 .728 .822 r
F P
0 g
s
.50834 .3455 m .48533 .36781 L .44985 .35013 L p .714 .627 .76 r
F P
0 g
s
.44985 .35013 m .47279 .33309 L .50834 .3455 L p .714 .627 .76 r
F P
0 g
s
.5063 .26657 m .48326 .2799 L .44796 .25019 L p .619 .558 .764 r
F P
0 g
s
.44796 .25019 m .47073 .24182 L .5063 .26657 L p .619 .558 .764 r
F P
0 g
s
.62367 .25007 m .60043 .26478 L .56515 .26321 L p .75 .769 .868 r
F P
0 g
s
.54197 .27961 m .56515 .26321 L .60043 .26478 L p .761 .752 .845 r
F P
0 g
s
.682 .24068 m .70588 .2338 L .74098 .24375 L p .628 .719 .913 r
F P
0 g
s
.70588 .2338 m .682 .24068 L .64711 .23793 L p .681 .761 .912 r
F P
0 g
s
.62367 .25007 m .64711 .23793 L .682 .24068 L p .719 .785 .904 r
F P
0 g
s
.51886 .29712 m .4958 .31517 L .46034 .2931 L p .677 .604 .767 r
F P
0 g
s
.46034 .2931 m .48326 .2799 L .51886 .29712 L p .677 .604 .767 r
F P
0 g
s
.64711 .23793 m .62367 .25007 L .58843 .24834 L p .731 .774 .887 r
F P
0 g
s
.56515 .26321 m .58843 .24834 L .62367 .25007 L p .75 .769 .868 r
F P
0 g
s
.70588 .2338 m .73009 .22814 L .74098 .24375 L closepath p .6 .727 .933 r
F P
0 g
s
.54197 .27961 m .51886 .29712 L .48326 .2799 L p .692 .641 .794 r
F P
0 g
s
.48326 .2799 m .5063 .26657 L .54197 .27961 L p .692 .641 .794 r
F P
0 g
s
.52947 .25345 m .5063 .26657 L .47073 .24182 L p .63 .596 .796 r
F P
0 g
s
.47073 .24182 m .4937 .23337 L .52947 .25345 L p .63 .596 .796 r
F P
0 g
s
.56515 .26321 m .54197 .27961 L .5063 .26657 L p .703 .678 .823 r
F P
0 g
s
.73009 .22814 m .70588 .2338 L .6708 .22804 L p .651 .735 .91 r
F P
0 g
s
.64711 .23793 m .6708 .22804 L .70588 .2338 L p .681 .761 .912 r
F P
0 g
s
.6708 .22804 m .64711 .23793 L .61186 .23515 L p .706 .768 .901 r
F P
0 g
s
.58843 .24834 m .61186 .23515 L .64711 .23793 L p .731 .774 .887 r
F P
0 g
s
.58843 .24834 m .56515 .26321 L .52947 .25345 L p .708 .711 .851 r
F P
0 g
s
.5063 .26657 m .52947 .25345 L .56515 .26321 L p .703 .678 .823 r
F P
0 g
s
.55276 .24082 m .52947 .25345 L .4937 .23337 L p .64 .637 .831 r
F P
0 g
s
.4937 .23337 m .51686 .22486 L .55276 .24082 L p .64 .637 .831 r
F P
0 g
s
.61186 .23515 m .58843 .24834 L .55276 .24082 L p .705 .736 .875 r
F P
0 g
s
.52947 .25345 m .55276 .24082 L .58843 .24834 L p .708 .711 .851 r
F P
0 g
s
.6708 .22804 m .69477 .21971 L .73009 .22814 L p .651 .735 .91 r
F P
0 g
s
.69477 .21971 m .6708 .22804 L .63549 .22364 L p .68 .758 .91 r
F P
0 g
s
.61186 .23515 m .63549 .22364 L .6708 .22804 L p .706 .768 .901 r
F P
0 g
s
.69477 .21971 m .71901 .21228 L .73009 .22814 L closepath p .633 .742 .926 r
F P
0 g
s
.63549 .22364 m .61186 .23515 L .5762 .22891 L p .696 .751 .894 r
F P
0 g
s
.55276 .24082 m .5762 .22891 L .61186 .23515 L p .705 .736 .875 r
F P
0 g
s
.5762 .22891 m .55276 .24082 L .51686 .22486 L p .648 .676 .863 r
F P
0 g
s
.51686 .22486 m .54022 .21627 L .5762 .22891 L p .648 .676 .863 r
F P
0 g
s
.71901 .21228 m .69477 .21971 L .65934 .21361 L p .661 .744 .911 r
F P
0 g
s
.63549 .22364 m .65934 .21361 L .69477 .21971 L p .68 .758 .91 r
F P
0 g
s
.65934 .21361 m .63549 .22364 L .59981 .21779 L p .684 .756 .906 r
F P
0 g
s
.5762 .22891 m .59981 .21779 L .63549 .22364 L p .696 .751 .894 r
F P
0 g
s
.59981 .21779 m .5762 .22891 L .54022 .21627 L p .653 .709 .889 r
F P
0 g
s
.54022 .21627 m .56379 .20761 L .59981 .21779 L p .653 .709 .889 r
F P
0 g
s
.65934 .21361 m .68343 .2046 L .71901 .21228 L p .661 .744 .911 r
F P
0 g
s
.68343 .2046 m .65934 .21361 L .62362 .20747 L p .671 .754 .913 r
F P
0 g
s
.59981 .21779 m .62362 .20747 L .65934 .21361 L p .684 .756 .906 r
F P
0 g
s
.62362 .20747 m .59981 .21779 L .56379 .20761 L p .655 .733 .907 r
F P
0 g
s
.68343 .2046 m .70777 .19617 L .71901 .21228 L closepath p .65 .749 .922 r
F P
0 g
s
.56379 .20761 m .58756 .19887 L .62362 .20747 L p .655 .733 .907 r
F P
0 g
s
.62362 .20747 m .64763 .19784 L .68343 .2046 L p .671 .754 .913 r
F P
0 g
s
.64763 .19784 m .62362 .20747 L .58756 .19887 L p .656 .746 .917 r
F P
0 g
s
.70777 .19617 m .68343 .2046 L .64763 .19784 L p .661 .749 .915 r
F P
0 g
s
.58756 .19887 m .61153 .19006 L .64763 .19784 L p .656 .746 .917 r
F P
0 g
s
.64763 .19784 m .67187 .1887 L .70777 .19617 L p .661 .749 .915 r
F P
0 g
s
.67187 .1887 m .64763 .19784 L .61153 .19006 L p .656 .751 .92 r
F P
0 g
s
.67187 .1887 m .69634 .17979 L .70777 .19617 L closepath p .656 .751 .92 r
F P
0 g
s
.61153 .19006 m .63571 .18117 L .67187 .1887 L p .656 .751 .92 r
F P
0 g
s
.69634 .17979 m .67187 .1887 L .63571 .18117 L p .656 .751 .92 r
F P
0 g
s
.63571 .18117 m .66011 .1722 L .69634 .17979 L p .656 .751 .92 r
F P
0 g
s
.66011 .1722 m .68472 .16315 L .69634 .17979 L closepath p .656 .751 .92 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00kOooool4o`000003oa0@4?oooooooooo07Cooooo003_ooooo`03o`00
0?oooooooooo07Kooooo003_ooooo`03o`000?oooooooooo07Kooooo003_ooooo`03o`000?oooooo
oooo07Kooooo003_ooooo`03o`000?oooooooooo07Kooooo003_ooooo`03o`000?oooooooooo07Ko
oooo003_ooooo`03o`000?oooooooooo07Kooooo003]ooooo`03oeEEEOmVIVKo000007Sooooo003o
ooooo`;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Rooooo`00ooooool2ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0H_ooool00?oooooo0_ooool01Ol@413ooooooooooooooooo410@06;ooooo003i
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000006;ooooo003fooooo`?o000000?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000006;ooooo003dooooo`;o00001?ooool2
o`0000Gooooo00Go410@oooooooooooooooooa0@401Rooooo`00lOooool4o`0000Gooooo00?o0000
ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06;ooooo003_ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06;ooooo003/
ooooo`?o00002oooool01?l0003oooooooooool0001Zooooo`00jOooool3o`0000kooooo00Go0000
ooooooooooooooooo`00001Yooooo`00ioooool2o`000003ooooool0003ooooo00kooooo00Go0000
ooooooooooooooooo`00001Yooooo`00i?ooool3o`0001?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Vooooo`00h_ooool2o`0001Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Uooooo`00goooool3o`0001Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Uooooo`00XOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`;o00007?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo002Qooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0Joooo
o`?o00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0_l0001Voooo
o`00M?ooool2o`0000;ooooo0_l0000Wooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Hoooool007Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdW
ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb
<S;ooooo01Gooooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_oo
ool007Gooooo00CogMgMo`000?l@413oc<c<:?ooool01Ol0003ooooooooooooooooo000000kooooo
00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool007Gooooo00Cok^k^ob4Q8Ol@413o
k^k^:?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`0Cooooo`?o000000?oooooo`000?ooool09Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo067ooooo001eooooo`04ob4Q8OmgMgOoMgMgoc8b<RSooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`0@ooooo`?o0000:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo001d
ooooo`;o00000_ooool2o`0002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?oo
ool4o`0000gooooo0_l0000^ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?oo
ool00<Sooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Goooool0
0<Kooooo0_l00002ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool01oooool00ol0
003oooooo`00001Pooooo`00`oooool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Nooooo`00`Oooool2o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Mooooo`00__ooool3o`0003[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Looooo`00_?ooool2o`000003ooooool0003ooooo03[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Looooo`00^Oooool3o`0000Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo002gooooo`;o0000@_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo002dooooo`?o0000A?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000G?ooool00;;ooooo0_l000000ooooooo0000ooooo`14ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0FOooool00:oooooo0ol00019ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0F?ooool00:cooooo0ol0001=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0F?ooool007Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l0001@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Eoooool007Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Coooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo001dooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`0Iooooo`;o0000EOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Kooooo001dooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`0Gooooo`?o0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05Gooooo001dooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01Kooooo0_l0001Jooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0<?ooool007Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Go
oooo0ol000000ooooooo0000ooooo`1Iooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00omgMgOo<S8booooo`0_ooooo`00M?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04oooool2o`0005oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP09ooooo`03o`000?oooooooooo02kooooo001dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000oooooo0ol0001Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`0_ooooo`00U_ooool2o`0006Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0<?ooool009?ooooo0ol000000ooooooo0000ooooo`1Sooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0booooo`00T?ooool3o`0006Wooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0<_ooool008ko
oooo0_l0001/ooooo`03o`000?oooooooooo01Cooooo0ol00004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000aooooo`00Roooool3o`00
06kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`00ROooool2o`0000;o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04oo
oooo0026ooooo`?o00001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0C_ooool008Cooooo0_l0001fooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0COooool0087ooooo0ol0001hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0COooool007oooooo0_l00002ooooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1<ooooo`00O?ooool3o`0007gooooo00?o0000oooooooo
ool06Oooool3o`0004gooooo000looooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd08?ooool2o`00087ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1;ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0L
ooooo`?o0000Poooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04[ooooo000loooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooo
oooo01Sooooo0ol00003ooooo`03o`000?oooooooooo07_ooooo0_l00003ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0B_ooool003cooooo00Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05oooool2o`00087ooooo0ol00000
0onW`>_o0000ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0BOooool0
03cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Eooooo`?o0000P?ooool3o`0000GoYl3[00Co0000oooooooooooo0000
7oooool00ol0003oooooooooo`18ooooo`00??ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool0
O_ooool4o`0000OoYl3[00?o0000ooooool000007oooool00ol0003oooooooooo`18ooooo`00??oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo01;ooooo0ol00020ooooo`?o00001?nW`>/4o`0000?oYl3[00?o0000ooooool0
00007oooool2o`0004Wooooo000looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0000?ooooo`;o0000P?ooool3o`0000_oYl3[1_l0000Qoooo
o`03o`000?oooooooooo04Kooooo001Uooooo`?o0000P?ooool2o`0001;oYl3[0_l0000Qooooo`03
o`000?oooooooooo04Kooooo001Sooooo`;o00000_ooool00ol0003oooooooooo`1kooooo`?o0000
1OnW`>/6o`0000CoYl3[1?l00002ojO0j`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8_ooool3o`000003oa0@4?oooooooooo01gooooo001Pooooo`?o0000P?ooool2o`0000koYl3[1Ol0
0005ojO0j`;o00008_ooool00ol0003oooooooooo`0Sooooo`03oa0@4?nj^[[ooooo01kooooo001N
ooooo`;o0000POooool2o`0000koYl3[0ol00004ojVojPCo000000CoYl3[o`000?nW`>_o00008Ooo
ool00ol0003oooooooooo`0Sooooo`03oiRHV?lb<S;ooooo01kooooo001Kooooo`?o0000P?ooool3
o`0000GoYkkZ1Ol00003ojO0j`?o00002onY_nX5o`00027ooooo00?o0000ooooooooool08_ooool0
0ooMgMgo0000okZj^P0Nooooo`00FOooool2o`0000?ooooo00?o0000ooooooooool0N_ooool3o`00
00goYkkZ0ol0000?ojVojP03o`000?nY_n[oZKoZ00;o00007oooool3o`0002?ooooo00?oEEEEogMg
Mom4A4@07_ooool005Kooooo0ol00020ooooo`;o00003onW_^X2o`0000CoZl7Y1?l00009ojVojP?o
000000?oY[o/o`000?ooool08?ooool00ol0003oooooooooo`0Pooooo`05omgMgOl@413oooooob4Q
8OoMgMd07Oooool005?ooooo0ol00020ooooo`?o00001?nW^nP4o`0000SoYkkZ00?o0000oj_1jOn[
`NT02?n[`NT4o`0000;oZKoZ1?l00004ojJok003o`000?oooooooooo01oooooo00?o0000oooooooo
ool07oooool01OmVIVKoQhN7oooooonHV9SoEEEE01gooooo001Aooooo`;o000000?oooooo`000?l0
0000OOooool3o`0000_oYk_X1?l00002ojNnjP;o00003on[`NT6o`0000GoY[o/00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool06oooool004kooooo0ol0001oooooo`?o00004_nW^nP2o`0000coZl7Y1?l00006ojVnj@Go0000
00?oY[o/o`000?ooool08?ooool00ol0003oooooooooo`0Mooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool06_ooool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`;o
0000Ooooool3o`0000GoYkGS1?l00009ojNkj0?o00002?n_`NL6o`0000[oZKkY00?o0000ojVnjOnY
_^T00_nY_^T3o`00027ooooo00?o0000ooooooooool0?oooool002Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Nooooo`?o0000O_ooool3o`0000coYkGS1?l00002ojNkj0?o00003?n_`NL2o`0000Go
[/;X1Ol00003ojVnj@Go00000_nR_Nd00ol0003oooooooooo`0Oooooo`;o0000@?ooool002Kooooo
00Go410@oooooooooooooooooa0@400Looooo`;o00000oooool00ol0003oooooooooo`1hooooo`?o
00000onU[M`3o`0000goYkGS0_l0000=ojo1i`;o00003?n^`^P5o`0000KoX[g]00?o0000oooooooo
ool07Oooool00ol0003oooooo`000008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Rooooo`009_ooool01Ol0003ooooooooooooooooo
000001Wooooo0ol0001mooooo`?o00002OnU[M`3o`0000OoYkGS0ol00005ok;0i0Go00000on_`NL2
o`0000co[/;X0ol00003ojJlj0Go00000onR_Nd00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0Qooooo`009_ooool01Ol0003ooooooooooooooooo000001Oooooo0_l0001nooooo`;o00003onU
[M`3o`000004ojNehol0003o0000o`0000go//3T0ol00004ojk2j0;o00001_n^`^P2o`0000KoY[cX
00?o0000ojJlj?nV_>P00_nV_>P5o`00023ooooo00?o0000ooooooooool01Oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool08?ooool002Kooooo00Go410@oooooooooooo
oooooa0@400Dooooo`Co0000O?ooool3o`0000?oXj?D0ol0000>ojF]g003o`000?nb`>Co//3T00co
//3T0ol00008okC4iPKo00002?nV_>P00ol0003oY[cXojJlj006ojJlj0;o00008?ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Qoooo
o`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0_l00004ooooo`03o`000?oooooooooo
07Oooooo0_l00009oj>Se0;o00002OnU[M`2o`0000Go];cO1_l00003ok;0i0;o00003?nda>H3o`00
00Go[/;Y1_l00003ojJlj0Co00000_nI^^h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08_oo
ool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`?o0000O_ooool2o`0000goXj?D0_l0
0006ojF]g003o`000?nd_=oo];cO00_o];cO0ol00004okC4iP;o00001Onda>H3o`0000go[/;Y1Ol0
0006oiVjkP03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool09?ooool003Oooooo0ol0001nooooo`?o00000onQ
V</2o`0000coXj?D0ol000000onU[Mco0000o`00000>okBlg`03o`000?nka^?o^lKS00Ko^lKS1Ol0
000<ojk2j@Go00001?nP^>T4o`0000?oVK[^00?o0000ooooooooool07?ooool3o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02Cooooo000eooooo`;o00000ooo
ool00ol0003oooooooooo`1hooooo`?o00002?nQV</2o`0000coXj?D0_l0000>okBlg`;o00002onk
a^<00ol0003o^<SWokS8i`06okS8i`Ko00001?nP^>T00ol0003oX;SYoj2hj@06oj2hj@Co00008Ooo
ool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00008oooool003;o
oooo0ol0001mooooo`?o00003OnQV</00ol0003oXj?Doj>Se007oj>Se0;o00001?ne]]T4o`0000Ko
];cO0_l0000;ok_6h`03o`000?nhb>Oo^<SW00Wo^<SW0_l00005oj_2j`Ko00002?nP^>T2o`00023o
oooo00?o0000ooooooooool0>Oooool0033ooooo0_l0001mooooo`?o00001?nNS/<00ol0003oXIS;
oj6Hb`0:oj6Hb`;o00001OnSXm@2o`0000[o]KKI0ol00002okBlg`03o`000?nka^?o^lKS00Wo^lKS
0_l00009okS8i`;o00002_n[`^/01?l0003oZl;[oj_2jon[`^/6o`0000?oRk;`00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0hooooo`00;Oooool4o`0007_ooooo0ol00008oij>``;o0000
3?nQV</2o`000003oj>Se?l0003o000000oo]KKI0_l000000onka^?o0000o`000009o`0000;o^<SW
2Ol0000<oj_2j`Co00001?nE/NX3o`0000?oRk;`00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0gooooo`00;?ooool2o`0000?ooooo00?o0000ooooooooool0MOooool3o`0000?oVhJl00?o
0000oij>`onNS/<01onNS/<00ol0003oXIS;oj6Hb`0:oj6Hb`;o00003one]]T2o`0000_o_lCN00?o
0000ol;=hoo2cN<02?o2cN<00ol0003o^<gYokS=j@06okS=j@Oo00002_nE/NX3o`000003oh^bl?l0
003ooooo01oooooo00?o0000ooooooooool0=oooool002cooooo00?o0000ooooool00000N?ooool2
o`0000OoVhJl00?o0000oij>`onNS/<01onNS/<2o`0000WoXIS;00?o0000ok>]d_nc[M800_nc[M84
o`0000So]KKI00?o0000oko4g_noa=h02Onoa=h2o`0000So`/gS0_l0000;okS=j@03o`000?nS`>ko
Xl3^00;oXl3^00Co0000oj?0k_l0003o00002_nE/NX3o`00023ooooo00?o0000ooooooooool0=_oo
ool002cooooo00Co0000oooooooooooo0000MOooool2o`0000[oVhJl00?o0000oij>`onNS/<02?nN
S/<00ol0003oXIS;oj6Hb`04oj6Hb`;o00002Onc[M84o`0000;o]KKI0_l0000:oko4gP;o00002?o2
cN<2o`0000Ko^<gY1?l00008oj?0kP03o`000?nS`>koXl3^00CoXl3^1_l00004oiFajP03o`000?oo
oooooooo01cooooo00?o0000ooooool00000=oooool002cooooo00Go0000ooooooooooooooooo`00
001aooooo`?o00000_nIOkH00ol0003oVhJloi^6_008oi^6_003o`000?nNS/?oWXk300SoWXk30_l0
0003oj6Hb`03o`000?nc[M;o/jgB00go/jgB0_l000000onoa=ko0000o`000003o`0000Go_lCN00?o
0000ol;=hoo2cN<00_o2cN<6o`0000;o^<gY0ol00004olKEi@[o]Lo]0_l00002oiBklP03o`000?n5
Z>_oQJS[00GoQJS[0_l00004ogFWl@03o`000?oooooooooo01kooooo00?o0000ooooooooool0=Ooo
ool002_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`;o00001_nIOkH0
0ol0003oVhJloi^6_008oi^6_003o`000?nNS/?oWXk300WoWXk300?o0000oj6Hbol000003onc[M80
0ol0003o`/3Hol;0f006ol;0f0Go000000?o`/gSo`000?l000000_l00004olW?gPSoa]GU00?o0000
okG?kOnecnd01Onecnd3o`0000?oU;_b00?o0000oiBkl_nD^o800onD^o82o`0000GoQJS[0ol00002
ogFWl@03o`000?oooooooooo01kooooo00?o0000ooooooooool0=?ooool002_ooooo0_l00005oooo
o`03o`000?oooooooooo06Sooooo0ol00009oiUo]P03o`000?nKQ[coVhJl00SoVhJl00?o0000oij>
`onNS/<02?nNS/<2o`0000oo/jgB00?o0000ol;0f?o2`=P02Oo2`=P00ol0003obLoNolW?gP06olW?
gP;o00001oo6eND2o`0000Co]Lo]00?o0000olOMjOo7gNT01on/d?<00ol0003oU;_boiBklP06oiBk
lP?o00001?n5Z>/2o`000003ogFWlOl0003ooooo01oooooo00?o0000ooooooooool0<oooool002_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Sooooo`Co00000_nGN[400ol0003o
VGnfoiUo]P08oiUo]P03o`000?nKQ[coVhJl00SoVhJl00?o0000oij>`onNS/<01OnNS/<2o`0000?o
/JC;0ol00009ok>]dP;o00002oo2`=P00ol0003obLoNolW?gP06olW?gP03o`000?o6eNGoa]GU00?o
a]GU1?l000000onecngo0000olOMj@03olOMj@[o[=3c00?o0000ognam?mo/O@01?mo/O@2ofjJj`?o
U;_b0ol00003ohFXj`;o00008?ooool00ol0003oooooooooo`0cooooo`00:oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05oooooo0ol00007oiMj/@03o`000?nIOkKoVGnf00SoVGnf
00?o0000oi^6_?nKQ[`02?nKQ[`00ol0003oWXk3oij>``02oij>``;o00002?naY</3o`0000Go/jgB
00?o0000ol;0f?o2`=P02_o2`=P00ol0003obLoNolW?gP06olW?gP04o`000?o6eNGoa]GUolKEi@?o
00000_oAf]l5olOMj@Co[=3c00?o0000olCSk_nMc?P01_nMc?P00ol0003oWLchoig<n002oig<n003
ognam?l0003oOk7d00;oOk7d1?m^V^/2o`000005oeJEkol0003o0000ohFXjol000008?ooool00ol0
003oooooooooo`0booooo`00:oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05_o
oooo0ol000000onFMjko0000oiMj/@08oiMj/@03o`000?nIOkKoVGnf00SoVGnf00?o0000oi^6_?nK
Q[`02?nKQ[`01?l0003oWXk3o`000?l0000=ok6Tb`?o000000?o/jgBo`000?o2`=P02oo2`=P00ol0
003obLoNolW?gP03olW?gPCo000000?oa]GUo`000?oAf]l01?oAf]l4olOMj@03omKUhOo4hnko0000
00;o000000?oa>?^okcUlonliO<00onliO<3ojoRn0;oWmSl00?oR<;jo`000?n8`_X00on8`_X4of>P
lP03ognam?l0003oKY[[00?oKY[[0_l00002oeJEk`03o`000?oooooooooo01gooooo0_l0000doooo
o`00:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo0_l00005oiIg[P03
o`000?nGN[7oUgZa00OoUgZa00?o0000oiUo]_nIOkH02?nIOkH00ol0003oVhJloi^6_007oi^6_0;o
00004_naY</00ol0003o`/3Ho`000004o`0000Ko`/3H00?o0000olW?g_o9cmh01?l00002olo=f0Ko
dM[O0_l00002olOMj@;oe^GQ0ol000000oo4hnkoenoSokcUl`02okcUl`?o[n;h00?oc=3Mol:id_o2
^M800_o2^M800onTZ]_o0000o`000004ojBZf`?oKk7i0omSX?83oe27iP?oKY[[0_l000000omFUNoo
0000ooooo`0Oooooo`03o`000?oooooooooo037ooooo000Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0E?ooool3o`0000SoUWN^00?o0000oiMj/OnGN[401onGN[400ol0003oVGnf
oiUo]P08oiUo]P03o`000?nKQ[coVhJl00CoVhJl0_l00003ojfJa0?o00003?naY</00ol0003o`[[B
ol:jdP06ol:jdPSo00001Oo?cMP00ol0003odM[Oom7Jg`03om7Jg`;o000000CoamgYomKUhOoFiN7o
e^GQ0_l000001?o4hnkoenoSomO_honliO<2om?di@04olgfjOoEin;oc=3Molc@g@So`[WB00?o0000
oj2KconPVll00_nPVll2o`0000;oY:[K00CoNI7Nod>:k?mSX?;oHj3b1?m@QnH2ofjJj`?o00008?oo
ool00ol0003oooooooooo`0`ooooo`00:_ooool2o`0000cooooo00?o0000ooooooooool0D?ooool3
o`0000;oUGB/00?o0000oiIg[_nFMjh01onFMjh00ol0003oUgZaoiMj/@07oiMj/@03o`000?nIOkKo
VGnf00SoVGnf00?o0000oi^6_?nKQ[`00_nKQ[`00ol0003o[I[4ojfJa006ojfJa0;o00002?naY</2
o`0000co`[[B00?o0000olo=f?o?cMP01_o?cMP00ol0003odM[Oom7Jg`02om7Jg`;o00001OoFiN40
0oo4hnko0000o`000002omO_h`;odoCU00CocOKYomGWh_o<d=goc=3M1?o2^M87o`0000KoX9_?00Go
NXODo`000?mjQmCoNXODogVAgP02od>:k007of>Pl_m@QnKoD8OVoe27i_l0003o;gcVofjJj`02o`00
01oooooo00?o0000ooooooooool0<?ooool002[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1<ooooo`?o00001_nEM:`00ol0003oUWN^oiIg[P07oiIg[P03o`000?nGN[7oUgZa00Oo
UgZa00?o0000oiUo]_nIOkH02?nIOkH01?l0003oVhJlo`000?l0000;ojfJa0;o00001OnaY</00ol0
003o`[[Bol:jdP0;ol:jdP03o`000?o?cMSoclgH00KoclgH00Oo0000om7JgooAf]oodM[Oo`000?oI
g=Wo000000Coe^GQ00?o0000omO_hol000000_oGkn<2om?di@;ocOKY00?o0000on3Md_l000001_l0
0005okVWb0Go00000onPVll2ogZ7e004o`000?mjQmCoNXODobEbh@;o@h[/00?o;W3Noe27i_m@QnH0
0_l00002obmliP03o`000?oooooooooo01gooooo00?o0000ooooooooool0;oooool002[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`18ooooo`?o000000?oUG>[o`000?nEM:`01onE
M:`00ol0003oUWN^oiIg[P06oiIg[P03o`000?nGN[7oUgZa00SoUgZa00?o0000oiUo]_nIOkH01onI
OkH2o`0000oo[I[40ol000000onaY<_o0000ol:jdP0;ol:jdP;o00002?o?cMP00ol0003odM[Oo`00
0003omWLf@05o`000?oFiN7oe^GQomKUhOoQjMP00ol00002omO_h`04om?diOo=m^WocOKYonOadP;o
h=gB0_l00003omC5b`;o00001_niYlP00ol0003o^JO8okVWb002okVWb0;o00000onPVll2ogZ7e003
o`000?mjQmCoA6WB00;o9G;Q00Oo;W3Noe27i_m@QnKoD8OVo`000?l_O>Ko0000023ooooo00?o0000
ooooooooool0;_ooool002[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`15oooo
o`;o00001OnELj/00ol0003oUGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^00?o0000oiMj
/OnGN[402?nGN[400ol0003oVGnfoiUo]P04oiUo]P;o00000onXTKh00ol0003o[I[4ojfJa00>ojfJ
a004o`000?o2^];o0000o`0000Wo`[[B00?o0000olo=f?o?cMP01?o?cMP4o`0000GofMcI00?o0000
omKUhOoFiN400_oQjMP2o`0000;oenoS0_oCm>D00ooMoMCofocIonOadP02on3MdP03o`000?oDaL_o
e<G;00;oe<G;00?o0000okVWb?niYlP01_niYlP01?l0003o^JO8o`000?l00004oijAa@?oOX7<00Oo
X9_?ogZ7e?mjQmCoNXODodAYd_lmK]Wo9G;Q00;o;W3N0_m@QnH3o`0001kooooo0_l0000`ooooo`00
:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo0_l00008oiEcZ`03o`00
0?nEM:coUGB/00KoUGB/00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUgZaoiMj/@08oiMj/@03o`00
0?nIOkKoVGnf00;oVGnf00?o0000ojRA__nXTKh01?nXTKh2o`0000co[I[400?o0000ol2bc?o0//`0
0oo0//`5o`0000?o`[[B00?o0000olo=f?o?cMP01Ol00002om7:d`KofMcI00?o0000omKUhOl00000
0_oQjMP2o`000003omO_hooCm>Go000000;ogOgD00Goi__:onOad_o]ml?oh=gBo`000003omC5b`;o
00000oniYlP7o`0000SoWY751OmnPL`3ogZ7e0;o?FkI00?o35OAobi`g_l^L=h00_m@QnH2o`0001oo
oooo00?o0000ooooooooool0;Oooool002[ooooo0_l0000Aooooo`03o`000?oooooooooo03kooooo
0ol000000onELj_o0000oiEcZ`08oiEcZ`03o`000?nEM:coUGB/00GoUGB/00?o0000oiIg[_nFMjh0
1onFMjh00ol0003oUgZaoiMj/@08oiMj/@04o`000?nIOkKo0000o`0000WoZ96n0_l00009ojfJa003
o`000?o0//co`;;<00Wo`;;<1Ol00006om7:d`03o`000?oIg=WofMcI00CofMcI00?o0000omKUhOoQ
jMP00_oQjMP2o`00000:on?de_oCm>GohO[Do`000?oMoMCoi__:onOad_o]ml?oh=gBo`0000;oe<G;
0ol00008olVa`P;o/i^o0_l00009oijAa@GoOX7<0_mjQm@00om4JM;o0473o`aGd@02obi`gP03o`00
0?m@QnKo0000023ooooo00?o0000ooooooooool0;?ooool002Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0kooooo`;o00001OnELj/00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nE
M:coUGB/00KoUGB/00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUgZaoiMj/@08oiMj/@;o00003OnX
TKh00ol0003o[I[4ojfJa004ojfJa0;o00003Oo0//`00ol0003odL[Com7:d`06om7:d`03o`000?oI
g=WofMcI00?ofMcI0_l00004on7Yf0Co000000CohO[Do`000?oMoMCoi__:0_o]ml<00ooPgM;o0000
omC5b`02o`000003on7?a_l0003obK7200KobK7200?o0000ok>K_oncVkl00_l00003ok>K_`03o`00
0?nNTLGoWY7500GoWY7500?o0000ogj1c?mnPL`00_mnPL`01?m>JLkoNXODodAYd_l0@L<2o`aGd@;o
;W3N0_l0000Oooooo`03o`000?oooooooooo02cooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0>?ooool2o`0000SoUG>[00?o0000oiEcZonELj/01_nELj/00ol0003o
UGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^00?o0000oiMj/OnGN[401OnGN[42o`0000?o
XhVi00?o0000ojRA__nXTKh02_nXTKh2o`0000?o[I[400?o0000ol2bc?o0//`03?o0//`00ol0003o
dL[Com7:d`06om7:d`04o`000?oIg=WofMcIomWLf@Co00000ooQjMP3o`000009onWgc?l0003ohO[D
o`000?oRoKooh_g1onOad_o]ml?ok>K900?o00000_oQclH00ol0003obK72olVa`P04olVa`P03o`00
0?ncVkoo000000;o000000?o/i^oo`000?ncVkl01?ncVkl3o`0000CoWY7500?o0000ogj1c?mnPL`0
0_mnPL`2odiYcP07o`000?l0@L?o02jfo`aGdOl0003o;W3No`00000Pooooo`03o`000?oooooooooo
02_ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0ol000000onE
M:co0000oiEcZ`08oiEcZ`03o`000?nELj_oUG>[00KoUG>[00?o0000oiEd[?nEM:`01_nEM:`00ol0
003oUWN^oiIg[P06oiIg[P03o`000?nGN[7oUgZa00;oUgZa0_l00006oj>9^@03o`000?nXTKkoZ96n
00_oZ96n00?o0000ojfJa?l000003_o0//`00ol0003odL[Com7:d`06om7:d`03o`000?oIg=Wo0000
00;o00000_oNfm<00ol0003ohNWHon7Yf002o`000008onO[dOl0003ojOO<onWgc?oQn]Co0000on;m
_ooRoL42ongg``03oncVbOl0003o000000?ohLo600?o0000olVa`_o9/L800_o9/L85o`0000Go/i^o
00?o0000ok>K_oncVkl01OncVkl3o`0000?oWY7500go0000ogj1c?mnPLcoOX7<odiYc_l8A<CoA6WB
o`11`ol0;[Ko35OAo`000?l^L=ko0000023ooooo00?o0000ooooooooool0:_ooool000Kooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool3o`0000GoUGB/00?o0000oiEcZonELj/0
1_nELj/00ol0003oUG>[oiEcZ`07oiEcZ`03o`000?nEM:coUGB/00GoUGB/00?o0000oiIg[_nFMjh0
1onFMjh01?l0003oUgZao`000?l00009oj>9^@03o`000?nXTKkoZ96n00[oZ96n1?l0000<ol2bc003
o`000?oAb]?odL[C00KodL[C00?o0000omWLfOl000001?oNfm<01?l0003ohNWHo`000?l00002onO[
d@03o`000?oYmlcojOO<00;o000000Coh_foon;m`Oo]ml?okOO30_l00004on7?aP04o`000?o9/L;o
bK72olVa`PGo00000oo1XkX6o`0000;o/i^o0ol00003oij;_P?oQ7o500Co0000oijAaOl0003o0000
0_mnPL`02Om>JLko24C4o`Q4a?l0@L?o04g;o`aGdOl0003o03k1o`00000Nooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@06ooooo`003_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo
0ol000000onFMjko0000oiEd[006oiEd[003o`000?nELj_oUG>[00KoUG>[00?o0000oiEcZonELj/0
1_nELj/00ol0003oUGB/oiEd[006oiEd[003o`000?nFMjkoUWN^00KoUWN^0_l0000<oj>9^@;o0000
2OnXTKh00ol0003o_:W7okbYa`02okbYa`Co00001oo0//`00ol0003odL[Com7:d`03om7:d`Co0000
1_oNfm<00ol0003ohNWHo`000003onO[d@03o`000?oYmlcojOO<00;o000000Ooh_foon;m`Oo]ml?o
kOO3o`000?o`kl?o000000?ohLo600?o0000olVa`_l000000ol00002omBi_`03o`000?o1Xk[o`J>j
00Oo`J>j0ol00007oij;_PKoQ7o50_l000002_mnPLcoCVW>o`Q4a?l8A<Co0473o`0^]_l<Em7o0000
o`0n`Ol0000Oooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Gooooo000>ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`;o00006Oooool2o`00
02[ooooo0_l00005oiIg[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonELj/01_nELj/00ol0
003oUG>[oiEcZ`06oiEcZ`03o`000?nEM:coUGB/00KoUGB/00?o0000oiIg[_nFMjh00_nFMjh3o`00
00?oWh>d00?o0000oj>9^OnSRKT02_nSRKT00ol0003oZ96nojRA_P05ojRA_P03o`000?nlZLOo_:W7
00Oo_:W71?l00002ol2bc003o`000?oAb]?o000000Co00000oo@a<l00ol0003og]_ComkKd`03omkK
d`?o00000ooWjm400ol0003ojOO<onWgc002o`000005on;m_ooRoL7oooooongg`ol000000_o`kl<2
on7?aPGo00001?oD^Kl00ol0003o`J>jol6S^P07ol6S^P04o`000?n`TkWo0000ok2C^@SoWX^n00?o
0000ohAoaOn4OlD00on4OlD01?mKK<_o0000o`000?m>JLh2o`Q4a003o`000?l0;[Ko000000;o0000
8?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00Cooooo000>ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool09?ooool3o`0000SoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03
o`000?nELj_oUG>[00KoUG>[00?o0000oiEd[?nEM:`01_nEM:`01?l0003oUWN^o`000?l00007oin3
]003o`000?nSRKWoXhVi00[oXhVi00?o0000ojRA__nXTKh00onXTKh00ol0003o_:W7okbYa`0<okbY
a`Co00001oo@a<l00ol0003og]_ComkKd`03omkKd`;o00001?oWjm402_l0003ojOO<onWgc?oVo<Co
0000on;m_ooRoL7oiO^fongg`ol00002oo3_``;ohLo60ol00006omBi_`03o`000?o1Xk[o`J>j00Ko
`J>j0_l00003ok2C^@04o`000?n`TkWo/9>io`0000OoWX^n00?o0000ohAoaOn4OlD00_n4OlD2oe]/
b`;o00000_l8A<@5o`0001oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`05ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo023ooooo0ol00002oiMj/@03o`000?nFMjkoUWN^00OoUWN^00?o0000
oiEd[?nEM:`01?nEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nELj_oUG>[00KoUG>[00?o0000
oiEd[?nEM:`01_nEM:`2o`0000[oWh>d00?o0000oj>9^OnSRKT02_nSRKT01Ol0003oZ96nojRA__nX
TKko000000ko_:W700?o0000om34coo@a<l02?o@a<l00ol0003og]_ComkKd`02omkKd`;o00001OoW
jm400ol0003ojOO<onWgc002onKla005o`000?oRoL7oiO^fongg`ol000000_o`kl<3o`0000;oj=S4
1_oD^Kl00ol0003o`J>jol6S^P06ol6S^P03o`000?n`TkWo/9>i00Co/9>i00Co0000ok2C^On`TkWo
/9>i0_l00005oij;_P03o`000?n4OlGoQ7o500;oQ7o50omKK</2o`000003o`Q4a?l0003o000000?o
00007oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`Co00001_nGN[400ol0003oUWN^oiIg[P06oiIg[P03o`000?nEM:co
UGB/00GoUGB/00?o0000oiEcZonELj/01_nELj/00ol0003oUG>[oiEcZ`06oiEcZ`03o`000?nEM:co
UGB/00;oUGB/0ol000000onKOK7o0000oin3]00:oin3]003o`000?nSRKWoXhVi00[oXhVi00?o0000
ojRA__l000003_nlZLL00ol0003od<C?om34c`08om34c`04o`000?oNfm?og]_ComkKd`;o000000?o
gmS@o`000?oWjm400ooWjm400ol0003ojOO<o`000002onKla003onKk]ooRoL7oiO^f00Oo00000_oX
f<@6omBi_`03o`000?o1Xk[o`J>j00Ko`J>j00?o0000ok2C^On`TkT01_n`TkT00ol0003o/9>iok2C
^@02ok2C^@;o00001OnNRkh01?l0003oQ7o5ohAoaOn4OlD2oe]/b`;o64c700?o0000o`Q4a?l00000
0ol0000Pooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool02?ooool002Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`?o00000_nIOkH00ol0003oUgZaoiMj/@06oiMj/@03o`00
0?nFMjkoUWN^00KoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`03o`00
0?nELj_oUG>[00KoUG>[00Co0000oiEd[?l0003o00001OnKOK400ol0003oWh>doin3]009oin3]0;o
00002_nSRKT3o`0000go_:W700?o0000om34coo@a<l02?o@a<l00ol0003og]_Co`000002o`0000;o
gmS@00Co0000onO[dOoWjm7oin_A0_l000001ooYmlco0000o`000?oVo<Coi_^gon;m_ooMnJ`00ol0
00000oo`kl?o0000o`000003onSHa003o`000?oD^Kooe;Vo00;oe;Vo0_l000000oo1Xk[o0000o`00
0006o`0000Wo/9>i00?o0000ok2C^On`TkT01?n`TkT5o`000003oij;__l0003oQ7o500;oQ7o50_mK
K</2oaQ<a`03o`000?l06jSo026]00?o00007Oooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`08ooooo`00
:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo0ol00006oiUo]P03o`00
0?nGN[7oUgZa00KoUgZa00?o0000oiIg[_nFMjh01_nFMjh00ol0003oUGB/oiEd[005oiEd[003o`00
0?nELj_oUG>[00GoUG>[00?o0000oiEcZonELj/01_nELj/2o`0000SoVgfa00?o0000oin3]?nOPk@0
2_nOPk@00ol0003oXhVioj>9^@06oj>9^@04o`000?nfX<;o]Z32okJP`P?o00002OnlZLL00ol0003o
d<C?om34c`08om34c`?o00001?oOf=001_l0003oin_AonO[dOoWjm7o0000on[[cP;o000000?ok?S4
onKla?oVnkL01?l00003oo3_``05o`000?oXf<Coj=S4onSHa?l000000ooD^Kl2o`000003omc1__l0
003objVh00OobjVh00?o0000okbI]OnlVKD00ol00005ok2C^@03o`000?n`TkWo000000;o00000onQ
R;X3oh]o`@Co00000_n4OlD2oe]/b`;o64c700?o0000o`0KZ?l08Jd00_l0000Pooooo`09o`000?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001oooool002Oo
oooo0_l0000Qooooo`03o`000?oooooooooo013ooooo0_l00003oi^6_0OoVGnf00?o0000oiMj/OnG
N[401_nGN[400ol0003oUWN^oiIg[P05oiIg[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonE
Lj/01_nELj/00ol0003oUG>[oiEcZ`02oiEcZ`?o000000?oUgV`o`000?nKOK402?nKOK400ol0003o
Wh>doin3]00:oin3]003o`000?nSRKWoXhVi00?oXhVi0_l00007okJP`P?o00001OnlZLL00ol0003o
d<C?om34c`08om34c`;o00001OoOf=000ol0003oin_AonO[d@02o`000004on[[c_l0003o0000onch
a0Co000000?oiO^fo`000?o`kl<00_o`kl<01Ol0003oj=S4onSHa?oXf<Co000000;oe;Vo0_l00002
omc1_P03o`000?o;ZKSobjVh00KobjVh00?o0000okbI]OnlVKD01?nlVKD3o`0000;o/9>i0_l00007
oj68^PGoRgo11?l00002oe]/b`;o64c700?o0000o`0KZ?l08Jd00_l0000Oooooo`03o`000?oooooo
oooo02Gooooo000Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool2o`00
00KoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@06oiMj/@03o`000?nFMjkoUWN^
00GoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`06oiEcZ`04o`000?nELj_o0000
o`0000GoUgV`00?o0000oi]m/OnKOK401onKOK400ol0003oWh>doin3]00:oin3]005o`000?nSRKWo
XhVioj>9^Ol000003?nfX<83o`000003okbYaol0003od<C?00?od<C?1ol00006omoHd004o`000?oW
jm7o0000o`0000;oj^_>1?l000001OoVnkOo0000o`000?oMnJco000000?ol>o300?o0000onSHa?oX
f<@00_oXf<@3o`0000?og<6n00?o0000ol^Y^?o;ZKP01_o;ZKP00ol0003o_9VeokbI]@08okbI]@;o
00000_nQR;X00ol0003oXHRjoj68^P05oj68^P03o`000?n;Ol7oRgo100;oRgo100?o0000ofQab?mX
LLP00_l000001_mKK<_o64c7oaQ<aol0003o01^Xo`0Q[@;o00007oooool00ol0003oooooooooo`0T
ooooo`009oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0ol00009oi^6
_003o`000?nIOkKoVGnf00CoVGnf00?o0000oiMj/OnGN[401OnGN[400ol0003oUWN^oiIg[P06oiIg
[P03o`000?nEM:coUGB/00GoUGB/00?o0000oiEcZonELj/01?nELj/3o`0000SoUgV`00?o0000oi]m
/OnKOK401onKOK400ol0003oWh>doin3]00:oin3]003o`000?nSRKWo0000013o]Z321_l00005olfm
b`03o`000?oOf=3ogmS@00GogmS@0_l00002on[[cP?o000000Sok?S4o`000?oVnkOo0000omkj[?l0
003oiO^fo`0000;ol>o30_l00003onSHa0;o00001?oL`Kh00ol0003objVhol^Y^006ol^Y^003o`00
0?nlVKGo_9Ve00So_9Ve00Ko0000ojn?]?n_SkCo[hndoj68^_l00008oj68^P03o`000?n;Ol7oRgo1
00;oRgo100Co0000ofQab?mXLLSoJ7780_l00002oaQ<a`03o`000?l06jSo026]00;o00007oooool0
0ol0003oooooooooo`0Sooooo`009oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Gooooo0ol00004oij>``WoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj
/@03o`000?nFMjkoUWN^00KoUWN^00?o0000oiEd[?nEM:`01OnEM:`00ol0003oUG>[oiEcZ`03o`00
00;oTgJ_00?o0000oiMi/?nGNK001onGNK000ol0003oVgfaoi]m/@07oi]m/@03o`000?nOPkCoWh>d
00WoWh>d0_l0000@okJP`P03o`000?o=_L_ocKg;00SocKg;00?o0000omoHd?oOf=001OoOf=07o`00
0008oncha?l0003oi_^gonKk]ooNnZco0000onGk]_l00002oo3_``04o`000?o^n;koj=S4onSHa0;o
00001OoL`Kh00ol0003objVhol^Y^006ol^Y^003o`000?nlVKGo_9Ve00So_9Ve00?o0000ojn?]?n_
Sk@01?n_Sk@00ol0003oXHRjoj68^P06oj68^P03o`000?n;Ol7oRgo100;oRgo100[o0000ofQab?mX
LLSo0000obaGbol0003o64c7o`0R[_l0003o01^X0_l0000Oooooo`03o`000?oooooooooo02?ooooo
000Wooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooooooo0ol00008oij>``03o`00
0?nKQ[coVhJl00KoVhJl00?o0000oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`00
0?nFMjkoUWN^00GoUWN^00?o0000oiEd[?nEM:`01?nEM:`4o`0000KoTgJ_00?o0000oiMi/?nGNK00
1onGNK000ol0003oVgfaoi]m/@07oi]m/@03o`000?nOPkCoWh>d00OoWh>d00Co0000ok2G__n`Ukko
/9Nn0_l0000<okJP`P03o`000?o=_L_ocKg;00SocKg;00?o0000omoHd?oOf=001OoOf=03o`0000?o
j^_>00Oo0000oncha?l0003oi_^go`000?oNnZcogOV/00;o00000_o`kl<01ol0003ok_RnonSHa?oX
f<Co0000ongSaOl000001OoL`Kh00ol0003objVhol^Y^005ol^Y^003o`000?nlVKGo_9Ve00So_9Ve
00?o0000ojn?]?n_Sk@01_n_Sk@2o`0000OoXHRj00?o0000oh]o`On;Ol400_n;Ol402_l0003oJ778
ofQab?l0003o;5O;o`000?lHC<Oo02:^o`000?l06jP2o`0001gooooo00?o0000ooooool000009?oo
ool002Oooooo0_l0000Vooooo`?o00000onQV</9oij>``03o`000?nKQ[coVhJl00KoVhJl00?o0000
oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`000?nFMjkoUWN^00GoUWN^00?o0000
oiEd[?nEM:`00ol00002oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK00
0ol0003oVgfaoi]m/@08oi]m/@03o`000?nOPkCoWh>d00CoWh>d0_l00006ok2G_P;o00002OnfX<80
0ol0003ocKg;olfmb`08olfmb`03o`000?oOf=3ogmS@00CogmS@0ol00004on[[cP03o`000?o/n<Co
000000;oi_^g00?o0000omkj[?l000000_l000001_o`kl?o0000onkh__l0003oj=S4o`0000;okN?5
1OoL`Kh00ol0003objVhol^Y^003ol^Y^0?o000000?o_9Veo`000?l000000_l00005okbI]@03o`00
0?n_SkCo[hnd00So[hnd0ol00006oj68^P03o`000?n;Ol7oRgo100;oRgo100[o0000ofQab?mXLLSo
0000obaGbol0003o64c7o`0R[_l0003o01^X0_l0000Oooooo`03o`000?oooooooooo027ooooo000V
ooooo`;o00009Oooool2o`0000SoXIS;00?o0000oij>`onNS/<01OnNS/<2o`0000OoVhJl00?o0000
oiUo]_nIOkH01?nIOkH00ol0003oUgZaoiMj/@05oiMj/@03o`000?nFMjkoUWN^00;oUWN^1Ol00006
oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK000ol0003oVgfaoi]m/@08
oi]m/@04o`000?nOPkCoWh>doin3]0;o00002_n`Ukh00ol0003o]Z32okJP`P05okJP`P03o`000?o=
_L_ocKg;00SocKg;00?o0000omoHd?oOf=000_oOf=03o`000003omgDcol0003oj^_>00?oj^_>0ol0
0002onKk]`Go000000Kol>o3o`000?o^n;ko0000onSHa?l00002ongSa@Gog<6n00?o0000ol^Y^?l0
00001?l00002om6_^003o`000?o4W[?oa9jc00?oa9jc1Ol0000;ojn?]004o`000?n_SkCo[hndo`00
00KoXHRj00?o0000oh]o`On;Ol400_n;Ol402?l0003oJ778ofQab?l0003o;5O;o`000?lHC<Oo02:^
1?l0000Nooooo`03o`000?oooooooooo027ooooo000Vooooo`03o`000?oooooooooo02;ooooo0_l0
000<oj6Hb`03o`000?nNS/?oWXk300GoWXk300?o0000oi^6_?nKQ[`01OnKQ[`00ol0003oVGnfoiUo
]P04oiUo]P03o`000?nGN[7oUgZa00;oUgZa1ol00003ohic/003o`000?nAM:ooTGB_00KoTGB_00?o
0000oi=f[onCMZl01_nCMZl00ol0003oUgV`oiMi/006oiMi/003o`000?nKOK7oVgfa00SoVgfa00?o
0000oin3]?l000003On`Ukh2o`0000Co]Z3200?o0000olfmboo=_L/02?o=_L/00ol0003ogmS@omoH
d003o`0000?ogMC?00Co0000on[[c_oZjlkoj^_>0ol000000oo[nL7o0000onKk]`07o`000004onkh
__l0003o0000o`0000;okN?51?oL`Kh4o`0000KodJnh00?o0000olBN/oo4W[<01oo4W[<00ol0003o
^IBaokVD/@02o`0000Wo[hnd00?o0000ojn?]?n_Sk@02_l00002oh]o`@08o`000?mXLLSoJ778o`00
0?l/El_o0000oaQ<aol08Zh4o`0001kooooo00?o0000ooooooooool08?ooool002Kooooo00?o0000
ooooooooool07oooool3o`0000?oXj?D0_l0000:oj6Hb`;o00001_nNS/<00ol0003oVhJloi^6_005
oi^6_004o`000?nIOkKoVGnfoiUo]POo00000on=M;800ol0003oSW>`ohic/005ohic/003o`000?nA
M:ooTGB_00KoTGB_00?o0000oi=f[onCMZl01OnCMZl00ol0003oUgV`oiMi/007oiMi/003o`000?nK
OK7oVgfa00OoVgfa0_l0000@ok2G_P;o000000?o]Z32o`000?o=_L/02Oo=_L/4o`0000GogMC?00?o
0000on[[c_oZjlh00_l000001OoZjlgo0000on_i`Oo[nL7oi_^g00Co000000Co_nV:o`000?l0003o
k_Rn0_l00003ongSa@?og<6n0_l000000ooQbL7o0000om6_^006om6_^003o`000?o4W[?oa9jc00Oo
a9jc00?o0000okVD/OniU;400oniU;43o`0000Go[hnd0ol00003oj>8]`KoTH6n00?o0000ogEgaol0
00000ol00002ofQab005o`000?l/El_o0000o`000?l08Zh00ol0000Oooooo`03o`000?oooooooooo
01oooooo000Vooooo`03o`000?oooooooooo01cooooo0ol00008oj>Se0?o00002OnQV</2o`0000Go
WXk300?o0000oi^6_?nKQ[`00_nKQ[`6o`0000?oS7Nf00?o0000ohed/_n=M;801On=M;800ol0003o
SW>`ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000oi=f[onCMZl01_nCMZl00ol0003o
UgV`oiMi/006oiMi/003o`000?nKOK7oVgfa00KoVgfa00Go0000ojR?^onXSk_oZ8nko`00000@ok2G
_Pgo00001ooMe<l01?l0003oj^_>on[[c_l00002on[[c@04o`000?o[nL7ojoW1onKk]`Oo00000_o^
n;h01_l0003okN?5ongSaOo]hlGo0000omc1_P;o00000_oQbL400ol0003odJnhom6_^005om6_^003
o`000?o4W[?oa9jc00Ooa9jc00?o0000okVD/OniU;401oniU;42o`000003ojn?]?l0003o000000?o
XhRg00Go0000oj>8]onSR;OoXhRgo`000005oi61_P04o`000?meMlOoMGO7ogEga`Co000000Go;5O;
o`0_^?l0;kSo0000o`0R[P03o`0001kooooo00?o0000ooooooooool07oooool002Kooooo00?o0000
ooooooooool06Oooool3o`0000?oYJgL0_l00009oj>Se0;o00002OnQV</:o`0000?oSG^k00?o0000
ohag]_n<MkH01?n<MkH00ol0003oSGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00GoSW>`00?o0000
oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`06oi=f[`03o`000?nGNK3oUgV`00KoUgV`00?o0000
oi]m/OnKOK400onKOK42o`0000GoZ8nk0_l0000=ok2G_P03o`000?o7]LSoakG800GoakG80ol00000
0oo7]LSo0000omgDc`06omgDc`04o`000?oZjlko0000o`0000;oj^_=00?o0000on_i`Oo[nL401_l0
00001OoJmjGo0000onkh__o^n;ko000000?okN?50ol00003on79`@03o`000?oA[kSodJnh00KodJnh
00?o0000olBN/oo4W[<01_o4W[<00ol0003o^IBaokVD/@0:okVD/@03o`000?nSR;OoXhRg00?oXhRg
00?o0000oj>8]onSR;L00_nSR;L00ol0003oTH6noi61_P03oi61_P06o`000?meMlOoMGO7ogEgaol0
003o@VC?0_l000001Ol/El_o02nho`0_^?l0003o02:^00?o00007?ooool00ol0003oooooo`00000P
ooooo`009Oooool3o`0001Oooooo0ol00009ojF]g0?o00001onSXm@2o`0000;oXIS;0ol00004oi6;
b@KoSX;11_n=Nk/00ol0003oS7Nfohag]P04ohag]P03o`000?n=M;;oSGBb00GoSGBb00?o0000ohic
/?n>Lk001On>Lk000ol0003oTGB_oi5d[`05oi5d[`03o`000?nCMZooTgJ_00KoTgJ_00?o0000oiMi
/?nGNK001_nGNK001Ol0003oVgfaoi]m/OnKOK7o000000WoZ8nk00?o0000ok2G__n`Ukh02On`Ukh0
0ol0003oakG8olNeb003olNeb0?o00000oo7]LP00ol0003ogMC?omgDc`05omgDc`?o00000ooZjld0
0ol0003ojoW1on_i`@02o`000003on3j[Ol0003o000000?o00000_o^n;h01?l0003okN?5ongSaOo]
hlD2o`0000GohLW100?o0000om6_^?oA[kP01OoA[kP00ol0003oa9jcolBN/`06olBN/`03o`000?ni
U;7o^IBa00Wo^IBa00Co0000ojn=/_n_SK;o[hfb1OnSR;L00ol0003oXhRgoj>8]`02oj>8]`03o`00
0?nAPKkoTH6n00?oTH6n00Ko0000ogEgaomeMlOoMGO7o`000?m2I<l2o`000003obaGbol0;kSo02nh
00Go00007_ooool00ol0003oooooooooo`0Mooooo`009_ooool00ol0003oooooooooo`0Cooooo`?o
00001?nW]N<2o`0000WoYJgL0ol00003oj>Se003o`000?nSXmCoXj?D00;o00002?nARlT00ol0003o
SX;1ohj2`@03ohj2`@03o`000?n=Nk_oSG^k00?oSG^k00?o0000ohag]_n<MkH01?n<MkH00ol0003o
SGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00CoSW>`00?o0000oi5d[onAM:l01_nAM:l00ol0003o
TgJ_oi=f[`05oi=f[`03o`000?nGNK3oUgV`00OoUgV`00?o0000oi]m/Ol000002onXSk/2o`0000So
/9Nn00Co0000olNeb?o7]LSoakG80ol00005olNeb003o`000?oMe<oogMC?00GogMC?0_l00004on[[
c@03o`000?o[nL7ojoW100;o000000?oh?Z]o`000?l000000_l000000ooJmjGo0000onkh_P02o`00
0003ongSaOl0003o000000KohLW100?o0000om6_^?oA[kP01OoA[kP00ol0003oa9jcolBN/`06olBN
/`03o`000?niU;7o^IBa00Wo^IBa00?o0000ojn=/_n_SK800on_SK82o`0000?oXhRg00?o0000oj>8
]onSR;L00_nSR;L00ol0003oTH6noi61_P03oi61_P05o`000?meMlOoMGO7ogEgaol000000_m2I<l0
1?l0003o;5O;o`0_^?l0;kP4o`0001kooooo00?o0000ooooooooool07Oooool002Kooooo00?o0000
ooooooooool04Oooool2o`0000_oYkGS0ol00007ojF]g0?o00001OnEUM49oi6;b@03o`000?n>P/7o
SX;100?oSX;100?o0000ohek^on=Nk/00on=Nk/00ol0003oS7Nfohag]P04ohag]P03o`000?n=M;;o
SGBb00CoSGBb00?o0000ohic/?n>Lk001On>Lk000ol0003oTGB_oi5d[`05oi5d[`03o`000?nCMZoo
TgJ_00KoTgJ_00?o0000oiMi/?nGNK001_nGNK02o`0000koZ8nk00?o0000ok2G__n`Ukh01?n`Ukh0
0ol0003oakG8o`000002o`0000OoakG800?o0000omgDcooMe<l01OoMe<l2o`0000Coj^_=00?o0000
on_i`Oo[nL400_l000000ooPnZgo0000o`000002o`000009om[gYOl0003ok_Rno`000?oMo;OokN?5
o`000?o/l<_o000000GohLW100?o0000om6_^?oA[kP00ooA[kP<o`0000;o^IBa00?o0000okVD/Oni
U;401_niU;400ol0003o[hfbojn=/P06ojn=/P04o`000?nSR;OoXhRgo`0000GoXhRg00?o0000oi61
__nAPKh00onAPKh01Ol0003oMGO7ogEgaomeMlOo000000;o@VC?00Co0000obaGbol0;kSo02nh1?l0
000Nooooo`03o`000?oooooooooo01cooooo000Uooooo`03o`000?oooooooooo013ooooo0_l0000@
ojNeh`Co00001OnJXMT00ol0003oUIGAoiFEd@05oiFEd@03o`000?nARlWoTH_900GoTH_900?o0000
ohj2`On>P/400on>P/400ol0003oSG^kohek^`03ohek^`03o`000?n<MkKoS7Nf00CoS7Nf00?o0000
ohed/_n=M;801?n=M;800ol0003oSW>`ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000
oi=f[onCMZl01_nCMZl00ol0003oUgV`oiMi/002oiMi/0?o00000onQQkT00ol0003oZ8nkojR?^`0;
ojR?^`;o00000on`Ukh3o`0000WoakG800?o0000omgDcooMe<l01?oMe<l2o`0000Goj^_=00Ko0000
on_i`Oo[nL7ojoW1o`000?oPnZd4o`000007om[gYOl0003ok_Rno`000?oMo;OokN?5o`000002onc`
b`KohLW100?o0000om6_^?oA[kP00ol00002omBe^P03o`000?o8Xk;ob:>b00Kob:>b00Co0000oknH
[onoV:oo_iR_1Ol00002okVD/@03o`000?n_SK;o[hfb00So[hfb00Co0000oj>8]onSR;Oo00001OnS
R;L00ol0003oTH6noi61_P03oi61_P05o`000?meMlOoMGO7ogEgaol000000_m2I<l2o`0000;o02nh
00Co02:^o`000?l0003o00007_ooool00ol0003oooooooooo`0Kooooo`009Oooool00ol0003ooooo
ooooo`0=ooooo`?o00001OnW^^L5o`0000CoYkGS0ol00004oin/h003o`000?nJXMWoVZ7I00GoVZ7I
0_l00006oiFEd@03o`000?nARlWoTH_900CoTH_900?o0000ohj2`On>P/400on>P/400ol0003oSG^k
ohek^`03ohek^`03o`000?n<MkKoS7Nf00CoS7Nf00?o0000ohed/_n=M;801?n=M;800ol0003oSW>`
ohic/005ohic/003o`000?nAM:ooTGB_00GoTGB_00?o0000oi=f[onCMZl01_nCMZl01?l0003oUgV`
o`000?l00007oj67^@03o`000?nXSk_oZ8nk00coZ8nk0ol0000<olNeb004o`000?oMe<oogMC?omgD
c`?o000000?ofLo?o`000?oZjld00ooZjld01Ol0003ojoW1on_i`Oo[nL7o000000;oh?Z]1ol00000
0ooMo;Oo0000o`000002onc`b`KohLW11?l00004omBe^P03o`000?o8Xk;ob:>b00Kob:>b00?o0000
oknH[onoV:l01onoV:l2o`0000co[hfb0_l000000onSR;Oo0000oj>8]`04oj>8]`03o`000?nAPKko
TH6n00?oTH6n00Wo0000ogEgaomeMlOoMGO7o`000?m2I<oo0000o`12a?l000000_l0;kP4o`0001co
oooo0_l0000Mooooo`009Oooool3o`0000[ooooo0ol0000=ojNji`Co00002_nO[>02o`0000KoVZ7I
0_l00004oiFEd@;o00001OnARlT00ol0003oSX;1ohj2`@03ohj2`@03o`000?n=Nk_oSG^k00?oSG^k
00?o0000ohag]_n<MkH00on<MkH00ol0003oSGBbohed/P05ohed/P03o`000?n>Lk3oSW>`00CoSW>`
00?o0000oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`06oi=f[`;o00002_nQQkT00ol0003oZ8nk
ojR?^`08ojR?^`So00002Oo7]LP00ol0003ogMC?o`000002o`0000?ofLo?00Co0000on[[cOoZjlgo
j^_=0_l00003on_i`@03o`000?oPnZgoh?Z]00Oo000000?ogObgo`000?l000000_o/l</00ol0003o
hLW1on79`@02on79`@?o00001_oD]KX00ol0003ob:>bolRS/P06olRS/P03o`000?noV:oo_iR_00Wo
_iR_00Co0000okRA[ol0003o00002on_SK800ol0003oXhRgo`000002oj>8]`So000000?oTH6no`00
0?meMlL00_meMlL01_l0003o@VC?o`000?l0@/Co0000o`0_^0Co00007_ooool00ol0003ooooooooo
o`0Jooooo`009Oooool00ol0003oooooooooo`07ooooo`?o00001OnW_^X5o`0000CoYk[W0ol00004
oj:gj0;o00002OnO[>03o`0000GoVZ7I0_l00004oiFEd@;o00001?nARlT00ol0003oSX;1ohj2`@03
ohj2`@03o`000?n=Nk_oSG^k00?oSG^k00?o0000ohag]_n<MkH00on<MkH00ol0003oSGBbohed/P04
ohed/P03o`000?n>Lk3oSW>`00GoSW>`00?o0000oi5d[onAM:l01OnAM:l00ol0003oTgJ_oi=f[`02
oi=f[`?o00000_nIPKL00ol0003oXHNioj67^@08oj67^@;o00001OnXSk/3o`0000;oZ8nk00?o0000
okn/aono[<L00ono[<L5o`0000?oakG80ol00005omW?c`07o`000?oZjlgoj^_=on[[cOl0003oin_@
o`000002on_i`@;o000000?oh?Z]o`000?l000000_l000001?oJmjGo0000o`000?oMo;L2o`0000;o
k?3;00Co0000on79`OoQbL7ohLW10_l000000ooRdlSo0000omBe^P06omBe^P03o`000?o8Xk;ob:>b
00Kob:>b00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`02okRA[`;o00002_n_SK84o`00
00GoV8Bl0on1OLH4o`0000;oMGO700Ko0000od9Tcol0003o04;4o`000?l0;kP4o`0001kooooo00?o
0000ooooooooool06Oooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00Gooooo0_l0000=ojNnjPCo00002onR]nP3o`0000OoWjcP1_l000000onJXMWo0000o`00
0003o`000003oiFEdOl0003o000000;o000000?oTH_9o`000?n>P/401?n>P/400ol0003oSG^kohek
^`03ohek^`03o`000?n<MkKoS7Nf00?oS7Nf00?o0000ohed/_n=M;801?n=M;800ol0003oSW>`ohic
/005ohic/003o`000?nAM:ooTGB_00GoTGB_00Co0000oi=f[ol0003o00001_nIPKL00ol0003oXHNi
oj67^@09oj67^@03o`000?nXSk_o000000;o00001?nXSk/00ol0003o_jc7okn/a`09okn/a`?o0000
2?oIcll01_l0003oj^_=on[[cOl0003oin_@o`0000;ojoW100?o0000onKl`_oPnZd01ol00002omgl
]`05o`000?o/l<_ok?3;onc`bol000000_oQbL401?l0003oh]?8on;Cb?l00007omBe^P03o`000?o8
Xk;ob:>b00Kob:>b00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`05okRA[`;o00001On_
SK82o`0000?oYhVe00?o0000oiR4_?nHQ;`01OnHQ;`5oh5maP?o000000CoMGO7o`000?m2I<oo0000
0_l0@/@00ol0;kSo0000o`000002o`0001gooooo00?o0000ooooooooool06Oooool001[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Wooooo1Ol00004ojNnjP?o0000
1OnU_^`5o`0000OoX[OX1?l00005ohfSi0OoQYGK1_moR=<2og]nb`Oo000000?oSX;1o`000?n=Nk/0
1?n=Nk/00ol0003oS7Nfohag]P03ohag]P03o`000?n=M;;oSGBb00CoSGBb00?o0000ohic/?n>Lk00
1On>Lk000ol0003oTGB_oi5d[`02oi5d[`Co00002OnIPKL00ol0003oXHNioj67^@07oj67^@?o0000
1OnXSk/2o`0000ko_jc700?o0000omW?cooIcll01OoIcll01_l0003oj^_=o`000?l0003oin_@o`00
00;ojoW100?o0000onKl`_oPnZd01ol00002omgl]`06o`000?o/l<_ok?3;onc`bol0003ohLW10_l0
0002on;Cb003o`000?oD]K[oe;Fj00Goe;Fj00?o0000olRS/_o8Xk801_o8Xk800ol0003o_iR_oknH
[`08oknH[`03o`000?nhTJoo^96_00So^96_0_l000000on_SK;o0000o`000006ojN9]@03o`000?nH
Q;coV8Bl00GoV8Bl00?o0000oh5ma_n1OLH00_n1OLH00ol0003oF7;Bo`000002o`000005od9Tcol0
003o04;4o`12a?l0;kP00ol0000Nooooo`03o`000?oooooooooo01Sooooo000Jooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`0?ooooo`Co00003OnU_^`5o`0000GoU[3Y
00?o0000ohfSi?n=Xn@01On=Xn@00ol0003oQYGKohJEf`03ohJEf`03o`000?moR=?oOhSC00?oOhSC
1OmkO//3og]ga0go000000?oS7Nfo`000?n=M;801On=M;800ol0003oSW>`ohic/002ohic/0Oo0000
0onBNkH00ol0003oVH6goiV1]`08oiV1]`03o`000?nQQkWoXHNi00CoXHNi0_l00003oj67^@05o`00
0?nXSk_oZ8nkojR?^ol000003ono[<L00ol0003ofLo?omW?c`05omW?c`03o`000?oZjlgo000000?o
in_@00Co0000on_i`Ol0003oi_c22?l00002omgl]`04o`000?o/l<_ok?3;onc`b`?o00001?oRdlP0
0ol0003oe;FjomBe^P04omBe^P03o`000?o8Xk;ob:>b00Oob:>b00?o0000oknH[onoV:l02?noV:l0
0ol0003o^96_okRA[`0:okRA[`;o00002?nWRKD00ol0003oV8BloiR4_005oiR4_003o`000?n1OLKo
PGg600;oPGg600?o0000oeQbd_mHL]800_l000001?m2I<oo0000o`12a?l0@/@4o`0001gooooo00?o
0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00[ooooo000Jooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Eooooo`Go00001?nU_^`3o`0000CoX[WY00?o
0000oiJ`jOnF/>T01OnF/>T2o`0000KoSJ?T1On6UM/00ol0003oOhSCogn8d`02ogn8d`03o`000?mk
O/_oNgk;00;oNgk;1?mkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00;oP7:j3Ol0
0003oh]g]`03o`000?nBNkKoTW^f00GoTW^f00?o0000oiV1]onIPKL02?nIPKL00ol0003oXHNioj67
^@03o`0000KoXHNi00?o0000ojR?^ol000003ono[<L00ol0003ofLo?omW?c`05omW?c`?o00000ooW
jm001?l0003ojoW1o`000?oVo<82o`000003om;gY?l0003o000000?o00000_oMo;L2o`0000?ok?3;
00?o0000on;Cb?oRdlP00ooRdlP00ol0003oe;FjomBe^P05omBe^P03o`000?o8Xk;ob:>b00Kob:>b
00?o0000oknH[onoV:l02?noV:l00ol0003o^96_okRA[`09okRA[`05o`000?naSK3o/Hf`ok6=/?l0
00001onWRKD3o`0000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH01?l0003oF7;BoeQbd_mHL]83o`00
0003o`12a?l0003o000000;o00007?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
00cooooo000Jooooo`05o`000?ooooooooooooooool000001Oooool2o`0001_ooooo1?l0000;oj:i
j@?o00001?nF/>T3o`0000CoSJ?T00Go0000ohJEfon6UM_oQYGKo`000004ogn8d`03o`000?mkO/_o
Ngk;00;oNgk;00Go0000og]ga?mkMlCoNgO4o`000005ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o
0000ohEc^?n5LkP01?n5LkP00ol0003oRgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00GoTW^f00?o
0000oiV1]onIPKL01onIPKL3o`0000WoXHNi1?l0000=okn/a`03o`000?oIcloofLo?00KofLo?00?o
0000onO[d?oWjm000_oWjm001_l0003ojoW1o`000?oVo<;o0000on3j[@Oo000000?ogObgo`000?l0
00000_o/l</2o`0000Goh]?800?o0000omBe^_oD]KX01OoD]KX01?l0003ob:>bolRS/_o8Xk8;o`00
00Go_iR_00?o0000okRA[onhTJl02OnhTJl00ol0003o/Hf`ok6=/003ok6=/0;o00001_nWRKD00ol0
003oYhVeo`000006oiR4_003o`000?n1OLKoPGg600;oPGg600Co0000oeQbd_mHL];oF7;B0ol00000
0ol0@/Co0000o`000002o`0001kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`006_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool08?ooool5
o`0000OoX[WY1Ol00002oiJ`j@Go000000CoSJ?To`000?n6UM_oQYGK0_l00004ogn8d`05o`000?mk
O/_oNgk;og]nbol000000omkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j
00?o0000ohEc^?n5LkP01?n5LkP00ol0003oRgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00GoTW^f
00?o0000oiV1]onIPKL00onIPKL3o`0000;oVH6g00?o0000oj67^OnQQkT01_nQQkT00ol0003o]J?6
okFSaP02okFSaP?o00002Ono[<L00ol0003ofLo?omW?c`06omW?c`03o`000?oWjm3oin_@00?oin_@
0_l00002onKl`P;o000000?od_NTo`000?l000000ol000000ooMo;Oo0000o`000002onc`b`03o`00
0?oNoM?o000000Coh]?800?o0000omBe^_oD]KX00ooD]KX7o`0000GobjNd00?o0000olBL[oo4W:l0
0oo4W:l7o`0000Wo^96_00?o0000ok6=/?naSK001_naSK000ol0003oYhVeojN9]@04ojN9]@03o`00
0?nWRKGo000000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH01?l0003oF7;BoeQbd_mHL]83o`000005
o`12a?l0003o0000o`0?V_l000007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo000Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Uoooo
o`Go00001_nB^o<5ogjZl0KoJiW[00CoGhSRohJEfon6UM_o00001?moR=<01Ol0003oNgk;og]nbomk
O/_o000000?oNgO400?o0000ogac__mlLkh00omlLkh00ol0003oP7:joh1b^P03oh1b^P03o`000?n5
LkSoQG>h00CoQG>h00?o0000oh]g]on;MkL01On;MkL00ol0003oTW^foi9k]P05oi9k]P03o`000?nI
PKOo000000;o00001_nIPKL00ol0003oXHNioj67^@03oj67^@;o00002?neXlH3o`0000Go_jc700?o
0000omW?cooIcll00ooIcll4o`0000Goin_@0_l00002onKl`P;o000000?od_NTo`000?l000000ol0
00001?oMo;Oo0000o`000?o/l</2o`000003omkmdol0003oh]?800Coh]?800?o0000omBe^_oD]KX0
0ol00002omFi_P03o`000?o;YkCobjNd00KobjNd00?o0000olBL[oo4W:l02?o4W:l00ol0003o_YB/
okjD[003o`0000Go^96_00?o0000ok6=/?naSK002?naSK000ol0003oYhVeojN9]@04ojN9]@03o`00
0?nWRKGo000000KoV8Bl00?o0000oh5ma_n1OLH00_n1OLH02?l0003oF7;BoeQbd_mHL];o0000oa1I
d_l0003o04;40_l000000ol03i[o0000ooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo02[ooooo00?o0000oi:klonB^o<01_nB^o<00ol0003oOZ[`ogjZl002ogjZl0GoJiW[0_mOR>83
o`0000;oOhSC00Go0000og]nbomkO/_oNgk;o`000003og]ga003o`000?mlLkkoO7>n00?oO7>n00?o
0000oh1b^_n0L[X00on0L[X00ol0003oQG>hohEc^004ohEc^003o`000?n;MkOoRgNg00CoRgNg00?o
0000oi9k]_nBNkH01?nBNkH3o`0000[oVH6g00Go0000oj67^OnQQkWoXHNio`00000=okFSaP?o0000
00?o_jc7o`000?oIcll01Ol00003om79d@03o`000?oWjm3oin_@00?oin_@00Ko0000onKl`_oVo<;o
i_c2o`000?oBmj@8o`000005onc`bol0003og_gComkmdol000001OoRdlP4o`0000CoeKVn00?o0000
ol^W]?o;Yk@01_o;Yk@00ol0003oa9b_olBL[`08olBL[`03o`000?nnU:co_YB/00Co_YB/0ol00000
0onhTJoo0000ok6=/00;ok6=/0;o00001?nWRKD00ol0003oYhVeo`000009o`0000?oPGg600So0000
oeQbd_mHL];oF7;Bo`000?l@FM;o0000o`12a0?o00007_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00cooooo000Sooooo`03o`000?oooooooooo033ooooo1Ol00002oi:kl`?o0000
0_mnZ_04of^Ij`;oGhSR00?oF7[Jo`000?l000000_l00003og]nb`05o`000?mkMlCoNgO4og]ga?l0
00001OmlLkh00ol0003oP7:joh1b^P03oh1b^P03o`000?n5LkSoQG>h00?oQG>h00?o0000oh]g]on;
MkL01On;MkL00ol0003oTW^foi9k]P03o`0000?oTW^f00?o0000oiV1]onIPKL02?nIPKL00ol0003o
XHNio`00000AokFSaP?o00001ooAbM400ol0003oin_@onO[d003onO[d005o`000?oVo<;oi_c2onKl
`_l000000_oBmj@5o`000004omgl]on]kZ?o0000o`0000?og_gC00Co0000on;Cb?oRdlSoh]?80ol0
0006omFi_P03o`000?o;YkCobjNd00OobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD
[008okjD[003o`000?naSK3o/Hf`00go/Hf`00?o0000ojN9]OnWRKD00ol00003oin9_0OoS8G60ol0
00000on1OLKo0000oeQbdP02oeQbdP03o`000?l@FM;o000000Co00006oooool3o`0000Oooooo00?o
0000ooooooooool03?ooool002?ooooo00?o0000ooooooooool0=Oooool00ol0003oL[Wkog:in`02
og:in`?o:Y;_00Ko0000ogjZl?m[VN_oJiW[o`000?mOR>83oeQjfPCo000000?oNgk;o`000?mkMl@0
0_mkMl@00ol0003oO7>nogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o0000ohEc^?n5LkP0
0on5LkP00ol0003oRgNgoh]g]`04oh]g]`?o00001onBNkH00ol0003oVH6goiV1]`07oiV1]`;o0000
4?neXlH00ol0003odLWAom79d@08om79d@03o`000?oWjm3oin_@00;oin_@0_l00002onKl`P;o0000
0_oBmj@5o`000004omgl]on]kZ?o0000o`0000?og_gC00?o0000on;Cb?oRdlP00_l000000ooNg]Go
0000omFi_P06omFi_P03o`000?o;YkCobjNd00KobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o
_YB/okjD[009okjD[004o`000?niTJgo0000o`0000go/Hf`0_l00003oin9_005o`000?nORKcoWhVl
oin9_?l000001_n<QLH2ofaoe0?o00000omHL]800ol0003o45WBoa1IdP03o`0001kooooo00?o0000
ooooooooool00_ooool00omEEEGoIVIVo`00000>ooooo`008oooool2o`0003[ooooo0ol000000omb
^O_o:Y;_obZBk`02obZBk`04oaili_m[VN_o0000oen8hPCoF7[J00CoF7;Bo`000?l0003o00000omk
Ml@00ol0003oO7>nogac_P02ogac_P03o`000?n0L[[oP7:j00CoP7:j00?o0000ohEc^?n5LkP00on5
LkP00ol0003oRgNgoh]g]`03o`0000;oRgNg00?o0000oi9k]_nBNkH01_nBNkH00ol0003oVH6goiV1
]`04oiV1]`;o00000onZVLD2o`0000co]J?600?o0000om79dOoAbM402?oAbM401?l0003oin_@onO[
d?oWjm02o`000007on;[f?l0003oi_c2o`000?oLo/Oo0000om;gY006o`000003ojg^Xol0003og_gC
00?og_gC00Co0000on;Cb?l0003o00000_oNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCo
bjNd00KobjNd00?o0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD[009okjD[003o`000?niTJgo
^I6]00;o^I6]0_l00008ok6=/0;o00000on[S;D4oin9_004o`000?nORKcoWhVloin9_0;o00001On<
QLH01?l0003oK7oDofaoe?m/Om@2o`0000;oF7;B00?o0000oa1Id_l@FM800ol0000Looooo`?o0000
5?ooool002?ooooo00?o0000ooooooooool0??ooool4o`0000?o:Y;_0_lNO>H00omOR>;oF7[JoeQj
fP02oeQjfP?oF7;B0ol000000omkMlCo0000ogac_P03ogac_P03o`000?n0L[[oP7:j00?oP7:j00?o
0000ohEc^?n5LkP00on5LkP3o`0000KoRgNg00?o0000oi9k]_nBNkH01_nBNkH00ol0003oVH6goiV1
]`02oiV1]`03o`000?nZVLGoZYW500GoZYW50_l00009okFSaP03o`000?oAbM7odLWA00SodLWA00?o
0000onO[d?oWjm000_l00002on;[f006o`000?oVo<;o0000omcnaol0003od_NT2?l00005omkmd`;o
00000ooNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCobjNd00OobjNd00?o0000olBL[oo4
W:l01oo4W:l00ol0003o_YB/okjD[008okjD[003o`000?niTJgo^I6]00Go^I6]0_l00005ok6=/003
o`000?n[S;GoZhbe00CoZhbe0_l000000onORKco0000oin9_004oin9_003o`000?n<QLKoS8G600?o
S8G600?o0000ofaoe?m/Om@00_m/Om@4o`0000;o45WB0_l0000Iooooo`?o00000_ooool00ol0003o
ooooooooo`0Booooo`008oooool00ol0003oooooooooo`10ooooo`?oEJci00Go:Y;_oaili_lNO>Ko
7WcVoen8hP03oeQjfP?oF7;B00?o0000oei`cOl000000_l00004ogac_P03o`000?n0L[[oP7:j00?o
P7:j00?o0000ohEc^?l000000_l00002ohEc^003o`000?n;MkOoRgNg00CoRgNg00?o0000oi9k]_nB
NkH01onBNkH01?l0003oVH6go`000?l0000:ojZIa@03o`000?neXlKo]J?600Go]J?600?o0000om79
dOoAbM402OoAbM400ol0003oin_@o`000003on;[f006o`000?oVo<;o0000omcnaol0003od_NT2?l0
0005omkmd`;o00001?oNg]D00ol0003oeKVnomFi_P05omFi_P03o`000?o;YkCobjNd00KobjNd00?o
0000olBL[oo4W:l01oo4W:l00ol0003o_YB/okjD[008okjD[003o`000?niTJgo^I6]00So^I6]0_l0
00000onaSK3o0000o`000009oj^<]@03o`000?nORKco000000GoWhVl0_l00005ohb5aP04o`000?m/
OmCoK7oDofaoe0;o<W7N0_l00002oa1IdP;o00005Oooool3o`0000Gooooo00?o0000ooooooooool0
4_ooool002?ooooo00?o0000ooooooooool0A?ooool2oeF/n@;o7WcV00Go2fOKoen8h_mHN][oF7[J
o`000002oeQbdP04o`000?mNL<goGW3=oei`c@?o00000_mlLkh01?l0003oP7:joh1b^_n0L[X3o`00
00GoQG>h00?o0000oh]g]on;MkL01On;MkL00ol0003oTW^foi9k]P05oi9k]P?o00003OnZVLD2o`00
00Co]J?600?o0000om79dOoAbM402OoAbM43o`0000?oh^_H0ol00002omcna`Wo00001?oNoM<2o`00
00Gog]kE00?o0000omFi__oE^Kh01OoE^Kh01?l0003objNdol^W]?o;Yk@;o`0000Coa9b_00?o0000
okjD[?nnU:`02OnnU:`00ol0003o^I6]okVA[@0:okVA[@;o00002on[S;D00ol0003oWhVlo`000006
oin9_003o`000?n<QLKoS8G600?oS8G600Go0000ofaoe?m/OmCoK7oDo`000002oc9agP;o000000?o
45WBo`000?l000004Oooool3o`0000Sooooo00?o0000ooooooooool04_ooool002?ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`02oailiP04o`]Wfol0003o0000o`0000;oF7;B00Ko
0000oei`cOmNL<goGW3=o`000?mXL/T6o`0000?oP7:j00?o0000ohEc^?n5LkP00on5LkP00ol0003o
RgNgoh]g]`05oh]g]`03o`000?nBNkKoTW^f00Co00001?nNT<D00ol0003oZYW5ojZIa@0;ojZIa@;o
000000?o]J?6o`000?oAbM402_oAbM42o`0000Coh^_H0_l00003omcna`Wo00000_oNoM<4o`0000Go
g]kE00?o0000omFi__oE^Kh00ooE^Kh7o`0000GobjZh00?o0000olFK[Oo5Vjd00oo5Vjd7o`0000So
_YB/00?o0000okVA[OniTJd02_niTJd00ol0003o]8naokB?/@02o`0000[oZhbe0ol00006oin9_003
o`000?n<QLKoS8G600?oS8G600Go0000ofaoe?m/OmCoK7oDo`000003oc9agP04o`000?l@FM;o0000
o`0000cooooo1?l0000;ooooo`03o`000?oooooooooo01;ooooo000Rooooo`03o`000?oooooooooo
04Oooooo00Go0000oooooooooooooooooailiP02o`]Wf`;o00000_mHL]801?l0003oGW3=oei`cOmN
L<d:o`000003oh1b^_l0003oQG>h00CoQG>h00?o0000oh]g]on;MkL00_n;MkL5o`0000WoWY3500?o
0000ojZIaOnZVLD03?nZVLD=o`0000Koh^_H00Co0000omcnaooLo/Oog?k70_l000000ongkY[o0000
o`000004o`000003omkmdol0003o000000;oYoSA00?o0000omkNeOoNg]D01?oNg]D00ol0003oeKVn
omFi_P03o`0000;od[o700?o0000ol^Z^?o;Z[P01_o;Z[P00ol0003oaI^]olFK[@07olFK[@04o`00
0?o2Ujco`YN/ol:G[0Go00000_nnU:`00ol0003o^I6]okVA[@0:okVA[@03o`000?ndSk7o]8na00?o
]8na00?o0000oj^<]On[S;D02On[S;D00ol0003oWhVloin9_002oin9_0So000000?oS8G6o`000?m/
Om@00_m/Om@01?l0003o<W7Noc9ag_lbLMh3o`0000Wooooo0ol0000@ooooo`03o`000?oooooooooo
017ooooo000Rooooo`;o0000BOooool00ol0003oooooooooo`02ooooo`04o`000?l;Im_o0000o`00
00;oF7;B1Ol00003ofQbb@03o`000?meMlOoMGO700;oMGO73?l00005oi67a@03o`000?nNT<GoWY35
00OoWY350_l0000:ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[f?oRjmP01OoRjmP01?l0
003og?k7omcnaooLo/L2o`000003okO^V_l0003o000000;o000000Soooooo`000?l0003o0000ojOh
dOooooooYoSAo`0000Kog]kE1?l00004om:oa`03o`000?o;Z[SobjZh00KobjZh00?o0000olFK[Oo5
Vjd01oo5Vjd00ol0003o`YN/ol:G[007ol:G[0Co00002_niTJd00ol0003o]8naokB?/@05okB?/@;o
00002On[S;D5o`0000GoUXc70omnRmH4o`0000;oK7oD00Co0000oc9ag_lbLMko<W7N0ol00005oooo
o`?o00004oooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo00;ooooo00?o7WcVo`]Wfol8G]H01?l00003oei`c@05o`000?mXL/WoJ7;9ofQb
bOl000001OmeMlL00ol0003oPgk6oh=naP04oh=naP03o`000?nAQlGoTHO500KoTHO500?o0000oij@
aOnNT<D02?nNT<D00ol0003oZYW5ojZIa@06ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[
f?oRjmP01OoRjmP00ol0003og?k7omcna`02omcna`03o`000?ngkY[o000000?o000000Goooooo`00
0?l0003oYoSAooooo`02ojOhd@03o`000?oNg]Gog]kE00;og]kE1?l00006om:oa`03o`000?o;Z[So
bjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008ol:G[003o`000?nnU:co
_YB/00?o00001_niTJd00ol0003o]8naokB?/@08okB?/@;o00001?n[S;D3o`0000;oYHjm00?o0000
oiJ<aonFS<L01_nFS<L00ol0003oOX_Fogj;eP03ogj;ePCo00000olbLMh3o`000004ooooool0003o
0000o`0001Kooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`02ooooo`Go000000?oF7;Bo`000?mNL<d00_mNL<d01Ol0003oJ7;9ofQbbOmX
L/Wo000000GoMGO700?o0000oh=na_n3O/H01?n3O/H00ol0003oTHO5oi67a@06oi67a@03o`000?nN
T<GoWY3500SoWY350_l00005ojZIa@03o`000?o7`MGoal7E00Woal7E00?o0000on;[f?oRjmP01?oR
jmP2o`0000Cog?k700?o0000okO^V_n7ehP01Ol000000onWn=7oooooojOhd@02ojOhd@03o`000?oN
g]Gog]kE00?o000000?oc>SZo`000?oB_lL01_oB_lL00ol0003objZhol^Z^007ol^Z^003o`000?o5
VjgoaI^]00OoaI^]00?o0000ol:G[?o2Uj`02?o2Uj`00ol0003o_YB/okjD[004okjD[0?o00000_ni
TJd00ol0003o]8naokB?/@0;okB?/@04o`000?n[S;Go0000o`0000KoYHjm0ol00006oiJ<a`03o`00
0?mnRmKoOX_F00?oOX_F00Co0000oe>8i_l0003o00001?lbLMh2o`0001Wooooo00?o0000oooooooo
ool04Oooool002;ooooo00?o0000ooooooooool0Boooool4o`0000?ooooo00?o2fOKo`QNe_l00000
0_l00003oei`c@05o`000?mXL/WoJ7;9ofQbbOl000001OmeMlL00ol0003oPgk6oh=naP04oh=naP03
o`000?nAQlGoTHO500KoTHO500?o0000oij@aOnNT<D02OnNT<D01Ol0003oZYW5ojZIaOnZVLGo0000
00_oal7E00?o0000on;[f?oRjmP00_oRjmP3o`000004omOZh_l0003og?k7omcna`;o000000?o]njJ
ohOGR?l000000ol00002ojOhd@04oooooonWn=7oYoSAojOhd@Co00000oo<j>X00ol0003od[o7om:o
a`05om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd02?o5Vjd00ol0003o`YN/ol:G
[007ol:G[003o`000?nnU:co_YB/00So_YB/0_l0000?okB?/@03o`000?nUS[goYHjm00KoYHjm00Co
0000ojF>_OnUS[go00001_nFS<L2o`0000CoOX_F00?o0000oe>8i_mCR>H00_l00003oc9agP03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0BOoo
ool4o`0000Kooooo00?o2fOKo`QNe_lDGmH00_l00003oei`c@05o`000?mXL/WoJ7;9ofQbbOl00000
1OmeMlL00ol0003oPgk6oh=naP04oh=naP03o`000?nAQlGoTHO500KoTHO50_l0000:oij@a@03o`00
0?nZVLGo000000_oal7E00?o0000on;[f?oRjmP00ol00003omOZhP07o`000?oLo/Oog?k7o`000?o6
o/ko0000ohOGR004o`000004ojOhdOooooooYoSAojOhd@Co00001Oo<j>X00ol0003od[o7om:oa`06
om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008
ol:G[003o`000?nnU:co_YB/00Wo_YB/00Co0000ok^AZol0003o00002_ndSk401Ol0003o/92eok2@
]On`T;Go000000OoYHjm00Co0000ojF>_OnUS[go00001onFS<L00ol0003oOX_Fogj;eP02ogj;eP;o
00000_mCR>H3o`000003oc9ag_l0003ooooo01Oooooo00?o0000ooooooooool04Oooool0027ooooo
00?o0000ooooooooool0Aoooool3o`0000Cooooo0_l00006ooooo`03o`000?lDGmKo55oF00;o0000
0_mNL<d01Ol0003oJ7;9ofQbbOmXL/Wo000000GoMGO700?o0000oh=na_n3O/H01?n3O/H00ol0003o
THO5oi67a@07oi67a@03o`000?nNT<GoWY3500OoWY352?l00005olO1e@Co00001OoGj^801ol0003o
g?k7o`000?l0003oa_k>o`000?n7ehP01?l00002ojOhd@Co00001oo<j>X00ol0003od[o7om:oa`06
om:oa`03o`000?o;Z[SobjZh00OobjZh00?o0000olFK[Oo5Vjd01oo5Vjd00ol0003o`YN/ol:G[008
ol:G[003o`000?nnU:co_YB/00Wo_YB/00?o0000ok^AZonkTJ/00_nkTJ/2o`0000Oo]8na00?o0000
ok2@]On`T;D01?n`T;D00ol0003oYHjmojF>_@04ojF>_@03o`000?nUS[goYHjm00;o00001_nFS<L0
0ol0003oOX_Fogj;eP03ogj;eP03o`000?mCR>KoDhSV00Go00005oooool00ol0003oooooooooo`0A
ooooo`008Oooool00ol0003oooooooooo`14ooooo`?o00002Oooool00ol0003oooooooooo`04oooo
o`;o00000_lDGmH4o`0000?oJ7;900?o0000ogEgaomeMlL00omeMlL00ol0003oPgk6oh=naP04oh=n
aP03o`000?nAQlGoTHO500OoTHO500?o0000oij@aOnNT<D01?nNT<D2o`0000So]kSI1_l00007omOZ
hP03o`000?oLo/Oo000000;oa_k>00?o0000ohOGR?l000002?l00008olcXjP03o`000?oB_lOod[o7
00Kod[o700?o0000ol^Z^?o;Z[P02?o;Z[P00ol0003oaI^]olFK[@07olFK[@03o`000?o2Ujco`YN/
00So`YN/00?o0000okjD[?nnU:`02?nnU:`00ol0003o^i6[ok^AZ`05ok^AZ`;o00001?ndSk400ol0
003o/92eok2@]@06ok2@]@;o00001OnUS[d01Ol0003oYHjmojF>_OnUS[go000000KoUXc700?o0000
ogj;e_mnRmH00omnRmH01?l0003oDhSVoe>8i_mCR>H2o`000003obmli_l0003ooooo01Kooooo00?o
0000ooooooooool04?ooool0027ooooo0_l00012ooooo`?o00003Oooool00ol0003oooooooooo`05
ooooo`03o`QNe_lDGmKo55oF00;o;F[J0_l00003ofQbb@03o`000?meMlOoMGO700;oMGO700?o0000
oh=na_n3O/H01On3O/H00ol0003oTHO5oi67a@07oi67a@03o`000?nNT<GoWY3500;oWY3500?o0000
okNhfOng^=T02ong^=T00ol0003oen[RomOZhP06omOZhP?o00000_o6o/h00ol0003oQmN8ohOGR008
o`0000Soc>SZ00Co0000om:oaooB_lOod[o72ol00005ol^Z^003o`000?o5VjgoaI^]00OoaI^]00?o
0000ol:G[?o2Uj`02?o2Uj`00ol0003o_YB/okjD[009okjD[003o`000?nkTJ_o^i6[00Oo^i6[0_l0
00000ondSk7o0000ok2@]@0:ok2@]@;o00000onUS[d00ol0003oYHjmojF>_@0>o`000003ogj;e_l0
003oDhSV00?oDhSV0_l0000Gooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooo
oooo03kooooo0ol0000Aooooo`03o`000?oooooooooo00Gooooo00?o25kFoaAOe_lDGmH00ol]J]X2
o`0000;oJ7;900?o0000ogEgaomeMlL00_meMlL00ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGo
THO500OoTHO500Co0000oij@aOl0003o00003Ong^=T00ol0003oen[RomOZhP06omOZhP;o00000oo6
o/h00ol0003oQmN8ohOGR00Eo`0000Go`M;W00?o0000olBY_oo4ZKl00oo4ZKl:o`0000GoaI^]00?o
0000ol:G[?o2Uj`01oo2Uj`00ol0003o_YB/okjD[009okjD[003o`000?nkTJ_o^i6[00[o^i6[00?o
0000ok2@]On`T;D03?n`T;D00ol0003oYHjmojF>_@03o`0000CoWiC91on>UmP3og2JjPGo00000_mC
R>H2o`0001Kooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool3
o`0001Gooooo00?o0000ooooooooool01_ooool00ol0003o55oFo`000003obeZfPCo00001?meMlL0
0ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGoTHO500GoTHO50ol0000>okNhf@03o`000?oGj^;o
en[R00Koen[R0_l00004olKncP03o`000?n7ehSo000000Co000000?o3`00ojWMn_nYgOX01onYgOX0
0ol0003o`M;Wol7Bi`08ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV^oo4Y[/00oo4Y[/:
o`0000Go`YN/00?o0000okjD[?nnU:`02?nnU:`00ol0003o^i6[ok^AZ`0:ok^AZ`03o`000?nhTk3o
^9>`00;o00003?n`T;D2o`0000;oWiC900?o0000oinDbOnOU<T01?nOU<T00ol0003oSYOHohjGf004
ohjGf003o`000?m`V^[oL9[Z00;oL9[Z1_l0000Eooooo`03o`000?oooooooooo013ooooo000Qoooo
o`03o`000?oooooooooo03Sooooo0ol0000Iooooo`03o`000?oooooooooo00Kooooo00?o0000oaAO
e_l000000ol]J]X2odajgP;o00001?meMlL00ol0003oPgk6oh=naP05oh=naP03o`000?nAQlGoTHO5
00Co00001?nT[=d3o`0000Wo]kSI00?o0000omOZh_oGj^801_oGj^800ol0003oa_k>olKncP03olKn
cP?o00000_l?0002o`0000WoZMgj0_l0000:ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV
^oo4Y[/02?o4Y[/00ol0003o`j:hol>R^003ol>R^0So00002?nnU:`00ol0003o^i6[ok^AZ`09ok^A
Z`03o`000?nhTk3o^9>`00?o^9>`0ol00005ok2@]@?o00000on/U;h01?l0003oWiC9oinDbOl00006
oinDb@;o00001On>UmP2o`0000CoL9[Z00?o0000oeJEkomFUNl00_l0000Dooooo`03o`000?oooooo
oooo013ooooo000Pooooo`03o`000?oooooooooo03Kooooo0ol0000Mooooo`03o`000?oooooooooo
00Kooooo0ol00003obeZfP03o`000?m<N]koC7[N00Co000000?oMGO7o`000?n3O/H00on3O/H5o`00
00_oY:cM0ol00005okNhf@03o`000?oGj^;oen[R00?oen[R1?l00005olKncP?o000000?oooooo`00
0?l000000_nYgOX3o`0000GoZMgj00?o0000ol7Bioo1d^L02Oo1d^L00ol0003oa:VoolBY_`08olBY
_`03o`000?o4Y[_oa:Jk00Soa:Jk00?o0000ol>R^?o3X[P02?o3X[P01?l0003o_iN^oknG[_noUjh5
o`0000;o_YB/00?o0000ok^AZonkTJ/02OnkTJ/00ol0003o^9>`okRC/007okRC/0;o000000?o/92e
o`000?l000002?n/U;h2o`0000SoWiC90_l00005ohjGf0;o00000om`V^X2o`000003oeJEkol0003o
oooo01?ooooo00?o0000ooooooooool04?ooool0023ooooo0ol0000cooooo`?o00008Oooool00ol0
003oooooooooo`07ooooo`;o00000ol]J]X01?l0003oC7[Nodajg_m<N]h2ofb<h@Ko00001On;WN02
o`0000coY:cM0ol000000ong^=Wo0000omOZhP05o`0000;o`^K`1Oo6o/h4o`0000Wooooo1Ol00000
0oo1d^Oo0000o`000008ol7Bi`03o`000?o4ZKooa:Vo00Soa:Vo00?o0000olBV^oo4Y[/02?o4Y[/0
0ol0003o`j:hol>R^008ol>R^003o`000?noUjko_iN^00Oo_iN^1?l00009ok^AZ`03o`000?nhTk3o
^9>`00[o^9>`00?o0000ojbD__n/U;h02_n/U;h2o`0000SoWiC900?o0000ohjGf?n>UmP01?n>UmP0
0ol0003oL9[Zog2JjP02og2JjP?o00004oooool00ol0003oooooooooo`0@ooooo`008?ooool00ol0
003oooooooooo`0`ooooo`?o00009Oooool00ol0003oooooooooo`07ooooo`;o00000ol]J]X01Ol0
003oC7[Nodajg_m<N]ko000000CoK8cQ00?o0000oh^Mh?n;WN001_n;WN02o`0000goY:cM0ol00005
ol;Vl004o`000?o6o/koa_k>olKncPKo00004_ooool5o`0000;o`M;W00?o0000olBY_oo4ZKl02?o4
ZKl00ol0003oa:JkolBV^`08olBV^`03o`000?o3X[So`j:h00So`j:h00?o0000oknG[_noUjh02Ono
Ujh00ol0003o_YZcokjJ/`03o`0000Go^i6[00?o0000okRC/?nhTk002_nhTk000ol0003o]INhokFG
^002o`0000[o[9Bn0ol00004oinDb@oo000000?oL9[Zo`000?ooool04_ooool00ol0003ooooooooo
o`0@ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0]ooooo`?o0000:Oooool00ol0003ooooooooo
o`08ooooo`05o`000?l]J][o;F[JobeZf_l000000om<N]h00ol0003oK8cQofb<h@02ofb<h@;o0000
2?n;WN02o`0000SoY:cM0_l00008ol;Vl003o`000?o6o/koa_k>00;o000000?oUO7>o`000?l00000
0_l0000Hooooo`Oo00001Oo4ZKl00ol0003oa:JkolBV^`08olBV^`03o`000?o3X[So`j:h00Wo`j:h
00?o0000oknG[_noUjh02?noUjh00ol0003o_YZcokjJ/`04okjJ/`?o000000?o^i6[o`000?nhTk00
2onhTk000ol0003o]INhokFG^003okFG^0;o00002On/U;h00ol0003o[9Bno`000003o`0000GoVZ7I
00?o0000ohJWj_n6YnX01?n6YnX2o`000004ogFWlOl0003o0000o`0001?ooooo00?o0000oooooooo
ool03oooool000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02[ooooo0ol0000]ooooo`03o`000?oooooooooo00So
oooo0_l00002obeZfP04o`000?m<N]koC7[NodajgP;o00001?m/S>400ol0003oRigPoh^Mh007oh^M
h0;o00001OnT[=d00ol0003o`^K`ol;Vl007ol;Vl004o`000?o6o/ko0000o`0000;oUO7>1?l0000P
ooooo`[o00001Oo4Y[/00ol0003o`j:hol>R^009ol>R^003o`000?noUjko_iN^00So_iN^00?o0000
okjJ/onnV[<02?nnV[<00ol0003o^9>`okRC/00:okRC/003o`000?neUkSo]INh00Ko]INh0_l00005
ojbD_P?o00000onWWL/00ol0003oVZ7IoiZQf@06oiZQf@;o00001On6YnX2o`000003ogFWlOl0003o
oooo01;ooooo00?o0000ooooooooool03oooool000Gooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool3o`00037ooooo00?o0000
ooooooooool02?ooool5o`0000CoC7[N00?o0000ofb<hOm/S>400_m/S>42o`0000WoRigP0_l00000
0onT[=go0000o`000009ol;Vl0?o00000onElLh3o`0002cooooo1ol00009ol>R^003o`000?noUjko
_iN^00So_iN^00?o0000okjJ/onnV[<02?nnV[<01?l0003o_9bhokbL^?nlW;P3o`0000Ko^9>`00?o
0000okFG^?neUkP02OneUkP2o`000003ojbD__l0003o000000?oYig;00?o0000ojNMbonWWL/00_nW
WL/2o`0000OoVZ7I0_l00005ohJWjP?o00004_ooool00ol0003oooooooooo`0?ooooo`001Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Vooooo`;o0000=Oooool00ol0003oooooooooo`09ooooo`Co00001?m<N]h00ol0003oK8cQofb<
h@03ofb<h@03o`000?n;WN3oRigP00OoRigP3Ol00005oiGacP?o0000=?ooool3o`0000Ko`j:h00?o
0000oknG[_noUjh01onoUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nlW;So_9bh00Go_9bh0ol0
0002okRC/003o`000?neUkSo]INh00co]INh00?o0000ojNMbonWWL/01?nWWL/00ol0003oYig;ojNM
b`03ojNMb`;o00001onJXMT2o`0000GoQZOZ0_l0000Aooooo`03o`000?oooooooooo00oooooo0005
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02?ooooo0ol0000hooooo`03o`000?oooooooooo00Wooooo1_l00002odajgP03o`000?m/
S>7oK8cQ00?oK8cQ0_l00004oh^Mh0?o00002_nMfO`00ol0003oUO7>oiGacP04oiGacP?o0000>?oo
ool3o`0000;o`j:h00?o0000oknG[_noUjh01onoUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nl
W;So_9bh00Wo_9bh0_l0000=okFG^004o`000?ncVkoo/i^ook>K_`?o00000onWWL/00ol0003oYig;
ojNMb`04ojNMb`;o00001?nJXMT2o`000003oiZQfOl0003o000000Co000000?oQZOZo`000?ooool0
3oooool00ol0003oooooooooo`0?ooooo`001Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool01?ooool2o`00027ooooo0ol0000looooo`03o`000?oooooooooo00[ooooo
0_l000000ol0El7o0000o`000003o`0000KoK8cQ00Co0000oh^Mh?l0003o00002onMfO`2o`0000Co
UO7>1Ol0000looooo`Oo00001?noUjh00ol0003o_YZcokjJ/`08okjJ/`03o`000?nlW;So_9bh00[o
_9bh00Co0000okZI]onjVKOo^YVg0ol00006okFG^0;o00001oncVkl2o`000003ojNMbol0003oYig;
00OoYig;1?l00006oiJajP?o00000_n;/o000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00oooooo0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01gooooo0ol00010ooooo`03o`000?oooooooooo00_ooooo3_l00002oigI
o003o`000?nMfOcoWMWl00OoWMWl00?o0000oiGac_nElLh01ol00015ooooo`Co000000?o_YZco`00
0?l000000_l00005okjJ/`03o`000?nlW;So_9bh00[o_9bh00?o0000okZI]onjVKL01OnjVKL3o`00
00;o]INh00?o0000ok>K_oncVkl02OncVkl3o`0000;oYig;0ol00004ojBYf`?o00002?nF/NX4o`00
00kooooo00?o0000ooooooooool03oooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool06_ooool3o`0004Cooooo00?o0000oooo
ooooool02oooool2o`000003o`1G`Ol0003o000000;o58_W0ol00006of:mo@Go00000onMfO`4o`00
00;o@l>j1?l00016ooooo`Co00001Oooool5o`0000co_9bh00?o0000okZI]onjVKL02OnjVKL2o`00
00oo/i^o0_l0000:ojBYf`;o00002OnF/NX2o`0000kooooo00?o0000ooooooooool03_ooool001oo
oooo00?o0000ooooooooool05oooool3o`0004Sooooo00?o0000ooooooooool03?ooool5o`0000?o
58_W0ol00008of:mo@Co00001?m3`kX3o`0004Gooooo0ol0000@ooooo`?o00001_nlW;P00ol0003o
^YVgokZI]`09okZI]`03o`000?nhX/?o^:;300;o^:;30ol00006ok>K_`?o000000Co[jG=o`000?n_
YLgo[jG=0_l00009ojBYf`?o00000_nF/NX3o`0000;oVKW_00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`0Dooooo`?o0000C?ooool00ol0003o
ooooooooo`0>ooooo`Co00001?lDRnL3o`0000;oH[gm0ol00007od?3^P;o0000A?ooool3o`0001Ko
oooo0ol00002okbL^003o`000?njVKOo^YVg00So^YVg0_l00008okRR``?o000000?o/i^oo`000?l0
00001On_YLd00ol0003o[jG=ojnUc@02ojnUc@?o00002?nTZM/3o`0000GoVKW_00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Booooo`?o0000
D?ooool00ol0003oooooooooo`0@oooooaCo0000@oooool3o`0001cooooo0_l0000:okZI]`03o`00
0?nhX/?o^:;300_o^:;300?o0000ojnUcOn_YLd01_n_YLd00ol0003o[jG=ojnUc@04ojnUc@Go0000
1_nR]nL6o`0000gooooo00?o0000ooooooooool03_ooool001kooooo0_l0000@ooooo`?o0000E?oo
ool00ol0003oooooooooo`0Aooooo`Wo00000olP0003o`0004;ooooo1?l0000Sooooo`Go00000_nj
VKL00ol0003o^:;3okRR``09okRR``;o00001OndZ/l5o`000003ojnUcOl0003o[jG=00?o00001OnZ
/]h3o`0000WoX[OW0_l0000<ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo00cooooo0ol0001Hooooo`03o`000?oooooooooo01?ooooo2Ol00012ooooo`?o0000;?ooool2
o`0000?o^:;30_l00005okRR``;o00003?ndZ/l3o`0000_oZ[;N0ol00002oj:gi`?o00000_nP_Nd0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo
00Wooooo0ol0001Looooo`;o0000Foooool3o`0003Kooooo1Ol0000;okBZc`?o00000_na[]D00ol0
003o/JkEo`000002o`0000[oZ[;N1?l00004oj2mk@03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool001kooooo00?o0000ooooooooool01_ooool3o`00067ooooo00?o0000oooooooo
ool0EOooool3o`00043ooooo1Ol00002okBZc`;o00001_na[]D01?l0003o/JkEok6^eOna[]D3o`00
00;oZ[;N0ol00006ojVii0Ko00002_ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003o
ooooooooo`03ooooo`?o0000IOooool00ol0003oooooooooo`1@ooooo`Co0000B?ooool2o`0000Wo
/JkE00?o0000ok6^eOna[]D00ona[]D2o`0000koZKWT0_l0000:ooooo`03o`000?oooooooooo00go
oooo000Mooooo`04o`000?ooooooooooooooo`?o0000JOooool00ol0003oooooooooo`1<ooooo`?o
0000DOooool5o`000003ok6^eOl0003o/JkE00?o00001On/^^@5o`0000?oZKWT0ol00002ojJok003
o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001gooooo1?l0001]ooooo`03o`00
0?oooooooooo04Sooooo0ol0001Iooooo`?o00003On/^^@7o`0000;oY[o/00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`007Oooool2o`00073ooooo00?o0000ooooooooool0A?oo
ool3o`0005oooooo1_l00003ojbji0?o00002?nY_NP4o`0000Sooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0oooooo`Co0000Hoooool0
0ol0003oooooooooo`02ooooo`?o00002OnY_NP3o`0000;oZ<3[00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
03_ooooo0ol0001Wooooo`03o`000?oooooooooo00Wooooo1ol00004ojS0j`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`0gooooo`?o0000Joooool00ol0003oooooooooo`0?ooooo`Ko00001_ooool00ol0003o
ooooooooo`0=ooooo`008_ooool2o`0006oooooo00?o0000ooooooooool0<oooool3o`0006oooooo
00?o0000ooooooooool04oooool2o`0000Kooooo00?o0000ooooooooool03?ooool002Cooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`0^ooooo`Co0000Loooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000Uooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool0:_ooool3o`0007Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`009_ooool2o`0006kooooo00?o0000ooooooooool09_ooool3o`0007_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0<ooooo`00:?ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo02;ooooo0ol0001oooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool03?ooool002Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Mooooo`Co0000
Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo000Zooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool06Oooool3o`0008Oooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0<ooooo`00:oooool2o`0006gooooo00?o0000ooooooooool05Oooool3
o`0008_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`00;Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo0ol0002?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02oooool002kooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`0<ooooo`Co0000Toooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo000_ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02?ooool3o`0009Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`00<?ooool2o`0006cooooo00?o
0000ooooooooool01?ooool3o`0009_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0;ooooo`00<_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00?o0000Woooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000cooooo`03o`000?oooooooooo
06[ooooo0_l0002Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool003Co
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool02oooool003Gooooo0_l0001Yooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00=oooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0:ooooo`00>?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00>Oooool2o`0006Gooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000kooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo000looooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo000mooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo000nooooo`;o0000H?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool0043ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0047o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool004;ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool004?ooooo0_l0
001Kooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`09ooooo`00AOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0:cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`00A_ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`00Aoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0:kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`00B?ooool2o`0005Gooooo00?o0000ooooooooool0
[oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo001:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo001;ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0/Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo001<ooooo`;o0000DOooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool004ko
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool004oooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0053ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool0057ooooo0_l0001<ooooo`03o`000?oooooooooo0;Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`00Doooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`00E?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0;Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo0;Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`00E_oo
ool2o`0004Oooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo001Hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0^?ooool0
1Ol0003ooooooooooooooooo000000Wooooo001Iooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0^Oooool01?l0003oooooooooool00009ooooo`00F_ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooool000002Oooool005_ooooo0_l00012oooo
o`03o`000?oooooooooo0;[ooooo00Co0000oooooooooooo00002?ooool005gooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`2kooooo`03o`000?oooooo000000Sooooo001Nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool2o`0000Sooooo001Oooooo`;o0000
?_ooool00ol0003oooooooooo`2kooooo`?o00002?ooool0067ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2gooooo`Co00002oooool006;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`2cooooo`Co00003oooool006?ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`2_ooooo`Co00004oooool006Cooooo0_l0000iooooo`03o`000?oooooooooo0:_o
oooo1?l0000Gooooo`00I_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Oooooo
1?l0000Kooooo`00Ioooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:?ooooo1?l0
000Oooooo`00J?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo09oooooo1?l0000S
ooooo`00JOooool2o`0003?ooooo00?o0000ooooooooool0W?ooool4o`0002Oooooo001[ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool4o`0002_ooooo001/ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002oooooo001]ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0T?ooool4o`0003?ooooo001^ooooo`;o0000;_ooool0
0ol0003oooooooooo`2=ooooo`?o0000=oooool0073ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`29ooooo`Co0000>_ooool0077ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`25ooooo`Co0000?_ooool007;ooooo0_l0000Zooooo`03o`000?oooooooooo087ooooo
1?l00012ooooo`00M?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07gooooo1?l0
0016ooooo`00MOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo1?l0001:
ooooo`00M_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Gooooo1?l0001>oooo
o`00Moooool2o`0002Gooooo00?o0000ooooooooool0LOooool4o`0005;ooooo001iooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0KOooool4o`0005Kooooo001jooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0JOooool4o`0005[ooooo001kooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0IOooool4o`0005kooooo001looooo`;o00008?ooool00ol0
003oooooooooo`1Qooooo`Co0000H_ooool007kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1Mooooo`Co0000I_ooool007oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Iooooo`Co0000J_ooool0083ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Eooooo`Co0000K_ooool0087ooooo0_l0000Kooooo`03o`000?oooooooooo057ooooo1?l0001b
ooooo`00Poooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04gooooo1?l0001foooo
o`00Q?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001jooooo`00
QOooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`0007kooooo0027ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0008;ooooo0028ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0?Oooool4o`0008Kooooo0029ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0>Oooool4o`0008[ooooo002:ooooo`;o00004_ooool00ol0003o
ooooooooo`0eooooo`Co0000S_ooool008cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0aooooo`Co0000T_ooool008gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0^ooooo`Co0000U_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[
ooooo`?o0000V_ooool008oooooo0_l0000<ooooo`03o`000?oooooooooo02Oooooo1?l0002Moooo
o`00TOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo1?l0002Qooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo1?l0002Uooooo`00Tooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo1?l0002Yooooo`00U?ooool2
o`0000Oooooo00?o0000ooooooooool05oooool4o`000:gooooo002Fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04oooool4o`000;7ooooo002Gooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool4o`000;Gooooo002Hooooo`;o00000oooool00ol0003ooooo
ooooo`0;ooooo`Co0000^Oooool009[ooooo00Co0000oooooooooooo00002Oooool4o`000;gooooo
002Kooooo`03o`000?oooooo000000Gooooo1?l00031ooooo`00W?ooool2o`000003ooooool0003o
000000;o0000aOooool009gooooo0_l00039ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00J?ooool01OlQ8B7o0000o`000?m4A4CogMgM
07Wooooo00Go8B4Qo`000?l0003oA4A4omgMg@1mooooo`00Joooool00omgMgOo<S8booooo`1koooo
o`03ogMgMolb<S;ooooo07cooooo001/ooooo`03o`000?oooooooooo07_ooooo00?o0000oooooooo
ool0Noooool0043ooooo00OoV9RHo`000?l0003oA4A4okZj^_oooooo410@00Go00001?ooool5o`00
00;ooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o0000
00So410@ooooooo^k^koEEEEo`000?l@413oc<c<o`0000?ooooo00OoV9RHo`000?l0003oMgMgo`00
0?l@413ooooo00Go00000oooool02?nHV9So0000o`000?mgMgOo410@o`000?oooooo410@1Ol00006
ooooo`06onk^k_mEEEGo0000o`000?nHV9So00000_l@4105o`0000Cooooo00KoV9RHo`000?l0003o
MgMgo`000?l@4102o`0000;ooooo00Co0000oooooooooooo00000_l@4102o`000007ooooool0003o
0000oa0@4?ooooook^k^oeEEE@02o`000005odA4A?nj^[[ooooooooooonHV9P00_l000000omgMgOo
410@o`000002ooooo`07onk^k_mEEEGo0000o`000?nHV9So0000oa0@4004ooooo`06onk^k_mEEEGo
0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002oooo
o`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?l0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^
k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co
^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVYZOooool01?ooool01onHV9So0000o`000?mE
EEGok^k^ofIVI_l000002?ooool5o`0002cooooo0010ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go0000olc<c?o^k^ko
QhN7o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^ko
EEEEo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000004ooooo`03o`000?oooooooooo00?ooooo
00Go0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Oooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ojVYZOooooooQhN7o`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool02Ol0003o
oooooooooomEEEGoMgMgooooooo^k^koMgMgoa0@4002ooooo`05o`000?o<c<cok^k^ohN7Qol00000
0oooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Gooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4105ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooo
oomEEEGoMgMgooooooo^k^koEEEEo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102oooo
o`06o`000?nYZJWooooooooooonj^[[o00001Oooool01ol0003oZJVYoooooon7QhOo<S8bofIVI_oo
ool01_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0;?ooool0043ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go410@ohN7Qooo
ooook^k^o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooo
ooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Oooooo00Ko0000oooo
ooooooooooooonk^k_l00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00007ooooo`05oa0@4?n7QhOoooooonk^k_l000000oooool01_l0003ooooooooo
ooooooook^k^o`0000Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`06
o`000?ooooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00000oooool01Oo^k^ko0000oooooooooooo000000Sooooo00Go^[ZjohN7
QomVIVKoIVIVoa0@4005ooooo`06o`000?oooooooooooooooon7QhOoA4A42_ooool00onHV9So8B4Q
onk^kP0]ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000
ooooooooool01oooool01_l0003oooooooooooooooook^k^o`0000?ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Ko00000_ooool00onj^[[o410@o`000002
o`0000?ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`Ko00001Oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6o`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?oo
ool01?l0003oooooooooool00003ooooo`04onk^k_l0003oooooooooo`Ko00000_ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kPGooooo00Oo8B4Qolc<c?oooooooooooiRHV?lb<S;ooooo00Ko0000
1?ooool00onHV9So8B4Qonk^kP0/ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?lb
<S;ogMgM00Oooooo00?o0000ooooooooool01Oooool00oo<c<co0000ooooo`03ooooo`05o`000?n7
QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00oooool0
0ol0003o<S8bomgMg@07ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000oooool00ol0003o<S8b
omgMg@05ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003oc<c<olc<c?l0003oZJVY
omgMgOlQ8B400_ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^kooooo
ohN7Qolb<S85ooooo`03olc<c?l0003ooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00005
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go
0000ohN7QoooooooZJVYo`000002ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooooooo
EEEEogMgM`;ooooo00[oMgMgoeEEEOooooooooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko0000okZj^_ooooook^k^ogMgMol00005oooo
o`07ojVYZOlQ8B7ogMgMonk^k_lb<S;oEEEEokZj^P0;ooooo`03ogMgMomVIVKooooo02_ooooo000n
ooooo`03oa0@4?l0003o000000?o00000oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@?ooooo00?o
410@o`000?l000001Oooool01?lb<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o0000
00goV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooool@413o000000;ooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo00Co<S8bo`000?l0003oV9RH0oooool2o`000004
ojVYZOlQ8B7o0000ob4Q8@Gooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2o`000009ooooool@413o0000ob4Q
8Ol0003oMgMgoa0@4?l0003oZJVY00;ooooo00Go0000ogMgMol0003o0000oiRHV002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0oooool01?lb<S;o0000o`000?nHV9P3ooooo`06onk^k_mEEEGo
0000oa0@4?o<c<co00001Oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP?ooooo00?o410@o`00
0?l000001?ooool02_o^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413oooooonk^k_mEEED2o`000007
odA4A?o^k^koooooooooool@413o0000ogMgM`02o`00000=oiRHV?oooooo410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`00000:oeEEEOo^k^koooooooooooo^k^koEEEE
o`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00001_ooool01_nHV9So0000o`000?nHV9So^[Zjoc8b<Pcooooo00?o0000
ooooooooool0:_ooool0043ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo02;ooooo00Go0000okZj^_ooooooV9RHoa0@400/ooooo`00@?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00/
ooooo`00D_ooool00ol@413oooooooooo`0Rooooo`03oa0@4?l0003o000001cooooo0_l0000Joooo
o`03oa0@4?l0003ooooo01Wooooo0_l0000@ooooo`03oa0@4?oooooooooo02kooooo0_l0001Eoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0865833, 0.00525911, \
0.00369676, 0.00369676}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66533e-16 1.05023 -0.0446497 1.05023 [
[.5 .87208 -104 0 ]
[.5 .87208 104 12 ]
[.05011 .23931 -6 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -16.6517 -9 ]
[.33812 .12455 1.34831 0 ]
[.495 .06208 -21.0373 -9 ]
[.495 .06208 2.96266 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.2956 .07454 -9.25094 -12 ]
[.2956 .07454 .74906 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 6 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 18 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 24 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.91306 .21061 0 -8.07062 ]
[.91306 .21061 10 3.92938 ]
[.03081 .27768 -24 -2.73146 ]
[.03081 .27768 0 6.26854 ]
[.01654 .36715 -6 -2.80783 ]
[.01654 .36715 0 6.19217 ]
[.00139 .46205 -18 -2.88932 ]
[.00139 .46205 0 6.11068 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -165 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(triangular) show
129.000 13.000 moveto
(drumhead) show
183.000 13.000 moveto
(eigenmodes) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
255.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
261.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
267.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(0)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(0.25)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0.5)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.75)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
gsave
.91306 .21061 -61 -12.0706 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04303 .27288 m
.04914 .27048 L
s
[(-0.1)] .03081 .27768 1 -0.39301 Mshowa
.02882 .36253 m
.03497 .36022 L
s
[(0)] .01654 .36715 1 -0.37604 Mshowa
.01375 .45763 m
.01993 .45542 L
s
[(0.1)] .00139 .46205 1 -0.35793 Mshowa
.125 Mabswid
.04026 .2904 m
.04393 .28897 L
s
.03745 .30812 m
.04112 .3067 L
s
.03461 .32605 m
.03828 .32464 L
s
.03173 .34418 m
.03541 .34279 L
s
.02588 .3811 m
.02957 .37973 L
s
.0229 .39989 m
.0266 .39853 L
s
.01989 .41891 m
.02359 .41756 L
s
.01684 .43815 m
.02054 .43681 L
s
.04578 .25556 m
.04944 .25411 L
s
.01063 .47735 m
.01434 .47603 L
s
.00747 .49731 m
.01118 .496 L
s
.00427 .51751 m
.00799 .51622 L
s
.00102 .53797 m
.00475 .53669 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.92728 .52324 m .94807 .517 L .95575 .52814 L closepath p .662 .75 .916 r
F P
0 g
s
.94807 .517 m .92728 .52324 L .89858 .51785 L p .665 .736 .903 r
F P
0 g
s
.89858 .51785 m .91931 .5114 L .94807 .517 L p .665 .736 .903 r
F P
0 g
s
.91931 .5114 m .89858 .51785 L .86972 .51258 L p .677 .721 .882 r
F P
0 g
s
.91931 .5114 m .9403 .5057 L .94807 .517 L closepath p .649 .745 .919 r
F P
0 g
s
.86972 .51258 m .89034 .50535 L .91931 .5114 L p .677 .721 .882 r
F P
0 g
s
.89034 .50535 m .86972 .51258 L .8407 .50726 L p .699 .668 .816 r
F P
0 g
s
.9403 .5057 m .91931 .5114 L .89034 .50535 L p .666 .714 .884 r
F P
0 g
s
.8407 .50726 m .861 .4973 L .89034 .50535 L p .699 .668 .816 r
F P
0 g
s
.861 .4973 m .8407 .50726 L .81137 .5005 L p .708 .654 .793 r
F P
0 g
s
.89034 .50535 m .91118 .49877 L .9403 .5057 L p .666 .714 .884 r
F P
0 g
s
.91118 .49877 m .89034 .50535 L .861 .4973 L p .669 .686 .857 r
F P
0 g
s
.91118 .49877 m .93242 .49425 L .9403 .5057 L closepath p .624 .734 .926 r
F P
0 g
s
.861 .4973 m .88174 .49028 L .91118 .49877 L p .669 .686 .857 r
F P
0 g
s
.88174 .49028 m .861 .4973 L .83151 .48891 L p .688 .629 .785 r
F P
0 g
s
.81137 .5005 m .83151 .48891 L .861 .4973 L p .708 .654 .793 r
F P
0 g
s
.83151 .48891 m .81137 .5005 L .78206 .4957 L p .723 .625 .748 r
F P
0 g
s
.93242 .49425 m .91118 .49877 L .88174 .49028 L p .631 .703 .898 r
F P
0 g
s
.83151 .48891 m .85187 .47869 L .88174 .49028 L p .688 .629 .785 r
F P
0 g
s
.85187 .47869 m .83151 .48891 L .80185 .47989 L p .703 .594 .732 r
F P
0 g
s
.78206 .4957 m .80185 .47989 L .83151 .48891 L p .723 .625 .748 r
F P
0 g
s
.80185 .47989 m .78206 .4957 L .75252 .49039 L p .729 .593 .704 r
F P
0 g
s
.88174 .49028 m .90289 .48558 L .93242 .49425 L p .631 .703 .898 r
F P
0 g
s
.90289 .48558 m .88174 .49028 L .85187 .47869 L p .641 .648 .841 r
F P
0 g
s
.80185 .47989 m .82175 .46497 L .85187 .47869 L p .703 .594 .732 r
F P
0 g
s
.82175 .46497 m .80185 .47989 L .77193 .46905 L p .711 .584 .711 r
F P
0 g
s
.75252 .49039 m .77193 .46905 L .80185 .47989 L p .729 .593 .704 r
F P
0 g
s
.85187 .47869 m .87286 .47331 L .90289 .48558 L p .641 .648 .841 r
F P
0 g
s
.87286 .47331 m .85187 .47869 L .82175 .46497 L p .657 .6 .78 r
F P
0 g
s
.82175 .46497 m .8424 .45728 L .87286 .47331 L p .657 .6 .78 r
F P
0 g
s
.8424 .45728 m .82175 .46497 L .79157 .45093 L p .676 .573 .731 r
F P
0 g
s
.77193 .46905 m .79157 .45093 L .82175 .46497 L p .711 .584 .711 r
F P
0 g
s
.79157 .45093 m .81176 .43897 L .8424 .45728 L p .676 .573 .731 r
F P
0 g
s
.81176 .43897 m .79157 .45093 L .76138 .43709 L p .693 .563 .703 r
F P
0 g
s
.79157 .45093 m .77193 .46905 L .74213 .46104 L p .724 .572 .684 r
F P
0 g
s
.74213 .46104 m .76138 .43709 L .79157 .45093 L p .724 .572 .684 r
F P
0 g
s
.77193 .46905 m .75252 .49039 L .72263 .48229 L p .74 .611 .715 r
F P
0 g
s
.72263 .48229 m .74213 .46104 L .77193 .46905 L p .74 .611 .715 r
F P
0 g
s
.90289 .48558 m .92443 .48266 L .93242 .49425 L closepath p .587 .716 .933 r
F P
0 g
s
.76138 .43709 m .78115 .42041 L .81176 .43897 L p .693 .563 .703 r
F P
0 g
s
.78115 .42041 m .76138 .43709 L .73126 .42461 L p .71 .566 .69 r
F P
0 g
s
.76138 .43709 m .74213 .46104 L .71223 .45372 L p .735 .569 .668 r
F P
0 g
s
.71223 .45372 m .73126 .42461 L .76138 .43709 L p .735 .569 .668 r
F P
0 g
s
.8016 .41149 m .78115 .42041 L .75074 .40392 L p .675 .554 .71 r
F P
0 g
s
.75074 .40392 m .77074 .39031 L .8016 .41149 L p .675 .554 .71 r
F P
0 g
s
.73126 .42461 m .75074 .40392 L .78115 .42041 L p .71 .566 .69 r
F P
0 g
s
.77074 .39031 m .75074 .40392 L .72059 .39116 L p .701 .566 .699 r
F P
0 g
s
.75074 .40392 m .73126 .42461 L .70131 .41614 L p .729 .575 .682 r
F P
0 g
s
.70131 .41614 m .72059 .39116 L .75074 .40392 L p .729 .575 .682 r
F P
0 g
s
.83268 .43389 m .81176 .43897 L .78115 .42041 L p .65 .553 .733 r
F P
0 g
s
.78115 .42041 m .8016 .41149 L .83268 .43389 L p .65 .553 .733 r
F P
0 g
s
.79143 .38419 m .77074 .39031 L .74025 .37291 L p .66 .552 .722 r
F P
0 g
s
.74025 .37291 m .76046 .36205 L .79143 .38419 L p .66 .552 .722 r
F P
0 g
s
.72059 .39116 m .74025 .37291 L .77074 .39031 L p .701 .566 .699 r
F P
0 g
s
.76046 .36205 m .74025 .37291 L .71014 .36124 L p .696 .578 .72 r
F P
0 g
s
.74025 .37291 m .72059 .39116 L .69063 .38288 L p .728 .589 .7 r
F P
0 g
s
.69063 .38288 m .71014 .36124 L .74025 .37291 L p .728 .589 .7 r
F P
0 g
s
.72059 .39116 m .70131 .41614 L .67136 .41055 L p .747 .591 .682 r
F P
0 g
s
.67136 .41055 m .69063 .38288 L .72059 .39116 L p .747 .591 .682 r
F P
0 g
s
.73126 .42461 m .71223 .45372 L .68215 .44567 L p .748 .586 .675 r
F P
0 g
s
.68215 .44567 m .70131 .41614 L .73126 .42461 L p .748 .586 .675 r
F P
0 g
s
.82283 .40953 m .8016 .41149 L .77074 .39031 L p .625 .539 .738 r
F P
0 g
s
.77074 .39031 m .79143 .38419 L .82283 .40953 L p .625 .539 .738 r
F P
0 g
s
.86372 .45466 m .8424 .45728 L .81176 .43897 L p .625 .569 .772 r
F P
0 g
s
.81176 .43897 m .83268 .43389 L .86372 .45466 L p .625 .569 .772 r
F P
0 g
s
.92443 .48266 m .90289 .48558 L .87286 .47331 L p .578 .678 .908 r
F P
0 g
s
.74213 .46104 m .72263 .48229 L .69283 .47841 L p .747 .604 .699 r
F P
0 g
s
.69283 .47841 m .71223 .45372 L .74213 .46104 L p .747 .604 .699 r
F P
0 g
s
.71014 .36124 m .73001 .3459 L .76046 .36205 L p .696 .578 .72 r
F P
0 g
s
.73001 .3459 m .71014 .36124 L .68025 .35546 L p .732 .618 .731 r
F P
0 g
s
.71014 .36124 m .69063 .38288 L .66073 .37893 L p .754 .619 .71 r
F P
0 g
s
.66073 .37893 m .68025 .35546 L .71014 .36124 L p .754 .619 .71 r
F P
0 g
s
.89438 .4712 m .87286 .47331 L .8424 .45728 L p .598 .612 .836 r
F P
0 g
s
.8424 .45728 m .86372 .45466 L .89438 .4712 L p .598 .612 .836 r
F P
0 g
s
.87286 .47331 m .89438 .4712 L .92443 .48266 L p .578 .678 .908 r
F P
0 g
s
.78139 .35889 m .76046 .36205 L .73001 .3459 L p .645 .563 .748 r
F P
0 g
s
.73001 .3459 m .75045 .3379 L .78139 .35889 L p .645 .563 .748 r
F P
0 g
s
.75045 .3379 m .73001 .3459 L .69999 .33704 L p .693 .611 .761 r
F P
0 g
s
.68025 .35546 m .69999 .33704 L .73001 .3459 L p .732 .618 .731 r
F P
0 g
s
.70131 .41614 m .68215 .44567 L .65211 .44183 L p .759 .595 .675 r
F P
0 g
s
.65211 .44183 m .67136 .41055 L .70131 .41614 L p .759 .595 .675 r
F P
0 g
s
.69063 .38288 m .67136 .41055 L .64128 .40621 L p .764 .616 .696 r
F P
0 g
s
.64128 .40621 m .66073 .37893 L .69063 .38288 L p .764 .616 .696 r
F P
0 g
s
.81296 .38551 m .79143 .38419 L .76046 .36205 L p .597 .532 .753 r
F P
0 g
s
.76046 .36205 m .78139 .35889 L .81296 .38551 L p .597 .532 .753 r
F P
0 g
s
.85438 .43459 m .83268 .43389 L .8016 .41149 L p .588 .543 .771 r
F P
0 g
s
.8016 .41149 m .82283 .40953 L .85438 .43459 L p .588 .543 .771 r
F P
0 g
s
.71223 .45372 m .69283 .47841 L .66282 .4744 L p .749 .59 .679 r
F P
0 g
s
.66282 .4744 m .68215 .44567 L .71223 .45372 L p .749 .59 .679 r
F P
0 g
s
.69999 .33704 m .72011 .32488 L .75045 .3379 L p .693 .611 .761 r
F P
0 g
s
.72011 .32488 m .69999 .33704 L .67015 .33488 L p .741 .683 .795 r
F P
0 g
s
.69999 .33704 m .68025 .35546 L .65037 .35437 L p .766 .671 .757 r
F P
0 g
s
.65037 .35437 m .67015 .33488 L .69999 .33704 L p .766 .671 .757 r
F P
0 g
s
.68025 .35546 m .66073 .37893 L .63071 .37785 L p .776 .655 .729 r
F P
0 g
s
.63071 .37785 m .65037 .35437 L .68025 .35546 L p .776 .655 .729 r
F P
0 g
s
.84491 .41389 m .82283 .40953 L .79143 .38419 L p .546 .52 .777 r
F P
0 g
s
.79143 .38419 m .81296 .38551 L .84491 .41389 L p .546 .52 .777 r
F P
0 g
s
.88567 .4557 m .86372 .45466 L .83268 .43389 L p .546 .573 .833 r
F P
0 g
s
.83268 .43389 m .85438 .43459 L .88567 .4557 L p .546 .573 .833 r
F P
0 g
s
.8032 .36328 m .78139 .35889 L .75045 .3379 L p .564 .536 .782 r
F P
0 g
s
.75045 .3379 m .77162 .33744 L .8032 .36328 L p .564 .536 .782 r
F P
0 g
s
.77162 .33744 m .75045 .3379 L .72011 .32488 L p .625 .594 .798 r
F P
0 g
s
.67136 .41055 m .65211 .44183 L .62185 .43816 L p .764 .6 .675 r
F P
0 g
s
.62185 .43816 m .64128 .40621 L .67136 .41055 L p .764 .6 .675 r
F P
0 g
s
.89438 .4712 m .91634 .4709 L .92443 .48266 L closepath p .52 .683 .94 r
F P
0 g
s
.68215 .44567 m .66282 .4744 L .63245 .46613 L p .761 .628 .713 r
F P
0 g
s
.63245 .46613 m .65211 .44183 L .68215 .44567 L p .761 .628 .713 r
F P
0 g
s
.66073 .37893 m .64128 .40621 L .61105 .40429 L p .776 .639 .71 r
F P
0 g
s
.61105 .40429 m .63071 .37785 L .66073 .37893 L p .776 .639 .71 r
F P
0 g
s
.72011 .32488 m .7408 .31962 L .77162 .33744 L p .625 .594 .798 r
F P
0 g
s
.7408 .31962 m .72011 .32488 L .69018 .32033 L p .686 .685 .843 r
F P
0 g
s
.67015 .33488 m .69018 .32033 L .72011 .32488 L p .741 .683 .795 r
F P
0 g
s
.91634 .4709 m .89438 .4712 L .86372 .45466 L p .508 .635 .91 r
F P
0 g
s
.86372 .45466 m .88567 .4557 L .91634 .4709 L p .508 .635 .91 r
F P
0 g
s
.83541 .39349 m .81296 .38551 L .78139 .35889 L p .497 .501 .791 r
F P
0 g
s
.78139 .35889 m .8032 .36328 L .83541 .39349 L p .497 .501 .791 r
F P
0 g
s
.87679 .43946 m .85438 .43459 L .82283 .40953 L p .483 .531 .831 r
F P
0 g
s
.82283 .40953 m .84491 .41389 L .87679 .43946 L p .483 .531 .831 r
F P
0 g
s
.69018 .32033 m .67015 .33488 L .64024 .33741 L p .78 .785 .857 r
F P
0 g
s
.67015 .33488 m .65037 .35437 L .6203 .35596 L p .793 .734 .798 r
F P
0 g
s
.6203 .35596 m .64024 .33741 L .67015 .33488 L p .793 .734 .798 r
F P
0 g
s
.65037 .35437 m .63071 .37785 L .60043 .37765 L p .789 .692 .757 r
F P
0 g
s
.60043 .37765 m .6203 .35596 L .65037 .35437 L p .789 .692 .757 r
F P
0 g
s
.64128 .40621 m .62185 .43816 L .59134 .43293 L p .772 .624 .696 r
F P
0 g
s
.59134 .43293 m .61105 .40429 L .64128 .40621 L p .772 .624 .696 r
F P
0 g
s
.65211 .44183 m .63245 .46613 L .60206 .46213 L p .762 .632 .716 r
F P
0 g
s
.60206 .46213 m .62185 .43816 L .65211 .44183 L p .762 .632 .716 r
F P
0 g
s
.69018 .32033 m .7106 .31145 L .7408 .31962 L p .686 .685 .843 r
F P
0 g
s
.7106 .31145 m .69018 .32033 L .66035 .32276 L p .729 .83 .928 r
F P
0 g
s
.64024 .33741 m .66035 .32276 L .69018 .32033 L p .78 .785 .857 r
F P
0 g
s
.79367 .34429 m .77162 .33744 L .7408 .31962 L p .518 .555 .833 r
F P
0 g
s
.7408 .31962 m .7622 .32134 L .79367 .34429 L p .518 .555 .833 r
F P
0 g
s
.7622 .32134 m .7408 .31962 L .7106 .31145 L p .586 .662 .891 r
F P
0 g
s
.63071 .37785 m .61105 .40429 L .58057 .40276 L p .78 .653 .722 r
F P
0 g
s
.58057 .40276 m .60043 .37765 L .63071 .37785 L p .78 .653 .722 r
F P
0 g
s
.8678 .42284 m .84491 .41389 L .81296 .38551 L p .409 .489 .83 r
F P
0 g
s
.81296 .38551 m .83541 .39349 L .8678 .42284 L p .409 .489 .83 r
F P
0 g
s
.90814 .45899 m .88567 .4557 L .85438 .43459 L p .411 .576 .905 r
F P
0 g
s
.85438 .43459 m .87679 .43946 L .90814 .45899 L p .411 .576 .905 r
F P
0 g
s
.82597 .37438 m .8032 .36328 L .77162 .33744 L p .438 .489 .815 r
F P
0 g
s
.77162 .33744 m .79367 .34429 L .82597 .37438 L p .438 .489 .815 r
F P
0 g
s
.88567 .4557 m .90814 .45899 L .91634 .4709 L closepath p .417 .626 .94 r
F P
0 g
s
.7106 .31145 m .73155 .30861 L .7622 .32134 L p .586 .662 .891 r
F P
0 g
s
.73155 .30861 m .7106 .31145 L .68072 .31246 L p .604 .834 .987 r
F P
0 g
s
.66035 .32276 m .68072 .31246 L .7106 .31145 L p .729 .83 .928 r
F P
0 g
s
.61105 .40429 m .59134 .43293 L .56065 .4293 L p .774 .636 .709 r
F P
0 g
s
.56065 .4293 m .58057 .40276 L .61105 .40429 L p .774 .636 .709 r
F P
0 g
s
.62185 .43816 m .60206 .46213 L .57146 .45909 L p .757 .614 .699 r
F P
0 g
s
.57146 .45909 m .59134 .43293 L .62185 .43816 L p .757 .614 .699 r
F P
0 g
s
.66035 .32276 m .64024 .33741 L .61001 .3412 L p .77 .889 .93 r
F P
0 g
s
.64024 .33741 m .6203 .35596 L .58989 .35722 L p .794 .787 .846 r
F P
0 g
s
.58989 .35722 m .61001 .3412 L .64024 .33741 L p .794 .787 .846 r
F P
0 g
s
.6203 .35596 m .60043 .37765 L .56984 .37632 L p .785 .712 .783 r
F P
0 g
s
.56984 .37632 m .58989 .35722 L .6203 .35596 L p .785 .712 .783 r
F P
0 g
s
.85874 .40634 m .83541 .39349 L .8032 .36328 L p .327 .447 .83 r
F P
0 g
s
.8032 .36328 m .82597 .37438 L .85874 .40634 L p .327 .447 .83 r
F P
0 g
s
.89982 .44691 m .87679 .43946 L .84491 .41389 L p .295 .502 .888 r
F P
0 g
s
.84491 .41389 m .8678 .42284 L .89982 .44691 L p .295 .502 .888 r
F P
0 g
s
.60043 .37765 m .58057 .40276 L .5498 .39835 L p .773 .662 .741 r
F P
0 g
s
.5498 .39835 m .56984 .37632 L .60043 .37765 L p .773 .662 .741 r
F P
0 g
s
.68072 .31246 m .66035 .32276 L .63028 .32859 L p .616 .939 .954 r
F P
0 g
s
.61001 .3412 m .63028 .32859 L .66035 .32276 L p .77 .889 .93 r
F P
0 g
s
.59134 .43293 m .57146 .45909 L .5406 .45098 L p .76 .644 .733 r
F P
0 g
s
.5406 .45098 m .56065 .4293 L .59134 .43293 L p .76 .644 .733 r
F P
0 g
s
.81667 .3576 m .79367 .34429 L .7622 .32134 L p .361 .486 .851 r
F P
0 g
s
.7622 .32134 m .78443 .32972 L .81667 .3576 L p .361 .486 .851 r
F P
0 g
s
.70148 .30683 m .72271 .30591 L .73083 .30747 L p .405 .758 .994 r
F P
0 g
s
.73155 .30861 m .75316 .31175 L .78443 .32972 L p .433 .597 .913 r
F P
0 g
s
.74921 .31595 m .73155 .30861 L p .74466 .31385 L .433 .597 .913 r
F P
0 g
s
.68072 .31246 m .70148 .30683 L .73155 .30861 L p .604 .834 .987 r
F P
0 g
s
.75316 .31175 m .73155 .30861 L .70148 .30683 L p .405 .758 .994 r
F P
0 g
s
.73083 .30747 m .75316 .31175 L p .73671 .31018 L .405 .758 .994 r
F P
0 g
s
.70148 .30683 m .73083 .30747 L .73671 .31018 L .405 .758 .994 r
F
.78443 .32972 m .7622 .32134 L .74921 .31595 L p .433 .597 .913 r
F P
0 g
s
.75316 .31175 m .77552 .32048 L .79025 .33127 L p .253 .495 .894 r
F P
0 g
s
.74857 .31565 m .78443 .32972 L .74921 .31595 L .433 .597 .913 r
F
.75857 .3194 m .78443 .32972 L .74857 .31565 L F
.81667 .3576 m .78443 .32972 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.84061 .37571 m .81872 .35915 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.81872 .35915 m .81667 .3576 L p .80664 .34791 L .157 .387 .836 r
F P
0 g
s
.78443 .32972 m .80757 .34397 L .84061 .37571 L p .157 .387 .836 r
F P
0 g
s
.77554 .32461 m .75316 .31175 L p .7689 .32107 L .253 .495 .894 r
F P
0 g
s
.78443 .32972 m .77554 .32461 L p .80757 .34397 L .253 .495 .894 r
F P
0 g
s
.77187 .32265 m .80757 .34397 L .77554 .32461 L .253 .495 .894 r
F
.7689 .32107 m .7804 .32788 L .77187 .32265 L F
.7804 .32788 m .80757 .34397 L .77187 .32265 L F
.77552 .32048 m .7987 .33409 L .81845 .35118 L p .088 .386 .846 r
F P
0 g
s
.75316 .31175 m .79025 .33127 L .77905 .32708 L .253 .495 .894 r
F
.79025 .33127 m .80757 .34397 L p .79338 .33556 L F P
0 g
s
.78778 .33035 m .79025 .33127 L .79338 .33556 L .253 .495 .894 r
F
.77552 .32048 m .75316 .31175 L .73402 .30808 L p .211 .627 .952 r
F P
0 g
s
.73402 .30808 m .72271 .30591 L p .74441 .3119 L .211 .627 .952 r
F P
0 g
s
.74441 .3119 m .77552 .32048 L .73402 .30808 L .211 .627 .952 r
F
.72271 .30591 m .74451 .3095 L .75261 .31237 L p F P
0 g
s
.75261 .31237 m .77552 .32048 L p .75956 .31608 L .211 .627 .952 r
F P
0 g
s
.72271 .30591 m .75261 .31237 L .75956 .31608 L .211 .627 .952 r
F
.80296 .34058 m .77552 .32048 L p .79425 .33454 L .088 .386 .846 r
F P
0 g
s
.84061 .37571 m .80757 .34397 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.80757 .34397 m .83161 .36256 L .86539 .3969 L p 0 .283 .785 r
F P
0 g
s
.83161 .36256 m .81022 .34601 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.81022 .34601 m .80757 .34397 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.80757 .34397 m .80296 .34058 L p .80951 .34561 L .088 .386 .846 r
F P
0 g
s
.79425 .33454 m .83161 .36256 L .80296 .34058 L .088 .386 .846 r
F
.77552 .32048 m .8151 .34878 L .80747 .34445 L F
.8151 .34878 m .81845 .35118 L .81593 .34963 L F
.8151 .34878 m .81593 .34963 L .80747 .34445 L F
.86539 .3969 m .84507 .37953 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.84507 .37953 m .84061 .37571 L p .83387 .36804 L 0 .283 .785 r
F P
0 g
s
.7987 .33409 m .77552 .32048 L .76192 .31567 L p .093 .507 .904 r
F P
0 g
s
.76192 .31567 m .74451 .3095 L p .75794 .3156 L .093 .507 .904 r
F P
0 g
s
.75894 .31561 m .7987 .33409 L .76192 .31567 L .093 .507 .904 r
F
.76425 .31846 m .7987 .33409 L .75894 .31561 L F
.74451 .3095 m .76694 .31721 L .777 .32255 L p F P
0 g
s
.777 .32255 m .7987 .33409 L p .78403 .32743 L .093 .507 .904 r
F P
0 g
s
.75794 .3156 m .76425 .31846 L .75894 .31561 L .093 .507 .904 r
F
.74451 .3095 m .777 .32255 L .78403 .32743 L F
.83161 .36256 m .7987 .33409 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.85648 .38395 m .83178 .36271 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.83178 .36271 m .83161 .36256 L p .82051 .35291 L 0 .31 .802 r
F P
0 g
s
.7987 .33409 m .82269 .35131 L .85648 .38395 L p 0 .31 .802 r
F P
0 g
s
.78945 .32917 m .76694 .31721 L p .78329 .3272 L .055 .426 .869 r
F P
0 g
s
.82269 .35131 m .7987 .33409 L .78945 .32917 L p .055 .426 .869 r
F P
0 g
s
.78334 .32722 m .82269 .35131 L .78945 .32917 L .055 .426 .869 r
F
.78329 .3272 m .78361 .3274 L .78334 .32722 L F
.78361 .3274 m .82269 .35131 L .78334 .32722 L F
.7965 .33292 m .80176 .33661 L p .78586 .32775 L F P
0 g
s
.76694 .31721 m .78715 .32795 L .78586 .32775 L .055 .426 .869 r
F
.78715 .32795 m .7965 .33292 L .78586 .32775 L F
.76694 .31721 m .79006 .3284 L .7965 .33292 L p F P
0 g
s
.80176 .33661 m .81348 .34485 L p .80636 .34062 L .055 .426 .869 r
F P
0 g
s
.76694 .31721 m .80176 .33661 L .80636 .34062 L .055 .426 .869 r
F
.81348 .34485 m .82269 .35131 L p .80252 .33897 L F P
0 g
s
.76694 .31721 m .81348 .34485 L .80252 .33897 L .055 .426 .869 r
F
.82269 .35131 m .84744 .37082 L .85648 .38395 L closepath p 0 .238 .751 r
F P
0 g
s
.84744 .37082 m .82269 .35131 L .8184 .3483 L p .083 .387 .847 r
F P
0 g
s
.8184 .3483 m .79006 .3284 L p .80927 .34261 L .083 .387 .847 r
F P
0 g
s
.80927 .34261 m .84744 .37082 L .8184 .3483 L .083 .387 .847 r
F
.74466 .31385 m .75857 .3194 L .74857 .31565 L .433 .597 .913 r
F
.79006 .3284 m .76694 .31721 L .74025 .31489 L p 0 .481 .77 r
F P
0 g
s
.74025 .31489 m .73618 .31454 L p .74694 .31731 L 0 .481 .77 r
F P
0 g
s
.74694 .31731 m .79006 .3284 L .74025 .31489 L 0 .481 .77 r
F
.73618 .31454 m .75864 .31977 L .76845 .32246 L p F P
0 g
s
.73618 .31454 m .76845 .32246 L .77453 .3244 L 0 .481 .77 r
F
.79006 .3284 m .81384 .34215 L .84188 .36608 L p .083 .387 .847 r
F P
0 g
s
.79006 .3284 m .84188 .36608 L .83349 .36051 L .083 .387 .847 r
F
.76845 .32246 m .79006 .3284 L p .77453 .3244 L 0 .481 .77 r
F P
0 g
s
.77905 .32708 m .78778 .33035 L .79338 .33556 L .253 .495 .894 r
F
.81384 .34215 m .79006 .3284 L .77738 .32492 L p .089 .526 .906 r
F P
0 g
s
.77738 .32492 m .75864 .31977 L p .7729 .32555 L .089 .526 .906 r
F P
0 g
s
.7729 .32555 m .81384 .34215 L .77738 .32492 L .089 .526 .906 r
F
.72806 .32632 m .75051 .32765 L .75996 .32738 L p .178 0 0 r
F P
0 g
s
.75864 .31977 m .78159 .32676 L .79125 .33137 L p .089 .526 .906 r
F P
0 g
s
.75864 .31977 m .79125 .33137 L .7987 .33601 L .089 .526 .906 r
F
.75996 .32738 m .78159 .32676 L p .76531 .32662 L .178 0 0 r
F P
0 g
s
.72806 .32632 m .75996 .32738 L .76531 .32662 L .178 0 0 r
F
.79125 .33137 m .81384 .34215 L p .7987 .33601 L .089 .526 .906 r
F P
0 g
s
.84188 .36608 m .84744 .37082 L p .83349 .36051 L .083 .387 .847 r
F P
0 g
s
.7142 .31152 m .73618 .31454 L .74581 .31537 L p .177 0 0 r
F P
0 g
s
.74581 .31537 m .76694 .31721 L p .75078 .31546 L .177 0 0 r
F P
0 g
s
.7142 .31152 m .74581 .31537 L .75078 .31546 L .177 0 0 r
F
.81845 .35118 m .83161 .36256 L p .80747 .34445 L .088 .386 .846 r
F P
0 g
s
.58057 .40276 m .56065 .4293 L .52973 .42496 L p .761 .618 .7 r
F P
0 g
s
.52973 .42496 m .5498 .39835 L .58057 .40276 L p .761 .618 .7 r
F P
0 g
s
.87679 .43946 m .89982 .44691 L .90814 .45899 L closepath p .28 .544 .921 r
F P
0 g
s
.70148 .30683 m .68072 .31246 L .65077 .31944 L p .281 .782 .785 r
F P
0 g
s
.63028 .32859 m .65077 .31944 L .68072 .31246 L p .616 .939 .954 r
F P
0 g
s
.89139 .43466 m .8678 .42284 L .83541 .39349 L p .175 .422 .859 r
F P
0 g
s
.83541 .39349 m .85874 .40634 L .89139 .43466 L p .175 .422 .859 r
F P
0 g
s
.84966 .39045 m .82597 .37438 L .79367 .34429 L p .24 .411 .832 r
F P
0 g
s
.79367 .34429 m .81667 .3576 L .84966 .39045 L p .24 .411 .832 r
F P
0 g
s
.61001 .3412 m .58989 .35722 L .55911 .35562 L p .761 .8 .884 r
F P
0 g
s
.58989 .35722 m .56984 .37632 L .53896 .37223 L p .763 .702 .794 r
F P
0 g
s
.53896 .37223 m .55911 .35562 L .58989 .35722 L p .763 .702 .794 r
F P
0 g
s
.56984 .37632 m .5498 .39835 L .51882 .39264 L p .757 .649 .742 r
F P
0 g
s
.51882 .39264 m .53896 .37223 L .56984 .37632 L p .757 .649 .742 r
F P
0 g
s
.56065 .4293 m .5406 .45098 L .50958 .44543 L p .755 .645 .739 r
F P
0 g
s
.50958 .44543 m .52973 .42496 L .56065 .4293 L p .755 .645 .739 r
F P
0 g
s
.63028 .32859 m .61001 .3412 L .57936 .34285 L p .664 .923 .974 r
F P
0 g
s
.55911 .35562 m .57936 .34285 L .61001 .3412 L p .761 .8 .884 r
F P
0 g
s
.5498 .39835 m .52973 .42496 L .49861 .41804 L p .755 .615 .703 r
F P
0 g
s
.49861 .41804 m .51882 .39264 L .5498 .39835 L p .755 .615 .703 r
F P
0 g
s
.65077 .31944 m .67154 .31366 L .70148 .30683 L p .281 .782 .785 r
F P
0 g
s
.72271 .30591 m .70148 .30683 L .67154 .31366 L p .007 0 0 r
F P
0 g
s
.65077 .31944 m .63028 .32859 L .59977 .33372 L p .204 .722 .693 r
F P
0 g
s
.57936 .34285 m .59977 .33372 L .63028 .32859 L p .664 .923 .974 r
F P
0 g
s
.8678 .42284 m .89139 .43466 L .89982 .44691 L closepath p .125 .44 .877 r
F P
0 g
s
.55911 .35562 m .53896 .37223 L .50787 .36473 L p .735 .668 .784 r
F P
0 g
s
.53896 .37223 m .51882 .39264 L .48765 .38561 L p .743 .621 .724 r
F P
0 g
s
.48765 .38561 m .50787 .36473 L .53896 .37223 L p .743 .621 .724 r
F P
0 g
s
.52973 .42496 m .50958 .44543 L .47833 .44244 L p .749 .611 .705 r
F P
0 g
s
.47833 .44244 m .49861 .41804 L .52973 .42496 L p .749 .611 .705 r
F P
0 g
s
.88285 .42225 m .85874 .40634 L .82597 .37438 L p .068 .35 .823 r
F P
0 g
s
.82597 .37438 m .84966 .39045 L .88285 .42225 L p .068 .35 .823 r
F P
0 g
s
.57936 .34285 m .55911 .35562 L .52806 .34976 L p .713 .758 .887 r
F P
0 g
s
.50787 .36473 m .52806 .34976 L .55911 .35562 L p .735 .668 .784 r
F P
0 g
s
.51882 .39264 m .49861 .41804 L .46734 .4104 L p .75 .609 .702 r
F P
0 g
s
.46734 .4104 m .48765 .38561 L .51882 .39264 L p .75 .609 .702 r
F P
0 g
s
.67154 .31366 m .65077 .31944 L .62041 .32786 L p .196 0 0 r
F P
0 g
s
.62041 .32786 m .59977 .33372 L .56879 .33452 L p .114 0 0 r
F P
0 g
s
.62041 .32786 m .5895 .33311 L p .61784 .32851 L .413 0 0 r
F P
0 g
s
.59977 .33372 m .62041 .32786 L p .62294 .32723 L .204 .722 .693 r
F P
0 g
s
.64132 .3247 m .62041 .32786 L p .61784 .32851 L .413 0 0 r
F P
0 g
s
.62041 .32786 m .65077 .31944 L p .62294 .32723 L .204 .722 .693 r
F P
0 g
s
.59977 .33372 m .57936 .34285 L .54834 .33982 L p .531 .867 .993 r
F P
0 g
s
.52806 .34976 m .54834 .33982 L .57936 .34285 L p .713 .758 .887 r
F P
0 g
s
.52806 .34976 m .50787 .36473 L .47666 .35445 L p .716 .628 .759 r
F P
0 g
s
.50787 .36473 m .48765 .38561 L .45638 .37568 L p .732 .602 .711 r
F P
0 g
s
.45638 .37568 m .47666 .35445 L .50787 .36473 L p .732 .602 .711 r
F P
0 g
s
.49861 .41804 m .47833 .44244 L .44696 .43437 L p .746 .608 .705 r
F P
0 g
s
.44696 .43437 m .46734 .4104 L .49861 .41804 L p .746 .608 .705 r
F P
0 g
s
.48765 .38561 m .46734 .4104 L .43585 .40436 L p .743 .584 .677 r
F P
0 g
s
.43585 .40436 m .45638 .37568 L .48765 .38561 L p .743 .584 .677 r
F P
0 g
s
.54834 .33982 m .52806 .34976 L .49685 .3396 L p .679 .683 .846 r
F P
0 g
s
.47666 .35445 m .49685 .3396 L .52806 .34976 L p .716 .628 .759 r
F P
0 g
s
.74451 .3095 m .72271 .30591 L .69267 .31112 L p .151 0 0 r
F P
0 g
s
.67154 .31366 m .69267 .31112 L .72271 .30591 L p .007 0 0 r
F P
0 g
s
.49685 .3396 m .47666 .35445 L .44538 .343 L p .71 .6 .731 r
F P
0 g
s
.47666 .35445 m .45638 .37568 L .42498 .36612 L p .732 .59 .697 r
F P
0 g
s
.42498 .36612 m .44538 .343 L .47666 .35445 L p .732 .59 .697 r
F P
0 g
s
.45638 .37568 m .43585 .40436 L .40424 .39673 L p .746 .582 .671 r
F P
0 g
s
.40424 .39673 m .42498 .36612 L .45638 .37568 L p .746 .582 .671 r
F P
0 g
s
.46734 .4104 m .44696 .43437 L .4154 .42726 L p .751 .623 .717 r
F P
0 g
s
.4154 .42726 m .43585 .40436 L .46734 .4104 L p .751 .623 .717 r
F P
0 g
s
.85874 .40634 m .88285 .42225 L .89139 .43466 L closepath p 0 .334 .816 r
F P
0 g
s
.54834 .33982 m .56879 .33452 L .59977 .33372 L p .531 .867 .993 r
F P
0 g
s
.49685 .3396 m .51707 .33097 L .54834 .33982 L p .679 .683 .846 r
F P
0 g
s
.51707 .33097 m .49685 .3396 L .46559 .32655 L p .669 .625 .797 r
F P
0 g
s
.44538 .343 m .46559 .32655 L .49685 .3396 L p .71 .6 .731 r
F P
0 g
s
.46559 .32655 m .44538 .343 L .41397 .33241 L p .717 .589 .712 r
F P
0 g
s
.44538 .343 m .42498 .36612 L .39335 .35898 L p .739 .586 .684 r
F P
0 g
s
.39335 .35898 m .41397 .33241 L .44538 .343 L p .739 .586 .684 r
F P
0 g
s
.87418 .40966 m .84966 .39045 L .81667 .3576 L p 0 .299 .795 r
F P
0 g
s
.81667 .3576 m .84061 .37571 L .87418 .40966 L p 0 .299 .795 r
F P
0 g
s
.69267 .31112 m .67154 .31366 L .64132 .3247 L p .348 0 0 r
F P
0 g
s
.62041 .32786 m .64132 .3247 L .67154 .31366 L p .196 0 0 r
F P
0 g
s
.46559 .32655 m .48573 .31742 L .51707 .33097 L p .669 .625 .797 r
F P
0 g
s
.48573 .31742 m .46559 .32655 L .43428 .31313 L p .678 .597 .758 r
F P
0 g
s
.41397 .33241 m .43428 .31313 L .46559 .32655 L p .717 .589 .712 r
F P
0 g
s
.56879 .33452 m .54834 .33982 L .51707 .33097 L p .502 .773 .992 r
F P
0 g
s
.43428 .31313 m .45439 .30166 L .48573 .31742 L p .678 .597 .758 r
F P
0 g
s
.45439 .30166 m .43428 .31313 L .40281 .30238 L p .7 .594 .734 r
F P
0 g
s
.43428 .31313 m .41397 .33241 L .38233 .3247 L p .733 .597 .704 r
F P
0 g
s
.38233 .3247 m .40281 .30238 L .43428 .31313 L p .733 .597 .704 r
F P
0 g
s
.42498 .36612 m .40424 .39673 L .37245 .38928 L p .754 .594 .678 r
F P
0 g
s
.37245 .38928 m .39335 .35898 L .42498 .36612 L p .754 .594 .678 r
F P
0 g
s
.41397 .33241 m .39335 .35898 L .36148 .35311 L p .751 .596 .684 r
F P
0 g
s
.36148 .35311 m .38233 .3247 L .41397 .33241 L p .751 .596 .684 r
F P
0 g
s
.43585 .40436 m .4154 .42726 L .38348 .42445 L p .75 .598 .688 r
F P
0 g
s
.38348 .42445 m .40424 .39673 L .43585 .40436 L p .75 .598 .688 r
F P
0 g
s
.51707 .33097 m .53745 .32853 L .56879 .33452 L p .502 .773 .992 r
F P
0 g
s
.53745 .32853 m .51707 .33097 L .48573 .31742 L p .542 .671 .921 r
F P
0 g
s
.40281 .30238 m .42301 .28714 L .45439 .30166 L p .7 .594 .734 r
F P
0 g
s
.42301 .28714 m .40281 .30238 L .37101 .29637 L p .73 .614 .729 r
F P
0 g
s
.40281 .30238 m .38233 .3247 L .35027 .32139 L p .755 .617 .706 r
F P
0 g
s
.35027 .32139 m .37101 .29637 L .40281 .30238 L p .755 .617 .706 r
F P
0 g
s
.48573 .31742 m .50595 .31571 L .53745 .32853 L p .542 .671 .921 r
F P
0 g
s
.50595 .31571 m .48573 .31742 L .45439 .30166 L p .586 .611 .844 r
F P
0 g
s
.45439 .30166 m .47446 .29851 L .50595 .31571 L p .586 .611 .844 r
F P
0 g
s
.47446 .29851 m .45439 .30166 L .42301 .28714 L p .632 .594 .793 r
F P
0 g
s
.56879 .33452 m .5895 .33311 L p .58378 .33259 L .114 0 0 r
F P
0 g
s
.5895 .33311 m .56879 .33452 L .55692 .33225 L p .209 0 0 r
F P
0 g
s
.55692 .33225 m .53745 .32853 L p .54976 .32961 L .209 0 0 r
F P
0 g
s
.54976 .32961 m .5895 .33311 L .55692 .33225 L .209 0 0 r
F
.5581 .3313 m .5895 .33311 L p .55376 .32996 L F P
0 g
s
.53745 .32853 m .5581 .3313 L p .55376 .32996 L .209 0 0 r
F P
0 g
s
.5895 .33311 m .5581 .3313 L p .59529 .33363 L .52 .018 .005 r
F P
0 g
s
.5581 .3313 m .5791 .338 L .61053 .33459 L p .52 .018 .005 r
F P
0 g
s
.50595 .31571 m .47446 .29851 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.5264 .321 m .51716 .31861 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.51716 .31861 m .50595 .31571 L p .5103 .31403 L .249 .563 .936 r
F P
0 g
s
.49466 .3036 m .46301 .28294 L p .47961 .29355 L 0 .33 .788 r
F P
0 g
s
.49466 .3036 m .5264 .321 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.47446 .29851 m .49034 .30251 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.49034 .30251 m .49466 .3036 L p .49769 .30857 L .249 .563 .936 r
F P
0 g
s
.51515 .31627 m .50319 .30863 L p .49466 .3036 L .513 0 0 r
F P
0 g
s
.50942 .3123 m .51515 .31627 L .52107 .31916 L p .513 0 0 r
F P
0 g
s
.53821 .32484 m .5264 .321 L p .53532 .32388 L .575 .032 0 r
F P
0 g
s
.5264 .321 m .5581 .3313 L p .53813 .32532 L 0 .483 .8 r
F P
0 g
s
.5264 .321 m .49466 .3036 L p .52424 .31953 L .513 0 0 r
F P
0 g
s
.52854 .32246 m .5264 .321 L .53813 .32532 L 0 .483 .8 r
F
.5581 .3313 m .53745 .32853 L .50595 .31571 L p F P
0 g
s
.5581 .3313 m .53821 .32484 L p .56249 .33264 L .575 .032 0 r
F P
0 g
s
.53532 .32388 m .56249 .33264 L .53821 .32484 L .575 .032 0 r
F
.5791 .338 m .5581 .3313 L p .56249 .33264 L F P
0 g
s
.5264 .321 m .54721 .33191 L .5791 .338 L p .575 .032 0 r
F P
0 g
s
.54721 .33191 m .5264 .321 L p .52424 .31953 L .513 0 0 r
F P
0 g
s
.50595 .31571 m .5264 .321 L p .52854 .32246 L 0 .483 .8 r
F P
0 g
s
.51829 .31633 m .52107 .31916 L .5275 .32129 L .513 0 0 r
F
.49466 .3036 m .5162 .31629 L .51829 .31633 L F
.5162 .31629 m .52107 .31916 L .51829 .31633 L F
.48316 .29407 m .51515 .31627 L p .50723 .31121 L 0 .33 .788 r
F P
0 g
s
.47895 .29313 m .48316 .29407 L .50723 .31121 L 0 .33 .788 r
F
.43142 .26367 m .45133 .27063 L .48316 .29407 L p .253 .494 .893 r
F P
0 g
s
.48316 .29407 m .45133 .27063 L p .4591 .27694 L 0 .122 .601 r
F P
0 g
s
.47385 .28893 m .48316 .29407 L p .47895 .29313 L 0 .33 .788 r
F P
0 g
s
.47961 .29355 m .50723 .31121 L .49485 .30372 L 0 .33 .788 r
F
.51515 .31627 m .51072 .31354 L p .50723 .31121 L F P
0 g
s
.51072 .31354 m .49485 .30372 L p .50723 .31121 L 0 .33 .788 r
F P
0 g
s
.46301 .28294 m .43142 .26367 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.48316 .29407 m .47116 .28744 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.47116 .28744 m .46301 .28294 L p .47048 .28662 L .253 .494 .893 r
F P
0 g
s
.4591 .27694 m .47443 .28937 L .48316 .29407 L 0 .122 .601 r
F
.49485 .30372 m .49466 .3036 L p .47961 .29355 L 0 .33 .788 r
F P
0 g
s
.49466 .3036 m .47446 .29851 L .44303 .28055 L p .448 .571 .886 r
F P
0 g
s
.44303 .28055 m .46301 .28294 L .49466 .3036 L p .448 .571 .886 r
F P
0 g
s
.50366 .31308 m .48742 .29802 L p .47443 .28937 L 0 .122 .601 r
F P
0 g
s
.48742 .29802 m .48316 .29407 L p .47443 .28937 L 0 .122 .601 r
F P
0 g
s
.47143 .28648 m .50366 .31308 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.45133 .27063 m .46833 .28403 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.46833 .28403 m .47143 .28648 L p .46932 .28523 L 0 .122 .601 r
F P
0 g
s
.51515 .31627 m .48316 .29407 L p .51197 .31622 L .674 .124 0 r
F P
0 g
s
.53608 .33475 m .51515 .31627 L p .51197 .31622 L .674 .124 0 r
F P
0 g
s
.46301 .28294 m .47385 .28893 L p .47895 .29313 L 0 .33 .788 r
F P
0 g
s
.52107 .31916 m .54721 .33191 L p .5275 .32129 L .513 0 0 r
F P
0 g
s
.61053 .33459 m .5895 .33311 L p .59529 .33363 L .52 .018 .005 r
F P
0 g
s
.5895 .33311 m .62041 .32786 L p .58378 .33259 L .114 0 0 r
F P
0 g
s
.42301 .28714 m .44303 .28055 L .47446 .29851 L p .632 .594 .793 r
F P
0 g
s
.44303 .28055 m .42301 .28714 L .3914 .27731 L p .68 .608 .768 r
F P
0 g
s
.37101 .29637 m .3914 .27731 L .42301 .28714 L p .73 .614 .729 r
F P
0 g
s
.39335 .35898 m .37245 .38928 L .34024 .38608 L p .76 .594 .671 r
F P
0 g
s
.34024 .38608 m .36148 .35311 L .39335 .35898 L p .76 .594 .671 r
F P
0 g
s
.38233 .3247 m .36148 .35311 L .32922 .35015 L p .768 .619 .695 r
F P
0 g
s
.32922 .35015 m .35027 .32139 L .38233 .3247 L p .768 .619 .695 r
F P
0 g
s
.40424 .39673 m .38348 .42445 L .35153 .41733 L p .751 .598 .687 r
F P
0 g
s
.35153 .41733 m .37245 .38928 L .40424 .39673 L p .751 .598 .687 r
F P
0 g
s
.69267 .31112 m .7142 .31152 L .74451 .3095 L p .151 0 0 r
F P
0 g
s
.7142 .31152 m .69267 .31112 L .66253 .32359 L p .401 0 .001 r
F P
0 g
s
.64132 .3247 m .66253 .32359 L .69267 .31112 L p .348 0 0 r
F P
0 g
s
.84966 .39045 m .87418 .40966 L .88285 .42225 L closepath p 0 .248 .757 r
F P
0 g
s
.76694 .31721 m .74451 .3095 L .7142 .31152 L p .177 0 0 r
F P
0 g
s
.3914 .27731 m .4115 .26597 L .44303 .28055 L p .68 .608 .768 r
F P
0 g
s
.4115 .26597 m .3914 .27731 L .3593 .27425 L p .731 .65 .769 r
F P
0 g
s
.3914 .27731 m .37101 .29637 L .33864 .29633 L p .765 .652 .737 r
F P
0 g
s
.33864 .29633 m .3593 .27425 L .3914 .27731 L p .765 .652 .737 r
F P
0 g
s
.37101 .29637 m .35027 .32139 L .31765 .32264 L p .782 .652 .719 r
F P
0 g
s
.31765 .32264 m .33864 .29633 L .37101 .29637 L p .782 .652 .719 r
F P
0 g
s
.36148 .35311 m .34024 .38608 L .30783 .38215 L p .77 .611 .682 r
F P
0 g
s
.30783 .38215 m .32922 .35015 L .36148 .35311 L p .77 .611 .682 r
F P
0 g
s
.37245 .38928 m .35153 .41733 L .31941 .41007 L p .765 .639 .722 r
F P
0 g
s
.31941 .41007 m .34024 .38608 L .37245 .38928 L p .765 .639 .722 r
F P
0 g
s
.46301 .28294 m .44303 .28055 L .4115 .26597 L p .567 .592 .838 r
F P
0 g
s
.35027 .32139 m .32922 .35015 L .29639 .35131 L p .787 .649 .71 r
F P
0 g
s
.29639 .35131 m .31765 .32264 L .35027 .32139 L p .787 .649 .71 r
F P
0 g
s
.4115 .26597 m .43142 .26367 L .46301 .28294 L p .567 .592 .838 r
F P
0 g
s
.43142 .26367 m .4115 .26597 L .37962 .2584 L p .657 .637 .819 r
F P
0 g
s
.3593 .27425 m .37962 .2584 L .4115 .26597 L p .731 .65 .769 r
F P
0 g
s
.66253 .32359 m .64132 .3247 L .61053 .33459 L p .488 .049 .131 r
F P
0 g
s
.5895 .33311 m .61053 .33459 L .64132 .3247 L p .413 0 0 r
F P
0 g
s
.37962 .2584 m .3593 .27425 L .32644 .27863 L p .784 .715 .787 r
F P
0 g
s
.3593 .27425 m .33864 .29633 L .30551 .30216 L p .805 .71 .761 r
F P
0 g
s
.30551 .30216 m .32644 .27863 L .3593 .27425 L p .805 .71 .761 r
F P
0 g
s
.37962 .2584 m .39965 .25038 L .43142 .26367 L p .657 .637 .819 r
F P
0 g
s
.39965 .25038 m .37962 .2584 L .34705 .25944 L p .735 .714 .831 r
F P
0 g
s
.32644 .27863 m .34705 .25944 L .37962 .2584 L p .784 .715 .787 r
F P
0 g
s
.33864 .29633 m .31765 .32264 L .28436 .32772 L p .811 .706 .749 r
F P
0 g
s
.28436 .32772 m .30551 .30216 L .33864 .29633 L p .811 .706 .749 r
F P
0 g
s
.32922 .35015 m .30783 .38215 L .2751 .37893 L p .786 .653 .716 r
F P
0 g
s
.2751 .37893 m .29639 .35131 L .32922 .35015 L p .786 .653 .716 r
F P
0 g
s
.73618 .31454 m .7142 .31152 L .68407 .32388 L p .404 0 0 r
F P
0 g
s
.66253 .32359 m .68407 .32388 L .7142 .31152 L p .401 0 .001 r
F P
0 g
s
.84061 .37571 m .86539 .3969 L .87418 .40966 L closepath p 0 .197 .72 r
F P
0 g
s
.34024 .38608 m .31941 .41007 L .2868 .40711 L p .762 .63 .714 r
F P
0 g
s
.2868 .40711 m .30783 .38215 L .34024 .38608 L p .762 .63 .714 r
F P
0 g
s
.31765 .32264 m .29639 .35131 L .26308 .35389 L p .806 .694 .741 r
F P
0 g
s
.26308 .35389 m .28436 .32772 L .31765 .32264 L p .806 .694 .741 r
F P
0 g
s
.41951 .25136 m .43938 .26145 L .44707 .26745 L p .052 .398 .854 r
F P
0 g
s
.45133 .27063 m .43142 .26367 L .42497 .26098 L p .478 .591 .888 r
F P
0 g
s
.43178 .26297 m .45133 .27063 L .42497 .26098 L .478 .591 .888 r
F
.39965 .25038 m .41951 .25136 L .45133 .27063 L p F P
0 g
s
.45133 .27063 m .41951 .25136 L p .44517 .26871 L .052 .398 .854 r
F P
0 g
s
.44517 .26871 m .4531 .27408 L .45112 .27222 L .052 .398 .854 r
F
.45992 .27741 m .45133 .27063 L p .44517 .26871 L F P
0 g
s
.47143 .28648 m .45992 .27741 L p .45112 .27222 L .052 .398 .854 r
F P
0 g
s
.4531 .27408 m .47143 .28648 L .45112 .27222 L .052 .398 .854 r
F
.44707 .26745 m .47143 .28648 L p .44042 .2655 L F P
0 g
s
.41951 .25136 m .44707 .26745 L .44042 .2655 L .052 .398 .854 r
F
.43938 .26145 m .45946 .28017 L .46825 .2883 L p .491 0 0 r
F P
0 g
s
.46825 .2883 m .49192 .31018 L p .46181 .28226 L .491 0 0 r
F P
0 g
s
.43938 .26145 m .46825 .2883 L .46181 .28226 L .491 0 0 r
F
.41951 .25136 m .39965 .25038 L .36734 .24636 L p .626 .69 .89 r
F P
0 g
s
.36734 .24636 m .38737 .24077 L .41951 .25136 L p .626 .69 .89 r
F P
0 g
s
.41951 .25136 m .38737 .24077 L p .4075 .24877 L .369 .594 .933 r
F P
0 g
s
.43938 .26145 m .4237 .25349 L p .41221 .25014 L .369 .594 .933 r
F P
0 g
s
.4157 .25203 m .43938 .26145 L .41221 .25014 L .369 .594 .933 r
F
.4237 .25349 m .41951 .25136 L p .4075 .24877 L F P
0 g
s
.40724 .24369 m .43938 .26145 L p .41925 .25345 L .369 .594 .933 r
F P
0 g
s
.43938 .26145 m .40724 .24369 L p .42993 .25954 L 0 .334 .808 r
F P
0 g
s
.45946 .28017 m .44566 .26731 L p .43321 .26116 L 0 .334 .808 r
F P
0 g
s
.43574 .2636 m .45946 .28017 L .43321 .26116 L 0 .334 .808 r
F
.44566 .26731 m .43938 .26145 L p .42993 .25954 L F P
0 g
s
.40724 .24369 m .42713 .25512 L .44039 .2654 L p 0 .334 .808 r
F P
0 g
s
.42993 .25954 m .43574 .2636 L .43321 .26116 L 0 .334 .808 r
F
.44039 .2654 m .45946 .28017 L p .43116 .2604 L F P
0 g
s
.40724 .24369 m .44039 .2654 L .43116 .2604 L 0 .334 .808 r
F
.45946 .28017 m .42713 .25512 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.47994 .30639 m .46816 .29132 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.46816 .29132 m .45946 .28017 L p .45326 .2805 L 0 .02 .519 r
F P
0 g
s
.42713 .25512 m .44723 .27452 L .46313 .29002 L p 0 .02 .519 r
F P
0 g
s
.42713 .25512 m .46313 .29002 L .45374 .28096 L 0 .02 .519 r
F
.4075 .24877 m .4157 .25203 L .41221 .25014 L .369 .594 .933 r
F
.38737 .24077 m .40118 .2428 L p .41925 .25345 L F P
0 g
s
.42497 .26098 m .39965 .25038 L p .43178 .26297 L .478 .591 .888 r
F P
0 g
s
.40118 .2428 m .40724 .24369 L p .41925 .25345 L .369 .594 .933 r
F P
0 g
s
.38737 .24077 m .36734 .24636 L .33415 .25215 L p .731 .817 .918 r
F P
0 g
s
.33415 .25215 m .35448 .24125 L .38737 .24077 L p .731 .817 .918 r
F P
0 g
s
.40724 .24369 m .38737 .24077 L .35448 .24125 L p .572 .767 .971 r
F P
0 g
s
.37457 .23707 m .40724 .24369 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.42713 .25512 m .40724 .24369 L .37457 .23707 L p .261 .607 .954 r
F P
0 g
s
.39454 .24045 m .42713 .25512 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.37457 .23707 m .38952 .2396 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.38952 .2396 m .39454 .24045 L p .40687 .24817 L .261 .607 .954 r
F P
0 g
s
.42713 .25512 m .39454 .24045 L p .41516 .25378 L 0 .338 .8 r
F P
0 g
s
.44723 .27452 m .43155 .25939 L p .41658 .25427 L 0 .338 .8 r
F P
0 g
s
.41836 .25585 m .44723 .27452 L .41658 .25427 L 0 .338 .8 r
F
.43155 .25939 m .42713 .25512 L p .41516 .25378 L F P
0 g
s
.41516 .25378 m .41836 .25585 L .41658 .25427 L 0 .338 .8 r
F
.39454 .24045 m .40871 .24814 L p .42721 .26158 L F P
0 g
s
.40871 .24814 m .41453 .2513 L p .42721 .26158 L 0 .338 .8 r
F P
0 g
s
.41453 .2513 m .44723 .27452 L p .42721 .26158 L 0 .338 .8 r
F P
0 g
s
.44723 .27452 m .41453 .2513 L p .4376 .27272 L 0 .102 .614 r
F P
0 g
s
.46773 .30071 m .45347 .28249 L p .43789 .2729 L 0 .102 .614 r
F P
0 g
s
.43832 .27339 m .46773 .30071 L .43789 .2729 L 0 .102 .614 r
F
.45347 .28249 m .44723 .27452 L p .4376 .27272 L F P
0 g
s
.41453 .2513 m .43474 .26905 L .45528 .28877 L p 0 .102 .614 r
F P
0 g
s
.4376 .27272 m .43832 .27339 L .43789 .2729 L 0 .102 .614 r
F
.41453 .2513 m .45528 .28877 L .44504 .27964 L F
.45528 .28877 m .46773 .30071 L p .44504 .27964 L F P
0 g
s
.46773 .30071 m .43474 .26905 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.48883 .33142 m .4765 .31347 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.4765 .31347 m .46773 .30071 L p .46182 .30027 L 0 0 .482 r
F P
0 g
s
.43474 .26905 m .45534 .29258 L .48051 .32176 L p 0 0 .482 r
F P
0 g
s
.43474 .26905 m .48051 .32176 L .47198 .31199 L 0 0 .482 r
F
.35448 .24125 m .37033 .23795 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.37033 .23795 m .37457 .23707 L p .38679 .24275 L .572 .767 .971 r
F P
0 g
s
.35448 .24125 m .33415 .25215 L .31947 .25816 L p .775 .949 .933 r
F P
0 g
s
.31947 .25816 m .29987 .26617 L p .32585 .25432 L .775 .949 .933 r
F P
0 g
s
.32585 .25432 m .35448 .24125 L .31947 .25816 L .775 .949 .933 r
F
.32051 .25216 m .34094 .24279 L .3466 .24183 L p .658 .926 .974 r
F P
0 g
s
.29987 .26617 m .32051 .25216 L .35448 .24125 L p .775 .949 .933 r
F P
0 g
s
.37457 .23707 m .35448 .24125 L .33963 .24602 L p .658 .926 .974 r
F P
0 g
s
.33963 .24602 m .32051 .25216 L p .37457 .23707 L .658 .926 .974 r
F P
0 g
s
.3466 .24183 m .37457 .23707 L p .33713 .24752 L .658 .926 .974 r
F P
0 g
s
.32051 .25216 m .3466 .24183 L .33713 .24752 L .658 .926 .974 r
F
.39454 .24045 m .37457 .23707 L .34094 .24279 L p .462 .829 .993 r
F P
0 g
s
.34094 .24279 m .36119 .23895 L .39454 .24045 L p .462 .829 .993 r
F P
0 g
s
.41453 .2513 m .39454 .24045 L .36119 .23895 L p .193 .639 .944 r
F P
0 g
s
.38136 .24126 m .41453 .2513 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.41453 .2513 m .39077 .24411 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.36119 .23895 m .37711 .24077 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.37711 .24077 m .38136 .24126 L p .39396 .24654 L .193 .639 .944 r
F P
0 g
s
.34705 .25944 m .36734 .24636 L .39965 .25038 L p .735 .714 .831 r
F P
0 g
s
.39077 .24411 m .38136 .24126 L p .40058 .25127 L 0 .425 .849 r
F P
0 g
s
.40058 .25127 m .43474 .26905 L .39077 .24411 L 0 .425 .849 r
F
.38136 .24126 m .3969 .24767 L p .41462 .25858 L F P
0 g
s
.43474 .26905 m .41732 .25375 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.41732 .25375 m .41453 .2513 L p .40421 .25173 L 0 .425 .849 r
F P
0 g
s
.3969 .24767 m .40158 .2496 L p .41462 .25858 L 0 .425 .849 r
F P
0 g
s
.36734 .24636 m .34705 .25944 L .31355 .26862 L p .803 .817 .862 r
F P
0 g
s
.31355 .26862 m .33415 .25215 L .36734 .24636 L p .803 .817 .862 r
F P
0 g
s
.32051 .25216 m .29987 .26617 L .29986 .26618 L p .65 .968 .835 r
F P
0 g
s
.29986 .26618 m .26453 .28478 L p .29364 .26782 L .65 .968 .835 r
F P
0 g
s
.29364 .26782 m .32051 .25216 L .29986 .26618 L .65 .968 .835 r
F
.26453 .28478 m .28536 .27047 L .32051 .25216 L p F P
0 g
s
.34094 .24279 m .32051 .25216 L .30239 .2616 L p .534 .921 .809 r
F P
0 g
s
.30239 .2616 m .28536 .27047 L p .30888 .25875 L .534 .921 .809 r
F P
0 g
s
.30888 .25875 m .34094 .24279 L .30239 .2616 L .534 .921 .809 r
F
.30608 .25866 m .34094 .24279 L p .28733 .26949 L F P
0 g
s
.36119 .23895 m .34094 .24279 L .30608 .25866 L p .41 .86 .811 r
F P
0 g
s
.32668 .25018 m .33345 .24798 L p .30608 .25866 L .41 .86 .811 r
F P
0 g
s
.33345 .24798 m .36119 .23895 L p .32244 .25281 L .41 .86 .811 r
F P
0 g
s
.30608 .25866 m .33345 .24798 L .32244 .25281 L .41 .86 .811 r
F
.28536 .27047 m .28686 .26961 L p .28733 .26949 L .534 .921 .809 r
F P
0 g
s
.28686 .26961 m .30608 .25866 L p .28733 .26949 L .534 .921 .809 r
F P
0 g
s
.38136 .24126 m .36119 .23895 L .32668 .25018 L p .3 .794 .858 r
F P
0 g
s
.32668 .25018 m .34719 .24566 L .38136 .24126 L p .3 .794 .858 r
F P
0 g
s
.40158 .2496 m .38136 .24126 L .34719 .24566 L p .201 .7 .913 r
F P
0 g
s
.36768 .2455 m .40158 .2496 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.34719 .24566 m .36394 .24553 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.36394 .24553 m .36768 .2455 L p .38039 .24806 L .201 .7 .913 r
F P
0 g
s
.41462 .25858 m .40158 .2496 L .41564 .25911 L 0 .425 .849 r
F
.40158 .2496 m .43474 .26905 L p .41564 .25911 L F P
0 g
s
.43474 .26905 m .40158 .2496 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.45534 .29258 m .43894 .27385 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.43894 .27385 m .43474 .26905 L p .42242 .26626 L 0 .266 .764 r
F P
0 g
s
.40158 .2496 m .41725 .26019 L .43631 .27734 L 0 .266 .764 r
F
.40158 .2496 m .43631 .27734 L .43592 .27705 L F
.41725 .26019 m .422 .26341 L p .43659 .27759 L F P
0 g
s
.422 .26341 m .40158 .2496 L .36768 .2455 L p .159 .583 .934 r
F P
0 g
s
.38825 .24956 m .422 .26341 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.36768 .2455 m .38441 .2488 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.38441 .2488 m .38825 .24956 L p .40152 .25666 L .159 .583 .934 r
F P
0 g
s
.43592 .27705 m .43631 .27734 L .43659 .27759 L 0 .266 .764 r
F
.422 .26341 m .45534 .29258 L p .43659 .27759 L F P
0 g
s
.48051 .32176 m .48883 .33142 L p .47198 .31199 L 0 0 .482 r
F P
0 g
s
.46313 .29002 m .47994 .30639 L p .45374 .28096 L 0 .02 .519 r
F P
0 g
s
.68407 .32388 m .66253 .32359 L .63189 .33772 L p .505 .09 .187 r
F P
0 g
s
.61053 .33459 m .63189 .33772 L .66253 .32359 L p .488 .049 .131 r
F P
0 g
s
.30783 .38215 m .2868 .40711 L .25415 .40131 L p .763 .648 .735 r
F P
0 g
s
.25415 .40131 m .2751 .37893 L .30783 .38215 L p .763 .648 .735 r
F P
0 g
s
.34705 .25944 m .32644 .27863 L .29267 .28916 L p .833 .804 .824 r
F P
0 g
s
.29267 .28916 m .31355 .26862 L .34705 .25944 L p .833 .804 .824 r
F P
0 g
s
.32644 .27863 m .30551 .30216 L .27158 .3119 L p .84 .79 .803 r
F P
0 g
s
.27158 .3119 m .29267 .28916 L .32644 .27863 L p .84 .79 .803 r
F P
0 g
s
.29639 .35131 m .2751 .37893 L .24184 .37863 L p .793 .682 .742 r
F P
0 g
s
.24184 .37863 m .26308 .35389 L .29639 .35131 L p .793 .682 .742 r
F P
0 g
s
.63189 .33772 m .61053 .33459 L .5791 .338 L p .574 .143 .183 r
F P
0 g
s
.30551 .30216 m .28436 .32772 L .25043 .33499 L p .834 .773 .794 r
F P
0 g
s
.25043 .33499 m .27158 .3119 L .30551 .30216 L p .834 .773 .794 r
F P
0 g
s
.75864 .31977 m .73618 .31454 L .70591 .32494 L p .355 0 0 r
F P
0 g
s
.68407 .32388 m .70591 .32494 L .73618 .31454 L p .404 0 0 r
F P
0 g
s
.83161 .36256 m .85648 .38395 L .86539 .3969 L closepath p 0 .192 .715 r
F P
0 g
s
.2751 .37893 m .25415 .40131 L .22134 .39497 L p .767 .723 .812 r
F P
0 g
s
.22134 .39497 m .24184 .37863 L .2751 .37893 L p .767 .723 .812 r
F P
0 g
s
.28436 .32772 m .26308 .35389 L .22935 .35672 L p .819 .758 .795 r
F P
0 g
s
.22935 .35672 m .25043 .33499 L .28436 .32772 L p .819 .758 .795 r
F P
0 g
s
.70591 .32494 m .68407 .32388 L .65357 .34125 L p .496 .086 .192 r
F P
0 g
s
.63189 .33772 m .65357 .34125 L .68407 .32388 L p .505 .09 .187 r
F P
0 g
s
.26308 .35389 m .24184 .37863 L .20843 .37648 L p .791 .726 .792 r
F P
0 g
s
.20843 .37648 m .22935 .35672 L .26308 .35389 L p .791 .726 .792 r
F P
0 g
s
.5791 .338 m .60051 .34703 L .63189 .33772 L p .574 .143 .183 r
F P
0 g
s
.60051 .34703 m .5791 .338 L .54721 .33191 L p .643 .191 .163 r
F P
0 g
s
.24184 .37863 m .22134 .39497 L .18811 .39064 L p .749 .723 .829 r
F P
0 g
s
.65357 .34125 m .63189 .33772 L .60051 .34703 L p .577 .178 .25 r
F P
0 g
s
.18811 .39064 m .20843 .37648 L .24184 .37863 L p .749 .723 .829 r
F P
0 g
s
.48316 .29407 m .50366 .31308 L .53608 .33475 L p .674 .124 0 r
F P
0 g
s
.33415 .25215 m .31355 .26862 L .27902 .28363 L p .833 .936 .896 r
F P
0 g
s
.31355 .26862 m .29267 .28916 L .25803 .30305 L p .854 .912 .872 r
F P
0 g
s
.25803 .30305 m .27902 .28363 L .31355 .26862 L p .854 .912 .872 r
F P
0 g
s
.29267 .28916 m .27158 .3119 L .23698 .32299 L p .853 .882 .86 r
F P
0 g
s
.23698 .32299 m .25803 .30305 L .29267 .28916 L p .853 .882 .86 r
F P
0 g
s
.27902 .28363 m .29987 .26617 L .33415 .25215 L p .833 .936 .896 r
F P
0 g
s
.78159 .32676 m .75864 .31977 L .72806 .32632 L p .178 0 0 r
F P
0 g
s
.70591 .32494 m .72806 .32632 L .75864 .31977 L p .355 0 0 r
F P
0 g
s
.54721 .33191 m .56848 .34664 L .60051 .34703 L p .643 .191 .163 r
F P
0 g
s
.56848 .34664 m .54721 .33191 L .51515 .31627 L p .695 .199 .062 r
F P
0 g
s
.51515 .31627 m .53608 .33475 L .56848 .34664 L p .695 .199 .062 r
F P
0 g
s
.27158 .3119 m .25043 .33499 L .21601 .34206 L p .837 .851 .856 r
F P
0 g
s
.21601 .34206 m .23698 .32299 L .27158 .3119 L p .837 .851 .856 r
F P
0 g
s
.72806 .32632 m .70591 .32494 L .67553 .34402 L p .461 .038 .149 r
F P
0 g
s
.65357 .34125 m .67553 .34402 L .70591 .32494 L p .496 .086 .192 r
F P
0 g
s
.20843 .37648 m .18811 .39064 L .1548 .38483 L p .724 .751 .873 r
F P
0 g
s
.25043 .33499 m .22935 .35672 L .19524 .35926 L p .809 .818 .857 r
F P
0 g
s
.19524 .35926 m .21601 .34206 L .25043 .33499 L p .809 .818 .857 r
F P
0 g
s
.22935 .35672 m .20843 .37648 L .1748 .3737 L p .773 .789 .866 r
F P
0 g
s
.1748 .3737 m .19524 .35926 L .22935 .35672 L p .773 .789 .866 r
F P
0 g
s
.1548 .38483 m .1748 .3737 L .20843 .37648 L p .724 .751 .873 r
F P
0 g
s
.1748 .3737 m .1548 .38483 L .12128 .37896 L p .685 .782 .925 r
F P
0 g
s
.49192 .31018 m .47143 .28648 L .43938 .26145 L p .491 0 0 r
F P
0 g
s
.67553 .34402 m .65357 .34125 L .62232 .35646 L p .561 .177 .271 r
F P
0 g
s
.60051 .34703 m .62232 .35646 L .65357 .34125 L p .577 .178 .25 r
F P
0 g
s
.62232 .35646 m .60051 .34703 L .56848 .34664 L p .642 .235 .258 r
F P
0 g
s
.19524 .35926 m .1748 .3737 L .14091 .37059 L p .731 .807 .912 r
F P
0 g
s
.12128 .37896 m .14091 .37059 L .1748 .3737 L p .685 .782 .925 r
F P
0 g
s
.75051 .32765 m .72806 .32632 L .6977 .34503 L p .38 0 .027 r
F P
0 g
s
.67553 .34402 m .6977 .34503 L .72806 .32632 L p .461 .038 .149 r
F P
0 g
s
.52467 .33789 m .50366 .31308 L .47143 .28648 L p .734 .207 0 r
F P
0 g
s
.47143 .28648 m .49192 .31018 L .52467 .33789 L p .734 .207 0 r
F P
0 g
s
.14091 .37059 m .12128 .37896 L .0875 .37322 L p .672 .755 .914 r
F P
0 g
s
.81384 .34215 m .83827 .3575 L .84744 .37082 L closepath p 0 .345 .823 r
F P
0 g
s
.80655 .33867 m .78159 .32676 L p .79888 .33613 L .249 .512 .907 r
F P
0 g
s
.83827 .3575 m .81384 .34215 L .80655 .33867 L p .249 .512 .907 r
F P
0 g
s
.79888 .33613 m .83827 .3575 L .80655 .33867 L .249 .512 .907 r
F
.78159 .32676 m .80504 .33501 L .83827 .3575 L p F P
0 g
s
.80504 .33501 m .78159 .32676 L .75051 .32765 L p .223 .69 .943 r
F P
0 g
s
.77323 .32874 m .78138 .33034 L p .75203 .32778 L .223 .69 .943 r
F P
0 g
s
.78138 .33034 m .80504 .33501 L p .78888 .33283 L .223 .69 .943 r
F P
0 g
s
.75051 .32765 m .78138 .33034 L .78888 .33283 L .223 .69 .943 r
F
.80504 .33501 m .82897 .34399 L .83827 .3575 L closepath p .212 .5 .904 r
F P
0 g
s
.82897 .34399 m .80504 .33501 L .77323 .32874 L p .463 .657 .944 r
F P
0 g
s
.79624 .32961 m .82897 .34399 L p .77385 .32891 L .463 .657 .944 r
F P
0 g
s
.77323 .32874 m .79624 .32961 L p .77385 .32891 L .463 .657 .944 r
F P
0 g
s
.77323 .32874 m .74243 .33987 L p .79554 .32974 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .77323 .32874 L p .79554 .32974 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .81953 .33028 L .82897 .34399 L closepath p .472 .657 .942 r
F P
0 g
s
.76488 .33359 m .79624 .32961 L p .7474 .33893 L .444 .868 .935 r
F P
0 g
s
.74243 .33987 m .76488 .33359 L p .7474 .33893 L .444 .868 .935 r
F P
0 g
s
.79624 .32961 m .76488 .33359 L p .81893 .33032 L .668 .771 .927 r
F P
0 g
s
.81953 .33028 m .79624 .32961 L p .81893 .33032 L .668 .771 .927 r
F P
0 g
s
.78738 .32554 m .81953 .33028 L p .76773 .33342 L .668 .771 .927 r
F P
0 g
s
.76488 .33359 m .78738 .32554 L p .76773 .33342 L .668 .771 .927 r
F P
0 g
s
.76488 .33359 m .73425 .35468 L p .78252 .3282 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .76488 .33359 L p .78252 .3282 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .80996 .31637 L .81953 .33028 L closepath p .686 .76 .908 r
F P
0 g
s
.75642 .34002 m .78738 .32554 L p .74378 .34946 L .666 .975 .864 r
F P
0 g
s
.73425 .35468 m .75642 .34002 L p .74378 .34946 L .666 .975 .864 r
F P
0 g
s
.78738 .32554 m .75642 .34002 L p .80719 .3176 L .812 .83 .865 r
F P
0 g
s
.80996 .31637 m .78738 .32554 L p .80719 .3176 L .812 .83 .865 r
F P
0 g
s
.75051 .32765 m .77323 .32874 L p .75203 .32778 L .223 .69 .943 r
F P
0 g
s
.77323 .32874 m .75051 .32765 L .72003 .34373 L p .149 0 0 r
F P
0 g
s
.72003 .34373 m .74243 .33987 L .77323 .32874 L p .149 0 0 r
F P
0 g
s
.76488 .33359 m .74243 .33987 L .71188 .36471 L p .046 0 0 r
F P
0 g
s
.71188 .36471 m .73425 .35468 L .76488 .33359 L p .046 0 0 r
F P
0 g
s
.75642 .34002 m .7784 .32209 L .80996 .31637 L p .812 .83 .865 r
F P
0 g
s
.74926 .34702 m .72579 .36999 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.75642 .34002 m .73425 .35468 L .70344 .38672 L p 0 0 0 r
F P
0 g
s
.72579 .36999 m .75642 .34002 L p .7323 .36128 L 0 0 0 r
F P
0 g
s
.70344 .38672 m .72579 .36999 L p .7323 .36128 L 0 0 0 r
F P
0 g
s
.71321 .38477 m .69452 .40674 L p .70828 .39117 L 0 0 0 r
F P
0 g
s
.72579 .36999 m .70344 .38672 L .67166 .42003 L p .213 0 .077 r
F P
0 g
s
.75642 .34002 m .74926 .34702 L p .76914 .33052 L .818 .997 .777 r
F P
0 g
s
.74127 .35589 m .76914 .33052 L .74926 .34702 L .818 .997 .777 r
F
.7784 .32209 m .75642 .34002 L p .76914 .33052 L F P
0 g
s
.7477 .34654 m .7784 .32209 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.72579 .36999 m .7477 .34654 L p .74127 .35589 L .818 .997 .777 r
F P
0 g
s
.69452 .40674 m .71688 .38334 L .7477 .34654 L p 0 0 0 r
F P
0 g
s
.7477 .34654 m .72579 .36999 L p .71916 .37885 L 0 0 0 r
F P
0 g
s
.7477 .34654 m .72133 .37803 L p .75388 .33756 L .905 .981 .713 r
F P
0 g
s
.76921 .3185 m .7477 .34654 L p .75388 .33756 L .905 .981 .713 r
F P
0 g
s
.67166 .42003 m .69452 .40674 L .72579 .36999 L p .213 0 .077 r
F P
0 g
s
.69452 .40674 m .67166 .42003 L .66623 .42388 L p .387 0 .17 r
F P
0 g
s
.66623 .42388 m .63846 .44359 L p .67573 .41909 L .387 0 .17 r
F P
0 g
s
.67573 .41909 m .69452 .40674 L .66623 .42388 L .387 0 .17 r
F
.66191 .43885 m .68497 .42145 L .69514 .40931 L p .064 0 0 r
F P
0 g
s
.63846 .44359 m .66191 .43885 L .69452 .40674 L p .387 0 .17 r
F P
0 g
s
.69452 .40674 m .66191 .43885 L p .70215 .39822 L .064 0 0 r
F P
0 g
s
.70215 .39822 m .70512 .39522 L .70311 .39741 L .064 0 0 r
F
.70215 .39822 m .70311 .39741 L .69452 .40674 L F
.73425 .35468 m .71188 .36471 L .68077 .39566 L p .301 0 .114 r
F P
0 g
s
.68077 .39566 m .70344 .38672 L .73425 .35468 L p .301 0 .114 r
F P
0 g
s
.70344 .38672 m .68077 .39566 L .6485 .42278 L p .434 .058 .224 r
F P
0 g
s
.6485 .42278 m .67166 .42003 L .70344 .38672 L p .434 .058 .224 r
F P
0 g
s
.69722 .39396 m .72904 .35291 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.66191 .43885 m .69514 .40931 L .68721 .4133 L .064 0 0 r
F
.71688 .38334 m .70362 .39722 L p .70512 .39522 L F P
0 g
s
.70362 .39722 m .69452 .40674 L p .70512 .39522 L .064 0 0 r
F P
0 g
s
.69514 .40931 m .71688 .38334 L p .68721 .4133 L .064 0 0 r
F P
0 g
s
.6149 .43615 m .63846 .44359 L .67166 .42003 L p .542 .154 .255 r
F P
0 g
s
.63846 .44359 m .6149 .43615 L .58031 .42986 L p .645 .224 .23 r
F P
0 g
s
.58031 .42986 m .60392 .44841 L .63846 .44359 L p .645 .224 .23 r
F P
0 g
s
.66191 .43885 m .65317 .44062 L p .65471 .44004 L .528 .102 .176 r
F P
0 g
s
.63846 .44359 m .62497 .44547 L p .65471 .44004 L .528 .102 .176 r
F P
0 g
s
.63636 .44306 m .65471 .44004 L .62497 .44547 L .528 .102 .176 r
F
.65317 .44062 m .63846 .44359 L p .65471 .44004 L F P
0 g
s
.62497 .44547 m .60392 .44841 L p .63636 .44306 L .528 .102 .176 r
F P
0 g
s
.60392 .44841 m .62773 .45538 L .66191 .43885 L p .528 .102 .176 r
F P
0 g
s
.68497 .42145 m .66191 .43885 L .65181 .44374 L p .29 0 .037 r
F P
0 g
s
.65181 .44374 m .62773 .45538 L p .66257 .43473 L .29 0 .037 r
F P
0 g
s
.66257 .43473 m .68497 .42145 L .65181 .44374 L .29 0 .037 r
F
.66608 .43676 m .68497 .42145 L p .65528 .43905 L F P
0 g
s
.62773 .45538 m .65142 .44865 L .66608 .43676 L p .29 0 .037 r
F P
0 g
s
.62773 .45538 m .66608 .43676 L .65528 .43905 L .29 0 .037 r
F
.70739 .39211 m .68497 .42145 L .65142 .44865 L p 0 0 0 r
F P
0 g
s
.67468 .42785 m .68744 .41391 L p .66309 .43686 L 0 0 0 r
F P
0 g
s
.68744 .41391 m .70739 .39211 L p .67795 .42185 L 0 0 0 r
F P
0 g
s
.66309 .43686 m .68744 .41391 L .67795 .42185 L 0 0 0 r
F
.65142 .44865 m .6657 .43587 L p .66309 .43686 L F P
0 g
s
.6657 .43587 m .67468 .42785 L p .66309 .43686 L 0 0 0 r
F P
0 g
s
.67468 .42785 m .68435 .41331 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.68435 .41331 m .69722 .39396 L p .68662 .41138 L .798 .941 .587 r
F P
0 g
s
.70739 .39211 m .71004 .38867 L p .69126 .41323 L .568 .814 .435 r
F P
0 g
s
.71004 .38867 m .73862 .35143 L p .70767 .39182 L .568 .814 .435 r
F P
0 g
s
.69126 .41323 m .71004 .38867 L .70767 .39182 L .568 .814 .435 r
F
.68497 .42145 m .68951 .41551 L p .69126 .41323 L F P
0 g
s
.68951 .41551 m .70739 .39211 L p .69126 .41323 L .568 .814 .435 r
F P
0 g
s
.72579 .36999 m .71321 .38477 L p .71916 .37885 L 0 0 0 r
F P
0 g
s
.70828 .39117 m .71916 .37885 L .71321 .38477 L 0 0 0 r
F
.72133 .37803 m .71688 .38334 L p .71977 .37976 L .905 .981 .713 r
F P
0 g
s
.71977 .37976 m .76921 .3185 L .72133 .37803 L .905 .981 .713 r
F
.21601 .34206 m .19524 .35926 L .16096 .35965 L p .765 .856 .918 r
F P
0 g
s
.14091 .37059 m .16096 .35965 L .19524 .35926 L p .731 .807 .912 r
F P
0 g
s
.29987 .26617 m .27902 .28363 L .24364 .30055 L p .735 .991 .869 r
F P
0 g
s
.27902 .28363 m .25803 .30305 L .22274 .31677 L p .787 .985 .898 r
F P
0 g
s
.22274 .31677 m .24364 .30055 L .27902 .28363 L p .787 .985 .898 r
F P
0 g
s
.25803 .30305 m .23698 .32299 L .20194 .33249 L p .803 .954 .915 r
F P
0 g
s
.20194 .33249 m .22274 .31677 L .25803 .30305 L p .803 .954 .915 r
F P
0 g
s
.23698 .32299 m .21601 .34206 L .18133 .34687 L p .79 .91 .922 r
F P
0 g
s
.16096 .35965 m .18133 .34687 L .21601 .34206 L p .765 .856 .918 r
F P
0 g
s
.18133 .34687 m .20194 .33249 L .23698 .32299 L p .79 .91 .922 r
F P
0 g
s
.24364 .30055 m .26453 .28478 L .29987 .26617 L p .735 .991 .869 r
F P
0 g
s
.55757 .35683 m .53608 .33475 L .50366 .31308 L p .754 .276 .107 r
F P
0 g
s
.50366 .31308 m .52467 .33789 L .55757 .35683 L p .754 .276 .107 r
F P
0 g
s
.0875 .37322 m .107 .36539 L .14091 .37059 L p .672 .755 .914 r
F P
0 g
s
.107 .36539 m .0875 .37322 L .05358 .36696 L p .658 .756 .922 r
F P
0 g
s
.56848 .34664 m .59025 .363 L .62232 .35646 L p .642 .235 .258 r
F P
0 g
s
.59025 .363 m .56848 .34664 L .53608 .33475 L p .704 .271 .217 r
F P
0 g
s
.16096 .35965 m .14091 .37059 L .107 .36539 L p .686 .788 .928 r
F P
0 g
s
.6977 .34503 m .67553 .34402 L .64448 .36443 L p .528 .147 .263 r
F P
0 g
s
.62232 .35646 m .64448 .36443 L .67553 .34402 L p .561 .177 .271 r
F P
0 g
s
.53608 .33475 m .55757 .35683 L .59025 .363 L p .704 .271 .217 r
F P
0 g
s
.18133 .34687 m .16096 .35965 L .12673 .35686 L p .693 .849 .958 r
F P
0 g
s
.107 .36539 m .12673 .35686 L .16096 .35965 L p .686 .788 .928 r
F P
0 g
s
.6977 .34503 m .72003 .34373 L .75051 .32765 L p .38 0 .027 r
F P
0 g
s
.05358 .36696 m .07292 .35974 L .107 .36539 L p .658 .756 .922 r
F P
0 g
s
.12673 .35686 m .107 .36539 L .07292 .35974 L p .658 .778 .937 r
F P
0 g
s
.64448 .36443 m .62232 .35646 L .59025 .363 L p .622 .238 .294 r
F P
0 g
s
.20194 .33249 m .18133 .34687 L .14665 .34784 L p .703 .906 .967 r
F P
0 g
s
.12673 .35686 m .14665 .34784 L .18133 .34687 L p .693 .849 .958 r
F P
0 g
s
.51297 .33949 m .49192 .31018 L .45946 .28017 L p .741 .224 0 r
F P
0 g
s
.45946 .28017 m .47994 .30639 L .51297 .33949 L p .741 .224 0 r
F P
0 g
s
.22274 .31677 m .20194 .33249 L .16682 .33771 L p .69 .953 .953 r
F P
0 g
s
.14665 .34784 m .16682 .33771 L .20194 .33249 L p .703 .906 .967 r
F P
0 g
s
.07292 .35974 m .09242 .35246 L .12673 .35686 L p .658 .778 .937 r
F P
0 g
s
.14665 .34784 m .12673 .35686 L .09242 .35246 L p .656 .807 .956 r
F P
0 g
s
.72003 .34373 m .6977 .34503 L .66687 .36923 L p .469 .079 .217 r
F P
0 g
s
.64448 .36443 m .66687 .36923 L .6977 .34503 L p .528 .147 .263 r
F P
0 g
s
.24364 .30055 m .22274 .31677 L .18722 .32654 L p .621 .959 .887 r
F P
0 g
s
.16682 .33771 m .18722 .32654 L .22274 .31677 L p .69 .953 .953 r
F P
0 g
s
.26453 .28478 m .24364 .30055 L .20779 .31472 L p .501 .899 .766 r
F P
0 g
s
.18722 .32654 m .20779 .31472 L .24364 .30055 L p .621 .959 .887 r
F P
0 g
s
.28536 .27047 m .26453 .28478 L .22848 .30265 L p .362 .797 .627 r
F P
0 g
s
.20779 .31472 m .22848 .30265 L .26453 .28478 L p .501 .899 .766 r
F P
0 g
s
.54631 .36596 m .52467 .33789 L .49192 .31018 L p .789 .311 .093 r
F P
0 g
s
.49192 .31018 m .51297 .33949 L .54631 .36596 L p .789 .311 .093 r
F P
0 g
s
.16682 .33771 m .14665 .34784 L .11206 .34513 L p .643 .854 .98 r
F P
0 g
s
.09242 .35246 m .11206 .34513 L .14665 .34784 L p .656 .807 .956 r
F P
0 g
s
.59025 .363 m .61249 .37838 L .64448 .36443 L p .622 .238 .294 r
F P
0 g
s
.61249 .37838 m .59025 .363 L .55757 .35683 L p .685 .284 .281 r
F P
0 g
s
.30608 .25866 m .28536 .27047 L .24925 .29081 L p 0 0 0 r
F P
0 g
s
.24925 .29081 m .22848 .30265 L .19222 .31521 L p 0 0 0 r
F P
0 g
s
.19222 .31521 m .21266 .30758 L .24925 .29081 L p 0 0 0 r
F P
0 g
s
.24925 .29081 m .21266 .30758 L p .26031 .28446 L .003 0 0 r
F P
0 g
s
.24925 .29081 m .28536 .27047 L p .23828 .2971 L .362 .797 .627 r
F P
0 g
s
.24925 .29081 m .27005 .27973 L .30608 .25866 L p 0 0 0 r
F P
0 g
s
.27005 .27973 m .24925 .29081 L p .26031 .28446 L .003 0 0 r
F P
0 g
s
.22848 .30265 m .24925 .29081 L p .23828 .2971 L .362 .797 .627 r
F P
0 g
s
.66687 .36923 m .64448 .36443 L .61249 .37838 L p .59 .217 .303 r
F P
0 g
s
.18722 .32654 m .16682 .33771 L .13187 .33773 L p .597 .902 .985 r
F P
0 g
s
.11206 .34513 m .13187 .33773 L .16682 .33771 L p .643 .854 .98 r
F P
0 g
s
.74243 .33987 m .72003 .34373 L .68939 .36953 L p .354 0 .101 r
F P
0 g
s
.66687 .36923 m .68939 .36953 L .72003 .34373 L p .469 .079 .217 r
F P
0 g
s
.57964 .37974 m .55757 .35683 L .52467 .33789 L p .747 .314 .222 r
F P
0 g
s
.52467 .33789 m .54631 .36596 L .57964 .37974 L p .747 .314 .222 r
F P
0 g
s
.32668 .25018 m .30608 .25866 L .27005 .27973 L p 0 0 0 r
F P
0 g
s
.55757 .35683 m .57964 .37974 L .61249 .37838 L p .685 .284 .281 r
F P
0 g
s
.50101 .33778 m .47994 .30639 L .44723 .27452 L p .686 .178 0 r
F P
0 g
s
.44723 .27452 m .46773 .30071 L .50101 .33778 L p .686 .178 0 r
F P
0 g
s
.20779 .31472 m .18722 .32654 L .15182 .33028 L p .479 .894 .908 r
F P
0 g
s
.13187 .33773 m .15182 .33028 L .18722 .32654 L p .597 .902 .985 r
F P
0 g
s
.34719 .24566 m .32668 .25018 L .29088 .26996 L p 0 0 0 r
F P
0 g
s
.27005 .27973 m .29088 .26996 L .32668 .25018 L p 0 0 0 r
F P
0 g
s
.68939 .36953 m .71188 .36471 L .74243 .33987 L p .354 0 .101 r
F P
0 g
s
.22848 .30265 m .20779 .31472 L .17194 .32278 L p .292 .78 .715 r
F P
0 g
s
.15182 .33028 m .17194 .32278 L .20779 .31472 L p .479 .894 .908 r
F P
0 g
s
.68939 .36953 m .66687 .36923 L .6351 .39035 L p .541 .171 .288 r
F P
0 g
s
.61249 .37838 m .6351 .39035 L .66687 .36923 L p .59 .217 .303 r
F P
0 g
s
.53472 .3716 m .51297 .33949 L .47994 .30639 L p .803 .313 .016 r
F P
0 g
s
.47994 .30639 m .50101 .33778 L .53472 .3716 L p .803 .313 .016 r
F P
0 g
s
.17194 .32278 m .19222 .31521 L .22848 .30265 L p .292 .78 .715 r
F P
0 g
s
.6351 .39035 m .61249 .37838 L .57964 .37974 L p .654 .27 .306 r
F P
0 g
s
.36768 .2455 m .34719 .24566 L .31171 .26192 L p 0 0 0 r
F P
0 g
s
.29088 .26996 m .31171 .26192 L .34719 .24566 L p 0 0 0 r
F P
0 g
s
.56863 .39409 m .54631 .36596 L .51297 .33949 L p .783 .337 .189 r
F P
0 g
s
.51297 .33949 m .53472 .3716 L .56863 .39409 L p .783 .337 .189 r
F P
0 g
s
.29088 .26996 m .27005 .27973 L .23326 .29989 L p .059 0 0 r
F P
0 g
s
.21266 .30758 m .23326 .29989 L .27005 .27973 L p .003 0 0 r
F P
0 g
s
.71188 .36471 m .68939 .36953 L .65792 .39667 L p .459 .083 .237 r
F P
0 g
s
.6351 .39035 m .65792 .39667 L .68939 .36953 L p .541 .171 .288 r
F P
0 g
s
.57964 .37974 m .60226 .40032 L .6351 .39035 L p .654 .27 .306 r
F P
0 g
s
.60226 .40032 m .57964 .37974 L .54631 .36596 L p .721 .313 .273 r
F P
0 g
s
.54631 .36596 m .56863 .39409 L .60226 .40032 L p .721 .313 .273 r
F P
0 g
s
.38825 .24956 m .36768 .2455 L .33257 .25595 L p .281 .779 .874 r
F P
0 g
s
.31171 .26192 m .33257 .25595 L .36768 .2455 L p 0 0 0 r
F P
0 g
s
.31171 .26192 m .29088 .26996 L .25403 .29213 L p .065 0 0 r
F P
0 g
s
.23326 .29989 m .25403 .29213 L .29088 .26996 L p .059 0 0 r
F P
0 g
s
.7784 .32209 m .80024 .30226 L .80996 .31637 L closepath p .819 .802 .835 r
F P
0 g
s
.5228 .37145 m .50101 .33778 L .46773 .30071 L p .76 .26 0 r
F P
0 g
s
.46773 .30071 m .48883 .33142 L .5228 .37145 L p .76 .26 0 r
F P
0 g
s
.65792 .39667 m .68077 .39566 L .71188 .36471 L p .459 .083 .237 r
F P
0 g
s
.65792 .39667 m .6351 .39035 L .60226 .40032 L p .61 .235 .308 r
F P
0 g
s
.33257 .25595 m .31171 .26192 L .27496 .28432 L p .014 0 0 r
F P
0 g
s
.25403 .29213 m .27496 .28432 L .31171 .26192 L p .065 0 0 r
F P
0 g
s
.45534 .29258 m .422 .26341 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.48883 .33142 m .45534 .29258 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.45924 .30192 m .45158 .29252 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.51063 .36381 m .50138 .35007 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.50138 .35007 m .48883 .33142 L p .48885 .33575 L 0 0 .439 r
F P
0 g
s
.48588 .32424 m .46403 .30268 L .46076 .29936 L p .261 .356 .772 r
F P
0 g
s
.45534 .29258 m .46356 .30315 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.45534 .29258 m .49911 .34894 L .50377 .35497 L 0 0 .439 r
F
.46122 .30014 m .45534 .29258 L p .4455 .28771 L 0 .178 .712 r
F P
0 g
s
.43007 .26822 m .45153 .28075 L .48588 .32424 L p .261 .356 .772 r
F P
0 g
s
.46076 .29936 m .43007 .26822 L p .45291 .29116 L .261 .356 .772 r
F P
0 g
s
.47648 .31975 m .49911 .34894 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.44277 .2817 m .47648 .31975 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.422 .26341 m .43741 .27698 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.43741 .27698 m .44277 .2817 L p .45924 .30192 L 0 .178 .712 r
F P
0 g
s
.422 .26341 m .39305 .25152 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.44277 .2817 m .42423 .26537 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.42423 .26537 m .422 .26341 L p .409 .26121 L .17 .468 .89 r
F P
0 g
s
.39305 .25152 m .38825 .24956 L p .40052 .25679 L .17 .468 .89 r
F P
0 g
s
.40052 .25679 m .44277 .2817 L .39305 .25152 L .17 .468 .89 r
F
.38825 .24956 m .40544 .25604 L p .42361 .2704 L F P
0 g
s
.40544 .25604 m .40901 .25739 L p .42361 .2704 L .17 .468 .89 r
F P
0 g
s
.33257 .25595 m .35349 .25223 L .38825 .24956 L p .281 .779 .874 r
F P
0 g
s
.40901 .25739 m .38825 .24956 L .35349 .25223 L p .404 .758 .994 r
F P
0 g
s
.37453 .25067 m .40901 .25739 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.35349 .25223 m .37134 .25091 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.37134 .25091 m .37453 .25067 L p .38786 .25542 L .404 .758 .994 r
F P
0 g
s
.40901 .25739 m .44277 .2817 L p .42906 .27362 L .17 .468 .89 r
F P
0 g
s
.42361 .2704 m .40901 .25739 L .42906 .27362 L .17 .468 .89 r
F
.46356 .30315 m .47648 .31975 L p .46389 .30359 L 0 0 .439 r
F P
0 g
s
.47648 .31975 m .46122 .30014 L p .45416 .29456 L 0 .178 .712 r
F P
0 g
s
.47648 .31975 m .44277 .2817 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.49911 .34894 m .51063 .36381 L p .50377 .35497 L 0 0 .439 r
F P
0 g
s
.51063 .36381 m .47648 .31975 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.53319 .39447 m .53249 .39353 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.53249 .39353 m .51063 .36381 L p .53113 .39176 L 0 0 .461 r
F P
0 g
s
.47648 .31975 m .4983 .34804 L .53319 .39447 L p 0 0 .461 r
F P
0 g
s
.4983 .34804 m .48452 .33017 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.48452 .33017 m .47648 .31975 L p .46967 .31384 L 0 .162 .701 r
F P
0 g
s
.46403 .30268 m .4983 .34804 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.44277 .2817 m .45726 .29599 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.45726 .29599 m .46403 .30268 L p .48688 .3344 L 0 .162 .701 r
F P
0 g
s
.45976 .29847 m .44277 .2817 L .43834 .27851 L p .206 .391 .825 r
F P
0 g
s
.43834 .27851 m .40901 .25739 L p .43149 .27559 L .206 .391 .825 r
F P
0 g
s
.46403 .30268 m .45976 .29847 L p .40901 .25739 L .206 .391 .825 r
F P
0 g
s
.43149 .27559 m .45976 .29847 L .44346 .28328 L .206 .391 .825 r
F
.43149 .27559 m .44346 .28328 L .43834 .27851 L F
.40901 .25739 m .42657 .26643 L p .44438 .28602 L F P
0 g
s
.42657 .26643 m .43007 .26822 L p .44438 .28602 L .206 .391 .825 r
F P
0 g
s
.40901 .25739 m .46034 .29893 L .45953 .29836 L .206 .391 .825 r
F
.40901 .25739 m .46076 .29936 L .46209 .30108 L F
.43007 .26822 m .40901 .25739 L .37453 .25067 L p .457 .629 .927 r
F P
0 g
s
.39575 .251 m .43007 .26822 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.37453 .25067 m .3932 .25096 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.3932 .25096 m .39575 .251 L p .41036 .262 L .457 .629 .927 r
F P
0 g
s
.43007 .26822 m .46034 .29893 L p .44438 .28602 L .206 .391 .825 r
F P
0 g
s
.46034 .29893 m .46076 .29936 L p .45953 .29836 L .206 .391 .825 r
F P
0 g
s
.43007 .26822 m .39575 .251 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.45153 .28075 m .43117 .26887 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.43117 .26887 m .43007 .26822 L p .41451 .26101 L .471 .522 .829 r
F P
0 g
s
.39575 .251 m .41522 .25263 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.41522 .25263 m .41722 .2528 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.37453 .25067 m .35349 .25223 L .31734 .2685 L p .402 .857 .835 r
F P
0 g
s
.31734 .2685 m .3388 .26049 L .37453 .25067 L p .402 .857 .835 r
F P
0 g
s
.39575 .251 m .37453 .25067 L .3388 .26049 L p .626 .881 .988 r
F P
0 g
s
.3388 .26049 m .36043 .25242 L .39575 .251 L p .626 .881 .988 r
F P
0 g
s
.41722 .2528 m .39575 .251 L .36043 .25242 L p .656 .724 .899 r
F P
0 g
s
.38223 .24428 m .41722 .2528 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.36043 .25242 m .38046 .24494 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.38046 .24494 m .38223 .24428 L p .39682 .25266 L .656 .724 .899 r
F P
0 g
s
.41722 .2528 m .45153 .28075 L p .43315 .27095 L .471 .522 .829 r
F P
0 g
s
.45291 .29116 m .45981 .29807 L .4602 .2986 L .261 .356 .772 r
F
.45291 .29116 m .4602 .2986 L .46076 .29936 L F
.45981 .29807 m .48588 .32424 L .46076 .29936 L F
.46076 .29936 m .46403 .30268 L p .46209 .30108 L .206 .391 .825 r
F P
0 g
s
.80024 .30226 m .7784 .32209 L .7477 .34654 L p .893 .848 .792 r
F P
0 g
s
.76921 .3185 m .79038 .28793 L .80024 .30226 L closepath p .89 .81 .764 r
F P
0 g
s
.7477 .34654 m .76921 .3185 L .80024 .30226 L p .893 .848 .792 r
F P
0 g
s
.55718 .40303 m .53472 .3716 L .50101 .33778 L p .808 .337 .099 r
F P
0 g
s
.50101 .33778 m .5228 .37145 L .55718 .40303 L p .808 .337 .099 r
F P
0 g
s
.35349 .25223 m .33257 .25595 L .29607 .27644 L p 0 0 0 r
F P
0 g
s
.27496 .28432 m .29607 .27644 L .33257 .25595 L p .014 0 0 r
F P
0 g
s
.68077 .39566 m .65792 .39667 L .62528 .41557 L p .545 .173 .286 r
F P
0 g
s
.60226 .40032 m .62528 .41557 L .65792 .39667 L p .61 .235 .308 r
F P
0 g
s
.62528 .41557 m .60226 .40032 L .56863 .39409 L p .682 .287 .291 r
F P
0 g
s
.59154 .41862 m .56863 .39409 L .53472 .3716 L p .756 .328 .233 r
F P
0 g
s
.53472 .3716 m .55718 .40303 L .59154 .41862 L p .756 .328 .233 r
F P
0 g
s
.29607 .27644 m .31734 .2685 L .35349 .25223 L p 0 0 0 r
F P
0 g
s
.56863 .39409 m .59154 .41862 L .62528 .41557 L p .682 .287 .291 r
F P
0 g
s
.75975 .31387 m .78037 .27339 L .79038 .28793 L closepath p .926 .807 .708 r
F P
0 g
s
.79038 .28793 m .76921 .3185 L .73862 .35143 L p .936 .847 .73 r
F P
0 g
s
.73862 .35143 m .75975 .31387 L .79038 .28793 L p .936 .847 .73 r
F P
0 g
s
.62528 .41557 m .6485 .42278 L .68077 .39566 L p .545 .173 .286 r
F P
0 g
s
.54535 .40382 m .5228 .37145 L .48883 .33142 L p .78 .281 0 r
F P
0 g
s
.48883 .33142 m .51063 .36381 L .54535 .40382 L p .78 .281 0 r
F P
0 g
s
.71688 .38334 m .73862 .35143 L .76921 .3185 L p .905 .981 .713 r
F P
0 g
s
.74995 .30732 m .77021 .25863 L .78037 .27339 L closepath p .945 .801 .67 r
F P
0 g
s
.78037 .27339 m .75975 .31387 L .72904 .35291 L p .957 .84 .687 r
F P
0 g
s
.72904 .35291 m .74995 .30732 L .78037 .27339 L p .957 .84 .687 r
F P
0 g
s
.6485 .42278 m .62528 .41557 L .59154 .41862 L p .628 .238 .287 r
F P
0 g
s
.58031 .42986 m .55718 .40303 L .5228 .37145 L p .788 .322 .133 r
F P
0 g
s
.5228 .37145 m .54535 .40382 L .58031 .42986 L p .788 .322 .133 r
F P
0 g
s
.59154 .41862 m .6149 .43615 L .6485 .42278 L p .628 .238 .287 r
F P
0 g
s
.6149 .43615 m .59154 .41862 L .55718 .40303 L p .713 .291 .244 r
F P
0 g
s
.75975 .31387 m .73862 .35143 L .70739 .39211 L p .952 .953 .679 r
F P
0 g
s
.70739 .39211 m .72904 .35291 L .75975 .31387 L p .952 .953 .679 r
F P
0 g
s
.55718 .40303 m .58031 .42986 L .6149 .43615 L p .713 .291 .244 r
F P
0 g
s
.73976 .29809 m .75989 .24365 L .77021 .25863 L closepath p .954 .796 .648 r
F P
0 g
s
.77021 .25863 m .74995 .30732 L .71891 .3494 L p .967 .834 .66 r
F P
0 g
s
.71891 .3494 m .73976 .29809 L .77021 .25863 L p .967 .834 .66 r
F P
0 g
s
.67166 .42003 m .6485 .42278 L .6149 .43615 L p .542 .154 .255 r
F P
0 g
s
.52082 .37437 m .4983 .34804 L .46403 .30268 L p 0 .192 .712 r
F P
0 g
s
.46403 .30268 m .48588 .32424 L .52082 .37437 L p 0 .192 .712 r
F P
0 g
s
.47346 .29346 m .45153 .28075 L .41722 .2528 L p .48 .459 .757 r
F P
0 g
s
.41722 .2528 m .43898 .25534 L .47346 .29346 L p .48 .459 .757 r
F P
0 g
s
.43898 .25534 m .41722 .2528 L .38223 .24428 L p .632 .598 .797 r
F P
0 g
s
.51063 .36381 m .53319 .39447 L .56858 .43091 L p .764 .254 0 r
F P
0 g
s
.56858 .43091 m .54535 .40382 L .52936 .38539 L p .764 .254 0 r
F P
0 g
s
.5371 .39446 m .56858 .43091 L .52936 .38539 L .764 .254 0 r
F
.54535 .40382 m .56858 .43091 L .60392 .44841 L p .742 .271 .127 r
F P
0 g
s
.60392 .44841 m .58031 .42986 L .54535 .40382 L p .742 .271 .127 r
F P
0 g
s
.62773 .45538 m .60392 .44841 L .59167 .44234 L p .656 .168 .081 r
F P
0 g
s
.59167 .44234 m .56858 .43091 L p .58328 .43699 L .656 .168 .081 r
F P
0 g
s
.58328 .43699 m .62773 .45538 L .59167 .44234 L .656 .168 .081 r
F
.56858 .43091 m .59232 .44901 L .62773 .45538 L p F P
0 g
s
.59232 .44901 m .56858 .43091 L .5519 .41374 L p .701 .163 0 r
F P
0 g
s
.5519 .41374 m .54189 .40343 L p .55829 .41825 L .701 .163 0 r
F P
0 g
s
.55829 .41825 m .59232 .44901 L .5519 .41374 L .701 .163 0 r
F
.53997 .40073 m .59232 .44901 L .54189 .40343 L F
.56358 .42547 m .59232 .44901 L p .57037 .42876 L F P
0 g
s
.55167 .41152 m .56165 .4232 L .57037 .42876 L .701 .163 0 r
F
.56165 .4232 m .56358 .42547 L .57037 .42876 L F
.54189 .40343 m .53319 .39447 L p .53997 .40073 L F P
0 g
s
.53319 .39447 m .55643 .41961 L .56358 .42547 L p .701 .163 0 r
F P
0 g
s
.53319 .39447 m .56358 .42547 L .55167 .41152 L .701 .163 0 r
F
.65142 .44865 m .62773 .45538 L .59232 .44901 L p .469 0 0 r
F P
0 g
s
.59232 .44901 m .6163 .45485 L .65142 .44865 L p .469 0 0 r
F P
0 g
s
.6163 .45485 m .59232 .44901 L .57518 .43496 L p .539 0 0 r
F P
0 g
s
.57518 .43496 m .55643 .41961 L p .56887 .42693 L .539 0 0 r
F P
0 g
s
.56887 .42693 m .58575 .43687 L .57518 .43496 L .539 0 0 r
F
.58575 .43687 m .6163 .45485 L .57551 .43513 L F
.58575 .43687 m .57551 .43513 L .57518 .43496 L F
.55643 .41961 m .5802 .43574 L .59153 .44174 L p F P
0 g
s
.59153 .44174 m .6163 .45485 L p .57907 .43293 L .539 0 0 r
F P
0 g
s
.55643 .41961 m .59153 .44174 L .57907 .43293 L .539 0 0 r
F
.5802 .43574 m .60423 .43985 L .61811 .44237 L p 0 .483 .716 r
F P
0 g
s
.67468 .42785 m .65142 .44865 L .63765 .45108 L p .018 0 0 r
F P
0 g
s
.63765 .45108 m .6163 .45485 L p .64905 .4397 L .018 0 0 r
F P
0 g
s
.64905 .4397 m .67468 .42785 L .63765 .45108 L .018 0 0 r
F
.6163 .45485 m .64017 .44637 L .67468 .42785 L p F P
0 g
s
.64017 .44637 m .6636 .42333 L .67848 .41034 L p .641 .924 .647 r
F P
0 g
s
.67848 .41034 m .69722 .39396 L p .66789 .4209 L .641 .924 .647 r
F P
0 g
s
.64017 .44637 m .67848 .41034 L .66789 .4209 L .641 .924 .647 r
F
.61811 .44237 m .64017 .44637 L p .6057 .44026 L 0 .483 .716 r
F P
0 g
s
.5802 .43574 m .61811 .44237 L .6057 .44026 L 0 .483 .716 r
F
.52082 .37437 m .54399 .39542 L .54502 .39656 L p 0 .153 .69 r
F P
0 g
s
.54502 .39656 m .5802 .43574 L p .55679 .41155 L 0 .153 .69 r
F P
0 g
s
.52082 .37437 m .54502 .39656 L .55679 .41155 L 0 .153 .69 r
F
.4983 .34804 m .52082 .37437 L .52534 .38012 L p 0 0 .545 r
F P
0 g
s
.52936 .38539 m .51063 .36381 L p .5371 .39446 L .764 .254 0 r
F P
0 g
s
.52534 .38012 m .55643 .41961 L p .53217 .38974 L 0 0 .545 r
F P
0 g
s
.4983 .34804 m .52534 .38012 L .53217 .38974 L 0 0 .545 r
F
.73862 .35143 m .71688 .38334 L .68497 .42145 L p .568 .814 .435 r
F P
0 g
s
.38223 .24428 m .40422 .23607 L .43898 .25534 L p .632 .598 .797 r
F P
0 g
s
.72918 .28553 m .74942 .22843 L .75989 .24365 L closepath p .957 .794 .638 r
F P
0 g
s
.75989 .24365 m .73976 .29809 L .70818 .3396 L p .97 .831 .65 r
F P
0 g
s
.70818 .3396 m .72918 .28553 L .75989 .24365 L p .97 .831 .65 r
F P
0 g
s
.50835 .3439 m .48588 .32424 L .45153 .28075 L p .319 .349 .736 r
F P
0 g
s
.45153 .28075 m .47346 .29346 L .50835 .3439 L p .319 .349 .736 r
F P
0 g
s
.74995 .30732 m .72904 .35291 L .69722 .39396 L p .974 .923 .668 r
F P
0 g
s
.69722 .39396 m .71891 .3494 L .74995 .30732 L p .974 .923 .668 r
F P
0 g
s
.46108 .25784 m .43898 .25534 L .40422 .23607 L p .609 .522 .731 r
F P
0 g
s
.40422 .23607 m .42639 .22779 L .46108 .25784 L p .609 .522 .731 r
F P
0 g
s
.55643 .41961 m .53319 .39447 L .4983 .34804 L p 0 0 .545 r
F P
0 g
s
.4959 .30462 m .47346 .29346 L .43898 .25534 L p .491 .426 .712 r
F P
0 g
s
.43898 .25534 m .46108 .25784 L .4959 .30462 L p .491 .426 .712 r
F P
0 g
s
.71818 .26928 m .73878 .21298 L .74942 .22843 L closepath p .956 .795 .642 r
F P
0 g
s
.74942 .22843 m .72918 .28553 L .69686 .32271 L p .968 .83 .654 r
F P
0 g
s
.69686 .32271 m .71818 .26928 L .74942 .22843 L p .968 .83 .654 r
F P
0 g
s
.48354 .25941 m .46108 .25784 L .42639 .22779 L p .593 .476 .689 r
F P
0 g
s
.42639 .22779 m .44875 .21945 L .48354 .25941 L p .593 .476 .689 r
F P
0 g
s
.54399 .39542 m .52082 .37437 L .48588 .32424 L p .107 .254 .733 r
F P
0 g
s
.48588 .32424 m .50835 .3439 L .54399 .39542 L p .107 .254 .733 r
F P
0 g
s
.72904 .35291 m .70739 .39211 L .67468 .42785 L p .798 .941 .587 r
F P
0 g
s
.73976 .29809 m .71891 .3494 L .68633 .38688 L p .977 .893 .672 r
F P
0 g
s
.68633 .38688 m .70818 .3396 L .73976 .29809 L p .977 .893 .672 r
F P
0 g
s
.53141 .35901 m .50835 .3439 L .47346 .29346 L p .377 .361 .715 r
F P
0 g
s
.47346 .29346 m .4959 .30462 L .53141 .35901 L p .377 .361 .715 r
F P
0 g
s
.51883 .31244 m .4959 .30462 L .46108 .25784 L p .505 .413 .685 r
F P
0 g
s
.46108 .25784 m .48354 .25941 L .51883 .31244 L p .505 .413 .685 r
F P
0 g
s
.50635 .25918 m .48354 .25941 L .44875 .21945 L p .582 .449 .664 r
F P
0 g
s
.44875 .21945 m .47129 .21103 L .50635 .25918 L p .582 .449 .664 r
F P
0 g
s
.70682 .24931 m .72798 .19729 L .73878 .21298 L closepath p .949 .799 .66 r
F P
0 g
s
.73878 .21298 m .71818 .26928 L .68502 .29869 L p .959 .832 .674 r
F P
0 g
s
.68502 .29869 m .70682 .24931 L .73878 .21298 L p .959 .832 .674 r
F P
0 g
s
.52947 .25637 m .50635 .25918 L .47129 .21103 L p .577 .434 .65 r
F P
0 g
s
.47129 .21103 m .49402 .20255 L .52947 .25637 L p .577 .434 .65 r
F P
0 g
s
.5802 .43574 m .55643 .41961 L .52082 .37437 L p 0 .153 .69 r
F P
0 g
s
.54217 .31535 m .51883 .31244 L .48354 .25941 L p .522 .412 .67 r
F P
0 g
s
.48354 .25941 m .50635 .25918 L .54217 .31535 L p .522 .412 .67 r
F P
0 g
s
.72918 .28553 m .70818 .3396 L .67473 .36967 L p .965 .861 .686 r
F P
0 g
s
.67473 .36967 m .69686 .32271 L .72918 .28553 L p .965 .861 .686 r
F P
0 g
s
.55285 .25036 m .52947 .25637 L .49402 .20255 L p .574 .428 .645 r
F P
0 g
s
.49402 .20255 m .51695 .19399 L .55285 .25036 L p .574 .428 .645 r
F P
0 g
s
.71891 .3494 m .69722 .39396 L .6636 .42333 L p .929 .97 .699 r
F P
0 g
s
.6636 .42333 m .68633 .38688 L .71891 .3494 L p .929 .97 .699 r
F P
0 g
s
.55495 .36726 m .53141 .35901 L .4959 .30462 L p .436 .385 .704 r
F P
0 g
s
.4959 .30462 m .51883 .31244 L .55495 .36726 L p .436 .385 .704 r
F P
0 g
s
.56768 .40819 m .54399 .39542 L .50835 .3439 L p .253 .335 .754 r
F P
0 g
s
.50835 .3439 m .53141 .35901 L .56768 .40819 L p .253 .335 .754 r
F P
0 g
s
.69512 .22586 m .717 .18135 L .72798 .19729 L closepath p .933 .805 .695 r
F P
0 g
s
.72798 .19729 m .70682 .24931 L .67275 .26806 L p .941 .836 .711 r
F P
0 g
s
.67275 .26806 m .69512 .22586 L .72798 .19729 L p .941 .836 .711 r
F P
0 g
s
.5764 .2408 m .55285 .25036 L .51695 .19399 L p .575 .43 .647 r
F P
0 g
s
.51695 .19399 m .54007 .18536 L .5764 .2408 L p .575 .43 .647 r
F P
0 g
s
.56579 .31205 m .54217 .31535 L .50635 .25918 L p .542 .421 .664 r
F P
0 g
s
.50635 .25918 m .52947 .25637 L .56579 .31205 L p .542 .421 .664 r
F P
0 g
s
.71818 .26928 m .69686 .32271 L .66252 .34226 L p .938 .826 .707 r
F P
0 g
s
.66252 .34226 m .68502 .29869 L .71818 .26928 L p .938 .826 .707 r
F P
0 g
s
.69722 .39396 m .67468 .42785 L .64017 .44637 L p .641 .924 .647 r
F P
0 g
s
.60006 .22767 m .5764 .2408 L .54007 .18536 L p .58 .442 .658 r
F P
0 g
s
.54007 .18536 m .56339 .17666 L .60006 .22767 L p .58 .442 .658 r
F P
0 g
s
.70818 .3396 m .68633 .38688 L .65178 .4063 L p .948 .912 .749 r
F P
0 g
s
.65178 .4063 m .67473 .36967 L .70818 .3396 L p .948 .912 .749 r
F P
0 g
s
.68316 .19943 m .70586 .16516 L .717 .18135 L closepath p .9 .81 .751 r
F P
0 g
s
.717 .18135 m .69512 .22586 L .66016 .23191 L p .903 .835 .769 r
F P
0 g
s
.66016 .23191 m .68316 .19943 L .717 .18135 L p .903 .835 .769 r
F P
0 g
s
.57879 .36664 m .55495 .36726 L .51883 .31244 L p .494 .419 .7 r
F P
0 g
s
.51883 .31244 m .54217 .31535 L .57879 .36664 L p .494 .419 .7 r
F P
0 g
s
.60423 .43985 m .5802 .43574 L .54399 .39542 L p .083 .382 .844 r
F P
0 g
s
.54399 .39542 m .56768 .40819 L .60423 .43985 L p .083 .382 .844 r
F P
0 g
s
.58955 .30178 m .56579 .31205 L .52947 .25637 L p .566 .439 .667 r
F P
0 g
s
.52947 .25637 m .55285 .25036 L .58955 .30178 L p .566 .439 .667 r
F P
0 g
s
.62374 .21124 m .60006 .22767 L .56339 .17666 L p .589 .466 .68 r
F P
0 g
s
.56339 .17666 m .5869 .16788 L .62374 .21124 L p .589 .466 .68 r
F P
0 g
s
.59166 .4101 m .56768 .40819 L .53141 .35901 L p .395 .422 .77 r
F P
0 g
s
.53141 .35901 m .55495 .36726 L .59166 .4101 L p .395 .422 .77 r
F P
0 g
s
.70682 .24931 m .68502 .29869 L .64985 .30544 L p .895 .784 .731 r
F P
0 g
s
.64985 .30544 m .67275 .26806 L .70682 .24931 L p .895 .784 .731 r
F P
0 g
s
.64739 .19202 m .62374 .21124 L .5869 .16788 L p .605 .51 .72 r
F P
0 g
s
.5869 .16788 m .61062 .15902 L .64739 .19202 L p .605 .51 .72 r
F P
0 g
s
.69686 .32271 m .67473 .36967 L .63934 .37663 L p .902 .821 .758 r
F P
0 g
s
.63934 .37663 m .66252 .34226 L .69686 .32271 L p .902 .821 .758 r
F P
0 g
s
.61329 .28455 m .58955 .30178 L .55285 .25036 L p .595 .468 .677 r
F P
0 g
s
.55285 .25036 m .5764 .2408 L .61329 .28455 L p .595 .468 .677 r
F P
0 g
s
.68633 .38688 m .6636 .42333 L .62819 .43008 L p .871 .967 .856 r
F P
0 g
s
.62819 .43008 m .65178 .4063 L .68633 .38688 L p .871 .967 .856 r
F P
0 g
s
.69512 .22586 m .67275 .26806 L .63686 .26088 L p .831 .733 .756 r
F P
0 g
s
.63686 .26088 m .66016 .23191 L .69512 .22586 L p .831 .733 .756 r
F P
0 g
s
.67099 .1709 m .69453 .14871 L .70586 .16516 L closepath p .826 .803 .83 r
F P
0 g
s
.70586 .16516 m .68316 .19943 L .64739 .19202 L p .822 .817 .845 r
F P
0 g
s
.64739 .19202 m .67099 .1709 L .70586 .16516 L p .822 .817 .845 r
F P
0 g
s
.6027 .356 m .57879 .36664 L .54217 .31535 L p .554 .461 .704 r
F P
0 g
s
.54217 .31535 m .56579 .31205 L .6027 .356 L p .554 .461 .704 r
F P
0 g
s
.64017 .44637 m .6163 .45485 L .5802 .43574 L p 0 .483 .716 r
F P
0 g
s
.63686 .26088 m .61329 .28455 L .5764 .2408 L p .632 .511 .697 r
F P
0 g
s
.5764 .2408 m .60006 .22767 L .63686 .26088 L p .632 .511 .697 r
F P
0 g
s
.67099 .1709 m .64739 .19202 L .61062 .15902 L p .63 .592 .792 r
F P
0 g
s
.61062 .15902 m .63455 .15009 L .67099 .1709 L p .63 .592 .792 r
F P
0 g
s
.68502 .29869 m .66252 .34226 L .62645 .33533 L p .832 .729 .751 r
F P
0 g
s
.62645 .33533 m .64985 .30544 L .68502 .29869 L p .832 .729 .751 r
F P
0 g
s
.61564 .39959 m .59166 .4101 L .55495 .36726 L p .53 .509 .777 r
F P
0 g
s
.55495 .36726 m .57879 .36664 L .61564 .39959 L p .53 .509 .777 r
F P
0 g
s
.68316 .19943 m .66016 .23191 L .62374 .21124 L p .744 .67 .778 r
F P
0 g
s
.62374 .21124 m .64739 .19202 L .68316 .19943 L p .744 .67 .778 r
F P
0 g
s
.62819 .43008 m .60423 .43985 L .56768 .40819 L p .43 .607 .922 r
F P
0 g
s
.56768 .40819 m .59166 .4101 L .62819 .43008 L p .43 .607 .922 r
F P
0 g
s
.6636 .42333 m .64017 .44637 L .60423 .43985 L p .573 .924 .954 r
F P
0 g
s
.60423 .43985 m .62819 .43008 L .6636 .42333 L p .573 .924 .954 r
F P
0 g
s
.66016 .23191 m .63686 .26088 L .60006 .22767 L p .681 .574 .729 r
F P
0 g
s
.60006 .22767 m .62374 .21124 L .66016 .23191 L p .681 .574 .729 r
F P
0 g
s
.62645 .33533 m .6027 .356 L .56579 .31205 L p .617 .511 .711 r
F P
0 g
s
.56579 .31205 m .58955 .30178 L .62645 .33533 L p .617 .511 .711 r
F P
0 g
s
.67275 .26806 m .64985 .30544 L .61329 .28455 L p .756 .646 .74 r
F P
0 g
s
.61329 .28455 m .63686 .26088 L .67275 .26806 L p .756 .646 .74 r
F P
0 g
s
.67473 .36967 m .65178 .4063 L .61564 .39959 L p .828 .8 .824 r
F P
0 g
s
.61564 .39959 m .63934 .37663 L .67473 .36967 L p .828 .8 .824 r
F P
0 g
s
.69453 .14871 m .67099 .1709 L .63455 .15009 L p .658 .749 .917 r
F P
0 g
s
.63455 .15009 m .65868 .14108 L .69453 .14871 L p .658 .749 .917 r
F P
0 g
s
.65868 .14108 m .68302 .132 L .69453 .14871 L closepath p .658 .749 .917 r
F P
0 g
s
.64985 .30544 m .62645 .33533 L .58955 .30178 L p .684 .572 .723 r
F P
0 g
s
.58955 .30178 m .61329 .28455 L .64985 .30544 L p .684 .572 .723 r
F P
0 g
s
.63934 .37663 m .61564 .39959 L .57879 .36664 L p .649 .59 .775 r
F P
0 g
s
.57879 .36664 m .6027 .356 L .63934 .37663 L p .649 .59 .775 r
F P
0 g
s
.66252 .34226 m .63934 .37663 L .6027 .356 L p .749 .663 .766 r
F P
0 g
s
.6027 .356 m .62645 .33533 L .66252 .34226 L p .749 .663 .766 r
F P
0 g
s
.65178 .4063 m .62819 .43008 L .59166 .4101 L p .687 .741 .892 r
F P
0 g
s
.59166 .4101 m .61564 .39959 L .65178 .4063 L p .687 .741 .892 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(0)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(0.25)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0.5)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.75)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
gsave
.2956 .07454 -70.2509 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00k?ooool4o`000003oa0@4?oooooooooo07Gooooo003^ooooo`03o`00
0?oooooooooo07Oooooo003^ooooo`03o`000?oooooooooo07Oooooo003^ooooo`03o`000?oooooo
oooo07Oooooo003^ooooo`03o`000?oooooooooo07Oooooo003^ooooo`03o`000?oooooooooo07Oo
oooo003^ooooo`03o`000?oooooooooo07Oooooo003/ooooo`03oeEEEOmVIVKo000007Wooooo003o
ooooo`7ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Sooooo`00ooooool1ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0Hoooool00?oooooo0Oooool01Ol@413ooooooooooooooooo410@06?ooooo003h
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000006?ooooo003eooooo`?o000000?ooooo
o`000?ooool01Oooool01Ol0003ooooooooooooooooo000006?ooooo003cooooo`;o00001?ooool2
o`0000Gooooo00Go410@oooooooooooooooooa0@401Sooooo`00l?ooool3o`000003ooooool0003o
oooo00?ooooo00?o0000ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg06?ooooo003^
ooooo`;o00001Oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^06?ooooo003[ooooo`?o00002oooool2o`000003ooooool0003ooooo06[ooooo
003Xooooo`?o00003_ooool01Ol0003ooooooooooooooooo000006[ooooo003Vooooo`;o000000?o
ooooo`000?ooool03_ooool01Ol0003ooooooooooooooooo000006[ooooo003Sooooo`?o00004ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo003Qooooo`;o00005oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo003Nooooo`?o00006Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Kooooo002Pooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM01kooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool0
0:3ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07
ooooo`03ogMgMolb<S;ooooo01[ooooo0ol00002ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool3o`0006Kooooo001cooooo`;o00000_ooool2o`0002Oooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool05oooool2
o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`00Loooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgBOooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool05Oooool3o`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Sooooo`00M?ooool01?oMgMgo0000oa0@4?o<c<`Xooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05?ooool2o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Soooo
o`00M?ooool01?o^k^ko8B4Qoa0@4?o^k^hXooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo01?ooooo0ol00002ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`00M?ooool01?lQ
8B7oMgMgogMgMolb<S8Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool04?ooool3o`0002_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Qooooo`00Loooool2o`0000;ooooo0_l0000Wooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0000=ooooo`;o0000;_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo067ooooo0037ooooo`?o0000<?ooool00ol0003ooooooooo
o`08ooooo`;o0000HOooool00<Gooooo0_l00002ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01oooool00ol0003oooooo`00001Qooooo`00`_ooool3o`0003Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`1Oooooo`00`?ooool2o`0003Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Nooooo`00_Oooool3o`0003[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Mooooo`00^oooool2o`000003ooooool0003ooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Mooooo`00^?ooool3o`0000Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05cooooo002foooo
o`;o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05_ooooo002cooooo`?o
0000AOooool00ol0003oooooooooo`0;ooooo`?o0000G?ooool00;7ooooo0_l000000ooooooo0000
ooooo`15ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0F_ooool00:kooooo0ol0
001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool00:_ooooo0ol0001=
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0FOooool007Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0_l0
001@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0F?ooool007Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`?o000000?o
ooooo`000?ooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo001d
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Hooooo`;o0000EOoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Oooooo001dooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`?o0000Eoooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo05Kooooo001dooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l0001Jooooo`03o`000?oooooooooo013ooooo
0_l00009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0<Oooool007Cooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Cooooo0ol000000ooooooo0000ooooo`1Iooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0`ooooo`00M?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0005oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo02oooooo001dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo0ol0001Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`0`ooooo`00UOooool2o`0006Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool009;ooooo0ol000000ooooooo
0000ooooo`1Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0coooo
o`00Soooool3o`0006Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool0<oooool008gooooo0_l0001Xooooo`;o00000oooool00ol0003oooooooooo`0Coooo
o`?o00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co0000<_ooool008[ooooo0ol0001Wooooo`?o000000?oZ;oZo`000?ooool00_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo053ooooo0028ooooo`;o00000_ooool00ol0
003oooooooooo`1Rooooo`?o00001OnX_nX01?l0003oooooooooool0000Hooooo`03o`000?oooooo
oooo053ooooo0025ooooo`?o00001Oooool00ol0003oooooooooo`1Oooooo`Co00001onX_nX00ol0
003oooooo`00000Iooooo`03o`000?oooooooooo04oooooo0023ooooo`;o0000Ioooool3o`0000Co
Z;oZ1?l00003ojRojP03o`000?oooooo000001[ooooo00?o0000ooooooooool0C_ooool0083ooooo
0ol0001Vooooo`?o00002onX_nX6o`0001[ooooo00?o0000ooooooooool0C_ooool007kooooo0_l0
0003ooooo`03o`000?oooooooooo067ooooo0_l0000BojRojP;o00006oooool00ol0003ooooooooo
o`1=ooooo`00Noooool3o`0006Kooooo0ol00003oj6GbP;o00003_nX_nX00ol0003odlgDo`00000J
ooooo`?o0000C_ooool003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o0000Ioooool2o`0000SoXIO:00?o
0000ojRoj_nX_nX02_nX_nX00ol0003odlgDom?=e002o`0001_ooooo00?o0000ooooooooool0C?oo
ool003_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool07?ooool3o`0006Oooooo0_l0000;oj6GbP;o0000
2OnX_nX01ol0003odlgDom?=e?oCcMCo0000om?=e?l000006oooool00ol0003oooooooooo`1;oooo
o`00>oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0
003oooooooooo`0Hooooo`?o00000oooool00ol0003oooooooooo`1Qooooo`?o00000_nJP[P00ol0
003oXIO:oj6GbP0:oj6GbP;o00001_nX_nX00ol0003odlgDom?=e002om?=e003o`000?oCcMCo0000
01_ooooo00?o0000ooooooooool0Boooool003_ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool05oooool2o`0006Oooooo0ol00006oiZ2
^003o`000?nQUl[oXIO:00_oXIO:00?o0000ojRoj_nX_nX00_nX_nX00ol0003odlgDom?=e003om?=
e0Co00006oooool00ol0003oooooooooo`1:ooooo`00>oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0ol0001W
ooooo`;o00002_nJP[P00ol0003oXIO:oj6GbP0;oj6GbP;o000000?oZ;oZo`000?oCcM@01_l00002
om;Af003o`000?oooooooooo01[ooooo00?o0000ooooooooool0BOooool003_ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool2
o`0000;ooooo00?o0000ooooooooool0H_ooool3o`000003oiIg[_l0003oVX:h00[oVX:h00?o0000
oj6Gb_nQUlX03?nQUlX3o`0000God]7H00Go0000om;Af?l0003oi/o0o`00000Kooooo`03o`000?oo
oooooooo04Wooooo000kooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Cooooo00?o0000ooooooooool04_ooool3o`0006Kooooo0ol00005oiIg[P03o`00
0?nJP[SoVX:h00WoVX:h00?o0000oj6Gb_nQUlX02OnQUlX00ol0003od]7Hom;Af007om;Af0;o0000
0ooVcl000ol0003oooooooooo`0Hooooo`;o0000B_ooool003_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000oooooo0_l0001Vooooo`?o
00002OnFMjh00ol0003oVX:hoiZ2^009oiZ2^003o`000?nQUl[oXIO:00OoXIO:00?o0000om;Af?oB
dMP02?oBdMP2o`0000Coi/o000?o0000ooooooooool06Oooool00ol0003oooooooooo`17ooooo`00
I?ooool3o`0006Gooooo0ol00002oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P0
2OnJP[P00ol0003oXIO:oj6GbP05oj6GbP03o`000?oBdMSod]7H00Wod]7H0_l00004onK?`0;o0000
6_ooool00ol0003oooooooooo`17ooooo`00H_ooool2o`0000;ooooo00?o0000ooooooooool0H?oo
ool3o`0000KoU76X00?o0000oiIg[_nFMjh02?nFMjh00ol0003oVX:hoiZ2^009oiZ2^003o`000?nQ
Ul[oXIO:00?oXIO:00?o0000om;Af?oBdMP02OoBdMP00ol0003oi/o0o`000002onK?`0;o000000?o
imG4o`000?ooool06_ooool00ol0003oooooooooo`0Sooooo`?o000000?o410@ooooooooool07Ooo
ool005oooooo0ol0001Tooooo`?o000000?oTfjUo`000?nDLJP01onDLJP00ol0003oUWN^oiIg[P08
oiIg[P03o`000?nJP[SoVX:h00WoVX:h00Go0000oj6Gb_nQUl[oXIO:o`00000<om;Af003o`000?oV
cl3o000000;o00000_oWeL@00ol0003ok/jao`00000Kooooo`03o`000?oooooooooo02Cooooo00?o
410@okZj^_ooool07_ooool005gooooo0_l0001Tooooo`?o00001OnCKZD00ol0003oU76XoiAaZ006
oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P02OnJP[P00ol0003oXIO:o`00000<
om;Af004o`000?oVcl3oi/o0o`0000CoimG400Co0000onk>/Oo^c[7o00006_ooool00ol0003ooooo
ooooo`0Tooooo`03oiRHV?lb<S;ooooo01kooooo001Jooooo`Co0000Hoooool2o`0000WoTfjU00?o
0000oiAaZ?nDLJP01OnDLJP00ol0003oUWN^oiIg[P08oiIg[P03o`000?nJP[SoVX:h00WoVX:h1Ol0
000:om;Af0Co00000ooWeL@01Ol0003ok/jaonk>/Oo^c[7o000001_ooooo00?o0000ooooooooool0
8oooool00ooMgMgo0000okZj^P0Nooooo`00F?ooool2o`0000Cooooo00?o0000ooooooooool0GOoo
ool3o`000003oi9]YOl0003oTfjU00SoTfjU00?o0000oiAaZ?nDLJP01_nDLJP00ol0003oUWN^oiIg
[P08oiIg[P03o`000?nJP[SoVX:h00OoVX:h00?o0000okj[aonnZlL00onnZlL6o`0000?od]7H0_l0
0002onOEa005o`000?oWeLCoimG4onOEa?l000000oo^c[42o`0001Wooooo0ol0000Tooooo`03oeEE
EOmgMgOoA4A401kooooo001Eooooo`?o0000I?ooool2o`0000GoTVfU00?o0000oi=^YOnCKZD01onC
KZD00ol0003oU76XoiAaZ006oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P01OnJ
P[P00ol0003o_Z_7okj[a`0:okj[a`?o00001?oWeL@01?l0003oimG4onOEa?l00003onk>/@03o`00
0?o`e[Ko000001_ooooo00?o0000ooooooooool08Oooool01OoMgMgo410@oooooolQ8B7ogMgM01go
oooo001Booooo`?o0000IOooool2o`0000SoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76X
oiAaZ006oiAaZ003o`000?nFMjkoUWN^00SoUWN^00?o0000oiZ2^?nJP[P00onJP[P00ol0003o_Z_7
okj[a`0=okj[a`03o`000?oWeLCoimG400;oimG400Co0000onOEa?oWeLCo00000_o^c[401Ol0003o
l=Jfoo3F]_obc:So000001_ooooo00?o0000ooooooooool08?ooool01OmVIVKoQhN7oooooonHV9So
EEEE01gooooo001@ooooo`;o000000?oooooo`000?l00000H_ooool3o`000003oi=_Y_l0003oTVfU
00OoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76XoiAaZ006oiAaZ003o`000?nFMjkoUWN^
00WoUWN^00Go0000oiZ2^?nJP[SoVX:ho`00000?okj[a`03o`000?oWeLCoimG400?oimG400?o0000
onOEa?l000000_o^c[401?l0003ol=Jfoo3F]_l00002oo;<Z003o`000?oooooooooo01Wooooo00?o
0000ooooooooool07_ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01_ooooo001=
ooooo`?o0000IOooool2o`0000GoTfnV00?o0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07
oi=^Y@03o`000?nDLJSoU76X00KoU76X00?o0000oiIg[_nFMjh02OnFMjh00ol0003oVX:ho`00000?
okj[a`03o`000?oWeLCoimG400CoimG400Go0000onOEa?l0003ok/jao`000003oo3F]P05o`000?ob
c:Sol/bXoo;<Z?l000006_ooool00ol0003oooooooooo`0Nooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@ooooooooool06_ooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Qooooo`;o
0000IOooool3o`0000SoTfnV00?o0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03
o`000?nDLJSoU76X00KoU76X00?o0000oiIg[_nFMjh02?nFMjh3o`0000oo_Z_700?o0000onOEa?oW
eL@01?oWeL@2o`000003onk>/Ol0003ol=Jf00;ol=Jf00?o0000oo;<Z?obc:P00oobc:P00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo043ooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool3o`0006Cooooo0ol00002oiAbZ@03o`000?nCKjKoTfnV00KoTfnV00?o0000oi9]YOnB
KJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00OoU76X00?o0000oiIg[_nF
Mjh01_nFMjh01?l0003o[Y:jojjB^_n^T[X2o`0000co_Z_700?o0000onOEa?oWeL@01OoWeL@3o`00
00Col=Jf00?o0000oo;<Z?obc:P00oobc:P00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03oooooo000Uooooo`05oa0@4?ooooooooooooooool@41007?ooool2o`0000?ooooo00?o0000oooo
ooooool0G_ooool3o`0000KoU7:Y00?o0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@06oi9]
Y@03o`000?nCKZGoTfjU00OoTfjU00?o0000oiAaZ?nDLJP01_nDLJP00ol0003oUWN^oiIg[P04oiIg
[P;o00001_n^T[X2o`0000Wo_Z_700?o0000onOEa?oWeL@01_oWeL@2o`0000Gol=Jf00?o0000oo;<
Z?obc:P00_obc:P00ol0003om<^To`00000Iooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool002Gooooo00Go0000
ooooooooooooooooo`00000Iooooo`?o0000Hoooool3o`000003oiMi/?l0003oU7:Y00OoU7:Y00?o
0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@06oi9]Y@03o`000?nCKZGoTfjU00OoTfjU00?o
0000oiAaZ?nDLJP01_nDLJP01?l0003oUWN^oiIg[_nFMjh2o`0000[o[Y:j0_l00006okj[a`03o`00
0?oWeLCoimG400OoimG400?o0000oo3F]_o`e[H00oo`e[H00ol0003ol/bXoo;<Z002oo;<Z0;o0000
0_odbj@00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Rooooo`009Oooool01Ol0003ooooo
oooooooooooo000001Oooooo0_l0001Sooooo`?o00001OnGNK000ol0003oU7:YoiAbZ@06oiAbZ@03
o`000?nCKjKoTfnV00KoTfnV00?o0000oi9]YOnBKJD01OnBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03
o`000?nDLJSoU76X00OoU76X00?o0000oiIg[_l000003_n^T[X2o`0000Co_Z_700?o0000onOEa?oW
eL@00ooWeL@5o`0000Gol=Jf00Oo0000oo;<Z?obc:Sol/bXo`000?oee:co000000;om<^T00?o0000
ooooooooool06?ooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0Qooooo`009Oooool01Ol@413ooooooooooooooooo410@01Cooooo1?l0
001Rooooo`;o00002OnGNK000ol0003oU7:YoiAbZ@05oiAbZ@03o`000?nCKjKoTfnV00KoTfnV00?o
0000oi9]YOnBKJD01_nBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00KoU76X0_l0
000AojjB^P;o000000?o_Z_7o`000?oWeL@01Ol00003omBk`@;o00001Oo`e[H01_l0003ol/bXoo;<
Z?l0003omMB/o`0000Com<^T00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Rooooo`009Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg01;ooooo0_l00004ooooo`03o`000?oooooooooo05cooooo0ol00003oi^5
^`WoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP06oi=_YP03o`000?nBKJGoTVfU
00KoTVfU00?o0000oi=^YOnCKZD01onCKZD00ol0003oU76XoiAaZ003oiAaZ0;o00000onQP[800ol0
003o[Y:jojjB^P0?ojjB^P?o00001ooD^l401?l0003ol=Jfoo3F]_l00003oo3F]P04o`000?obc:So
l/bXo`0000;omMB/00?o0000ooC;Y?odbj@00_odbj@00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`08oooool002Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`?o0000Hoooool2o`0000Oo
VhFk00?o0000oiMi/?nGNK001_nGNK000ol0003oU7:YoiAbZ@05oiAbZ@03o`000?nCKjKoTfnV00Ko
TfnV00?o0000oi9]YOnBKJD01OnBKJD00ol0003oTfjUoi=^Y@07oi=^Y@03o`000?nDLJSoU76X00;o
U76X00?o0000oj62/_nQP[801?nQP[800ol0003o[Y:jojjB^P0>ojjB^P03o`000?oD^l7oe;_100Oo
e;_100Co0000oo3F]_o`e[Ko00000oo`e[H01_l0003ol/bXoo;<Z?l0003omMB/o`0000Com<^T0ol0
000Jooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo02Gooooo000fooooo`?o0000F?ooool8o`0000?ooooo0ol0000:oi^5^`03o`000?nG
NK3oUgV`00KoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP05oi=_YP03o`000?nB
KJGoTVfU00KoTVfU00?o0000oi=^YOnCKZD01onCKZD01?l0003oU76Xo`000?l00008oj62/P03o`00
0?n^T[[o[Y:j00co[Y:j00?o0000omBk`OoD^l401ooD^l401Ol0003ol=Jfoo3F]_o`e[Ko000000?o
l=Jf00?o0000oo;<Z?l000000_oee:`01?l0003om<^TooC;Y?odbj@2o`0000;om<^S00?o0000oooo
ooooool05_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo02Gooooo000dooooo`;o00000oooool00ol0003oooooooooo`1Aooooo`oo00001?nQVL`:oi^5
^`03o`000?nGNK3oUgV`00KoUgV`00?o0000oiAbZOnDLZT01?nDLZT00ol0003oTfnVoi=_YP06oi=_
YP03o`000?nBKJGoTVfU00KoTVfU00?o0000oi=^YOnCKZD01_nCKZD2o`0000_oXH:b00?o0000ojjB
^_n^T[X02_n^T[X00ol0003oe;_1omBk`@08omBk`@05o`000?o`e[Kol=Jfoo3F]_l000000_o`e[H0
0ol0003ol/bXo`000003ooGD[006o`000?odbjCom<^To`000?oge:Oo00000oodbj<00ol0003ooooo
ooooo`0Hooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000T
ooooo`00<Oooool3o`0005Gooooo1Ol000000om<bm_o0000o`000003o`0000?o<k?Y0_l00009oj6I
c003o`000?nKQK_oVhFk00KoVhFk0_l00006oiMi/003o`000?nDLZWoU7:Y00GoU7:Y00?o0000oi=_
Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@05oi9]Y@03o`000?nCKZGoTfjU00?oTfjU0ol000000onH
Mjgo0000oj62/P0;oj62/P03o`000?n^T[[o[Y:j00So[Y:j00?o0000omBk`OoD^l402?oD^l400ol0
003ol=Jfoo3F]P02oo3F]P03o`000?o`e[Kol=Jf00;o00000ooee:`01ol0003om<^TooC;Y?odbjCo
0000ooODYol000001?odbj<00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03[ooooo000_
ooooo`;o0000EOoooolBo`0000;oYkWV2_nQVL`00ol0003oVhFkoi^5^`06oi^5^`03o`000?nGNK3o
UgV`00CoUgV`00?o0000oiAbZOnDLZT01OnDLZT00ol0003oTfnVoi=_YP06oi=_YP03o`000?nBKJGo
TVfU00GoTVfU00?o0000oi=^YOl000000_l00005oiQg[@03o`000?nQP[;oXH:b00[oXH:b00?o0000
ojjB^_n^T[X01_n^T[X00ol0003oe;_1omBk`@09omBk`@03o`000?o`e[Kol=Jf00;ol=Jf00Co0000
oo3F]_o`e[Ko00001?oee:`01_l0003om<^TooC;Y?l0003ommBWo`0000Gom<^S00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0iooooo`00;?ooool5o`0005?ooooo3?l00002odO7g`?o0000
2OnW^NH00ol0003oXIW<oj6Ic004oj6Ic0;o00001onKQK/00ol0003oUgV`oiMi/004oiMi/003o`00
0?nDLZWoU7:Y00CoU7:Y00?o0000oi=_Y_nCKjH01_nCKjH00ol0003oTVfUoi9]Y@04oi9]Y@?o0000
2OnHMjd00ol0003oXH:boj62/P0:oj62/P03o`000?n^T[[o[Y:j00Go[Y:j00?o0000omBk`OoD^l40
2?oD^l400ol0003ol=Jfoo3F]P03oo3F]P?o00001Ooee:`00ol0003om<^To`000002ooODY`03o`00
0?odbj?om<^S00;om<^S00?o0000ooC;YOl000006_ooool00ol0003oooooooooo`0hooooo`00:ooo
ool2o`0000Cooooo00?o0000ooooooooool0C_ooool@o`0000ooYkWV0_l00004oj6Ic0;o00001_nK
QK/00ol0003oUgV`oiMi/004oiMi/003o`000?nDLZWoU7:Y00CoU7:Y00?o0000oi=_Y_nCKjH01_nC
KjH00ol0003oTVfUoi9]Y@03o`0000;oT72Z00?o0000oiQg[OnHMjd02?nHMjd00ol0003oXH:boj62
/P0:oj62/P03o`000?n^T[[o[Y:j00?o[Y:j00?o0000omBk`OoD^l402OoD^l400ol0003ol=Jfoo3F
]P02oo3F]P;o000000?oiLRko`000?oee:`00ooee:`00ol0003om<^To`000003ooODY`04o`000?od
bj?om<^SooC;X`;o00000_odbjD00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Sooooo
000[ooooo`?o0000D_ooool?o`0000WoX>7l0_mW`_h3ogBQk@OoN8GD0omjML400ol0003oXIW<o`00
0004o`0000;oVhFk00?o0000oiMi/?nGNK001?nGNK000ol0003oU7:YoiAbZ@04oiAbZ@03o`000?nC
KjKoTfnV00;oTfnV1_l00006oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o0000oj62/_nQP[802_nQ
P[801Ol0003o[Y:jojjB^_n^T[[o000000_oe;_100Co0000oo3F]_o`e[Kol=Jf0_l000000ooUb;_o
0000o`000005ooGD[0;o00000ooge:L01ol0003om<^SooC;Xoodbj?o0000ooSDY_l000000_odbjD0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Oooooo000[ooooo`04o`000?oooooooooo
o`0004oooooo3_l00006oj3Qo0Go00001_nXXm42ogBQk@KoN8GD1?mjML400ol0003oOFffoge]]P02
oge]]QGo00001?n:JjT00ol0003oT72Zoi1`ZP06oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o0000
oj62/_nQP[802_nQP[800ol0003o[Y:jo`00000<omBk`@04o`000?o`e[Kol=Jfo`0000?oiLRk0_l0
0004ooGD[003o`000?odbjCo000000?ommBW00Co0000ooC;Xoodbj?om<^S0_l00004ooC;Y@03o`00
0?oooooooooo01Kooooo00?o0000ooooool00000>?ooool002_ooooo00Go0000oooooooooooooooo
o`00001<ooooo`Ko000000?o0`00o`000?l000001Ol00002oj3Qo0Wob;O91OnkY/@00ol0003oZ:?A
ojRSd@03ojRSd@03ogBQkOmhQMCoN8GD00?oN8GD1?mjML400ol0003oOFffoge]]P04oge]]P03o`00
0?n1JJooPFV_00CoPFV_00?o0000ohEYZon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@06ohY[Z@03o`00
0?n@L:[oT72Z00GoT72Z00?o0000oiQg[OnHMjd02OnHMjd00ol0003oXH:boj62/P0:oj62/PCo0000
2OoD^l401?l0003ol=Jfo`000?l00004onG8^`03o`000?oee:comMB/00?omMB/0_l00004ooODY`06
o`000?odbj?om<^So`000?ohe:Ko00001?odbjD00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03Kooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Aoooool5o`00
00;o0`001_l00002omG=dP03o`000?o8]lWob;O900Oob;O900?o0000ok^Va?nkY/@02OnkY/@2o`00
00;o:gOS00GoM:7]ogR5e?mhQMCoN8GDo`000003ogYe`@03o`000?mmKKKoOFff00CoOFff00?o0000
oh5Y[on1JJl01?n1JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00KoRV^Y00?o0000
oi1`Z_n@L:X01On@L:X00ol0003oV7N]oiQg[@08oiQg[@03o`000?nQP[;oXH:b00WoXH:b00?o0000
ol6U_Oo1YKd00_o1YKd6o`0000?oe;_10_l00006onG8^`03o`000?oee:comMB/00?omMB/00?o0000
ooODYooge:L00_oge:L01_l0003om<^SooC;Xol0003on=BVo`0000Com<^U00?o0000oo7=Zol00000
6_ooool00ol0003oooooooooo`0eooooo`00:_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04Gooooo1Ol000000ol3003o0000o`000003o`0000CoeLgB00?o0000olRgbOo8]lT01oo8
]lT00ol0003o^jK4ok^Va009ok^Va0;o00000on^Vl@00ol[Mn?o=6CCo`000003ogR5e0?oNWG100?o
0000oge]]_mmKKH01?mmKKH00ol0003oPFV_oh5Y[`04oh5Y[`03o`000?n5JJ_oQFV[00CoQFV[00?o
0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP06oi1`ZP03o`000?nHMjgoV7N]00SoV7N]00?o
0000oj62/_nQP[801onQP[800ol0003o`JFmol6U_@09ol6U_@?o00002?oUb;/00ol0003omMB/ooGD
[002ooGD[003o`000?oge:OommBW00?ommBW00Ko0000ooC;Xoodbj?o0000ooSDY_l00003ooC;Y@;o
00000_oacJ/00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo000Zooooo`?o0000
1Oooool00ol0003oooooooooo`12ooooo`Go00000_l30003o`0000KoeLgB00?o0000olRgbOo8]lT0
1oo8]lT00ol0003o^jK4ok^Va009ok^Va003o`000?n^VlCo[Y_400Co[Y_400Co:gOSocATdoldI=?o
00000_mhQM@01?l0003oNWG1ogYe`Ol00006oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@06ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg
[OnHMjd02?nHMjd00ol0003oXH:boj62/P05oj62/P03o`000?o1YKgo`JFm00co`JFm00?o0000onG8
^ooUb;/01OoUb;/2o`0000?omMB/0_l00005ooODY`03o`000?odbj?o000000;on=BV00Ko0000ooC;
YOodbjGo0000ooOEZ?l00002oo7=Z`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?oo
ool002[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0oooooo`Go00000_l30004
o`0000KoeLgB00?o0000olRgbOo8]lT00_o8]lT6o`0000;o^jK40ol00005ok^Va0;o00002On^Vl@2
ocATd`04o`000?mhQMCoN8GDo`0000;oNWG100?o0000oge]]_mmKKH00ommKKH00ol0003oPFV_oh5Y
[`04oh5Y[`03o`000?n5JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`
ZP06oi1`ZP03o`000?nHMjgoV7N]00WoV7N]00?o0000oj62/_nQP[800onQP[800ol0003o`JFmol6U
_@0<ol6U_@03o`000?oUb;_oiLRk00KoiLRk0_l00002ooGD[003o`000?o`dkCommBW00CommBW00?o
0000ooC;Xol000000_ohe:H01?l0003om<^UooC;YOodbjD2o`0000ColLf[00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0cooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03cooooo1_l000000ol3003o0000o`000002om[Yg`03o`000?oEcM;oeLgB00?oeLgB
1ol00004olje`P03o`000?o3Y[co`jJl00Co`jJl1Ol0000=ojjKa005ocATdol0003o0000ogR5e?l0
00000_mjML400ol0003oOFffoge]]P03oge]]P03o`000?n1JJooPFV_00CoPFV_00?o0000ohEYZon5
JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg[OnH
Mjd02OnHMjd01Ol0003oXH:boj62/_nQP[;o000000ko`JFm00?o0000onG8^ooUb;/01_oUb;/01ol0
003omMB/o`000?oee:co0000oo3C]?l000001Ooge:L2o`0000?on=BV00Ko0000ooC;YOodbjGo0000
ooOEZ?l00004oo7=Z`;o00006?ooool2o`0003Gooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03Wooooo2Ol00003om[Yg`04o`000?oEcM;oeLgBomG=dP?o000000?oel[=o`00
0?o>]L801oo>]L800ol0003o`jJlol>V_008ol>V_004o`000?njWK[o^YfjokZM^P?o00002On^Vl@0
1?ldI=?o0000o`000?m2FlD2o`000003ogYe`Ol0003oOFff00CoOFff00?o0000oh5Y[on1JJl00on1
JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00KoRV^Y00?o0000oi1`Z_n@L:X01_n@
L:X00ol0003oV7N]oiQg[@09oiQg[@03o`000?nQP[;o000000oo`JFm00?o0000onG8^ooUb;/01_oU
b;/01?l0003omMB/o`000?l00002oo3C]003o`000?oge:OommBW00?ommBW0_l00003ooSDYP03o`00
0?odbjGo000000;ommFX00Go0000oo7=ZooacJ_olLf[o`000002ong>]@03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0<_ooool000Oooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0=_ooool8o`0000Gof^WO00?o0000omG=d_l000000_l00003omO:c@03o`000?o>]L;oc[G200Ko
c[G200?o0000ol>V_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P05okZM^P?o00000on^Vl@3o`000004
oj6HboldI=?o0000od9Ka@;oDEVl0ol00005oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z00?o0000oiQg
[OnHMjd02OnHMjd3o`0000ko`JFm00?o0000onG8^ooUb;/01_oUb;/00ol0003omMB/ooGD[002o`00
0003oo3C]?l0003ommBW00CommBW0_l00003ooSDYP03o`000?odbjGo000000;ommFX00Co0000oo7=
ZooacJ_olLf[0_l00003ong>]@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool0
00oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0cooooo`?o000000?o3`00o`000?l000000_l00006
om[Yg`?o00001OoGb/d00ol0003oc[G2olje`P06olje`P03o`000?o3Y[co`jJl00So`jJl00?o0000
okZM^_njWKX02OnjWKX3o`0000GoXIS;00?o=6CCo`000?m2FlD00omAFK`2o`0000CoOFff00?o0000
oh5Y[on1JJl01?n1JJl00ol0003oQFV[ohEYZ`04ohEYZ`03o`000?n:JjWoRV^Y00GoRV^Y00?o0000
oi1`Z_n@L:X01_n@L:X00ol0003oV7N]oiQg[@07oiQg[@05o`000?n_T[Wo[i:iojnB^Ol000003?o1
YKd00ol0003oiLRkonG8^`07onG8^`07o`000?oee:co0000oo3C]?l0003ol=>do`000005ooODY`03
o`000?ohe:Kon=BV00;on=BV0_l00003ooOEZ003o`000?oacJ_olLf[00;o00001?o]c[D2o`0001So
oooo00?o0000ooooooooool0<Oooool000oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo033ooooo0ol000000ol?003o
0000o`000002o`000003olWliOoJjMoof^WO00?of^WO0_l00007omO:c@03o`000?o>]L;oc[G200Ko
c[G200?o0000ol>V_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P09okZM^P05o`000?ncV;_o/iRkok>H
^ol000001OnQV</00ol0;KKo0000od9Ka@03oe5I_0;o00001?mmKKH00ol0003oPFV_oh5Y[`03oh5Y
[`03o`000?n5JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP07oi1`
ZP03o`000?nHMjgoV7N]00GoV7N]00?o0000ojnB^On_T[T00on_T[T2o`0000[o`JFm00?o0000onG8
^ooUb;/01ooUb;/2o`0000;ol=>d0_l00006ooODY`07o`000?ohe:Kon=BVooSDY_l0003om<^Uo`00
0002ooOEZ006o`000?oacJ_olLf[o`000?odejoo00000oo]c[D00ol0003okmRjo`00000Iooooo`03
o`000?oooooooooo033ooooo000?ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;Oooool7o`0000;o
bOcU00Co0000om[YgooJjMoof^WO1?l00007omO:c@03o`000?o>]L;oc[G200Koc[G200?o0000ol>V
_?o3Y[`02?o3Y[`00ol0003o^YfjokZM^P09okZM^P03o`000?ncV;_o/iRk00Co/iRk0_l00003oj6H
b`03o`0]]_l0003o@U_500CoDEVl0_l00003oge]]P03o`000?n1JJooPFV_00?oPFV_00?o0000ohEY
Zon5JJ/01?n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[oT72Z00OoT72Z00?o0000oiQg
[OnHMjd00_nHMjd2o`0000So[i:i0_l00007ol6U_@03o`000?oUb;_oiLRk00OoiLRk0_l00003oo3C
]0;o00001Ooge:L00ol0003on=BVooSDYP02ooSDYP;o00000oogeJP01Ol0003olLf[o`000?odejoo
000000?okLje00Go0000onoH^_o_f;[ohlo3o`00000Iooooo`03o`000?oooooooooo02oooooo000?
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0:_ooool7o`0000?obOcU00?o0000om[Ygol000000_l0
0002om[Qg003o`000?oGb/goel[=00Goel[=00?o0000olje`_o>]L800oo>]L8?o`0000;o^Yfj00?o
0000okZM^_njWKX01_njWKX00ol0003o/iRkok>H^`07ok>H^`;o00000_nQV</2o`000004od9KaOmA
FKcoDEVloe5I_0;oH5bg0_l000000ommKKKo0000oh5Y[`04oh5Y[`03o`000?n5JJ_oQFV[00GoQFV[
00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP06oi1`ZP05o`000?nHMjgoV7N]oiQg[Ol0
00003?n_T[T00ol0003o`JFmol6U_@03ol6U_@03o`000?oUb;_oiLRk00SoiLRk00?o0000oo3C]?o`
dk@00_o`dk@2o`0000CommBW0_l00004ooSDYP03o`000?ogeJSommFX00;ommFX00Go0000oo7=Zol0
003om=N_o`000002ong>]@03o`000?o_f;[okmRj00?ohlo300?o0000ooooooooool05Oooool2o`00
037ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool3o`000003oh3Va?l0003o0000
00CobOcU0ol00004om[Qg003o`000?oGb/goel[=00Goel[=00?o0000olje`_l000001?l00003olnd
_`03o`000?o8Y[Sob:Jh00Sob:Jh00Co0000ol6M]?o1WKCo`Ifd1Ol00002okZM^P03o`000?ncV;_o
/iRk00[o/iRk0_l000001?l0;KKo02Vco`000?l00003oe5I_0?oH5bg0ol00005oh5Y[`03o`000?n5
JJ_oQFV[00CoQFV[00?o0000ohY[ZOn:JjT01On:JjT00ol0003oT72Zoi1`ZP07oi1`ZP03o`000?nH
Mjgo000000ko[i:i0_l00003ol6U_@03o`000?oUb;_oiLRk00CoiLRk1?l00005oo3C]003o`000?og
e:OommBW00;ommBW00?o0000ooOL[ol000000oohe:H00ol0003ommFXooOEZ002ooOEZ003o`000?oa
cJ_o000000;om=N_00?o0000ong>]Ol000000_o_f;X01Ol0003ohlo3on??`ooScl?o000001Wooooo
00?o0000ooooooooool0;_ooool002Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Uooooo`Ko00001?o9o>D2o`0000Kof^7L00?o0000omO:cOoGb/d00ooGb/d5o`0000OockBo00?o
0000olRV^?o8Y[P02?o8Y[P00ol0003o`Ifdol6M]007ol6M]0;o00003oncV;/00ol0003o02ffo`0Y
/`02o`0000?oDEVl1?mPG;L2o`0000GoPFV_00?o0000ohEYZon5JJ/01?n5JJ/00ol0003oRV^YohY[
Z@05ohY[Z@03o`000?n@L:[oT72Z00KoT72Z0_l0000AojnB^@04o`000?o1YKgo0000onG8^`Ko0000
0ooD^/000ol0003ol=>doo3C]003oo3C]007o`000?oge:OommBWooODYol0003ommb_o`000004ooSD
YP03o`000?ogeJSommFX00;ommFX0_l00002ooCG[`03o`000?o]c[Go000000;okmRj00?o0000on??
`ooScl<00_oScl<2o`0001Wooooo00?o0000ooooooooool0;Oooool002Sooooo0_l0000Cooooo`03
o`000?oooooooooo02;ooooo1Ol000000onNmN?o0000olWli@02olWli@?o00001_oJhM`00ol0003o
el[=omO:c@04o`0000;oeLG;00?o0000olnd_oo?];l01_o?];l00ol0003ob:JholRV^008olRV^003
o`000?o1WKCo`Ifd00So`Ifd00?o0000ok^H]?nkV;@00ol00009ok>H^`06o`000?n]V<;o[IS2ojfH
`_l0:K?o036f0_l00003oe5I_0GoH5bg0ol00002oh5Y[`03o`000?n5JJ_oQFV[00GoQFV[00?o0000
ohY[ZOn:JjT01?n:JjT00ol0003oT72Zoi1`ZP03oi1`ZP?o00000onMP[H00ol0003o[i:iojnB^@0>
ojnB^@?o00002?oD^/000ol0003ol=>doo3C]003oo3C]0;o00000_oge:L01?l0003ommb_ooOL[ol0
0003ooSDYP03o`000?ogeJSommFX00?ommFX00Co0000ooCG[oodejoom=N_0_l00002onoH^P04o`00
0?oScl?ohlo3on??``;o000000?odLgEo`000?ooool06?ooool00ol0003oooooooooo`0]ooooo`00
:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo1_l00002oikeh`03o`00
0?o9o>Go000000;o000000?ocOCZo`000?oJhM`01OoJhM`4o`0000GoeLG;00?o0000olnd_oo?];l0
1_o?];l00ol0003ob:JholRV^008olRV^003o`000?o1WKCo`Ifd00So`Ifd00?o0000ok^H]?nkV;@0
1?nkV;@2o`0000Go/iRk0_l00005ojfH`P04o`0Y/ol0<KKo0000o`0000;oDEVl00?o0000of1L]omP
G;L00_mPG;L3ofmR]0Co00001_n5JJ/00ol0003oRV^YohY[Z@05ohY[Z@03o`000?n@L:[o000000;o
00001onMP[H00ol0003o[i:iojnB^@0=ojnB^@03o`000?oD^/3oe;[000Soe;[000?o0000oo3C]?o`
dk@01Ol000001Ooge:Oo0000ooOL[oogg:oo000000?on=BV0_l00004ooOEZ004o`000?odejoom=N_
ooCG[`;o00000oo_f;X2on??``;o000000Goi=W:om7=eOoAcMGodLgEo`00000Iooooo`03o`000?oo
oooooooo02cooooo000Xooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool3
o`000004od[7]ol0003o0000o`0000?oW_GS0ol00003olgdjP03o`000?oJhMcof^7L00?of^7L0ol0
0007omG5b`03o`000?o?];oockBo00KockBo00?o0000olRV^?o8Y[P02?o8Y[P00ol0003o`Ifdol6M
]008ol6M]003o`000?nkV;Co^iRd00Oo^iRd0ol000000oncV;_o0000ojfH`P07ojfH`P03o`000?l0
<KKo000000?oDEVl00?o0000of1L]omPG;L00_mPG;L5ofmR]0Ko00000_n5JJ/00ol0003oRV^YohY[
Z@02ohY[Z@Co00002onMP[H00ol0003o[i:iojnB^@0;ojnB^@03o`000?oD^/3oe;[000Soe;[01?l0
0003oo3C]003o`000?oge:Oo000000?ommb_00Ko0000ooSDY_ohe:Ko0000oo[T[?l00004ooOEZ005
o`000?odejoom=N_ooCG[ol000000oo_f;X3o`0000;oi=W:1OoAcMD00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02_ooooo000Xooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05_ooool3o`000004od[7]ol0003o0000o`0000GoW_GS0_l00004olgdjP04o`000?oJhMcof^7L
om[Qg0?o000000?oe]WKo`000?oEaL/01_oEaL/00ol0003ockBoolnd_`07olnd_`03o`000?o8Y[So
b:Jh00Oob:Jh00?o0000ol6M]?o1WK@02?o1WK@00ol0003o^iRdok^H]00;ok^H]003o`000?n]V<;o
[IS200So[IS200?o0000o`0a]_l000000omAFK`00ol0003oH5bgof1L]`02of1L]`GoKf:d00?o0000
ogi[/omnJk<00_mnJk<7o`0000?oSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0003o[i:iojnB^@09
ojnB^@03o`000?oD^/3oe;[000Ooe;[00ol00005oo3C]007o`000?oge:Oo0000ooOL[ol0003ommb_
o`000003ooSDYP;o00001?ogeJP01Ol0003om=N_ooCG[oodejoo000000?okmRj0_l00003onCIbPKo
dLgE00?o0000ooooooooool05_ooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool0
02Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`?o000000?oB/Ngo`00
0?l000000_l00004oikeh`?o00001Oo=m>X00ol0003of^7Lo`000002o`0000?oe]WK00?o0000omG5
booEaL/01_oEaL/00ol0003ockBoolnd_`06olnd_`03o`000?o8Y[Sob:Jh00Oob:Jh00?o0000ol6M
]?o1WK@02?o1WK@00ol0003o^iRdok^H]00:ok^H]004o`000?ngU[Ko]iJfokNF]P?o00001_n]V<80
1?l0:K?o0000o`0a]_l00003oe5I_005o`000?mPG;OoH5bgof1L]ol000001Om_H[@00ol0003oOV^c
ogi[/`04ogi[/`03o`000?n=M[CoSGJd00GoSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0003o[i:i
ojnB^@08ojnB^@03o`000?oD^/3oe;[000Coe;[00ol000000ooD^/3o0000oo3C]005oo3C]0;o0000
0oogg:l2o`0000;on=BV00?o0000oo[T[?l000000oogeJP2o`0000?om=N_00Co0000onoH^_o_f;[o
00001?oTfLX3om7=e@Ko00006Oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`06oooo
o`00:?ooool00ol0003oooooooooo`0Gooooo`;o00004?ooool2o`000003od[7]ol0003o000000;o
N^CX00?o0000oikehonNmN<01?l000000on`lo?ocOCZolgdjP04olgdjP?o00001OoFfM/00ol0003o
eLG;omG5b`06omG5b`03o`000?o?];oockBo00KockBo00?o0000olRV^?o8Y[P00_o8Y[P;o`0000Go
`Ifd00?o0000ok^H]?nkV;@02_nkV;@00ol0003o]iJfokNF]P05okNF]P;o00001On]V<801?l0:K?o
0000o`0a]_l00002oe5I_003o`000?mPG;OoH5bg00;oH5bg00?o0000ofmR]?m_H[@00om_H[@00ol0
003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00GoSGJd00?o0000oif2]_nMP[H02_nMP[H00ol0
003o[i:iojnB^@06ojnB^@03o`000?oD^/3oe;[000;oe;[00ol00003omBj`003o`000?o`dkCol=>d
00Gol=>d00?o0000ooOL[oogg:l00_ogg:l2o`000005ooSDY_l0003on^B/oo[T[?l000000_ogeJP2
o`0000?om=N_00Go0000onoH^_o_f;[okmRjo`000002onCIbPGo00001?o?e=d00on_`^So0000oooo
o`0Iooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVY
ZOmEEEGooooo00Sooooo00?o0000ooooooooool01Oooool002Oooooo0_l0000Kooooo`03o`000?oo
oooooooo00_ooooo0ol00004og[Tj0Go00000_n`lo<2o`0000CocOCZ0ol00007omKIf`03o`000?oE
aL_oeLG;00KoeLG;00Co0000olnd_oo?];oockBo2ol00005olVV]@03o`000?o4W[7oa9ja00?oa9ja
1ol0000:ok^H]003o`000?ngU[Ko]iJf00So]iJf0ol000001?n]V<;o0000o`000?l0:K<2o`0a]P;o
000000?oDEVlo`000?mPG;L00omPG;L00ol0003oKf:dofmR]002ofmR]003o`000?mnJk?oOV^c00Go
OV^c00?o0000ohef]?n=M[@01On=M[@00ol0003oWH:foif2]P0:oif2]P03o`000?n_T[Wo[i:i00Co
[i:i00?o0000omBj`?oD^/000ol00006omBj`003o`000?o`dkCol=>d00?ol=>d0_l00005ooOL[`?o
00000_oji:`01?l0003ommFXooOEZ?ogeJP2o`0000;om=N_0_l00002onoH^P04o`000?oTfL[oi=W:
om7oaPKocmCM1On_`^P00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01_oo
ool002Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`?o000000?oN^CX
o`000?l000001Ol00005ok3cl`03o`000?o=m>[ocOCZ00Co000000?ob^S/o`000?oFfM/01ooFfM/0
0ol0003oeLG;omG5b`03omG5b`Oo00001Oo>/Kd00ol0003obJJeolVV]@07olVV]@03o`000?o4W[7o
a9ja00Soa9ja00?o0000ol2H[oo0V:l00ol00006ok^H]003o`000?ngU[Ko]iJf00co]iJf00Ko0000
oj^Oc?n[WlcoZio<o`0Y/ol0<KH2oa]1^`03o`000?mAFKco000000?oH5bg00?o0000ofmR]?m_H[@0
0om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00KoSGJd00?o0000oif2]_nMP[H0
2_nMP[H00ol0003o[i:iojnB^@02ojnB^@Co00002?oD^/000ol0003ol=>doo3C]002oo3C]0;o0000
00?oi];2o`000?ogg:l01?ogg:l3o`0000;on^B/00?o0000ooOEZ?ogeJP00_l00002ooCG[`;o0000
0_o_f;X01?l0003oi=W:onCIb_oAolH5oloDg@Go00000on_`^P00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`009oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo1ol00002oiSVo0;o00001on`lo<4o`0000Cob^S/00?o0000omKI
fooFfM/01_oFfM/00ol0003oeLG;omG5b`04o`0000;odL;;00?o0000olja_Oo>/Kd01_o>/Kd00ol0
003obJJeolVV]@07olVV]@03o`000?o4W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l01?o0V:l3o`00
00;o^iRd00?o0000okNF]_ngU[H02ongU[H01?l0003o]IVkokFI^oneVK/4o`000006o`0a]_lK@K_o
6d6ko`000?mAFKco00000omPG;L00ol0003oKf:dofmR]003ofmR]003o`000?mnJk?oOV^c00CoOV^c
00?o0000ohef]?n=M[@01_n=M[@00ol0003oWH:foif2]P0:oif2]P03o`000?n_T[Wo000000;o0000
2ooD^/000ol0003ol=>doo3C]002o`0000;oi];200?o0000ooOL[oogg:l00oogg:l01?l0003on=BV
o`000?oji:`2o`0000;ommFX00Ko0000ooW/Zol0003om=N_o`000?ocljd2onoH^P04o`000?oTfL[o
i=W:om7oaP?ocmCM00?o0000oj_5kOn[aNd01On[aNd5o`0001Wooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`09ooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000;o00001onH
i_`2o`0000?o/??c1ol00006ol[Xk003o`000?oFfM_oe]WK00Koe]WK1?l00005om72b`03o`000?o>
/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D01oo9Y[D00ol0003oa9jaolBN/@08olBN/@03o`000?o0
V:oo`9R_00So`9R_0_l0000<okNF]P;o00001oneVK/2o`000003o`0a]_lK@K_o6d6k00;o00001?mP
G;L00ol0003oKf:dofmR]002ofmR]003o`000?mnJk?oOV^c00GoOV^c00?o0000ohef]?n=M[@01_n=
M[@00ol0003oWH:foif2]P08oif2]P?o000000?o[i:io`000?oD^/002_oD^/001?l0003ol=>doo3C
]?l00004onKB`P03o`000?ogg:oommb_00?ommb_0_l00002oo[T[0;o000000commFXo`000?oik:_o
0000ooCG[ol0003olo>]o`000?o_f;[o0000onCIb_l00003oloDg@03oj[igOn[aNgoZlG]00?oZlG]
0_mfZ?43o`0000?oN:Sa00?o0000ooooooooool05Oooool3o`0000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`09oooo
o`009oooool00ol0003oooooooooo`0Looooo`?o000000?oV>Klo`000?l000001ol000000on`lo?o
0000o`000002o`0000?o/nOg00?o0000ol[Xk?o:j>`01_o:j>`00ol0003oe]WKomKIf`03omKIf`Go
00001ooA`//00ol0003oc[6molja_@06olja_@03o`000?o9Y[GobJJe00OobJJe00?o0000olBN/Oo4
W[402?o4W[400ol0003o`9R_ol2H[`0:ol2H[`03o`000?nmUZoo_IJ_00?o00001_ngU[H00ol0003o
]IVkokFI^`08okFI^`03o`0Y/ol0003o036f00?o6d6k00Go0000of1L]omPG;OoH5bgo`000005ofmR
]003o`000?mnJk?oOV^c00CoOV^c00?o0000ohef]?n=M[@01_n=M[@00ol0003oWH:foif2]P05oif2
]P?o00000_nMP[H5o`0000Soe;[000Co0000oo3C]?l0003o00001?oVd/800ol0003ommb_ooOL[`04
ooOL[`03o`000?oji:con^B/00;on^B/0_l00002ooW/Z`05o`000?odejoo0000o`000?o_f;X00_l0
00001OoAolKocmCMoloDgOnZnMgo000000;oQ8kE00?o0000oealfOmLO=T00_m0O^@4ogJXl@?o0000
00?oN:Sao`000?ooool06?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000Sooooo000Wooooo`03o`000?oooooooooo01Wooooo0ol00009ojCJ
nP;o00002?ncioL00ol0003ob^S/ol[Xk007ol[Xk003o`000?oFfM_o000000Co00000_o?dM/00ol0
003odL;;om72b`06om72b`03o`000?o>/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D02?o9Y[D00ol0
003oa9jaolBN/@07olBN/@03o`000?o0V:oo`9R_00[o`9R_00?o0000okfF[onmUZl01?nmUZl3o`00
00;o]iJf00?o0000okFI^oneVK/02_neVK/00ol0003o036fo`000003oa]1^`05o`000?mPG;OoH5bg
of1L]ol000001Om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00KoSGJd00Co0000
oif2]_nMP[KoWH:f0ol00004oif2]P03o`000?noZLCo_jW400?o_jW41Ol00003omBj`0;o00001_oV
d/800ol0003ommb_ooOL[`02ooOL[`;o00001?oji:`02?l0003ommFXo`000?oik:_o0000ooCG[ol0
003olo>]0_l000001?oWnkKodOo6oj[igOnZnMd3oi29b0?o000000KoQ8kEoealfOmLO=WoG7cIod1n
i?l>KMh2ocn3j0?oMZSa0ol0000Hooooo`03o`000?oooooooooo02Kooooo000Vooooo`;o00006Ooo
ool2o`0000_oY=[j00?o0000ok?WmoncioL01_ncioL2o`0000?ob^S/2Ol00006oloAf`03o`000?oA
`/_odL;;00KodL;;00?o0000olja_Oo>/Kd01oo>/Kd00ol0003obJJeolVV]@07olVV]@03o`000?o4
W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l02Oo0V:l00ol0003o_IJ_okfF[`08okfF[`;o00003_ne
VK/00ol0003o036fo`000003oa]1^`;o000000?oH5bgo`000?m_H[@01?m_H[@00ol0003oOV^cogi[
/`05ogi[/`03o`000?n=M[CoSGJd00KoSGJd0ol00006oif2]P03o`000?noZLCo_jW400Wo_jW40ol0
0007onKB`P03o`000?ogg:oommb_00;ommb_00?o0000oo;Y_ol000001?oji:`3o`000004ooW/Zol0
003o0000oo?c[@;o000000?oio^fom7oa_nZnMd01_n@RLP2og1md0?o00000_mLO=T01?lXHmKo5V;H
o`i]g_loPnP2o`0000;o=WoW00?oMZSao`000?ooool05oooool00ol0003oooooooooo`0Uooooo`00
9_ooool00ol0003oooooooooo`0Fooooo`;o00000_nTf_X4o`0000GoY=[j0_l00003ok?Wm`_o0000
1Oo3fn/9oloAf`03o`000?oA`/_odL;;00OodL;;00?o0000olja_Oo>/Kd01_o>/Kd00ol0003obJJe
olVV]@07olVV]@03o`000?o4W[7oa9ja00Soa9ja00?o0000ol2H[oo0V:l02Oo0V:l00ol0003o_IJ_
okfF[`0:okfF[`03o`000?nkUk;o000000;o00002OneVK/01?l0003o]j32o`000?l0<KH3oa]1^`;o
@5G100?o0000of1L]ol000001Om_H[@00ol0003oOV^cogi[/`04ogi[/`03o`000?n=M[CoSGJd00?o
SGJd0ol000000on=M[Co0000oif2]P04oif2]P;o00003_noZL@00ol0003oi];2onKB`P05onKB`P05
o`000?ogg:oommb_ooOL[ol000000_objKl5oo[T[003o`000?oik:_onNb[00;o000000Golo>]o`00
0?l0003oio^fom7oaP03ojF@_`KoT8W800Co0000og1md?m`OM3oL7g@0_l000001_mLO=Wo:6?FoaIR
f?l0003o5F?Hocn3j0;o000000?o=WoWo`000?ooool06?ooool00ol0003oooooooooo`0Tooooo`00
9_ooool00ol0003oooooooooo`0Cooooo`?o00002?nWc_@5o`000003ok?Wmol0003o000000;o0000
0onafOD00ol0003o`m_[ol?Kj`07ol?Kj`;o00002Oo?dM/00ol0003odL;;om72b`07om72b`03o`00
0?o>/Kgoc[6m00Koc[6m00?o0000olVV]Oo9Y[D00_o9Y[D;o`0000Goa9ja00?o0000ol2H[oo0V:l0
2_o0V:l00ol0003o_IJ_okfF[`09okfF[`03o`000?nkUk;o^iNb00?o^iNb0ol00005okFI^`06o`00
0?ngX<;o]j32okNP`_l0003o036f0olK@K/2od1E`@?o00001Om_H[@00ol0003oOV^cogi[/`04ogi[
/`03o`000?n=M[Co000000;o00001On=M[@01Ol0003oWH:foif2]_nMP[Ko000000oo_jW400?o0000
onKB`_oVd/801OoVd/801Ol0003ommb_ooOL[oogg:oo000000;ol^Vo00?o0000oo[T[?oji:`00_oj
i:`01?l0003onNb[ooW/Zooik:/2o`000004oo?c[Ol0003oio^fo`0000GoYI2o00?o0000oi29b?n@
RLP00on@RLP00ol0003oL7g@og1md002og1md0?o000000So:6?FoaIRf?lEHmSo5F?Hocn3j?l0003o
=WoWo`0001Sooooo0_l0000Uooooo`009_ooool00ol0003oooooooooo`0@ooooo`?o00003?nWc_@2
o`0000Wo/MWe00?o0000ol?Kjoo3fn/01oo3fn/00ol0003ocm7KoloAf`08oloAf`03o`000?oA`/_o
dL;;00OodL;;00Co0000olja_Oo>/Kgoc[6m2ol00005olVW]`03o`000?o5W:koaIb^00?oaIb^2?l0
0009ol2H[`03o`000?nmUZoo_IJ_00Wo_IJ_00?o0000ok^G/_nkUk801onkUk83o`000003okFI^ol0
003o]j3200?o]j320ol00003oa]1^`?o@5G100?o0000ofmR]?m_H[@00om_H[@00ol0003oOV^cogi[
/`03ogi[/`?o00002On=M[@00ol0003oWH:fo`00000?oknYa003o`000?oVd/;oi];200Koi];200Co
0000ooOL[oogg:oo00000_objKl00ol0003on^B/oo[T[003oo[T[004o`000?oik:_onNb[o`0000;o
lo>]00?o0000onOk]_l000002?nUT;l00ol0003oT8W8oi29b003oi29b006o`000?m`OM3oL7g@og1m
d?lmJMCo00000_lXHmH01?lFH]So0000o`000?loPnP3o`0001Oooooo0_l0000Uooooo`009_ooool0
0ol0003oooooooooo`0>ooooo`;o00001OnXanl5o`0000?oYlkd0_l0000:ok7Im@03o`000?o3fn_o
`m_[00Oo`m_[00?o0000oloAfoo?dM/02?o?dM/00ol0003odL;;om72b`02om72b`[o00001Oo;[[d0
0ol0003obJNgolVW]`07olVW]`03o`000?o5W:koaIb^00SoaIb^00Co0000ol:HZoo2V:_o`YR[1Ol0
0003ol2H[`03o`000?nmUZoo_IJ_00Wo_IJ_00?o0000ok^G/_nkUk802onkUk800ol0003o]j32okNP
`P04okNP`P?o00000_lK@K/01Ol0003o@5G1od1E`Om0EL7o000000GoKf:d00?o0000ogi[/ol00000
0_l00002ogi[/`03o`000?n=M[CoSGJd00OoSGJd0_l0000@oknYa003o`000?oVd/;oi];200Koi];2
00?o0000ooOL[ol000000oobjKl00ol0003on^B/oo[T[002oo[T[005o`000?oik:_onNb[ooW/Zol0
00000_ocljd00ol0003oio^fok:C^002o`0000SoYI2o00?o0000oi29b?n@RLP00_n@RLP01Ol0003o
L7g@og1md?m`OM3o?FWD00;o000000?o:6?Fo`000?lFH]P00_l000000oloPnSo0000ooooo`0Hoooo
o`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooooooo00cooooo0_l0000<ojS7k`?o
000000?o/MWeo`000?l000000ol00005ok7Im@03o`000?o3fn_o`m_[00;o`m_[5_l00005olZibP03
o`000?o;[[gobjjm00Kobjjm00?o0000olVW]oo9YkL01oo9YkL00ol0003oaIb^olFL[P08olFL[P03
o`000?o2V:_o`YR[00Oo`YR[1Ol0000:okfF[`03o`000?nkUk;o^iNb00[o^iNb00Co0000ok^J]_nk
V[Ko^iZf0ol00002okNP`P?o00000_lK@K/01?l0003o@5G1od1E`Om0EL42o`0000;oKf:d0ol00006
ogi[/`03o`000?n=M[CoSGJd00CoSGJd0_l00003ojJGaP;o00003?noZL@00ol0003oi];2onKB`P06
onKB`P03o`000?ogg:oo000000?ol^Vo00?o0000oo[T[?oji:`00_oji:`2o`0000;onNb[00Ko0000
oo?c[Oocljgo0000onOk]_l00003ok:C^0;o00001?nUT;l6o`0000;oT8W800Ko0000og1md?m`OM3o
L7g@o`000?lmJM@3o`000003o`18b?l0003o000000;o00006?ooool00ol0003oooooooooo`0Roooo
o`009Oooool3o`0000[ooooo0ol0000<ojS7k`?o00002?n_bNd5o`000003ol?Kjol0003o000000;o
00000onkc^T00ol0003oaLWMolG9g@08olG9g@03o`000?o:^L[ob[W:00Wob[W:00?o0000ol^^_Oo;
[[d01_o;[[d00ol0003obJNgolVW]`08olVW]`03o`000?o5W:koaIb^00SoaIb^00?o0000ol:HZoo2
V:/02Oo2V:/00ol0003o`IR]ol6H[@03o`0000Ko_IJ_00?o0000ok^G/_nkUk802_nkUk800ol0003o
^iZfok^J]P05ok^J]PKo00000_lK@K/00ol0003o@5G1od1E`@05o`000003ofmR]?l0003oOV^c00Go
OV^c00?o0000ohef]?n=M[@00_n=M[@2o`0000OoYYO600?o0000oknYa?noZL@02?noZL@00ol0003o
i];2onKB`P07onKB`P;o00001?objKl01?l0003on^B/oo[T[?oji:`2o`0000;onNb[0_l000000ooc
ljgo0000onOk]P02ok:C^003o`000?nbTkSo/Y>h00;o/Y>h1?l00005oiR8`003ogn0b_l0003o0000
00;o00000om`OM000ol0003o?FWDoceYe002o`000004o`18b?l0003o0000o`0001Wooooo00?o0000
ooooooooool08Oooool002Gooooo00?o0000ooooooooool01oooool3o`0000WoZ<7/1_l0000;ojo9
k@?o00002?nkc^T2o`0000[oaLWM00?o0000olZib_o:^LX02Oo:^LX00ol0003objjmol^^_@07ol^^
_@03o`000?o9YkOobJNg00OobJNg00?o0000olFL[_o5W:h02?o5W:h00ol0003o`YR[ol:HZ`09ol:H
Z`03o`000?o1V:go`IR]00Co`IR]0ol00002okfF[`03o`000?nkUk;o^iNb00[o^iNb00?o0000ok^J
]_nkV[H02OnkV[H3o`0000;o6d6k00?o0000od1E`Ol000000_l00003ofE/a@?o00001_mnJk<01?l0
003oSGJdo`000?l0000:ojJGaP;o00002?noZL@00ol0003oi];2onKB`P06onKB`P;o00001?objKl0
2?l0003on^B/oo[T[?oji:co0000ongh/_l0003onNb[0_l000000oocljgo0000o`000004ok:C^0?o
00000onXSKP8oiR8`0?oOh3:0ol00002og1md003o`000?lmJMCo?FWD00?o000000?o036go`000?l0
00006Oooool00ol0003oooooooooo`0Pooooo`006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01Oooool2o`0000coZ<7/0ol00005ojc1j@Go00000_n_bNd2o`0000[o
^lkY00?o0000olG9gOo5bMd02Oo5bMd00ol0003ob[W:olZibP09olZibP03o`000?o;[[gobjjm00Oo
bjjm00?o0000olVW]oo9YkL01oo9YkL00ol0003oaIb^olFL[P09olFL[P03o`000?o2V:_o`YR[00So
`YR[00?o0000ol6H[Oo1V:d02?o1V:d4o`0000[o^iNb00?o0000ok^J]_nkV[H02_nkV[H2o`000003
o`00Rol0003o000000;o00000om0EL400ol0003oIFc5ofE/a@03ofE/a@So00003_nVUlH2o`0000Go
_jW400?o0000onKB`_oVd/801ooVd/800ol0003ol^Vooo;Y_`03oo;Y_`06o`000?oji:con^B/o`00
0?o]n;;o00000_oik:/00oo<l9Ko0000oo?c[@02o`0000Co/Y>h00?o0000ojR=^?nXSKP01?nXSKP0
0ol0003oV8S0oiR8`005oiR8`003o`000?moP<[oOh3:00;oOh3:1?l00002oceYe0?o000000?o036g
o`000?l000006?ooool00ol0003oooooooooo`0Pooooo`006_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool02Oooool5o`0000?oZ<7/0_l0000=ojc1j@;o000000?o^lkY
o`000?l000000ol00005ok_>j@03o`000?o5bMgoaLWM00WoaLWM00?o0000olZib_o:^LX02Oo:^LX0
0ol0003objjmol^^_@07ol^^_@03o`000?o9YkOobJNg00SobJNg00?o0000olFL[_o5W:h02?o5W:h0
0ol0003o`YR[ol:HZ`09ol:HZ`03o`000?o1V:go`IR]00Wo`IR]00?o0000okjDZonnU:/00ol00006
ok^G/P03o`000?nkV[Ko^iZf00[o^iZf00?o0000okjN^Ol000000ol00002oa]1^`05o`000?m0EL7o
@5G1od1E`Ol000001?mUK<D00ol0003oQh;6ohN2aP06ohN2aP03o`000?nVUlKoYYO600coYYO600?o
0000oknYa?noZL@00_noZL@00ol0003oi];2onKB`P03onKB`PCo00001_objKl00ol0003on^B/o`00
0002ongh/P07o`000?oik:_o0000o`000?ocljgo0000onOk]P02o`000005ok:C^?l0003o0000ojR=
^?l000001onXSKP00ol0003oV8S0oiR8`004oiR8`003o`000?moP<[oOh3:00;oOh3:0_mCL]@2o`00
00;o?FWD00Co04c;o`000?l0003o036g0_l0000Fooooo`03o`000?oooooo0000027ooooo000Joooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0>ooooo`?o00003On/`NT2
o`0000So[lS/2ol00005olG9g@03o`000?o:^L[ob[W:00Wob[W:00?o0000ol^^_Oo;[[d02?o;[[d0
0ol0003obJNgolVW]`07olVW]`03o`000?o5W:koaIb^00SoaIb^00?o0000ol:HZoo2V:/02Oo2V:/0
0ol0003o`IR]ol6H[@09ol6H[@03o`000?nnU:_o_YB[00Co_YB[0ol00002ok^G/P03o`000?nkV[Ko
^iZf00[o^iZf0ol00002okjN^@05o`000?l008_o0000oa]1^ol000000om0EL400ol0003oIFc5ofE/
a@03ofE/a@03o`000?n7P/KoQh;600KoQh;600?o0000ojJGa_nVUlH03?nVUlH2o`000003oknYa?l0
003oi];200Go00000ooCc=800ol0003ol^Vooo;Y_`03oo;Y_`03o`000?oji:co000000;okORb00Oo
0000ooW/Zol0003o0000oo?c[Ol0003oio^f00?o^YJc0_l00003ojR=^003o`000?nXSKSoZ8fh00Go
Z8fh00?o0000oiR8`?nHR<001?nHR<000ol0003oOh3:ogn0bP02ogn0bP?oDg;D0_l000001_lmJMCo
04c;o`000?l0003o036go`0001Wooooo00?o0000ooooooooool07_ooool001[ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo01Cooooo1Ol00003ojc1j@;o00003?n_b>`0
0ol0003o^L3OokW0g`06okW0g`_o00001Oo:^LX00ol0003objjmol^^_@08ol^^_@03o`000?o9YkOo
bJNg00SobJNg00?o0000olFL[_o5W:h02?o5W:h00ol0003o`YR[ol:HZ`08ol:HZ`03o`000?o1V:go
`IR]00Wo`IR]00?o0000okjDZonnU:/02?nnU:/4o`0000So^iZf0ol00006okjN^@?o000000?o6d6k
o`000?m0EL400_m0EL400ol0003oIFc5ofE/a@03ofE/a@03o`000?n7P/KoQh;600KoQh;600?o0000
ojJGa_nVUlH03OnVUlH3o`0000OodlcB00?o0000oo;Y_oobjKl01?objKl2o`0000?okORb00?o0000
ooW/Zoo<l9H00ol00003okZF/`03o`000?ncT;;o/i2b00;o00000_nXSKP00ol0003oZ8fhojR=^005
ojR=^0;o00001OnHR<000ol0003oOh3:ogn0bP02ogn0bP03o`000?mCL]CoDg;D00;o000000Ko?FWD
o`1<bol0003o0000o`0a]ol0000Hooooo`03o`000?oooooooooo01kooooo000Jooooo`05o`000?oo
ooooooooooooool000001Oooool3o`0001[ooooo0ol0000<ojo8k0;o00002oni`=l00ol0003o_kWD
oknie006oknie1Go00001Oo9YkL00ol0003oaIb^olFL[P08olFL[P03o`000?o2V:_o`YR[00So`YR[
00?o0000ol6H[Oo1V:d02Oo1V:d00ol0003o_YB[okjDZ`0:okjDZ`03o`000?nnUJgo_YF]00?o0000
0_nkV[H3o`000003ok^J]_l0003o_Yji00Ko_Yji00Go001fo`000?l0003o6d6ko`000004od1E`@03
o`000?mUK<GoIFc500?oIFc500?o0000ohN2a_n7P/H01_n7P/H00ol0003oYYO6ojJGaP0:ojJGaP03
o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl00oobjKl2o`0000CokORb00Go0000olc`U_l0
003olo>]o`000003okZF/`03o`000?ncT;;o/i2b00?o/i2b0ol00009ojR=^003o`000?nHR<3oV8S0
00?oV8S000?o0000ogn0b_moP<X00_moP<X00ol0003oDg;Doe=be003o`000005o`1<bol0003o0000
o`0a]ol000006?ooool00ol0003oooooooooo`0Mooooo`006_ooool01Ol@413ooooooooooooooooo
410@00Gooooo00?o0000ooooooooool08?ooool5o`0000?o[lS/00?o0000okW0goni`=l02Oni`=l2
o`0000_o_kWD00?o0000olBicoo4^Ll02Oo4^Ll00ol0003o`jFlol>U_004ol>U_0_o00001Oo5W:h0
0ol0003o`YR[ol:HZ`08ol:HZ`03o`000?o1V:go`IR]00So`IR]00?o0000okjDZonnU:/02_nnU:/0
0ol0003o_YF]okjE[@03okjE[@Co00000_nkV[H00ol0003o_YjiokjN^@07okjN^@?o000000?o6d6k
o`000?m0EL400om0EL400ol0003oIFc5ofE/a@03ofE/a@03o`000?n7P/KoQh;600KoQh;60_l00009
ojJGaP03o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl01?objKl00ol0003okORbongh/P02
ongh/P;o000000?oc?2Fo`000?l000000onjU[<00ol0003o/i2bok>@/P06ok>@/P;o00001onXSKP7
o`000003oiR8`?l0003oOh3:00?oOh3:00Oo0000oe=be?mCL]Co0000oa5Id_l0003o04c;00;o0000
00?o036go`000?ooool05oooool00ol0003oooooooooo`0Looooo`006_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?o0000ooooooooool09Oooool3o`0000;o^L3O1?l00005okW0g`03o`00
0?no^MCo_kWD00Wo_kWD0_l0000;olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH0
1?o3XKH:o`0000Go`YR[00?o0000ol6H[Oo1V:d02Oo1V:d00ol0003o_YB[okjDZ`09okjDZ`04o`00
0?nnUJgo_YF]okjE[@?o00001?nnUJd5o`0000So_Yji0ol000000olK@K_o0000od1E`@02od1E`@03
o`000?mUK<GoIFc500CoIFc500?o0000ohN2a_n7P/H01on7P/H00ol0003oYYO6ojJGaP05ojJGaP03
o`000?oCc=;odlcB00WodlcB00?o0000oo;Y_oobjKl00oobjKl2o`0000GokORb00?o0000olc`U_l0
00000_l00002okZF/`03o`000?ncT;;o/i2b00Wo/i2b0_l00002ojR=^0?o00001?nORK`3oh^5aPGo
00000_moP<X01?l0003oDg;Doe=be?l00002oa5IdPCo00005oooool2o`0001kooooo000Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0^ooooo`Go00000_no^M@00ol0
003o_kWDoknie006oknie003o`000?o4^Looa;W?00[oa;W?00?o0000ol>U_?o3YK`02Oo3YK`00ol0
003o`j6fol>Q]P09ol>Q]P03o`000?o3XkSo`j>h00?o`j>h2?l00008ol6H[@03o`000?nnU:_o_YB[
00Wo_YB[00?o0000okjE[Ol000000_l00008okjE[@04o`000?noVk?o_i^coknK/`Go00000_nnW[T0
1_l0003o`JJmo`000?l0003o02N`o`0000Co@5G100?o0000ofE/aOmUK<D01?mUK<D00ol0003oQh;6
ohN2aP07ohN2aP03o`000?nVUlKoYYO600?oYYO600?o0000om?<d_oCc=802_oCc=800ol0003ol^Vo
oo;Y_`02oo;Y_`03o`000?oNmm_o000000CokORb00?o0000olc`U_o<l9H00_l00002okZF/`03o`00
0?ncT;;o/i2b00_o/i2b0ol00008oin9_003o`000?n;QLKoRhG600?oRhG600?oJ7gDo`000?l00000
0_l00002oe=be003o`000?lAFM;o4EWB00Co00006?ooool00ol0003oooooooooo`0Kooooo`009?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooo000000Co00000_no^M@00ol0003oa;W?olBi
c`0:olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH02Oo3XKH00ol0003o`j>hol>S
^008ol>S^004o`000?o0VJoo`9V_ol2I[`Go00000_o1V:d00ol0003o_YB[okjDZ`09okjDZ`?o0000
2_nnUJd00ol0003o_i^coknK/`07oknK/`Oo000000?o02N`o`000?m0EL400om0EL400ol0003oIFc5
ofE/a@03ofE/a@03o`000?n7P/KoQh;600SoQh;600Go0000ojJGa_nVUlKoYYO6o`00000<om?<dP04
o`000?objKool^Vooo;Y_`;o000000?og_OKo`000?o]n;801?o]n;801Ol0003oc?2Fo`000?l0003o
_iN^00;o00003OncT;82o`0000;o[8fe2OnORK`00ol0003oRhG6oh^5aP03oh^5aP?oJ7gD0ol00000
1OmCL]Co0000oa5Id_l0003o03o100?o00006?ooool00ol0003oooooooooo`0Jooooo`009?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo0_l000000oo4^Loo0000o`000009
olBic`03o`000?o3YKco`jFl00Wo`jFl00?o0000ol>Q]_o3XKH02Oo3XKH00ol0003o`j>hol>S^008
ol>S^003o`000?o0VJoo`9V_00Oo`9V_1?l00007okjDZ`Co00002onnUJd00ol0003o_i^coknK/`09
oknK/`04o`000?o1WK?o`Ifcol6M/`?o000000?o02N`o`000?l000000om0EL400ol0003oIFc5ofE/
a@03ofE/a@03o`000?n7P/KoQh;600SoQh;600?o0000ojJGa_l000003OoCc=801?l0003ol^Voo`00
0?l00003omkgf`04o`000?o]n;;okORbongh/P;o000000?oc?2Fo`000?l000000onoUjh00ol0003o
^Y>^o`000002o`0000So/i2b00Co0000ojb=]On/SKGo00000_n/SKD2o`0000OoWhVl00?o0000oh^5
a_n;QLH00on;QLH01?l0003oJ7gDofQme?mXOM@2o`000005oe=be?l0003o4EWBo`000?l0?l400_l0
000Hooooo`03o`000?oooooooooo01[ooooo000Sooooo`?o0000=oooool00ol0003oooooooooo`07
ooooo`Go00000oo4^Ll00ol0003o`jFlol>U_009ol>U_003o`000?o3XKKo`j6f00Wo`j6f00?o0000
ol>S^?o3XkP02?o3XkP00ol0003o`9V_ol2I[`09ol2I[`03o`000?noVK3o_iV`00?o000000Co_YB[
o`000?l0003o00000_nnU:/00ol0003o_YF]okjE[@09okjE[@03o`000?noVk?o_i^c00Wo_i^c00?o
0000ol6M/oo1WK<00oo1WK<4o`000005oaEQf?l0003o0000od1E`Ol000001_mUK<D00ol0003oQh;6
ohN2aP07ohN2aPCo00002ooCc=800ol0003ol^Voo`000004omkgf`06o`000?o]n;;okORbongh/_l0
003oY>bU0ol00003oknG[P03o`000?njTjko^Y>^00?o^Y>^0_l00005ok>@/P03o`000?n/SKGo[8fe
00;o[8fe00Go0000ojb=]On/SKGo[8feo`000007oin9_003o`000?n;QLKoRhG600?oRhG600Co0000
ofQme?mXOMCoJ7gD1?l000000olAFM;o0000o`0o`@02o`0001Sooooo00?o0000ooooooooool06Ooo
ool002?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`Ko00002?o3YK`0
0ol0003o`j6fol>Q]P09ol>Q]P03o`000?o3XkSo`j>h00So`j>h00?o0000ol2I[oo0VJl02Oo0VJl0
0ol0003o_iV`oknI/002oknI/0Go00000_nnU:/00ol0003o_YF]okjE[@0:okjE[@03o`000?noVk?o
_i^c00So_i^c00?o0000ol6M/oo1WK<01Oo1WK<2o`000004o`0W/?l0003o5F7HoaEQf0?o00001_mU
K<D00ol0003oQh;6ohN2aP04ohN2aP;o00001?n__N@4o`0000KodlcB0ol00004omkgf`06o`000?o]
n;;okORbongh/_l0003oY>bU1?l00002oknG[P03o`000?njTjko^Y>^00Ko^Y>^0ol000000oncT;;o
0000ojb=]@04ojb=]@03o`000?n/SKGo[8fe00;o[8fe00?o0000oin9_?nORK`01OnORK`00ol0003o
RhG6oh^5aP03oh^5aP06o`000?mXOMCoJ7gDofQme?l0003o;6cK0_l000001?lAFM;o0000o`0o`Ol0
000Hooooo`;o00002?ooool4o`000003oa0@4?oooooooooo00_ooooo000Sooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool04?ooool5o`0000;o`jFl00?o0000ol>Q]_o3XKH02Oo3XKH0
0ol0003o`j>hol>S^008ol>S^003o`000?o0VJoo`9V_00Wo`9V_00?o0000oknI/?noVK000ol00005
oknI/0Go00002OnnUJd00ol0003o_i^coknK/`08oknK/`03o`000?o1WK?o`Ifc00Oo`Ifc0_l00000
0ol09k3o0000oaEQf002oaEQf0;o00001_mUK<D00ol0003oQh;6ohN2aP02ohN2aP03o`000?n__NCo
[kgT00So[kgT1?l00002om?<dP03o`000?oNmm_og_OK00Cog_OK00Go0000ongh/_o]n;;o0000ojC/
Y@04o`0000;o_iN^00?o0000okZC[_njTjh02_njTjh2o`0000Ko[8fe00?o0000ojb=]On/SKD00_n/
SKD2o`0000KoWhVl00?o0000oh^5a_n;QLH00on;QLH01Ol0003oJ7gDofQme?mXOMCo000000;o;6cK
00Go0000oa5Id_l0003o03o1o`00000Fooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool03Oooool002?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Dooooo`So0000
1Oo3XKH00ol0003o`j>hol>S^009ol>S^003o`000?o0VJoo`9V_00Wo`9V_0ol00009oknI/004o`00
0?o0WkOo`9ngol2O]`Go00000onnUJd00ol0003o_i^coknK/`09oknK/`03o`000?o1WK?o`Ifc00So
`Ifc0_l000000ol09k3o0000oaEQf003oaEQf0Go00000_mUK<D01?l0003oQh;6o`000?l0000?ojnm
i0;o00001_oNmm/01Ol0003okORbo`000?l0003oY>bU00Co00000onoUjh00ol0003o^Y>^okZC[P08
okZC[P04o`000?neT;3o]I2`okF@/0;o00001On/SKD00ol0003o[8feojb=]@03ojb=]@03o`000?nO
RKcoWhVl00CoWhVl00?o0000oh^5a_n;QLH00on;QLH01Ol0003oJ7gDofQme?mXOMCo000000;o;6cK
0ol000000ol0?l7o0000ooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool002?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`So00002?o3
XkP00ol0003o`9V_ol2I[`07ol2I[`?o00002onoVK000ol0003o`9ngol2O]`07ol2O]`Ko00002?no
Vk<00ol0003o`Ifcol6M/`09ol6M/`;o00000_l09k000ol0003o5F7HoaEQf003oaEQf0?oKY_/1?l0
000@ojnmi003o`000?oNmm_og_OK00Kog_OK0ol000000onTk:Go0000o`000002o`0000?o_iN^00?o
0000okZC[_njTjh02?njTjh00ol0003o]I2`okF@/004okF@/0;o00001?n/SKD00ol0003o[8feojb=
]@02ojb=]@go000000?oRhG6o`000?mXOM@00_mXOM@01?l0003o;6cKoba/fol/K=/2o`000003o`0o
`Ol0003ooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`008ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo1Ol00002ol>S^003o`000?o0
VJoo`9V_00Go`9V_0ol000000oo0VJoo0000oknI/00:oknI/003o`000?o0WkOo`9ng00[o`9ng00Co
0000okjK]?nnVkCo_Y^d1Ol00002oknK/`03o`000?o1WK?o`Ifc00Wo`Ifc00Co0000ol:N/oo2W[?o
00000_l09k000ol0003o5F7HoaEQf003oaEQf003o`000?m^VncoKY_/00CoKY_/0_l0000<ojnmi003
o`000?oNmm_og_OK00Kog_OK0_l00003ojC/Y@Co00000_noUjh00ol0003o^Y>^okZC[P08okZC[P03
o`000?neT;3o]I2`00Oo]I2`0_l00002ojb=]@03o`000?n/SKGo[8fe00;o00000onVSK/7oiJ;a@?o
NhOD1?l00002ofQme004o`000?l/K=_o;6cKoba/f`?o00006?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo000Sooooo`;o0000?_ooool00ol0003oooooooooo`0Vooooo`Go
00000_o0VJl3o`0000Co`9V_00?o0000oknI/?noVK002?noVK000ol0003o`9ngol2O]`0:ol2O]`03
o`000?nnVkCo_Y^d00Oo_Y^d1?l00009ol6M/`03o`000?o2W[?o`Yjc00;o`Yjc00Co0000o`0W/?l0
9k3o00001OlEHMP00ol0003oKY_/ofjKk005ofjKk0;o00002On__N@00ol0003og_OKomkgf`06omkg
f`03o`000?o]n;;oY>bU00;oY>bU0ol00002ol:H[0Co00002?njTjh00ol0003o]I2`okF@/00:okF@
/0;o000000?o[8feo`000?l000001_nVSK/00ol0003oUX_5oiJ;a@04oiJ;a@03o`000?mkQmCoNhOD
00?oNhOD1?l00003oba/f`?o00006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00gooooo000Rooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:Oooool6o`0000?o
`9V_00?o0000oknI/?noVK002?noVK000ol0003o`9ngol2O]`0:ol2O]`03o`000?nnVkCo_Y^d00Wo
_Y^d00?o0000oknL]?noW;@00ol00006ol6M/`03o`000?o2W[?o`Yjc00?o`Yjc0_l000000ol09k3o
0000oaEQf004oaEQf003o`000?m^VncoKY_/00KoKY_/00?o0000ojnmi?n__N@01On__N@00ol0003o
g_OKomkgf`07omkgf`04o`000?nTk:GoY>bUojC/Y@?o00001?o2V:`00ol0003o_iJ/oknF[005o`00
00;o^Y>^00?o0000okF@/?neT;003OneT;000ol0003oYXfko`000008ojJ=^`03o`000?nFRlGoUX_5
00?oUX_500?o0000og^7e?mkQm@00omkQm@2od^0h`;o00000ol/K=/2o`0001Kooooo0ol00007oooo
o`03o`000?oooooooooo00gooooo000Rooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool09Oooool3o`0000Kooooo2?l00005oknI/003o`000?o0WkOo`9ng00[o`9ng00?o0000okjK]?nn
Vk@02OnnVk@00ol0003o_ibdoknL]004oknL]0?o00000_o1WK<00ol0003o`Yjcol:N/`06ol:N/`03
o`000?l09k3o000000Go5F7H0_l00007ofjKk0;o00001?n__N@00ol0003og_OKomkgf`04omkgf`Co
00000onTk:D2o`0000Go`YR/00?o0000oknF[?noUZ`01_noUZ`2o`0000ko]I2`00Co0000ok6@/ona
T;?o/I2c0_l00008ojJ=^`03o`000?nFRlGoUX_500?oUX_50_l00004og^7e003o`000?m;P>?oBh3S
00;o00000_l/K=/2o`0001Sooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`00000?oooo
o`008_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02;ooooo0_l0000Aooooo`Go
000000?o`9ngo`000?o0WkL02Oo0WkL00ol0003o_Y^dokjK]009okjK]003o`000?noW;Co_ibd00So
_ibd1ol00005ol:N/`?o00001_lEHMP00ol0003oKY_/ofjKk006ofjKk0;o000000?o[kgTo`000?oN
mm/01_l000000onBk?Co0000ojC/Y@02ojC/Y@?o00001Oo2V:`00ol0003o_iJ/oknF[008oknF[003
o`000?nlTJ_o000000;o00002?neT;02o`0000Go/I2c0_l00008ojJ=^`;o00001OnFRlD00ol0003o
NhODog^7e002og^7e0;o00000_m;P><2o`000003oba/fol0003ooooo01Kooooo0ol0000Eooooo`00
8_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01kooooo0ol0000Jooooo`?o0000
1_o0WkL00ol0003o_Y^dokjK]009okjK]003o`000?noW;Co_ibd00So_ibd00?o0000ol6U_Oo1YKd0
1Oo1YKd6o`000003ohT00?l0003o000000Ko5F7H00?o0000ofjKk?m^Vn`01_m^Vn`4o`0000KoT^cd
0_l000000onTk:Go0000o`000002o`0000Ko`YR/00?o0000oknF[?noUZ`01onoUZ`00ol0003o_96[
okbAZ`03okbAZ`;o00001OneT;000ol0003o/I2cok6@/`06ok6@/`;o00002OnVSK/00ol0003oUX_5
oiJ;a@03oiJ;a@03o`000?mkQmCoNhOD00?oNhOD00?o0000od^0hom;P><01?l0000Cooooo`?o0000
0_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo0ol0000Pooooo`?o00000_o0WkL00ol0003o_Y^dokjK]009okjK]003o`000?no
W;Co_ibd00So_ibd00?o0000ol6U_Oo1YKd02Oo1YKd01?l0003o`ZBkol:T^oo2Y;/2ohT00003o`00
0?lEHMSo5F7H00Co5F7H00?o0000ofjKk?m^Vn`00_m^Vn`3o`0000WoT^cd00Go0000ojC/YOl0003o
0000o`@00002o`0000Ko`YR/00?o0000oknF[?noUZ`01onoUZ`00ol0003o_96[okbAZ`06okbAZ`?o
000000?o]I2`o`000?naT;<02OnaT;<3o`0000KoYXfk1ol000000onFRlGo0000og^7e004og^7e003
o`000?m;P>?oBh3S00Co00003oooool3o`0000Gooooo00?o0000ooooooooool04oooool002;ooooo
0_l00015ooooo`03o`000?oooooooooo01Kooooo0ol0000Vooooo`Go00002?nnVk@00ol0003o_ibd
oknL]008oknL]003o`000?o1YKgo`JFm00Wo`JFm00?o0000ol:T^oo2Y;/00oo2Y;/2ohT000Go0000
0_lEHMP01?l0003oKY_/o`000?l0000;oi;/m003o`000?nTk:Go000000;o10000_l00006ol:H[003
o`000?noUZco_iJ/00So_iJ/00?o0000okbAZonlTJ/02OnlTJ/00ol0003o/I2cok6@/`0:ok6@/`03
o`000?naT;?o000000;oYXfk0ol00004oinAa@?oRi;E1ol000000omkQmCo0000od^0h`02od^0h`03
o`000?lOL>3o000000_ooooo0ol00008ooooo`03o`000?oooooooooo01?ooooo000Qooooo`;o0000
Aoooool00ol0003oooooooooo`0Booooo`?o0000;_ooool5o`0000;o_Y^d00?o0000oknL]?noW;@0
2?noW;@00ol0003o`JFmol6U_@09ol6U_@03o`000?o2Y;_o`ZBk00Ko`ZBk0_n90002o`000003o`1k
]ol0003o000000;o000000?oT^cdo`000?l000002OnBk?@3o`0000;o100000?o0000ol:H[?o2V:`0
1_o2V:`00ol0003o_iJ/oknF[007oknF[003o`000?nlTJ_o_96[00[o_96[00Co0000okVB[ol0003o
00002OnaT;<00ol0003o/I2cok6@/`02o`0000SoWi750_l00004oh^Be@?oJI?W1?l00002od^0h`;o
00001oooool4o`0000_ooooo00?o0000ooooooooool04oooool0027ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0>ooooo`?o0000=_ooool2o`000003oknL]?l0003o000000;o0000
1OnoW;@00ol0003o`JFmol6U_@09ol6U_@03o`000?o2Y;_o`ZBk00So`ZBk00?o0000ohT00?n90000
0_l00006o`1k]`Go00000onBk?@2o`0000?o10001?l00005ol:H[003o`000?noUZco_iJ/00So_iJ/
00?o0000okbAZonlTJ/02OnlTJ/00ol0003o^I:_okVB[`02okVB[`;o00002?naT;<01Ol0003o[I:k
ojfB^on]T[_o000000WoWi7500?o0000oh^BeOn;T]D00on;T]D00ol0003oJI?WofVCi`02ofVCi`?o
000000?oBh3So`000?ooool00_ooool3o`00013ooooo00?o0000ooooooooool04_ooool0027ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0:ooooo`?o0000@?ooool5o`000003ol6U
_Ol0003o000000So`JFm00?o0000ol:T^oo2Y;/02Oo2Y;/00ol0003o`Ifbo`000002ohT00003o`00
0?l0NkOo07^g00So07^g0ol00004o`@00003o`000?o2X;Ko`Z2f00;o`Z2f1ol00008oknF[003o`00
0?nlTJ_o_96[00Wo_96[00?o0000okVB[oniTZl01OniTZl2o`0000Co/I2c0_l000000on]T[_o0000
ojfB^`03ojfB^`03o`000?nOTLGoWi7500KoWi7500?o0000oh^BeOn;T]D00on;T]D2o`0000CoJI?W
1_l0000Cooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool01_ooool3o`0004_ooooo1Ol00002ol6U_@03o`000?o2Y;_o`ZBk00Wo`ZBk00Co
0000ol6M/_o1WK;o`Ifb1Ol00006o`1k]`?o00000ol40003o`0000Wo`Z2f00?o0000oknG[OnoUjd0
0ol00004oknF[003o`000?nlTJ_o_96[00Wo_96[00?o0000okVB[oniTZl02?niTZl2o`000003ok6@
/ol0003o[I:k00?o[I:k00?o0000ojfB^on]T[/00_n]T[/2o`0000OoWi750_l00005oh^Be@;o0000
0omYTnL2o`000003odN;jol0003ooooo01?ooooo00?o0000ooooooooool04_ooool0027ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`02ooooo`?o0000Doooool4o`0000Wo`ZBk00?o
0000ol6M/_o1WK801Oo1WK84o`000003o`1k]ol0003o000000So00002_o2X;H00ol0003o_iN]oknG
[@04oknG[@?o000000?o_iJ/o`000?nlTJ/02_nlTJ/00ol0003o^I:_okVB[`0:okVB[`03o`000?n]
T[_o[I:k00?o[I:k00?o0000ojfB^on]T[/01?n]T[/2o`0000OoWi7500?o0000oh^BeOn;T]D01?n;
T]D00ol0003oJI?WofVCi`02ofVCi`;o00005?ooool00ol0003oooooooooo`0Booooo`008Oooool2
o`0004cooooo1?l0001Jooooo`?o00001_o2Y;/00ol0003o`Ifbol6M/P08ol6M/POo00000oo3XKL0
0ol0003o`Z2fol:P]P08ol:P]P03o`000?noUjgo_iN]00So_iN]1?l00008okbAZ`03o`000?niTZoo
^I:_00[o^I:_00?o0000okJE]_nfUKH00ol00002ojfB^`03o`000?n]T[_o[I:k00Go[I:k00?o0000
oinAaOnOTLD00_nOTLD?o`000003ofVCiol0003ooooo01;ooooo00?o0000ooooooooool04_ooool0
023ooooo0_l0001;ooooo`Co0000Goooool3o`0000;o`ZBk00?o0000ol6M/_o1WK802?o1WK800ol0
003o`j6gol>Q]`08ol>Q]`03o`000?o2X;Ko`Z2f00Oo`Z2f00?o0000oknG[OnoUjd02OnoUjd01?l0
003o_iZboknJ/_noV[85o`0000;o_96[00?o0000okVB[oniTZl02_niTZl00ol0003o]YFfokJE]P04
okJE]P;o000000?o[I:ko`000?n]T[/01_n]T[/4o`0000GoVIcF00?o0000oh:Rj?n2X^P01?n2X^P2
o`000004ofZPl?l0003o0000o`0001;ooooo00?o0000ooooooooool04_ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool0Aoooool3o`0000Cooooo0_l0001Pooooo`Oo00001Oo1WK800ol0003o`j6gol>Q
]`08ol>Q]`03o`000?o2X;Ko`Z2f00Oo`Z2f00?o0000oknG[OnoUjd02OnoUjd00ol0003o_iZboknJ
/P07oknJ/PCo00002_niTZl00ol0003o]YFfokJE]P07okJE]P?o00000_n]T[/3o`0000?oZ9W700?o
0000oiVLe_nIW=H01_nIW=H2o`0000GoPZ;X0_l000000omZX?3o0000ooooo`0Aooooo`03o`000?oo
oooooooo01;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`?o00002Oooool00ol0003ooooooooo
o`1Tooooo`[o00001Oo3XKL00ol0003o`Z2fol:P]P08ol:P]P03o`000?noUjgo_iN]00So_iN]00?o
0000oknJ/_noV[802OnoV[800ol0003o_IbgokfL]`03o`0000Ko^I:_00?o0000okJE]_nfUKH02_nf
UKH3o`0000SoZ9W70_l00007oiVLeP;o00001On2X^P3o`0001;ooooo00?o0000ooooooooool04Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0@Oooool3o`0000gooooo00?o0000ooooooooool0KOooool7o`0000So`Z2f00?o
0000oknG[OnoUjd02?noUjd00ol0003o_iZboknJ/P09oknJ/P03o`000?nmW;Oo_Ibg00Co_Ibg0ol0
0002okVB[`03o`000?nfUKKo]YFf00[o]YFf00Co0000ok>H^ol0003o/iRk0_l00008ojRIa`;o0000
1onIW=H2o`0000GoPZ;X0_l0000Aooooo`03o`000?oooooooooo017ooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo
0ol0000Aooooo`03o`000?oooooooooo07?ooooo1Ol00002ol:P]P03o`000?noUjgo_iN]00Wo_iN]
00?o0000oknJ/_noV[802?noV[800ol0003o_IbgokfL]`08okfL]`;o00002onfUKH2o`0000?o/iRk
00?o0000ok>H^oncV;/00_l00008ojRIa`;o00001?nIW=H9o`000003oh:Rj?l0003ooooo00oooooo
00?o0000ooooooooool04Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0>oooool3o`0001Gooooo00?o0000ooooooooool0
Moooool5o`0000So_iN]00?o0000oknJ/_noV[802?noV[800ol0003o_IbgokfL]`09okfL]`04o`00
0?njUkCo^YNdokZG]0?o00001OnfUKH00ol0003o/iRkok>H^`03ok>H^`03o`000?ncV;_o/iRk00;o
/iRk00?o0000ojRIaonXVLL01onXVLL4o`0000GoTjgX0ol00002ohF^l003o`000?oooooooooo00ko
oooo00?o0000ooooooooool04Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00?ooooo0ol0000iooooo`?o00006Oooool00ol0003oooooooooo`1kooooo`Go
00000_noUjd00ol0003o_iZboknJ/P08oknJ/P03o`000?nmW;Oo_Ibg00Wo_Ibg00?o0000okZG]?nj
Uk@01OnjUk@3o`000003okJE]_l0003o/iRk00Ko/iRk00?o0000ok>H^oncV;/00_ncV;/2o`0000;o
Z9W70ol00004ojBUe`;o00002?nC[NP2o`000003ohF^l?l0003ooooo00kooooo00?o0000oooooooo
ool04Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0=_ooool3o`0001gooooo00?o0000ooooooooool0Ooooool7o`0000Go
_iZb00?o0000okfL]onmW;L02OnmW;L00ol0003o^YNdokZG]009okZG]003o`000?ncV;_o/iRk00Oo
/iRk00?o0000ok>H^oncV;/00oncV;/2o`0000[oY:GG0_l00007oi>]j0?o00003_ooool00ol0003o
ooooooooo`0Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool00ol0003oooooooooo`0cooooo`?o00008Oooool00ol0003oooooooooo`25ooooo`Go
000000?o_Ibgo`000?nmW;L02?nmW;L00ol0003o^YNdokZG]008okZG]003o`000?niWkoo^Ino00;o
^Ino0ol00005ok>H^`04o`000?ncV;_o0000o`0000?o/:780ol00009ojBUe`?o00001?nC[NP01?l0
003oTjgXoi>]j?l0000=ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
037ooooo0_l0000Uooooo`03o`000?oooooooooo08_ooooo0ol00005okfL]`03o`000?njUkCo^YNd
00So^YNd00?o0000okVO_oniWkl01_niWkl3o`0000;o/iRk0_l00008ok2Qb0;o00002_nTYML4o`00
00?oU[O^00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`0^ooooo`?o0000:?ooool00ol0003oooooooooo`2=ooooo`?o000000?o_Ibgo`000?nj
Uk@02OnjUk@00ol0003o^InookVO_`0:okVO_`;o000000?o/:78o`000?n`XLP02On`XLP3o`0000;o
Y:GG0ol00005oj6ci@?o00000_nF]nh00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013o
oooo000Oooooo`03o`000?oooooooooo02_ooooo0ol0000/ooooo`03o`000?oooooooooo08gooooo
0ol000000onjUkCo0000o`000002o`0000Go^YNd00?o0000okVO_oniWkl02OniWkl2o`0000Co]JO;
0ol0000:ok2Qb0;o00002onQ/nD3o`0000gooooo00?o0000ooooooooool04?ooool001oooooo0_l0
000Yooooo`?o0000<?ooool00ol0003oooooooooo`29ooooo`?o00002?ooool5o`0000_o^Ino00?o
0000okFWboneYl/01OneYl/00ol0003o]JO;o`000002o`0000;o/:780ol00005oj^_f`Go00002?nQ
/nD00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooo
oooo02Kooooo0ol0000dooooo`03o`000?oooooooooo08Gooooo0ol0000Booooo`Go00000_niWkl2
o`0000So]JO;00?o0000okFWboneYl/00_neYl/2o`0000goZjoK1Ol00003oinkk@03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooooooool08oooool3o`00
03Sooooo00?o0000ooooooooool0P?ooool4o`0001[ooooo0_l0000;okFWb`?o00001OnbZm05o`00
00?oZjoK0ol00004ojZfhP?o00000_nO^nd00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
013ooooo000Nooooo`03o`000?oooooooooo023ooooo0ol0000looooo`03o`000?oooooooooo07co
oooo0ol0000Sooooo`Go00000_neYl/3o`0000_o/Z_@0ol0000:ojZfhPCo00002_ooool00ol0003o
ooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`0Mooooo`?o0000@?ooool00ol0003ooooo
ooooo`1hooooo`?o0000:oooool2o`0000?o/Z_@00?o0000ok:[d?nbZm001OnbZm03o`0000Co[KSQ
1Ol00007ojZfhP;o00002Oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003ooooooooo
o`0Jooooo`?o0000A?ooool00ol0003oooooooooo`1cooooo`Co0000<_ooool5o`0000;o/Z_@0_l0
000<ojfhh@Go00000onV_^/00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo000N
ooooo`03o`000?oooooooooo01Oooooo0ol00018ooooo`03o`000?oooooooooo06oooooo0ol0000h
ooooo`03o`000?oooooooooo00;o00002_n]^>43o`0000GoZ[cW1_l00009ooooo`03o`000?oooooo
oooo00oooooo000Mooooo`?o00005Oooool3o`0004cooooo00?o0000ooooooooool0Joooool3o`00
03cooooo00?o0000ooooooooool01_ooool5o`0000goZ[cW0_l00008ooooo`03o`000?oooooooooo
00oooooo000Mooooo`03o`000?oooooooooo01;ooooo0ol0001@ooooo`03o`000?oooooooooo06Oo
oooo0ol0000oooooo`03o`000?oooooooooo00gooooo1Ol00003ojZli`?o000000?oZKoZo`000?oo
ool01oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0?ooooo`?o0000
E?ooool00ol0003oooooooooo`1Rooooo`Co0000@oooool00ol0003oooooooooo`0Aooooo`Co0000
1?nY_nX00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oo
oooooooo00cooooo0ol0001Hooooo`03o`000?oooooooooo05kooooo0ol00018ooooo`03o`000?oo
oooooooo01Cooooo1_l00006ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo00Wooooo0ol0001Looooo`;o0000Foooool3o`0004cooooo00?o0000ooooooooool06?ooool2
o`0000Gooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool01_ooool3o`00
067ooooo00?o0000ooooooooool0EOooool3o`0004oooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o0000IOooool00ol0003o
ooooooooo`1@ooooo`Co0000Doooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00ko
oooo000Looooo`?o000000Coooooo`000?l0003o0000JOooool00ol0003oooooooooo`1<ooooo`?o
0000F?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo000Looooo`Co0000
KOooool00ol0003oooooooooo`18ooooo`?o0000G?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00kooooo000Looooo`;o0000L?ooool00ol0003oooooooooo`14ooooo`?o0000Gooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0?oooool4o`0006?ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
03_ooooo0ol0001Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool0023o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0gooooo`?o0000K?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00kooooo000Qooooo`;o0000Koooool00ol0003ooooo
ooooo`0cooooo`?o0000Koooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo
000Sooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0;_ooool4o`0007?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`009?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02[ooooo0ol0001hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03Oooool002Gooooo0_l0001^ooooo`03o`000?oooooooooo02Kooooo0ol0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool002Oooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0Rooooo`?o0000Ooooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00gooooo000Xooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
7Oooool4o`0008?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`00:Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo0ol00028ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03Oooool002[ooooo0_l0001]ooooo`03o`000?oooooo
oooo01Gooooo0ol0002;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool0
02cooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Aooooo`?o0000Soooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo000]ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool03?ooool4o`0009?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0<ooooo`00;_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Sooooo
0ol0002Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03?ooool002oooooo0_l0
001/ooooo`03o`000?oooooooooo00Cooooo0ol0002Kooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool03?ooool0037ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`03
o`0009oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`00<_ooool00ol0
003oooooooooo`1Zooooo`;o0000Xoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo000cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00cooooo000dooooo`;o0000JOooool00ol0003ooooo
ooooo`2Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool003Kooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool003Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`2U
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool003Sooooo0_l0001Uoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;oooo
o`00>_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0:Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0;ooooo`00>oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo0:Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`00??oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`00?Oooool2o`00063ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000oooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00[ooooo0010ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo0011ooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
0012ooooo`;o0000Foooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool004Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool004Gooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool004Kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool004Oooooo0_l0001Eooooo`03o`00
0?oooooooooo0:oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`00BOoo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`00B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo0;7ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`00Boooool2o`00
057ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo001=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo001>ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0/oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
001?ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0]?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo001@ooooo`;o0000C?ooool00ol0003oooooooooo`2e
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool005;ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool005?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool005Cooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool005Gooooo0_l00017ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo0;Sooooo00Go0000ooooooooooooooooo`00000:ooooo`00F?ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo0;Wooooo00Co0000oooooooooooo00002_ooool005Wooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`2jooooo`03o`000?oooooo000000[ooooo001Joooo
o`;o0000@_ooool00ol0003oooooooooo`2jooooo`04o`000?ooooooooooo`0000Wooooo001Loooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0^oooool00ol0003oooooo`000009oooo
o`00GOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0;cooooo0_l00009ooooo`00
G_ooool2o`0003kooooo00?o0000ooooooooool0^oooool3o`0000Wooooo001Pooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0]oooool4o`0000cooooo001Qooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0/oooool4o`00013ooooo001Rooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0[oooool4o`0001Cooooo001Sooooo`;o0000>Oooool00ol0003o
ooooooooo`2[ooooo`Co00006?ooool006Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`2Wooooo`Co00007?ooool006Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2Sooooo`Co00008?ooool006Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2O
ooooo`Co00009?ooool006Sooooo0_l0000cooooo`03o`000?oooooooooo09cooooo1?l0000Xoooo
o`00J_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Sooooo1?l0000/ooooo`00
Joooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo1?l0000`ooooo`00K?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo093ooooo1?l0000dooooo`00KOooool2
o`0002kooooo00?o0000ooooooooool0SOooool3o`0003Sooooo001_ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0ROooool4o`0003_ooooo001`ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0QOooool4o`0003oooooo001aooooo`;o0000:_ooool00ol0003ooooo
ooooo`21ooooo`Co0000@oooool007?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1mooooo`Co0000Aoooool007Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1i
ooooo`Co0000Boooool007Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1eoooo
o`Co0000Coooool007Kooooo0_l0000Uooooo`03o`000?oooooooooo077ooooo1?l0001Cooooo`00
N?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06gooooo1?l0001Gooooo`00NOoo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Kooooo`00N_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Oooooo`00Noooool2o`00
023ooooo00?o0000ooooooooool0HOooool4o`0006?ooooo001mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0GOooool4o`0006Oooooo001nooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0FOooool4o`0006_ooooo001oooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0EOooool4o`0006oooooo0020ooooo`;o00006oooool00ol0003oooooooooo`1A
ooooo`Co0000Loooool008;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1=oooo
o`Co0000Moooool008?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co
0000Noooool008Cooooo0_l0000Gooooo`03o`000?oooooooooo04Gooooo1?l0001oooooo`00Q_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo047ooooo1?l00023ooooo`00Qoooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo1?l00027ooooo`00R?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo1?l0002;ooooo`00ROooool2o`0001;o
oooo00?o0000ooooooooool0=Oooool4o`0008oooooo002;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<Oooool4o`0009?ooooo002<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0;_ooool4o`0009Oooooo002=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:oooool3o`0009_ooooo002>ooooo`;o00003?ooool00ol0003oooooooooo`0Woooo
o`Co0000W_ooool0093ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`Co
0000X_ooool0097ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Co0000
Y_ooool009;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`Co0000Z_oo
ool009?ooooo0_l00007ooooo`03o`000?oooooooooo01Oooooo1?l0002^ooooo`00UOooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1?l0002booooo`00U_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo1?l0002fooooo`00Uoooool2o`0000?ooooo
00?o0000ooooooooool02oooool4o`000;[ooooo002Iooooo`04o`000?ooooooooooo`0000Wooooo
1?l0002nooooo`00V_ooool00ol0003oooooo`000005ooooo`Co0000`_ooool009_ooooo0_l00000
0ooooooo0000o`000002o`000<Kooooo002Looooo`;o0000b_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool006Sooooo00Go8B4Qo`000?l0
003oA4A4omgMg@1iooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0OOooool006_ooooo00?oMgMgoc8b
<_ooool0Noooool00omgMgOo<S8booooo`1looooo`00K?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo07_ooooo0010ooooo`07oiRHV?l0003o0000odA4A?nj^[[ooooooa0@4005o`00
00Cooooo1Ol00002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool01?l@413o0000o`00
0?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00003ooooo`07oiRHV?l0003o
0000ogMgMol0003o410@ooooo`05o`0000?ooooo00SoV9RHo`000?l0003oMgMgoa0@4?l0003ooooo
oa0@40Go00001Oooool01_o^k^koEEEEo`000?l0003oV9RHo`0000;o410@1Ol00004ooooo`06oiRH
V?l0003o0000ogMgMol0003o410@0_l00002ooooo`04o`000?ooooooooooo`0000;o410@0_l00000
1ooooooo0000o`000?l@413oooooonk^k_mEEED00_l000001Om4A4Co^[ZjooooooooooooV9RH00;o
000000?oMgMgoa0@4?l000000_ooool01oo^k^koEEEEo`000?l0003oV9RHo`000?l@41001Oooool0
1_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo1Ol00002ooooo`06onk^k_mEEEGo0000oa0@4?o<
c<co00000_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413o0000o`000002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`00
0006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000001_nHV9So0000oa0@4?ooooook^k^oeEEE@;o
000000KoA4A4okZj^_oooooooooooa0@4?lb<S82o`000003oa0@4?nYZJWooooo00?ooooo00OoV9RH
o`000?l0003oEEEEonk^k_mVIVKo000000Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c00]ooooo`00
@?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?nYZJWoooooohN7Qol0
00001?ooool00ol0003oooooooooo`03ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0
003oooooooooo`06ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00ol0003ooooooooo
o`05ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Wo0000ooooooooooooEEEEogMgMoooooook^k^ogMgMol@4100
0_ooool01Ol0003oc<c<onk^k_n7QhOo000000?ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00006
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Cooooo
00Ko0000ojVYZOooooooQhN7oc8b<_mVIVH2ooooo`Ko000000Kooooooa0@4?nj^[[oooooogMgMolb
<S8]ooooo`00@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00?o
0000ooooooooool01_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Oooooo00Go410@ohN7Qooooooo
k^k^o`000003ooooo`06o`000?ooooooooooooooooo^k^ko00001_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00003ooooo`05onk^k_l0003o
ooooooooool000002?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Cooooo00Ko0000oooooooooooo
ooooohN7Qom4A4@=ooooo`03o`000?oooooooooo02_ooooo0010ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o
00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l0
0003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03okZj
^_l@413o000000;o00001?ooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooooooooo^
k^ko00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1_l00002ooooo`03okZj^_l@413o000000;o00000oooool01_l0003oooooooooooooooook^k^o`00
00Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooonk^k_l0
0002ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Cok^k^o`00
0?oooooooooo1_l00002ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^1?ooool01_lQ8B7oc<c<
ooooooooooooV9RHoc8b<P;ooooo1_l00004ooooo`03ojVYZOl@413ooooo02cooooo0010ooooo`03
o`000?oooooooooo00Gooooo00?o0000oc8b<_oMgMd01oooool00ol0003oooooooooo`05ooooo`03
olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooo
onk^k_mEEEGo00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
1_ooool00oo<c<co0000ooooo`03ooooo`03o`000?lb<S;ogMgM00Kooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00003ooooo`03o`000?lb<S;ogMgM00Gooooo00Go0000ooooooooooooooooo`000002
ooooo`07o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8@02ooooo`05o`000?mgMgOoooooojVYZOl0
00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PGooooo00?oc<c<o`000?ooool00_ooool0
1_mVIVKoMgMgooooooo^k^koEEEEo`0000Kooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85oooo
o`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIV
ogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0
003o^[Zjooooooo^k^koMgMgo`0000Cooooo00OoZJVYob4Q8OoMgMgok^k^oc8b<_mEEEGo^[Zj00[o
oooo00?o410@o`000?nj^[X0;Oooool003kooooo00?o410@o`000?l000000ol00003ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o0000oiRH
V0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVY
o`000?l@413ooooooa0@4?l000000_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool01?lb
<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool01_o^k^koEEEEo`00
0?l@413oc<c<o`0000;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`04oa0@4?l0003ooooo
ooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT00_ooool01Ol0003o
MgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`04oc8b<_l0
003o0000oiRHV0?ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00006ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^k_mEEEGo0000ob4Q8OnYZJWo
0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o0000
00goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o0000
00[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00005ooooo`06oiRHV?l0003o
0000oiRHV?nj^[[o<S8b2oooool00onj^[[o8B4Qooooo`0/ooooo`00@?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08Oooool01Ol@413oV9RHoooo
oonj^[[o000002gooooo0010ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08Ooo
ool01OnYZJWo410@o`000?l@413oZJVY02gooooo001Booooo`03oa0@4?oooooooooo02;ooooo00?o
410@o`000?l000006oooool2o`0001[ooooo00?o410@o`000?ooool06Oooool2o`00017ooooo00?o
410@ooooooooool0;_ooool2o`0005Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0844552, 0.00525911, \
0.00369676, 0.00369676}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.3 Galerkin-Method Eigenmodes", "Subsubtitle",
  CellTags->{"i:41", "c:34"}],

Cell[CellGroupData[{

Cell["General Theory", "Section",
  CellTags->"c:35"],

Cell["\<\
\t It is also possible to obtain numerical approximations to the \
low-order eigenvalues and eigenmodes of a system using the Galerkin method. \
In fact, this method is superior to the grid method in some respects. For \
instance, we will see that the error in the low-order eigenvalues scales far \
more favorably with the size of the operator matrix than in the grid method.  \
\
\>", "Text"],

Cell["\<\
\tFurthermore, the Galerkin method can be easily adapted to \
determine the eigenmodes and eigenvalues of  two- and even three-dimensional \
systems. As we saw above, it is rather difficult to apply the grid method to \
such problems, because of the complexity of identifying and modifying the \
boundary point equations in order to match homogeneous boundary conditions.  \
In the Galerkin method, boundary conditions are automatically satisfied by \
the choice of  functions used in the expansion. \
\>", "Text"],

Cell["\<\
\tIn the Galerkin method, we begin with  a general eigenmode \
problem in any number of spatial dimensions,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]],
  ","
}], "NE3",
  CellTags->"(6.3.8)"],

Cell[TextData[{
  "for some spatial operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", subject to general homogeneous boundary conditions. We next expand ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " in a complete set of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_m}\)]],
  " that match the boundary conditions, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = \ \[Sum]\+m c\_m\%\((n)\)\ v\_m\)]],
  "."
}], "NE3",
  CellTags->"(6.3.9)"],

Cell[TextData[{
  " The constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\%\((n)\)\)]],
  " remain to be determined.  Equation ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  " then becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+m c\_m\%\((n)\)\ \(L\&^\) 
            v\_m = \[Sum]\+m\ \(c\_m\%\((n)\)\) \(\[Lambda]\_n\) v\_m\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "We now take an inner product of this equation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`v\_l\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+m\ \((v\_l, \(L\&^\) v\_m)\) 
          c\_m\%\((n)\) = \[Lambda]\_n\ \(\[Sum]\+m\((v\_l, v\_m)\) 
            c\_m\%\((n)\)\)\)]]], "NE3",
  CellTags->"(6.3.10)"],

Cell[TextData[{
  " Let us define the matrices ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\_\(l\ m\)\)\(=\)\((v\_l, \(L\&^\) 
            v\_m)\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(l\ m\) = \((v\_l, v\_m)\)\)]],
  ". Then Eq. ",
  ButtonBox["(6.3.10)",
    ButtonData:>"(6.3.10)",
    ButtonStyle->"Hyperlink"],
  " is a matrix equation,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[\((n)\),
                FontWeight->"Plain"]]}], "=", 
          RowBox[{\(\[Lambda]\_n\), 
            RowBox[{
              StyleBox["S",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              StyleBox[
                SuperscriptBox[
                  StyleBox["c",
                    FontSlant->"Plain"], 
                  StyleBox[\((n)\),
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox["c", 
            StyleBox[\((n)\),
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " is the vector with components ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_m\%\((n)\)}\)]],
  ". This generalized matrix eigenvalue equation can be converted into a \
standard eigenvalue problem by multiplying both sides by the inverse of the \
matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " (assuming that this inverse exists):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SuperscriptBox[
                StyleBox["S",
                  FontSlant->"Plain"], 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "\[CenterDot]", 
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[\((n)\),
                FontWeight->"Plain"]]}], "=", 
          RowBox[{\(\[Lambda]\_n\), 
            StyleBox[
              SuperscriptBox[
                StyleBox["c",
                  FontSlant->"Plain"], 
                StyleBox[\((n)\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(6.3.11)"],

Cell[TextData[{
  "Thus, the eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  " of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " are also the eigenvalues of the matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SuperscriptBox[
              StyleBox["S",
                FontSlant->"Plain"], 
              StyleBox[\(-1\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "\[CenterDot]", 
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", and the expansion coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_m\%\((n)\)}\)]],
  "are the corresponding eigenvectors.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: 1D Quantum Harmonic Oscillator Eigenmodes", "Section",
  CellTags->"c:36"],

Cell["\<\
\t Below, we illustrate the Galerkin method using the dimensionless \
quantum harmonic oscillator as our example system:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\(1\/2\)\) \[PartialD]\^2\/\[PartialD]x\^2 + \
\(1\/2\) x\^2)\) \(\(\[Psi]\_n\)(x)\) = E\_n\ \(\(\[Psi]\_n\)(x)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.12)"],

Cell[TextData[{
  " We will solve for the eigenmodes and energy levels of the oscillator, \
choosing boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " vanishes as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \(\[PlusMinus]\[Infinity]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFirst, we must choose a set of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_m}\)]],
  " that match these boundary conditions.  Any complete set will do, but \
there is a certain amount of art to making a good choice. We know that the \
eigenmodes of this system are peaked around ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = 0\)\(,\)\)\)]],
  " so we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(
          x) = \[ExponentialE]\^\(\(-x\^2\)/3\)\ x\^m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, 1, 2,  ... \)]],
  ". The choice of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/3\)\)]],
  " is arbitrary: in principle, any smooth function that vanishes as infinity \
faster than ",
  Cell[BoxData[
      \(TraditionalForm\`1/x\^m\)]],
  " is valid. However, some choices work better than others. If we had chosen \
",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\(v\_m\)(x) = \[ExponentialE]\^\(\(-x\^2\)/2\)\ x\^m\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", we could construct any given exact eigenmode from a ",
  StyleBox["finite number ",
    FontSlant->"Italic"],
  "of our functions, since the exact modes are Hermite polynomials multiplied \
by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ExponentialE]\^\(\(-x\^2\)/2\)\)\(\ \)\)\)]],
  "(see Eq. ",
  ButtonBox["(4.1.32)",
    ButtonData:>{"Chapter4.nb", "(4.1.32)"},
    ButtonStyle->"Hyperlink"],
  " ).  The choice ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/3\)\)]],
  " implies that an infinite number of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_m\)]],
  "'s  will be needed to exactly describe any one eigenmode, but it is not so \
different from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/2\)\)]],
  ", so that the expansion converges reasonably quickly. "
}], "Text"],

Cell[TextData[{
  "\tBasically, the main idea is to choose functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_m\)(x)\)]],
  " that look as much as possible like the eigenmodes one is trying to \
describe, so that the smallest possible number of terms need be kept in the \
expansions. While this requires a certain amount of foreknowledge  concerning \
the solutions, one can often make guesses that work admirably."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n", 
      StyleBox[\( (*\ define\ basis\ functions\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    RowBox[{\(v[n_, x_]\  = \ x\^n\ Exp[\(-x^2\)/3];\), "\[IndentingNewLine]",
       
      StyleBox[\( (*\ define\ the\ inner\ product\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
    RowBox[{\(norm[f_, g_]\  := \ 
          Integrate[f\ \ g, {x, \(-Infinity\), Infinity}];\), 
      "\[IndentingNewLine]", 
      StyleBox[\( (*\ 
          define\ the\ quantum\ harmonic\ oscillator\ operator\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", \(V[x_]\  = \ 
        1/2\ x^2;\), "\[IndentingNewLine]", \(L\&^[
          f_] := \(-1\)/2\ D[f, {x, 2}]\  + \ V[x]\ f;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.155"],

Cell[TextData[{
  "The inner product is evaluated analytically, because we can do the \
required integrations to determine the projection of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " onto the basis functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[j_, k_]\  = \ 
      FullSimplify[norm[v[j, x], L\&^[v[k, x]]], 
        j > \(-1\)\  && \ k > 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.156"],

Cell[BoxData[
    \(\(1\/\(1 + j + 
            k\)\) \((2\^\(1\/2\ \((\(-7\) - j - k)\)\)\ 3\^\(1\/2\ \((\(-1\) \
+ j + k)\)\)\ \((1 + \((\(-1\))\)\^\(j + k\))\)\ \((\(-4\)\ \((\(-1\) + 
                    k)\)\ k\ \((1 + j + k)\)\ Gamma[
                  1\/2\ \((\(-1\) + j + k)\)] + \((13 + 5\ j + 
                    21\ k)\)\ Gamma[1\/2\ \((3 + j + k)\)])\))\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This form for the matrix elements ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(j\ k\)\)]],
  " does not work for ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(1\ 0\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\(\ \)\(0\ 1\)\)\)]],
  ", but these elements are zero by symmetry, so we simply set these elements \
equal to zero:"
}], "Text"],

Cell[BoxData[
    \(\(L[0, 1] = \(L[1, 0] = 0\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.157"],

Cell[TextData[{
  "The elements of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can also be determined analytically :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S[j_, k_]\  = \ 
      Simplify[norm[v[j, x], v[k, x]], j + k > \(-1\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.158"],

Cell[BoxData[
    \(\(\((2\/3)\)\^\(\(-\(1\/2\)\) - j\/2 - k\/2\)\ \((1 + \((\(-1\))\)\^\(j \
+ k\))\)\ Gamma[1\/2\ \((3 + j + k)\)]\)\/\(1 + j + k\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now construct the matrices and determine their eigenvalues and \
eigenvectors, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ":"
}], "Text"],

Cell[BoxData[{\(M = 10;\), "\[IndentingNewLine]", 
    StyleBox[\( (*\ construct\ the\ matrices\ *) \),
      FontColor->RGBColor[1, 0, 
      0]], "\n", \(Smat\  = \ 
        Table[S[j, k], {j, 0, M}, {k, 0, M}];\), "\[IndentingNewLine]", 
    RowBox[{\(Lmat\  = \ Table[L[j, k], {j, 0, M}, {k, 0, M}];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    StyleBox[\( (*\ 
        take\ the\ \((numerical)\)\ inverse\ of\ S\ and\ matrix\ multiply\ it\
\ by\ L\ *) \),
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    RowBox[{\(mat\  = \ Inverse[Smat\  // N] . Lmat;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    StyleBox[\( (*\ find\ the\ eigenvalues\ and\ eigenvectors\ *) \),
      FontColor->RGBColor[1, 0, 
      0]], "\[IndentingNewLine]", \(lam = 
        Eigenvalues[mat];\), "\[IndentingNewLine]", \(c = 
        Eigenvectors[mat];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.159"],

Cell[TextData[{
  "The lowest eigenvalues are very close to the exact result, ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = n + 1/2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reverse[lam\ ]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.160"],

Cell[BoxData[
    \({0.5000000108181728`, 1.5000025657726987`, 2.500014487659602`, 
      3.5007342672320707`, 4.502009033309626`, 5.533931766890636`, 
      6.559606098799942`, 7.887756864326234`, 9.018403789946419`, 
      11.369241202442145`, 12.669966579461617`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.161"],

Cell["\<\
{0.5000000108181728, 1.5000025657726987, 2.500014487659602, 
 3.5007342672320707, 4.502009033309626, 5.533931766890636, 
 6.559606098799942, 7.887756864326234, 9.018403789946419, 
 11.369241202442145, 12.669966579461617}\
\>", "Output"]
}, Open  ]],

Cell[TextData[{
  "The error could be reduced even further, by taking ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " larger. The eigenfunctions can also be constructed from the basis \
functions using Eq. ",
  ButtonBox["(6.3.9)",
    ButtonData:>"(6.3.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][n_, x_]\  := \ 
      Sum[\(c[\([M - n + 1]\)]\)[\([j + 1]\)] v[j, x], {j, 0, M}]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.162"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.163",
    ButtonData:>"Cell 6.163",
    ButtonStyle->"Hyperlink"],
  " we plot the first few modes. One can easily check that they closely match \
the exact  eigenmodes. The reader is invited to vary ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " as well as the form of the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_m\)(x)\)]],
  " in order to study the convergence properties of this method."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Evaluate[\[Psi][n, x]], {x, \(-8\), 8}, PlotRange \[Rule] All, 
          PlotLabel \[Rule] \*"\"\<Galerkin \!\(\[Psi]\_n\)(x), n=\>\"" <> 
              ToString[n]], {n, 0, 3}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.163"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0147231 0.596769 [
[.05357 .00222 -12 -9 ]
[.05357 .00222 12 0 ]
[.20238 .00222 -6 -9 ]
[.20238 .00222 6 0 ]
[.35119 .00222 -12 -9 ]
[.35119 .00222 12 0 ]
[.64881 .00222 -9 -9 ]
[.64881 .00222 9 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.94643 .00222 -9 -9 ]
[.94643 .00222 9 0 ]
[.4875 .13408 -18 -4.5 ]
[.4875 .13408 0 4.5 ]
[.4875 .25343 -18 -4.5 ]
[.4875 .25343 0 4.5 ]
[.4875 .37278 -18 -4.5 ]
[.4875 .37278 0 4.5 ]
[.4875 .49214 -18 -4.5 ]
[.4875 .49214 0 4.5 ]
[.4875 .61149 -6 -4.5 ]
[.4875 .61149 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .01472 m
.05357 .02097 L
s
[(-7.5)] .05357 .00222 0 1 Mshowa
.20238 .01472 m
.20238 .02097 L
s
[(-5)] .20238 .00222 0 1 Mshowa
.35119 .01472 m
.35119 .02097 L
s
[(-2.5)] .35119 .00222 0 1 Mshowa
.64881 .01472 m
.64881 .02097 L
s
[(2.5)] .64881 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(5)] .79762 .00222 0 1 Mshowa
.94643 .01472 m
.94643 .02097 L
s
[(7.5)] .94643 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76786 .01472 m
.76786 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13408 m
.50625 .13408 L
s
[(0.2)] .4875 .13408 1 0 Mshowa
.5 .25343 m
.50625 .25343 L
s
[(0.4)] .4875 .25343 1 0 Mshowa
.5 .37278 m
.50625 .37278 L
s
[(0.6)] .4875 .37278 1 0 Mshowa
.5 .49214 m
.50625 .49214 L
s
[(0.8)] .4875 .49214 1 0 Mshowa
.5 .61149 m
.50625 .61149 L
s
[(1)] .4875 .61149 1 0 Mshowa
.125 Mabswid
.5 .04456 m
.50375 .04456 L
s
.5 .0744 m
.50375 .0744 L
s
.5 .10424 m
.50375 .10424 L
s
.5 .16392 m
.50375 .16392 L
s
.5 .19375 m
.50375 .19375 L
s
.5 .22359 m
.50375 .22359 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .31311 m
.50375 .31311 L
s
.5 .34295 m
.50375 .34295 L
s
.5 .40262 m
.50375 .40262 L
s
.5 .43246 m
.50375 .43246 L
s
.5 .4623 m
.50375 .4623 L
s
.5 .52198 m
.50375 .52198 L
s
.5 .55182 m
.50375 .55182 L
s
.5 .58165 m
.50375 .58165 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
176.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.0941 .01472 L
.10458 .01472 L
.11468 .01472 L
.12571 .01472 L
.1458 .01472 L
.15067 .01472 L
.15593 .01472 L
.16057 .01472 L
.16311 .01472 L
.16548 .01472 L
.1668 .01472 L
.16821 .01472 L
.16901 .01472 L
.16978 .01472 L
.17046 .01472 L
.17121 .01472 L
.17184 .01472 L
.17253 .01472 L
.17326 .01472 L
.17394 .01472 L
.17516 .01472 L
.17648 .01472 L
.17769 .01472 L
.17901 .01472 L
.18168 .01472 L
.18415 .01472 L
.18645 .01472 L
.1915 .01472 L
.19435 .01472 L
.19697 .01472 L
.2017 .01472 L
.20691 .01472 L
.21594 .01473 L
.22087 .01473 L
.22549 .01474 L
.23047 .01475 L
.2359 .01476 L
Mistroke
.24103 .01478 L
.24578 .0148 L
.25049 .01482 L
.25476 .01485 L
.25969 .0149 L
.26432 .01496 L
.26899 .01504 L
.27411 .01516 L
.27945 .01534 L
.28444 .01556 L
.28911 .01583 L
.29336 .01614 L
.29828 .0166 L
.30292 .01717 L
.30753 .01787 L
.3126 .01886 L
.3179 .02018 L
.32287 .02175 L
.33175 .02556 L
.33674 .02841 L
.3413 .03157 L
.35113 .04053 L
.36027 .05216 L
.37029 .06951 L
.38098 .09446 L
.39125 .12564 L
.40237 .16804 L
.42253 .26707 L
.44205 .38121 L
.4524 .44227 L
.4635 .50247 L
.47417 .55044 L
.47922 .56854 L
.4839 .58219 L
.48858 .59261 L
.49105 .59672 L
.49232 .59845 L
.49368 .60003 L
.49487 .60115 L
.49595 .60197 L
.49699 .60258 L
.49809 .60303 L
.49929 .60329 L
.50041 .60332 L
.50164 .60311 L
.50296 .60261 L
.50419 .60188 L
.50554 .60079 L
.50827 .59767 L
.51081 .59371 L
Mistroke
.51318 .58908 L
.51853 .5755 L
.52428 .55637 L
.5348 .51089 L
.54442 .46029 L
.56503 .33882 L
.58415 .23141 L
.60265 .14777 L
.61299 .11185 L
.62236 .08588 L
.6324 .06434 L
.64162 .04945 L
.65175 .03756 L
.65685 .03301 L
.66245 .02893 L
.6677 .02585 L
.67266 .02348 L
.68197 .02022 L
.68718 .01891 L
.692 .01795 L
.69728 .01714 L
.70289 .01648 L
.70779 .01605 L
.71227 .01574 L
.7172 .01548 L
.72238 .01527 L
.72691 .01514 L
.73111 .01504 L
.73573 .01496 L
.74066 .0149 L
.746 .01485 L
.75092 .01481 L
.75631 .01479 L
.76203 .01477 L
.76699 .01475 L
.77163 .01475 L
.77672 .01474 L
.78218 .01473 L
.78745 .01473 L
.79232 .01472 L
.79768 .01472 L
.80337 .01472 L
.80599 .01472 L
.80881 .01472 L
.8113 .01472 L
.81393 .01472 L
.8163 .01472 L
.81891 .01472 L
.82005 .01472 L
.82127 .01472 L
Mistroke
.82241 .01472 L
.82348 .01472 L
.8247 .01472 L
.82535 .01472 L
.82605 .01472 L
.82679 .01472 L
.82748 .01472 L
.82879 .01472 L
.83 .01472 L
.83113 .01472 L
.83237 .01472 L
.83369 .01472 L
.83668 .01472 L
.8395 .01472 L
.84477 .01472 L
.86491 .01472 L
.88328 .01472 L
.89371 .01472 L
.90345 .01472 L
.91307 .01472 L
.91846 .01472 L
.92338 .01472 L
.92856 .01472 L
.93419 .01472 L
.93952 .01472 L
.94444 .01472 L
.94818 .01472 L
.95222 .01472 L
.95953 .01472 L
.96376 .01472 L
.96822 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@12ooooo`Go00001Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Qooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool00ol0003o
k^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo000Sooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Cooooo00?oMgMgoc8b<_oo
ool07oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
047ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0S
ooooo`03ogMgMolb<S;ooooo02;ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool07_ooool001Wooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool05oooool6o`0000Oooooo00?o0000ooooooooool05_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h04Oooool00ol0003oooooooooo`11ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Qooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool07Oooool002Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Tooooo`03
ogMgMolb<S;ooooo027ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`13ooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool08oooool00omgMgOo<S8booooo`0Sooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool07_ooool002Cooooo00?oEEEEolc<c?ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c015ooooo`03ogMgMomVIVKo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Qooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
9?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool002Cooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Vooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool08Oooool0027ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool0A?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Sooooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Qooooo`008Oooool5o`0000cooooo1?l0000Sooooo`Co00008Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00013ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0002;ooooo1?l0000Rooooo`Go00003?ooool4o`00023ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo000Hoooooooo0000>?l0000I
ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool9o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo2?l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00:?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo01oooooo1Ol00007ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`?o00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo001nooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0<_ooool3o`0007gooooo001oooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<?ooool2o`00083ooooo0020ooooo`?o0000<?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo083ooooo0023ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool2o`0008?ooooo0024ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Poooool008Gooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Cooooo0026ooooo`03o`000?oo
oooooooo02[ooooo0_l0000[ooooo`03o`000?oooooooooo08Gooooo0027ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`26ooooo`00R?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool008So
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oo
oooo0029ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`28ooooo`00R_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0R?ooool008[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`29ooooo`00Roooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool0
9?ooool2o`0002Kooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2;ooooo`00SOooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0S?ooool008go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08co
oooo002=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`2=ooooo`00S_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0SOooool008kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo08gooooo002>ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`0Qooooo`;o
00008_ooool00ol0003oooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo002@ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2?ooooo`00T?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Soooool0093o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo093o
oooo002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`2@ooooo`00TOooool00ol0003oooooooooo`04ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
T?ooool0097ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo093ooooo002Aooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Nooooo`03o`000?oooooooooo097o
oooo002Booooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Aooooo`00
T_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0TOooool009;ooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo097ooooo002Cooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09;ooooo002Cooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo09;ooooo002Coooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Boooo
o`00U?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0T_ooool009Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo09?ooooo002Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`;o00007Oooool0
0ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Toooool009Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0U?ooool009Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Foooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Doooo
o`00U_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0UOooool009Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo09Gooooo002Fooooo`03o`000?oooooooooo01[ooooo0_l0000Kooooo`03o`000?oo
oooooooo09Gooooo002Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2Eooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo09Kooooo002Gooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009Sooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09Oooooo002Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Goooo
o`00V?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0Uoooool009Sooooo00?o0000ooooooooool06?ooool2o`0001Wooooo00?o0000ooooooooool0
Uoooool009Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo09Oooooo002Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0V?ooool009Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo09Sooooo002Iooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0V?ooool009Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2Iooooo`00V?ooool01OmgMgOoV9RHo`000?nH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`2Iooooo`00V?ooool01Ol@413oooooo`000?oooooo410@00_ooooo1Ol0
0006ooooo`?o00005_ooool00ol0003oooooooooo`2Iooooo`00V?ooool01Ol0003oooooo`000?oo
oooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo09Wooooo002Hooooo`05o`000?oooooo0000ooooool000002oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009Sooooo
00Go410@oooooooooooo0000oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`2Jooooo`00V?ooool01OmgMgOoV9RHooooool0003oMgMg00co
oooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[o
oooo002Hooooo`05onk^k_lb<S;o0000o`000?o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool009_ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[ooooo002Kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Jooooo`00Voooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool0
09cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
09_ooooo002Looooo`03o`000?oooooooooo01Cooooo0_l0000Eooooo`03o`000?oooooooooo09_o
oooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`2Kooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Voooool009cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo09_ooooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2Looooo`00WOooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0W?ooool009gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09cooooo002Mooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Looooo`00WOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0W?ooool0
09gooooo00?o0000ooooooooool04oooool2o`0001Cooooo00?o0000ooooooooool0W?ooool009go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09go
oooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2Mooooo`00W_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0WOooool009kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo09gooooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`2Mooooo`00W_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0W_ooool009oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09kooooo002Oooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Nooooo`00Woooool0
0ol0003oooooooooo`0Aooooo`;o00004_ooool00ol0003oooooooooo`2Nooooo`00Woooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0W_ooool009oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09ko
oooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`2Oooooo`00X?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Woooool00:3ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo09oooooo002Pooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00V?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Hooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`04ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?o0000ooooooooool01?ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0X?ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00Gooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0:3ooooo002Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Pooooo`00X_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0XOooool00:;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Qooooo`00
X_ooool00ol0003oooooooooo`0>ooooo`;o00003oooool00ol0003oooooooooo`2Qooooo`00X_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0XOoo
ool00:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0:7ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0X_ooool00:?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X_ooool00:?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03
o`000?oooooooooo00gooooo0_l0000=ooooo`03o`000?oooooooooo0:?ooooo002Tooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Sooooo`00Y?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Xooo
ool00:Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0:?ooooo002Tooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`2Sooooo`00Y?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0Xoooool00:Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0:?ooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000oooo
ooooool02oooool2o`0000cooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Cooooo002Vooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Tooooo`00Y_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0YOoo
ool00:Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0:Gooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2Uooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0YOooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q0oooool01_l0003oc<c<ob4Q8Ol0003o8B4Qolc<c0Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2Uooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B43
ooooo`06o`000?lQ8B7oV9RHoooooonHV9So8B4Q1_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:Kooooo002Hooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Hooooo`05o`000?ooooooooooooooool000002_ooool01_l0003o<S8boiRHV?ooooooV9RHoc8b
<PKooooo0ol00009ooooo`03o`000?oooooooooo0:Kooooo002Hooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oc<c<o`000002o`000003olc<c?oooooooooo00Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Vooooo`00V?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Y_ooool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Ol0003o410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Yoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Woooo
o`00ZOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Z?ooool00:Wooooo00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0
Z?ooool00:Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0:Sooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Xooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Z?ooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00Z_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo002[oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Yoooo
o`00Zoooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`2Zooooo`00
Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Z_ooool00:cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0:[ooooo002/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2[ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Zoooool00:gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo002^oooo
o`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2]ooooo`00
[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
[Oooool00:oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo
002_ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`2_ooooo`00/?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0:oooooo002aooooo`05o`000?oo
oooo0000ooooool00000/_ooool00:Wooooo1?l000000ol@413oooooooooo`02ooooo`?o0000/ooo
ool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Go
oooo0ol0002booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000
ooooooooool0^_ooool00:Wooooo00?oEEEEofIVI_l00000_?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00;;ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool0
0008ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool01Oooool00ol0003o^[Zjoooo
o`2?ooooo`00/oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Ooo
ool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Gooooo0_lb<S:@ooooo`00KOooool0
1OnYZJWo410@o`000?l@413oEEEE00?ooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`Go
00000oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`;o00000_oo
ool00ol@413o0000o`000002ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00?ooooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000oooo
ooooool01Oooool01?mEEEGoV9RHooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7QomVIVKo
oooo00Cooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1`ooooo`00K?ooool01_nYZJWo0000okZj
^_ooooooc<c<o`0000?ooooo00Go0000olc<c?o^k^koQhN7o`000005ooooo`03o`000?oooooooooo
00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooo^k^ko<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`0:o`000?oooooo
ooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?ok^k^o`000?ooool01?ooool00oo<
c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6o`000006oooooomgMgOo
V9RHoooooonHV9SoMgMgL?ooool006cooooo00?o8B4QojVYZOooool00_ooool02Ol0003ooooooooo
oooooooo410@ohN7Qoooooook^k^o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`04o`000?nHV9So<S8bolc<c0Kooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Ko<S8bonk^k_nHV9SoEEEE
omgMgOl@410;ooooo`03oc8b<_oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<1Oooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000002Oooool01Ol@413ooooooooooooo
oooo410@073ooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@
4003o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooo
ooooooooool000000_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0K_oo
ool006cooooo00?o0000ooooooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo
00Co0000onk^k_mEEEGoQhN71_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVY
ZOl000001_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^oooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7
oooooonYZJWo000000Wooooo00Go0000ooooooooooooooooo`00001`ooooo`00K?ooool01_lQ8B7o
ZJVYooooooooooook^k^oa0@40Cooooo00Co<S8bo`000?l0003oV9RH1Oooool00ol0003ooooooooo
o`03ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q
8@?ooooo00Go0000oooooom4A4Co0000oa0@4003ooooo`03oa0@4?l0003o000000Cooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`04ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool02?ooool01?mEEEGoMgMgooooooooool2o`0000;ooooo0_l00003ooooo`03ogMg
MomEEEGooooo01;ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`07ooooo`05oa0@
4?ooooooooooooooool@4100L?ooool006cooooo00KoZJVYob4Q8OoMgMgoooooohN7Qol0000=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00omVIVKoQhN7ooooo`0;oooo
o`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd08_ooool01OmgMgOoV9RHoooooonHV9So
MgMg073ooooo001]ooooo`05oiRHV?l@413o0000ob4Q8Ol000003Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00onYZJWoA4A4ooooo`0<
ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool08_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^073ooooo001mooooo`03oa0@4?l0003o000001Gooooo0_l00009ooooo`03oa0@4?oooooo
oooo0<Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.71045, -0.0816598, \
0.0676215, 0.0067448}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30903 0.491191 [
[.05357 .29653 -12 -9 ]
[.05357 .29653 12 0 ]
[.20238 .29653 -6 -9 ]
[.20238 .29653 6 0 ]
[.35119 .29653 -12 -9 ]
[.35119 .29653 12 0 ]
[.64881 .29653 -9 -9 ]
[.64881 .29653 9 0 ]
[.79762 .29653 -3 -9 ]
[.79762 .29653 3 0 ]
[.94643 .29653 -9 -9 ]
[.94643 .29653 9 0 ]
[.4875 .01432 -24 -4.5 ]
[.4875 .01432 0 4.5 ]
[.4875 .11255 -24 -4.5 ]
[.4875 .11255 0 4.5 ]
[.4875 .21079 -24 -4.5 ]
[.4875 .21079 0 4.5 ]
[.4875 .40727 -18 -4.5 ]
[.4875 .40727 0 4.5 ]
[.4875 .50551 -18 -4.5 ]
[.4875 .50551 0 4.5 ]
[.4875 .60374 -18 -4.5 ]
[.4875 .60374 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30903 m
.05357 .31528 L
s
[(-7.5)] .05357 .29653 0 1 Mshowa
.20238 .30903 m
.20238 .31528 L
s
[(-5)] .20238 .29653 0 1 Mshowa
.35119 .30903 m
.35119 .31528 L
s
[(-2.5)] .35119 .29653 0 1 Mshowa
.64881 .30903 m
.64881 .31528 L
s
[(2.5)] .64881 .29653 0 1 Mshowa
.79762 .30903 m
.79762 .31528 L
s
[(5)] .79762 .29653 0 1 Mshowa
.94643 .30903 m
.94643 .31528 L
s
[(7.5)] .94643 .29653 0 1 Mshowa
.125 Mabswid
.08333 .30903 m
.08333 .31278 L
s
.1131 .30903 m
.1131 .31278 L
s
.14286 .30903 m
.14286 .31278 L
s
.17262 .30903 m
.17262 .31278 L
s
.23214 .30903 m
.23214 .31278 L
s
.2619 .30903 m
.2619 .31278 L
s
.29167 .30903 m
.29167 .31278 L
s
.32143 .30903 m
.32143 .31278 L
s
.38095 .30903 m
.38095 .31278 L
s
.41071 .30903 m
.41071 .31278 L
s
.44048 .30903 m
.44048 .31278 L
s
.47024 .30903 m
.47024 .31278 L
s
.52976 .30903 m
.52976 .31278 L
s
.55952 .30903 m
.55952 .31278 L
s
.58929 .30903 m
.58929 .31278 L
s
.61905 .30903 m
.61905 .31278 L
s
.67857 .30903 m
.67857 .31278 L
s
.70833 .30903 m
.70833 .31278 L
s
.7381 .30903 m
.7381 .31278 L
s
.76786 .30903 m
.76786 .31278 L
s
.82738 .30903 m
.82738 .31278 L
s
.85714 .30903 m
.85714 .31278 L
s
.8869 .30903 m
.8869 .31278 L
s
.91667 .30903 m
.91667 .31278 L
s
.02381 .30903 m
.02381 .31278 L
s
.97619 .30903 m
.97619 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.5 .01432 m
.50625 .01432 L
s
[(-0.6)] .4875 .01432 1 0 Mshowa
.5 .11255 m
.50625 .11255 L
s
[(-0.4)] .4875 .11255 1 0 Mshowa
.5 .21079 m
.50625 .21079 L
s
[(-0.2)] .4875 .21079 1 0 Mshowa
.5 .40727 m
.50625 .40727 L
s
[(0.2)] .4875 .40727 1 0 Mshowa
.5 .50551 m
.50625 .50551 L
s
[(0.4)] .4875 .50551 1 0 Mshowa
.5 .60374 m
.50625 .60374 L
s
[(0.6)] .4875 .60374 1 0 Mshowa
.125 Mabswid
.5 .03887 m
.50375 .03887 L
s
.5 .06343 m
.50375 .06343 L
s
.5 .08799 m
.50375 .08799 L
s
.5 .13711 m
.50375 .13711 L
s
.5 .16167 m
.50375 .16167 L
s
.5 .18623 m
.50375 .18623 L
s
.5 .23535 m
.50375 .23535 L
s
.5 .25991 m
.50375 .25991 L
s
.5 .28447 m
.50375 .28447 L
s
.5 .33359 m
.50375 .33359 L
s
.5 .35815 m
.50375 .35815 L
s
.5 .38271 m
.50375 .38271 L
s
.5 .43183 m
.50375 .43183 L
s
.5 .45639 m
.50375 .45639 L
s
.5 .48095 m
.50375 .48095 L
s
.5 .53007 m
.50375 .53007 L
s
.5 .55463 m
.50375 .55463 L
s
.5 .57918 m
.50375 .57918 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
176.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30903 m
.02846 .30903 L
.03279 .30903 L
.03754 .30903 L
.04262 .30903 L
.04795 .30903 L
.053 .30903 L
.05753 .30903 L
.06244 .30903 L
.06751 .30903 L
.07308 .30903 L
.0789 .30903 L
.08435 .30903 L
.0941 .30904 L
.09957 .30904 L
.10458 .30904 L
.11442 .30904 L
.12357 .30905 L
.14429 .30907 L
.16309 .30909 L
.17297 .3091 L
.17837 .30911 L
.18342 .30911 L
.18598 .30911 L
.1873 .30911 L
.18873 .30911 L
.18955 .30911 L
.1903 .30911 L
.19101 .30911 L
.19179 .30911 L
.19248 .30911 L
.19314 .30911 L
.19383 .30911 L
.19457 .30911 L
.19581 .30911 L
.19652 .30911 L
.19718 .30911 L
.1985 .30911 L
.19992 .30911 L
.20249 .30911 L
.20483 .30911 L
.20981 .30911 L
.21243 .3091 L
.21521 .3091 L
.21638 .3091 L
.21763 .3091 L
.21835 .3091 L
.21901 .3091 L
.2203 .3091 L
.22145 .3091 L
Mistroke
.22271 .3091 L
.2239 .3091 L
.225 .3091 L
.22629 .3091 L
.22765 .30911 L
.22882 .30911 L
.23009 .30911 L
.23147 .30911 L
.23294 .30912 L
.2356 .30913 L
.23828 .30914 L
.24081 .30916 L
.24309 .30918 L
.24556 .30921 L
.25026 .30928 L
.25263 .30932 L
.25524 .30938 L
.25986 .30952 L
.26418 .3097 L
.26889 .30995 L
.27404 .31032 L
.27941 .31084 L
.2844 .31147 L
.2891 .31223 L
.29336 .31309 L
.30292 .31575 L
.30779 .31761 L
.31293 .32003 L
.32214 .32582 L
.32727 .33002 L
.33206 .33469 L
.34296 .34849 L
.35339 .36656 L
.36328 .38865 L
.38183 .44316 L
.40003 .50786 L
.41039 .54426 L
.42013 .57372 L
.42476 .58497 L
.42963 .59428 L
.43218 .59796 L
.43353 .59954 L
.43498 .60094 L
.43631 .60196 L
.43752 .60264 L
.43873 .6031 L
.43988 .60332 L
.44109 .60331 L
.44178 .6032 L
.44242 .60301 L
Mistroke
.44372 .60243 L
.44445 .60198 L
.44512 .60148 L
.4463 .6004 L
.4476 .59893 L
.44995 .59548 L
.4527 .59015 L
.45562 .58292 L
.46088 .56586 L
.46624 .54318 L
.47117 .51784 L
.48231 .44689 L
.50248 .28884 L
.51235 .21063 L
.52292 .13571 L
.5329 .079 L
.53731 .05929 L
.54199 .04225 L
.5443 .03536 L
.54685 .02893 L
.54919 .0241 L
.55134 .02056 L
.55386 .01749 L
.55519 .01634 L
.55586 .01587 L
.55658 .01546 L
.5578 .01497 L
.55893 .01475 L
.55963 .01472 L
.56028 .01476 L
.5615 .01503 L
.56257 .01546 L
.56375 .01614 L
.56497 .01707 L
.56612 .01815 L
.57037 .02378 L
.57279 .02805 L
.57501 .03257 L
.57998 .04463 L
.60063 .11259 L
.61976 .18018 L
.6383 .23328 L
.64865 .25545 L
.65803 .27101 L
.66809 .28353 L
.67733 .29185 L
.68217 .29521 L
.68747 .29824 L
.69297 .30076 L
.69817 .30267 L
Mistroke
.70308 .30411 L
.70841 .30535 L
.71284 .30617 L
.71773 .30688 L
.72301 .30747 L
.72861 .30794 L
.7338 .30826 L
.73866 .30848 L
.74362 .30865 L
.74643 .30872 L
.74904 .30877 L
.75381 .30885 L
.75648 .30888 L
.7589 .3089 L
.76113 .30891 L
.76348 .30893 L
.76606 .30894 L
.76844 .30895 L
.7695 .30895 L
.77065 .30895 L
.77272 .30895 L
.77398 .30896 L
.77518 .30896 L
.77625 .30896 L
.77742 .30896 L
.77864 .30896 L
.77975 .30896 L
.78098 .30896 L
.78227 .30896 L
.78339 .30896 L
.78444 .30896 L
.78681 .30896 L
.79225 .30895 L
.79719 .30895 L
.79969 .30895 L
.80111 .30895 L
.80241 .30895 L
.80355 .30895 L
.8048 .30895 L
.80611 .30895 L
.80734 .30895 L
.80801 .30895 L
.80874 .30895 L
.80943 .30895 L
.81007 .30895 L
.81128 .30895 L
.81257 .30895 L
.81552 .30895 L
.81819 .30895 L
.82308 .30896 L
Mistroke
.82824 .30896 L
.83747 .30897 L
.8583 .30899 L
.86779 .309 L
.87797 .30901 L
.88757 .30902 L
.89631 .30902 L
.90113 .30902 L
.90624 .30902 L
.91542 .30903 L
.92052 .30903 L
.9253 .30903 L
.93055 .30903 L
.93619 .30903 L
.94102 .30903 L
.94551 .30903 L
.95043 .30903 L
.95569 .30903 L
.96122 .30903 L
.96643 .30903 L
.97112 .30903 L
.97619 .30903 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`2booooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2b
ooooo`00T?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`2booooo`00V?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00003oooool4o`0009oooooo
002Hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02o`0009kooooo002Hooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Looooo`00V?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Voooool009Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo09[ooooo002cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Jooooo`00/oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0V_ooool00;?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09[ooooo002c
ooooo`;o00003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09Wooooo002coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Ioooo
o`00/oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0V?ooool00;?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo09Sooooo002cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Hooooo`00/oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Uoooool00;?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo09Oooooo002cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Gooooo`00/oooool2o`0000[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Fooooo`00/oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0U_ooool00;?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09Kooooo002coooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Eoooo
o`00/oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0UOooool00;?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09Gooooo002cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2Dooooo`00/oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0U?ooool00;?ooooo0_l00008ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0U?ooool00;?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo09?ooooo002cooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Cooooo`00/oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Toooool00;?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09;ooooo002Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2B
ooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo09;ooooo002@ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2A
ooooo`00V?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001ooo
ool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Aooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0TOooool009Sooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo097ooooo002Hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`2@ooooo`00V?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0T?ooool00;?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo093ooooo002cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2?ooooo`00/oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Soooool00;?o
oooo0_l00005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Soooool00;?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08oooooo
002cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`2>ooooo`00/oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0S_ooool00;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo08kooooo002cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`2>ooooo`00/oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0SOooool00;?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`;o00001?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2<ooooo`00/oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0S?ooool00;?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08cooooo
002cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`2<ooooo`00/oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0Roooool00;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo08_ooooo002cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`2;ooooo`00/oooool2o`0000?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`2:ooooo`00/oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0R_ooool00;?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08[ooooo002cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`29ooooo`00/oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0ROooool009Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00Go0000oooooooo
ooooooooo`00000Tooooo`03o`000?oooooooooo08Wooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`05o`000?oooooo
ooooooooool000009Oooool00ol0003oooooooooo`28ooooo`00T?ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00Go0000oooooooooooooooo
o`00000Uooooo`03o`000?oooooooooo08Sooooo002Hooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP06ooooo`?o000000?oooooo`000?ooool09?ooool00ol0003ooooo
ooooo`28ooooo`00V?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool0Qoooool009Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000Vooooo`03o`000?oooooooooo08Oooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00Go0000ooooooooooooooooo`00
000Vooooo`03o`000?oooooooooo08Oooooo002Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00Go0000ooooooooooooooooo`00000Wooooo`03
o`000?oooooooooo08Kooooo002cooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooooooo
ool0Q_ooool00;?ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`26ooooo`00
/oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo08Gooooo002cooooo`;o0000
00?oooooo`000?ooool0:?ooool00ol0003oooooooooo`25ooooo`00/oooool01?l0003ooooooooo
ool0000Zooooo`03o`000?oooooooooo08Cooooo002cooooo`04o`000?ooooooooooo`0002[ooooo
00?o0000ooooooooool0Q?ooool00;?ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooo
ooooo`23ooooo`00/oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo08?ooooo
002cooooo`03o`000?oooooo000002cooooo00?o0000ooooooooool0Poooool00;?ooooo00?o0000
ooooool00000;Oooool00ol0003oooooooooo`22ooooo`00/oooool00ol0003oooooo`00000]oooo
o`03o`000?oooooooooo08;ooooo002cooooo`?o0000;_ooool00ol0003oooooooooo`21ooooo`00
/oooool00ol0003oooooo`00000_ooooo`03o`000?oooooooooo083ooooo002cooooo`03o`000?oo
oooo000002oooooo00?o0000ooooooooool0P?ooool001gooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`05odA4A?l0003o0000oc8b<_oMgMd0
8oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Oooool00ol0003o
ooooo`00000Rooooo`Go00001Oooool2ob4Q8@;ooooo00Co0000ooooooooooooA4A40_l000000olb
<S;ogMgMooooo`0Sooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Wooooo000Mooooo`03oeEEEOnYZJWo
oooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool08_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo023ooooo00?o
0000ooooool000008_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B43ooooo`03o`00
0?oooooooooo00;ooooo00?oMgMgoc8b<_ooool09_ooool00omgMgOo<S8booooo`0Sooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Sooooo000Cooooo`Ko00001?oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01Sooooo1_l00007ooooo`03o`000?oo
oooooooo01Wooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooo`00000Sooooo`03oiRHV?lQ8B7ok^k^00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0Gooooo`007_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool09?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;o
oooo023ooooo0_l0000Uooooo`03oiRHV?lQ8B7ok^k^00cooooo00Go0000ooooooooooooMgMgoc8b
<P0Wooooo`03ogMgMolb<S;ooooo02Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8boooo
o`0Hooooo`007_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<027ooooo0_l0000Vooooo`03ogMgMomVIVKooooo00_ooooo0ol000000olb<S;o
c<c<ooooo`0Sooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omEEEGoc<c<ooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool001kooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Sooooo`;o00009oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
02Kooooo00?o0000ooooooooool09oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
01_ooooo000Kooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooo
oooo02?ooooo0_l0000Sooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool01?l0003ooooooooo
ool0000Uooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03
o`000?oooooooooo01_ooooo000Kooooo`Go00003?ooool4o`0002Cooooo1?l0000Tooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0002;ooooo0_l0000Sooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool5o`0002Cooooo1?l0000Sooooo`Go00003?ooool4o`0001[ooooo002cooooo`;o
0000>Oooool2o`0007Sooooo002cooooo`;o0000>oooool2o`0007Kooooo002cooooo`;o0000?Ooo
ool2o`0007Cooooo002cooooo`03o`000?oooooooooo03kooooo0ol0001aooooo`00/oooool00ol0
003oooooooooo`11ooooo`So0000JOooool0013oooooool00018o`00017ooooo000Hooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`Ko0000
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo000Rooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08Oooool007Cooooo1?l0000kooooo`03o`000?oooooo
oooo0;;ooooo001hooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0/_ooool007Wo
oooo00?o0000ooooooooool0=_ooool2o`000;Cooooo001jooooo`03o`000?oooooooooo03Gooooo
0_l0002dooooo`00Noooool00ol0003oooooooooo`0dooooo`;o0000]?ooool007cooooo00?o0000
ooooooooool0<oooool3o`000;?ooooo001looooo`03o`000?oooooooooo03?ooooo0_l0002doooo
o`00OOooool00ol0003oooooooooo`0booooo`;o0000]?ooool007kooooo00?o0000ooooooooool0
<Oooool2o`000;Cooooo001oooooo`03o`000?oooooooooo033ooooo0_l0002dooooo`00P?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooo00000;Cooooo0020ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooool00000]?ooool0087ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooo`00002dooooo`00POooool00ol0003oooooooooo`0]ooooo`04o`000?oooooo0000o`000;?o
oooo0022ooooo`03o`000?oooooooooo02cooooo00?o0000ooooool00000]?ooool008;ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooo`00002dooooo`00Poooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooo00000;Cooooo0023ooooo`03o`000?oooooooooo02[ooooo00Co0000oooo
oooooooo0000]?ooool008Cooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0002d
ooooo`00Q?ooool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`000;Cooooo0025oooo
o`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000]?ooool008Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`02o`000;?ooooo0025ooooo`03o`000?oooooooooo02So
oooo00Co0000oooooooooooo0000]?ooool008Kooooo00?o0000ooooooooool09oooool01?l0003o
ooooooooool0002dooooo`00Q_ooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool00000]?ooool008Oooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000
0;Cooooo0027ooooo`03o`000?oooooooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000;ooooo00Go0000ooooooooooooooooo`00002dooooo`00Qoooool00ol0
003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A002ooooo`05o`000?ooooooooooooooool00000]?ooool008Sooooo00?o
0000ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo00000;Cooooo0028ooooo`03o`000?oooooooooo00gooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00;ooooo00Co0000oooooooo
oooooooo0ol0002booooo`00ROooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000003_ooool01OmgMgOoIVIVoooooooooooo000000?ooooo00?o0000ooooooooool0/_ooool0
08Wooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo410@00oooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01ol0003o^[ZjoooooonHV9So410@ooooool0
00001?ooool00ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01onHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool0
0ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0/_ooool008_ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo002;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2booooo`00S?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00;ooooo0_l0002cooooo`00S?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002=ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00
SOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
/_ooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0;;ooooo002>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2booooo`00S_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0/_ooool008kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`03ooooo`;o0000/oooool008kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;;ooooo002>ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00Soooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002?ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00
Soooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
/_ooool0093ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0;;ooooo002@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool2
o`000;?ooooo002@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2booooo`00T?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool0097ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00TOooool00ol0003oooooooooo`04
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo0;;ooooo002Aooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;;ooooo002Aooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00001_ooool00ol0003oooooooooo`2booooo`00T_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`?o0000
/_ooool009;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOl0003o00001oooool00ol0003oooooooooo`2booooo`00T_ooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOo0000o`000007ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_l0003o000000Oooooo00?o0000ooooooooool0/_ooool009?ooooo
00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo0_l00007ooooo`03
o`000?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2booooo`00U?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0/_ooool009Cooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo002Dooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01oooool2o`000;?ooooo002Eooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00UOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool009Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;;ooooo002F
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2b
ooooo`00U_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0/_ooool009Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0;;ooooo002Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2booooo`00Uoooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Wooooo0_l0002cooooo`00Uoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0/_ooool009Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2booooo`00V?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/_ooool009Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;;ooooo002I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2b
ooooo`00VOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0/_ooool009Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`;o
0000/oooool009[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo0;;ooooo002Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2booooo`00V_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`05onk^k_lb<S;o0000oc8b
<_l000001Oooool00olQ8B7o0000ooooo`03ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool0
0ol0003oooooooooo`2booooo`00V?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo00?o
0000ob4Q8Oooool00oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
/_ooool009Sooooo00Ko410@oooooooooooooooooa0@4?ooool2o`000003ooooool0003o000000Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000Oooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000/_ooool009Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`2booooo`00V?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`2booooo`00V?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`2booooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8booooo`02
ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgoooo
o`05ooooo`03o`000?nj^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01Ooo
ool2oc8b<Y3ooooo001]ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000o`00
0?mgMgOo410@o`0000;ooooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@
4105o`0000?ooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVYoooo
ool000000_ooool00ol0003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_ooool2
o`0000?ooooo00?oQhN7ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool01oooool4o`000003oa0@4?oooooooooo06gooooo001/
ooooo`06ojVYZOl0003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Go
oooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000
ooooooooool01Oooool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`00
00Sooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko
0000ooooo`04ooooo`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00001?ooool00ol0003oooooooooo`1_ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09
o`000?ooooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<
1_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`5ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooooooo06oooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zj
oa0@4003o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooo
oooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oo
ooooooooooooool000000_ooool6o`0000Cooooo00?o0000ooooooooool0Koooool006cooooo00?o
0000ooooooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mE
EEGoQhN71_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool0
1oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q
8OmgMgOoMgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo0000
00cooooo00?o0000ooooooooool0Koooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104
ooooo`04oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4
o`000?l@41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00Co
EEEEogMgMooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@
4?l0003oMgMg00;o000000?oV9RHooooooooool02_ooool00ol0003oooooooooo`1_ooooo`00K?oo
ool01_nYZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko
410@omgMg@0Uooooo`03o`000?oooooooooo06oooooo001]ooooo`05oiRHV?l@413o0000ob4Q8Ol0
00003Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04Oooool00onYZJWoA4A4ooooo`0<ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMooo
ool08oooool00omEEEGoIVIVo`00001aooooo`00OOooool00ol@413o0000o`00000Eooooo`;o0000
2Oooool00ol@413oooooooooo`35ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.2566, -0.635149, \
0.064461, 0.00781155}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.329376 0.658474 [
[.05357 .31688 -12 -9 ]
[.05357 .31688 12 0 ]
[.20238 .31688 -6 -9 ]
[.20238 .31688 6 0 ]
[.35119 .31688 -12 -9 ]
[.35119 .31688 12 0 ]
[.64881 .31688 -9 -9 ]
[.64881 .31688 9 0 ]
[.79762 .31688 -3 -9 ]
[.79762 .31688 3 0 ]
[.94643 .31688 -9 -9 ]
[.94643 .31688 9 0 ]
[.4875 .06599 -24 -4.5 ]
[.4875 .06599 0 4.5 ]
[.4875 .19768 -24 -4.5 ]
[.4875 .19768 0 4.5 ]
[.4875 .46107 -18 -4.5 ]
[.4875 .46107 0 4.5 ]
[.4875 .59277 -18 -4.5 ]
[.4875 .59277 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .32938 m
.05357 .33563 L
s
[(-7.5)] .05357 .31688 0 1 Mshowa
.20238 .32938 m
.20238 .33563 L
s
[(-5)] .20238 .31688 0 1 Mshowa
.35119 .32938 m
.35119 .33563 L
s
[(-2.5)] .35119 .31688 0 1 Mshowa
.64881 .32938 m
.64881 .33563 L
s
[(2.5)] .64881 .31688 0 1 Mshowa
.79762 .32938 m
.79762 .33563 L
s
[(5)] .79762 .31688 0 1 Mshowa
.94643 .32938 m
.94643 .33563 L
s
[(7.5)] .94643 .31688 0 1 Mshowa
.125 Mabswid
.08333 .32938 m
.08333 .33313 L
s
.1131 .32938 m
.1131 .33313 L
s
.14286 .32938 m
.14286 .33313 L
s
.17262 .32938 m
.17262 .33313 L
s
.23214 .32938 m
.23214 .33313 L
s
.2619 .32938 m
.2619 .33313 L
s
.29167 .32938 m
.29167 .33313 L
s
.32143 .32938 m
.32143 .33313 L
s
.38095 .32938 m
.38095 .33313 L
s
.41071 .32938 m
.41071 .33313 L
s
.44048 .32938 m
.44048 .33313 L
s
.47024 .32938 m
.47024 .33313 L
s
.52976 .32938 m
.52976 .33313 L
s
.55952 .32938 m
.55952 .33313 L
s
.58929 .32938 m
.58929 .33313 L
s
.61905 .32938 m
.61905 .33313 L
s
.67857 .32938 m
.67857 .33313 L
s
.70833 .32938 m
.70833 .33313 L
s
.7381 .32938 m
.7381 .33313 L
s
.76786 .32938 m
.76786 .33313 L
s
.82738 .32938 m
.82738 .33313 L
s
.85714 .32938 m
.85714 .33313 L
s
.8869 .32938 m
.8869 .33313 L
s
.91667 .32938 m
.91667 .33313 L
s
.02381 .32938 m
.02381 .33313 L
s
.97619 .32938 m
.97619 .33313 L
s
.25 Mabswid
0 .32938 m
1 .32938 L
s
.5 .06599 m
.50625 .06599 L
s
[(-0.4)] .4875 .06599 1 0 Mshowa
.5 .19768 m
.50625 .19768 L
s
[(-0.2)] .4875 .19768 1 0 Mshowa
.5 .46107 m
.50625 .46107 L
s
[(0.2)] .4875 .46107 1 0 Mshowa
.5 .59277 m
.50625 .59277 L
s
[(0.4)] .4875 .59277 1 0 Mshowa
.125 Mabswid
.5 .09891 m
.50375 .09891 L
s
.5 .13183 m
.50375 .13183 L
s
.5 .16476 m
.50375 .16476 L
s
.5 .2306 m
.50375 .2306 L
s
.5 .26353 m
.50375 .26353 L
s
.5 .29645 m
.50375 .29645 L
s
.5 .3623 m
.50375 .3623 L
s
.5 .39522 m
.50375 .39522 L
s
.5 .42815 m
.50375 .42815 L
s
.5 .49399 m
.50375 .49399 L
s
.5 .52692 m
.50375 .52692 L
s
.5 .55984 m
.50375 .55984 L
s
.5 .03306 m
.50375 .03306 L
s
.5 .00014 m
.50375 .00014 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
176.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .32938 m
.02846 .32937 L
.03279 .32937 L
.03754 .32937 L
.04262 .32937 L
.04795 .32937 L
.053 .32937 L
.05753 .32937 L
.06244 .32937 L
.06751 .32937 L
.07308 .32936 L
.0789 .32936 L
.08435 .32936 L
.0941 .32935 L
.10458 .32933 L
.11468 .32931 L
.12571 .32929 L
.1458 .32923 L
.15593 .3292 L
.1609 .32919 L
.16548 .32918 L
.16805 .32917 L
.17076 .32917 L
.17217 .32917 L
.17349 .32917 L
.17424 .32917 L
.17493 .32917 L
.17572 .32917 L
.17648 .32917 L
.17768 .32917 L
.17896 .32917 L
.18005 .32917 L
.18125 .32917 L
.18254 .32917 L
.18393 .32917 L
.18645 .32918 L
.19141 .32919 L
.19602 .3292 L
.20151 .32922 L
.20649 .32923 L
.20901 .32924 L
.21043 .32924 L
.21174 .32924 L
.21288 .32924 L
.21414 .32924 L
.21546 .32924 L
.21669 .32924 L
.21737 .32924 L
.2181 .32924 L
.21944 .32923 L
Mistroke
.22074 .32923 L
.22195 .32922 L
.22468 .3292 L
.22621 .32918 L
.22759 .32917 L
.22992 .32913 L
.23248 .32908 L
.23515 .32901 L
.23764 .32893 L
.2421 .32873 L
.24687 .32845 L
.25248 .32797 L
.25778 .32734 L
.26254 .32658 L
.26771 .32551 L
.27257 .32422 L
.27713 .32269 L
.28256 .32041 L
.28752 .31778 L
.29764 .3104 L
.30296 .3052 L
.30854 .29852 L
.31811 .28369 L
.32832 .26231 L
.33796 .23623 L
.3467 .2075 L
.36755 .12422 L
.37669 .08614 L
.38674 .0492 L
.39141 .0354 L
.39398 .02905 L
.39642 .02398 L
.39868 .02018 L
.39987 .01856 L
.40114 .01712 L
.40221 .01617 L
.40339 .01539 L
.40445 .01493 L
.40546 .01472 L
.40661 .01476 L
.40788 .01515 L
.4092 .01595 L
.41043 .01707 L
.41158 .01845 L
.41263 .01999 L
.41498 .02446 L
.41752 .03084 L
.42026 .03966 L
.42526 .06075 L
.43014 .0876 L
Mistroke
.4347 .11808 L
.44511 .204 L
.46614 .41195 L
.47653 .50428 L
.48165 .54114 L
.4864 .56852 L
.49069 .58682 L
.49309 .59419 L
.49527 .59902 L
.49651 .60099 L
.49766 .60227 L
.49892 .6031 L
.49955 .60329 L
.50025 .60332 L
.50142 .60294 L
.50267 .60196 L
.50386 .60047 L
.50493 .59865 L
.50722 .59334 L
.50975 .58524 L
.51486 .56195 L
.51959 .53284 L
.52403 .49979 L
.5448 .30225 L
.55374 .21466 L
.56329 .13297 L
.56878 .09438 L
.57377 .06564 L
.57878 .0432 L
.58351 .02807 L
.58594 .02254 L
.58727 .02015 L
.58852 .01833 L
.58967 .01697 L
.59072 .01602 L
.59188 .01527 L
.59313 .01481 L
.59378 .01472 L
.59446 .01472 L
.59569 .01498 L
.59645 .0153 L
.59716 .01572 L
.59848 .01677 L
.59976 .01811 L
.60093 .01962 L
.60356 .02394 L
.60846 .03505 L
.61383 .05106 L
.62467 .09164 L
.64587 .17967 L
Mistroke
.66516 .24533 L
.67477 .26944 L
.6852 .28934 L
.69505 .30296 L
.70414 .31193 L
.7088 .31544 L
.71381 .31854 L
.72286 .32269 L
.72838 .3245 L
.73363 .32582 L
.73834 .32674 L
.74348 .3275 L
.74879 .32809 L
.75379 .32849 L
.75829 .32875 L
.76315 .32895 L
.76568 .32903 L
.76846 .3291 L
.77136 .32915 L
.77407 .32919 L
.77537 .3292 L
.7766 .32921 L
.77892 .32923 L
.78021 .32923 L
.78141 .32924 L
.78272 .32924 L
.78338 .32924 L
.78412 .32924 L
.78533 .32924 L
.78646 .32924 L
.7877 .32924 L
.7884 .32924 L
.78903 .32924 L
.7903 .32924 L
.79169 .32924 L
.7942 .32923 L
.80345 .3292 L
.80872 .32919 L
.8116 .32918 L
.8143 .32918 L
.8166 .32917 L
.81778 .32917 L
.81906 .32917 L
.81979 .32917 L
.82047 .32917 L
.82117 .32917 L
.8218 .32917 L
.82302 .32917 L
.82431 .32917 L
.82551 .32917 L
Mistroke
.82664 .32917 L
.82787 .32917 L
.82919 .32917 L
.83189 .32917 L
.83435 .32918 L
.83909 .32919 L
.84358 .3292 L
.86441 .32926 L
.88266 .32931 L
.89304 .32933 L
.90278 .32934 L
.91232 .32935 L
.91768 .32936 L
.92259 .32936 L
.93283 .32937 L
.93798 .32937 L
.9436 .32937 L
.94786 .32937 L
.95187 .32937 L
.95937 .32937 L
.96357 .32937 L
.96744 .32937 L
.97619 .32938 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool2
o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002C
ooooo`?o00007Oooool00ol0003oooooooooo`0Kooooo`?o0000U?ooool009;ooooo0_l00002oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02o`00
09?ooooo002Booooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`0Joooo
o`05o`000?ooooooooooooooool00000Toooool0097ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2@ooooo`00TOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo093o
oooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool0093ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`;o00006Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo08oooooo002?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0S_ooool008oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2>oooo
o`00Soooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08kooooo002>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0SOooool008kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2=ooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08gooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0SOooool008go
oooo00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0SOooool008gooooo00?o0000ooooooooool02?ooool01OmgMgOo
V9RHooooool0003oMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002=ooooo`03
o`000?oooooooooo00Ko00000_ooool01Ol@413oooooooooool0003o410@00_ooooo1Ol00006oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2<oooo
o`00SOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o00002oooool01?m4A4Co
gMgMooooool00007ooooo`?o00005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
08cooooo002<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_l0000;ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooo
oooo0000oa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo002<ooooo`03o`000?oooooooooo00Wo
oooo00GoMgMgoiRHV?ooooooV9RHo`00000<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo002<ooooo`03
o`000?oooooooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bo`00000=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
08[ooooo002;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0R_ooool008_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`00Roooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0ROooool008[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`29oooo
o`00R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo0_l0000Eooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool008[ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`28ooooo`00R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo08Sooooo0029ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0R?ooool0
08Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0029ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Qoooool008Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`27ooooo`00R?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0028oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Q_ooool008Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`26ooooo`00R?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo0_l0000Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Q_ooool008Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26ooooo`00Qoooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo0027ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0QOooool008Oooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`25ooooo`00Q_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo
0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0QOooool008Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`24ooooo`00Q_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo08Cooooo0025ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Q?ooool008Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`00QOoo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo0_l0000Booooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0Poooool008Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`23ooooo`00Q?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
08?ooooo0024ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Poooool008Cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`22ooooo`00Poooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo08;ooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0P_ooool008?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`22oooo
o`00Poooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01?l0
003oooooob4Q8OlQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0POooool008;ooooo00?o0000ooooooooool04oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo087ooooo0022ooooo`03o`000?oooooooooo00_ooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo0022
ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Kooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00013ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`20ooooo`00P_ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo083ooooo0021
ooooo`03o`000?oooooooooo01Cooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0P?ooool0087ooooo00?o0000ooooooooool05?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01?ooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo01Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`03o`000?oooooooooo00Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1oooooo`00
P?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
07kooooo001oooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0O_ooool007oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1nooooo`00O_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0OOooool007kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1m
ooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07gooooo001mooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo07cooooo001looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Noooool0
07cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo07_ooooo001kooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0N_ooool007_ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0=ooooo`;o00003_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07[ooooo001k
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool007[ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo07Wooooo001iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
N?ooool007Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1hooooo`00N?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07Oooooo001gooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0M_ooool007Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1fooooo`007?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0Mooooo`03o`000?oooooooooo
00;ooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo1Ol00005
ooooo`;o8B4Q1Oooool01om4A4Co0000o`000?lb<S;ogMgMooooool000008Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02Gooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Hooooo`007?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0Vooooo`03ogMgMolb<S;ooooo01_ooooo00?o0000ooooooooool00oooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool0000Tooooo`03ogMgMolb
<S;ooooo02Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05ooo
ool001;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06Oooool6
o`0000Oooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooo
oooo01Gooooo00?oV9RHob4Q8Oo^k^h04Oooool01?l0003oooooooooool0000Tooooo`03o`000?oo
oooooooo02?ooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Fooooo`007Oooool0
0olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool04_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool08?ooool0
0omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05oooool0
01gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00Kooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool07?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo000Moooo
o`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Joooo
o`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00Go0000okZj^_ooooooV9RHoa0@400<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`05oa0@4?oo
oooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`006_ooool5o`0000cooooo1?l0
000Uooooo`Co00006?ooool2o`0000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co0000
5Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00008ooooo`03o`000?oooooooooo01Wo
oooo1?l0000Tooooo`Go00003?ooool4o`0001Wooooo001^ooooo`;o0000=Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool2o`0006oooooo
001]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo03Cooooo0_l0001]ooooo`00Joooool2o`0003Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0J_ooool006Sooooo0ol0000jooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`?o0000JOooool0067ooooo1ol0000mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`Go
0000I?ooool000ooooooool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo023ooooo
002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2Tooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0Y?ooool00:Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0:Cooooo002Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2Uooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0YOooool00:Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Vooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`00Y_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0YOooool00:Ko
oooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o0000ooooooooool0YOooool00:Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo
002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2Uooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0YOooool00:Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0:Kooooo002Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Vooooo`00Yoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Wooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`00Yoooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:Oo
oooo00?o0000ooooooooool02Oooool2o`0000[ooooo00?o0000ooooooooool0Y_ooool00:Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Vooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:Oo
oooo002Xooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03o`000?oooooooooo0:Oooooo
002Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Wooooo`00ZOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Z?ooool00:Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool009So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2Xooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?l0003ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:Sooooo002Hooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So0000onk^kP07ooooo`?o00001_ooool00ol0003oooooooooo`2Yooooo`00V?ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0:Wooooo002Hooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oMgMgofIVIP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool0
09Sooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00V?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_l0003oV9RHoa0@4006ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0ZOooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Wooooo
002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Yooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Ooo
ool2o`0000Kooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002[ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo
002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Zoooool00:cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`03o`000?oooooooooo0:cooooo002/ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo
002]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2/ooooo`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0:cooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03o`000?oooooo
oooo00;ooooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002^ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2]ooooo`00[oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0[Oooool00:oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo0:gooooo002_ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`2^ooooo`00[oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0[_ooool00:oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo0:kooooo002`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0[_ooool00;3ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`2_oooo
o`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000Go410@oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`000;7ooooo002Hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo0:oooooo002Hooooo`05oa0@4?ooooooooooooooool@4100
2oooool5o`0000Cooooo00?o0000ooooool000000_l0002booooo`00V?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001Oooool01Ol0003oooooo`000?oooooo0000
0;;ooooo002Hooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00005
ooooo`05o`000?oooooo0000ooooool00000/_ooool009Sooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000Kooooo0ol0002cooooo`00V?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`2booooo`00V?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8boooo
o`02ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`05ooooo`03o`000?nj^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd0
1Oooool2oc8b<Y3ooooo001]ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000
o`000?mgMgOo410@o`0000;ooooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjoooo
ool@4105o`0000?ooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVY
ooooool000000_ooool00ol0003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_oo
ool2o`0000?ooooo00?oQhN7ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool01_ooool5o`00073ooooo001/ooooo`06ojVYZOl0
003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko0000ooooo`04oooo
o`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko000000Kooooo
oiRHV?lQ8B7ok^k^oooooom4A4A`ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09o`000?oo
ooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<1_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03oiRHV?lQ8B7o
k^k^077ooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@4003
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000000_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0L?ooool006cooooo00?o0000oooo
ooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mEEEGoQhN7
1_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool01oo^k^ko
0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo000000cooooo
00?oMgMgofIVI_ooool0Koooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104ooooo`04
oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4o`000?l@
41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00CoEEEEogMg
Mooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool02oooool00ol0003oooooooooo`1^ooooo`00K?ooool01_nY
ZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgM
g@0Rooooo`05o`000?nj^[[ooooooiRHV?l@4100L?ooool006gooooo00GoV9RHoa0@4?l0003o8B4Q
o`00000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`0Rooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0L?ooool007gooooo00?o410@o`000?l00000
5Oooool2o`0000Wooooo00?o410@ooooooooool0aOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -0.500216, \
0.0641612, 0.00579995}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30902 0.818412 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .0635 -24 -4.5 ]
[.4875 .0635 0 4.5 ]
[.4875 .14534 -24 -4.5 ]
[.4875 .14534 0 4.5 ]
[.4875 .22718 -24 -4.5 ]
[.4875 .22718 0 4.5 ]
[.4875 .39086 -18 -4.5 ]
[.4875 .39086 0 4.5 ]
[.4875 .4727 -18 -4.5 ]
[.4875 .4727 0 4.5 ]
[.4875 .55454 -18 -4.5 ]
[.4875 .55454 0 4.5 ]
[.5 .63053 -58.625 0 ]
[.5 .63053 58.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .0635 m
.50625 .0635 L
s
[(-0.3)] .4875 .0635 1 0 Mshowa
.5 .14534 m
.50625 .14534 L
s
[(-0.2)] .4875 .14534 1 0 Mshowa
.5 .22718 m
.50625 .22718 L
s
[(-0.1)] .4875 .22718 1 0 Mshowa
.5 .39086 m
.50625 .39086 L
s
[(0.1)] .4875 .39086 1 0 Mshowa
.5 .4727 m
.50625 .4727 L
s
[(0.2)] .4875 .4727 1 0 Mshowa
.5 .55454 m
.50625 .55454 L
s
[(0.3)] .4875 .55454 1 0 Mshowa
.125 Mabswid
.5 .07986 m
.50375 .07986 L
s
.5 .09623 m
.50375 .09623 L
s
.5 .1126 m
.50375 .1126 L
s
.5 .12897 m
.50375 .12897 L
s
.5 .16171 m
.50375 .16171 L
s
.5 .17807 m
.50375 .17807 L
s
.5 .19444 m
.50375 .19444 L
s
.5 .21081 m
.50375 .21081 L
s
.5 .24355 m
.50375 .24355 L
s
.5 .25992 m
.50375 .25992 L
s
.5 .27628 m
.50375 .27628 L
s
.5 .29265 m
.50375 .29265 L
s
.5 .32539 m
.50375 .32539 L
s
.5 .34176 m
.50375 .34176 L
s
.5 .35812 m
.50375 .35812 L
s
.5 .37449 m
.50375 .37449 L
s
.5 .40723 m
.50375 .40723 L
s
.5 .4236 m
.50375 .4236 L
s
.5 .43997 m
.50375 .43997 L
s
.5 .45633 m
.50375 .45633 L
s
.5 .48907 m
.50375 .48907 L
s
.5 .50544 m
.50375 .50544 L
s
.5 .52181 m
.50375 .52181 L
s
.5 .53818 m
.50375 .53818 L
s
.5 .04713 m
.50375 .04713 L
s
.5 .03076 m
.50375 .03076 L
s
.5 .01439 m
.50375 .01439 L
s
.5 .57091 m
.50375 .57091 L
s
.5 .58728 m
.50375 .58728 L
s
.5 .60365 m
.50375 .60365 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -119.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Galerkin) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
123.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.250 13.000 moveto
(H) show
134.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.250 13.000 moveto
(L) show
146.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
158.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
164.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
170.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
176.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02846 .30902 L
.03279 .30902 L
.03754 .30902 L
.04262 .30901 L
.04795 .30901 L
.053 .30901 L
.05753 .309 L
.06244 .309 L
.06751 .30899 L
.07308 .30898 L
.0789 .30897 L
.08435 .30895 L
.0941 .30891 L
.09957 .30888 L
.10458 .30884 L
.11442 .30876 L
.12357 .30865 L
.1336 .30849 L
.14429 .3083 L
.16426 .30788 L
.16974 .30777 L
.17273 .30772 L
.17552 .30768 L
.1781 .30765 L
.18045 .30763 L
.1818 .30762 L
.18307 .30762 L
.18376 .30761 L
.18441 .30761 L
.18512 .30761 L
.18587 .30761 L
.18707 .30761 L
.18834 .30761 L
.18942 .30762 L
.1906 .30763 L
.19187 .30764 L
.19324 .30765 L
.19569 .30769 L
.19818 .30775 L
.20053 .30781 L
.20492 .30797 L
.21016 .30824 L
.215 .30857 L
.22031 .30904 L
.22594 .30967 L
.23537 .31109 L
.24067 .31214 L
.24551 .31328 L
.25491 .31614 L
Mistroke
.26382 .31994 L
.26887 .32273 L
.27344 .32577 L
.27836 .32969 L
.28367 .33486 L
.29315 .34702 L
.30207 .36277 L
.3116 .38517 L
.32205 .41696 L
.34312 .50014 L
.35317 .54202 L
.36267 .57603 L
.36792 .59018 L
.37089 .59615 L
.3723 .59842 L
.37363 .60018 L
.37483 .60145 L
.37593 .60233 L
.37715 .603 L
.37847 .60332 L
.37966 .60325 L
.38097 .60276 L
.38163 .60235 L
.38233 .60179 L
.3836 .60045 L
.38484 .59872 L
.3862 .59634 L
.38895 .58996 L
.39149 .58214 L
.39387 .57314 L
.39923 .54689 L
.40499 .50984 L
.42515 .32612 L
.43531 .2239 L
.44067 .17493 L
.44637 .13021 L
.45133 .09949 L
.45415 .08602 L
.45681 .07628 L
.45799 .0729 L
.45924 .06999 L
.4603 .06805 L
.46146 .06648 L
.46272 .06548 L
.46342 .06522 L
.46406 .06519 L
.4653 .06565 L
.46648 .06672 L
.46763 .06838 L
.46887 .07082 L
Mistroke
.4711 .07696 L
.47376 .08708 L
.47619 .09894 L
.48146 .13256 L
.48647 .17318 L
.50491 .36098 L
.51451 .45338 L
.51978 .49427 L
.52236 .51087 L
.52473 .52388 L
.52695 .53392 L
.52937 .54256 L
.53063 .54603 L
.53181 .54864 L
.53305 .55072 L
.53375 .55158 L
.53438 .55217 L
.5355 .55277 L
.53653 .55282 L
.53767 .55233 L
.53887 .55117 L
.53992 .54964 L
.5409 .54777 L
.54313 .54195 L
.54556 .5332 L
.54783 .5229 L
.55297 .49243 L
.56332 .40712 L
.58183 .22171 L
.59237 .12809 L
.59754 .09084 L
.60231 .06277 L
.60664 .04282 L
.60886 .03472 L
.61123 .0276 L
.61361 .02207 L
.61584 .01833 L
.61719 .0167 L
.61848 .01561 L
.61964 .015 L
.6209 .01472 L
.62155 .01472 L
.62224 .01484 L
.62347 .01533 L
.62479 .01625 L
.62554 .01695 L
.62624 .0177 L
.62866 .02112 L
.63125 .02605 L
.63616 .03851 L
Mistroke
.64063 .0528 L
.66162 .13801 L
.67169 .17853 L
.68237 .21545 L
.69226 .24269 L
.70153 .2622 L
.71034 .27598 L
.71981 .28668 L
.72519 .29125 L
.73032 .29481 L
.73536 .29769 L
.73994 .29986 L
.74952 .30337 L
.75478 .30484 L
.75973 .30599 L
.76856 .3076 L
.7735 .3083 L
.77812 .30884 L
.78308 .30931 L
.78762 .30966 L
.79265 .30996 L
.79545 .31008 L
.79805 .31018 L
.80051 .31026 L
.80323 .31033 L
.80596 .31038 L
.80745 .3104 L
.80886 .31041 L
.81011 .31042 L
.81143 .31043 L
.81256 .31043 L
.81379 .31043 L
.81449 .31043 L
.81512 .31043 L
.81585 .31043 L
.81654 .31043 L
.81777 .31042 L
.81911 .31041 L
.82146 .31039 L
.82399 .31036 L
.82857 .31029 L
.83897 .3101 L
.86001 .30966 L
.87014 .30948 L
.88118 .30933 L
.89161 .30923 L
.90128 .30916 L
.90637 .30913 L
.91187 .3091 L
.91671 .30909 L
Mistroke
.92183 .30907 L
.92646 .30906 L
.93153 .30905 L
.9358 .30904 L
.94045 .30904 L
.94509 .30903 L
.94948 .30903 L
.95339 .30903 L
.95771 .30903 L
.96237 .30902 L
.96731 .30902 L
.97189 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool2o`0002Gooooo0ol0002;ooooo`00/oooool00ol0003oooooooooo`0Soooo
o`04o`000?ooooooooooo`0008_ooooo002cooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`28ooooo`00/oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool00;?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002cooooo`;o00008_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002cooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`26ooooo`00/oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool00;?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Go
oooo002cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`25ooooo`00/oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0QOooool00;?ooooo0_l0000Qooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Q?ooool00;?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo08Cooooo002Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`24ooooo`00V?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Q?ooool0093ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`23ooooo`00V?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00Ko0000ooooooooooooooooojVYZOl@4106ooooo`?o
00007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08?ooooo002Hooooo`05o`00
0?ooooooooooooooool000002Oooool3o`000004ooooool@413o0000okZj^PKooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08?ooooo002Hooooo`05
oa0@4?ooooooooooooooool@41002Oooool01ol0003oooooo`000?l0003ooooookZj^_lQ8B401_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Pooo
ool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`08o`000?oooooooooooa0@4?l0003o
oooookZj^_l00006ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`22ooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00So0000oooo
ooooooooZJVYoa0@4?l0003o410@ojVYZ@Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo08;ooooo002Uooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool2o`0001kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`22ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08;ooooo002Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0POooool00:Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`21ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo087ooooo002Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0POoo
ool00:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o00007_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo002Sooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0P?ooool00:?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`20ooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo083ooooo
002Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ooooool00:;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00007Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo07oooooo002Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Ooooool00:;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1oooooo`00
X_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07kooooo002Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0O_ooool00:7ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`;o00007?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo07kooooo002Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0O_ooool00:7o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1mooooo`00V?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00?o0000ob4Q8OlQ8B401?ooool6o`0000Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo002Hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01?ooool00ol0003o8B4Qob4Q8@04ooooo`06oiRHV?lQ8B7ok^k^oooo
oom4A4Co00001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0OOooool0093ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0ol0003oooooooooo`05ooooo`05oiRHV?lQ8B7ok^k^ooooool000001Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0OOooool009Sooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^kooooo
o`000004ooooo`?o00006_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07cooooo
002Hooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`04ogMg
MomVIVKoooooo`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo07cooooo002Hooooo`05oa0@4?ooooooooooooooool@41001?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo07cooooo002Hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool00ol0003oooooooooo`05ooooo`07o`000?nj^[[ooooooiRHV?l@413oooooo`000004
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1l
ooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool01Oooool0
1onHV9So410@o`000?lQ8B7oc<c<ooooool000001?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0O?ooool00:3ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`;o00006oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo07_ooooo002Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool0
0:3ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1kooooo`00X?ooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo07_ooooo002Pooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000L
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00:3ooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooooooool2o`0001[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1jooooo`00X?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo07[ooooo002Poooo
o`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0N_ooool00:3ooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1i
ooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`000?oooooooooo
00kooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo07Wooooo002Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0000Joooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000oooooooo
ool03_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0N?ooool009oooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000oooooooo
ool03_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Moooool009oooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Moooool009oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02o`0001Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1gooooo`00W_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0001[o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1fooooo`00W_ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1fooooo`00V?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000oooool2ob4Q
8@Gooooo1?l000001?l@413oooooooooool00002ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1fooooo`00V?ooool01omgMgOoV9RHoooooonHV9So
MgMgooooool000000oooool2ob4Q8@Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
000Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0MOooool0093ooooo1_l00002
ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_l0000Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
MOooool009Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?o0000oooooooo
ool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0MOooool009Sooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0M?ooool009Sooooo00Oo410@oooooooooooooooooa0@4?oooooo000000cooooo00?o0000
ooooooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0M?ooool009Sooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000cooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0M?ooool009Sooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000[ooooo
00?oEEEEofIVI_l000001Oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Loooool009gooooo00?o0000ooooooooool04Oooool01?l0003oooooo`00
0?l0000Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Loooool009gooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0Loooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000I
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0L_ooool009gooooo00?o0000oooo
ooooool04_ooool2o`0001Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1boooo
o`00WOooool00ol0003oooooooooo`0Booooo`;o00006Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo077ooooo002Mooooo`03o`000?oooooooooo01;ooooo0ol0000Hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0LOooool009gooooo00?o0000ooooooooool04_oo
ool2o`0001Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1`ooooo`00WOooool0
0ol0003oooooooooo`0Booooo`;o00006Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo073ooooo000Looooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd09?ooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo1Ol00005ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00cooooo00?o0000ooooooooool04_ooool2o`0001Wooooo
00?o0000ooooooooool02Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01oooool00ol0003oooooooooo`0Iooooo`05odA4A?l0003o0000oc8b<_oMgMd09Oooool00ol0
003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo000Loooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b
<_ooool08Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00_ooooo00?o0000ooooooooool04_ooool2o`0001Sooooo00?o0000ooooooooool02_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo00?o
0000ooooooooool06oooool00omgMgOo<S8booooo`0Tooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo01Oooooo000Booooo`Ko00001?ooool00onYZJWoEEEEooooo`0@
ooooo`03o`000?oooooooooo01Wooooo1_l00007ooooo`03o`000?oooooooooo01Sooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`;o00006?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?oZJVY
oeEEEOooool04?ooool00ol0003oooooooooo`0Fooooo`007Oooool00olQ8B7oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo02Kooooo00?oMgMgoc8b<_ooool08oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo00[ooooo00?o0000ooooooooool04oooool3o`0001Oooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Sooooo00?o0000oooo
ooooool06_ooool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b
<_ooool05oooool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Uooooo`03ogMgMomVIVKooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo01?ooooo0_l0000Hooooo`03o`000?oo
oooooooo00gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo
00?o0000ooooooooool05_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oEEEEolc<c?oo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo000Mooooo`03ojVYZOmgMgOooooo00_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`;o00006?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003o
ooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0>
ooooo`;o00005Oooool00ol0003oooooooooo`0Uooooo`05oa0@4?oooooooooooooooolb<S803?oo
ool00ol0003oooooooooo`0Jooooo`006_ooool5o`0000cooooo1?l0000Uooooo`Co00008oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
3?ooool4o`0000oooooo00?o0000ooooooooool04_ooool4o`0002Cooooo1Ol0000<ooooo`Co0000
6Oooool009cooooo00?o0000ooooooooool05?ooool2o`0001Oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1Xooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0;oooool2o`0006Sooooo002Looooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0aooooo`Go0000Hoooool009co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0H?ooool009cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Sooooo1Ol0001Mooooo`003oooooooo`0004[o00004?oo
ool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool5o`0000Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05oooooa?o00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Kooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool3o`00
01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool08?ooool006?ooooo0ol0000eooooo`03o`000?oooooooooo01Go
oooo0_l0000Fooooo`03o`000?oooooooooo09[ooooo001Vooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05Oooool2o`0001Kooooo00?o0000ooooooooool0V_ooool006Oooooo0_l0
000booooo`03o`000?oooooooooo01Gooooo0_l0000Fooooo`03o`000?oooooooooo09[ooooo001Y
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05Oooool2o`0001Kooooo00?o0000
ooooooooool0V_ooool006[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eoooo
o`;o00005_ooool00ol0003oooooooooo`2Jooooo`00Joooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001/ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ooooooooool0
Voooool006cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Eooooo`;o00005Ooo
ool00ol0003oooooooooo`2Kooooo`00KOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01Kooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001^ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool05_ooool2o`0001Gooooo00?o0000ooooooooool0Voooool006oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000001Co
oooo00?o0000ooooooooool0Voooool006oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0Voooool0073ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool0Voooool0077ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0F
ooooo`?o00005?ooool00ol0003oooooooooo`2Kooooo`00LOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`2Koooo
o`00L_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool0
00004oooool00ol0003oooooooooo`2Looooo`00L_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00Looo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool000004ooo
ool00ol0003oooooooooo`2Looooo`00Loooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00M?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo01Oooooo0ol0000Cooooo`03o`000?oooooooooo
09cooooo001dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo09cooooo001dooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo
09cooooo001eooooo`03o`000?oooooooooo023ooooo00Gok^k^o`000?l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo00004_ooool0
0ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0Pooooo`05ogMgMol0003ooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
000Booooo`03o`000?oooooooooo09cooooo001fooooo`03o`000?oooooooooo01oooooo00Go410@
o`000?oooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo1?l0000Booooo`03o`000?oo
oooooooo09cooooo001fooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
000>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004Oooool00ol0003ooooo
ooooo`2Mooooo`00M_ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00017ooooo00?o0000oooooooo
ool0WOooool007Oooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo
09gooooo001gooooo`03o`000?oooooooooo01kooooo00Go0000oiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2M
ooooo`00Moooool00ol0003oooooooooo`0Nooooo`05o`000?lb<S;o0000oc8b<_o^k^h03?ooool0
0omEEEGoIVIVo`000007ooooo`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`2M
ooooo`00N?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000@ooooo`03o`000?oooooooooo09gooooo001hooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000
ooooooooool0WOooool007Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`2Mooooo`00NOooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo09kooooo001iooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool0
07Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`;o00000_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oooo
ooooool0W_ooool007[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`05
o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool007_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o00000_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo09oooooo001kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Woooool007_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2Oooooo`00Noooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo001loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool007cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Jooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo09oooooo001looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Woooool007gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00OOooool0
0ol0003oooooooooo`0Fooooo`07o`000?ooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0:3ooooo001mooooo`03o`000?oooooooooo01Kooooo00Oo0000oooooomgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0X?ooool007go
oooo00?o0000ooooooooool05_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0X?ooool007kooooo00?o0000ooooooooool05?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00O_ooool00ol0003ooooo
ooooo`0Dooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Pooooo`00O_ooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`00O_ooool00ol0003ooooo
ooooo`0Dooooo`08o`000?ooooooooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0XOooool007oooooo00?o0000ooooooooool04oooool02?l0003oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo001oooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool2o`0000Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Qooooo`00Ooooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0:7ooooo001oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0XOoo
ool0083ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Qooooo`00P?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo0020ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0XOooool0083ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Looooo`;o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo
0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_ooool0087ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X_ooool0087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`;o0000
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0022ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0X_ooool008;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Rooooo`00P_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0:?ooooo0022ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Xoooool008;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`;o00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:?ooooo0023ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
Y_ooool008?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00002Vooooo`00Poooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool0002Wooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00Kooooo00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo0:Kooooo0024oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`?o0000Yoooool0
08Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000003_ooool00onYZJWo410@ooooo`05ooooo`?o0000/_ooool008Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0;;ooooo0025ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zj
ob4Q8Oooool01Oooool00ol0003oooooooooo`2booooo`00QOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?nHV9So
oooookZj^_l000001_ooool00ol0003oooooooooo`2booooo`00QOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`2booooo`00QOooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo023ooooo0_l0002cooooo`00Q_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0/_ooool008Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2booooo`00
Qoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
/_ooool008Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o0000/ooo
ool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0;;ooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0/_ooool008Wooooo00Go0000ooooooooooooooooo`00000Uooooo`03
o`000?oooooooooo0;;ooooo002:ooooo`Co00009Oooool00ol0003oooooooooo`2booooo`00Rooo
ool2o`0002Kooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0
003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooo
ooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00/_ooool00onj^[[o<S8booooo`02ooooo`04o`000?oooooo
ooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`05ooooo`03o`000?nj
^[[ooooo08oooooo002cooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01Oooool2oc8b<Y3ooooo001]
ooooo`05ojVYZOl@413o0000oa0@4?mEEED00oooool01_nHV9So0000o`000?mgMgOo410@o`0000;o
oooo1Ol00003ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo0_l0
0002ooooo`03oa0@4?l0003o000000;ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00oooool01onHV9So410@o`000?l0003oZJVYooooool000000_ooool00ol0
003oooooooooo`05ooooo`04oeEEEOnHV9Soooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7
ofIVI_ooool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool01_ooool01OnHV9So410@o`000?lb<S;oc<c<073ooooo001/ooooo`06ojVYZOl0
003o^[Zjooooooo<c<co00000oooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003oooooonk^k_lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo^k^ko0000ooooo`04oooo
o`03olc<c?l0003o410@00cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko000000Kooooo
oa0@4?nj^[[oooooogMgMolb<S9`ooooo`00K?ooool00olQ8B7oZJVYooooo`02ooooo`09o`000?oo
ooooooooooooool@413oQhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oiRHV?lb<S;oc<c<1_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40_ooooo00?o<S8booooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo06kooooo001/ooooo`03o`000?oooooooooo00?o000000Go410@oooooooooooo^[Zjoa0@4003
o`0000Gooooo00?o0000ooooooooool00oooool6o`0000?ooooo00?o0000ooooooooool01Oooool0
0ol0003o410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000000_ooool6o`0000Cooooo00?oZJVYoa0@4?ooool0Koooool006cooooo00?o0000oooo
ooooool02Oooool00oo<c<co0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Gooooo00Co0000onk^k_mEEEGoQhN7
1_ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000001_ooool01oo^k^ko
0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<PCooooo00?ok^k^o`000?ooool04oooool01Ol0003oQhN7oooooonYZJWo000000_ooooo
00?o410@o`000?nj^[X0L?ooool006cooooo00Ko8B4QojVYZOooooooooooonk^k_l@4104ooooo`04
oc8b<_l0003o0000oiRHV0Gooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43ooooo`05o`000?ooooooA4A4o`000?l@
41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHoooooooo
ool01?ooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00Sooooo00CoEEEEogMg
Mooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`0Booooo`03oa0@4?l0003o
MgMg00;o000000?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1_ooooo`00K?ooool01_nY
ZJWo8B4QomgMgOooooooQhN7o`0000gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Kooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgM
g@0Rooooo`05oa0@4?nHV9SooooookZj^_l00000L?ooool006gooooo00GoV9RHoa0@4?l0003o8B4Q
o`00000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMg
ooooo`0Rooooo`05ojVYZOl@413o0000oa0@4?nYZJT0L?ooool007gooooo00?o410@o`000?l00000
5Oooool2o`0000Wooooo00?o410@ooooooooool0aOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -0.377589, \
0.0641612, 0.0046665}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: 2D Drumhead Eigenmodes", "Section",
  CellTags->{"i:48", "c:37"}],

Cell[TextData[{
  "The Galerkin method for determining eigenmodes works in any number of \
spatial dimensions: no mention of dimensionality was made in Eqs. ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(6.3.11)",
    ButtonData:>"(6.3.11)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, we can find the eigenmodes for any spatial linear operator in \
a region of almost any shape (subject to the restrictions discussed in Sec. \
",
  ButtonBox["6.1.2",
    ButtonData:>"c:4",
    ButtonStyle->"Hyperlink"],
  "). Below, we find the low-order modes of a 2D drumhead with an unusual \
parabolic shape. The boundary of the drumhead is specified by the equations \
",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\^2\)]],
  ". These eigenmodes satisfy the following PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\( \[Psi]\_n\)(x, 
            y)\)\  = \(\[Lambda]\_n\) \(\(\[Psi]\_n\)(x, y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "subject to the boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\^2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIn order to match the boundary conditions, our basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_\(i\ j\)}\)]],
  "are chosen as ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(i\ j\) = 
        x\^i\ y\^j\ \((y - 1)\) \((y - x\^2)\)\)]],
  ". The one piece of tricky business is to note that, in order to construct \
the matrices  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_\(m\ n\)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\)\)]],
  ", the counters ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " must be converted to a single counter ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that runs over all ",
  Cell[BoxData[
      \(TraditionalForm\`\((M + 1)\)\^2\)]],
  " basis functions.  This is most easily accomplished by means of the ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Quotient",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions. The function ",
  StyleBox["Quotient[m,n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " gives the number of times that",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " can be divided into ",
  Cell[BoxData[
      FormBox[
        StyleBox["m",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["m",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "=", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["Quotient",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["n",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}]}]}]}], TraditionalForm]]],
  StyleBox[" ",
    FontWeight->"Bold"],
  " is what is left over after taking away the multiples of",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ". For example, ",
  Cell[BoxData[
      FormBox[
        StyleBox[Cell[TextData[{
            "Quotient[7,3]",
            StyleBox["=2",
              FontFamily->"Times",
              FontWeight->"Plain"]
          }]],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(Mod[7, 3]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", \(7 - 3\[Cross]\ 2 = 1\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tTo evaluate the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " we first create the matrix  element ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(\(i\)\(\ \)\(j\)\(\ \ \)\(k\)\(\ \)\(l\)\(\ \
\)\) = \((v\_\(i\ j\), v\_\(k\ l\))\)\)]],
  ". Then for  the matrix elements ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\)\)]],
  ", we let ",
  Cell[BoxData[
      \(TraditionalForm\`m\ and\ n\ run\ from\ 0\ to\ \((M + 1)\)\^2 - 1\)]],
  ", and set ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\) = \ S\_\(i\ j\ k\ l\)\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["i",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["j",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Quotient",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Quotient",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["M",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["+",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["1",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ". We do the same thing for ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(m\ n\)\)]],
  ".  For ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2\)]],
  " the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`S\_\(m\ n\)\)]],
  " has the form shown below:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(M = 2;\)\), "\n", 
    \(\(i = Mod[m, M + 1];\)\), "\n", 
    \(\(j = Quotient[m, M + 1];\)\), "\n", 
    \(\(k = Mod[n, M + 1];\)\), "\n", 
    \(\(\(l = Quotient[n, M + 1];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Smat\  = \ 
        Table[S\_\(\(\ \)\(i, j, k, l\)\), {m, 0, \((M + 1)\)^2\  - 1}, {n, 
            0, \((M + 1)\)\^2 - 1}];\)\), "\n", 
    \(MatrixForm[Smat]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.164"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(S\_\(0, 0, 0, 0\)\), \(S\_\(0, 0, 1, 0\)\), \(S\_\(0, 0, 2, 
                  0\)\), \(S\_\(0, 0, 0, 1\)\), \(S\_\(0, 0, 1, 
                  1\)\), \(S\_\(0, 0, 2, 1\)\), \(S\_\(0, 0, 0, 
                  2\)\), \(S\_\(0, 0, 1, 2\)\), \(S\_\(0, 0, 2, 2\)\)},
            {\(S\_\(1, 0, 0, 0\)\), \(S\_\(1, 0, 1, 0\)\), \(S\_\(1, 0, 2, 
                  0\)\), \(S\_\(1, 0, 0, 1\)\), \(S\_\(1, 0, 1, 
                  1\)\), \(S\_\(1, 0, 2, 1\)\), \(S\_\(1, 0, 0, 
                  2\)\), \(S\_\(1, 0, 1, 2\)\), \(S\_\(1, 0, 2, 2\)\)},
            {\(S\_\(2, 0, 0, 0\)\), \(S\_\(2, 0, 1, 0\)\), \(S\_\(2, 0, 2, 
                  0\)\), \(S\_\(2, 0, 0, 1\)\), \(S\_\(2, 0, 1, 
                  1\)\), \(S\_\(2, 0, 2, 1\)\), \(S\_\(2, 0, 0, 
                  2\)\), \(S\_\(2, 0, 1, 2\)\), \(S\_\(2, 0, 2, 2\)\)},
            {\(S\_\(0, 1, 0, 0\)\), \(S\_\(0, 1, 1, 0\)\), \(S\_\(0, 1, 2, 
                  0\)\), \(S\_\(0, 1, 0, 1\)\), \(S\_\(0, 1, 1, 
                  1\)\), \(S\_\(0, 1, 2, 1\)\), \(S\_\(0, 1, 0, 
                  2\)\), \(S\_\(0, 1, 1, 2\)\), \(S\_\(0, 1, 2, 2\)\)},
            {\(S\_\(1, 1, 0, 0\)\), \(S\_\(1, 1, 1, 0\)\), \(S\_\(1, 1, 2, 
                  0\)\), \(S\_\(1, 1, 0, 1\)\), \(S\_\(1, 1, 1, 
                  1\)\), \(S\_\(1, 1, 2, 1\)\), \(S\_\(1, 1, 0, 
                  2\)\), \(S\_\(1, 1, 1, 2\)\), \(S\_\(1, 1, 2, 2\)\)},
            {\(S\_\(2, 1, 0, 0\)\), \(S\_\(2, 1, 1, 0\)\), \(S\_\(2, 1, 2, 
                  0\)\), \(S\_\(2, 1, 0, 1\)\), \(S\_\(2, 1, 1, 
                  1\)\), \(S\_\(2, 1, 2, 1\)\), \(S\_\(2, 1, 0, 
                  2\)\), \(S\_\(2, 1, 1, 2\)\), \(S\_\(2, 1, 2, 2\)\)},
            {\(S\_\(0, 2, 0, 0\)\), \(S\_\(0, 2, 1, 0\)\), \(S\_\(0, 2, 2, 
                  0\)\), \(S\_\(0, 2, 0, 1\)\), \(S\_\(0, 2, 1, 
                  1\)\), \(S\_\(0, 2, 2, 1\)\), \(S\_\(0, 2, 0, 
                  2\)\), \(S\_\(0, 2, 1, 2\)\), \(S\_\(0, 2, 2, 2\)\)},
            {\(S\_\(1, 2, 0, 0\)\), \(S\_\(1, 2, 1, 0\)\), \(S\_\(1, 2, 2, 
                  0\)\), \(S\_\(1, 2, 0, 1\)\), \(S\_\(1, 2, 1, 
                  1\)\), \(S\_\(1, 2, 2, 1\)\), \(S\_\(1, 2, 0, 
                  2\)\), \(S\_\(1, 2, 1, 2\)\), \(S\_\(1, 2, 2, 2\)\)},
            {\(S\_\(2, 2, 0, 0\)\), \(S\_\(2, 2, 1, 0\)\), \(S\_\(2, 2, 2, 
                  0\)\), \(S\_\(2, 2, 0, 1\)\), \(S\_\(2, 2, 1, 
                  1\)\), \(S\_\(2, 2, 2, 1\)\), \(S\_\(2, 2, 0, 
                  2\)\), \(S\_\(2, 2, 1, 2\)\), \(S\_\(2, 2, 2, 2\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["The following module performs the required calculations:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(galerkinmodes[M_]\), ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({i, j, k, l, z, \[Phi], norm, L, S, Lmat, Smat, mat}\), 
            ",", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                define\ the\ curves\ that\ determine\ the\ \
\(\(boundary\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(z[1, x_, y_]\  = \ y - 1\), ";", 
              "\[IndentingNewLine]", \(z[2, x_, y_]\  = \ y - x\^2\), ";", 
              " ", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  define\ the\ basis\ \(\(functions\)\(:\)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(v[i_, j_, x_, y_]\  = \ \(x\^i\) 
                  y\^j\ \ \ \ Product[z[p, x, y], {p, 1, 2}]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["(*",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[" ",
                  FontColor->RGBColor[1, 0, 0]], 
                StyleBox[\(define\ the\ inner\ product\),
                  FontColor->RGBColor[1, 0, 0]], " ", 
                StyleBox["*)",
                  FontColor->RGBColor[1, 0, 0]]}], 
              "\[IndentingNewLine]", \(norm[f_, g_]\  := \ 
                Integrate[Integrate[f\ g, {y, x\^2, 1}], {x, \(-1\), 1}]\  // 
                  N\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ define\ the\ \(\(operator\)\(:\)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(L\&^[f_]\  := \ 
                D[f, {x, 2}]\  + \ D[f, {y, 2}]\), ";", "\[IndentingNewLine]",
               
              
              StyleBox[\( (*\ 
                  determine\ the\ projection\ of\ the\ operator\ onto\ the\ \
basis\ \(\(functions\)\(:\)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(L[i_, j_, k_, l_]\  := \ 
                norm[v[i, j, x, y], \ L\&^[v[k, l, x, y]]]\), ";", 
              "\[IndentingNewLine]", \(S[i_, j_, k_, l_]\  := \ 
                norm[v[i, j, x, y], v[k, l, x, y]]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*create\ the\ matrices\ \ L\ and\ S\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
                RowBox[{
                  StyleBox[Cell[""],
                    FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
                  "Lmat"}], " ", "=", 
                " ", \(Table[
                  L[Mod[m, M + 1], Quotient[m, M + 1], Mod[n, M + 1], 
                    Quotient[n, M + 1]], {m, 0, \((M + 1)\)^2\  - 1}, {n, 
                    0, \((M + 1)\)\^2 - 1}]\)}], ";", 
              "\[IndentingNewLine]", \(Smat\  = \ 
                Table[S[Mod[m, M + 1], Quotient[m, M + 1], Mod[n, M + 1], 
                    Quotient[n, M + 1]], {m, 0, \((M + 1)\)^2\  - 1}, {n, 
                    0, \((M + 1)\)\^2 - 1}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  take\ the\ \((numerical)\)\ inverse\ of\ S\ and\ matrix\ \
multiply\ it\ by\ L\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(mat\  = \ 
                Inverse[Smat\  // N] . Lmat\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  find\ the\ eigenvalues\ and\ eigenvectors\ of\ the\ matrix\ \
problem\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Lambda] = Eigenvalues[mat]\), ";", 
              "\[IndentingNewLine]", \(c = Eigenvectors[mat]\), ";"}]}], 
          "]"}]}], "\[IndentingNewLine]"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.165"],

Cell[TextData[{
  "We now call the module for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 4\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(galerkinmodes[4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.166"],

Cell["The eigenvalues are", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Lambda]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.167"],

Cell[BoxData[
    \({\(-800.5458534140322`\), \(-665.7185371581247`\), \
\(-657.4570023544487`\), \(-523.7241901785272`\), \(-463.134489462566`\), \
\(-402.49313487770524`\), \(-364.7393389760164`\), \(-353.06684868732805`\), \
\(-303.6987744239891`\), \(-293.61793118117595`\), \(-256.1919033916323`\), \
\(-225.7161091047095`\), \(-224.19832751857842`\), \(-185.43115785793603`\), \
\(-182.1320451599159`\), \(-153.61489723889187`\), \(-127.67960060197203`\), \
\(-112.60818763552953`\), \(-111.7595199668621`\), \(-92.68187645628711`\), \
\(-71.0387861090244`\), \(-59.18138278943022`\), \(-47.25446476094882`\), \
\(-33.33322854214339`\), \(-16.946835600260673`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The numbers are negative and real, as expected, since they equal -",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\^2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " is the frequency of a given drumhead mode.  In order to test the accuracy \
of the method, we increase ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(galerkinmodes[5];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Lambda]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.168"],

Cell[BoxData[
    \({\(-1391.3870788531817`\), \(-1167.1370503837777`\), \
\(-1153.634563723851`\), \(-952.1043003694479`\), \(-884.9811846210089`\), \
\(-715.8134933425775`\), \(-690.8244164760657`\), \(-614.935918456444`\), \
\(-580.4886186732188`\), \(-535.955192409204`\), \(-500.6305803603995`\), \
\(-481.68009938928003`\), \(-424.64154725352677`\), \(-422.8934466192252`\), \
\(-395.83056109121196`\), \(-376.46893918826044`\), \(-346.4795966834327`\), \
\(-280.09141398501976`\), \(-278.15326085916945`\), \(-271.44504020770927`\), \
\(-230.20704885377086`\), \(-229.95594878067266`\), \(-190.19616002660553`\), \
\(-186.03561790009636`\), \(-177.48637671484343`\), \(-153.11652624899176`\), \
\(-151.81662313564348`\), \(-119.8518754476218`\), \(-111.71542022904302`\), \
\(-92.58863688538456`\), \(-90.96573719387683`\), \(-69.09239781570932`\), \
\(-59.16315554932787`\), \(-47.235455868341845`\), \(-33.24411088666115`\), \
\(-16.946833399000536`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The lowest eigenvalues are nearly the same as for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 4\)]],
  ", indicating that the method has converged reasonably well for the lowest \
modes. In Cell ",
  ButtonBox["6.169",
    ButtonData:>"Cell 6.169",
    ButtonStyle->"Hyperlink"],
  " we plot a few of the corresponding eigenmodes, using Eq. ",
  ButtonBox["(6.3.9)",
    ButtonData:>"(6.3.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:67"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Psi][n_, x_]\  := \ 
        Sum[\(c[\([\((M + 1)\)^2 - n]\)]\)[\([j + 1]\)]\ v[Mod[j, M + 1], 
              Quotient[j, M + 1], x, y], {j, 
            0, \((M + 1)\)^2 - 1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(<< Calculus`;\)\[IndentingNewLine]\), "\n", 
    \(\(z[1, x_, y_]\  = \ y - 1;\)\), "\[IndentingNewLine]", 
    \(\(z[2, x_, y_]\  = \ y - x\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Table[
        Plot3D[\[Psi][n, x]\ Boole[
              z[1, x, y] \[LessEqual] \ 0\  && \ 
                z[2, x, y] \[GreaterEqual] \ 0], {x, \(-1.01\), 
            1}, {y, \(-0.01\), 1.3}, PlotPoints \[Rule] 50, 
          PlotRange \[Rule] All, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
          PlotLabel -> \*"\"\<\!\(\[Psi]\_n\)[x,y], n=\>\"" <> 
              ToString[n]], {n, 0, 3}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.169"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.0216 .28084 -30 -2.7556 ]
[.0216 .28084 0 6.2444 ]
[.01374 .33014 -30 -2.79732 ]
[.01374 .33014 0 6.20268 ]
[.00562 .38104 -30 -2.84054 ]
[.00562 .38104 0 6.15946 ]
[-0.00277 .43362 -30 -2.88532 ]
[-0.00277 .43362 0 6.11468 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03384 .2761 m
.03996 .27372 L
s
[(-0.08)] .0216 .28084 1 -0.38764 Mshowa
.02601 .3255 m
.03215 .32318 L
s
[(-0.06)] .01374 .33014 1 -0.37837 Mshowa
.01793 .3765 m
.02408 .37423 L
s
[(-0.04)] .00562 .38104 1 -0.36877 Mshowa
.00958 .42918 m
.01575 .42697 L
s
[(-0.02)] -0.00277 .43362 1 -0.35882 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.0319 .2883 m
.03558 .28689 L
s
.02996 .3006 m
.03363 .29919 L
s
.02799 .313 m
.03167 .3116 L
s
.02401 .3381 m
.0277 .33671 L
s
.022 .35079 m
.02569 .34942 L
s
.01997 .3636 m
.02366 .36223 L
s
.01587 .38951 m
.01956 .38816 L
s
.01379 .40263 m
.01749 .40128 L
s
.01169 .41585 m
.01539 .41451 L
s
.00745 .44263 m
.01116 .44131 L
s
.0053 .45618 m
.00901 .45487 L
s
.00313 .46985 m
.00685 .46854 L
s
.03576 .26399 m
.03943 .26256 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.646 .762 .934 r
.39143 .80041 .39806 .80578 .40912 .80287 .40252 .79748 Metetra
.646 .762 .934 r
.40252 .79748 .40912 .80287 .42022 .79996 .41365 .79454 Metetra
.646 .762 .934 r
.41365 .79454 .42022 .79996 .43137 .79703 .42483 .79159 Metetra
.646 .762 .934 r
.42483 .79159 .43137 .79703 .44256 .79408 .43605 .78862 Metetra
.646 .762 .934 r
.43605 .78862 .44256 .79408 .4538 .79113 .44732 .78564 Metetra
.646 .762 .934 r
.44732 .78564 .4538 .79113 .46509 .78816 .45864 .78266 Metetra
.646 .762 .934 r
.45864 .78266 .46509 .78816 .47642 .78519 .47001 .77965 Metetra
.646 .762 .934 r
.47001 .77965 .47642 .78519 .48781 .78219 .48142 .77664 Metetra
.646 .762 .934 r
.48142 .77664 .48781 .78219 .49924 .77919 .49288 .77361 Metetra
.646 .762 .934 r
.49288 .77361 .49924 .77919 .51071 .77617 .50439 .77057 Metetra
.646 .762 .934 r
.50439 .77057 .51071 .77617 .52224 .77315 .51594 .76752 Metetra
.646 .762 .934 r
.51594 .76752 .52224 .77315 .53381 .7701 .52755 .76446 Metetra
.646 .762 .934 r
.52755 .76446 .53381 .7701 .54544 .76705 .53921 .76138 Metetra
.646 .762 .934 r
.53921 .76138 .54544 .76705 .55711 .76398 .55091 .75829 Metetra
.646 .762 .934 r
.55091 .75829 .55711 .76398 .56883 .7609 .56267 .75518 Metetra
.646 .762 .934 r
.56267 .75518 .56883 .7609 .5806 .75781 .57447 .75206 Metetra
.646 .762 .934 r
.57447 .75206 .5806 .75781 .59242 .7547 .58633 .74893 Metetra
.646 .762 .934 r
.58633 .74893 .59242 .7547 .6043 .75158 .59823 .74579 Metetra
.646 .762 .934 r
.59823 .74579 .6043 .75158 .61622 .74845 .61019 .74263 Metetra
.646 .762 .934 r
.61019 .74263 .61622 .74845 .62819 .7453 .6222 .73946 Metetra
.646 .762 .934 r
.6222 .73946 .62819 .7453 .64022 .74214 .63426 .73627 Metetra
.646 .762 .934 r
.63426 .73627 .64022 .74214 .65229 .73897 .64637 .73307 Metetra
.646 .762 .934 r
.64637 .73307 .65229 .73897 .66442 .73578 .65853 .72986 Metetra
.646 .762 .934 r
.65853 .72986 .66442 .73578 .67661 .73258 .67075 .72663 Metetra
.646 .762 .934 r
.67075 .72663 .67661 .73258 .68884 .72937 .68302 .72339 Metetra
.646 .762 .934 r
.68302 .72339 .68884 .72937 .70113 .72614 .69535 .72014 Metetra
.646 .762 .934 r
.69535 .72014 .70113 .72614 .71347 .72289 .70772 .71687 Metetra
.646 .762 .934 r
.70772 .71687 .71347 .72289 .72586 .71964 .72016 .71359 Metetra
.646 .762 .934 r
.72016 .71359 .72586 .71964 .73831 .71637 .73264 .71029 Metetra
.646 .762 .934 r
.73264 .71029 .73831 .71637 .75081 .71308 .74518 .70698 Metetra
.646 .762 .934 r
.74518 .70698 .75081 .71308 .76337 .70978 .75778 .70365 Metetra
.646 .762 .934 r
.75778 .70365 .76337 .70978 .77598 .70647 .77043 .70031 Metetra
.646 .762 .934 r
.77043 .70031 .77598 .70647 .78865 .70314 .78314 .69695 Metetra
.646 .762 .934 r
.78314 .69695 .78865 .70314 .80138 .69979 .79591 .69358 Metetra
.646 .762 .934 r
.79591 .69358 .80138 .69979 .81416 .69643 .80873 .69019 Metetra
.646 .762 .934 r
.80873 .69019 .81416 .69643 .827 .69306 .82161 .68679 Metetra
.646 .762 .934 r
.82161 .68679 .827 .69306 .83989 .68967 .83454 .68338 Metetra
.646 .762 .934 r
.83454 .68338 .83989 .68967 .85284 .68627 .84753 .67994 Metetra
.646 .762 .934 r
.84753 .67994 .85284 .68627 .86585 .68285 .86059 .6765 Metetra
.646 .762 .934 r
.86059 .6765 .86585 .68285 .87892 .67941 .8737 .67303 Metetra
.646 .762 .934 r
.8737 .67303 .87892 .67941 .89205 .67597 .88687 .66956 Metetra
.646 .762 .934 r
.88687 .66956 .89205 .67597 .90523 .6725 .9001 .66606 Metetra
.646 .762 .934 r
.9001 .66606 .90523 .6725 .91848 .66902 .91338 .66255 Metetra
.646 .762 .934 r
.91338 .66255 .91848 .66902 .93178 .66552 .92673 .65903 Metetra
.646 .762 .934 r
.92673 .65903 .93178 .66552 .94515 .66201 .94014 .65549 Metetra
.646 .762 .934 r
.94014 .65549 .94515 .66201 .95858 .65848 .95361 .65193 Metetra
.646 .762 .934 r
.95361 .65193 .95858 .65848 .97206 .65494 .96715 .64835 Metetra
.646 .762 .934 r
.96715 .64835 .97206 .65494 .98561 .65138 .98074 .64476 Metetra
.646 .762 .934 r
.98074 .64476 .98561 .65138 .99922 .6478 .9944 .64116 Metetra
.646 .762 .934 r
.38476 .79499 .39143 .80041 .40252 .79748 .39587 .79204 Metetra
.646 .762 .934 r
.39587 .79204 .40252 .79748 .41365 .79454 .40703 .78908 Metetra
.646 .762 .934 r
.40703 .78908 .41365 .79454 .42483 .79159 .41824 .7861 Metetra
.646 .762 .934 r
.41824 .7861 .42483 .79159 .43605 .78862 .42949 .78312 Metetra
.646 .762 .934 r
.42949 .78312 .43605 .78862 .44732 .78564 .44079 .78012 Metetra
.646 .762 .934 r
.44079 .78012 .44732 .78564 .45864 .78266 .45214 .7771 Metetra
.646 .762 .934 r
.45214 .7771 .45864 .78266 .47001 .77965 .46354 .77408 Metetra
.646 .762 .934 r
.46354 .77408 .47001 .77965 .48142 .77664 .47498 .77104 Metetra
.646 .762 .934 r
.47498 .77104 .48142 .77664 .49288 .77361 .48647 .76799 Metetra
.646 .762 .934 r
.48647 .76799 .49288 .77361 .50439 .77057 .49801 .76493 Metetra
.646 .762 .934 r
.49801 .76493 .50439 .77057 .51594 .76752 .5096 .76185 Metetra
.646 .762 .934 r
.5096 .76185 .51594 .76752 .52755 .76446 .52124 .75876 Metetra
.646 .762 .934 r
.52124 .75876 .52755 .76446 .53921 .76138 .53293 .75566 Metetra
.646 .762 .934 r
.53293 .75566 .53921 .76138 .55091 .75829 .54466 .75254 Metetra
.646 .762 .934 r
.54466 .75254 .55091 .75829 .56267 .75518 .55645 .74941 Metetra
.646 .762 .934 r
.55645 .74941 .56267 .75518 .57447 .75206 .56829 .74627 Metetra
.646 .762 .934 r
.56829 .74627 .57447 .75206 .58633 .74893 .58018 .74312 Metetra
.646 .762 .934 r
.58018 .74312 .58633 .74893 .59823 .74579 .59212 .73995 Metetra
.646 .762 .934 r
.59212 .73995 .59823 .74579 .61019 .74263 .60411 .73676 Metetra
.646 .762 .934 r
.60411 .73676 .61019 .74263 .6222 .73946 .61615 .73357 Metetra
.646 .762 .934 r
.61615 .73357 .6222 .73946 .63426 .73627 .62825 .73036 Metetra
.646 .762 .934 r
.62825 .73036 .63426 .73627 .64637 .73307 .6404 .72713 Metetra
.646 .762 .934 r
.6404 .72713 .64637 .73307 .65853 .72986 .6526 .72389 Metetra
.646 .762 .934 r
.6526 .72389 .65853 .72986 .67075 .72663 .66485 .72064 Metetra
.646 .762 .934 r
.66485 .72064 .67075 .72663 .68302 .72339 .67716 .71737 Metetra
.646 .762 .934 r
.67716 .71737 .68302 .72339 .69535 .72014 .68952 .71409 Metetra
.646 .762 .934 r
.68952 .71409 .69535 .72014 .70772 .71687 .70193 .7108 Metetra
.646 .762 .934 r
.70193 .7108 .70772 .71687 .72016 .71359 .7144 .70749 Metetra
.646 .762 .934 r
.7144 .70749 .72016 .71359 .73264 .71029 .72693 .70416 Metetra
.646 .762 .934 r
.72693 .70416 .73264 .71029 .74518 .70698 .73951 .70082 Metetra
.646 .762 .934 r
.73951 .70082 .74518 .70698 .75778 .70365 .75214 .69747 Metetra
.646 .762 .934 r
.75214 .69747 .75778 .70365 .77043 .70031 .76484 .6941 Metetra
.646 .762 .934 r
.76484 .6941 .77043 .70031 .78314 .69695 .77758 .69072 Metetra
.646 .762 .934 r
.77758 .69072 .78314 .69695 .79591 .69358 .79039 .68732 Metetra
.646 .762 .934 r
.79039 .68732 .79591 .69358 .80873 .69019 .80325 .6839 Metetra
.646 .762 .934 r
.80325 .6839 .80873 .69019 .82161 .68679 .81617 .68047 Metetra
.646 .762 .934 r
.81617 .68047 .82161 .68679 .83454 .68338 .82915 .67703 Metetra
.646 .762 .934 r
.82915 .67703 .83454 .68338 .84753 .67994 .84218 .67357 Metetra
.646 .762 .934 r
.84218 .67357 .84753 .67994 .86059 .6765 .85528 .67009 Metetra
.646 .762 .934 r
.85528 .67009 .86059 .6765 .8737 .67303 .86843 .6666 Metetra
.646 .762 .934 r
.86843 .6666 .8737 .67303 .88687 .66956 .88164 .66309 Metetra
.646 .762 .934 r
.88164 .66309 .88687 .66956 .9001 .66606 .89491 .65957 Metetra
.646 .762 .934 r
.89491 .65957 .9001 .66606 .91338 .66255 .90825 .65603 Metetra
.646 .762 .934 r
.90825 .65603 .91338 .66255 .92673 .65903 .92164 .65248 Metetra
.646 .762 .934 r
.92164 .65248 .92673 .65903 .94014 .65549 .9351 .6489 Metetra
.646 .762 .934 r
.9351 .6489 .94014 .65549 .95361 .65193 .94861 .64532 Metetra
.646 .762 .934 r
.94861 .64532 .95361 .65193 .96715 .64835 .96219 .64171 Metetra
.646 .762 .934 r
.96219 .64171 .96715 .64835 .98074 .64476 .97583 .63809 Metetra
.646 .762 .934 r
.97583 .63809 .98074 .64476 .9944 .64116 .98953 .63445 Metetra
.646 .762 .934 r
.37803 .78953 .38476 .79499 .39587 .79204 .38918 .78656 Metetra
.646 .762 .934 r
.38918 .78656 .39587 .79204 .40703 .78908 .40037 .78358 Metetra
.646 .762 .934 r
.40037 .78358 .40703 .78908 .41824 .7861 .4116 .78058 Metetra
.646 .762 .934 r
.4116 .78058 .41824 .7861 .42949 .78312 .42289 .77757 Metetra
.646 .762 .934 r
.42289 .77757 .42949 .78312 .44079 .78012 .43422 .77455 Metetra
.646 .762 .934 r
.43422 .77455 .44079 .78012 .45214 .7771 .44559 .77151 Metetra
.646 .762 .934 r
.44559 .77151 .45214 .7771 .46354 .77408 .45702 .76846 Metetra
.646 .762 .934 r
.45702 .76846 .46354 .77408 .47498 .77104 .46849 .7654 Metetra
.646 .762 .934 r
.46849 .7654 .47498 .77104 .48647 .76799 .48002 .76233 Metetra
.646 .762 .934 r
.48002 .76233 .48647 .76799 .49801 .76493 .49159 .75924 Metetra
.646 .762 .934 r
.49159 .75924 .49801 .76493 .5096 .76185 .50321 .75614 Metetra
.646 .762 .934 r
.50321 .75614 .5096 .76185 .52124 .75876 .51488 .75302 Metetra
.646 .762 .934 r
.51488 .75302 .52124 .75876 .53293 .75566 .5266 .7499 Metetra
.646 .762 .934 r
.5266 .7499 .53293 .75566 .54466 .75254 .53837 .74676 Metetra
.646 .762 .934 r
.53837 .74676 .54466 .75254 .55645 .74941 .55019 .7436 Metetra
.646 .762 .934 r
.55019 .7436 .55645 .74941 .56829 .74627 .56206 .74044 Metetra
.646 .762 .934 r
.56206 .74044 .56829 .74627 .58018 .74312 .57398 .73725 Metetra
.646 .762 .934 r
.57398 .73725 .58018 .74312 .59212 .73995 .58596 .73406 Metetra
.646 .762 .934 r
.58596 .73406 .59212 .73995 .60411 .73676 .59798 .73085 Metetra
.646 .762 .934 r
.59798 .73085 .60411 .73676 .61615 .73357 .61006 .72763 Metetra
.646 .762 .934 r
.61006 .72763 .61615 .73357 .62825 .73036 .62219 .72439 Metetra
.646 .762 .934 r
.62219 .72439 .62825 .73036 .6404 .72713 .63438 .72114 Metetra
.646 .762 .934 r
.63438 .72114 .6404 .72713 .6526 .72389 .64661 .71788 Metetra
.646 .762 .934 r
.64661 .71788 .6526 .72389 .66485 .72064 .6589 .7146 Metetra
.646 .762 .934 r
.6589 .7146 .66485 .72064 .67716 .71737 .67125 .7113 Metetra
.646 .762 .934 r
.67125 .7113 .67716 .71737 .68952 .71409 .68365 .708 Metetra
.646 .762 .934 r
.68365 .708 .68952 .71409 .70193 .7108 .6961 .70467 Metetra
.646 .762 .934 r
.6961 .70467 .70193 .7108 .7144 .70749 .70861 .70134 Metetra
.646 .762 .934 r
.70861 .70134 .7144 .70749 .72693 .70416 .72117 .69799 Metetra
.646 .762 .934 r
.72117 .69799 .72693 .70416 .73951 .70082 .73379 .69462 Metetra
.646 .762 .934 r
.73379 .69462 .73951 .70082 .75214 .69747 .74646 .69124 Metetra
.646 .762 .934 r
.74646 .69124 .75214 .69747 .76484 .6941 .75919 .68784 Metetra
.646 .762 .934 r
.75919 .68784 .76484 .6941 .77758 .69072 .77198 .68443 Metetra
.646 .762 .934 r
.77198 .68443 .77758 .69072 .79039 .68732 .78483 .681 Metetra
.646 .762 .934 r
.78483 .681 .79039 .68732 .80325 .6839 .79773 .67756 Metetra
.646 .762 .934 r
.79773 .67756 .80325 .6839 .81617 .68047 .81069 .6741 Metetra
.646 .762 .934 r
.81069 .6741 .81617 .68047 .82915 .67703 .82371 .67063 Metetra
.646 .762 .934 r
.82371 .67063 .82915 .67703 .84218 .67357 .83678 .66714 Metetra
.646 .762 .934 r
.83678 .66714 .84218 .67357 .85528 .67009 .84992 .66363 Metetra
.646 .762 .934 r
.84992 .66363 .85528 .67009 .86843 .6666 .86312 .66011 Metetra
.646 .762 .934 r
.86312 .66011 .86843 .6666 .88164 .66309 .87637 .65658 Metetra
.646 .762 .934 r
.87637 .65658 .88164 .66309 .89491 .65957 .88969 .65302 Metetra
.646 .762 .934 r
.88969 .65302 .89491 .65957 .90825 .65603 .90307 .64945 Metetra
.646 .762 .934 r
.90307 .64945 .90825 .65603 .92164 .65248 .9165 .64587 Metetra
.646 .762 .934 r
.9165 .64587 .92164 .65248 .9351 .6489 .93 .64227 Metetra
.646 .762 .934 r
.93 .64227 .9351 .6489 .94861 .64532 .94357 .63865 Metetra
.646 .762 .934 r
.94357 .63865 .94861 .64532 .96219 .64171 .95719 .63501 Metetra
.646 .762 .934 r
.95719 .63501 .96219 .64171 .97583 .63809 .97088 .63136 Metetra
.646 .762 .934 r
.97088 .63136 .97583 .63809 .98953 .63445 .98463 .62769 Metetra
.646 .762 .934 r
.37126 .78404 .37803 .78953 .38918 .78656 .38243 .78104 Metetra
.646 .762 .934 r
.38243 .78104 .38918 .78656 .40037 .78358 .39365 .77803 Metetra
.646 .762 .934 r
.39365 .77803 .40037 .78358 .4116 .78058 .40491 .77501 Metetra
.646 .762 .934 r
.40491 .77501 .4116 .78058 .42289 .77757 .41622 .77198 Metetra
.646 .762 .934 r
.41622 .77198 .42289 .77757 .43422 .77455 .42759 .76893 Metetra
.646 .762 .934 r
.42759 .76893 .43422 .77455 .44559 .77151 .43899 .76587 Metetra
.646 .762 .934 r
.43899 .76587 .44559 .77151 .45702 .76846 .45045 .7628 Metetra
.646 .762 .934 r
.45045 .7628 .45702 .76846 .46849 .7654 .46196 .75971 Metetra
.646 .762 .934 r
.46196 .75971 .46849 .7654 .48002 .76233 .47351 .75662 Metetra
.646 .762 .934 r
.47351 .75662 .48002 .76233 .49159 .75924 .48511 .7535 Metetra
.646 .762 .934 r
.48511 .7535 .49159 .75924 .50321 .75614 .49677 .75038 Metetra
.646 .762 .934 r
.49677 .75038 .50321 .75614 .51488 .75302 .50847 .74724 Metetra
.646 .762 .934 r
.50847 .74724 .51488 .75302 .5266 .7499 .52022 .74409 Metetra
.646 .762 .934 r
.52022 .74409 .5266 .7499 .53837 .74676 .53202 .74092 Metetra
.646 .762 .934 r
.53202 .74092 .53837 .74676 .55019 .7436 .54388 .73774 Metetra
.646 .762 .934 r
.54388 .73774 .55019 .7436 .56206 .74044 .55578 .73455 Metetra
.646 .762 .934 r
.55578 .73455 .56206 .74044 .57398 .73725 .56774 .73135 Metetra
.646 .762 .934 r
.56774 .73135 .57398 .73725 .58596 .73406 .57975 .72813 Metetra
.646 .762 .934 r
.57975 .72813 .58596 .73406 .59798 .73085 .59181 .72489 Metetra
.646 .762 .934 r
.59181 .72489 .59798 .73085 .61006 .72763 .60392 .72164 Metetra
.646 .762 .934 r
.60392 .72164 .61006 .72763 .62219 .72439 .61609 .71838 Metetra
.646 .762 .934 r
.61609 .71838 .62219 .72439 .63438 .72114 .62831 .7151 Metetra
.646 .762 .934 r
.62831 .7151 .63438 .72114 .64661 .71788 .64058 .71181 Metetra
.646 .762 .934 r
.64058 .71181 .64661 .71788 .6589 .7146 .65291 .70851 Metetra
.646 .762 .934 r
.65291 .70851 .6589 .7146 .67125 .7113 .66529 .70519 Metetra
.646 .762 .934 r
.66529 .70519 .67125 .7113 .68365 .708 .67772 .70185 Metetra
.646 .762 .934 r
.67772 .70185 .68365 .708 .6961 .70467 .69021 .6985 Metetra
.646 .762 .934 r
.69021 .6985 .6961 .70467 .70861 .70134 .70276 .69514 Metetra
.646 .762 .934 r
.70276 .69514 .70861 .70134 .72117 .69799 .71536 .69176 Metetra
.646 .762 .934 r
.71536 .69176 .72117 .69799 .73379 .69462 .72802 .68836 Metetra
.646 .762 .934 r
.72802 .68836 .73379 .69462 .74646 .69124 .74073 .68495 Metetra
.646 .762 .934 r
.74073 .68495 .74646 .69124 .75919 .68784 .7535 .68153 Metetra
.646 .762 .934 r
.7535 .68153 .75919 .68784 .77198 .68443 .76633 .67809 Metetra
.646 .762 .934 r
.76633 .67809 .77198 .68443 .78483 .681 .77922 .67463 Metetra
.646 .762 .934 r
.77922 .67463 .78483 .681 .79773 .67756 .79216 .67116 Metetra
.646 .762 .934 r
.79216 .67116 .79773 .67756 .81069 .6741 .80516 .66768 Metetra
.646 .762 .934 r
.80516 .66768 .81069 .6741 .82371 .67063 .81822 .66417 Metetra
.646 .762 .934 r
.81822 .66417 .82371 .67063 .83678 .66714 .83134 .66066 Metetra
.646 .762 .934 r
.83134 .66066 .83678 .66714 .84992 .66363 .84452 .65712 Metetra
.646 .762 .934 r
.84452 .65712 .84992 .66363 .86312 .66011 .85776 .65357 Metetra
.646 .762 .934 r
.85776 .65357 .86312 .66011 .87637 .65658 .87106 .65 Metetra
.646 .762 .934 r
.87106 .65 .87637 .65658 .88969 .65302 .88442 .64642 Metetra
.646 .762 .934 r
.88442 .64642 .88969 .65302 .90307 .64945 .89784 .64282 Metetra
.646 .762 .934 r
.89784 .64282 .90307 .64945 .9165 .64587 .91132 .63921 Metetra
.646 .762 .934 r
.91132 .63921 .9165 .64587 .93 .64227 .92487 .63557 Metetra
.646 .762 .934 r
.92487 .63557 .93 .64227 .94357 .63865 .93848 .63193 Metetra
.646 .762 .934 r
.93848 .63193 .94357 .63865 .95719 .63501 .95215 .62826 Metetra
.646 .762 .934 r
.95215 .62826 .95719 .63501 .97088 .63136 .96588 .62458 Metetra
.646 .762 .934 r
.96588 .62458 .97088 .63136 .98463 .62769 .97968 .62088 Metetra
.646 .762 .934 r
.36443 .7785 .37126 .78404 .38243 .78104 .37563 .77548 Metetra
.646 .762 .934 r
.37563 .77548 .38243 .78104 .39365 .77803 .38688 .77245 Metetra
.646 .762 .934 r
.38688 .77245 .39365 .77803 .40491 .77501 .39817 .7694 Metetra
.646 .762 .934 r
.39817 .7694 .40491 .77501 .41622 .77198 .40951 .76634 Metetra
.646 .762 .934 r
.40951 .76634 .41622 .77198 .42759 .76893 .4209 .76327 Metetra
.646 .762 .934 r
.4209 .76327 .42759 .76893 .43899 .76587 .43234 .76019 Metetra
.646 .762 .934 r
.43234 .76019 .43899 .76587 .45045 .7628 .44383 .75709 Metetra
.646 .762 .934 r
.44383 .75709 .45045 .7628 .46196 .75971 .45537 .75398 Metetra
.646 .762 .934 r
.45537 .75398 .46196 .75971 .47351 .75662 .46695 .75086 Metetra
.646 .762 .934 r
.46695 .75086 .47351 .75662 .48511 .7535 .47859 .74772 Metetra
.646 .762 .934 r
.47859 .74772 .48511 .7535 .49677 .75038 .49027 .74457 Metetra
.646 .762 .934 r
.49027 .74457 .49677 .75038 .50847 .74724 .50201 .74141 Metetra
.646 .762 .934 r
.50201 .74141 .50847 .74724 .52022 .74409 .51379 .73823 Metetra
.646 .762 .934 r
.51379 .73823 .52022 .74409 .53202 .74092 .52563 .73504 Metetra
.646 .762 .934 r
.52563 .73504 .53202 .74092 .54388 .73774 .53752 .73184 Metetra
.646 .762 .934 r
.53752 .73184 .54388 .73774 .55578 .73455 .54945 .72862 Metetra
.646 .762 .934 r
.54945 .72862 .55578 .73455 .56774 .73135 .56145 .72539 Metetra
.646 .762 .934 r
.56145 .72539 .56774 .73135 .57975 .72813 .57349 .72214 Metetra
.646 .762 .934 r
.57349 .72214 .57975 .72813 .59181 .72489 .58558 .71888 Metetra
.646 .762 .934 r
.58558 .71888 .59181 .72489 .60392 .72164 .59773 .71561 Metetra
.646 .762 .934 r
.59773 .71561 .60392 .72164 .61609 .71838 .60993 .71232 Metetra
.646 .762 .934 r
.60993 .71232 .61609 .71838 .62831 .7151 .62219 .70902 Metetra
.646 .762 .934 r
.62219 .70902 .62831 .7151 .64058 .71181 .6345 .7057 Metetra
.646 .762 .934 r
.6345 .7057 .64058 .71181 .65291 .70851 .64686 .70237 Metetra
.646 .762 .934 r
.64686 .70237 .65291 .70851 .66529 .70519 .65928 .69902 Metetra
.646 .762 .934 r
.65928 .69902 .66529 .70519 .67772 .70185 .67175 .69566 Metetra
.646 .762 .934 r
.67175 .69566 .67772 .70185 .69021 .6985 .68428 .69228 Metetra
.646 .762 .934 r
.68428 .69228 .69021 .6985 .70276 .69514 .69687 .68889 Metetra
.646 .762 .934 r
.69687 .68889 .70276 .69514 .71536 .69176 .70951 .68548 Metetra
.646 .762 .934 r
.70951 .68548 .71536 .69176 .72802 .68836 .7222 .68206 Metetra
.646 .762 .934 r
.7222 .68206 .72802 .68836 .74073 .68495 .73496 .67862 Metetra
.646 .762 .934 r
.73496 .67862 .74073 .68495 .7535 .68153 .74777 .67517 Metetra
.646 .762 .934 r
.74777 .67517 .7535 .68153 .76633 .67809 .76063 .6717 Metetra
.646 .762 .934 r
.76063 .6717 .76633 .67809 .77922 .67463 .77356 .66821 Metetra
.646 .762 .934 r
.77356 .66821 .77922 .67463 .79216 .67116 .78654 .66471 Metetra
.646 .762 .934 r
.78654 .66471 .79216 .67116 .80516 .66768 .79959 .6612 Metetra
.646 .762 .934 r
.79959 .6612 .80516 .66768 .81822 .66417 .81269 .65767 Metetra
.646 .762 .934 r
.81269 .65767 .81822 .66417 .83134 .66066 .82585 .65412 Metetra
.646 .762 .934 r
.82585 .65412 .83134 .66066 .84452 .65712 .83908 .65055 Metetra
.646 .762 .934 r
.83908 .65055 .84452 .65712 .85776 .65357 .85236 .64697 Metetra
.646 .762 .934 r
.85236 .64697 .85776 .65357 .87106 .65 .8657 .64338 Metetra
.646 .762 .934 r
.8657 .64338 .87106 .65 .88442 .64642 .87911 .63976 Metetra
.646 .762 .934 r
.87911 .63976 .88442 .64642 .89784 .64282 .89257 .63613 Metetra
.646 .762 .934 r
.89257 .63613 .89784 .64282 .91132 .63921 .9061 .63249 Metetra
.646 .762 .934 r
.9061 .63249 .91132 .63921 .92487 .63557 .91969 .62882 Metetra
.646 .762 .934 r
.91969 .62882 .92487 .63557 .93848 .63193 .93335 .62514 Metetra
.646 .762 .934 r
.93335 .62514 .93848 .63193 .95215 .62826 .94706 .62145 Metetra
.646 .762 .934 r
.94706 .62145 .95215 .62826 .96588 .62458 .96084 .61773 Metetra
.646 .762 .934 r
.96084 .61773 .96588 .62458 .97968 .62088 .97469 .614 Metetra
.646 .762 .934 r
.35754 .77291 .36443 .7785 .37563 .77548 .36877 .76987 Metetra
.646 .762 .934 r
.36877 .76987 .37563 .77548 .38688 .77245 .38005 .76681 Metetra
.646 .762 .934 r
.38005 .76681 .38688 .77245 .39817 .7694 .39138 .76375 Metetra
.646 .762 .934 r
.39138 .76375 .39817 .7694 .40951 .76634 .40275 .76066 Metetra
.646 .762 .934 r
.40275 .76066 .40951 .76634 .4209 .76327 .41417 .75757 Metetra
.646 .762 .934 r
.41417 .75757 .4209 .76327 .43234 .76019 .42564 .75446 Metetra
.646 .762 .934 r
.42564 .75446 .43234 .76019 .44383 .75709 .43716 .75134 Metetra
.646 .762 .934 r
.43716 .75134 .44383 .75709 .45537 .75398 .44872 .74821 Metetra
.646 .762 .934 r
.44872 .74821 .45537 .75398 .46695 .75086 .46034 .74506 Metetra
.646 .762 .934 r
.46034 .74506 .46695 .75086 .47859 .74772 .47201 .7419 Metetra
.646 .762 .934 r
.47201 .7419 .47859 .74772 .49027 .74457 .48373 .73872 Metetra
.646 .762 .934 r
.48373 .73872 .49027 .74457 .50201 .74141 .49549 .73554 Metetra
.646 .762 .934 r
.49549 .73554 .50201 .74141 .51379 .73823 .50731 .73233 Metetra
.646 .762 .934 r
.50731 .73233 .51379 .73823 .52563 .73504 .51918 .72912 Metetra
.646 .762 .934 r
.51918 .72912 .52563 .73504 .53752 .73184 .5311 .72589 Metetra
.646 .762 .934 r
.5311 .72589 .53752 .73184 .54945 .72862 .54308 .72264 Metetra
.646 .762 .934 r
.54308 .72264 .54945 .72862 .56145 .72539 .5551 .71939 Metetra
.646 .762 .934 r
.5551 .71939 .56145 .72539 .57349 .72214 .56718 .71611 Metetra
.646 .762 .934 r
.56718 .71611 .57349 .72214 .58558 .71888 .57931 .71283 Metetra
.646 .762 .934 r
.57931 .71283 .58558 .71888 .59773 .71561 .59149 .70953 Metetra
.646 .762 .934 r
.59149 .70953 .59773 .71561 .60993 .71232 .60373 .70621 Metetra
.646 .762 .934 r
.60373 .70621 .60993 .71232 .62219 .70902 .61602 .70288 Metetra
.646 .762 .934 r
.61602 .70288 .62219 .70902 .6345 .7057 .62837 .69953 Metetra
.646 .762 .934 r
.62837 .69953 .6345 .7057 .64686 .70237 .64077 .69617 Metetra
.646 .762 .934 r
.64077 .69617 .64686 .70237 .65928 .69902 .65322 .6928 Metetra
.646 .762 .934 r
.65322 .6928 .65928 .69902 .67175 .69566 .66573 .68941 Metetra
.646 .762 .934 r
.66573 .68941 .67175 .69566 .68428 .69228 .6783 .68601 Metetra
.646 .762 .934 r
.6783 .68601 .68428 .69228 .69687 .68889 .69092 .68259 Metetra
.646 .762 .934 r
.69092 .68259 .69687 .68889 .70951 .68548 .7036 .67915 Metetra
.646 .762 .934 r
.7036 .67915 .70951 .68548 .7222 .68206 .71634 .6757 Metetra
.646 .762 .934 r
.71634 .6757 .7222 .68206 .73496 .67862 .72913 .67223 Metetra
.646 .762 .934 r
.72913 .67223 .73496 .67862 .74777 .67517 .74198 .66875 Metetra
.646 .762 .934 r
.74198 .66875 .74777 .67517 .76063 .6717 .75489 .66525 Metetra
.646 .762 .934 r
.75489 .66525 .76063 .6717 .77356 .66821 .76786 .66174 Metetra
.646 .762 .934 r
.76786 .66174 .77356 .66821 .78654 .66471 .78088 .65821 Metetra
.646 .762 .934 r
.78088 .65821 .78654 .66471 .79959 .6612 .79397 .65467 Metetra
.646 .762 .934 r
.79397 .65467 .79959 .6612 .81269 .65767 .80711 .6511 Metetra
.646 .762 .934 r
.80711 .6511 .81269 .65767 .82585 .65412 .82032 .64753 Metetra
.646 .762 .934 r
.82032 .64753 .82585 .65412 .83908 .65055 .83358 .64393 Metetra
.646 .762 .934 r
.83358 .64393 .83908 .65055 .85236 .64697 .84691 .64032 Metetra
.646 .762 .934 r
.84691 .64032 .85236 .64697 .8657 .64338 .8603 .63669 Metetra
.646 .762 .934 r
.8603 .63669 .8657 .64338 .87911 .63976 .87375 .63305 Metetra
.646 .762 .934 r
.87375 .63305 .87911 .63976 .89257 .63613 .88726 .62939 Metetra
.646 .762 .934 r
.88726 .62939 .89257 .63613 .9061 .63249 .90083 .62571 Metetra
.646 .762 .934 r
.90083 .62571 .9061 .63249 .91969 .62882 .91447 .62202 Metetra
.646 .762 .934 r
.91447 .62202 .91969 .62882 .93335 .62514 .92817 .6183 Metetra
.646 .762 .934 r
.92817 .6183 .93335 .62514 .94706 .62145 .94193 .61457 Metetra
.646 .762 .934 r
.94193 .61457 .94706 .62145 .96084 .61773 .95576 .61083 Metetra
.646 .762 .934 r
.95576 .61083 .96084 .61773 .97469 .614 .96966 .60706 Metetra
.646 .762 .934 r
.35061 .76729 .35754 .77291 .36877 .76987 .36187 .76422 Metetra
.646 .762 .934 r
.36187 .76422 .36877 .76987 .38005 .76681 .37317 .76114 Metetra
.646 .762 .934 r
.37317 .76114 .38005 .76681 .39138 .76375 .38453 .75805 Metetra
.646 .762 .934 r
.38453 .75805 .39138 .76375 .40275 .76066 .39593 .75494 Metetra
.646 .762 .934 r
.39593 .75494 .40275 .76066 .41417 .75757 .40738 .75182 Metetra
.646 .762 .934 r
.40738 .75182 .41417 .75757 .42564 .75446 .41888 .74869 Metetra
.646 .762 .934 r
.41888 .74869 .42564 .75446 .43716 .75134 .43043 .74555 Metetra
.646 .762 .934 r
.43043 .74555 .43716 .75134 .44872 .74821 .44203 .74239 Metetra
.646 .762 .934 r
.44203 .74239 .44872 .74821 .46034 .74506 .45368 .73921 Metetra
.646 .762 .934 r
.45368 .73921 .46034 .74506 .47201 .7419 .46538 .73603 Metetra
.646 .762 .934 r
.46538 .73603 .47201 .7419 .48373 .73872 .47713 .73283 Metetra
.646 .762 .934 r
.47713 .73283 .48373 .73872 .49549 .73554 .48893 .72961 Metetra
.646 .762 .934 r
.48893 .72961 .49549 .73554 .50731 .73233 .50078 .72639 Metetra
.646 .762 .934 r
.50078 .72639 .50731 .73233 .51918 .72912 .51268 .72314 Metetra
.646 .762 .934 r
.51268 .72314 .51918 .72912 .5311 .72589 .52464 .71989 Metetra
.646 .762 .934 r
.52464 .71989 .5311 .72589 .54308 .72264 .53664 .71662 Metetra
.646 .762 .934 r
.53664 .71662 .54308 .72264 .5551 .71939 .5487 .71333 Metetra
.646 .762 .934 r
.5487 .71333 .5551 .71939 .56718 .71611 .56082 .71003 Metetra
.646 .762 .934 r
.56082 .71003 .56718 .71611 .57931 .71283 .57298 .70672 Metetra
.646 .762 .934 r
.57298 .70672 .57931 .71283 .59149 .70953 .5852 .70339 Metetra
.646 .762 .934 r
.5852 .70339 .59149 .70953 .60373 .70621 .59748 .70005 Metetra
.646 .762 .934 r
.59748 .70005 .60373 .70621 .61602 .70288 .6098 .69669 Metetra
.646 .762 .934 r
.6098 .69669 .61602 .70288 .62837 .69953 .62219 .69332 Metetra
.646 .762 .934 r
.62219 .69332 .62837 .69953 .64077 .69617 .63462 .68993 Metetra
.646 .762 .934 r
.63462 .68993 .64077 .69617 .65322 .6928 .64712 .68653 Metetra
.646 .762 .934 r
.64712 .68653 .65322 .6928 .66573 .68941 .65966 .68311 Metetra
.646 .762 .934 r
.65966 .68311 .66573 .68941 .6783 .68601 .67227 .67968 Metetra
.646 .762 .934 r
.67227 .67968 .6783 .68601 .69092 .68259 .68493 .67623 Metetra
.646 .762 .934 r
.68493 .67623 .69092 .68259 .7036 .67915 .69765 .67277 Metetra
.646 .762 .934 r
.69765 .67277 .7036 .67915 .71634 .6757 .71042 .66929 Metetra
.646 .762 .934 r
.71042 .66929 .71634 .6757 .72913 .67223 .72326 .66579 Metetra
.646 .762 .934 r
.72326 .66579 .72913 .67223 .74198 .66875 .73615 .66228 Metetra
.646 .762 .934 r
.73615 .66228 .74198 .66875 .75489 .66525 .7491 .65875 Metetra
.646 .762 .934 r
.7491 .65875 .75489 .66525 .76786 .66174 .76211 .65521 Metetra
.646 .762 .934 r
.76211 .65521 .76786 .66174 .78088 .65821 .77517 .65165 Metetra
.646 .762 .934 r
.77517 .65165 .78088 .65821 .79397 .65467 .7883 .64808 Metetra
.646 .762 .934 r
.7883 .64808 .79397 .65467 .80711 .6511 .80149 .64449 Metetra
.646 .762 .934 r
.80149 .64449 .80711 .6511 .82032 .64753 .81474 .64088 Metetra
.646 .762 .934 r
.81474 .64088 .82032 .64753 .83358 .64393 .82805 .63725 Metetra
.646 .762 .934 r
.82805 .63725 .83358 .64393 .84691 .64032 .84142 .63361 Metetra
.646 .762 .934 r
.84142 .63361 .84691 .64032 .8603 .63669 .85485 .62995 Metetra
.646 .762 .934 r
.85485 .62995 .8603 .63669 .87375 .63305 .86834 .62628 Metetra
.646 .762 .934 r
.86834 .62628 .87375 .63305 .88726 .62939 .8819 .62259 Metetra
.646 .762 .934 r
.8819 .62259 .88726 .62939 .90083 .62571 .89552 .61888 Metetra
.646 .762 .934 r
.89552 .61888 .90083 .62571 .91447 .62202 .9092 .61515 Metetra
.646 .762 .934 r
.9092 .61515 .91447 .62202 .92817 .6183 .92295 .61141 Metetra
.646 .762 .934 r
.92295 .61141 .92817 .6183 .94193 .61457 .93676 .60764 Metetra
.646 .762 .934 r
.93676 .60764 .94193 .61457 .95576 .61083 .95064 .60386 Metetra
.646 .762 .934 r
.95064 .60386 .95576 .61083 .96966 .60706 .96458 .60007 Metetra
.646 .762 .934 r
.34362 .76161 .35061 .76729 .36187 .76422 .35491 .75852 Metetra
.646 .762 .934 r
.35491 .75852 .36187 .76422 .37317 .76114 .36624 .75542 Metetra
.646 .762 .934 r
.36624 .75542 .37317 .76114 .38453 .75805 .37763 .7523 Metetra
.646 .762 .934 r
.37763 .7523 .38453 .75805 .39593 .75494 .38906 .74917 Metetra
.646 .762 .934 r
.38906 .74917 .39593 .75494 .40738 .75182 .40054 .74603 Metetra
.646 .762 .934 r
.40054 .74603 .40738 .75182 .41888 .74869 .41207 .74287 Metetra
.646 .762 .934 r
.41207 .74287 .41888 .74869 .43043 .74555 .42365 .7397 Metetra
.646 .762 .934 r
.42365 .7397 .43043 .74555 .44203 .74239 .43528 .73652 Metetra
.646 .762 .934 r
.43528 .73652 .44203 .74239 .45368 .73921 .44696 .73332 Metetra
.646 .762 .934 r
.44696 .73332 .45368 .73921 .46538 .73603 .45869 .73011 Metetra
.646 .762 .934 r
.45869 .73011 .46538 .73603 .47713 .73283 .47048 .72688 Metetra
.646 .762 .934 r
.47048 .72688 .47713 .73283 .48893 .72961 .48231 .72364 Metetra
.646 .762 .934 r
.48231 .72364 .48893 .72961 .50078 .72639 .49419 .72039 Metetra
.646 .762 .934 r
.49419 .72039 .50078 .72639 .51268 .72314 .50613 .71712 Metetra
.646 .762 .934 r
.50613 .71712 .51268 .72314 .52464 .71989 .51812 .71384 Metetra
.646 .762 .934 r
.51812 .71384 .52464 .71989 .53664 .71662 .53016 .71054 Metetra
.646 .762 .934 r
.53016 .71054 .53664 .71662 .5487 .71333 .54226 .70723 Metetra
.646 .762 .934 r
.54226 .70723 .5487 .71333 .56082 .71003 .5544 .70391 Metetra
.646 .762 .934 r
.5544 .70391 .56082 .71003 .57298 .70672 .5666 .70057 Metetra
.646 .762 .934 r
.5666 .70057 .57298 .70672 .5852 .70339 .57886 .69721 Metetra
.646 .762 .934 r
.57886 .69721 .5852 .70339 .59748 .70005 .59117 .69384 Metetra
.646 .762 .934 r
.59117 .69384 .59748 .70005 .6098 .69669 .60353 .69045 Metetra
.646 .762 .934 r
.60353 .69045 .6098 .69669 .62219 .69332 .61595 .68705 Metetra
.646 .762 .934 r
.61595 .68705 .62219 .69332 .63462 .68993 .62843 .68364 Metetra
.646 .762 .934 r
.62843 .68364 .63462 .68993 .64712 .68653 .64096 .68021 Metetra
.646 .762 .934 r
.64096 .68021 .64712 .68653 .65966 .68311 .65355 .67676 Metetra
.646 .762 .934 r
.65355 .67676 .65966 .68311 .67227 .67968 .66619 .6733 Metetra
.646 .762 .934 r
.66619 .6733 .67227 .67968 .68493 .67623 .67889 .66982 Metetra
.646 .762 .934 r
.67889 .66982 .68493 .67623 .69765 .67277 .69165 .66633 Metetra
.646 .762 .934 r
.69165 .66633 .69765 .67277 .71042 .66929 .70446 .66282 Metetra
.646 .762 .934 r
.70446 .66282 .71042 .66929 .72326 .66579 .71733 .6593 Metetra
.646 .762 .934 r
.71733 .6593 .72326 .66579 .73615 .66228 .73027 .65576 Metetra
.646 .762 .934 r
.73027 .65576 .73615 .66228 .7491 .65875 .74326 .6522 Metetra
.646 .762 .934 r
.74326 .6522 .7491 .65875 .76211 .65521 .75631 .64863 Metetra
.646 .762 .934 r
.75631 .64863 .76211 .65521 .77517 .65165 .76942 .64504 Metetra
.646 .762 .934 r
.76942 .64504 .77517 .65165 .7883 .64808 .78259 .64143 Metetra
.646 .762 .934 r
.78259 .64143 .7883 .64808 .80149 .64449 .79582 .63781 Metetra
.646 .762 .934 r
.79582 .63781 .80149 .64449 .81474 .64088 .80911 .63417 Metetra
.646 .762 .934 r
.80911 .63417 .81474 .64088 .82805 .63725 .82246 .63052 Metetra
.646 .762 .934 r
.82246 .63052 .82805 .63725 .84142 .63361 .83587 .62684 Metetra
.646 .762 .934 r
.83587 .62684 .84142 .63361 .85485 .62995 .84935 .62316 Metetra
.646 .762 .934 r
.84935 .62316 .85485 .62995 .86834 .62628 .86289 .61945 Metetra
.646 .762 .934 r
.86289 .61945 .86834 .62628 .8819 .62259 .87649 .61572 Metetra
.646 .762 .934 r
.87649 .61572 .8819 .62259 .89552 .61888 .89016 .61198 Metetra
.646 .762 .934 r
.89016 .61198 .89552 .61888 .9092 .61515 .90389 .60822 Metetra
.646 .762 .934 r
.90389 .60822 .9092 .61515 .92295 .61141 .91768 .60445 Metetra
.646 .762 .934 r
.91768 .60445 .92295 .61141 .93676 .60764 .93154 .60065 Metetra
.646 .762 .934 r
.93154 .60065 .93676 .60764 .95064 .60386 .94547 .59684 Metetra
.646 .762 .934 r
.94547 .59684 .95064 .60386 .96458 .60007 .95946 .59301 Metetra
.646 .762 .934 r
.33657 .7559 .34362 .76161 .35491 .75852 .34789 .75278 Metetra
.646 .762 .934 r
.34789 .75278 .35491 .75852 .36624 .75542 .35926 .74966 Metetra
.646 .762 .934 r
.35926 .74966 .36624 .75542 .37763 .7523 .37067 .74651 Metetra
.646 .762 .934 r
.37067 .74651 .37763 .7523 .38906 .74917 .38213 .74336 Metetra
.646 .762 .934 r
.38213 .74336 .38906 .74917 .40054 .74603 .39364 .74019 Metetra
.646 .762 .934 r
.39364 .74019 .40054 .74603 .41207 .74287 .40521 .73701 Metetra
.646 .762 .934 r
.40521 .73701 .41207 .74287 .42365 .7397 .41682 .73381 Metetra
.646 .762 .934 r
.41682 .73381 .42365 .7397 .43528 .73652 .42848 .7306 Metetra
.646 .762 .934 r
.42848 .7306 .43528 .73652 .44696 .73332 .44019 .72738 Metetra
.646 .762 .934 r
.44019 .72738 .44696 .73332 .45869 .73011 .45196 .72414 Metetra
.646 .762 .934 r
.45196 .72414 .45869 .73011 .47048 .72688 .46377 .72089 Metetra
.646 .762 .934 r
.46377 .72089 .47048 .72688 .48231 .72364 .47564 .71763 Metetra
.646 .762 .934 r
.47564 .71763 .48231 .72364 .49419 .72039 .48756 .71435 Metetra
.646 .762 .934 r
.48756 .71435 .49419 .72039 .50613 .71712 .49953 .71105 Metetra
.646 .762 .934 r
.49953 .71105 .50613 .71712 .51812 .71384 .51155 .70774 Metetra
.646 .762 .934 r
.51155 .70774 .51812 .71384 .53016 .71054 .52363 .70442 Metetra
.646 .762 .934 r
.52363 .70442 .53016 .71054 .54226 .70723 .53576 .70108 Metetra
.646 .762 .934 r
.53576 .70108 .54226 .70723 .5544 .70391 .54794 .69773 Metetra
.646 .762 .934 r
.54794 .69773 .5544 .70391 .5666 .70057 .56017 .69436 Metetra
.646 .762 .934 r
.56017 .69436 .5666 .70057 .57886 .69721 .57247 .69098 Metetra
.646 .762 .934 r
.57247 .69098 .57886 .69721 .59117 .69384 .58481 .68758 Metetra
.646 .762 .934 r
.58481 .68758 .59117 .69384 .60353 .69045 .59721 .68417 Metetra
.646 .762 .934 r
.59721 .68417 .60353 .69045 .61595 .68705 .60967 .68074 Metetra
.646 .762 .934 r
.60967 .68074 .61595 .68705 .62843 .68364 .62218 .67729 Metetra
.646 .762 .934 r
.62218 .67729 .62843 .68364 .64096 .68021 .63475 .67383 Metetra
.646 .762 .934 r
.63475 .67383 .64096 .68021 .65355 .67676 .64738 .67036 Metetra
.646 .762 .934 r
.64738 .67036 .65355 .67676 .66619 .6733 .66006 .66687 Metetra
.646 .762 .934 r
.66006 .66687 .66619 .6733 .67889 .66982 .6728 .66336 Metetra
.646 .762 .934 r
.6728 .66336 .67889 .66982 .69165 .66633 .68559 .65984 Metetra
.646 .762 .934 r
.68559 .65984 .69165 .66633 .70446 .66282 .69845 .6563 Metetra
.646 .762 .934 r
.69845 .6563 .70446 .66282 .71733 .6593 .71136 .65275 Metetra
.646 .762 .934 r
.71136 .65275 .71733 .6593 .73027 .65576 .72434 .64918 Metetra
.646 .762 .934 r
.72434 .64918 .73027 .65576 .74326 .6522 .73737 .64559 Metetra
.646 .762 .934 r
.73737 .64559 .74326 .6522 .75631 .64863 .75046 .64199 Metetra
.646 .762 .934 r
.75046 .64199 .75631 .64863 .76942 .64504 .76361 .63837 Metetra
.646 .762 .934 r
.76361 .63837 .76942 .64504 .78259 .64143 .77682 .63473 Metetra
.646 .762 .934 r
.77682 .63473 .78259 .64143 .79582 .63781 .7901 .63108 Metetra
.646 .762 .934 r
.7901 .63108 .79582 .63781 .80911 .63417 .80343 .62741 Metetra
.646 .762 .934 r
.80343 .62741 .80911 .63417 .82246 .63052 .81683 .62372 Metetra
.646 .762 .934 r
.81683 .62372 .82246 .63052 .83587 .62684 .83029 .62002 Metetra
.646 .762 .934 r
.83029 .62002 .83587 .62684 .84935 .62316 .84381 .6163 Metetra
.646 .762 .934 r
.84381 .6163 .84935 .62316 .86289 .61945 .85739 .61256 Metetra
.646 .762 .934 r
.85739 .61256 .86289 .61945 .87649 .61572 .87104 .6088 Metetra
.646 .762 .934 r
.87104 .6088 .87649 .61572 .89016 .61198 .88475 .60503 Metetra
.646 .762 .934 r
.88475 .60503 .89016 .61198 .90389 .60822 .89853 .60124 Metetra
.646 .762 .934 r
.89853 .60124 .90389 .60822 .91768 .60445 .91237 .59743 Metetra
.646 .762 .934 r
.91237 .59743 .91768 .60445 .93154 .60065 .92628 .5936 Metetra
.646 .762 .934 r
.92628 .5936 .93154 .60065 .94547 .59684 .94025 .58976 Metetra
.646 .762 .934 r
.94025 .58976 .94547 .59684 .95946 .59301 .95429 .58589 Metetra
.646 .762 .934 r
.32947 .75014 .33657 .7559 .34789 .75278 .34082 .747 Metetra
.646 .762 .934 r
.34082 .747 .34789 .75278 .35926 .74966 .35221 .74385 Metetra
.646 .762 .934 r
.35221 .74385 .35926 .74966 .37067 .74651 .36366 .74068 Metetra
.646 .762 .934 r
.36366 .74068 .37067 .74651 .38213 .74336 .37515 .7375 Metetra
.646 .762 .934 r
.37515 .7375 .38213 .74336 .39364 .74019 .38669 .73431 Metetra
.646 .762 .934 r
.38669 .73431 .39364 .74019 .40521 .73701 .39829 .7311 Metetra
.646 .762 .934 r
.39829 .7311 .40521 .73701 .41682 .73381 .40993 .72788 Metetra
.646 .762 .934 r
.40993 .72788 .41682 .73381 .42848 .7306 .42162 .72464 Metetra
.646 .762 .934 r
.42162 .72464 .42848 .7306 .44019 .72738 .43337 .72139 Metetra
.646 .762 .934 r
.43337 .72139 .44019 .72738 .45196 .72414 .44517 .71813 Metetra
.646 .762 .934 r
.44517 .71813 .45196 .72414 .46377 .72089 .45701 .71485 Metetra
.646 .762 .934 r
.45701 .71485 .46377 .72089 .47564 .71763 .46891 .71156 Metetra
.646 .762 .934 r
.46891 .71156 .47564 .71763 .48756 .71435 .48086 .70825 Metetra
.646 .762 .934 r
.48086 .70825 .48756 .71435 .49953 .71105 .49287 .70493 Metetra
.646 .762 .934 r
.49287 .70493 .49953 .71105 .51155 .70774 .50493 .70159 Metetra
.646 .762 .934 r
.50493 .70159 .51155 .70774 .52363 .70442 .51704 .69824 Metetra
.646 .762 .934 r
.51704 .69824 .52363 .70442 .53576 .70108 .5292 .69488 Metetra
.646 .762 .934 r
.5292 .69488 .53576 .70108 .54794 .69773 .54142 .6915 Metetra
.646 .762 .934 r
.54142 .6915 .54794 .69773 .56017 .69436 .55369 .6881 Metetra
.646 .762 .934 r
.55369 .6881 .56017 .69436 .57247 .69098 .56602 .68469 Metetra
.646 .762 .934 r
.56602 .68469 .57247 .69098 .58481 .68758 .5784 .68127 Metetra
.646 .762 .934 r
.5784 .68127 .58481 .68758 .59721 .68417 .59084 .67782 Metetra
.646 .762 .934 r
.59084 .67782 .59721 .68417 .60967 .68074 .60333 .67437 Metetra
.646 .762 .934 r
.60333 .67437 .60967 .68074 .62218 .67729 .61588 .6709 Metetra
.646 .762 .934 r
.61588 .6709 .62218 .67729 .63475 .67383 .62849 .66741 Metetra
.646 .762 .934 r
.62849 .66741 .63475 .67383 .64738 .67036 .64115 .6639 Metetra
.646 .762 .934 r
.64115 .6639 .64738 .67036 .66006 .66687 .65387 .66038 Metetra
.646 .762 .934 r
.65387 .66038 .66006 .66687 .6728 .66336 .66665 .65685 Metetra
.646 .762 .934 r
.66665 .65685 .6728 .66336 .68559 .65984 .67949 .6533 Metetra
.646 .762 .934 r
.67949 .6533 .68559 .65984 .69845 .6563 .69239 .64973 Metetra
.646 .762 .934 r
.69239 .64973 .69845 .6563 .71136 .65275 .70534 .64615 Metetra
.646 .762 .934 r
.70534 .64615 .71136 .65275 .72434 .64918 .71835 .64255 Metetra
.646 .762 .934 r
.71835 .64255 .72434 .64918 .73737 .64559 .73143 .63893 Metetra
.646 .762 .934 r
.73143 .63893 .73737 .64559 .75046 .64199 .74456 .63529 Metetra
.646 .762 .934 r
.74456 .63529 .75046 .64199 .76361 .63837 .75775 .63164 Metetra
.646 .762 .934 r
.75775 .63164 .76361 .63837 .77682 .63473 .77101 .62798 Metetra
.646 .762 .934 r
.77101 .62798 .77682 .63473 .7901 .63108 .78433 .62429 Metetra
.646 .762 .934 r
.78433 .62429 .7901 .63108 .80343 .62741 .79771 .62059 Metetra
.646 .762 .934 r
.79771 .62059 .80343 .62741 .81683 .62372 .81115 .61687 Metetra
.646 .762 .934 r
.81115 .61687 .81683 .62372 .83029 .62002 .82465 .61314 Metetra
.646 .762 .934 r
.82465 .61314 .83029 .62002 .84381 .6163 .83822 .60938 Metetra
.646 .762 .934 r
.83822 .60938 .84381 .6163 .85739 .61256 .85185 .60561 Metetra
.646 .762 .934 r
.85185 .60561 .85739 .61256 .87104 .6088 .86554 .60182 Metetra
.646 .762 .934 r
.86554 .60182 .87104 .6088 .88475 .60503 .8793 .59802 Metetra
.646 .762 .934 r
.8793 .59802 .88475 .60503 .89853 .60124 .89312 .59419 Metetra
.646 .762 .934 r
.89312 .59419 .89853 .60124 .91237 .59743 .90701 .59035 Metetra
.646 .762 .934 r
.90701 .59035 .91237 .59743 .92628 .5936 .92097 .58649 Metetra
.646 .762 .934 r
.92097 .58649 .92628 .5936 .94025 .58976 .93499 .58261 Metetra
.646 .762 .934 r
.93499 .58261 .94025 .58976 .95429 .58589 .94908 .57871 Metetra
.646 .762 .934 r
.32231 .74433 .32947 .75014 .34082 .747 .33369 .74117 Metetra
.646 .762 .934 r
.33369 .74117 .34082 .747 .35221 .74385 .34512 .73799 Metetra
.646 .762 .934 r
.34512 .73799 .35221 .74385 .36366 .74068 .35659 .7348 Metetra
.646 .762 .934 r
.35659 .7348 .36366 .74068 .37515 .7375 .36811 .73159 Metetra
.646 .762 .934 r
.36811 .73159 .37515 .7375 .38669 .73431 .37969 .72837 Metetra
.646 .762 .934 r
.37969 .72837 .38669 .73431 .39829 .7311 .39131 .72514 Metetra
.646 .762 .934 r
.39131 .72514 .39829 .7311 .40993 .72788 .40299 .72189 Metetra
.646 .762 .934 r
.40299 .72189 .40993 .72788 .42162 .72464 .41471 .71863 Metetra
.646 .762 .934 r
.41471 .71863 .42162 .72464 .43337 .72139 .42649 .71536 Metetra
.646 .762 .934 r
.42649 .71536 .43337 .72139 .44517 .71813 .43832 .71207 Metetra
.646 .762 .934 r
.43832 .71207 .44517 .71813 .45701 .71485 .4502 .70876 Metetra
.646 .762 .934 r
.4502 .70876 .45701 .71485 .46891 .71156 .46213 .70544 Metetra
.646 .762 .934 r
.46213 .70544 .46891 .71156 .48086 .70825 .47412 .70211 Metetra
.646 .762 .934 r
.47412 .70211 .48086 .70825 .49287 .70493 .48616 .69876 Metetra
.646 .762 .934 r
.48616 .69876 .49287 .70493 .50493 .70159 .49825 .6954 Metetra
.646 .762 .934 r
.49825 .6954 .50493 .70159 .51704 .69824 .51039 .69202 Metetra
.646 .762 .934 r
.51039 .69202 .51704 .69824 .5292 .69488 .52259 .68863 Metetra
.646 .762 .934 r
.52259 .68863 .5292 .69488 .54142 .6915 .53485 .68522 Metetra
.646 .762 .934 r
.53485 .68522 .54142 .6915 .55369 .6881 .54716 .68179 Metetra
.646 .762 .934 r
.54716 .68179 .55369 .6881 .56602 .68469 .55952 .67836 Metetra
.646 .762 .934 r
.55952 .67836 .56602 .68469 .5784 .68127 .57194 .6749 Metetra
.646 .762 .934 r
.57194 .6749 .5784 .68127 .59084 .67782 .58441 .67143 Metetra
.646 .762 .934 r
.58441 .67143 .59084 .67782 .60333 .67437 .59694 .66795 Metetra
.646 .762 .934 r
.59694 .66795 .60333 .67437 .61588 .6709 .60953 .66444 Metetra
.646 .762 .934 r
.60953 .66444 .61588 .6709 .62849 .66741 .62218 .66093 Metetra
.646 .762 .934 r
.62218 .66093 .62849 .66741 .64115 .6639 .63488 .65739 Metetra
.646 .762 .934 r
.63488 .65739 .64115 .6639 .65387 .66038 .64764 .65385 Metetra
.646 .762 .934 r
.64764 .65385 .65387 .66038 .66665 .65685 .66046 .65028 Metetra
.646 .762 .934 r
.66046 .65028 .66665 .65685 .67949 .6533 .67334 .6467 Metetra
.646 .762 .934 r
.67334 .6467 .67949 .6533 .69239 .64973 .68627 .6431 Metetra
.646 .762 .934 r
.68627 .6431 .69239 .64973 .70534 .64615 .69927 .63949 Metetra
.646 .762 .934 r
.69927 .63949 .70534 .64615 .71835 .64255 .71232 .63585 Metetra
.646 .762 .934 r
.71232 .63585 .71835 .64255 .73143 .63893 .72544 .63221 Metetra
.646 .762 .934 r
.72544 .63221 .73143 .63893 .74456 .63529 .73861 .62854 Metetra
.646 .762 .934 r
.73861 .62854 .74456 .63529 .75775 .63164 .75185 .62486 Metetra
.646 .762 .934 r
.75185 .62486 .75775 .63164 .77101 .62798 .76515 .62116 Metetra
.646 .762 .934 r
.76515 .62116 .77101 .62798 .78433 .62429 .77851 .61745 Metetra
.646 .762 .934 r
.77851 .61745 .78433 .62429 .79771 .62059 .79193 .61371 Metetra
.646 .762 .934 r
.79193 .61371 .79771 .62059 .81115 .61687 .80542 .60996 Metetra
.646 .762 .934 r
.80542 .60996 .81115 .61687 .82465 .61314 .81896 .60619 Metetra
.646 .762 .934 r
.81896 .60619 .82465 .61314 .83822 .60938 .83258 .60241 Metetra
.646 .762 .934 r
.83258 .60241 .83822 .60938 .85185 .60561 .84625 .5986 Metetra
.646 .762 .934 r
.84625 .5986 .85185 .60561 .86554 .60182 .85999 .59478 Metetra
.646 .762 .934 r
.85999 .59478 .86554 .60182 .8793 .59802 .8738 .59094 Metetra
.646 .762 .934 r
.8738 .59094 .8793 .59802 .89312 .59419 .88767 .58708 Metetra
.646 .762 .934 r
.88767 .58708 .89312 .59419 .90701 .59035 .90161 .58321 Metetra
.646 .762 .934 r
.90161 .58321 .90701 .59035 .92097 .58649 .91561 .57931 Metetra
.646 .762 .934 r
.91561 .57931 .92097 .58649 .93499 .58261 .92968 .5754 Metetra
.646 .762 .934 r
.92968 .5754 .93499 .58261 .94908 .57871 .94382 .57146 Metetra
.648 .763 .933 r
.3151 .73848 .32231 .74433 .33369 .74117 .32651 .73523 Metetra
.654 .762 .929 r
.32651 .73523 .33369 .74117 .34512 .73799 .33798 .73183 Metetra
.658 .757 .923 r
.33798 .73183 .34512 .73799 .35659 .7348 .34949 .7283 Metetra
.662 .749 .914 r
.34949 .7283 .35659 .7348 .36811 .73159 .36107 .72465 Metetra
.666 .737 .903 r
.36107 .72465 .36811 .73159 .37969 .72837 .37269 .72087 Metetra
.669 .723 .89 r
.37269 .72087 .37969 .72837 .39131 .72514 .38437 .71697 Metetra
.67 .707 .876 r
.38437 .71697 .39131 .72514 .40299 .72189 .39609 .71296 Metetra
.67 .69 .86 r
.39609 .71296 .40299 .72189 .41471 .71863 .40787 .70886 Metetra
.669 .673 .845 r
.40787 .70886 .41471 .71863 .42649 .71536 .41969 .70466 Metetra
.667 .655 .829 r
.41969 .70466 .42649 .71536 .43832 .71207 .43157 .70039 Metetra
.664 .638 .814 r
.43157 .70039 .43832 .71207 .4502 .70876 .44348 .69607 Metetra
.66 .622 .8 r
.44348 .69607 .4502 .70876 .46213 .70544 .45545 .6917 Metetra
.657 .607 .788 r
.45545 .6917 .46213 .70544 .47412 .70211 .46746 .68732 Metetra
.653 .594 .776 r
.46746 .68732 .47412 .70211 .48616 .69876 .47951 .68292 Metetra
.649 .581 .765 r
.47951 .68292 .48616 .69876 .49825 .6954 .49162 .67854 Metetra
.645 .57 .756 r
.49162 .67854 .49825 .6954 .51039 .69202 .50377 .67418 Metetra
.641 .56 .748 r
.50377 .67418 .51039 .69202 .52259 .68863 .51596 .66987 Metetra
.638 .551 .74 r
.51596 .66987 .52259 .68863 .53485 .68522 .52821 .66561 Metetra
.634 .544 .734 r
.52821 .66561 .53485 .68522 .54716 .68179 .5405 .66142 Metetra
.631 .537 .729 r
.5405 .66142 .54716 .68179 .55952 .67836 .55285 .65732 Metetra
.629 .531 .725 r
.55285 .65732 .55952 .67836 .57194 .6749 .56525 .6533 Metetra
.626 .527 .722 r
.56525 .6533 .57194 .6749 .58441 .67143 .5777 .64939 Metetra
.624 .523 .719 r
.5777 .64939 .58441 .67143 .59694 .66795 .5902 .64558 Metetra
.621 .52 .718 r
.5902 .64558 .59694 .66795 .60953 .66444 .60277 .64188 Metetra
.619 .518 .717 r
.60277 .64188 .60953 .66444 .62218 .66093 .61539 .6383 Metetra
.618 .517 .717 r
.61539 .6383 .62218 .66093 .63488 .65739 .62808 .63483 Metetra
.616 .517 .718 r
.62808 .63483 .63488 .65739 .64764 .65385 .64082 .63148 Metetra
.615 .518 .72 r
.64082 .63148 .64764 .65385 .66046 .65028 .65364 .62823 Metetra
.614 .519 .723 r
.65364 .62823 .66046 .65028 .67334 .6467 .66651 .62509 Metetra
.614 .522 .727 r
.66651 .62509 .67334 .6467 .68627 .6431 .67946 .62205 Metetra
.613 .525 .731 r
.67946 .62205 .68627 .6431 .69927 .63949 .69247 .61909 Metetra
.613 .53 .737 r
.69247 .61909 .69927 .63949 .71232 .63585 .70556 .61621 Metetra
.613 .536 .743 r
.70556 .61621 .71232 .63585 .72544 .63221 .71872 .6134 Metetra
.614 .543 .751 r
.71872 .6134 .72544 .63221 .73861 .62854 .73194 .61063 Metetra
.614 .551 .76 r
.73194 .61063 .73861 .62854 .75185 .62486 .74524 .6079 Metetra
.616 .561 .77 r
.74524 .6079 .75185 .62486 .76515 .62116 .75861 .60519 Metetra
.617 .572 .782 r
.75861 .60519 .76515 .62116 .77851 .61745 .77206 .60247 Metetra
.618 .585 .794 r
.77206 .60247 .77851 .61745 .79193 .61371 .78557 .59974 Metetra
.62 .6 .808 r
.78557 .59974 .79193 .61371 .80542 .60996 .79915 .59698 Metetra
.622 .616 .823 r
.79915 .59698 .80542 .60996 .81896 .60619 .81281 .59416 Metetra
.625 .633 .838 r
.81281 .59416 .81896 .60619 .83258 .60241 .82653 .59128 Metetra
.627 .651 .854 r
.82653 .59128 .83258 .60241 .84625 .5986 .84031 .58831 Metetra
.629 .67 .87 r
.84031 .58831 .84625 .5986 .85999 .59478 .85416 .58523 Metetra
.631 .689 .885 r
.85416 .58523 .85999 .59478 .8738 .59094 .86807 .58205 Metetra
.633 .707 .899 r
.86807 .58205 .8738 .59094 .88767 .58708 .88205 .57874 Metetra
.635 .723 .911 r
.88205 .57874 .88767 .58708 .90161 .58321 .89608 .5753 Metetra
.637 .738 .921 r
.89608 .5753 .90161 .58321 .91561 .57931 .91017 .57173 Metetra
.64 .749 .928 r
.91017 .57173 .91561 .57931 .92968 .5754 .92432 .56802 Metetra
.643 .758 .932 r
.92432 .56802 .92968 .5754 .94382 .57146 .93852 .56416 Metetra
.648 .763 .933 r
.30783 .73258 .3151 .73848 .32651 .73523 .31927 .72931 Metetra
.663 .767 .927 r
.31927 .72931 .32651 .73523 .33798 .73183 .33078 .72561 Metetra
.672 .76 .917 r
.33078 .72561 .33798 .73183 .34949 .7283 .34235 .72165 Metetra
.68 .75 .904 r
.34235 .72165 .34949 .7283 .36107 .72465 .35398 .71742 Metetra
.686 .736 .889 r
.35398 .71742 .36107 .72465 .37269 .72087 .36566 .71293 Metetra
.689 .719 .872 r
.36566 .71293 .37269 .72087 .38437 .71697 .3774 .70819 Metetra
.691 .701 .854 r
.3774 .70819 .38437 .71697 .39609 .71296 .38919 .70321 Metetra
.69 .681 .836 r
.38919 .70321 .39609 .71296 .40787 .70886 .40102 .69803 Metetra
.688 .662 .819 r
.40102 .69803 .40787 .70886 .41969 .70466 .4129 .69267 Metetra
.684 .642 .802 r
.4129 .69267 .41969 .70466 .43157 .70039 .42482 .68717 Metetra
.68 .624 .786 r
.42482 .68717 .43157 .70039 .44348 .69607 .43678 .68155 Metetra
.674 .607 .772 r
.43678 .68155 .44348 .69607 .45545 .6917 .44878 .67587 Metetra
.669 .591 .759 r
.44878 .67587 .45545 .6917 .46746 .68732 .46082 .67015 Metetra
.663 .577 .747 r
.46082 .67015 .46746 .68732 .47951 .68292 .47289 .66444 Metetra
.658 .563 .737 r
.47289 .66444 .47951 .68292 .49162 .67854 .485 .65877 Metetra
.652 .552 .728 r
.485 .65877 .49162 .67854 .50377 .67418 .49715 .65318 Metetra
.647 .541 .721 r
.49715 .65318 .50377 .67418 .51596 .66987 .50934 .64771 Metetra
.642 .532 .714 r
.50934 .64771 .51596 .66987 .52821 .66561 .52157 .64238 Metetra
.637 .523 .708 r
.52157 .64238 .52821 .66561 .5405 .66142 .53384 .63723 Metetra
.632 .516 .704 r
.53384 .63723 .5405 .66142 .55285 .65732 .54615 .63229 Metetra
.628 .51 .7 r
.54615 .63229 .55285 .65732 .56525 .6533 .55851 .62758 Metetra
.623 .504 .697 r
.55851 .62758 .56525 .6533 .5777 .64939 .57093 .62311 Metetra
.62 .5 .695 r
.57093 .62311 .5777 .64939 .5902 .64558 .58339 .61891 Metetra
.616 .496 .694 r
.58339 .61891 .5902 .64558 .60277 .64188 .59592 .61497 Metetra
.612 .493 .693 r
.59592 .61497 .60277 .64188 .61539 .6383 .6085 .61131 Metetra
.609 .491 .693 r
.6085 .61131 .61539 .6383 .62808 .63483 .62116 .60793 Metetra
.606 .49 .695 r
.62116 .60793 .62808 .63483 .64082 .63148 .63388 .60483 Metetra
.604 .489 .696 r
.63388 .60483 .64082 .63148 .65364 .62823 .64667 .602 Metetra
.601 .49 .699 r
.64667 .602 .65364 .62823 .66651 .62509 .65953 .59942 Metetra
.599 .491 .703 r
.65953 .59942 .66651 .62509 .67946 .62205 .67248 .59708 Metetra
.597 .494 .707 r
.67248 .59708 .67946 .62205 .69247 .61909 .6855 .59497 Metetra
.595 .497 .713 r
.6855 .59497 .69247 .61909 .70556 .61621 .69861 .59304 Metetra
.594 .502 .72 r
.69861 .59304 .70556 .61621 .71872 .6134 .71181 .59129 Metetra
.593 .508 .727 r
.71181 .59129 .71872 .6134 .73194 .61063 .72508 .58967 Metetra
.592 .515 .737 r
.72508 .58967 .73194 .61063 .74524 .6079 .73845 .58815 Metetra
.592 .524 .747 r
.73845 .58815 .74524 .6079 .75861 .60519 .75189 .58669 Metetra
.592 .534 .759 r
.75189 .58669 .75861 .60519 .77206 .60247 .76543 .58526 Metetra
.592 .547 .773 r
.76543 .58526 .77206 .60247 .78557 .59974 .77904 .58381 Metetra
.594 .562 .788 r
.77904 .58381 .78557 .59974 .79915 .59698 .79273 .58231 Metetra
.595 .579 .805 r
.79273 .58231 .79915 .59698 .81281 .59416 .8065 .58072 Metetra
.598 .597 .822 r
.8065 .58072 .81281 .59416 .82653 .59128 .82034 .57899 Metetra
.601 .618 .841 r
.82034 .57899 .82653 .59128 .84031 .58831 .83425 .57709 Metetra
.604 .64 .86 r
.83425 .57709 .84031 .58831 .85416 .58523 .84823 .57498 Metetra
.608 .663 .878 r
.84823 .57498 .85416 .58523 .86807 .58205 .86226 .57265 Metetra
.613 .686 .895 r
.86226 .57265 .86807 .58205 .88205 .57874 .87635 .57006 Metetra
.618 .708 .91 r
.87635 .57006 .88205 .57874 .89608 .5753 .89049 .56719 Metetra
.624 .727 .921 r
.89049 .56719 .89608 .5753 .91017 .57173 .90468 .56405 Metetra
.63 .744 .93 r
.90468 .56405 .91017 .57173 .92432 .56802 .91891 .56062 Metetra
.641 .759 .934 r
.91891 .56062 .92432 .56802 .93852 .56416 .93316 .55678 Metetra
.646 .762 .934 r
.3005 .72663 .30783 .73258 .31927 .72931 .31196 .72339 Metetra
.67 .77 .925 r
.31196 .72339 .31927 .72931 .33078 .72561 .32352 .71948 Metetra
.685 .767 .914 r
.32352 .71948 .33078 .72561 .34235 .72165 .33514 .71508 Metetra
.696 .757 .899 r
.33514 .71508 .34235 .72165 .35398 .71742 .34683 .71027 Metetra
.704 .743 .883 r
.34683 .71027 .35398 .71742 .36566 .71293 .35858 .70507 Metetra
.709 .727 .865 r
.35858 .70507 .36566 .71293 .3774 .70819 .37038 .69949 Metetra
.711 .71 .847 r
.37038 .69949 .3774 .70819 .38919 .70321 .38223 .69356 Metetra
.711 .691 .829 r
.38223 .69356 .38919 .70321 .40102 .69803 .39413 .68731 Metetra
.709 .672 .812 r
.39413 .68731 .40102 .69803 .4129 .69267 .40606 .6808 Metetra
.705 .653 .796 r
.40606 .6808 .4129 .69267 .42482 .68717 .41804 .67408 Metetra
.7 .635 .781 r
.41804 .67408 .42482 .68717 .43678 .68155 .43005 .66719 Metetra
.694 .618 .767 r
.43005 .66719 .43678 .68155 .44878 .67587 .44209 .6602 Metetra
.687 .602 .755 r
.44209 .6602 .44878 .67587 .46082 .67015 .45416 .65318 Metetra
.681 .588 .744 r
.45416 .65318 .46082 .67015 .47289 .66444 .46626 .64617 Metetra
.674 .574 .735 r
.46626 .64617 .47289 .66444 .485 .65877 .47838 .63923 Metetra
.667 .562 .727 r
.47838 .63923 .485 .65877 .49715 .65318 .49054 .63244 Metetra
.661 .551 .719 r
.49054 .63244 .49715 .65318 .50934 .64771 .50272 .62583 Metetra
.654 .541 .713 r
.50272 .62583 .50934 .64771 .52157 .64238 .51494 .61946 Metetra
.648 .531 .708 r
.51494 .61946 .52157 .64238 .53384 .63723 .52719 .61338 Metetra
.641 .523 .704 r
.52719 .61338 .53384 .63723 .54615 .63229 .53947 .60762 Metetra
.635 .516 .7 r
.53947 .60762 .54615 .63229 .55851 .62758 .5518 .60223 Metetra
.629 .509 .698 r
.5518 .60223 .55851 .62758 .57093 .62311 .56418 .59722 Metetra
.624 .504 .696 r
.56418 .59722 .57093 .62311 .58339 .61891 .57661 .59262 Metetra
.618 .499 .695 r
.57661 .59262 .58339 .61891 .59592 .61497 .5891 .58846 Metetra
.613 .495 .695 r
.5891 .58846 .59592 .61497 .6085 .61131 .60165 .58472 Metetra
.608 .492 .695 r
.60165 .58472 .6085 .61131 .62116 .60793 .61427 .58143 Metetra
.603 .489 .696 r
.61427 .58143 .62116 .60793 .63388 .60483 .62696 .57858 Metetra
.599 .488 .699 r
.62696 .57858 .63388 .60483 .64667 .602 .63973 .57614 Metetra
.594 .487 .702 r
.63973 .57614 .64667 .602 .65953 .59942 .65258 .57412 Metetra
.59 .487 .705 r
.65258 .57412 .65953 .59942 .67248 .59708 .66553 .57247 Metetra
.586 .488 .71 r
.66553 .57247 .67248 .59708 .6855 .59497 .67856 .57117 Metetra
.582 .491 .716 r
.67856 .57117 .6855 .59497 .69861 .59304 .69169 .57018 Metetra
.579 .494 .723 r
.69169 .57018 .69861 .59304 .71181 .59129 .70491 .56946 Metetra
.576 .499 .731 r
.70491 .56946 .71181 .59129 .72508 .58967 .71824 .56896 Metetra
.573 .505 .741 r
.71824 .56896 .72508 .58967 .73845 .58815 .73166 .56862 Metetra
.571 .514 .752 r
.73166 .56862 .73845 .58815 .75189 .58669 .74518 .5684 Metetra
.569 .524 .765 r
.74518 .5684 .75189 .58669 .76543 .58526 .75879 .56823 Metetra
.568 .536 .779 r
.75879 .56823 .76543 .58526 .77904 .58381 .7725 .56804 Metetra
.568 .55 .795 r
.7725 .56804 .77904 .58381 .79273 .58231 .7863 .56778 Metetra
.568 .567 .812 r
.7863 .56778 .79273 .58231 .8065 .58072 .80018 .56739 Metetra
.57 .586 .83 r
.80018 .56739 .8065 .58072 .82034 .57899 .81414 .5668 Metetra
.573 .607 .849 r
.81414 .5668 .82034 .57899 .83425 .57709 .82817 .56596 Metetra
.577 .63 .868 r
.82817 .56596 .83425 .57709 .84823 .57498 .84226 .56481 Metetra
.583 .654 .886 r
.84226 .56481 .84823 .57498 .86226 .57265 .85642 .56332 Metetra
.59 .679 .902 r
.85642 .56332 .86226 .57265 .87635 .57006 .87062 .56144 Metetra
.598 .702 .917 r
.87062 .56144 .87635 .57006 .89049 .56719 .88487 .55915 Metetra
.608 .724 .928 r
.88487 .55915 .89049 .56719 .90468 .56405 .89915 .55645 Metetra
.618 .743 .936 r
.89915 .55645 .90468 .56405 .91891 .56062 .91347 .55332 Metetra
.644 .765 .937 r
.91347 .55332 .91891 .56062 .93316 .55678 .92776 .54934 Metetra
.646 .762 .934 r
.29311 .72064 .3005 .72663 .31196 .72339 .30461 .71737 Metetra
.667 .767 .925 r
.30461 .71737 .31196 .72339 .32352 .71948 .31619 .71351 Metetra
.698 .776 .912 r
.31619 .71351 .32352 .71948 .33514 .71508 .32787 .70865 Metetra
.711 .766 .895 r
.32787 .70865 .33514 .71508 .34683 .71027 .33962 .70327 Metetra
.721 .752 .877 r
.33962 .70327 .34683 .71027 .35858 .70507 .35143 .69737 Metetra
.727 .736 .859 r
.35143 .69737 .35858 .70507 .37038 .69949 .3633 .69096 Metetra
.73 .719 .841 r
.3633 .69096 .37038 .69949 .38223 .69356 .37522 .68408 Metetra
.73 .701 .823 r
.37522 .68408 .38223 .69356 .39413 .68731 .38718 .67679 Metetra
.728 .682 .806 r
.38718 .67679 .39413 .68731 .40606 .6808 .39919 .66915 Metetra
.724 .664 .791 r
.39919 .66915 .40606 .6808 .41804 .67408 .41122 .66122 Metetra
.718 .646 .776 r
.41122 .66122 .41804 .67408 .43005 .66719 .42329 .65309 Metetra
.712 .63 .764 r
.42329 .65309 .43005 .66719 .44209 .6602 .43537 .64483 Metetra
.705 .614 .752 r
.43537 .64483 .44209 .6602 .45416 .65318 .44748 .63652 Metetra
.698 .599 .742 r
.44748 .63652 .45416 .65318 .46626 .64617 .45961 .62824 Metetra
.69 .585 .733 r
.45961 .62824 .46626 .64617 .47838 .63923 .47175 .62008 Metetra
.682 .573 .726 r
.47175 .62008 .47838 .63923 .49054 .63244 .48392 .6121 Metetra
.674 .561 .719 r
.48392 .6121 .49054 .63244 .50272 .62583 .4961 .60439 Metetra
.666 .55 .713 r
.4961 .60439 .50272 .62583 .51494 .61946 .50831 .597 Metetra
.659 .54 .708 r
.50831 .597 .51494 .61946 .52719 .61338 .52055 .59001 Metetra
.651 .531 .705 r
.52055 .59001 .52719 .61338 .53947 .60762 .53281 .58346 Metetra
.643 .523 .702 r
.53281 .58346 .53947 .60762 .5518 .60223 .54512 .5774 Metetra
.636 .515 .699 r
.54512 .5774 .5518 .60223 .56418 .59722 .55746 .57186 Metetra
.628 .509 .698 r
.55746 .57186 .56418 .59722 .57661 .59262 .56986 .56689 Metetra
.621 .503 .697 r
.56986 .56689 .57661 .59262 .5891 .58846 .58231 .56249 Metetra
.614 .498 .697 r
.58231 .56249 .5891 .58846 .60165 .58472 .59482 .55869 Metetra
.607 .493 .698 r
.59482 .55869 .60165 .58472 .61427 .58143 .60741 .55548 Metetra
.6 .49 .699 r
.60741 .55548 .61427 .58143 .62696 .57858 .62008 .55286 Metetra
.594 .487 .702 r
.62008 .55286 .62696 .57858 .63973 .57614 .63282 .55082 Metetra
.587 .485 .705 r
.63282 .55082 .63973 .57614 .65258 .57412 .64566 .54932 Metetra
.581 .484 .709 r
.64566 .54932 .65258 .57412 .66553 .57247 .6586 .54834 Metetra
.575 .484 .714 r
.6586 .54834 .66553 .57247 .67856 .57117 .67164 .54784 Metetra
.569 .485 .72 r
.67164 .54784 .67856 .57117 .69169 .57018 .68479 .54776 Metetra
.563 .487 .728 r
.68479 .54776 .69169 .57018 .70491 .56946 .69804 .54805 Metetra
.557 .491 .736 r
.69804 .54805 .70491 .56946 .71824 .56896 .71141 .54864 Metetra
.552 .496 .746 r
.71141 .54864 .71824 .56896 .73166 .56862 .72488 .54946 Metetra
.548 .503 .758 r
.72488 .54946 .73166 .56862 .74518 .5684 .73847 .55044 Metetra
.544 .513 .771 r
.73847 .55044 .74518 .5684 .75879 .56823 .75217 .55149 Metetra
.541 .524 .786 r
.75217 .55149 .75879 .56823 .7725 .56804 .76596 .55254 Metetra
.539 .538 .802 r
.76596 .55254 .7725 .56804 .7863 .56778 .77986 .5535 Metetra
.539 .555 .819 r
.77986 .5535 .7863 .56778 .80018 .56739 .79385 .55428 Metetra
.539 .574 .838 r
.79385 .55428 .80018 .56739 .81414 .5668 .80792 .55481 Metetra
.542 .596 .857 r
.80792 .55481 .81414 .5668 .82817 .56596 .82207 .55501 Metetra
.547 .62 .876 r
.82207 .55501 .82817 .56596 .84226 .56481 .83628 .5548 Metetra
.555 .646 .895 r
.83628 .5548 .84226 .56481 .85642 .56332 .85055 .55414 Metetra
.564 .672 .911 r
.85055 .55414 .85642 .56332 .87062 .56144 .86486 .55297 Metetra
.576 .698 .925 r
.86486 .55297 .87062 .56144 .88487 .55915 .87922 .55126 Metetra
.59 .722 .936 r
.87922 .55126 .88487 .55915 .89915 .55645 .8936 .54899 Metetra
.614 .748 .941 r
.8936 .54899 .89915 .55645 .91347 .55332 .90798 .54591 Metetra
.646 .764 .935 r
.90798 .54591 .91347 .55332 .92776 .54934 .92232 .54183 Metetra
.646 .762 .934 r
.28566 .7146 .29311 .72064 .30461 .71737 .29719 .7113 Metetra
.655 .765 .93 r
.29719 .7113 .30461 .71737 .31619 .71351 .30878 .70776 Metetra
.711 .786 .91 r
.30878 .70776 .31619 .71351 .32787 .70865 .32052 .70245 Metetra
.726 .775 .892 r
.32052 .70245 .32787 .70865 .33962 .70327 .33234 .69649 Metetra
.737 .762 .873 r
.33234 .69649 .33962 .70327 .35143 .69737 .34422 .68989 Metetra
.744 .746 .854 r
.34422 .68989 .35143 .69737 .3633 .69096 .35616 .68266 Metetra
.747 .729 .835 r
.35616 .68266 .3633 .69096 .37522 .68408 .36815 .67486 Metetra
.748 .711 .818 r
.36815 .67486 .37522 .68408 .38718 .67679 .38019 .66655 Metetra
.746 .693 .801 r
.38019 .66655 .38718 .67679 .39919 .66915 .39226 .6578 Metetra
.742 .676 .786 r
.39226 .6578 .39919 .66915 .41122 .66122 .40436 .6487 Metetra
.736 .658 .773 r
.40436 .6487 .41122 .66122 .42329 .65309 .41648 .63935 Metetra
.73 .642 .761 r
.41648 .63935 .42329 .65309 .43537 .64483 .42862 .62985 Metetra
.722 .626 .75 r
.42862 .62985 .43537 .64483 .44748 .63652 .44078 .62029 Metetra
.714 .611 .741 r
.44078 .62029 .44748 .63652 .45961 .62824 .45294 .61078 Metetra
.705 .597 .732 r
.45294 .61078 .45961 .62824 .47175 .62008 .46511 .60141 Metetra
.697 .584 .725 r
.46511 .60141 .47175 .62008 .48392 .6121 .47729 .59229 Metetra
.688 .572 .719 r
.47729 .59229 .48392 .6121 .4961 .60439 .48948 .58351 Metetra
.679 .56 .714 r
.48948 .58351 .4961 .60439 .50831 .597 .50169 .57513 Metetra
.67 .55 .71 r
.50169 .57513 .50831 .597 .52055 .59001 .51391 .56725 Metetra
.661 .54 .706 r
.51391 .56725 .52055 .59001 .53281 .58346 .52616 .55993 Metetra
.651 .531 .704 r
.52616 .55993 .53281 .58346 .54512 .5774 .53844 .55323 Metetra
.642 .522 .702 r
.53844 .55323 .54512 .5774 .55746 .57186 .55076 .54719 Metetra
.633 .514 .7 r
.55076 .54719 .55746 .57186 .56986 .56689 .56313 .54185 Metetra
.624 .507 .7 r
.56313 .54185 .56986 .56689 .58231 .56249 .57555 .53723 Metetra
.615 .501 .7 r
.57555 .53723 .58231 .56249 .59482 .55869 .58803 .53336 Metetra
.606 .496 .701 r
.58803 .53336 .59482 .55869 .60741 .55548 .60059 .53023 Metetra
.598 .491 .703 r
.60059 .53023 .60741 .55548 .62008 .55286 .61323 .52784 Metetra
.589 .487 .706 r
.61323 .52784 .62008 .55286 .63282 .55082 .62596 .52617 Metetra
.58 .483 .709 r
.62596 .52617 .63282 .55082 .64566 .54932 .63878 .52519 Metetra
.571 .481 .714 r
.63878 .52519 .64566 .54932 .6586 .54834 .65171 .52485 Metetra
.562 .48 .719 r
.65171 .52485 .6586 .54834 .67164 .54784 .66476 .52512 Metetra
.554 .479 .726 r
.66476 .52512 .67164 .54784 .68479 .54776 .67792 .52592 Metetra
.546 .48 .733 r
.67792 .52592 .68479 .54776 .69804 .54805 .6912 .52718 Metetra
.537 .483 .742 r
.6912 .52718 .69804 .54805 .71141 .54864 .7046 .52883 Metetra
.53 .487 .753 r
.7046 .52883 .71141 .54864 .72488 .54946 .71813 .53078 Metetra
.523 .493 .765 r
.71813 .53078 .72488 .54946 .73847 .55044 .73178 .53292 Metetra
.516 .501 .778 r
.73178 .53292 .73847 .55044 .75217 .55149 .74555 .53517 Metetra
.511 .512 .793 r
.74555 .53517 .75217 .55149 .76596 .55254 .75943 .53742 Metetra
.507 .526 .81 r
.75943 .53742 .76596 .55254 .77986 .5535 .77342 .53956 Metetra
.505 .542 .828 r
.77342 .53956 .77986 .5535 .79385 .55428 .78751 .5415 Metetra
.505 .562 .847 r
.78751 .5415 .79385 .55428 .80792 .55481 .80169 .54312 Metetra
.508 .584 .867 r
.80169 .54312 .80792 .55481 .82207 .55501 .81595 .54433 Metetra
.514 .61 .886 r
.81595 .54433 .82207 .55501 .83628 .5548 .83028 .54504 Metetra
.523 .637 .904 r
.83028 .54504 .83628 .5548 .85055 .55414 .84466 .54519 Metetra
.536 .666 .921 r
.84466 .54519 .85055 .55414 .86486 .55297 .85909 .54472 Metetra
.551 .694 .934 r
.85909 .54472 .86486 .55297 .87922 .55126 .87355 .54357 Metetra
.569 .721 .945 r
.87355 .54357 .87922 .55126 .8936 .54899 .88803 .54176 Metetra
.621 .76 .945 r
.88803 .54176 .8936 .54899 .90798 .54591 .90243 .53837 Metetra
.646 .762 .934 r
.90243 .53837 .90798 .54591 .92232 .54183 .91682 .53426 Metetra
.646 .762 .934 r
.27815 .70851 .28566 .7146 .29719 .7113 .28971 .70519 Metetra
.646 .762 .934 r
.28971 .70519 .29719 .7113 .30878 .70776 .30132 .70185 Metetra
.71 .782 .908 r
.30132 .70185 .30878 .70776 .32052 .70245 .31309 .69652 Metetra
.74 .786 .89 r
.31309 .69652 .32052 .70245 .33234 .69649 .32498 .69 Metetra
.752 .773 .87 r
.32498 .69 .33234 .69649 .34422 .68989 .33693 .68271 Metetra
.76 .757 .85 r
.33693 .68271 .34422 .68989 .35616 .68266 .34895 .67469 Metetra
.764 .74 .831 r
.34895 .67469 .35616 .68266 .36815 .67486 .36102 .66598 Metetra
.765 .723 .813 r
.36102 .66598 .36815 .67486 .38019 .66655 .37313 .65667 Metetra
.763 .705 .797 r
.37313 .65667 .38019 .66655 .39226 .6578 .38528 .64685 Metetra
.759 .687 .783 r
.38528 .64685 .39226 .6578 .40436 .6487 .39745 .63661 Metetra
.753 .67 .77 r
.39745 .63661 .40436 .6487 .41648 .63935 .40964 .62608 Metetra
.746 .654 .758 r
.40964 .62608 .41648 .63935 .42862 .62985 .42184 .61537 Metetra
.739 .639 .748 r
.42184 .61537 .42862 .62985 .44078 .62029 .43404 .6046 Metetra
.73 .624 .74 r
.43404 .6046 .44078 .62029 .45294 .61078 .44624 .59389 Metetra
.721 .61 .732 r
.44624 .59389 .45294 .61078 .46511 .60141 .45845 .58336 Metetra
.711 .596 .726 r
.45845 .58336 .46511 .60141 .47729 .59229 .47065 .57313 Metetra
.701 .583 .72 r
.47065 .57313 .47729 .59229 .48948 .58351 .48285 .56331 Metetra
.691 .571 .715 r
.48285 .56331 .48948 .58351 .50169 .57513 .49507 .55398 Metetra
.681 .56 .712 r
.49507 .55398 .50169 .57513 .51391 .56725 .50729 .54525 Metetra
.671 .55 .709 r
.50729 .54525 .51391 .56725 .52616 .55993 .51953 .53719 Metetra
.66 .54 .706 r
.51953 .53719 .52616 .55993 .53844 .55323 .53179 .52986 Metetra
.65 .53 .705 r
.53179 .52986 .53844 .55323 .55076 .54719 .54408 .52333 Metetra
.639 .521 .704 r
.54408 .52333 .55076 .54719 .56313 .54185 .55642 .51763 Metetra
.628 .513 .704 r
.55642 .51763 .56313 .54185 .57555 .53723 .56882 .51281 Metetra
.617 .506 .704 r
.56882 .51281 .57555 .53723 .58803 .53336 .58127 .50886 Metetra
.606 .499 .706 r
.58127 .50886 .58803 .53336 .60059 .53023 .5938 .50581 Metetra
.595 .493 .708 r
.5938 .50581 .60059 .53023 .61323 .52784 .60641 .50364 Metetra
.584 .487 .711 r
.60641 .50364 .61323 .52784 .62596 .52617 .61912 .50233 Metetra
.572 .483 .715 r
.61912 .50233 .62596 .52617 .63878 .52519 .63194 .50184 Metetra
.561 .479 .719 r
.63194 .50184 .63878 .52519 .65171 .52485 .64486 .50213 Metetra
.549 .476 .725 r
.64486 .50213 .65171 .52485 .66476 .52512 .65791 .50313 Metetra
.538 .474 .732 r
.65791 .50313 .66476 .52512 .67792 .52592 .67108 .50478 Metetra
.526 .474 .74 r
.67108 .50478 .67792 .52592 .6912 .52718 .68439 .50699 Metetra
.515 .475 .75 r
.68439 .50699 .6912 .52718 .7046 .52883 .69782 .50966 Metetra
.505 .477 .76 r
.69782 .50966 .7046 .52883 .71813 .53078 .7114 .51269 Metetra
.494 .482 .773 r
.7114 .51269 .71813 .53078 .73178 .53292 .72511 .51596 Metetra
.485 .489 .787 r
.72511 .51596 .73178 .53292 .74555 .53517 .73895 .51937 Metetra
.477 .499 .802 r
.73895 .51937 .74555 .53517 .75943 .53742 .75291 .52278 Metetra
.471 .512 .819 r
.75291 .52278 .75943 .53742 .77342 .53956 .76699 .52607 Metetra
.467 .529 .837 r
.76699 .52607 .77342 .53956 .78751 .5415 .78118 .52912 Metetra
.466 .549 .857 r
.78118 .52912 .78751 .5415 .80169 .54312 .79547 .5318 Metetra
.469 .572 .876 r
.79547 .5318 .80169 .54312 .81595 .54433 .80984 .53399 Metetra
.476 .599 .896 r
.80984 .53399 .81595 .54433 .83028 .54504 .82427 .53561 Metetra
.487 .629 .914 r
.82427 .53561 .83028 .54504 .84466 .54519 .83877 .53655 Metetra
.503 .66 .931 r
.83877 .53655 .84466 .54519 .85909 .54472 .8533 .53675 Metetra
.523 .691 .944 r
.8533 .53675 .85909 .54472 .87355 .54357 .86787 .53617 Metetra
.546 .721 .955 r
.86787 .53617 .87355 .54357 .88803 .54176 .88245 .5348 Metetra
.64 .779 .948 r
.88245 .5348 .88803 .54176 .90243 .53837 .89683 .53076 Metetra
.646 .762 .934 r
.89683 .53076 .90243 .53837 .91682 .53426 .91127 .52661 Metetra
.646 .762 .934 r
.27058 .70237 .27815 .70851 .28971 .70519 .28217 .69902 Metetra
.646 .762 .934 r
.28217 .69902 .28971 .70519 .30132 .70185 .29381 .69566 Metetra
.691 .772 .913 r
.29381 .69566 .30132 .70185 .31309 .69652 .30558 .69093 Metetra
.753 .799 .889 r
.30558 .69093 .31309 .69652 .32498 .69 .31754 .68385 Metetra
.767 .784 .868 r
.31754 .68385 .32498 .69 .33693 .68271 .32957 .67589 Metetra
.775 .769 .847 r
.32957 .67589 .33693 .68271 .34895 .67469 .34167 .6671 Metetra
.78 .752 .828 r
.34167 .6671 .34895 .67469 .36102 .66598 .35382 .65752 Metetra
.781 .734 .81 r
.35382 .65752 .36102 .66598 .37313 .65667 .36601 .64724 Metetra
.779 .717 .794 r
.36601 .64724 .37313 .65667 .38528 .64685 .37824 .63638 Metetra
.775 .7 .78 r
.37824 .63638 .38528 .64685 .39745 .63661 .39048 .62504 Metetra
.77 .683 .768 r
.39048 .62504 .39745 .63661 .40964 .62608 .40274 .61336 Metetra
.763 .667 .757 r
.40274 .61336 .40964 .62608 .42184 .61537 .415 .60148 Metetra
.755 .652 .747 r
.415 .60148 .42184 .61537 .43404 .6046 .42726 .58954 Metetra
.746 .637 .739 r
.42726 .58954 .43404 .6046 .44624 .59389 .43951 .57768 Metetra
.736 .623 .732 r
.43951 .57768 .44624 .59389 .45845 .58336 .45175 .56604 Metetra
.726 .609 .726 r
.45175 .56604 .45845 .58336 .47065 .57313 .46399 .55474 Metetra
.715 .596 .722 r
.46399 .55474 .47065 .57313 .48285 .56331 .47621 .54391 Metetra
.704 .584 .717 r
.47621 .54391 .48285 .56331 .49507 .55398 .48843 .53367 Metetra
.693 .572 .714 r
.48843 .53367 .49507 .55398 .50729 .54525 .50066 .52411 Metetra
.681 .56 .712 r
.50066 .52411 .50729 .54525 .51953 .53719 .51289 .51534 Metetra
.669 .55 .71 r
.51289 .51534 .51953 .53719 .53179 .52986 .52514 .50741 Metetra
.657 .539 .709 r
.52514 .50741 .53179 .52986 .54408 .52333 .53742 .50041 Metetra
.645 .53 .708 r
.53742 .50041 .54408 .52333 .55642 .51763 .54974 .49437 Metetra
.632 .52 .709 r
.54974 .49437 .55642 .51763 .56882 .51281 .56211 .48934 Metetra
.619 .512 .71 r
.56211 .48934 .56882 .51281 .58127 .50886 .57454 .48533 Metetra
.606 .503 .712 r
.57454 .48533 .58127 .50886 .5938 .50581 .58704 .48235 Metetra
.592 .496 .714 r
.58704 .48235 .5938 .50581 .60641 .50364 .59963 .48039 Metetra
.578 .489 .717 r
.59963 .48039 .60641 .50364 .61912 .50233 .61232 .47943 Metetra
.564 .483 .722 r
.61232 .47943 .61912 .50233 .63194 .50184 .62512 .47941 Metetra
.55 .477 .727 r
.62512 .47941 .63194 .50184 .64486 .50213 .63804 .48029 Metetra
.535 .473 .733 r
.63804 .48029 .64486 .50213 .65791 .50313 .65109 .48201 Metetra
.52 .469 .74 r
.65109 .48201 .65791 .50313 .67108 .50478 .66428 .48447 Metetra
.505 .467 .748 r
.66428 .48447 .67108 .50478 .68439 .50699 .6776 .48758 Metetra
.49 .466 .758 r
.6776 .48758 .68439 .50699 .69782 .50966 .69108 .49123 Metetra
.476 .467 .769 r
.69108 .49123 .69782 .50966 .7114 .51269 .70469 .4953 Metetra
.462 .471 .781 r
.70469 .4953 .7114 .51269 .72511 .51596 .71846 .49967 Metetra
.449 .476 .795 r
.71846 .49967 .72511 .51596 .73895 .51937 .73236 .50419 Metetra
.438 .485 .811 r
.73236 .50419 .73895 .51937 .75291 .52278 .7464 .50872 Metetra
.429 .497 .828 r
.7464 .50872 .75291 .52278 .76699 .52607 .76057 .51311 Metetra
.423 .513 .847 r
.76057 .51311 .76699 .52607 .78118 .52912 .77485 .51723 Metetra
.42 .534 .866 r
.77485 .51723 .78118 .52912 .79547 .5318 .78924 .52093 Metetra
.423 .558 .886 r
.78924 .52093 .79547 .5318 .80984 .53399 .80372 .52408 Metetra
.432 .587 .906 r
.80372 .52408 .80984 .53399 .82427 .53561 .81826 .52657 Metetra
.446 .619 .924 r
.81826 .52657 .82427 .53561 .83877 .53655 .83286 .52828 Metetra
.466 .653 .941 r
.83286 .52828 .83877 .53655 .8533 .53675 .84751 .52914 Metetra
.491 .688 .955 r
.84751 .52914 .8533 .53675 .86787 .53617 .86217 .52911 Metetra
.558 .74 .961 r
.86217 .52911 .86787 .53617 .88245 .5348 .87675 .52725 Metetra
.645 .765 .936 r
.87675 .52725 .88245 .5348 .89683 .53076 .89118 .52308 Metetra
.646 .762 .934 r
.89118 .52308 .89683 .53076 .91127 .52661 .90567 .5189 Metetra
.646 .762 .934 r
.26295 .69617 .27058 .70237 .28217 .69902 .27457 .6928 Metetra
.646 .762 .934 r
.27457 .6928 .28217 .69902 .29381 .69566 .28624 .68941 Metetra
.656 .765 .93 r
.28624 .68941 .29381 .69566 .30558 .69093 .29798 .68573 Metetra
.767 .812 .889 r
.29798 .68573 .30558 .69093 .31754 .68385 .31001 .6781 Metetra
.781 .797 .866 r
.31001 .6781 .31754 .68385 .32957 .67589 .32212 .6695 Metetra
.79 .781 .844 r
.32212 .6695 .32957 .67589 .34167 .6671 .3343 .65995 Metetra
.795 .764 .825 r
.3343 .65995 .34167 .6671 .35382 .65752 .34654 .64953 Metetra
.796 .747 .807 r
.34654 .64953 .35382 .65752 .36601 .64724 .35882 .63832 Metetra
.795 .73 .791 r
.35882 .63832 .36601 .64724 .37824 .63638 .37113 .62645 Metetra
.791 .713 .778 r
.37113 .62645 .37824 .63638 .39048 .62504 .38345 .61406 Metetra
.786 .696 .766 r
.38345 .61406 .39048 .62504 .40274 .61336 .39579 .60128 Metetra
.779 .681 .756 r
.39579 .60128 .40274 .61336 .415 .60148 .40812 .58828 Metetra
.77 .665 .747 r
.40812 .58828 .415 .60148 .42726 .58954 .42044 .57522 Metetra
.761 .651 .739 r
.42044 .57522 .42726 .58954 .43951 .57768 .43274 .56225 Metetra
.751 .637 .733 r
.43274 .56225 .43951 .57768 .45175 .56604 .44503 .54953 Metetra
.741 .623 .728 r
.44503 .54953 .45175 .56604 .46399 .55474 .4573 .5372 Metetra
.73 .61 .724 r
.4573 .5372 .46399 .55474 .47621 .54391 .46955 .52542 Metetra
.718 .597 .72 r
.46955 .52542 .47621 .54391 .48843 .53367 .48179 .5143 Metetra
.705 .585 .717 r
.48179 .5143 .48843 .53367 .50066 .52411 .49402 .50395 Metetra
.693 .573 .716 r
.49402 .50395 .50066 .52411 .51289 .51534 .50626 .49449 Metetra
.679 .561 .714 r
.50626 .49449 .51289 .51534 .52514 .50741 .5185 .486 Metetra
.666 .55 .714 r
.5185 .486 .52514 .50741 .53742 .50041 .53077 .47854 Metetra
.651 .539 .714 r
.53077 .47854 .53742 .50041 .54974 .49437 .54307 .47218 Metetra
.637 .529 .715 r
.54307 .47218 .54974 .49437 .56211 .48934 .55542 .46696 Metetra
.621 .519 .716 r
.55542 .46696 .56211 .48934 .57454 .48533 .56783 .46288 Metetra
.606 .509 .719 r
.56783 .46288 .57454 .48533 .58704 .48235 .58031 .45997 Metetra
.589 .5 .722 r
.58031 .45997 .58704 .48235 .59963 .48039 .59289 .45821 Metetra
.573 .492 .725 r
.59289 .45821 .59963 .48039 .61232 .47943 .60556 .45757 Metetra
.555 .484 .73 r
.60556 .45757 .61232 .47943 .62512 .47941 .61835 .458 Metetra
.537 .476 .735 r
.61835 .458 .62512 .47941 .63804 .48029 .63126 .45946 Metetra
.519 .47 .742 r
.63126 .45946 .63804 .48029 .65109 .48201 .64431 .46185 Metetra
.5 .464 .749 r
.64431 .46185 .65109 .48201 .66428 .48447 .65751 .46508 Metetra
.481 .46 .758 r
.65751 .46508 .66428 .48447 .6776 .48758 .67085 .46906 Metetra
.461 .457 .767 r
.67085 .46906 .6776 .48758 .69108 .49123 .68436 .47365 Metetra
.442 .456 .779 r
.68436 .47365 .69108 .49123 .70469 .4953 .69802 .47872 Metetra
.424 .458 .791 r
.69802 .47872 .70469 .4953 .71846 .49967 .71183 .48412 Metetra
.407 .462 .805 r
.71183 .48412 .71846 .49967 .73236 .50419 .7258 .48971 Metetra
.391 .469 .82 r
.7258 .48971 .73236 .50419 .7464 .50872 .73991 .49532 Metetra
.379 .48 .837 r
.73991 .49532 .7464 .50872 .76057 .51311 .75416 .50077 Metetra
.371 .496 .855 r
.75416 .50077 .76057 .51311 .77485 .51723 .76854 .50592 Metetra
.367 .516 .874 r
.76854 .50592 .77485 .51723 .78924 .52093 .78302 .51061 Metetra
.37 .542 .894 r
.78302 .51061 .78924 .52093 .80372 .52408 .7976 .51467 Metetra
.38 .573 .914 r
.7976 .51467 .80372 .52408 .81826 .52657 .81225 .51799 Metetra
.398 .607 .933 r
.81225 .51799 .81826 .52657 .83286 .52828 .82695 .52044 Metetra
.422 .645 .95 r
.82695 .52044 .83286 .52828 .84751 .52914 .8417 .52194 Metetra
.453 .683 .964 r
.8417 .52194 .84751 .52914 .86217 .52911 .85647 .52245 Metetra
.592 .771 .965 r
.85647 .52245 .86217 .52911 .87675 .52725 .871 .51954 Metetra
.646 .762 .934 r
.871 .51954 .87675 .52725 .89118 .52308 .88548 .51534 Metetra
.646 .762 .934 r
.88548 .51534 .89118 .52308 .90567 .5189 .90002 .51111 Metetra
.646 .762 .934 r
.25526 .68993 .26295 .69617 .27457 .6928 .2669 .68653 Metetra
.646 .762 .934 r
.2669 .68653 .27457 .6928 .28624 .68941 .2786 .68311 Metetra
.646 .762 .934 r
.2786 .68311 .28624 .68941 .29798 .68573 .29036 .67968 Metetra
.745 .788 .887 r
.29036 .67968 .29798 .68573 .31001 .6781 .30238 .6728 Metetra
.794 .81 .865 r
.30238 .6728 .31001 .6781 .32212 .6695 .31457 .66357 Metetra
.804 .794 .843 r
.31457 .66357 .32212 .6695 .3343 .65995 .32684 .65331 Metetra
.809 .777 .823 r
.32684 .65331 .3343 .65995 .34654 .64953 .33917 .64207 Metetra
.811 .76 .805 r
.33917 .64207 .34654 .64953 .35882 .63832 .35154 .62998 Metetra
.81 .743 .789 r
.35154 .62998 .35882 .63832 .37113 .62645 .36394 .61715 Metetra
.806 .726 .776 r
.36394 .61715 .37113 .62645 .38345 .61406 .37635 .60374 Metetra
.801 .71 .765 r
.37635 .60374 .38345 .61406 .39579 .60128 .38877 .58991 Metetra
.794 .695 .755 r
.38877 .58991 .39579 .60128 .40812 .58828 .40117 .57584 Metetra
.786 .68 .747 r
.40117 .57584 .40812 .58828 .42044 .57522 .41356 .5617 Metetra
.777 .665 .74 r
.41356 .5617 .42044 .57522 .43274 .56225 .42593 .54767 Metetra
.767 .651 .734 r
.42593 .54767 .43274 .56225 .44503 .54953 .43827 .53393 Metetra
.756 .638 .73 r
.43827 .53393 .44503 .54953 .4573 .5372 .45058 .52063 Metetra
.744 .624 .726 r
.45058 .52063 .4573 .5372 .46955 .52542 .46286 .50792 Metetra
.732 .611 .723 r
.46286 .50792 .46955 .52542 .48179 .5143 .47512 .49596 Metetra
.719 .599 .721 r
.47512 .49596 .48179 .5143 .49402 .50395 .48737 .48487 Metetra
.705 .586 .72 r
.48737 .48487 .49402 .50395 .50626 .49449 .49961 .47476 Metetra
.69 .574 .72 r
.49961 .47476 .50626 .49449 .5185 .486 .51186 .46572 Metetra
.675 .562 .72 r
.51186 .46572 .5185 .486 .53077 .47854 .52412 .45783 Metetra
.659 .55 .721 r
.52412 .45783 .53077 .47854 .54307 .47218 .53641 .45116 Metetra
.642 .539 .722 r
.53641 .45116 .54307 .47218 .55542 .46696 .54875 .44574 Metetra
.624 .528 .724 r
.54875 .44574 .55542 .46696 .56783 .46288 .56114 .44161 Metetra
.606 .517 .727 r
.56114 .44161 .56783 .46288 .58031 .45997 .57361 .43876 Metetra
.587 .506 .731 r
.57361 .43876 .58031 .45997 .59289 .45821 .58616 .43719 Metetra
.566 .496 .735 r
.58616 .43719 .59289 .45821 .60556 .45757 .59882 .43686 Metetra
.545 .486 .74 r
.59882 .43686 .60556 .45757 .61835 .458 .6116 .43772 Metetra
.523 .476 .746 r
.6116 .43772 .61835 .458 .63126 .45946 .62451 .43971 Metetra
.5 .468 .752 r
.62451 .43971 .63126 .45946 .64431 .46185 .63757 .44275 Metetra
.477 .46 .76 r
.63757 .44275 .64431 .46185 .65751 .46508 .65077 .44672 Metetra
.452 .453 .769 r
.65077 .44672 .65751 .46508 .67085 .46906 .66414 .45152 Metetra
.428 .447 .778 r
.66414 .45152 .67085 .46906 .68436 .47365 .67767 .457 Metetra
.403 .444 .789 r
.67767 .457 .68436 .47365 .69802 .47872 .69136 .46302 Metetra
.379 .443 .801 r
.69136 .46302 .69802 .47872 .71183 .48412 .70523 .46942 Metetra
.357 .444 .814 r
.70523 .46942 .71183 .48412 .7258 .48971 .71926 .47603 Metetra
.337 .45 .828 r
.71926 .47603 .7258 .48971 .73991 .49532 .73344 .48265 Metetra
.32 .46 .844 r
.73344 .48265 .73991 .49532 .75416 .50077 .74777 .48913 Metetra
.309 .475 .861 r
.74777 .48913 .75416 .50077 .76854 .50592 .76223 .49526 Metetra
.305 .495 .88 r
.76223 .49526 .76854 .50592 .78302 .51061 .7768 .50088 Metetra
.308 .522 .899 r
.7768 .50088 .78302 .51061 .7976 .51467 .79148 .50582 Metetra
.32 .555 .919 r
.79148 .50582 .7976 .51467 .81225 .51799 .80623 .50993 Metetra
.342 .593 .938 r
.80623 .50993 .81225 .51799 .82695 .52044 .82104 .51309 Metetra
.372 .634 .956 r
.82104 .51309 .82695 .52044 .8417 .52194 .83589 .5152 Metetra
.421 .684 .972 r
.83589 .5152 .8417 .52194 .85647 .52245 .85074 .51599 Metetra
.638 .8 .96 r
.85074 .51599 .85647 .52245 .871 .51954 .86519 .51176 Metetra
.646 .762 .934 r
.86519 .51176 .871 .51954 .88548 .51534 .87972 .50752 Metetra
.646 .762 .934 r
.87972 .50752 .88548 .51534 .90002 .51111 .89432 .50326 Metetra
.646 .762 .934 r
.2475 .68364 .25526 .68993 .2669 .68653 .25918 .68021 Metetra
.646 .762 .934 r
.25918 .68021 .2669 .68653 .2786 .68311 .27091 .67676 Metetra
.646 .762 .934 r
.27091 .67676 .2786 .68311 .29036 .67968 .28269 .6733 Metetra
.705 .775 .906 r
.28269 .6733 .29036 .67968 .30238 .6728 .29465 .66799 Metetra
.807 .824 .864 r
.29465 .66799 .30238 .6728 .31457 .66357 .30693 .65816 Metetra
.817 .807 .841 r
.30693 .65816 .31457 .66357 .32684 .65331 .31929 .64721 Metetra
.823 .79 .821 r
.31929 .64721 .32684 .65331 .33917 .64207 .33171 .63521 Metetra
.825 .773 .803 r
.33171 .63521 .33917 .64207 .35154 .62998 .34417 .62227 Metetra
.824 .756 .788 r
.34417 .62227 .35154 .62998 .36394 .61715 .35666 .60853 Metetra
.821 .74 .775 r
.35666 .60853 .36394 .61715 .37635 .60374 .36917 .59415 Metetra
.816 .724 .764 r
.36917 .59415 .37635 .60374 .38877 .58991 .38167 .57933 Metetra
.81 .709 .755 r
.38167 .57933 .38877 .58991 .40117 .57584 .39416 .56423 Metetra
.802 .695 .747 r
.39416 .56423 .40117 .57584 .41356 .5617 .40662 .54907 Metetra
.793 .681 .741 r
.40662 .54907 .41356 .5617 .42593 .54767 .41905 .53404 Metetra
.782 .667 .736 r
.41905 .53404 .42593 .54767 .43827 .53393 .43145 .51932 Metetra
.771 .653 .732 r
.43145 .51932 .43827 .53393 .45058 .52063 .44381 .50508 Metetra
.759 .64 .729 r
.44381 .50508 .45058 .52063 .46286 .50792 .45613 .49151 Metetra
.746 .627 .727 r
.45613 .49151 .46286 .50792 .47512 .49596 .46843 .47875 Metetra
.732 .614 .726 r
.46843 .47875 .47512 .49596 .48737 .48487 .4807 .46695 Metetra
.717 .601 .726 r
.4807 .46695 .48737 .48487 .49961 .47476 .49295 .45621 Metetra
.702 .589 .726 r
.49295 .45621 .49961 .47476 .51186 .46572 .50521 .44666 Metetra
.685 .576 .727 r
.50521 .44666 .51186 .46572 .52412 .45783 .51747 .43836 Metetra
.667 .563 .729 r
.51747 .43836 .52412 .45783 .53641 .45116 .52975 .4314 Metetra
.648 .551 .731 r
.52975 .4314 .53641 .45116 .54875 .44574 .54208 .4258 Metetra
.628 .538 .734 r
.54208 .4258 .54875 .44574 .56114 .44161 .55446 .4216 Metetra
.606 .526 .738 r
.55446 .4216 .56114 .44161 .57361 .43876 .56692 .41881 Metetra
.584 .513 .742 r
.56692 .41881 .57361 .43876 .58616 .43719 .57946 .41742 Metetra
.56 .501 .747 r
.57946 .41742 .58616 .43719 .59882 .43686 .59211 .41738 Metetra
.534 .489 .752 r
.59211 .41738 .59882 .43686 .6116 .43772 .60488 .41865 Metetra
.507 .477 .758 r
.60488 .41865 .6116 .43772 .62451 .43971 .61779 .42115 Metetra
.479 .466 .765 r
.61779 .42115 .62451 .43971 .63757 .44275 .63085 .42479 Metetra
.449 .455 .773 r
.63085 .42479 .63757 .44275 .65077 .44672 .64406 .42947 Metetra
.418 .445 .781 r
.64406 .42947 .65077 .44672 .66414 .45152 .65745 .43504 Metetra
.387 .436 .79 r
.65745 .43504 .66414 .45152 .67767 .457 .671 .44137 Metetra
.356 .429 .799 r
.671 .44137 .67767 .457 .69136 .46302 .68474 .4483 Metetra
.325 .425 .81 r
.68474 .4483 .69136 .46302 .70523 .46942 .69865 .45564 Metetra
.297 .424 .821 r
.69865 .45564 .70523 .46942 .71926 .47603 .71273 .4632 Metetra
.271 .427 .834 r
.71273 .4632 .71926 .47603 .73344 .48265 .72698 .4708 Metetra
.251 .434 .848 r
.72698 .4708 .73344 .48265 .74777 .48913 .74138 .47823 Metetra
.237 .448 .863 r
.74138 .47823 .74777 .48913 .76223 .49526 .75593 .4853 Metetra
.231 .469 .881 r
.75593 .4853 .76223 .49526 .7768 .50088 .77059 .49181 Metetra
.235 .497 .899 r
.77059 .49181 .7768 .50088 .79148 .50582 .78536 .49757 Metetra
.251 .532 .919 r
.78536 .49757 .79148 .50582 .80623 .50993 .80021 .50244 Metetra
.277 .574 .939 r
.80021 .50244 .80623 .50993 .82104 .51309 .81513 .50627 Metetra
.313 .62 .957 r
.81513 .50627 .82104 .51309 .83589 .5152 .83008 .50897 Metetra
.484 .738 .983 r
.83008 .50897 .83589 .5152 .85074 .51599 .84483 .50817 Metetra
.646 .762 .934 r
.84483 .50817 .85074 .51599 .86519 .51176 .85933 .50391 Metetra
.646 .762 .934 r
.85933 .50391 .86519 .51176 .87972 .50752 .87391 .49963 Metetra
.646 .762 .934 r
.87391 .49963 .87972 .50752 .89432 .50326 .88857 .49533 Metetra
.646 .762 .934 r
.23968 .67729 .2475 .68364 .25918 .68021 .25139 .67383 Metetra
.646 .762 .934 r
.25139 .67383 .25918 .68021 .27091 .67676 .26315 .67036 Metetra
.646 .762 .934 r
.26315 .67036 .27091 .67676 .28269 .6733 .27496 .66687 Metetra
.646 .762 .934 r
.27496 .66687 .28269 .6733 .29465 .66799 .28683 .66336 Metetra
.812 .83 .864 r
.28683 .66336 .29465 .66799 .30693 .65816 .29918 .65331 Metetra
.83 .821 .84 r
.29918 .65331 .30693 .65816 .31929 .64721 .31163 .64171 Metetra
.836 .804 .819 r
.31163 .64171 .31929 .64721 .33171 .63521 .32415 .62898 Metetra
.839 .787 .802 r
.32415 .62898 .33171 .63521 .34417 .62227 .33671 .61524 Metetra
.838 .77 .786 r
.33671 .61524 .34417 .62227 .35666 .60853 .3493 .60063 Metetra
.836 .754 .774 r
.3493 .60063 .35666 .60853 .36917 .59415 .3619 .58535 Metetra
.831 .739 .763 r
.3619 .58535 .36917 .59415 .38167 .57933 .37449 .56958 Metetra
.825 .725 .754 r
.37449 .56958 .38167 .57933 .39416 .56423 .38707 .55352 Metetra
.817 .71 .747 r
.38707 .55352 .39416 .56423 .40662 .54907 .39961 .53739 Metetra
.808 .697 .742 r
.39961 .53739 .40662 .54907 .41905 .53404 .41211 .52141 Metetra
.798 .683 .738 r
.41211 .52141 .41905 .53404 .43145 .51932 .42458 .50576 Metetra
.787 .67 .735 r
.42458 .50576 .43145 .51932 .44381 .50508 .43699 .49065 Metetra
.774 .657 .733 r
.43699 .49065 .44381 .50508 .45613 .49151 .44936 .47625 Metetra
.761 .644 .732 r
.44936 .47625 .45613 .49151 .46843 .47875 .4617 .46274 Metetra
.747 .631 .732 r
.4617 .46274 .46843 .47875 .4807 .46695 .47399 .45026 Metetra
.731 .618 .732 r
.47399 .45026 .4807 .46695 .49295 .45621 .48627 .43894 Metetra
.714 .605 .733 r
.48627 .43894 .49295 .45621 .50521 .44666 .49854 .42889 Metetra
.696 .592 .735 r
.49854 .42889 .50521 .44666 .51747 .43836 .51081 .42021 Metetra
.676 .578 .738 r
.51081 .42021 .51747 .43836 .52975 .4314 .52309 .41296 Metetra
.655 .565 .742 r
.52309 .41296 .52975 .4314 .54208 .4258 .53542 .4072 Metetra
.632 .551 .745 r
.53542 .4072 .54208 .4258 .55446 .4216 .54779 .40294 Metetra
.607 .537 .75 r
.54779 .40294 .55446 .4216 .56692 .41881 .56024 .40021 Metetra
.58 .523 .755 r
.56024 .40021 .56692 .41881 .57946 .41742 .57277 .39898 Metetra
.552 .508 .761 r
.57277 .39898 .57946 .41742 .59211 .41738 .58542 .39921 Metetra
.521 .493 .767 r
.58542 .39921 .59211 .41738 .60488 .41865 .59818 .40086 Metetra
.488 .479 .773 r
.59818 .40086 .60488 .41865 .61779 .42115 .61109 .40384 Metetra
.453 .464 .78 r
.61109 .40384 .61779 .42115 .63085 .42479 .62415 .40806 Metetra
.416 .449 .787 r
.62415 .40806 .63085 .42479 .64406 .42947 .63738 .41339 Metetra
.378 .435 .794 r
.63738 .41339 .64406 .42947 .65745 .43504 .65078 .4197 Metetra
.338 .422 .801 r
.65078 .4197 .65745 .43504 .671 .44137 .66437 .42683 Metetra
.299 .411 .809 r
.66437 .42683 .671 .44137 .68474 .4483 .67813 .4346 Metetra
.26 .403 .817 r
.67813 .4346 .68474 .4483 .69865 .45564 .69209 .44283 Metetra
.225 .398 .825 r
.69209 .44283 .69865 .45564 .71273 .4632 .70623 .4513 Metetra
.193 .397 .835 r
.70623 .4513 .71273 .4632 .72698 .4708 .72054 .45982 Metetra
.168 .403 .845 r
.72054 .45982 .72698 .4708 .74138 .47823 .73501 .46816 Metetra
.152 .415 .858 r
.73501 .46816 .74138 .47823 .75593 .4853 .74964 .4761 Metetra
.145 .436 .873 r
.74964 .4761 .75593 .4853 .77059 .49181 .76439 .48344 Metetra
.151 .465 .89 r
.76439 .48344 .77059 .49181 .78536 .49757 .77925 .48999 Metetra
.17 .503 .91 r
.77925 .48999 .78536 .49757 .80021 .50244 .7942 .49556 Metetra
.202 .549 .931 r
.7942 .49556 .80021 .50244 .81513 .50627 .80921 .50003 Metetra
.246 .6 .951 r
.80921 .50003 .81513 .50627 .83008 .50897 .82426 .50328 Metetra
.574 .802 .986 r
.82426 .50328 .83008 .50897 .84483 .50817 .83886 .50029 Metetra
.646 .762 .934 r
.83886 .50029 .84483 .50817 .85933 .50391 .85342 .49599 Metetra
.646 .762 .934 r
.85342 .49599 .85933 .50391 .87391 .49963 .86805 .49167 Metetra
.646 .762 .934 r
.86805 .49167 .87391 .49963 .88857 .49533 .88276 .48732 Metetra
.646 .762 .934 r
.23179 .6709 .23968 .67729 .25139 .67383 .24353 .66741 Metetra
.646 .762 .934 r
.24353 .66741 .25139 .67383 .26315 .67036 .25532 .6639 Metetra
.646 .762 .934 r
.25532 .6639 .26315 .67036 .27496 .66687 .26717 .66038 Metetra
.646 .762 .934 r
.26717 .66038 .27496 .66687 .28683 .66336 .27907 .65685 Metetra
.76 .782 .871 r
.27907 .65685 .28683 .66336 .29918 .65331 .29131 .64904 Metetra
.842 .835 .839 r
.29131 .64904 .29918 .65331 .31163 .64171 .30386 .63683 Metetra
.849 .817 .818 r
.30386 .63683 .31163 .64171 .32415 .62898 .31648 .62341 Metetra
.852 .801 .8 r
.31648 .62341 .32415 .62898 .33671 .61524 .32914 .60892 Metetra
.852 .784 .785 r
.32914 .60892 .33671 .61524 .3493 .60063 .34183 .59351 Metetra
.849 .769 .773 r
.34183 .59351 .3493 .60063 .3619 .58535 .35453 .57737 Metetra
.845 .754 .763 r
.35453 .57737 .3619 .58535 .37449 .56958 .36722 .56071 Metetra
.839 .74 .754 r
.36722 .56071 .37449 .56958 .38707 .55352 .37989 .54375 Metetra
.832 .726 .748 r
.37989 .54375 .38707 .55352 .39961 .53739 .39252 .52671 Metetra
.823 .713 .743 r
.39252 .52671 .39961 .53739 .41211 .52141 .4051 .50983 Metetra
.814 .7 .74 r
.4051 .50983 .41211 .52141 .42458 .50576 .41763 .49331 Metetra
.803 .688 .738 r
.41763 .49331 .42458 .50576 .43699 .49065 .43011 .47737 Metetra
.79 .675 .737 r
.43011 .47737 .43699 .49065 .44936 .47625 .44254 .4622 Metetra
.777 .662 .737 r
.44254 .4622 .44936 .47625 .4617 .46274 .45491 .44798 Metetra
.762 .649 .738 r
.45491 .44798 .4617 .46274 .47399 .45026 .46725 .43486 Metetra
.745 .636 .739 r
.46725 .43486 .47399 .45026 .48627 .43894 .47955 .42299 Metetra
.727 .623 .742 r
.47955 .42299 .48627 .43894 .49854 .42889 .49184 .41249 Metetra
.708 .61 .745 r
.49184 .41249 .49854 .42889 .51081 .42021 .50412 .40344 Metetra
.686 .596 .749 r
.50412 .40344 .51081 .42021 .52309 .41296 .51642 .39593 Metetra
.662 .581 .754 r
.51642 .39593 .52309 .41296 .53542 .4072 .52874 .39 Metetra
.636 .566 .759 r
.52874 .39 .53542 .4072 .54779 .40294 .54112 .38569 Metetra
.608 .551 .765 r
.54112 .38569 .54779 .40294 .56024 .40021 .55356 .383 Metetra
.577 .534 .771 r
.55356 .383 .56024 .40021 .57277 .39898 .5661 .38192 Metetra
.543 .517 .777 r
.5661 .38192 .57277 .39898 .58542 .39921 .57874 .38242 Metetra
.505 .499 .784 r
.57874 .38242 .58542 .39921 .59818 .40086 .5915 .38442 Metetra
.465 .481 .79 r
.5915 .38442 .59818 .40086 .61109 .40384 .60441 .38785 Metetra
.422 .462 .796 r
.60441 .38785 .61109 .40384 .62415 .40806 .61748 .39261 Metetra
.376 .442 .802 r
.61748 .39261 .62415 .40806 .63738 .41339 .63072 .39856 Metetra
.328 .423 .807 r
.63072 .39856 .63738 .41339 .65078 .4197 .64414 .40555 Metetra
.278 .405 .812 r
.64414 .40555 .65078 .4197 .66437 .42683 .65775 .41343 Metetra
.229 .388 .815 r
.65775 .41343 .66437 .42683 .67813 .4346 .67155 .422 Metetra
.182 .374 .819 r
.67155 .422 .67813 .4346 .69209 .44283 .68555 .43105 Metetra
.138 .365 .822 r
.68555 .43105 .69209 .44283 .70623 .4513 .69974 .44038 Metetra
.101 .36 .826 r
.69974 .44038 .70623 .4513 .72054 .45982 .71411 .44975 Metetra
.072 .363 .832 r
.71411 .44975 .72054 .45982 .73501 .46816 .72866 .45894 Metetra
.053 .374 .841 r
.72866 .45894 .73501 .46816 .74964 .4761 .74335 .4677 Metetra
.048 .395 .853 r
.74335 .4677 .74964 .4761 .76439 .48344 .75819 .47582 Metetra
.057 .426 .869 r
.75819 .47582 .76439 .48344 .77925 .48999 .77314 .48309 Metetra
.081 .467 .889 r
.77314 .48309 .77925 .48999 .7942 .49556 .78818 .48933 Metetra
.119 .517 .912 r
.78818 .48933 .7942 .49556 .80921 .50003 .80329 .49439 Metetra
.272 .641 .965 r
.80329 .49439 .80921 .50003 .82426 .50328 .8183 .49665 Metetra
.639 .799 .96 r
.8183 .49665 .82426 .50328 .83886 .50029 .83284 .49233 Metetra
.646 .762 .934 r
.83284 .49233 .83886 .50029 .85342 .49599 .84745 .48799 Metetra
.646 .762 .934 r
.84745 .48799 .85342 .49599 .86805 .49167 .86214 .48363 Metetra
.646 .762 .934 r
.86214 .48363 .86805 .49167 .88276 .48732 .8769 .47925 Metetra
.646 .762 .934 r
.22384 .66444 .23179 .6709 .24353 .66741 .23561 .66093 Metetra
.646 .762 .934 r
.23561 .66093 .24353 .66741 .25532 .6639 .24743 .65739 Metetra
.646 .762 .934 r
.24743 .65739 .25532 .6639 .26717 .66038 .25931 .65385 Metetra
.646 .762 .934 r
.25931 .65385 .26717 .66038 .27907 .65685 .27125 .65028 Metetra
.69 .772 .914 r
.27125 .65028 .27907 .65685 .29131 .64904 .28333 .64536 Metetra
.853 .849 .838 r
.28333 .64536 .29131 .64904 .30386 .63683 .29597 .63259 Metetra
.86 .832 .817 r
.29597 .63259 .30386 .63683 .31648 .62341 .30869 .61854 Metetra
.864 .815 .799 r
.30869 .61854 .31648 .62341 .32914 .60892 .32146 .60335 Metetra
.864 .799 .784 r
.32146 .60335 .32914 .60892 .34183 .59351 .33425 .58719 Metetra
.863 .784 .772 r
.33425 .58719 .34183 .59351 .35453 .57737 .34706 .57026 Metetra
.859 .77 .762 r
.34706 .57026 .35453 .57737 .36722 .56071 .35985 .55277 Metetra
.854 .756 .755 r
.35985 .55277 .36722 .56071 .37989 .54375 .37261 .53496 Metetra
.847 .743 .749 r
.37261 .53496 .37989 .54375 .39252 .52671 .38534 .51708 Metetra
.839 .731 .745 r
.38534 .51708 .39252 .52671 .4051 .50983 .39801 .49936 Metetra
.829 .718 .742 r
.39801 .49936 .4051 .50983 .41763 .49331 .41062 .48203 Metetra
.819 .706 .741 r
.41062 .48203 .41763 .49331 .43011 .47737 .42316 .46531 Metetra
.806 .694 .741 r
.42316 .46531 .43011 .47737 .44254 .4622 .43565 .44942 Metetra
.793 .682 .742 r
.43565 .44942 .44254 .4622 .45491 .44798 .44808 .43453 Metetra
.778 .67 .744 r
.44808 .43453 .45491 .44798 .46725 .43486 .46046 .42082 Metetra
.761 .657 .747 r
.46046 .42082 .46725 .43486 .47955 .42299 .4728 .40843 Metetra
.742 .644 .751 r
.4728 .40843 .47955 .42299 .49184 .41249 .48511 .39749 Metetra
.721 .63 .756 r
.48511 .39749 .49184 .41249 .50412 .40344 .49741 .3881 Metetra
.697 .616 .762 r
.49741 .3881 .50412 .40344 .51642 .39593 .50972 .38033 Metetra
.671 .601 .768 r
.50972 .38033 .51642 .39593 .52874 .39 .52205 .37426 Metetra
.642 .585 .775 r
.52205 .37426 .52874 .39 .54112 .38569 .53443 .36989 Metetra
.609 .567 .782 r
.53443 .36989 .54112 .38569 .55356 .383 .54688 .36725 Metetra
.572 .549 .79 r
.54688 .36725 .55356 .383 .5661 .38192 .55942 .36631 Metetra
.531 .528 .797 r
.55942 .36631 .5661 .38192 .57874 .38242 .57206 .36704 Metetra
.486 .507 .804 r
.57206 .36704 .57874 .38242 .5915 .38442 .58482 .36938 Metetra
.437 .484 .81 r
.58482 .36938 .5915 .38442 .60441 .38785 .59774 .37323 Metetra
.383 .459 .815 r
.59774 .37323 .60441 .38785 .61748 .39261 .61081 .37848 Metetra
.325 .433 .818 r
.61081 .37848 .61748 .39261 .63072 .39856 .62407 .38501 Metetra
.265 .407 .819 r
.62407 .38501 .63072 .39856 .64414 .40555 .63751 .39264 Metetra
.204 .382 .818 r
.63751 .39264 .64414 .40555 .65775 .41343 .65114 .40122 Metetra
.144 .358 .816 r
.65114 .40122 .65775 .41343 .67155 .422 .66498 .41053 Metetra
.087 .338 .812 r
.66498 .41053 .67155 .422 .68555 .43105 .67902 .42036 Metetra
.036 .322 .807 r
.67902 .42036 .68555 .43105 .69974 .44038 .69326 .43048 Metetra
0 .314 .804 r
.69326 .43048 .69974 .44038 .71411 .44975 .70769 .44064 Metetra
0 .314 .804 r
.70769 .44064 .71411 .44975 .72866 .45894 .7223 .45061 Metetra
0 .324 .808 r
.7223 .45061 .72866 .45894 .74335 .4677 .73708 .46014 Metetra
0 .345 .817 r
.73708 .46014 .74335 .4677 .75819 .47582 .75199 .46898 Metetra
0 .378 .832 r
.75199 .46898 .75819 .47582 .77314 .48309 .76703 .47693 Metetra
0 .423 .854 r
.76703 .47693 .77314 .48309 .78818 .48933 .78216 .48378 Metetra
.03 .477 .879 r
.78216 .48378 .78818 .48933 .80329 .49439 .79736 .48938 Metetra
.428 .757 .995 r
.79736 .48938 .80329 .49439 .8183 .49665 .81217 .48866 Metetra
.646 .762 .934 r
.81217 .48866 .8183 .49665 .83284 .49233 .82676 .4843 Metetra
.646 .762 .934 r
.82676 .4843 .83284 .49233 .84745 .48799 .84143 .47992 Metetra
.646 .762 .934 r
.84143 .47992 .84745 .48799 .86214 .48363 .85617 .47552 Metetra
.646 .762 .934 r
.85617 .47552 .86214 .48363 .8769 .47925 .87098 .47109 Metetra
.646 .762 .934 r
.21582 .65794 .22384 .66444 .23561 .66093 .22762 .65439 Metetra
.646 .762 .934 r
.22762 .65439 .23561 .66093 .24743 .65739 .23948 .65083 Metetra
.646 .762 .934 r
.23948 .65083 .24743 .65739 .25931 .65385 .25139 .64725 Metetra
.646 .762 .934 r
.25139 .64725 .25931 .65385 .27125 .65028 .26335 .64365 Metetra
.646 .762 .934 r
.26335 .64365 .27125 .65028 .28333 .64536 .27537 .64004 Metetra
.818 .815 .846 r
.27537 .64004 .28333 .64536 .29597 .63259 .28796 .62901 Metetra
.871 .846 .816 r
.28796 .62901 .29597 .63259 .30869 .61854 .30078 .61438 Metetra
.875 .829 .798 r
.30078 .61438 .30869 .61854 .32146 .60335 .31365 .59855 Metetra
.876 .813 .783 r
.31365 .59855 .32146 .60335 .33425 .58719 .32656 .5817 Metetra
.875 .799 .771 r
.32656 .5817 .33425 .58719 .34706 .57026 .33947 .56403 Metetra
.872 .785 .762 r
.33947 .56403 .34706 .57026 .35985 .55277 .35237 .54578 Metetra
.867 .772 .755 r
.35237 .54578 .35985 .55277 .37261 .53496 .36524 .52719 Metetra
.861 .76 .75 r
.36524 .52719 .37261 .53496 .38534 .51708 .37805 .50852 Metetra
.854 .748 .746 r
.37805 .50852 .38534 .51708 .39801 .49936 .39081 .49002 Metetra
.845 .737 .744 r
.39081 .49002 .39801 .49936 .41062 .48203 .40351 .47193 Metetra
.835 .726 .744 r
.40351 .47193 .41062 .48203 .42316 .46531 .41613 .4545 Metetra
.823 .714 .745 r
.41613 .4545 .42316 .46531 .43565 .44942 .42869 .43793 Metetra
.809 .703 .748 r
.42869 .43793 .43565 .44942 .44808 .43453 .44117 .42242 Metetra
.794 .692 .751 r
.44117 .42242 .44808 .43453 .46046 .42082 .4536 .40815 Metetra
.777 .68 .756 r
.4536 .40815 .46046 .42082 .4728 .40843 .46598 .39528 Metetra
.757 .667 .762 r
.46598 .39528 .4728 .40843 .48511 .39749 .47833 .38394 Metetra
.735 .654 .769 r
.47833 .38394 .48511 .39749 .49741 .3881 .49066 .37423 Metetra
.71 .639 .776 r
.49066 .37423 .49741 .3881 .50972 .38033 .50299 .36623 Metetra
.681 .624 .785 r
.50299 .36623 .50972 .38033 .52205 .37426 .51534 .36001 Metetra
.648 .606 .794 r
.51534 .36001 .52205 .37426 .53443 .36989 .52773 .35559 Metetra
.61 .587 .803 r
.52773 .35559 .53443 .36989 .54688 .36725 .54019 .35299 Metetra
.567 .566 .812 r
.54019 .35299 .54688 .36725 .55942 .36631 .55273 .35218 Metetra
.518 .542 .821 r
.55273 .35218 .55942 .36631 .57206 .36704 .56537 .35313 Metetra
.462 .516 .828 r
.56537 .35313 .57206 .36704 .58482 .36938 .57815 .35577 Metetra
.401 .487 .832 r
.57815 .35577 .58482 .36938 .59774 .37323 .59107 .36001 Metetra
.334 .455 .834 r
.59107 .36001 .59774 .37323 .61081 .37848 .60416 .36572 Metetra
.262 .421 .832 r
.60416 .36572 .61081 .37848 .62407 .38501 .61742 .37278 Metetra
.187 .386 .827 r
.61742 .37278 .62407 .38501 .63751 .39264 .63089 .38101 Metetra
.113 .351 .817 r
.63089 .38101 .63751 .39264 .65114 .40122 .64455 .39023 Metetra
.041 .319 .804 r
.64455 .39023 .65114 .40122 .66498 .41053 .65842 .40022 Metetra
0 .291 .79 r
.65842 .40022 .66498 .41053 .67902 .42036 .6725 .41077 Metetra
0 .27 .776 r
.6725 .41077 .67902 .42036 .69326 .43048 .68679 .42162 Metetra
0 .258 .764 r
.68679 .42162 .69326 .43048 .70769 .44064 .70128 .43252 Metetra
0 .256 .757 r
.70128 .43252 .70769 .44064 .7223 .45061 .71595 .44321 Metetra
0 .265 .757 r
.71595 .44321 .7223 .45061 .73708 .46014 .7308 .45344 Metetra
0 .287 .764 r
.7308 .45344 .73708 .46014 .75199 .46898 .74579 .46294 Metetra
0 .323 .78 r
.74579 .46294 .75199 .46898 .76703 .47693 .76091 .4715 Metetra
0 .371 .803 r
.76091 .4715 .76703 .47693 .78216 .48378 .77613 .47891 Metetra
0 .433 .834 r
.77613 .47891 .78216 .48378 .79736 .48938 .79142 .48498 Metetra
.603 .863 .992 r
.79142 .48498 .79736 .48938 .81217 .48866 .80599 .4806 Metetra
.646 .762 .934 r
.80599 .4806 .81217 .48866 .82676 .4843 .82063 .4762 Metetra
.646 .762 .934 r
.82063 .4762 .82676 .4843 .84143 .47992 .83535 .47178 Metetra
.646 .762 .934 r
.83535 .47178 .84143 .47992 .85617 .47552 .85014 .46733 Metetra
.646 .762 .934 r
.85014 .46733 .85617 .47552 .87098 .47109 .86501 .46286 Metetra
.646 .762 .934 r
.20773 .65138 .21582 .65794 .22762 .65439 .21957 .6478 Metetra
.646 .762 .934 r
.21957 .6478 .22762 .65439 .23948 .65083 .23145 .64421 Metetra
.646 .762 .934 r
.23145 .64421 .23948 .65083 .25139 .64725 .2434 .6406 Metetra
.646 .762 .934 r
.2434 .6406 .25139 .64725 .26335 .64365 .25539 .63697 Metetra
.646 .762 .934 r
.25539 .63697 .26335 .64365 .27537 .64004 .26745 .63333 Metetra
.746 .781 .882 r
.26745 .63333 .27537 .64004 .28796 .62901 .27981 .62609 Metetra
.881 .859 .815 r
.27981 .62609 .28796 .62901 .30078 .61438 .29274 .61094 Metetra
.886 .843 .797 r
.29274 .61094 .30078 .61438 .31365 .59855 .30572 .59453 Metetra
.887 .828 .783 r
.30572 .59453 .31365 .59855 .32656 .5817 .31874 .57704 Metetra
.887 .814 .771 r
.31874 .57704 .32656 .5817 .33947 .56403 .33176 .5587 Metetra
.884 .801 .762 r
.33176 .5587 .33947 .56403 .35237 .54578 .34477 .53975 Metetra
.881 .789 .755 r
.34477 .53975 .35237 .54578 .36524 .52719 .35774 .52045 Metetra
.875 .777 .75 r
.35774 .52045 .36524 .52719 .37805 .50852 .37066 .50105 Metetra
.868 .767 .748 r
.37066 .50105 .37805 .50852 .39081 .49002 .38352 .48184 Metetra
.86 .756 .747 r
.38352 .48184 .39081 .49002 .40351 .47193 .3963 .46306 Metetra
.851 .746 .747 r
.3963 .46306 .40351 .47193 .41613 .4545 .40901 .44495 Metetra
.839 .736 .75 r
.40901 .44495 .41613 .4545 .42869 .43793 .42164 .42776 Metetra
.826 .726 .754 r
.42164 .42776 .42869 .43793 .44117 .42242 .43419 .41168 Metetra
.811 .715 .759 r
.43419 .41168 .44117 .42242 .4536 .40815 .44668 .3969 Metetra
.794 .704 .765 r
.44668 .3969 .4536 .40815 .46598 .39528 .45911 .38358 Metetra
.774 .693 .773 r
.45911 .38358 .46598 .39528 .47833 .38394 .47149 .37186 Metetra
.751 .68 .783 r
.47149 .37186 .47833 .38394 .49066 .37423 .48386 .36185 Metetra
.723 .666 .793 r
.48386 .36185 .49066 .37423 .50299 .36623 .49622 .35364 Metetra
.691 .65 .804 r
.49622 .35364 .50299 .36623 .51534 .36001 .50859 .34728 Metetra
.654 .632 .816 r
.50859 .34728 .51534 .36001 .52773 .35559 .521 .34281 Metetra
.61 .611 .828 r
.521 .34281 .52773 .35559 .54019 .35299 .53347 .34025 Metetra
.559 .587 .839 r
.53347 .34025 .54019 .35299 .55273 .35218 .54602 .33956 Metetra
.499 .559 .848 r
.54602 .33956 .55273 .35218 .56537 .35313 .55868 .34071 Metetra
.431 .526 .854 r
.55868 .34071 .56537 .35313 .57815 .35577 .57146 .34363 Metetra
.354 .489 .856 r
.57146 .34363 .57815 .35577 .59107 .36001 .58439 .34822 Metetra
.27 .447 .852 r
.58439 .34822 .59107 .36001 .60416 .36572 .5975 .35436 Metetra
.181 .402 .841 r
.5975 .35436 .60416 .36572 .61742 .37278 .61078 .36191 Metetra
.09 .355 .824 r
.61078 .36191 .61742 .37278 .63089 .38101 .62427 .37068 Metetra
.003 .31 .801 r
.62427 .37068 .63089 .38101 .64455 .39023 .63796 .38049 Metetra
0 .268 .775 r
.63796 .38049 .64455 .39023 .65842 .40022 .65186 .39111 Metetra
0 .234 .748 r
.65186 .39111 .65842 .40022 .6725 .41077 .66599 .40231 Metetra
0 .208 .723 r
.66599 .40231 .6725 .41077 .68679 .42162 .68032 .41383 Metetra
0 .193 .704 r
.68032 .41383 .68679 .42162 .70128 .43252 .69487 .4254 Metetra
0 .191 .692 r
.69487 .4254 .70128 .43252 .71595 .44321 .7096 .43675 Metetra
0 .201 .689 r
.7096 .43675 .71595 .44321 .7308 .45344 .72451 .4476 Metetra
0 .225 .696 r
.72451 .4476 .7308 .45344 .74579 .46294 .73958 .45771 Metetra
0 .264 .713 r
.73958 .45771 .74579 .46294 .76091 .4715 .75478 .46682 Metetra
0 .316 .74 r
.75478 .46682 .76091 .4715 .77613 .47891 .77009 .47473 Metetra
.173 .631 .937 r
.77009 .47473 .77613 .47891 .79142 .48498 .78512 .47688 Metetra
.646 .762 .934 r
.78512 .47688 .79142 .48498 .80599 .4806 .79974 .47246 Metetra
.646 .762 .934 r
.79974 .47246 .80599 .4806 .82063 .4762 .81444 .46802 Metetra
.646 .762 .934 r
.81444 .46802 .82063 .4762 .83535 .47178 .82921 .46355 Metetra
.646 .762 .934 r
.82921 .46355 .83535 .47178 .85014 .46733 .84405 .45906 Metetra
.646 .762 .934 r
.84405 .45906 .85014 .46733 .86501 .46286 .85898 .45455 Metetra
.646 .762 .934 r
.19958 .64476 .20773 .65138 .21957 .6478 .21144 .64116 Metetra
.646 .762 .934 r
.21144 .64116 .21957 .6478 .23145 .64421 .22336 .63753 Metetra
.646 .762 .934 r
.22336 .63753 .23145 .64421 .2434 .6406 .23534 .63389 Metetra
.646 .762 .934 r
.23534 .63389 .2434 .6406 .25539 .63697 .24737 .63024 Metetra
.646 .762 .934 r
.24737 .63024 .25539 .63697 .26745 .63333 .25945 .62656 Metetra
.646 .762 .934 r
.25945 .62656 .26745 .63333 .27981 .62609 .27159 .62287 Metetra
.874 .856 .821 r
.27159 .62287 .27981 .62609 .29274 .61094 .28456 .60821 Metetra
.895 .857 .796 r
.28456 .60821 .29274 .61094 .30572 .59453 .29766 .59128 Metetra
.897 .842 .782 r
.29766 .59128 .30572 .59453 .31874 .57704 .31079 .57323 Metetra
.898 .828 .77 r
.31079 .57323 .31874 .57704 .33176 .5587 .32392 .55429 Metetra
.896 .816 .761 r
.32392 .55429 .33176 .5587 .34477 .53975 .33704 .5347 Metetra
.893 .805 .755 r
.33704 .5347 .34477 .53975 .35774 .52045 .35013 .51475 Metetra
.888 .795 .751 r
.35013 .51475 .35774 .52045 .37066 .50105 .36316 .4947 Metetra
.882 .785 .749 r
.36316 .4947 .37066 .50105 .38352 .48184 .37612 .47483 Metetra
.875 .776 .749 r
.37612 .47483 .38352 .48184 .3963 .46306 .38899 .45541 Metetra
.866 .767 .751 r
.38899 .45541 .3963 .46306 .40901 .44495 .40179 .4367 Metetra
.856 .758 .754 r
.40179 .4367 .40901 .44495 .42164 .42776 .41449 .41893 Metetra
.844 .75 .76 r
.41449 .41893 .42164 .42776 .43419 .41168 .42712 .40232 Metetra
.829 .741 .767 r
.42712 .40232 .43419 .41168 .44668 .3969 .43967 .38707 Metetra
.812 .731 .775 r
.43967 .38707 .44668 .3969 .45911 .38358 .45216 .37334 Metetra
.791 .721 .786 r
.45216 .37334 .45911 .38358 .47149 .37186 .46459 .36127 Metetra
.767 .709 .798 r
.46459 .36127 .47149 .37186 .48386 .36185 .477 .35099 Metetra
.738 .696 .811 r
.477 .35099 .48386 .36185 .49622 .35364 .48939 .34257 Metetra
.703 .681 .826 r
.48939 .34257 .49622 .35364 .50859 .34728 .50179 .33609 Metetra
.661 .663 .841 r
.50179 .33609 .50859 .34728 .521 .34281 .51422 .33158 Metetra
.609 .64 .856 r
.51422 .33158 .521 .34281 .53347 .34025 .52671 .32904 Metetra
.548 .613 .869 r
.52671 .32904 .53347 .34025 .54602 .33956 .53928 .32846 Metetra
.475 .578 .879 r
.53928 .32846 .54602 .33956 .55868 .34071 .55195 .32979 Metetra
.39 .537 .883 r
.55195 .32979 .55868 .34071 .57146 .34363 .56475 .33296 Metetra
.293 .488 .878 r
.56475 .33296 .57146 .34363 .58439 .34822 .5777 .33788 Metetra
.188 .433 .863 r
.5777 .33788 .58439 .34822 .5975 .35436 .59082 .3444 Metetra
.08 .373 .838 r
.59082 .3444 .5975 .35436 .61078 .36191 .60413 .35239 Metetra
0 .313 .804 r
.60413 .35239 .61078 .36191 .62427 .37068 .61764 .36166 Metetra
0 .256 .763 r
.61764 .36166 .62427 .37068 .63796 .38049 .63136 .37201 Metetra
0 .206 .722 r
.63136 .37201 .63796 .38049 .65186 .39111 .6453 .3832 Metetra
0 .167 .682 r
.6453 .3832 .65186 .39111 .66599 .40231 .65946 .39499 Metetra
0 .139 .649 r
.65946 .39499 .66599 .40231 .68032 .41383 .67385 .40711 Metetra
0 .125 .625 r
.67385 .40711 .68032 .41383 .69487 .4254 .68844 .41929 Metetra
0 .124 .611 r
.68844 .41929 .69487 .4254 .7096 .43675 .70324 .43123 Metetra
0 .136 .608 r
.70324 .43123 .7096 .43675 .72451 .4476 .71822 .44265 Metetra
0 .163 .616 r
.71822 .44265 .72451 .4476 .73958 .45771 .73336 .45328 Metetra
0 .204 .637 r
.73336 .45328 .73958 .45771 .75478 .46682 .74864 .46289 Metetra
0 .259 .668 r
.74864 .46289 .75478 .46682 .77009 .47473 .76403 .47124 Metetra
.463 .83 .993 r
.76403 .47124 .77009 .47473 .78512 .47688 .77876 .4687 Metetra
.646 .762 .934 r
.77876 .4687 .78512 .47688 .79974 .47246 .79344 .46424 Metetra
.646 .762 .934 r
.79344 .46424 .79974 .47246 .81444 .46802 .80819 .45976 Metetra
.646 .762 .934 r
.80819 .45976 .81444 .46802 .82921 .46355 .82301 .45525 Metetra
.646 .762 .934 r
.82301 .45525 .82921 .46355 .84405 .45906 .83791 .45072 Metetra
.646 .762 .934 r
.83791 .45072 .84405 .45906 .85898 .45455 .85289 .44617 Metetra
.646 .762 .934 r
.19135 .63809 .19958 .64476 .21144 .64116 .20325 .63445 Metetra
.646 .762 .934 r
.20325 .63445 .21144 .64116 .22336 .63753 .2152 .6308 Metetra
.646 .762 .934 r
.2152 .6308 .22336 .63753 .23534 .63389 .22721 .62713 Metetra
.646 .762 .934 r
.22721 .62713 .23534 .63389 .24737 .63024 .23927 .62344 Metetra
.646 .762 .934 r
.23927 .62344 .24737 .63024 .25945 .62656 .25139 .61973 Metetra
.646 .762 .934 r
.25139 .61973 .25945 .62656 .27159 .62287 .26356 .61601 Metetra
.788 .784 .848 r
.26356 .61601 .27159 .62287 .28456 .60821 .27624 .60618 Metetra
.903 .87 .795 r
.27624 .60618 .28456 .60821 .29766 .59128 .28945 .58879 Metetra
.906 .856 .781 r
.28945 .58879 .29766 .59128 .31079 .57323 .30269 .57025 Metetra
.907 .843 .769 r
.30269 .57025 .31079 .57323 .32392 .55429 .31595 .55077 Metetra
.907 .832 .761 r
.31595 .55077 .32392 .55429 .33704 .5347 .32918 .53062 Metetra
.904 .821 .755 r
.32918 .53062 .33704 .5347 .35013 .51475 .34238 .51008 Metetra
.901 .812 .751 r
.34238 .51008 .35013 .51475 .36316 .4947 .35552 .48944 Metetra
.896 .804 .75 r
.35552 .48944 .36316 .4947 .37612 .47483 .36859 .46899 Metetra
.889 .796 .751 r
.36859 .46899 .37612 .47483 .38899 .45541 .38156 .44899 Metetra
.881 .788 .753 r
.38156 .44899 .38899 .45541 .40179 .4367 .39445 .42973 Metetra
.872 .781 .758 r
.39445 .42973 .40179 .4367 .41449 .41893 .40725 .41144 Metetra
.861 .775 .765 r
.40725 .41144 .41449 .41893 .42712 .40232 .41995 .39435 Metetra
.847 .767 .774 r
.41995 .39435 .42712 .40232 .43967 .38707 .43257 .37867 Metetra
.83 .76 .786 r
.43257 .37867 .43967 .38707 .45216 .37334 .44512 .36456 Metetra
.809 .752 .799 r
.44512 .36456 .45216 .37334 .46459 .36127 .45761 .35218 Metetra
.784 .743 .814 r
.45761 .35218 .46459 .36127 .477 .35099 .47006 .34164 Metetra
.753 .731 .832 r
.47006 .34164 .477 .35099 .48939 .34257 .4825 .33304 Metetra
.715 .717 .851 r
.4825 .33304 .48939 .34257 .50179 .33609 .49493 .32644 Metetra
.667 .699 .87 r
.49493 .32644 .50179 .33609 .51422 .33158 .5074 .32188 Metetra
.606 .674 .889 r
.5074 .32188 .51422 .33158 .52671 .32904 .51991 .31937 Metetra
.532 .642 .904 r
.51991 .31937 .52671 .32904 .53928 .32846 .53251 .31888 Metetra
.441 .6 .912 r
.53251 .31888 .53928 .32846 .55195 .32979 .5452 .32038 Metetra
.333 .546 .91 r
.5452 .32038 .55195 .32979 .56475 .33296 .55802 .32378 Metetra
.212 .482 .893 r
.55802 .32378 .56475 .33296 .5777 .33788 .57099 .32898 Metetra
.084 .408 .86 r
.57099 .32898 .5777 .33788 .59082 .3444 .58413 .33586 Metetra
0 .331 .813 r
.58413 .33586 .59082 .3444 .60413 .35239 .59746 .34425 Metetra
0 .257 .757 r
.59746 .34425 .60413 .35239 .61764 .36166 .61099 .35397 Metetra
0 .191 .699 r
.61099 .35397 .61764 .36166 .63136 .37201 .62475 .36479 Metetra
0 .137 .644 r
.62475 .36479 .63136 .37201 .6453 .3832 .63872 .3765 Metetra
0 .096 .597 r
.63872 .3765 .6453 .3832 .65946 .39499 .65293 .38882 Metetra
0 .07 .56 r
.65293 .38882 .65946 .39499 .67385 .40711 .66736 .40147 Metetra
0 .058 .535 r
.66736 .40147 .67385 .40711 .68844 .41929 .68201 .41418 Metetra
.473 0 0 r
.68201 .41418 .68844 .41929 .70324 .43123 .69686 .42664 Metetra
.468 0 0 r
.69686 .42664 .70324 .43123 .71822 .44265 .71191 .43856 Metetra
.449 0 0 r
.71191 .43856 .71822 .44265 .73336 .45328 .72712 .44966 Metetra
.416 0 0 r
.72712 .44966 .73336 .45328 .74864 .46289 .74247 .45969 Metetra
0 .411 .758 r
.74247 .45969 .74864 .46289 .76403 .47124 .7577 .46493 Metetra
.634 .816 .97 r
.7577 .46493 .76403 .47124 .77876 .4687 .77235 .46045 Metetra
.646 .762 .934 r
.77235 .46045 .77876 .4687 .79344 .46424 .78707 .45594 Metetra
.646 .762 .934 r
.78707 .45594 .79344 .46424 .80819 .45976 .80188 .45142 Metetra
.646 .762 .934 r
.80188 .45142 .80819 .45976 .82301 .45525 .81676 .44687 Metetra
.646 .762 .934 r
.81676 .44687 .82301 .45525 .83791 .45072 .83171 .4423 Metetra
.646 .762 .934 r
.83171 .4423 .83791 .45072 .85289 .44617 .84674 .4377 Metetra
.646 .762 .934 r
.18306 .63136 .19135 .63809 .20325 .63445 .19499 .62769 Metetra
.646 .762 .934 r
.19499 .62769 .20325 .63445 .2152 .6308 .20697 .62401 Metetra
.646 .762 .934 r
.20697 .62401 .2152 .6308 .22721 .62713 .21901 .62031 Metetra
.646 .762 .934 r
.21901 .62031 .22721 .62713 .23927 .62344 .23111 .61659 Metetra
.646 .762 .934 r
.23111 .61659 .23927 .62344 .25139 .61973 .24326 .61285 Metetra
.646 .762 .934 r
.24326 .61285 .25139 .61973 .26356 .61601 .25547 .60909 Metetra
.663 .767 .927 r
.25547 .60909 .26356 .61601 .27624 .60618 .26777 .60483 Metetra
.91 .883 .794 r
.26777 .60483 .27624 .60618 .28945 .58879 .28109 .58705 Metetra
.914 .869 .78 r
.28109 .58705 .28945 .58879 .30269 .57025 .29445 .56808 Metetra
.916 .857 .768 r
.29445 .56808 .30269 .57025 .31595 .55077 .30783 .54814 Metetra
.916 .846 .76 r
.30783 .54814 .31595 .55077 .32918 .53062 .32118 .5275 Metetra
.915 .837 .754 r
.32118 .5275 .32918 .53062 .34238 .51008 .3345 .50645 Metetra
.912 .829 .751 r
.3345 .50645 .34238 .51008 .35552 .48944 .34775 .48528 Metetra
.908 .822 .75 r
.34775 .48528 .35552 .48944 .36859 .46899 .36093 .4643 Metetra
.903 .816 .752 r
.36093 .4643 .36859 .46899 .38156 .44899 .37401 .4438 Metetra
.896 .81 .756 r
.37401 .4438 .38156 .44899 .39445 .42973 .387 .42404 Metetra
.887 .805 .762 r
.387 .42404 .39445 .42973 .40725 .41144 .39988 .40529 Metetra
.877 .8 .771 r
.39988 .40529 .40725 .41144 .41995 .39435 .41267 .38777 Metetra
.864 .796 .782 r
.41267 .38777 .41995 .39435 .43257 .37867 .42537 .37169 Metetra
.848 .791 .796 r
.42537 .37169 .43257 .37867 .44512 .36456 .43799 .35725 Metetra
.828 .785 .812 r
.43799 .35725 .44512 .36456 .45761 .35218 .45054 .34458 Metetra
.802 .779 .832 r
.45054 .34458 .45761 .35218 .47006 .34164 .46305 .33381 Metetra
.769 .77 .854 r
.46305 .33381 .47006 .34164 .4825 .33304 .47553 .32504 Metetra
.727 .758 .877 r
.47553 .32504 .4825 .33304 .49493 .32644 .48801 .31833 Metetra
.671 .74 .902 r
.48801 .31833 .49493 .32644 .5074 .32188 .50051 .31372 Metetra
.599 .714 .924 r
.50051 .31372 .5074 .32188 .51991 .31937 .51306 .31123 Metetra
.507 .675 .94 r
.51306 .31123 .51991 .31937 .53251 .31888 .52568 .31083 Metetra
.392 .621 .944 r
.52568 .31083 .53251 .31888 .5452 .32038 .5384 .31246 Metetra
.257 .55 .928 r
.5384 .31246 .5452 .32038 .55802 .32378 .55124 .31607 Metetra
.108 .463 .889 r
.55124 .31607 .55802 .32378 .57099 .32898 .56424 .32153 Metetra
0 .368 .83 r
.56424 .32153 .57099 .32898 .58413 .33586 .5774 .32872 Metetra
0 .273 .757 r
.5774 .32872 .58413 .33586 .59746 .34425 .59076 .33747 Metetra
0 .189 .68 r
.59076 .33747 .59746 .34425 .61099 .35397 .60432 .34758 Metetra
0 .119 .609 r
.60432 .34758 .61099 .35397 .62475 .36479 .61811 .35883 Metetra
0 .066 .548 r
.61811 .35883 .62475 .36479 .63872 .3765 .63212 .37098 Metetra
.497 0 0 r
.63212 .37098 .63872 .3765 .65293 .38882 .64637 .38377 Metetra
.527 0 0 r
.64637 .38377 .65293 .38882 .66736 .40147 .66085 .39689 Metetra
.543 .001 0 r
.66085 .39689 .66736 .40147 .68201 .41418 .67555 .41006 Metetra
.545 0 0 r
.67555 .41006 .68201 .41418 .69686 .42664 .69046 .42297 Metetra
.535 0 0 r
.69046 .42297 .69686 .42664 .71191 .43856 .70557 .43532 Metetra
.512 0 0 r
.70557 .43532 .71191 .43856 .72712 .44966 .72085 .44681 Metetra
.476 0 0 r
.72085 .44681 .72712 .44966 .74247 .45969 .73628 .4572 Metetra
.25 .733 .93 r
.73628 .4572 .74247 .45969 .7577 .46493 .75117 .45664 Metetra
.646 .762 .934 r
.75117 .45664 .7577 .46493 .77235 .46045 .76587 .45212 Metetra
.646 .762 .934 r
.76587 .45212 .77235 .46045 .78707 .45594 .78065 .44757 Metetra
.646 .762 .934 r
.78065 .44757 .78707 .45594 .80188 .45142 .79551 .443 Metetra
.646 .762 .934 r
.79551 .443 .80188 .45142 .81676 .44687 .81044 .43841 Metetra
.646 .762 .934 r
.81044 .43841 .81676 .44687 .83171 .4423 .82545 .43379 Metetra
.646 .762 .934 r
.82545 .43379 .83171 .4423 .84674 .4377 .84054 .42915 Metetra
.646 .762 .934 r
.17469 .62458 .18306 .63136 .19499 .62769 .18665 .62088 Metetra
.646 .762 .934 r
.18665 .62088 .19499 .62769 .20697 .62401 .19867 .61716 Metetra
.646 .762 .934 r
.19867 .61716 .20697 .62401 .21901 .62031 .21074 .61342 Metetra
.646 .762 .934 r
.21074 .61342 .21901 .62031 .23111 .61659 .22287 .60967 Metetra
.646 .762 .934 r
.22287 .60967 .23111 .61659 .24326 .61285 .23505 .6059 Metetra
.646 .762 .934 r
.23505 .6059 .24326 .61285 .25547 .60909 .2473 .60211 Metetra
.646 .762 .934 r
.2473 .60211 .25547 .60909 .26777 .60483 .2596 .59831 Metetra
.822 .794 .826 r
.2596 .59831 .26777 .60483 .28109 .58705 .27258 .58603 Metetra
.921 .882 .779 r
.27258 .58603 .28109 .58705 .29445 .56808 .28606 .56669 Metetra
.924 .87 .767 r
.28606 .56669 .29445 .56808 .30783 .54814 .29955 .54636 Metetra
.924 .861 .759 r
.29955 .54636 .30783 .54814 .32118 .5275 .31303 .5253 Metetra
.924 .853 .754 r
.31303 .5253 .32118 .5275 .3345 .50645 .32646 .50381 Metetra
.922 .846 .751 r
.32646 .50381 .3345 .50645 .34775 .48528 .33984 .4822 Metetra
.919 .84 .75 r
.33984 .4822 .34775 .48528 .36093 .4643 .35312 .46076 Metetra
.915 .835 .753 r
.35312 .46076 .36093 .4643 .37401 .4438 .36632 .43981 Metetra
.909 .832 .757 r
.36632 .43981 .37401 .4438 .387 .42404 .37941 .41961 Metetra
.902 .829 .765 r
.37941 .41961 .387 .42404 .39988 .40529 .39239 .40045 Metetra
.892 .826 .775 r
.39239 .40045 .39988 .40529 .41267 .38777 .40527 .38254 Metetra
.88 .825 .788 r
.40527 .38254 .41267 .38777 .42537 .37169 .41805 .36612 Metetra
.865 .823 .805 r
.41805 .36612 .42537 .37169 .43799 .35725 .43075 .35137 Metetra
.845 .821 .825 r
.43075 .35137 .43799 .35725 .45054 .34458 .44337 .33844 Metetra
.819 .818 .849 r
.44337 .33844 .45054 .34458 .46305 .33381 .45594 .32747 Metetra
.784 .813 .876 r
.45594 .32747 .46305 .33381 .47553 .32504 .46848 .31854 Metetra
.736 .803 .905 r
.46848 .31854 .47553 .32504 .48801 .31833 .481 .31173 Metetra
.672 .786 .935 r
.481 .31173 .48801 .31833 .50051 .31372 .49355 .30709 Metetra
.584 .757 .96 r
.49355 .30709 .50051 .31372 .51306 .31123 .50613 .30461 Metetra
.469 .708 .973 r
.50613 .30461 .51306 .31123 .52568 .31083 .51879 .30427 Metetra
.323 .636 .964 r
.51879 .30427 .52568 .31083 .5384 .31246 .53154 .30604 Metetra
.156 .539 .924 r
.53154 .30604 .5384 .31246 .55124 .31607 .54442 .30982 Metetra
0 .426 .854 r
.54442 .30982 .55124 .31607 .56424 .32153 .55744 .31551 Metetra
0 .309 .763 r
.55744 .31551 .56424 .32153 .5774 .32872 .57064 .32296 Metetra
0 .204 .667 r
.57064 .32296 .5774 .32872 .59076 .33747 .58402 .33202 Metetra
0 .116 .579 r
.58402 .33202 .59076 .33747 .60432 .34758 .59762 .34247 Metetra
.488 0 0 r
.59762 .34247 .60432 .34758 .61811 .35883 .61144 .3541 Metetra
.541 0 0 r
.61144 .3541 .61811 .35883 .63212 .37098 .62549 .36664 Metetra
.575 .031 0 r
.62549 .36664 .63212 .37098 .64637 .38377 .63978 .37982 Metetra
.595 .048 0 r
.63978 .37982 .64637 .38377 .66085 .39689 .65431 .39335 Metetra
.602 .052 0 r
.65431 .39335 .66085 .39689 .67555 .41006 .66906 .40691 Metetra
.599 .043 0 r
.66906 .40691 .67555 .41006 .69046 .42297 .68403 .4202 Metetra
.584 .022 0 r
.68403 .4202 .69046 .42297 .70557 .43532 .6992 .4329 Metetra
.559 0 0 r
.6992 .4329 .70557 .43532 .72085 .44681 .71455 .44471 Metetra
.406 0 0 r
.71455 .44471 .72085 .44681 .73628 .4572 .72989 .45281 Metetra
.601 .867 .993 r
.72989 .45281 .73628 .4572 .75117 .45664 .74457 .44827 Metetra
.646 .762 .934 r
.74457 .44827 .75117 .45664 .76587 .45212 .75933 .44371 Metetra
.646 .762 .934 r
.75933 .44371 .76587 .45212 .78065 .44757 .77417 .43912 Metetra
.646 .762 .934 r
.77417 .43912 .78065 .44757 .79551 .443 .78908 .4345 Metetra
.646 .762 .934 r
.78908 .4345 .79551 .443 .81044 .43841 .80406 .42987 Metetra
.646 .762 .934 r
.80406 .42987 .81044 .43841 .82545 .43379 .81913 .42521 Metetra
.646 .762 .934 r
.81913 .42521 .82545 .43379 .84054 .42915 .83428 .42052 Metetra
.646 .762 .934 r
.16626 .61773 .17469 .62458 .18665 .62088 .17825 .614 Metetra
.646 .762 .934 r
.17825 .614 .18665 .62088 .19867 .61716 .1903 .61025 Metetra
.646 .762 .934 r
.1903 .61025 .19867 .61716 .21074 .61342 .2024 .60648 Metetra
.646 .762 .934 r
.2024 .60648 .21074 .61342 .22287 .60967 .21456 .6027 Metetra
.646 .762 .934 r
.21456 .6027 .22287 .60967 .23505 .6059 .22678 .5989 Metetra
.646 .762 .934 r
.22678 .5989 .23505 .6059 .2473 .60211 .23906 .59508 Metetra
.646 .762 .934 r
.23906 .59508 .2473 .60211 .2596 .59831 .25139 .59124 Metetra
.7 .775 .91 r
.25139 .59124 .2596 .59831 .27258 .58603 .26391 .58568 Metetra
.926 .893 .778 r
.26391 .58568 .27258 .58603 .28606 .56669 .27751 .56606 Metetra
.93 .883 .766 r
.27751 .56606 .28606 .56669 .29955 .54636 .29112 .5454 Metetra
.931 .874 .758 r
.29112 .5454 .29955 .54636 .31303 .5253 .30472 .524 Metetra
.932 .867 .753 r
.30472 .524 .31303 .5253 .32646 .50381 .31828 .50214 Metetra
.931 .862 .75 r
.31828 .50214 .32646 .50381 .33984 .4822 .33177 .48015 Metetra
.929 .857 .75 r
.33177 .48015 .33984 .4822 .35312 .46076 .34517 .45833 Metetra
.925 .855 .753 r
.34517 .45833 .35312 .46076 .36632 .43981 .35848 .43699 Metetra
.921 .853 .758 r
.35848 .43699 .36632 .43981 .37941 .41961 .37168 .41642 Metetra
.915 .852 .767 r
.37168 .41642 .37941 .41961 .39239 .40045 .38477 .39689 Metetra
.906 .853 .779 r
.38477 .39689 .39239 .40045 .40527 .38254 .39774 .37866 Metetra
.895 .854 .794 r
.39774 .37866 .40527 .38254 .41805 .36612 .41061 .36193 Metetra
.881 .856 .813 r
.41061 .36193 .41805 .36612 .43075 .35137 .42339 .34691 Metetra
.861 .858 .836 r
.42339 .34691 .43075 .35137 .44337 .33844 .43609 .33375 Metetra
.834 .859 .864 r
.43609 .33375 .44337 .33844 .45594 .32747 .44873 .32259 Metetra
.796 .858 .896 r
.44873 .32259 .45594 .32747 .46848 .31854 .46132 .31353 Metetra
.742 .851 .931 r
.46132 .31353 .46848 .31854 .481 .31173 .47391 .30663 Metetra
.665 .834 .965 r
.47391 .30663 .481 .31173 .49355 .30709 .4865 .30194 Metetra
.556 .798 .989 r
.4865 .30194 .49355 .30709 .50613 .30461 .49913 .29947 Metetra
.41 .734 .991 r
.49913 .29947 .50613 .30461 .51879 .30427 .51183 .29919 Metetra
.229 .635 .957 r
.51183 .29919 .51879 .30427 .53154 .30604 .52462 .30106 Metetra
.032 .506 .881 r
.52462 .30106 .53154 .30604 .54442 .30982 .53753 .305 Metetra
0 .367 .775 r
.53753 .305 .54442 .30982 .55744 .31551 .55059 .31088 Metetra
0 .238 .661 r
.55059 .31088 .55744 .31551 .57064 .32296 .56382 .31857 Metetra
.425 0 0 r
.56382 .31857 .57064 .32296 .58402 .33202 .57724 .32789 Metetra
.509 0 0 r
.57724 .32789 .58402 .33202 .59762 .34247 .59087 .33863 Metetra
.568 .012 0 r
.59087 .33863 .59762 .34247 .61144 .3541 .60472 .35057 Metetra
.606 .054 0 r
.60472 .35057 .61144 .3541 .62549 .36664 .61882 .36344 Metetra
.63 .079 0 r
.61882 .36344 .62549 .36664 .63978 .37982 .63315 .37695 Metetra
.642 .091 0 r
.63315 .37695 .63978 .37982 .65431 .39335 .64772 .39081 Metetra
.644 .091 0 r
.64772 .39081 .65431 .39335 .66906 .40691 .66253 .40469 Metetra
.636 .08 0 r
.66253 .40469 .66906 .40691 .68403 .4202 .67756 .41828 Metetra
.62 .057 0 r
.67756 .41828 .68403 .4202 .6992 .4329 .69279 .43125 Metetra
.592 .022 0 r
.69279 .43125 .6992 .4329 .71455 .44471 .70821 .44332 Metetra
.023 .588 .792 r
.70821 .44332 .71455 .44471 .72989 .45281 .72318 .44441 Metetra
.646 .762 .934 r
.72318 .44441 .72989 .45281 .74457 .44827 .73792 .43982 Metetra
.646 .762 .934 r
.73792 .43982 .74457 .44827 .75933 .44371 .75273 .43522 Metetra
.646 .762 .934 r
.75273 .43522 .75933 .44371 .77417 .43912 .76762 .43058 Metetra
.646 .762 .934 r
.76762 .43058 .77417 .43912 .78908 .4345 .78258 .42592 Metetra
.646 .762 .934 r
.78258 .42592 .78908 .4345 .80406 .42987 .79763 .42124 Metetra
.646 .762 .934 r
.79763 .42124 .80406 .42987 .81913 .42521 .81275 .41654 Metetra
.646 .762 .934 r
.81275 .41654 .81913 .42521 .83428 .42052 .82795 .41181 Metetra
.646 .762 .934 r
.15775 .61083 .16626 .61773 .17825 .614 .16977 .60706 Metetra
.646 .762 .934 r
.16977 .60706 .17825 .614 .1903 .61025 .18185 .60328 Metetra
.646 .762 .934 r
.18185 .60328 .1903 .61025 .2024 .60648 .19399 .59948 Metetra
.646 .762 .934 r
.19399 .59948 .2024 .60648 .21456 .6027 .20618 .59566 Metetra
.646 .762 .934 r
.20618 .59566 .21456 .6027 .22678 .5989 .21843 .59183 Metetra
.646 .762 .934 r
.21843 .59183 .22678 .5989 .23906 .59508 .23074 .58797 Metetra
.646 .762 .934 r
.23074 .58797 .23906 .59508 .25139 .59124 .24311 .5841 Metetra
.646 .762 .934 r
.24311 .5841 .25139 .59124 .26391 .58568 .25554 .58021 Metetra
.85 .817 .817 r
.25554 .58021 .26391 .58568 .27751 .56606 .2688 .56611 Metetra
.934 .895 .765 r
.2688 .56611 .27751 .56606 .29112 .5454 .28253 .54522 Metetra
.937 .887 .757 r
.28253 .54522 .29112 .5454 .30472 .524 .29625 .52355 Metetra
.938 .881 .752 r
.29625 .52355 .30472 .524 .31828 .50214 .30993 .5014 Metetra
.938 .877 .749 r
.30993 .5014 .31828 .50214 .33177 .48015 .32354 .4791 Metetra
.937 .874 .749 r
.32354 .4791 .33177 .48015 .34517 .45833 .33707 .45696 Metetra
.934 .873 .752 r
.33707 .45696 .34517 .45833 .35848 .43699 .35049 .4353 Metetra
.931 .873 .758 r
.35049 .4353 .35848 .43699 .37168 .41642 .3638 .41441 Metetra
.925 .875 .768 r
.3638 .41441 .37168 .41642 .38477 .39689 .377 .39458 Metetra
.918 .878 .78 r
.377 .39458 .38477 .39689 .39774 .37866 .39007 .37606 Metetra
.908 .882 .797 r
.39007 .37606 .39774 .37866 .41061 .36193 .40304 .35908 Metetra
.893 .888 .819 r
.40304 .35908 .41061 .36193 .42339 .34691 .41591 .34382 Metetra
.873 .894 .845 r
.41591 .34382 .42339 .34691 .43609 .33375 .42869 .33047 Metetra
.844 .9 .876 r
.42869 .33047 .43609 .33375 .44873 .32259 .4414 .31914 Metetra
.802 .903 .912 r
.4414 .31914 .44873 .32259 .46132 .31353 .45406 .30996 Metetra
.739 .899 .951 r
.45406 .30996 .46132 .31353 .47391 .30663 .46671 .30298 Metetra
.645 .879 .984 r
.46671 .30298 .47391 .30663 .4865 .30194 .47936 .29825 Metetra
.508 .83 1 r
.47936 .29825 .4865 .30194 .49913 .29947 .49204 .29578 Metetra
.325 .74 .978 r
.49204 .29578 .49913 .29947 .51183 .29919 .50478 .29555 Metetra
.111 .605 .906 r
.50478 .29555 .51183 .29919 .52462 .30106 .51762 .29751 Metetra
0 .447 .791 r
.51762 .29751 .52462 .30106 .53753 .305 .53057 .30156 Metetra
0 .293 .661 r
.53057 .30156 .53753 .305 .55059 .31088 .54367 .30761 Metetra
.415 0 0 r
.54367 .30761 .55059 .31088 .56382 .31857 .55693 .31548 Metetra
.511 0 0 r
.55693 .31548 .56382 .31857 .57724 .32789 .57039 .32502 Metetra
.577 .01 0 r
.57039 .32502 .57724 .32789 .59087 .33863 .58406 .33601 Metetra
.622 .062 0 r
.58406 .33601 .59087 .33863 .60472 .35057 .59796 .3482 Metetra
.65 .096 0 r
.59796 .3482 .60472 .35057 .61882 .36344 .61209 .36133 Metetra
.666 .117 0 r
.61209 .36133 .61882 .36344 .63315 .37695 .62647 .37511 Metetra
.673 .125 0 r
.62647 .37511 .63315 .37695 .64772 .39081 .64109 .38922 Metetra
.671 .122 0 r
.64109 .38922 .64772 .39081 .66253 .40469 .65595 .40335 Metetra
.662 .108 0 r
.65595 .40335 .66253 .40469 .67756 .41828 .67104 .41716 Metetra
.643 .084 0 r
.67104 .41716 .67756 .41828 .69279 .43125 .68633 .43034 Metetra
.551 0 0 r
.68633 .43034 .69279 .43125 .70821 .44332 .7017 .44053 Metetra
.546 .891 .982 r
.7017 .44053 .70821 .44332 .72318 .44441 .71641 .43593 Metetra
.646 .762 .934 r
.71641 .43593 .72318 .44441 .73792 .43982 .7312 .4313 Metetra
.646 .762 .934 r
.7312 .4313 .73792 .43982 .75273 .43522 .74606 .42664 Metetra
.646 .762 .934 r
.74606 .42664 .75273 .43522 .76762 .43058 .76101 .42196 Metetra
.646 .762 .934 r
.76101 .42196 .76762 .43058 .78258 .42592 .77603 .41726 Metetra
.646 .762 .934 r
.77603 .41726 .78258 .42592 .79763 .42124 .79113 .41253 Metetra
.646 .762 .934 r
.79113 .41253 .79763 .42124 .81275 .41654 .80631 .40778 Metetra
.646 .762 .934 r
.80631 .40778 .81275 .41654 .82795 .41181 .82157 .40301 Metetra
.646 .762 .934 r
.14916 .60386 .15775 .61083 .16977 .60706 .16122 .60007 Metetra
.646 .762 .934 r
.16122 .60007 .16977 .60706 .18185 .60328 .17333 .59625 Metetra
.646 .762 .934 r
.17333 .59625 .18185 .60328 .19399 .59948 .1855 .59242 Metetra
.646 .762 .934 r
.1855 .59242 .19399 .59948 .20618 .59566 .19773 .58857 Metetra
.646 .762 .934 r
.19773 .58857 .20618 .59566 .21843 .59183 .21001 .5847 Metetra
.646 .762 .934 r
.21001 .5847 .21843 .59183 .23074 .58797 .22236 .58081 Metetra
.646 .762 .934 r
.22236 .58081 .23074 .58797 .24311 .5841 .23476 .5769 Metetra
.646 .762 .934 r
.23476 .5769 .24311 .5841 .25554 .58021 .24722 .57298 Metetra
.713 .777 .903 r
.24722 .57298 .25554 .58021 .2688 .56611 .25992 .56681 Metetra
.938 .906 .765 r
.25992 .56681 .2688 .56611 .28253 .54522 .27377 .54575 Metetra
.941 .899 .756 r
.27377 .54575 .28253 .54522 .29625 .52355 .28761 .52388 Metetra
.943 .894 .75 r
.28761 .52388 .29625 .52355 .30993 .5014 .30141 .50152 Metetra
.944 .891 .748 r
.30141 .50152 .30993 .5014 .32354 .4791 .31515 .47898 Metetra
.943 .889 .748 r
.31515 .47898 .32354 .4791 .33707 .45696 .3288 .4566 Metetra
.941 .89 .751 r
.3288 .4566 .33707 .45696 .35049 .4353 .34234 .43468 Metetra
.938 .892 .757 r
.34234 .43468 .35049 .4353 .3638 .41441 .35577 .41354 Metetra
.934 .896 .767 r
.35577 .41354 .3638 .41441 .377 .39458 .36908 .39347 Metetra
.927 .902 .781 r
.36908 .39347 .377 .39458 .39007 .37606 .38226 .37471 Metetra
.917 .909 .798 r
.38226 .37471 .39007 .37606 .40304 .35908 .39532 .35751 Metetra
.902 .918 .821 r
.39532 .35751 .40304 .35908 .41591 .34382 .40828 .34206 Metetra
.881 .928 .849 r
.40828 .34206 .41591 .34382 .42869 .33047 .42115 .32854 Metetra
.848 .938 .882 r
.42115 .32854 .42869 .33047 .4414 .31914 .43394 .31707 Metetra
.799 .943 .92 r
.43394 .31707 .4414 .31914 .45406 .30996 .44668 .30778 Metetra
.722 .938 .957 r
.44668 .30778 .45406 .30996 .46671 .30298 .4594 .30073 Metetra
.605 .909 .982 r
.4594 .30073 .46671 .30298 .47936 .29825 .47211 .29597 Metetra
.435 .837 .976 r
.47211 .29597 .47936 .29825 .49204 .29578 .48485 .2935 Metetra
.217 .712 .917 r
.48485 .2935 .49204 .29578 .50478 .29555 .49765 .2933 Metetra
0 .545 .805 r
.49765 .2933 .50478 .29555 .51762 .29751 .51053 .29532 Metetra
.221 0 0 r
.51053 .29532 .51762 .29751 .53057 .30156 .52353 .29947 Metetra
.379 0 0 r
.52353 .29947 .53057 .30156 .54367 .30761 .53667 .30564 Metetra
.492 0 0 r
.53667 .30564 .54367 .30761 .55693 .31548 .54997 .31367 Metetra
.569 0 0 r
.54997 .31367 .55693 .31548 .57039 .32502 .56347 .32337 Metetra
.621 .056 0 r
.56347 .32337 .57039 .32502 .58406 .33601 .57719 .33454 Metetra
.656 .1 0 r
.57719 .33454 .58406 .33601 .59796 .3482 .59113 .34693 Metetra
.677 .128 0 r
.59113 .34693 .59796 .3482 .61209 .36133 .60531 .36026 Metetra
.689 .144 0 r
.60531 .36026 .61209 .36133 .62647 .37511 .61973 .37424 Metetra
.693 .149 0 r
.61973 .37424 .62647 .37511 .64109 .38922 .63441 .38854 Metetra
.689 .144 0 r
.63441 .38854 .64109 .38922 .65595 .40335 .64932 .40283 Metetra
.677 .128 0 r
.64932 .40283 .65595 .40335 .67104 .41716 .66446 .41679 Metetra
.658 .103 0 r
.66446 .41679 .67104 .41716 .68633 .43034 .67981 .43009 Metetra
.132 0 0 r
.67981 .43009 .68633 .43034 .7017 .44053 .69481 .43201 Metetra
.646 .762 .934 r
.69481 .43201 .7017 .44053 .71641 .43593 .70958 .42736 Metetra
.646 .762 .934 r
.70958 .42736 .71641 .43593 .7312 .4313 .72442 .42269 Metetra
.646 .762 .934 r
.72442 .42269 .7312 .4313 .74606 .42664 .73934 .41799 Metetra
.646 .762 .934 r
.73934 .41799 .74606 .42664 .76101 .42196 .75433 .41326 Metetra
.646 .762 .934 r
.75433 .41326 .76101 .42196 .77603 .41726 .76941 .40852 Metetra
.646 .762 .934 r
.76941 .40852 .77603 .41726 .79113 .41253 .78456 .40374 Metetra
.646 .762 .934 r
.78456 .40374 .79113 .41253 .80631 .40778 .7998 .39894 Metetra
.646 .762 .934 r
.7998 .39894 .80631 .40778 .82157 .40301 .81512 .39412 Metetra
.646 .762 .934 r
.1405 .59684 .14916 .60386 .16122 .60007 .15259 .59301 Metetra
.646 .762 .934 r
.15259 .59301 .16122 .60007 .17333 .59625 .16474 .58916 Metetra
.646 .762 .934 r
.16474 .58916 .17333 .59625 .1855 .59242 .17694 .5853 Metetra
.646 .762 .934 r
.17694 .5853 .1855 .59242 .19773 .58857 .1892 .58141 Metetra
.646 .762 .934 r
.1892 .58141 .19773 .58857 .21001 .5847 .20152 .57751 Metetra
.646 .762 .934 r
.20152 .57751 .21001 .5847 .22236 .58081 .2139 .57358 Metetra
.646 .762 .934 r
.2139 .57358 .22236 .58081 .23476 .5769 .22634 .56964 Metetra
.646 .762 .934 r
.22634 .56964 .23476 .5769 .24722 .57298 .23883 .56568 Metetra
.646 .762 .934 r
.23883 .56568 .24722 .57298 .25992 .56681 .25139 .5617 Metetra
.859 .828 .815 r
.25139 .5617 .25992 .56681 .27377 .54575 .26484 .54692 Metetra
.944 .909 .755 r
.26484 .54692 .27377 .54575 .28761 .52388 .2788 .52494 Metetra
.946 .906 .749 r
.2788 .52494 .28761 .52388 .30141 .50152 .29273 .50244 Metetra
.948 .904 .746 r
.29273 .50244 .30141 .50152 .31515 .47898 .30659 .47974 Metetra
.948 .903 .746 r
.30659 .47974 .31515 .47898 .3288 .4566 .32036 .45718 Metetra
.946 .905 .749 r
.32036 .45718 .3288 .4566 .34234 .43468 .33403 .43508 Metetra
.944 .909 .755 r
.33403 .43508 .34234 .43468 .35577 .41354 .34757 .41375 Metetra
.939 .915 .765 r
.34757 .41375 .35577 .41354 .36908 .39347 .36099 .39349 Metetra
.932 .923 .779 r
.36099 .39349 .36908 .39347 .38226 .37471 .37428 .37455 Metetra
.922 .933 .797 r
.37428 .37455 .38226 .37471 .39532 .35751 .38746 .35717 Metetra
.906 .945 .819 r
.38746 .35717 .39532 .35751 .40828 .34206 .40051 .34156 Metetra
.881 .958 .848 r
.40051 .34156 .40828 .34206 .42115 .32854 .41347 .3279 Metetra
.843 .969 .88 r
.41347 .3279 .42115 .32854 .43394 .31707 .42635 .31633 Metetra
.783 .974 .915 r
.42635 .31633 .43394 .31707 .44668 .30778 .43917 .30694 Metetra
.687 .961 .943 r
.43917 .30694 .44668 .30778 .4594 .30073 .45196 .29983 Metetra
.541 .913 .949 r
.45196 .29983 .4594 .30073 .47211 .29597 .46474 .29503 Metetra
.338 .81 .909 r
.46474 .29503 .47211 .29597 .48485 .2935 .47754 .29255 Metetra
.1 .651 .812 r
.47754 .29255 .48485 .2935 .49765 .2933 .4904 .29237 Metetra
.13 0 0 r
.4904 .29237 .49765 .2933 .51053 .29532 .50334 .29444 Metetra
.314 0 0 r
.50334 .29444 .51053 .29532 .52353 .29947 .51639 .29866 Metetra
.449 0 0 r
.51639 .29866 .52353 .29947 .53667 .30564 .52958 .30492 Metetra
.542 0 0 r
.52958 .30492 .53667 .30564 .54997 .31367 .54293 .31306 Metetra
.605 .035 0 r
.54293 .31306 .54997 .31367 .56347 .32337 .55648 .32289 Metetra
.648 .09 0 r
.55648 .32289 .56347 .32337 .57719 .33454 .57024 .33419 Metetra
.676 .127 0 r
.57024 .33419 .57719 .33454 .59113 .34693 .58422 .34671 Metetra
.693 .151 0 r
.58422 .34671 .59113 .34693 .60531 .36026 .59845 .36017 Metetra
.702 .164 0 r
.59845 .36017 .60531 .36026 .61973 .37424 .61293 .37427 Metetra
.703 .166 0 r
.61293 .37427 .61973 .37424 .63441 .38854 .62765 .38868 Metetra
.698 .159 0 r
.62765 .38868 .63441 .38854 .64932 .40283 .64261 .40307 Metetra
.686 .142 0 r
.64261 .40307 .64932 .40283 .66446 .41679 .65781 .4171 Metetra
.608 .039 0 r
.65781 .4171 .66446 .41679 .67981 .43009 .67312 .42808 Metetra
.51 .892 .961 r
.67312 .42808 .67981 .43009 .69481 .43201 .68786 .42341 Metetra
.646 .762 .934 r
.68786 .42341 .69481 .43201 .70958 .42736 .70267 .41871 Metetra
.646 .762 .934 r
.70267 .41871 .70958 .42736 .72442 .42269 .71757 .41399 Metetra
.646 .762 .934 r
.71757 .41399 .72442 .42269 .73934 .41799 .73254 .40925 Metetra
.646 .762 .934 r
.73254 .40925 .73934 .41799 .75433 .41326 .74759 .40448 Metetra
.646 .762 .934 r
.74759 .40448 .75433 .41326 .76941 .40852 .76273 .39968 Metetra
.646 .762 .934 r
.76273 .39968 .76941 .40852 .78456 .40374 .77794 .39486 Metetra
.646 .762 .934 r
.77794 .39486 .78456 .40374 .7998 .39894 .79323 .39002 Metetra
.646 .762 .934 r
.79323 .39002 .7998 .39894 .81512 .39412 .8086 .38515 Metetra
.646 .762 .934 r
.13177 .58976 .1405 .59684 .15259 .59301 .14389 .58589 Metetra
.646 .762 .934 r
.14389 .58589 .15259 .59301 .16474 .58916 .15607 .58201 Metetra
.646 .762 .934 r
.15607 .58201 .16474 .58916 .17694 .5853 .1683 .57811 Metetra
.646 .762 .934 r
.1683 .57811 .17694 .5853 .1892 .58141 .1806 .57419 Metetra
.646 .762 .934 r
.1806 .57419 .1892 .58141 .20152 .57751 .19295 .57025 Metetra
.646 .762 .934 r
.19295 .57025 .20152 .57751 .2139 .57358 .20536 .56629 Metetra
.646 .762 .934 r
.20536 .56629 .2139 .57358 .22634 .56964 .21784 .56232 Metetra
.646 .762 .934 r
.21784 .56232 .22634 .56964 .23883 .56568 .23037 .55832 Metetra
.646 .762 .934 r
.23037 .55832 .23883 .56568 .25139 .5617 .24296 .55431 Metetra
.696 .774 .912 r
.24296 .55431 .25139 .5617 .26484 .54692 .25575 .54866 Metetra
.945 .919 .755 r
.25575 .54866 .26484 .54692 .2788 .52494 .26983 .52665 Metetra
.948 .916 .749 r
.26983 .52665 .2788 .52494 .29273 .50244 .28387 .50408 Metetra
.95 .915 .745 r
.28387 .50408 .29273 .50244 .30659 .47974 .29785 .48131 Metetra
.95 .916 .744 r
.29785 .48131 .30659 .47974 .32036 .45718 .31175 .45864 Metetra
.949 .919 .747 r
.31175 .45864 .32036 .45718 .33403 .43508 .32554 .43642 Metetra
.947 .925 .753 r
.32554 .43642 .33403 .43508 .34757 .41375 .3392 .41497 Metetra
.942 .932 .762 r
.3392 .41497 .34757 .41375 .36099 .39349 .35274 .39457 Metetra
.934 .942 .775 r
.35274 .39457 .36099 .39349 .37428 .37455 .36615 .37549 Metetra
.922 .954 .792 r
.36615 .37549 .37428 .37455 .38746 .35717 .37943 .35799 Metetra
.903 .967 .813 r
.37943 .35799 .38746 .35717 .40051 .34156 .39259 .34226 Metetra
.874 .98 .839 r
.39259 .34226 .40051 .34156 .41347 .3279 .40564 .32849 Metetra
.827 .99 .867 r
.40564 .32849 .41347 .3279 .42635 .31633 .41862 .31683 Metetra
.751 .989 .893 r
.41862 .31683 .42635 .31633 .43917 .30694 .43152 .30737 Metetra
.632 .961 .904 r
.43152 .30737 .43917 .30694 .45196 .29983 .44439 .3002 Metetra
.457 .886 .881 r
.44439 .3002 .45196 .29983 .46474 .29503 .45725 .29537 Metetra
.231 .75 .806 r
.45725 .29537 .46474 .29503 .47754 .29255 .47012 .29288 Metetra
.009 0 0 r
.47012 .29288 .47754 .29255 .4904 .29237 .48304 .2927 Metetra
.219 0 0 r
.48304 .2927 .4904 .29237 .50334 .29444 .49604 .2948 Metetra
.38 0 0 r
.49604 .2948 .50334 .29444 .51639 .29866 .50914 .29906 Metetra
.493 0 0 r
.50914 .29906 .51639 .29866 .52958 .30492 .52239 .30537 Metetra
.572 0 0 r
.52239 .30537 .52958 .30492 .54293 .31306 .53579 .31358 Metetra
.625 .066 0 r
.53579 .31358 .54293 .31306 .55648 .32289 .54939 .32348 Metetra
.662 .114 0 r
.54939 .32348 .55648 .32289 .57024 .33419 .5632 .33486 Metetra
.686 .146 0 r
.5632 .33486 .57024 .33419 .58422 .34671 .57723 .34745 Metetra
.701 .167 0 r
.57723 .34745 .58422 .34671 .59845 .36017 .59151 .36098 Metetra
.708 .177 0 r
.59151 .36098 .59845 .36017 .61293 .37427 .60604 .37513 Metetra
.708 .177 0 r
.60604 .37513 .61293 .37427 .62765 .38868 .62081 .38958 Metetra
.703 .168 0 r
.62081 .38958 .62765 .38868 .64261 .40307 .63583 .40398 Metetra
.69 .151 0 r
.63583 .40398 .64261 .40307 .65781 .4171 .65108 .418 Metetra
.171 0 0 r
.65108 .418 .65781 .4171 .67312 .42808 .66604 .41944 Metetra
.646 .762 .934 r
.66604 .41944 .67312 .42808 .68786 .42341 .68083 .41472 Metetra
.646 .762 .934 r
.68083 .41472 .68786 .42341 .70267 .41871 .6957 .40998 Metetra
.646 .762 .934 r
.6957 .40998 .70267 .41871 .71757 .41399 .71065 .40521 Metetra
.646 .762 .934 r
.71065 .40521 .71757 .41399 .73254 .40925 .72568 .40042 Metetra
.646 .762 .934 r
.72568 .40042 .73254 .40925 .74759 .40448 .74079 .39561 Metetra
.646 .762 .934 r
.74079 .39561 .74759 .40448 .76273 .39968 .75598 .39076 Metetra
.646 .762 .934 r
.75598 .39076 .76273 .39968 .77794 .39486 .77124 .3859 Metetra
.646 .762 .934 r
.77124 .3859 .77794 .39486 .79323 .39002 .7866 .381 Metetra
.646 .762 .934 r
.7866 .381 .79323 .39002 .8086 .38515 .80203 .37608 Metetra
.646 .762 .934 r
.12296 .58261 .13177 .58976 .14389 .58589 .13511 .57871 Metetra
.646 .762 .934 r
.13511 .57871 .14389 .58589 .15607 .58201 .14732 .57479 Metetra
.646 .762 .934 r
.14732 .57479 .15607 .58201 .1683 .57811 .15959 .57086 Metetra
.646 .762 .934 r
.15959 .57086 .1683 .57811 .1806 .57419 .17192 .5669 Metetra
.646 .762 .934 r
.17192 .5669 .1806 .57419 .19295 .57025 .18431 .56293 Metetra
.646 .762 .934 r
.18431 .56293 .19295 .57025 .20536 .56629 .19675 .55894 Metetra
.646 .762 .934 r
.19675 .55894 .20536 .56629 .21784 .56232 .20926 .55493 Metetra
.646 .762 .934 r
.20926 .55493 .21784 .56232 .23037 .55832 .22183 .5509 Metetra
.646 .762 .934 r
.22183 .5509 .23037 .55832 .24296 .55431 .23446 .54684 Metetra
.646 .762 .934 r
.23446 .54684 .24296 .55431 .25575 .54866 .24715 .54277 Metetra
.844 .818 .823 r
.24715 .54277 .25575 .54866 .26983 .52665 .26067 .52891 Metetra
.949 .925 .748 r
.26067 .52891 .26983 .52665 .28387 .50408 .27484 .50637 Metetra
.951 .925 .744 r
.27484 .50637 .28387 .50408 .29785 .48131 .28894 .48358 Metetra
.951 .927 .743 r
.28894 .48358 .29785 .48131 .31175 .45864 .30296 .46089 Metetra
.95 .932 .744 r
.30296 .46089 .31175 .45864 .32554 .43642 .31687 .43862 Metetra
.947 .938 .749 r
.31687 .43862 .32554 .43642 .3392 .41497 .33066 .4171 Metetra
.941 .947 .757 r
.33066 .4171 .3392 .41497 .35274 .39457 .34432 .39663 Metetra
.932 .957 .769 r
.34432 .39663 .35274 .39457 .36615 .37549 .35784 .37747 Metetra
.918 .97 .784 r
.35784 .37747 .36615 .37549 .37943 .35799 .37123 .35989 Metetra
.894 .983 .803 r
.37123 .35989 .37943 .35799 .39259 .34226 .3845 .34408 Metetra
.857 .995 .824 r
.3845 .34408 .39259 .34226 .40564 .32849 .39766 .33023 Metetra
.798 .999 .844 r
.39766 .33023 .40564 .32849 .41862 .31683 .41073 .3185 Metetra
.705 .985 .855 r
.41073 .3185 .41862 .31683 .43152 .30737 .42372 .30899 Metetra
.561 .935 .843 r
.42372 .30899 .43152 .30737 .44439 .3002 .43668 .30177 Metetra
.363 .832 .789 r
.43668 .30177 .44439 .3002 .45725 .29537 .44961 .29691 Metetra
.44961 .29691 .45725 .29537 .47012 .29288 .46256 .29439 Metetra
.097 0 0 r
.46256 .29439 .47012 .29288 .48304 .2927 .47555 .29421 Metetra
.283 0 0 r
.47555 .29421 .48304 .2927 .49604 .2948 .48862 .29631 Metetra
.422 0 0 r
.48862 .29631 .49604 .2948 .50914 .29906 .50178 .30059 Metetra
.52 0 0 r
.50178 .30059 .50914 .29906 .52239 .30537 .51509 .30692 Metetra
.588 .028 0 r
.51509 .30692 .52239 .30537 .53579 .31358 .52855 .31515 Metetra
.636 .088 0 r
.52855 .31515 .53579 .31358 .54939 .32348 .5422 .32508 Metetra
.668 .13 0 r
.5422 .32508 .54939 .32348 .5632 .33486 .55606 .33647 Metetra
.69 .159 0 r
.55606 .33647 .5632 .33486 .57723 .34745 .57015 .34908 Metetra
.703 .176 0 r
.57015 .34908 .57723 .34745 .59151 .36098 .58448 .3626 Metetra
.709 .184 0 r
.58448 .3626 .59151 .36098 .60604 .37513 .59906 .37673 Metetra
.709 .183 0 r
.59906 .37673 .60604 .37513 .62081 .38958 .61389 .39114 Metetra
.703 .173 0 r
.61389 .39114 .62081 .38958 .63583 .40398 .62896 .40547 Metetra
.599 .035 0 r
.62896 .40547 .63583 .40398 .65108 .418 .64413 .41545 Metetra
.537 .894 .976 r
.64413 .41545 .65108 .418 .66604 .41944 .65889 .41071 Metetra
.646 .762 .934 r
.65889 .41071 .66604 .41944 .68083 .41472 .67374 .40595 Metetra
.646 .762 .934 r
.67374 .40595 .68083 .41472 .6957 .40998 .68867 .40116 Metetra
.646 .762 .934 r
.68867 .40116 .6957 .40998 .71065 .40521 .70367 .39635 Metetra
.646 .762 .934 r
.70367 .39635 .71065 .40521 .72568 .40042 .71875 .39151 Metetra
.646 .762 .934 r
.71875 .39151 .72568 .40042 .74079 .39561 .73392 .38665 Metetra
.646 .762 .934 r
.73392 .38665 .74079 .39561 .75598 .39076 .74916 .38176 Metetra
.646 .762 .934 r
.74916 .38176 .75598 .39076 .77124 .3859 .76449 .37684 Metetra
.646 .762 .934 r
.76449 .37684 .77124 .3859 .7866 .381 .77989 .3719 Metetra
.646 .762 .934 r
.77989 .3719 .7866 .381 .80203 .37608 .79539 .36693 Metetra
.646 .762 .934 r
.11407 .5754 .12296 .58261 .13511 .57871 .12625 .57146 Metetra
.646 .762 .934 r
.12625 .57146 .13511 .57871 .14732 .57479 .1385 .56751 Metetra
.646 .762 .934 r
.1385 .56751 .14732 .57479 .15959 .57086 .1508 .56354 Metetra
.646 .762 .934 r
.1508 .56354 .15959 .57086 .17192 .5669 .16316 .55955 Metetra
.646 .762 .934 r
.16316 .55955 .17192 .5669 .18431 .56293 .17558 .55554 Metetra
.646 .762 .934 r
.17558 .55554 .18431 .56293 .19675 .55894 .18807 .55152 Metetra
.646 .762 .934 r
.18807 .55152 .19675 .55894 .20926 .55493 .20061 .54747 Metetra
.646 .762 .934 r
.20061 .54747 .20926 .55493 .22183 .5509 .21321 .5434 Metetra
.646 .762 .934 r
.21321 .5434 .22183 .5509 .23446 .54684 .22588 .53931 Metetra
.646 .762 .934 r
.22588 .53931 .23446 .54684 .24715 .54277 .23861 .53521 Metetra
.646 .762 .934 r
.23861 .53521 .24715 .54277 .26067 .52891 .25139 .53108 Metetra
.945 .93 .756 r
.25139 .53108 .26067 .52891 .27484 .50637 .26563 .50919 Metetra
.95 .934 .743 r
.26563 .50919 .27484 .50637 .28894 .48358 .27985 .48647 Metetra
.95 .937 .741 r
.27985 .48647 .28894 .48358 .30296 .46089 .29399 .46383 Metetra
.949 .942 .742 r
.29399 .46383 .30296 .46089 .31687 .43862 .30802 .44158 Metetra
.945 .949 .746 r
.30802 .44158 .31687 .43862 .33066 .4171 .32193 .42006 Metetra
.938 .958 .752 r
.32193 .42006 .33066 .4171 .34432 .39663 .33571 .39957 Metetra
.927 .969 .761 r
.33571 .39957 .34432 .39663 .35784 .37747 .34935 .38039 Metetra
.908 .981 .774 r
.34935 .38039 .35784 .37747 .37123 .35989 .36286 .36277 Metetra
.879 .993 .788 r
.36286 .36277 .37123 .35989 .3845 .34408 .37624 .34692 Metetra
.833 .999 .802 r
.37624 .34692 .3845 .34408 .39766 .33023 .38951 .33303 Metetra
.76 .994 .81 r
.38951 .33303 .39766 .33023 .41073 .3185 .40268 .32125 Metetra
.647 .964 .803 r
.40268 .32125 .41073 .3185 .42372 .30899 .41577 .3117 Metetra
.483 .891 .767 r
.41577 .3117 .42372 .30899 .43668 .30177 .42881 .30445 Metetra
.273 .764 .69 r
.42881 .30445 .43668 .30177 .44961 .29691 .44184 .29955 Metetra
.44184 .29955 .44961 .29691 .46256 .29439 .45486 .29701 Metetra
.162 0 0 r
.45486 .29701 .46256 .29439 .47555 .29421 .46793 .29681 Metetra
.327 0 0 r
.46793 .29681 .47555 .29421 .48862 .29631 .48107 .29889 Metetra
.448 0 0 r
.48107 .29889 .48862 .29631 .50178 .30059 .4943 .30315 Metetra
.535 0 0 r
.4943 .30315 .50178 .30059 .51509 .30692 .50767 .30947 Metetra
.596 .048 0 r
.50767 .30947 .51509 .30692 .52855 .31515 .52119 .31768 Metetra
.639 .102 0 r
.52119 .31768 .52855 .31515 .5422 .32508 .5349 .32758 Metetra
.669 .14 0 r
.5349 .32758 .5422 .32508 .55606 .33647 .54882 .33894 Metetra
.69 .166 0 r
.54882 .33894 .55606 .33647 .57015 .34908 .56297 .35149 Metetra
.702 .181 0 r
.56297 .35149 .57015 .34908 .58448 .3626 .57735 .36494 Metetra
.708 .187 0 r
.57735 .36494 .58448 .3626 .59906 .37673 .59198 .37898 Metetra
.707 .185 0 r
.59198 .37898 .59906 .37673 .61389 .39114 .60687 .39326 Metetra
.701 .174 0 r
.60687 .39326 .61389 .39114 .62896 .40547 .622 .40745 Metetra
.075 0 0 r
.622 .40745 .62896 .40547 .64413 .41545 .63686 .40668 Metetra
.646 .762 .934 r
.63686 .40668 .64413 .41545 .65889 .41071 .65168 .4019 Metetra
.646 .762 .934 r
.65168 .4019 .65889 .41071 .67374 .40595 .66658 .39709 Metetra
.646 .762 .934 r
.66658 .39709 .67374 .40595 .68867 .40116 .68156 .39226 Metetra
.646 .762 .934 r
.68156 .39226 .68867 .40116 .70367 .39635 .69662 .3874 Metetra
.646 .762 .934 r
.69662 .3874 .70367 .39635 .71875 .39151 .71176 .38251 Metetra
.646 .762 .934 r
.71176 .38251 .71875 .39151 .73392 .38665 .72698 .3776 Metetra
.646 .762 .934 r
.72698 .3776 .73392 .38665 .74916 .38176 .74228 .37266 Metetra
.646 .762 .934 r
.74228 .37266 .74916 .38176 .76449 .37684 .75766 .3677 Metetra
.646 .762 .934 r
.75766 .3677 .76449 .37684 .77989 .3719 .77313 .36271 Metetra
.646 .762 .934 r
.77313 .36271 .77989 .3719 .79539 .36693 .78868 .35769 Metetra
.646 .762 .934 r
.1051 .56812 .11407 .5754 .12625 .57146 .11732 .56416 Metetra
.646 .762 .934 r
.11732 .56416 .12625 .57146 .1385 .56751 .1296 .56017 Metetra
.646 .762 .934 r
.1296 .56017 .1385 .56751 .1508 .56354 .14193 .55616 Metetra
.646 .762 .934 r
.14193 .55616 .1508 .56354 .16316 .55955 .15433 .55214 Metetra
.646 .762 .934 r
.15433 .55214 .16316 .55955 .17558 .55554 .16678 .54809 Metetra
.646 .762 .934 r
.16678 .54809 .17558 .55554 .18807 .55152 .1793 .54403 Metetra
.646 .762 .934 r
.1793 .54403 .18807 .55152 .20061 .54747 .19188 .53994 Metetra
.646 .762 .934 r
.19188 .53994 .20061 .54747 .21321 .5434 .20452 .53584 Metetra
.646 .762 .934 r
.20452 .53584 .21321 .5434 .22588 .53931 .21722 .53172 Metetra
.646 .762 .934 r
.21722 .53172 .22588 .53931 .23861 .53521 .22998 .52757 Metetra
.646 .762 .934 r
.22998 .52757 .23861 .53521 .25139 .53108 .24281 .52341 Metetra
.796 .787 .844 r
.24281 .52341 .25139 .53108 .26563 .50919 .25624 .51245 Metetra
.948 .942 .744 r
.25624 .51245 .26563 .50919 .27985 .48647 .27058 .48988 Metetra
.948 .945 .741 r
.27058 .48988 .27985 .48647 .29399 .46383 .28484 .46735 Metetra
.946 .951 .74 r
.28484 .46735 .29399 .46383 .30802 .44158 .29899 .4452 Metetra
.941 .958 .742 r
.29899 .4452 .30802 .44158 .32193 .42006 .31303 .42375 Metetra
.932 .967 .747 r
.31303 .42375 .32193 .42006 .33571 .39957 .32693 .4033 Metetra
.918 .978 .753 r
.32693 .4033 .33571 .39957 .34935 .38039 .34069 .38415 Metetra
.895 .988 .762 r
.34069 .38415 .34935 .38039 .36286 .36277 .35431 .36653 Metetra
.859 .996 .77 r
.35431 .36653 .36286 .36277 .37624 .34692 .36781 .35068 Metetra
.802 .996 .775 r
.36781 .35068 .37624 .34692 .38951 .33303 .38118 .33678 Metetra
.715 .979 .771 r
.38118 .33678 .38951 .33303 .40268 .32125 .39446 .32499 Metetra
.585 .931 .746 r
.39446 .32499 .40268 .32125 .41577 .3117 .40765 .31541 Metetra
.407 .837 .689 r
.40765 .31541 .41577 .3117 .42881 .30445 .42079 .30813 Metetra
.42079 .30813 .42881 .30445 .44184 .29955 .4339 .30321 Metetra
.021 0 0 r
.4339 .30321 .44184 .29955 .45486 .29701 .44702 .30064 Metetra
.208 0 0 r
.44702 .30064 .45486 .29701 .46793 .29681 .46016 .3004 Metetra
.355 0 0 r
.46016 .3004 .46793 .29681 .48107 .29889 .47338 .30244 Metetra
.464 0 0 r
.47338 .30244 .48107 .29889 .4943 .30315 .48668 .30666 Metetra
.542 0 0 r
.48668 .30666 .4943 .30315 .50767 .30947 .50012 .31292 Metetra
.598 .062 0 r
.50012 .31292 .50767 .30947 .52119 .31768 .51371 .32106 Metetra
.639 .111 0 r
.51371 .32106 .52119 .31768 .5349 .32758 .52748 .33088 Metetra
.667 .145 0 r
.52748 .33088 .5349 .32758 .54882 .33894 .54146 .34215 Metetra
.686 .169 0 r
.54146 .34215 .54882 .33894 .56297 .35149 .55567 .35458 Metetra
.698 .182 0 r
.55567 .35458 .56297 .35149 .57735 .36494 .57011 .36789 Metetra
.703 .187 0 r
.57011 .36789 .57735 .36494 .59198 .37898 .5848 .38176 Metetra
.703 .183 0 r
.5848 .38176 .59198 .37898 .60687 .39326 .59974 .39585 Metetra
.513 0 0 r
.59974 .39585 .60687 .39326 .622 .40745 .61473 .40264 Metetra
.609 .865 .991 r
.61473 .40264 .622 .40745 .63686 .40668 .62952 .39783 Metetra
.646 .762 .934 r
.62952 .39783 .63686 .40668 .65168 .4019 .6444 .393 Metetra
.646 .762 .934 r
.6444 .393 .65168 .4019 .66658 .39709 .65935 .38815 Metetra
.646 .762 .934 r
.65935 .38815 .66658 .39709 .68156 .39226 .67438 .38327 Metetra
.646 .762 .934 r
.67438 .38327 .68156 .39226 .69662 .3874 .68949 .37836 Metetra
.646 .762 .934 r
.68949 .37836 .69662 .3874 .71176 .38251 .70469 .37342 Metetra
.646 .762 .934 r
.70469 .37342 .71176 .38251 .72698 .3776 .71997 .36846 Metetra
.646 .762 .934 r
.71997 .36846 .72698 .3776 .74228 .37266 .73532 .36348 Metetra
.646 .762 .934 r
.73532 .36348 .74228 .37266 .75766 .3677 .75077 .35846 Metetra
.646 .762 .934 r
.75077 .35846 .75766 .3677 .77313 .36271 .76629 .35342 Metetra
.646 .762 .934 r
.76629 .35342 .77313 .36271 .78868 .35769 .7819 .34835 Metetra
.646 .762 .934 r
.09606 .56078 .1051 .56812 .11732 .56416 .10831 .55678 Metetra
.646 .762 .934 r
.10831 .55678 .11732 .56416 .1296 .56017 .12062 .55276 Metetra
.646 .762 .934 r
.12062 .55276 .1296 .56017 .14193 .55616 .13298 .54872 Metetra
.646 .762 .934 r
.13298 .54872 .14193 .55616 .15433 .55214 .14541 .54466 Metetra
.646 .762 .934 r
.14541 .54466 .15433 .55214 .16678 .54809 .1579 .54057 Metetra
.646 .762 .934 r
.1579 .54057 .16678 .54809 .1793 .54403 .17046 .53647 Metetra
.646 .762 .934 r
.17046 .53647 .1793 .54403 .19188 .53994 .18307 .53235 Metetra
.646 .762 .934 r
.18307 .53235 .19188 .53994 .20452 .53584 .19574 .52821 Metetra
.646 .762 .934 r
.19574 .52821 .20452 .53584 .21722 .53172 .20848 .52405 Metetra
.646 .762 .934 r
.20848 .52405 .21722 .53172 .22998 .52757 .22128 .51987 Metetra
.646 .762 .934 r
.22128 .51987 .22998 .52757 .24281 .52341 .23415 .51566 Metetra
.646 .762 .934 r
.23415 .51566 .24281 .52341 .25624 .51245 .24707 .51144 Metetra
.911 .909 .806 r
.24707 .51144 .25624 .51245 .27058 .48988 .26114 .49369 Metetra
.945 .952 .741 r
.26114 .49369 .27058 .48988 .28484 .46735 .27551 .47136 Metetra
.942 .958 .739 r
.27551 .47136 .28484 .46735 .29899 .4452 .28978 .44936 Metetra
.936 .966 .739 r
.28978 .44936 .29899 .4452 .31303 .42375 .30394 .42804 Metetra
.925 .974 .741 r
.30394 .42804 .31303 .42375 .32693 .4033 .31796 .4077 Metetra
.907 .984 .745 r
.31796 .4077 .32693 .4033 .34069 .38415 .33184 .38863 Metetra
.879 .991 .749 r
.33184 .38863 .34069 .38415 .35431 .36653 .34558 .37107 Metetra
.835 .994 .751 r
.34558 .37107 .35431 .36653 .36781 .35068 .35919 .35526 Metetra
.768 .986 .747 r
.35919 .35526 .36781 .35068 .38118 .33678 .37268 .34138 Metetra
.667 .956 .729 r
.37268 .34138 .38118 .33678 .39446 .32499 .38606 .32959 Metetra
.524 .891 .688 r
.38606 .32959 .39446 .32499 .40765 .31541 .39936 .32001 Metetra
.39936 .32001 .40765 .31541 .42079 .30813 .4126 .31271 Metetra
.4126 .31271 .42079 .30813 .4339 .30321 .42581 .30776 Metetra
.07 0 0 r
.42581 .30776 .4339 .30321 .44702 .30064 .43901 .30515 Metetra
.24 0 0 r
.43901 .30515 .44702 .30064 .46016 .3004 .45225 .30487 Metetra
.372 0 0 r
.45225 .30487 .46016 .3004 .47338 .30244 .46554 .30684 Metetra
.471 0 0 r
.46554 .30684 .47338 .30244 .48668 .30666 .47893 .31098 Metetra
.544 .007 0 r
.47893 .31098 .48668 .30666 .50012 .31292 .49244 .31716 Metetra
.597 .069 0 r
.49244 .31716 .50012 .31292 .51371 .32106 .5061 .32519 Metetra
.635 .114 0 r
.5061 .32519 .51371 .32106 .52748 .33088 .51994 .33488 Metetra
.662 .146 .001 r
.51994 .33488 .52748 .33088 .54146 .34215 .53398 .34599 Metetra
.681 .167 .009 r
.53398 .34599 .54146 .34215 .55567 .35458 .54825 .35824 Metetra
.692 .179 .009 r
.54825 .35824 .55567 .35458 .57011 .36789 .56275 .37134 Metetra
.697 .183 .002 r
.56275 .37134 .57011 .36789 .5848 .38176 .5775 .38497 Metetra
.693 .173 0 r
.5775 .38497 .5848 .38176 .59974 .39585 .59249 .39857 Metetra
.59249 .39857 .59974 .39585 .61473 .40264 .60726 .39375 Metetra
.646 .762 .934 r
.60726 .39375 .61473 .40264 .62952 .39783 .62211 .3889 Metetra
.646 .762 .934 r
.62211 .3889 .62952 .39783 .6444 .393 .63704 .38402 Metetra
.646 .762 .934 r
.63704 .38402 .6444 .393 .65935 .38815 .65205 .37911 Metetra
.646 .762 .934 r
.65205 .37911 .65935 .38815 .67438 .38327 .66713 .37418 Metetra
.646 .762 .934 r
.66713 .37418 .67438 .38327 .68949 .37836 .6823 .36923 Metetra
.646 .762 .934 r
.6823 .36923 .68949 .37836 .70469 .37342 .69755 .36424 Metetra
.646 .762 .934 r
.69755 .36424 .70469 .37342 .71997 .36846 .71289 .35923 Metetra
.646 .762 .934 r
.71289 .35923 .71997 .36846 .73532 .36348 .7283 .3542 Metetra
.646 .762 .934 r
.7283 .3542 .73532 .36348 .75077 .35846 .7438 .34913 Metetra
.646 .762 .934 r
.7438 .34913 .75077 .35846 .76629 .35342 .75939 .34404 Metetra
.646 .762 .934 r
.75939 .34404 .76629 .35342 .7819 .34835 .77506 .33892 Metetra
.646 .762 .934 r
.08693 .55338 .09606 .56078 .10831 .55678 .09921 .54934 Metetra
.646 .762 .934 r
.09921 .54934 .10831 .55678 .12062 .55276 .11155 .54528 Metetra
.646 .762 .934 r
.11155 .54528 .12062 .55276 .13298 .54872 .12396 .5412 Metetra
.646 .762 .934 r
.12396 .5412 .13298 .54872 .14541 .54466 .13642 .53711 Metetra
.646 .762 .934 r
.13642 .53711 .14541 .54466 .1579 .54057 .14894 .53299 Metetra
.646 .762 .934 r
.14894 .53299 .1579 .54057 .17046 .53647 .16153 .52885 Metetra
.646 .762 .934 r
.16153 .52885 .17046 .53647 .18307 .53235 .17418 .52469 Metetra
.646 .762 .934 r
.17418 .52469 .18307 .53235 .19574 .52821 .18689 .52051 Metetra
.646 .762 .934 r
.18689 .52051 .19574 .52821 .20848 .52405 .19966 .51631 Metetra
.646 .762 .934 r
.19966 .51631 .20848 .52405 .22128 .51987 .2125 .51209 Metetra
.646 .762 .934 r
.2125 .51209 .22128 .51987 .23415 .51566 .2254 .50785 Metetra
.646 .762 .934 r
.2254 .50785 .23415 .51566 .24707 .51144 .23837 .50358 Metetra
.693 .774 .914 r
.23837 .50358 .24707 .51144 .26114 .49369 .25152 .49779 Metetra
.941 .958 .742 r
.25152 .49779 .26114 .49369 .27551 .47136 .26601 .47571 Metetra
.937 .964 .739 r
.26601 .47571 .27551 .47136 .28978 .44936 .28039 .45395 Metetra
.93 .971 .738 r
.28039 .45395 .28978 .44936 .30394 .42804 .29466 .43283 Metetra
.916 .979 .737 r
.29466 .43283 .30394 .42804 .31796 .4077 .3088 .41266 Metetra
.895 .987 .738 r
.3088 .41266 .31796 .4077 .33184 .38863 .3228 .39371 Metetra
.862 .992 .737 r
.3228 .39371 .33184 .38863 .34558 .37107 .33667 .37626 Metetra
.81 .989 .733 r
.33667 .37626 .34558 .37107 .35919 .35526 .35039 .36053 Metetra
.733 .972 .719 r
.35039 .36053 .35919 .35526 .37268 .34138 .364 .34671 Metetra
.621 .93 .69 r
.364 .34671 .37268 .34138 .38606 .32959 .37749 .33495 Metetra
.469 .852 .636 r
.37749 .33495 .38606 .32959 .39936 .32001 .3909 .32537 Metetra
.3909 .32537 .39936 .32001 .4126 .31271 .40424 .31807 Metetra
.40424 .31807 .4126 .31271 .42581 .30776 .41755 .31309 Metetra
.104 0 0 r
.41755 .31309 .42581 .30776 .43901 .30515 .43085 .31044 Metetra
.26 0 0 r
.43085 .31044 .43901 .30515 .45225 .30487 .44417 .31009 Metetra
.382 0 0 r
.44417 .31009 .45225 .30487 .46554 .30684 .45755 .31198 Metetra
.474 0 0 r
.45755 .31198 .46554 .30684 .47893 .31098 .47102 .31602 Metetra
.542 .014 0 r
.47102 .31602 .47893 .31098 .49244 .31716 .48461 .32206 Metetra
.593 .071 0 r
.48461 .32206 .49244 .31716 .5061 .32519 .49834 .32994 Metetra
.629 .113 0 r
.49834 .32994 .5061 .32519 .51994 .33488 .51226 .33945 Metetra
.656 .143 .012 r
.51226 .33945 .51994 .33488 .53398 .34599 .52637 .35034 Metetra
.674 .163 .017 r
.52637 .35034 .53398 .34599 .54825 .35824 .5407 .36235 Metetra
.685 .173 .014 r
.5407 .36235 .54825 .35824 .56275 .37134 .55526 .37516 Metetra
.69 .175 .005 r
.55526 .37516 .56275 .37134 .5775 .38497 .57007 .38847 Metetra
.273 0 0 r
.57007 .38847 .5775 .38497 .59249 .39857 .5849 .38964 Metetra
.646 .762 .934 r
.5849 .38964 .59249 .39857 .60726 .39375 .59973 .38477 Metetra
.646 .762 .934 r
.59973 .38477 .60726 .39375 .62211 .3889 .61463 .37987 Metetra
.646 .762 .934 r
.61463 .37987 .62211 .3889 .63704 .38402 .62961 .37494 Metetra
.646 .762 .934 r
.62961 .37494 .63704 .38402 .65205 .37911 .64467 .36999 Metetra
.646 .762 .934 r
.64467 .36999 .65205 .37911 .66713 .37418 .65981 .36501 Metetra
.646 .762 .934 r
.65981 .36501 .66713 .37418 .6823 .36923 .67504 .36001 Metetra
.646 .762 .934 r
.67504 .36001 .6823 .36923 .69755 .36424 .69035 .35497 Metetra
.646 .762 .934 r
.69035 .35497 .69755 .36424 .71289 .35923 .70574 .34991 Metetra
.646 .762 .934 r
.70574 .34991 .71289 .35923 .7283 .3542 .72121 .34483 Metetra
.646 .762 .934 r
.72121 .34483 .7283 .3542 .7438 .34913 .73677 .33971 Metetra
.646 .762 .934 r
.73677 .33971 .7438 .34913 .75939 .34404 .75241 .33457 Metetra
.646 .762 .934 r
.75241 .33457 .75939 .34404 .77506 .33892 .76814 .32939 Metetra
.646 .762 .934 r
.07772 .54591 .08693 .55338 .09921 .54934 .09003 .54183 Metetra
.646 .762 .934 r
.09003 .54183 .09921 .54934 .11155 .54528 .10241 .53774 Metetra
.646 .762 .934 r
.10241 .53774 .11155 .54528 .12396 .5412 .11485 .53362 Metetra
.646 .762 .934 r
.11485 .53362 .12396 .5412 .13642 .53711 .12734 .52949 Metetra
.646 .762 .934 r
.12734 .52949 .13642 .53711 .14894 .53299 .1399 .52533 Metetra
.646 .762 .934 r
.1399 .52533 .14894 .53299 .16153 .52885 .15252 .52115 Metetra
.646 .762 .934 r
.15252 .52115 .16153 .52885 .17418 .52469 .16521 .51696 Metetra
.646 .762 .934 r
.16521 .51696 .17418 .52469 .18689 .52051 .17795 .51274 Metetra
.646 .762 .934 r
.17795 .51274 .18689 .52051 .19966 .51631 .19076 .5085 Metetra
.646 .762 .934 r
.19076 .5085 .19966 .51631 .2125 .51209 .20364 .50424 Metetra
.646 .762 .934 r
.20364 .50424 .2125 .51209 .2254 .50785 .21658 .49996 Metetra
.646 .762 .934 r
.21658 .49996 .2254 .50785 .23837 .50358 .22958 .49566 Metetra
.646 .762 .934 r
.22958 .49566 .23837 .50358 .25152 .49779 .24265 .49133 Metetra
.807 .823 .864 r
.24265 .49133 .25152 .49779 .26601 .47571 .25633 .4803 Metetra
.932 .969 .741 r
.25633 .4803 .26601 .47571 .28039 .45395 .27082 .45884 Metetra
.923 .976 .738 r
.27082 .45884 .28039 .45395 .29466 .43283 .28521 .43798 Metetra
.907 .983 .735 r
.28521 .43798 .29466 .43283 .3088 .41266 .29947 .41803 Metetra
.882 .989 .732 r
.29947 .41803 .3088 .41266 .3228 .39371 .31358 .39928 Metetra
.844 .99 .727 r
.31358 .39928 .3228 .39371 .33667 .37626 .32757 .38198 Metetra
.786 .982 .717 r
.32757 .38198 .33667 .37626 .35039 .36053 .34141 .36636 Metetra
.701 .957 .695 r
.34141 .36636 .35039 .36053 .364 .34671 .35513 .35263 Metetra
.58 .905 .656 r
.35513 .35263 .364 .34671 .37749 .33495 .36874 .34092 Metetra
.423 .817 .594 r
.36874 .34092 .37749 .33495 .3909 .32537 .38226 .33138 Metetra
.38226 .33138 .3909 .32537 .40424 .31807 .39571 .32408 Metetra
.39571 .32408 .40424 .31807 .41755 .31309 .40912 .31907 Metetra
.127 0 0 r
.40912 .31907 .41755 .31309 .43085 .31044 .42252 .31637 Metetra
.272 0 0 r
.42252 .31637 .43085 .31044 .44417 .31009 .43594 .31594 Metetra
.386 0 0 r
.43594 .31594 .44417 .31009 .45755 .31198 .44941 .31772 Metetra
.473 0 0 r
.44941 .31772 .45755 .31198 .47102 .31602 .46296 .32162 Metetra
.538 .015 0 r
.46296 .32162 .47102 .31602 .48461 .32206 .47663 .3275 Metetra
.586 .069 0 r
.47663 .3275 .48461 .32206 .49834 .32994 .49044 .33518 Metetra
.622 .109 .006 r
.49044 .33518 .49834 .32994 .51226 .33945 .50443 .34445 Metetra
.648 .137 .016 r
.50443 .34445 .51226 .33945 .52637 .35034 .51861 .35507 Metetra
.665 .155 .019 r
.51861 .35507 .52637 .35034 .5407 .36235 .53301 .36676 Metetra
.676 .164 .014 r
.53301 .36676 .5407 .36235 .55526 .37516 .54765 .37923 Metetra
.516 0 0 r
.54765 .37923 .55526 .37516 .57007 .38847 .56244 .38552 Metetra
.557 .894 .983 r
.56244 .38552 .57007 .38847 .5849 .38964 .57724 .38063 Metetra
.646 .762 .934 r
.57724 .38063 .5849 .38964 .59973 .38477 .59211 .3757 Metetra
.646 .762 .934 r
.59211 .3757 .59973 .38477 .61463 .37987 .60707 .37076 Metetra
.646 .762 .934 r
.60707 .37076 .61463 .37987 .62961 .37494 .6221 .36578 Metetra
.646 .762 .934 r
.6221 .36578 .62961 .37494 .64467 .36999 .63722 .36078 Metetra
.646 .762 .934 r
.63722 .36078 .64467 .36999 .65981 .36501 .65242 .35575 Metetra
.646 .762 .934 r
.65242 .35575 .65981 .36501 .67504 .36001 .6677 .35069 Metetra
.646 .762 .934 r
.6677 .35069 .67504 .36001 .69035 .35497 .68307 .34561 Metetra
.646 .762 .934 r
.68307 .34561 .69035 .35497 .70574 .34991 .69851 .3405 Metetra
.646 .762 .934 r
.69851 .3405 .70574 .34991 .72121 .34483 .71405 .33536 Metetra
.646 .762 .934 r
.71405 .33536 .72121 .34483 .73677 .33971 .72967 .33019 Metetra
.646 .762 .934 r
.72967 .33019 .73677 .33971 .75241 .33457 .74537 .325 Metetra
.646 .762 .934 r
.74537 .325 .75241 .33457 .76814 .32939 .76116 .31977 Metetra
.646 .762 .934 r
.06842 .53837 .07772 .54591 .09003 .54183 .08077 .53426 Metetra
.646 .762 .934 r
.08077 .53426 .09003 .54183 .10241 .53774 .09318 .53012 Metetra
.646 .762 .934 r
.09318 .53012 .10241 .53774 .11485 .53362 .10565 .52597 Metetra
.646 .762 .934 r
.10565 .52597 .11485 .53362 .12734 .52949 .11819 .5218 Metetra
.646 .762 .934 r
.11819 .5218 .12734 .52949 .1399 .52533 .13078 .51761 Metetra
.646 .762 .934 r
.13078 .51761 .1399 .52533 .15252 .52115 .14344 .51339 Metetra
.646 .762 .934 r
.14344 .51339 .15252 .52115 .16521 .51696 .15616 .50916 Metetra
.646 .762 .934 r
.15616 .50916 .16521 .51696 .17795 .51274 .16894 .5049 Metetra
.646 .762 .934 r
.16894 .5049 .17795 .51274 .19076 .5085 .18178 .50062 Metetra
.646 .762 .934 r
.18178 .50062 .19076 .5085 .20364 .50424 .1947 .49632 Metetra
.646 .762 .934 r
.1947 .49632 .20364 .50424 .21658 .49996 .20767 .492 Metetra
.646 .762 .934 r
.20767 .492 .21658 .49996 .22958 .49566 .22071 .48766 Metetra
.646 .762 .934 r
.22071 .48766 .22958 .49566 .24265 .49133 .23382 .48329 Metetra
.646 .762 .934 r
.23382 .48329 .24265 .49133 .25633 .4803 .24699 .47891 Metetra
.884 .927 .845 r
.24699 .47891 .25633 .4803 .27082 .45884 .26108 .46389 Metetra
.916 .98 .74 r
.26108 .46389 .27082 .45884 .28521 .43798 .27558 .44336 Metetra
.898 .986 .735 r
.27558 .44336 .28521 .43798 .29947 .41803 .28995 .42369 Metetra
.87 .99 .729 r
.28995 .42369 .29947 .41803 .31358 .39928 .30418 .40518 Metetra
.827 .988 .721 r
.30418 .40518 .31358 .39928 .32757 .38198 .31828 .38808 Metetra
.764 .975 .705 r
.31828 .38808 .32757 .38198 .34141 .36636 .33224 .37262 Metetra
.672 .943 .676 r
.33224 .37262 .34141 .36636 .35513 .35263 .34608 .35901 Metetra
.546 .883 .63 r
.34608 .35901 .35513 .35263 .36874 .34092 .3598 .34739 Metetra
.3598 .34739 .36874 .34092 .38226 .33138 .37344 .33789 Metetra
.37344 .33789 .38226 .33138 .39571 .32408 .387 .3306 Metetra
.387 .3306 .39571 .32408 .40912 .31907 .40051 .32557 Metetra
.141 0 0 r
.40051 .32557 .40912 .31907 .42252 .31637 .41401 .3228 Metetra
.277 0 0 r
.41401 .3228 .42252 .31637 .43594 .31594 .42753 .32228 Metetra
.385 0 0 r
.42753 .32228 .43594 .31594 .44941 .31772 .4411 .32393 Metetra
.468 0 0 r
.4411 .32393 .44941 .31772 .46296 .32162 .45474 .32767 Metetra
.531 .011 0 r
.45474 .32767 .46296 .32162 .47663 .3275 .4685 .33333 Metetra
.578 .062 0 r
.4685 .33333 .47663 .3275 .49044 .33518 .48239 .34077 Metetra
.613 .1 .006 r
.48239 .34077 .49044 .33518 .50443 .34445 .49646 .34975 Metetra
.638 .127 .014 r
.49646 .34975 .50443 .34445 .51861 .35507 .51072 .36004 Metetra
.656 .144 .015 r
.51072 .36004 .51861 .35507 .53301 .36676 .52519 .37136 Metetra
.624 .099 0 r
.52519 .37136 .53301 .36676 .54765 .37923 .53988 .38138 Metetra
.255 .756 .708 r
.53988 .38138 .54765 .37923 .56244 .38552 .55465 .37646 Metetra
.646 .762 .934 r
.55465 .37646 .56244 .38552 .57724 .38063 .5695 .37152 Metetra
.646 .762 .934 r
.5695 .37152 .57724 .38063 .59211 .3757 .58443 .36655 Metetra
.646 .762 .934 r
.58443 .36655 .59211 .3757 .60707 .37076 .59944 .36155 Metetra
.646 .762 .934 r
.59944 .36155 .60707 .37076 .6221 .36578 .61453 .35653 Metetra
.646 .762 .934 r
.61453 .35653 .6221 .36578 .63722 .36078 .6297 .35147 Metetra
.646 .762 .934 r
.6297 .35147 .63722 .36078 .65242 .35575 .64495 .34639 Metetra
.646 .762 .934 r
.64495 .34639 .65242 .35575 .6677 .35069 .66029 .34129 Metetra
.646 .762 .934 r
.66029 .34129 .6677 .35069 .68307 .34561 .67571 .33615 Metetra
.646 .762 .934 r
.67571 .33615 .68307 .34561 .69851 .3405 .69122 .33099 Metetra
.646 .762 .934 r
.69122 .33099 .69851 .3405 .71405 .33536 .70681 .3258 Metetra
.646 .762 .934 r
.70681 .3258 .71405 .33536 .72967 .33019 .72249 .32058 Metetra
.646 .762 .934 r
.72249 .32058 .72967 .33019 .74537 .325 .73825 .31533 Metetra
.646 .762 .934 r
.73825 .31533 .74537 .325 .76116 .31977 .7541 .31005 Metetra
.646 .762 .934 r
.05905 .53076 .06842 .53837 .08077 .53426 .07143 .52661 Metetra
.646 .762 .934 r
.07143 .52661 .08077 .53426 .09318 .53012 .08387 .52244 Metetra
.646 .762 .934 r
.08387 .52244 .09318 .53012 .10565 .52597 .09638 .51825 Metetra
.646 .762 .934 r
.09638 .51825 .10565 .52597 .11819 .5218 .10894 .51404 Metetra
.646 .762 .934 r
.10894 .51404 .11819 .5218 .13078 .51761 .12157 .50981 Metetra
.646 .762 .934 r
.12157 .50981 .13078 .51761 .14344 .51339 .13426 .50556 Metetra
.646 .762 .934 r
.13426 .50556 .14344 .51339 .15616 .50916 .14702 .50128 Metetra
.646 .762 .934 r
.14702 .50128 .15616 .50916 .16894 .5049 .15984 .49698 Metetra
.646 .762 .934 r
.15984 .49698 .16894 .5049 .18178 .50062 .17272 .49267 Metetra
.646 .762 .934 r
.17272 .49267 .18178 .50062 .1947 .49632 .18567 .48833 Metetra
.646 .762 .934 r
.18567 .48833 .1947 .49632 .20767 .492 .19868 .48397 Metetra
.646 .762 .934 r
.19868 .48397 .20767 .492 .22071 .48766 .21176 .47958 Metetra
.646 .762 .934 r
.21176 .47958 .22071 .48766 .23382 .48329 .22491 .47518 Metetra
.646 .762 .934 r
.22491 .47518 .23382 .48329 .24699 .47891 .23812 .47075 Metetra
.646 .762 .934 r
.23812 .47075 .24699 .47891 .26108 .46389 .2514 .4663 Metetra
.903 .977 .801 r
.2514 .4663 .26108 .46389 .27558 .44336 .26578 .44882 Metetra
.89 .988 .738 r
.26578 .44882 .27558 .44336 .28995 .42369 .28026 .4295 Metetra
.859 .99 .73 r
.28026 .4295 .28995 .42369 .30418 .40518 .2946 .41128 Metetra
.813 .986 .718 r
.2946 .41128 .30418 .40518 .31828 .38808 .30882 .39442 Metetra
.745 .969 .697 r
.30882 .39442 .31828 .38808 .33224 .37262 .3229 .37917 Metetra
.649 .932 .664 r
.3229 .37917 .33224 .37262 .34608 .35901 .33685 .3657 Metetra
.52 .867 .613 r
.33685 .3657 .34608 .35901 .3598 .34739 .35069 .35419 Metetra
.35069 .35419 .3598 .34739 .37344 .33789 .36443 .34475 Metetra
.36443 .34475 .37344 .33789 .387 .3306 .37811 .33748 Metetra
.37811 .33748 .387 .3306 .40051 .32557 .39173 .33243 Metetra
.146 0 0 r
.39173 .33243 .40051 .32557 .41401 .3228 .40534 .3296 Metetra
.277 0 0 r
.40534 .3296 .41401 .3228 .42753 .32228 .41896 .32896 Metetra
.38 0 0 r
.41896 .32896 .42753 .32228 .4411 .32393 .43262 .33047 Metetra
.46 0 0 r
.43262 .33047 .4411 .32393 .45474 .32767 .44636 .334 Metetra
.521 .003 0 r
.44636 .334 .45474 .32767 .4685 .33333 .46021 .33942 Metetra
.568 .052 0 r
.46021 .33942 .4685 .33333 .48239 .34077 .47419 .34656 Metetra
.602 .088 0 r
.47419 .34656 .48239 .34077 .49646 .34975 .48834 .3552 Metetra
.627 .114 .006 r
.48834 .3552 .49646 .34975 .51072 .36004 .50267 .3651 Metetra
.644 .129 .004 r
.50267 .3651 .51072 .36004 .52519 .37136 .51722 .37598 Metetra
.51722 .37598 .52519 .37136 .53988 .38138 .53196 .37228 Metetra
.646 .762 .934 r
.53196 .37228 .53988 .38138 .55465 .37646 .54678 .36731 Metetra
.646 .762 .934 r
.54678 .36731 .55465 .37646 .5695 .37152 .56168 .36232 Metetra
.646 .762 .934 r
.56168 .36232 .5695 .37152 .58443 .36655 .57666 .3573 Metetra
.646 .762 .934 r
.57666 .3573 .58443 .36655 .59944 .36155 .59173 .35225 Metetra
.646 .762 .934 r
.59173 .35225 .59944 .36155 .61453 .35653 .60687 .34718 Metetra
.646 .762 .934 r
.60687 .34718 .61453 .35653 .6297 .35147 .6221 .34207 Metetra
.646 .762 .934 r
.6221 .34207 .6297 .35147 .64495 .34639 .63741 .33694 Metetra
.646 .762 .934 r
.63741 .33694 .64495 .34639 .66029 .34129 .6528 .33178 Metetra
.646 .762 .934 r
.6528 .33178 .66029 .34129 .67571 .33615 .66828 .3266 Metetra
.646 .762 .934 r
.66828 .3266 .67571 .33615 .69122 .33099 .68385 .32138 Metetra
.646 .762 .934 r
.68385 .32138 .69122 .33099 .70681 .3258 .6995 .31614 Metetra
.646 .762 .934 r
.6995 .31614 .70681 .3258 .72249 .32058 .71524 .31086 Metetra
.646 .762 .934 r
.71524 .31086 .72249 .32058 .73825 .31533 .73106 .30556 Metetra
.646 .762 .934 r
.73106 .30556 .73825 .31533 .7541 .31005 .74698 .30023 Metetra
.646 .762 .934 r
.04958 .52308 .05905 .53076 .07143 .52661 .062 .5189 Metetra
.646 .762 .934 r
.062 .5189 .07143 .52661 .08387 .52244 .07448 .51469 Metetra
.646 .762 .934 r
.07448 .51469 .08387 .52244 .09638 .51825 .08701 .51046 Metetra
.646 .762 .934 r
.08701 .51046 .09638 .51825 .10894 .51404 .09962 .50621 Metetra
.646 .762 .934 r
.09962 .50621 .10894 .51404 .12157 .50981 .11228 .50194 Metetra
.646 .762 .934 r
.11228 .50194 .12157 .50981 .13426 .50556 .12501 .49765 Metetra
.646 .762 .934 r
.12501 .49765 .13426 .50556 .14702 .50128 .1378 .49333 Metetra
.646 .762 .934 r
.1378 .49333 .14702 .50128 .15984 .49698 .15065 .489 Metetra
.646 .762 .934 r
.15065 .489 .15984 .49698 .17272 .49267 .16357 .48464 Metetra
.646 .762 .934 r
.16357 .48464 .17272 .49267 .18567 .48833 .17656 .48026 Metetra
.646 .762 .934 r
.17656 .48026 .18567 .48833 .19868 .48397 .18961 .47586 Metetra
.646 .762 .934 r
.18961 .47586 .19868 .48397 .21176 .47958 .20273 .47143 Metetra
.646 .762 .934 r
.20273 .47143 .21176 .47958 .22491 .47518 .21591 .46699 Metetra
.646 .762 .934 r
.21591 .46699 .22491 .47518 .23812 .47075 .22916 .46252 Metetra
.646 .762 .934 r
.22916 .46252 .23812 .47075 .2514 .4663 .24248 .45803 Metetra
.646 .762 .934 r
.24248 .45803 .2514 .4663 .26578 .44882 .25587 .45351 Metetra
.883 .992 .762 r
.25587 .45351 .26578 .44882 .28026 .4295 .27039 .4353 Metetra
.851 .991 .734 r
.27039 .4353 .28026 .4295 .2946 .41128 .28485 .41743 Metetra
.802 .985 .719 r
.28485 .41743 .2946 .41128 .30882 .39442 .29918 .40086 Metetra
.731 .965 .696 r
.29918 .40086 .30882 .39442 .3229 .37917 .31337 .38584 Metetra
.633 .925 .659 r
.31337 .38584 .3229 .37917 .33685 .3657 .32744 .37256 Metetra
.502 .857 .605 r
.32744 .37256 .33685 .3657 .35069 .35419 .34139 .36118 Metetra
.34139 .36118 .35069 .35419 .36443 .34475 .35525 .35183 Metetra
.35525 .35183 .36443 .34475 .37811 .33748 .36904 .34458 Metetra
.36904 .34458 .37811 .33748 .39173 .33243 .38277 .33951 Metetra
.145 0 0 r
.38277 .33951 .39173 .33243 .40534 .3296 .39649 .3366 Metetra
.271 0 0 r
.39649 .3366 .40534 .3296 .41896 .32896 .41021 .33584 Metetra
.371 0 0 r
.41021 .33584 .41896 .32896 .43262 .33047 .42398 .33717 Metetra
.449 0 0 r
.42398 .33717 .43262 .33047 .44636 .334 .43781 .34047 Metetra
.509 0 0 r
.43781 .34047 .44636 .334 .46021 .33942 .45175 .34561 Metetra
.555 .037 0 r
.45175 .34561 .46021 .33942 .47419 .34656 .46583 .35241 Metetra
.589 .072 0 r
.46583 .35241 .47419 .34656 .48834 .3552 .48006 .36066 Metetra
.614 .096 0 r
.48006 .36066 .48834 .3552 .50267 .3651 .49448 .37012 Metetra
.124 0 0 r
.49448 .37012 .50267 .3651 .51722 .37598 .50917 .36808 Metetra
.642 .794 .955 r
.50917 .36808 .51722 .37598 .53196 .37228 .52396 .36309 Metetra
.646 .762 .934 r
.52396 .36309 .53196 .37228 .54678 .36731 .53883 .35807 Metetra
.646 .762 .934 r
.53883 .35807 .54678 .36731 .56168 .36232 .55379 .35303 Metetra
.646 .762 .934 r
.55379 .35303 .56168 .36232 .57666 .3573 .56882 .34796 Metetra
.646 .762 .934 r
.56882 .34796 .57666 .3573 .59173 .35225 .58394 .34286 Metetra
.646 .762 .934 r
.58394 .34286 .59173 .35225 .60687 .34718 .59914 .33773 Metetra
.646 .762 .934 r
.59914 .33773 .60687 .34718 .6221 .34207 .61442 .33258 Metetra
.646 .762 .934 r
.61442 .33258 .6221 .34207 .63741 .33694 .62979 .3274 Metetra
.646 .762 .934 r
.62979 .3274 .63741 .33694 .6528 .33178 .64524 .32219 Metetra
.646 .762 .934 r
.64524 .32219 .6528 .33178 .66828 .3266 .66078 .31695 Metetra
.646 .762 .934 r
.66078 .31695 .66828 .3266 .68385 .32138 .6764 .31168 Metetra
.646 .762 .934 r
.6764 .31168 .68385 .32138 .6995 .31614 .69211 .30638 Metetra
.646 .762 .934 r
.69211 .30638 .6995 .31614 .71524 .31086 .70791 .30105 Metetra
.646 .762 .934 r
.70791 .30105 .71524 .31086 .73106 .30556 .7238 .29569 Metetra
.646 .762 .934 r
.7238 .29569 .73106 .30556 .74698 .30023 .73977 .2903 Metetra
.646 .762 .934 r
.04004 .51534 .04958 .52308 .062 .5189 .05248 .51111 Metetra
.646 .762 .934 r
.05248 .51111 .062 .5189 .07448 .51469 .06499 .50687 Metetra
.646 .762 .934 r
.06499 .50687 .07448 .51469 .08701 .51046 .07757 .5026 Metetra
.646 .762 .934 r
.07757 .5026 .08701 .51046 .09962 .50621 .0902 .49831 Metetra
.646 .762 .934 r
.0902 .49831 .09962 .50621 .11228 .50194 .1029 .494 Metetra
.646 .762 .934 r
.1029 .494 .11228 .50194 .12501 .49765 .11566 .48967 Metetra
.646 .762 .934 r
.11566 .48967 .12501 .49765 .1378 .49333 .12849 .48531 Metetra
.646 .762 .934 r
.12849 .48531 .1378 .49333 .15065 .489 .14138 .48094 Metetra
.646 .762 .934 r
.14138 .48094 .15065 .489 .16357 .48464 .15434 .47654 Metetra
.646 .762 .934 r
.15434 .47654 .16357 .48464 .17656 .48026 .16736 .47212 Metetra
.646 .762 .934 r
.16736 .47212 .17656 .48026 .18961 .47586 .18045 .46767 Metetra
.646 .762 .934 r
.18045 .46767 .18961 .47586 .20273 .47143 .19361 .46321 Metetra
.646 .762 .934 r
.19361 .46321 .20273 .47143 .21591 .46699 .20683 .45872 Metetra
.646 .762 .934 r
.20683 .45872 .21591 .46699 .22916 .46252 .22012 .45421 Metetra
.646 .762 .934 r
.22012 .45421 .22916 .46252 .24248 .45803 .23348 .44967 Metetra
.646 .762 .934 r
.23348 .44967 .24248 .45803 .25587 .45351 .24691 .44511 Metetra
.646 .762 .934 r
.24691 .44511 .25587 .45351 .27039 .4353 .26041 .44053 Metetra
.845 .995 .754 r
.26041 .44053 .27039 .4353 .28485 .41743 .27493 .42347 Metetra
.794 .986 .726 r
.27493 .42347 .28485 .41743 .29918 .40086 .28937 .40724 Metetra
.722 .965 .701 r
.28937 .40724 .29918 .40086 .31337 .38584 .30367 .3925 Metetra
.623 .923 .662 r
.30367 .3925 .31337 .38584 .32744 .37256 .31785 .37943 Metetra
.493 .853 .607 r
.31785 .37943 .32744 .37256 .34139 .36118 .33192 .36821 Metetra
.33192 .36821 .34139 .36118 .35525 .35183 .3459 .35895 Metetra
.3459 .35895 .35525 .35183 .36904 .34458 .35979 .35174 Metetra
.35979 .35174 .36904 .34458 .38277 .33951 .37364 .34664 Metetra
.137 0 0 r
.37364 .34664 .38277 .33951 .39649 .3366 .38747 .34366 Metetra
.26 0 0 r
.38747 .34366 .39649 .3366 .41021 .33584 .4013 .34276 Metetra
.358 0 0 r
.4013 .34276 .41021 .33584 .42398 .33717 .41517 .34388 Metetra
.435 0 0 r
.41517 .34388 .42398 .33717 .43781 .34047 .4291 .34693 Metetra
.495 0 0 r
.4291 .34693 .43781 .34047 .45175 .34561 .44314 .35175 Metetra
.54 .018 0 r
.44314 .35175 .45175 .34561 .46583 .35241 .45731 .35817 Metetra
.574 .052 0 r
.45731 .35817 .46583 .35241 .48006 .36066 .47163 .36598 Metetra
.127 0 0 r
.47163 .36598 .48006 .36066 .49448 .37012 .48627 .36386 Metetra
.631 .837 .979 r
.48627 .36386 .49448 .37012 .50917 .36808 .50103 .35885 Metetra
.646 .762 .934 r
.50103 .35885 .50917 .36808 .52396 .36309 .51588 .35381 Metetra
.646 .762 .934 r
.51588 .35381 .52396 .36309 .53883 .35807 .5308 .34874 Metetra
.646 .762 .934 r
.5308 .34874 .53883 .35807 .55379 .35303 .54581 .34365 Metetra
.646 .762 .934 r
.54581 .34365 .55379 .35303 .56882 .34796 .5609 .33853 Metetra
.646 .762 .934 r
.5609 .33853 .56882 .34796 .58394 .34286 .57607 .33338 Metetra
.646 .762 .934 r
.57607 .33338 .58394 .34286 .59914 .33773 .59133 .3282 Metetra
.646 .762 .934 r
.59133 .3282 .59914 .33773 .61442 .33258 .60667 .32299 Metetra
.646 .762 .934 r
.60667 .32299 .61442 .33258 .62979 .3274 .62209 .31775 Metetra
.646 .762 .934 r
.62209 .31775 .62979 .3274 .64524 .32219 .6376 .31249 Metetra
.646 .762 .934 r
.6376 .31249 .64524 .32219 .66078 .31695 .6532 .30719 Metetra
.646 .762 .934 r
.6532 .30719 .66078 .31695 .6764 .31168 .66888 .30187 Metetra
.646 .762 .934 r
.66888 .30187 .6764 .31168 .69211 .30638 .68465 .29652 Metetra
.646 .762 .934 r
.68465 .29652 .69211 .30638 .70791 .30105 .70051 .29113 Metetra
.646 .762 .934 r
.70051 .29113 .70791 .30105 .7238 .29569 .71646 .28572 Metetra
.646 .762 .934 r
.71646 .28572 .7238 .29569 .73977 .2903 .7325 .28028 Metetra
.646 .762 .934 r
.0304 .50752 .04004 .51534 .05248 .51111 .04288 .50326 Metetra
.646 .762 .934 r
.04288 .50326 .05248 .51111 .06499 .50687 .05542 .49897 Metetra
.646 .762 .934 r
.05542 .49897 .06499 .50687 .07757 .5026 .06803 .49466 Metetra
.646 .762 .934 r
.06803 .49466 .07757 .5026 .0902 .49831 .0807 .49033 Metetra
.646 .762 .934 r
.0807 .49033 .0902 .49831 .1029 .494 .09343 .48598 Metetra
.646 .762 .934 r
.09343 .48598 .1029 .494 .11566 .48967 .10623 .48161 Metetra
.646 .762 .934 r
.10623 .48161 .11566 .48967 .12849 .48531 .1191 .47722 Metetra
.646 .762 .934 r
.1191 .47722 .12849 .48531 .14138 .48094 .13202 .4728 Metetra
.646 .762 .934 r
.13202 .4728 .14138 .48094 .15434 .47654 .14502 .46836 Metetra
.646 .762 .934 r
.14502 .46836 .15434 .47654 .16736 .47212 .15808 .4639 Metetra
.646 .762 .934 r
.15808 .4639 .16736 .47212 .18045 .46767 .17121 .45941 Metetra
.646 .762 .934 r
.17121 .45941 .18045 .46767 .19361 .46321 .1844 .4549 Metetra
.646 .762 .934 r
.1844 .4549 .19361 .46321 .20683 .45872 .19766 .45037 Metetra
.646 .762 .934 r
.19766 .45037 .20683 .45872 .22012 .45421 .21099 .44582 Metetra
.646 .762 .934 r
.21099 .44582 .22012 .45421 .23348 .44967 .22439 .44124 Metetra
.646 .762 .934 r
.22439 .44124 .23348 .44967 .24691 .44511 .23786 .43664 Metetra
.646 .762 .934 r
.23786 .43664 .24691 .44511 .26041 .44053 .2514 .43201 Metetra
.646 .762 .934 r
.2514 .43201 .26041 .44053 .27493 .42347 .26501 .42736 Metetra
.791 .998 .799 r
.26501 .42736 .27493 .42347 .28937 .40724 .27939 .41341 Metetra
.718 .967 .712 r
.27939 .41341 .28937 .40724 .30367 .3925 .29381 .39898 Metetra
.62 .925 .673 r
.29381 .39898 .30367 .3925 .31785 .37943 .3081 .38615 Metetra
.492 .857 .618 r
.3081 .38615 .31785 .37943 .33192 .36821 .32228 .37511 Metetra
.32228 .37511 .33192 .36821 .3459 .35895 .33637 .36596 Metetra
.33637 .36596 .3459 .35895 .35979 .35174 .35038 .3588 Metetra
.35038 .3588 .35979 .35174 .37364 .34664 .36434 .35368 Metetra
.123 0 0 r
.36434 .35368 .37364 .34664 .38747 .34366 .37828 .3506 Metetra
.243 0 0 r
.37828 .3506 .38747 .34366 .4013 .34276 .39222 .34955 Metetra
.341 0 0 r
.39222 .34955 .4013 .34276 .41517 .34388 .40619 .35046 Metetra
.417 0 0 r
.40619 .35046 .41517 .34388 .4291 .34693 .42023 .35321 Metetra
.477 0 0 r
.42023 .35321 .4291 .34693 .44314 .35175 .43437 .35768 Metetra
.523 0 0 r
.43437 .35768 .44314 .35175 .45731 .35817 .44863 .36368 Metetra
.44863 .36368 .45731 .35817 .47163 .36598 .46327 .35962 Metetra
.632 .835 .978 r
.46327 .35962 .47163 .36598 .48627 .36386 .478 .35459 Metetra
.646 .762 .934 r
.478 .35459 .48627 .36386 .50103 .35885 .49282 .34952 Metetra
.646 .762 .934 r
.49282 .34952 .50103 .35885 .51588 .35381 .50772 .34443 Metetra
.646 .762 .934 r
.50772 .34443 .51588 .35381 .5308 .34874 .5227 .33932 Metetra
.646 .762 .934 r
.5227 .33932 .5308 .34874 .54581 .34365 .53776 .33417 Metetra
.646 .762 .934 r
.53776 .33417 .54581 .34365 .5609 .33853 .5529 .32899 Metetra
.646 .762 .934 r
.5529 .32899 .5609 .33853 .57607 .33338 .56813 .32379 Metetra
.646 .762 .934 r
.56813 .32379 .57607 .33338 .59133 .3282 .58344 .31856 Metetra
.646 .762 .934 r
.58344 .31856 .59133 .3282 .60667 .32299 .59884 .3133 Metetra
.646 .762 .934 r
.59884 .3133 .60667 .32299 .62209 .31775 .61432 .30801 Metetra
.646 .762 .934 r
.61432 .30801 .62209 .31775 .6376 .31249 .62988 .30269 Metetra
.646 .762 .934 r
.62988 .30269 .6376 .31249 .6532 .30719 .64554 .29734 Metetra
.646 .762 .934 r
.64554 .29734 .6532 .30719 .66888 .30187 .66128 .29196 Metetra
.646 .762 .934 r
.66128 .29196 .66888 .30187 .68465 .29652 .67711 .28655 Metetra
.646 .762 .934 r
.67711 .28655 .68465 .29652 .70051 .29113 .69303 .28111 Metetra
.646 .762 .934 r
.69303 .28111 .70051 .29113 .71646 .28572 .70904 .27564 Metetra
.646 .762 .934 r
.70904 .27564 .71646 .28572 .7325 .28028 .72514 .27014 Metetra
.646 .762 .934 r
.02067 .49963 .0304 .50752 .04288 .50326 .03319 .49533 Metetra
.646 .762 .934 r
.03319 .49533 .04288 .50326 .05542 .49897 .04577 .491 Metetra
.646 .762 .934 r
.04577 .491 .05542 .49897 .06803 .49466 .05841 .48665 Metetra
.646 .762 .934 r
.05841 .48665 .06803 .49466 .0807 .49033 .07111 .48228 Metetra
.646 .762 .934 r
.07111 .48228 .0807 .49033 .09343 .48598 .08388 .47789 Metetra
.646 .762 .934 r
.08388 .47789 .09343 .48598 .10623 .48161 .09671 .47348 Metetra
.646 .762 .934 r
.09671 .47348 .10623 .48161 .1191 .47722 .10961 .46904 Metetra
.646 .762 .934 r
.10961 .46904 .1191 .47722 .13202 .4728 .12258 .46458 Metetra
.646 .762 .934 r
.12258 .46458 .13202 .4728 .14502 .46836 .13561 .4601 Metetra
.646 .762 .934 r
.13561 .4601 .14502 .46836 .15808 .4639 .14871 .4556 Metetra
.646 .762 .934 r
.14871 .4556 .15808 .4639 .17121 .45941 .16187 .45107 Metetra
.646 .762 .934 r
.16187 .45107 .17121 .45941 .1844 .4549 .17511 .44652 Metetra
.646 .762 .934 r
.17511 .44652 .1844 .4549 .19766 .45037 .18841 .44194 Metetra
.646 .762 .934 r
.18841 .44194 .19766 .45037 .21099 .44582 .20178 .43735 Metetra
.646 .762 .934 r
.20178 .43735 .21099 .44582 .22439 .44124 .21522 .43272 Metetra
.646 .762 .934 r
.21522 .43272 .22439 .44124 .23786 .43664 .22873 .42808 Metetra
.646 .762 .934 r
.22873 .42808 .23786 .43664 .2514 .43201 .24231 .42341 Metetra
.646 .762 .934 r
.24231 .42341 .2514 .43201 .26501 .42736 .25596 .41871 Metetra
.646 .762 .934 r
.25596 .41871 .26501 .42736 .27939 .41341 .26968 .41399 Metetra
.69 .976 .909 r
.26968 .41399 .27939 .41341 .29381 .39898 .28379 .40512 Metetra
.623 .932 .692 r
.28379 .40512 .29381 .39898 .3081 .38615 .29819 .39257 Metetra
.5 .866 .638 r
.29819 .39257 .3081 .38615 .32228 .37511 .31248 .38172 Metetra
.31248 .38172 .32228 .37511 .33637 .36596 .32668 .3727 Metetra
.32668 .3727 .33637 .36596 .35038 .3588 .3408 .3656 Metetra
.3408 .3656 .35038 .3588 .36434 .35368 .35488 .36045 Metetra
.101 0 0 r
.35488 .36045 .36434 .35368 .37828 .3506 .36892 .35728 Metetra
.221 0 0 r
.36892 .35728 .37828 .3506 .39222 .34955 .38297 .35606 Metetra
.318 0 0 r
.38297 .35606 .39222 .34955 .40619 .35046 .39706 .35672 Metetra
.395 0 0 r
.39706 .35672 .40619 .35046 .42023 .35321 .4112 .35916 Metetra
.331 0 0 r
.4112 .35916 .42023 .35321 .43437 .35768 .42553 .36039 Metetra
.252 .752 .695 r
.42553 .36039 .43437 .35768 .44863 .36368 .44016 .35536 Metetra
.644 .786 .95 r
.44016 .35536 .44863 .36368 .46327 .35962 .45487 .3503 Metetra
.646 .762 .934 r
.45487 .3503 .46327 .35962 .478 .35459 .46965 .34522 Metetra
.646 .762 .934 r
.46965 .34522 .478 .35459 .49282 .34952 .48452 .3401 Metetra
.646 .762 .934 r
.48452 .3401 .49282 .34952 .50772 .34443 .49947 .33496 Metetra
.646 .762 .934 r
.49947 .33496 .50772 .34443 .5227 .33932 .5145 .32979 Metetra
.646 .762 .934 r
.5145 .32979 .5227 .33932 .53776 .33417 .52962 .32459 Metetra
.646 .762 .934 r
.52962 .32459 .53776 .33417 .5529 .32899 .54482 .31937 Metetra
.646 .762 .934 r
.54482 .31937 .5529 .32899 .56813 .32379 .5601 .31411 Metetra
.646 .762 .934 r
.5601 .31411 .56813 .32379 .58344 .31856 .57547 .30883 Metetra
.646 .762 .934 r
.57547 .30883 .58344 .31856 .59884 .3133 .59092 .30351 Metetra
.646 .762 .934 r
.59092 .30351 .59884 .3133 .61432 .30801 .60646 .29817 Metetra
.646 .762 .934 r
.60646 .29817 .61432 .30801 .62988 .30269 .62209 .29279 Metetra
.646 .762 .934 r
.62209 .29279 .62988 .30269 .64554 .29734 .6378 .28739 Metetra
.646 .762 .934 r
.6378 .28739 .64554 .29734 .66128 .29196 .6536 .28195 Metetra
.646 .762 .934 r
.6536 .28195 .66128 .29196 .67711 .28655 .6695 .27649 Metetra
.646 .762 .934 r
.6695 .27649 .67711 .28655 .69303 .28111 .68548 .27099 Metetra
.646 .762 .934 r
.68548 .27099 .69303 .28111 .70904 .27564 .70155 .26546 Metetra
.646 .762 .934 r
.70155 .26546 .70904 .27564 .72514 .27014 .71771 .2599 Metetra
.646 .762 .934 r
.01086 .49167 .02067 .49963 .03319 .49533 .02341 .48732 Metetra
.646 .762 .934 r
.02341 .48732 .03319 .49533 .04577 .491 .03602 .48296 Metetra
.646 .762 .934 r
.03602 .48296 .04577 .491 .05841 .48665 .04869 .47857 Metetra
.646 .762 .934 r
.04869 .47857 .05841 .48665 .07111 .48228 .06143 .47416 Metetra
.646 .762 .934 r
.06143 .47416 .07111 .48228 .08388 .47789 .07424 .46973 Metetra
.646 .762 .934 r
.07424 .46973 .08388 .47789 .09671 .47348 .08711 .46527 Metetra
.646 .762 .934 r
.08711 .46527 .09671 .47348 .10961 .46904 .10004 .46079 Metetra
.646 .762 .934 r
.10004 .46079 .10961 .46904 .12258 .46458 .11304 .45629 Metetra
.646 .762 .934 r
.11304 .45629 .12258 .46458 .13561 .4601 .12611 .45177 Metetra
.646 .762 .934 r
.12611 .45177 .13561 .4601 .14871 .4556 .13925 .44722 Metetra
.646 .762 .934 r
.13925 .44722 .14871 .4556 .16187 .45107 .15245 .44265 Metetra
.646 .762 .934 r
.15245 .44265 .16187 .45107 .17511 .44652 .16572 .43805 Metetra
.646 .762 .934 r
.16572 .43805 .17511 .44652 .18841 .44194 .17906 .43344 Metetra
.646 .762 .934 r
.17906 .43344 .18841 .44194 .20178 .43735 .19247 .42879 Metetra
.646 .762 .934 r
.19247 .42879 .20178 .43735 .21522 .43272 .20596 .42413 Metetra
.646 .762 .934 r
.20596 .42413 .21522 .43272 .22873 .42808 .21951 .41944 Metetra
.646 .762 .934 r
.21951 .41944 .22873 .42808 .24231 .42341 .23313 .41472 Metetra
.646 .762 .934 r
.23313 .41472 .24231 .42341 .25596 .41871 .24682 .40998 Metetra
.646 .762 .934 r
.24682 .40998 .25596 .41871 .26968 .41399 .26059 .40521 Metetra
.646 .762 .934 r
.26059 .40521 .26968 .41399 .28379 .40512 .27443 .40042 Metetra
.616 .864 .99 r
.27443 .40042 .28379 .40512 .29819 .39257 .28834 .39561 Metetra
.491 .898 .787 r
.28834 .39561 .29819 .39257 .31248 .38172 .30252 .3879 Metetra
.373 .795 .601 r
.30252 .3879 .31248 .38172 .32668 .3727 .31683 .37902 Metetra
.31683 .37902 .32668 .3727 .3408 .3656 .33107 .37197 Metetra
.33107 .37197 .3408 .3656 .35488 .36045 .34525 .36681 Metetra
.072 0 0 r
.34525 .36681 .35488 .36045 .36892 .35728 .35941 .36354 Metetra
.191 0 0 r
.35941 .36354 .36892 .35728 .38297 .35606 .37357 .36213 Metetra
.212 0 0 r
.37357 .36213 .38297 .35606 .39706 .35672 .38782 .36116 Metetra
.38782 .36116 .39706 .35672 .4112 .35916 .40234 .35614 Metetra
.568 .896 .984 r
.40234 .35614 .4112 .35916 .42553 .36039 .41694 .35108 Metetra
.646 .762 .934 r
.41694 .35108 .42553 .36039 .44016 .35536 .43162 .346 Metetra
.646 .762 .934 r
.43162 .346 .44016 .35536 .45487 .3503 .44638 .34089 Metetra
.646 .762 .934 r
.44638 .34089 .45487 .3503 .46965 .34522 .46122 .33576 Metetra
.646 .762 .934 r
.46122 .33576 .46965 .34522 .48452 .3401 .47614 .33059 Metetra
.646 .762 .934 r
.47614 .33059 .48452 .3401 .49947 .33496 .49114 .3254 Metetra
.646 .762 .934 r
.49114 .3254 .49947 .33496 .5145 .32979 .50623 .32017 Metetra
.646 .762 .934 r
.50623 .32017 .5145 .32979 .52962 .32459 .5214 .31492 Metetra
.646 .762 .934 r
.5214 .31492 .52962 .32459 .54482 .31937 .53665 .30964 Metetra
.646 .762 .934 r
.53665 .30964 .54482 .31937 .5601 .31411 .55199 .30433 Metetra
.646 .762 .934 r
.55199 .30433 .5601 .31411 .57547 .30883 .56741 .29899 Metetra
.646 .762 .934 r
.56741 .29899 .57547 .30883 .59092 .30351 .58293 .29362 Metetra
.646 .762 .934 r
.58293 .29362 .59092 .30351 .60646 .29817 .59852 .28822 Metetra
.646 .762 .934 r
.59852 .28822 .60646 .29817 .62209 .29279 .61421 .28279 Metetra
.646 .762 .934 r
.61421 .28279 .62209 .29279 .6378 .28739 .62998 .27733 Metetra
.646 .762 .934 r
.62998 .27733 .6378 .28739 .6536 .28195 .64584 .27184 Metetra
.646 .762 .934 r
.64584 .27184 .6536 .28195 .6695 .27649 .6618 .26632 Metetra
.646 .762 .934 r
.6618 .26632 .6695 .27649 .68548 .27099 .67784 .26076 Metetra
.646 .762 .934 r
.67784 .26076 .68548 .27099 .70155 .26546 .69398 .25518 Metetra
.646 .762 .934 r
.69398 .25518 .70155 .26546 .71771 .2599 .71021 .24956 Metetra
.646 .762 .934 r
.00095 .48363 .01086 .49167 .02341 .48732 .01353 .47925 Metetra
.646 .762 .934 r
.01353 .47925 .02341 .48732 .03602 .48296 .02618 .47484 Metetra
.646 .762 .934 r
.02618 .47484 .03602 .48296 .04869 .47857 .03889 .47041 Metetra
.646 .762 .934 r
.03889 .47041 .04869 .47857 .06143 .47416 .05166 .46596 Metetra
.646 .762 .934 r
.05166 .46596 .06143 .47416 .07424 .46973 .0645 .46148 Metetra
.646 .762 .934 r
.0645 .46148 .07424 .46973 .08711 .46527 .07741 .45699 Metetra
.646 .762 .934 r
.07741 .45699 .08711 .46527 .10004 .46079 .09038 .45247 Metetra
.646 .762 .934 r
.09038 .45247 .10004 .46079 .11304 .45629 .10342 .44792 Metetra
.646 .762 .934 r
.10342 .44792 .11304 .45629 .12611 .45177 .11652 .44335 Metetra
.646 .762 .934 r
.11652 .44335 .12611 .45177 .13925 .44722 .1297 .43876 Metetra
.646 .762 .934 r
.1297 .43876 .13925 .44722 .15245 .44265 .14294 .43415 Metetra
.646 .762 .934 r
.14294 .43415 .15245 .44265 .16572 .43805 .15625 .42951 Metetra
.646 .762 .934 r
.15625 .42951 .16572 .43805 .17906 .43344 .16963 .42485 Metetra
.646 .762 .934 r
.16963 .42485 .17906 .43344 .19247 .42879 .18308 .42016 Metetra
.646 .762 .934 r
.18308 .42016 .19247 .42879 .20596 .42413 .1966 .41545 Metetra
.646 .762 .934 r
.1966 .41545 .20596 .42413 .21951 .41944 .21019 .41071 Metetra
.646 .762 .934 r
.21019 .41071 .21951 .41944 .23313 .41472 .22386 .40595 Metetra
.646 .762 .934 r
.22386 .40595 .23313 .41472 .24682 .40998 .23759 .40116 Metetra
.646 .762 .934 r
.23759 .40116 .24682 .40998 .26059 .40521 .2514 .39635 Metetra
.646 .762 .934 r
.2514 .39635 .26059 .40521 .27443 .40042 .26528 .39151 Metetra
.646 .762 .934 r
.26528 .39151 .27443 .40042 .28834 .39561 .27924 .38665 Metetra
.646 .762 .934 r
.27924 .38665 .28834 .39561 .30252 .3879 .29327 .38176 Metetra
.633 .834 .978 r
.29327 .38176 .30252 .3879 .31683 .37902 .30738 .37684 Metetra
.547 .9 .974 r
.30738 .37684 .31683 .37902 .33107 .37197 .32156 .3719 Metetra
.448 .879 .9 r
.32156 .3719 .33107 .37197 .34525 .36681 .33582 .36693 Metetra
.435 .873 .888 r
.33582 .36693 .34525 .36681 .35941 .36354 .35015 .36194 Metetra
.519 .899 .957 r
.35015 .36194 .35941 .36354 .37357 .36213 .36456 .35691 Metetra
.619 .861 .989 r
.36456 .35691 .37357 .36213 .38782 .36116 .37905 .35186 Metetra
.646 .762 .934 r
.37905 .35186 .38782 .36116 .40234 .35614 .39362 .34679 Metetra
.646 .762 .934 r
.39362 .34679 .40234 .35614 .41694 .35108 .40827 .34168 Metetra
.646 .762 .934 r
.40827 .34168 .41694 .35108 .43162 .346 .423 .33655 Metetra
.646 .762 .934 r
.423 .33655 .43162 .346 .44638 .34089 .43781 .33139 Metetra
.646 .762 .934 r
.43781 .33139 .44638 .34089 .46122 .33576 .4527 .3262 Metetra
.646 .762 .934 r
.4527 .3262 .46122 .33576 .47614 .33059 .46767 .32098 Metetra
.646 .762 .934 r
.46767 .32098 .47614 .33059 .49114 .3254 .48273 .31573 Metetra
.646 .762 .934 r
.48273 .31573 .49114 .3254 .50623 .32017 .49787 .31046 Metetra
.646 .762 .934 r
.49787 .31046 .50623 .32017 .5214 .31492 .51309 .30515 Metetra
.646 .762 .934 r
.51309 .30515 .5214 .31492 .53665 .30964 .5284 .29981 Metetra
.646 .762 .934 r
.5284 .29981 .53665 .30964 .55199 .30433 .5438 .29445 Metetra
.646 .762 .934 r
.5438 .29445 .55199 .30433 .56741 .29899 .55928 .28905 Metetra
.646 .762 .934 r
.55928 .28905 .56741 .29899 .58293 .29362 .57485 .28363 Metetra
.646 .762 .934 r
.57485 .28363 .58293 .29362 .59852 .28822 .5905 .27817 Metetra
.646 .762 .934 r
.5905 .27817 .59852 .28822 .61421 .28279 .60625 .27269 Metetra
.646 .762 .934 r
.60625 .27269 .61421 .28279 .62998 .27733 .62208 .26717 Metetra
.646 .762 .934 r
.62208 .26717 .62998 .27733 .64584 .27184 .638 .26162 Metetra
.646 .762 .934 r
.638 .26162 .64584 .27184 .6618 .26632 .65402 .25604 Metetra
.646 .762 .934 r
.65402 .25604 .6618 .26632 .67784 .26076 .67013 .25042 Metetra
.646 .762 .934 r
.67013 .25042 .67784 .26076 .69398 .25518 .68632 .24478 Metetra
.646 .762 .934 r
.68632 .24478 .69398 .25518 .71021 .24956 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Kooooo`00ooooool9ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Foooool00?oooooo2Oooool01Ol@413ooooooooooooooooo410@05_ooooo003oooooo`Wooooo00Go
0000ooooooooooooooooo`00001Kooooo`00ooooool9ooooo`05o`000?ooooooooooooooool00000
Foooool00?oooooo0oooool2o`0000Cooooo00Go410@oooooooooooooooooa0@401Kooooo`00oooo
ool3o`000003ooooool0003ooooo00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Kooooo`00oOoo
ool2o`0000;ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Foooool00?[ooooo0ol0
0006ooooo`03o`000?oooooo000006;ooooo003hooooo`;o00002Oooool00ol0003oooooo`00001R
ooooo`00mOooool3o`0000_ooooo00Co0000oooooooooooo0000HOooool00?;ooooo0ol00003oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001Pooooo`00l?ooool2o`00
017ooooo00Go0000ooooooooooooooooo`00001Pooooo`00kOooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00joooool2o`0001Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Mooooo`00/oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool3o`000003ooooool0003ooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`00/oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0000Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo01Sooooo0ol0000Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`00/oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3
o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`;o0000Foooool0
0;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01;ooooo0_l0000Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool007_ooooo0_l00002oooo
o`;o0000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o0000:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001kooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMDoooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Gooooo`00O?ooool01?oMgMgo0000oa0@4?o<c<aAooooo`?o00000_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool007cooooo00Cok^k^
ob4Q8Ol@413ok^k^Coooool2o`0003?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`00O?ooool01?lQ8B7oMgMgogMgMolb<S9<ooooo`?o0000=Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Gooooo001kooooo`;o00000_ooool2o`0004Wooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00<Oooooo1?l0000ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool00<Gooooo0_l00004ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
`_ooool3o`0003oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_ooo
ool3o`0004;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_Oooool3
o`0004Cooooo00?o0000ooooooooool03?ooool2o`0005?ooooo002jooooo`?o00000oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;So
oooo0_l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;Gooooo
0ol0001<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool008_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Sooooo`;o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04kooooo002;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08?ooool3o`0000;ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo
002;ooooo`05oa0@4?ooooooooooooooool@41007_ooool2o`0005Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`00Roooool01Ol0003ooooooooooooooooo000001_ooooo
0ol0001Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool008_ooooo00Go
0000ooooooooooooooooo`00000Iooooo`;o0000F_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo002;ooooo`05oa0@4?ooooooooooooooool@41005_ooool3o`000003oooo
ool0003ooooo05Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`00Rooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0ol0001Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool008_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o0000
H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo002Nooooo`?o0000I?oo
ool00ol0003oooooooooo`0Booooo`?o0000Boooool009cooooo0_l00002ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`00VOooool3o`00
06Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`00Uoooool2o`0006co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`00U?ooool3o`0006kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`00T_ooool2o`000003ooooool0
003ooooo06kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`00Soooool3
o`0000Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo04Gooooo002<ooooo`?o0000M_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo002:ooooo`;o0000NOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Co
oooo0027ooooo`Go0000NOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo
0025ooooo`;o0000O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo0022
ooooo`?o0000POooool00ol0003oooooooooo`0Iooooo`;o0000A?ooool004Wooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM027ooooo0_l0
0024ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@Oooool004Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Mooooo`?o000000?o
ooooo`000?ooool0Poooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047ooooo0011
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06_oo
ool2o`0008Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`00BOooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool06?ooool3o`0008_ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0oooooo`00BOooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`;o0000S_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02?ooooo0019ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Fooooo`?o000000?oooooo`000?ooool0SOooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Rooooo`00BOooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool04oooool3o`0009?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Qooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@ooooo`;o0000U_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo02;ooooo001[ooooo`?o0000V?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`08oooool006Wooooo0_l00002ooooo`03o`000?oooooooooo09Kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0Uooooo`00I_ooool3o`0009gooooo00?o0000ooooooooool0
8?ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00co
oooo0ol000000ol@413oooooooooo`0Cooooo`00I?ooool2o`000:3ooooo00?o0000ooooooooool0
7oooool01?l0003oooooooooool00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00gooooo00?o410@okZj^_ooool05?ooool0067ooooo0ol0002Rooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08oooool00onHV9So<S8booooo`0Dooooo`00Goooool2o`0000;ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo
00?ogMgMo`000?nj^[X05?ooool005cooooo0ol00005ooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`03oeEEEOmgMgOoA4A401Cooooo001J
ooooo`;o0000Z_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo00GogMgM
oa0@4?oooooo8B4QomgMg@0Cooooo`00Eoooool3o`000:cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Oooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool005Cooooo0ol00003
ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0M
ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04Oooool005;ooooo0_l0002boooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo013ooooo000Zooooo`Co000000?o410@ooooooooool07_ooool3o`00
0;Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0003o
ooooooooo`0Nooooo`?o0000]oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Go
oooo000Qooooo`Ko00001Oooool00ol0003oooooooooo`0Kooooo`?o00000oooool00ol0003ooooo
ooooo`2dooooo`03o`000?oooooooooo02Kooooo0_l0000fooooo`00;?ooool00ol0003ooooooooo
o`0Iooooo`;o0000_Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo000/
ooooo`03o`000?oooooooooo01Kooooo0ol0002oooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0<oooool002cooooo00?o0000ooooooooool05?ooool2o`0000;ooooo00?o0000oooo
ooooool0_Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03;ooooo000/ooooo`03
o`000?oooooooooo017ooooo0ol00034ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0<Oooool002[ooooo00?oEEEEofIVI_l000004?ooool3o`000<Kooooo0_l0000/ooooo`03o`00
0?oooooooooo037ooooo000kooooo`;o0000a_ooool3o`000003ojG3kol0003ooooo02cooooo00?o
0000ooooooooool0<?ooool003Sooooo0ol00002ooooo`03o`000?oooooooooo0<3ooooo0ol00003
ojG3k`?o0000;Oooool00ol0003oooooooooo`0_ooooo`00=_ooool2o`000<Cooooo1?l00002ojG3
k`Co000000CoYL?_o`000?l0003o0000;?ooool00ol0003oooooooooo`0_ooooo`00<oooool3o`00
0<?ooooo0ol000001?nU`noo0000ojG3konU`nl4o`000003ojG3kol0003o000000?o0000;Oooool0
0ol0003oooooooooo`0^ooooo`00<_ooool3o`000<7ooooo0ol00004ojG3k`?o00000onU`nl2o`00
00CoYL?_0_l0000/ooooo`;o0000;oooool003;ooooo00Co0000ooooool0003o0000_Oooool3o`00
0004ojG3kol0003oYL?_ojG3k`?o000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU`noo
YL?_00;oYL?_0_l0000/ooooo`03o`000?oooooooooo02gooooo000booooo`;o000000?oooooo`00
0?ooool0^_ooool2o`0000CoYL?_0ol00004ojG3k`;o00001_nU`nl01?l0003oYL?_ojG3konU`nl3
o`0002cooooo00?o0000ooooooooool0;?ooool003;ooooo00Go0000ooooooooooooooooo`00002g
ooooo`?o00000_nU`nl4o`0000;oYL?_00?o0000ojG3kol000000_l00002ojG3k`03o`000?nU`noo
YL?_00?oYL?_1?l000000onU`noo0000o`00000/ooooo`03o`000?oooooooooo02cooooo000aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/_ooool2o`0000?oYL?_1?l00003ojG3
k`?o00001_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000/oooo
o`03o`000?oooooooooo02_ooooo000aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0[_ooool3o`0000;oYL?_0ol00003ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04ojG3k`;o
00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002cooooo00?o0000ooooooooool0:_ooool0037o
oooo0ol00005ooooo`03o`000?oooooooooo0:[ooooo0ol00003ojG3k`;o000000?oYL?_o`000?nU
`nl00ol000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`nooYL?_00?o000000?oYL?_o`000?nU
`nl01?nU`nl00ol0003oYL?_o`000003o`000003ojG3kol0003ooooo02[ooooo00?o0000oooooooo
ool0:_ooool0037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Uooooo`Co0000
0onU`nl3o`0000?oYL?_0_l00005ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00005ojG3k`04o`00
0?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0003oYL?_o`00000[ooooo`03o`000?oooooooooo02Wo
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0:7ooooo0ol000001?nU`noo0000ojG3konU`nl3o`000003ojG3kol0
003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`0000;oYL?_00?o
0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`0002_ooooo00?o
0000ooooooooool0:?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0W_ooool2o`0000CoYL?_0ol00004ojG3k`;o
00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol000000_l000000onU
`noo0000ojG3k`04ojG3k`03o`000?nU`nooYL?_00?o000000?oYL?_o`000?ooool0:_ooool00ol0
003oooooooooo`0Xooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0
000:ooooo`03o`000?oooooooooo09[ooooo0ol00002ojG3k`Co00000_nU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00CoYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l0
0005ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo000002[ooooo0_l0
000Yooooo`003_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo09Oooooo0_l00003ojG3k`Co00000onU`nl3o`0000GoYL?_00?o0000ojG3kol0
00000_l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o
0000:oooool00ol0003oooooooooo`0Vooooo`003_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Wooooo3_l0000<ooooo`?o00000_nU`nl3
o`0000?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006ojG3k`04o`000?nU`noo
YL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol00000
1?l0000[ooooo`03o`000?oooooooooo02Kooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@okZj^_oooooo^[Zjoa0@4005oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L_ooool:o`0000?oD`002ol00005oooo
o`?o00000_nU`nl3o`000003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl00ol0
003oYL?_o`000002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000?oYL?_00?o0000ojG3
kol00000:oooool00ol0003oooooooooo`0Uooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooookZj^_l000001Ooo
ool2o`0000oooooo0_l0001`ooooo`[o00000_mJ0004o`0000;oLP000_l000000om/003o0000o`00
0008o`0000?oYL?_0_l00004ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_
00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
0onU`nl3o`0002_ooooo00?o0000ooooooooool09?ooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`Oo000000?o?@00o`00
0?mO00000omO0004o`0000;oMP001_l00002ohD000?o00000_nU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3
konU`nl00onU`nl2o`0000GoYL?_00?o0000ojG3konU`nl00_nU`nl2o`0000KoYL?_00Co0000ojG3
konU`nooYL?_0ol00005ojG3k`03o`000?nU`noo000000Co0000:oooool00ol0003oooooooooo`0T
ooooo`00<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06Oooooo0_l000000olA
003o0000o`000007o`0000;oG`0000?o0000ogP00?mh00000_mh0003o`0000;oRP001Ol00004ojG3
k`?o00000onU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`05ojG3
k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`00
00;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`00
00CoYL?_0_l0000[ooooo`03o`000?oooooooooo02?ooooo000_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0I?ooool6o`0000?o@P0000?o0000of400?mQ00000_mQ0004o`0000;o
N00000Co0000oh/10?n;0@3oR`400_l000000on:003o0000o`000002ojG3k`Co00000_nU`nl4o`00
00;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00?o0000ojG3konU`nl00onU`nl2o`00
00GoYL?_00Co0000ojG3konU`nooYL?_0ol00006ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000/
ooooo`03o`000?oooooooooo02;ooooo000_ooooo`;o00005Oooool00ol0003oooooooooo`1Poooo
oa?o00000_mi0003o`0000?oR`400ol00002ojG3k`Co000000KoYL?_o`000?l0003o0000ojG3kol0
0005ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU
`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU
`nl2o`0000GoYL?_00?o0000ojG3konU`nl00_nU`nl2o`0000GoYL?_00Co0000ojG3konU`nooYL?_
0ol0000[ooooo`03o`000?oooooooooo02;ooooo000_ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0G_ooool7o`000003odD00?l0003o000000?o00000_mR00000ol0003oN@00ogT0
0002ogT000?o000000?oRP<0o`000?l000000_l00002ojG3k`?o00000onU`nl2o`0000GoYL?_00?o
0000ojG3konU`nl00_nU`nl2o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o0000
00?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_
1?l00002ojG3k`;o0000:oooool00ol0003oooooooooo`0Qooooo`00;oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo05_ooooo2ol00004of8000Co00000_mi00000ol0003oR@<0o`00
0002o`000003ojG3kol0003oYL?_00?o000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU
`nooYL?_00?oYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000Go
YL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`000?nU`noo000000;o00000_nU`nl01ol0
003oYL?_ojG3konU`noo0000ojG3kol00000:_ooool2o`0002;ooooo000_ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0F?ooool5o`0000?o90001_l00002of800003o`000?mg003o
M`0000;oM`001?l00003ojG3k`?o00000onU`nl3o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol0
0005ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`00
0002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU
`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000KoYL?_00Co0000ojG3konU`nooYL?_
0ol0000Zooooo`03o`000?oooooooooo023ooooo000_ooooo`?o00006?ooool00ol0003ooooooooo
o`1Fooooo`Go000000?o9000o`000?l000000_l000000om6003o0000of400002of4000Go000000Co
M`00o`000?l0003o00000_nU`nl3o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?oYL?_
1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o
00001_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol0
00000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003o
YL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l00000:oooool00ol0003oooooooooo`0Oooooo`00
;_ooool2o`0001_ooooo00?o0000ooooooooool0E?ooool8o`0000?oAP0000?o0000of400?mQ0000
0_mQ00000ol0003oM@00ogD00003o`0000?oYL?_0_l000000onU`noo0000ojG3k`02o`000003ojG3
kol0003oYL?_00GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`03ojG3k`;o00001OnU`nl00ol0003oYL?_ojG3k`02ojG3k`;o00001OnU`nl01?l0003oYL?_
ojG3konU`nl3o`0000KoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`;o
0000:_ooool00ol0003oooooooooo`08ooooo`Co000000?o410@ooooooooool04?ooool000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0DOoooolEo`0000?oYL?_0ol00003ojG3k`;o00001?nU`nl00ol0003oYL?_ojG3k`03
ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000KoYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l00003ojG3k`03o`00
0?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o0000:_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01;ooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04kooooo2Ol00003
odD00003o`000?mN003oGP0000;oGP000_l00002ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl00ol000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_
o`000?nU`nl01?nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_
o`000002o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3
kol0003oYL?_00CoYL?_1?l000000onU`noo0000o`00000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool000Cooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00007_ooool00ol0003oooooooooo`1<oooooa;o00000onU`nl3o`0000?oYL?_0ol00005ojG3
k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`0000;oYL?_00?o0000
ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006
ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_0_l0000Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_oo
ool000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool07_ooool2o`0004_o
oooo2?l00004od800003o`000?mK003o000000;o000000?oYL?_o`000?l000000_l00002ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`;o
00001_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU
`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3
k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00000_nU`nl00ol0
003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Booooo`003?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Oooooo3ol00002ojG3k`Co0000
00CoYL?_o`000?l0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;o
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol00006ojG3k`03o`000?nU`nooYL?_00?o00001_nU`nl00ol0003oYL?_o`000002
o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04
ojG3k`Co000000?oYL?_o`000?l00000:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo000<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo04Gooooo1_l000000olO003o0000och00004o`0000;oYL?_0ol00003ojG3k`;o00001_nU
`nl00ol0003oYL?_ojG3k`03o`0000KoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl3o`0000?oYL?_
00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl2o`0002[ooooo0_l00007ooooo`03
o`000?oooooooooo01;ooooo000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P01_ooool2o`0002Cooooo00?o0000oooo
ooooool0@_ooool6o`0000;o7`000ol00002ojG3k`Co00000_nU`nl01?l0003oYL?_o`000?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00002
ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001_nU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000ojG3kol00000
0_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol0000Xooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000005?ooool000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<
c<coA4A4o`000?l@4104ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@?ooool:
o`0000;oYL?_1?l00003ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojC9lol0003o
YL?_00CoYL?_00?o0000ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000
ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`noo
YL?_00?oYL?_0_l00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3
konU`nl3o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`000004ojG3kol0003oYL?_o`0002[o
oooo00?o0000ooooooooool06Oooool002gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0mooooo`[o000000CoW]cmo`000?l0003o00000onU`nl4o`0000;oTNGk00?o0000ojG3konU
`nl00onU`nl2o`0000GoY<Wc00Co0000ojG3konU`nooYL?_0ol00006ojG3k`03o`000?nU`nooYL?_
00?o00001_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00?o0000
ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03
ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU
`nl3o`0000GoYL?_00?o0000ojG3kol000000_l00002ojG3k`07o`000?nU`nooYL?_ojG3kol0003o
YL?_o`00000Yooooo`03o`000?oooooooooo01Wooooo000]ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0>oooool>o`000003ojG3kol0003o000000Wo000000?oYL?_o`000?l00000
0_l000000om0`;7o0000ojC9l`03ojC9l`Co00000onQeOX00ol0003oYL?_ojG3k`03ojG3k`?o0000
0onU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000Go
YL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o
000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00Co
YL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00006ojG3k`04o`000?nU`nooYL?_ojG3
k`?o0000:Oooool00ol0003oooooooooo`0Hooooo`00;Oooool2o`0002Sooooo00?o0000oooooooo
ool0>?ooool7o`0000;oQ>Kd2?l00002onc^c003o`000?oZj<co000000;oj>7<0_l000001ooQfm3o
0000o`000?l0003ogM;>o`000?oIb//00ol000000onTbO?o0000o`000002olo0c0;o00001?nQeOX0
0ol0003oYL?_o`000002o`000003oj7Fn_l0003oYL?_00CoYL?_00?o0000ojG3kol000000_l00000
0onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl0
1?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`nooYL?_1?l00004ojG3k`03o`00
0?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;o0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l00000:Oooool00ol0003ooooo
ooooo`0Hooooo`00;?ooool2o`0002[ooooo00?o0000ooooooooool0=_ooool4o`0000;oKmoS1Ol0
00000ooXnlKo0000o`000002oncdbP06o`000?o/k/cok>k<o`000?oZj<co00000ooXhL`00ol0003o
iM[;o`000003omgBcP03o`000?oIb/_ofL[;00;ofL[;0_l00003olo0c0;o000000?oa;G<o`000?l0
00001?l00005oj7FnP04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3
k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`03o`00
00KoYL?_00?o0000ojG3konU`nl00ol00006ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`00
0?nU`nl00_nU`nl00ol0003oYL?_o`00000Yooooo`03o`000?oooooooooo01Oooooo000/ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool;o`0000;oj?_60_l00002oncdbP06
o`000?o/k/cok>k<o`000?oZj<co00000ooXhL`00ol0003oiM[;onGJb`02o`000003omgBc_l0003o
fL[;00CofL[;00Go0000olo0c?o?`<cocl3<o`000002olZhb@03o`000?o4]Lco000000?o`:k80_l0
0003oj7FnPGo00000onTbo@01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol00005ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03
o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`03ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003o
YL?_ojG3konU`nl3o`0002Wooooo00?o0000ooooooooool05_ooool002cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0_ooooo`go00000_oXnlH2o`0000;ok?C:00Co0000onc^c?o/
k/co00000_oZj<`01?l0003oj>7<onSQc?l00002onGJb`04o`000?oQdlWohM?9o`0000GofL[;00Go
0000omC2bOl0003ocl3<o`000004olZhb@03o`000?o0[/So`:k800;o`:k800?o0000okVZbol00000
0ol00002ojjOb003o`000?nTboCoY<_d00;oY<_d1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_
1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0_l00006ojG3k`03o`000?nU`nooYL?_00?o0000
1_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol00000
0_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl0
1?nU`nl4o`000003ojG3kol0003o000002Wooooo00?o0000ooooooooool05_ooool002cooooo0ol0
000/ooooo`03o`000?oooooooooo02cooooo0_l00002ohcVn@Ko000000Kog?flo`000?l0003oiOc3
o`000?oXnlH9o`000005on[Xc?l0003oj>7<onSQc?l000000_oUf//01?l0003ohM?9on7CbOoQdlT2
o`0000?ofL[;00Go0000omC2bOoD`/Woe<;9o`000004olZhb@;o00001?o0[/P2o`0000Co]J?600Go
0000ojjOb?n^WlSo0000ojC;m002o`000003ojBEa_l0003o000000GoYL?_00Co0000ojG3kol0003o
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00onU`nl2o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00?oYL?_0_l0000Yooooo`;o00005_ooool002cooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`co000000Cog?flo`000?l0003oiOc30ol0
00001Oo^m<Co0000onoaa_o_lLKo000000;ok^c700Ko0000ongVaol0003o0000onSQc?l00003onGJ
b`04o`000?oQdlWohM?9o`0000;ogL_800?o0000omW:bol000000ooD`/T2o`0000?ob[S900Co0000
olJaaOo6/LGo00000_o0[/P00ol0003o_:O4o`000004okFSaP03o`000?n^WlSo000000?o00001?nT
ULH01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003
ojG3kol0003oYL?_00CoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00003ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0002Sooooo0_l0000F
ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Sooooo`Co00000onReOX7o`000003omSm^_l0003o000000Co000000?o
kOS2o`000?l000000_o_lLH01?l0003ok^c7onk/aol00002ongVa`03o`000?o[h<Oo000000;o0000
00GoiM[;o`000?oQdlWohM?9o`000004omg;b005o`000?oD`/Woe<;9omC2bOl000000_o?^lH00ol0
003ob[S9o`000003olJaa@03o`000?o0[/So000000?o_:O400Co0000okFSa_neXlKo]J?60_l00004
oj^Ia004o`000?nTULKoY9G6ojBEaPGo000000?o@L6eo`000?nU`nl01?nU`nl4o`0000?oYL?_00Co
0000ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000?oYL?_o`000?l0
0000:Oooool00ol0003oooooooooo`0Dooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02oooooo0_l0000Qooooo`;o00000onU`nl:o`000003omSm^_l0003o0000
00;o000000Sojo[0o`000?o]n<;o0000onkda?l0003oko76o`0000;ok^c700Co0000ongVaoo]i/Oo
00000_o[h<L00ol0003oim[7onOJa`02o`000003on7CbOl0003ogL_800CogL_80_l000000ooD`/Wo
0000olnkaP03olnkaP03o`000?o6/LGoa[7500?oa[7500?o0000okbWa?nlYl@00_nlYl@01_l0003o
]J?6okFSa_l0003o/Yg3o`0000CoZiW400Go0000ojBEa_nTULKoY9G6o`000002oi^Ab0Go000000Ko
YL?_o`000?l0003o0000ohkTnol00005ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`00
00GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`03o`000?nU`noo0000
00;o000000?oYL?_o`000?nU`nl00onU`nl2o`0002Wooooo00?o0000ooooooooool04oooool00003
ooooool0003o000000Co00000_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`Go00001Oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01cooooo0_l00003ojG3k`Oo000000Co^oNbo`000?l0003odobh0ol000002?oXnkko0000on_j
`?l0003okOS2o`000?o^m<Co00000_o_lLH00ol0003ok^c7o`000002ongVa`04o`000?o[h<Oojn37
o`0000?oim[700?o0000onCCa_l000001OoMblP01?l0003of<C6omS4a_l00004olnkaP;o00001?o6
/LD2o`0000Co_:O400?o0000okFSa_l000000onbWL<01Ol0003oZiW4oj^Ia?n[VLCo000000;oY9G6
1?l00002oi^=``03o`000?nCR<GoThS500?o00000on>i?/00ol0003oYL?_o`000002o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_
00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_
ojG3k`03ojG3k`;o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00Co0000ojG3konU
`nooYL?_0ol0000Yooooo`03o`000?oooooooooo01;ooooo0009ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo00001_oo
ool3o`0003?ooooo00?o0000ooooooooool06?ooool3o`000003ojG3kol0003o000000Co000000Co
ONG9o`000?l0003o^?Nc0ol000003?oCo;So0000o`000?l0003oj?^no`000?o[n/3o0000ongh`_l0
003ok_C4o`0000;oko7600?o0000onk/aol000000oo]i/L00ol0003ojn37o`000003onOJa`03o`00
0?oTdlKoi=?600;o00000ooMblP01Ol0003of<C6omS4a_oHa<Ko000000?ock_600Co0000ol^d`oo;
]<?o00000_o6/LD01?l0003o`J[3ol6Z`ol00003okbWa0;o00001?nbWL<01?l0003oZiW4oj^Ia?n[
VL@3o`0000;oXY3200?o0000oi^=`onKSL<00_nKSL<01?l0003oThS5oi>8aOnCR<D6o`0000KoYL?_
00?o0000ojG3konU`nl00ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co000000CoYL?_o`000?nU
`noo0000:?ooool00ol0003oooooooooo`0Booooo`002Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Dooooo`Co000000?oYL?_o`000?l000000_l0
00000onU`noo0000o`000003o`000004okSg/ol0003o0000om3l]`?o000000?oiOblo`000?l00000
0_o[n/02o`0000;ok_C41ol000001?o]i/Oo0000on_Paol00003onOJa`04o`000?oTdlKoi=?6o`00
00;oh<c500?o0000omg;b?l000000ooHa<H01Ol0003oe;g4o`000?o?^lKo000000?obkC300?o0000
olJaaOl000000oo1Z/<01_l0003o_:O4okbWa?l0003o^:71o`0000Co/Yg300Ko0000oj^Ia?l0003o
0000ojVD`Ol00004oj:@`P05o`000?nKSL?oVhg3oi^=`ol000000onCR<D00ol0003oRhC6oh^4aP02
oh^4aP;o00001OnU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000
ojG3k`03ojG3k`?o0000:?ooool00ol0003oooooooooo`0Aooooo`002Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03ogMgMoo<c<co000000Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`?o00000_nU`nl3o`0000;o
YL?_1_l000001OngmkKo0000o`000?l0003od?bg00;o000000KohOfko`000?l0003oj?^no`000?o[
n/06o`000004oo7^`ol0003ol>[3o`0000;oknG41Ol000001OoWf/Oo0000onCCa_oTdlKo000000Co
h<c500Go0000omS4a_oHa<Kof<C6o`000003omBma003o`000?o;]<?obkC300?obkC300?o0000ol6Z
`oo1Z/<00_o1Z/<00ol0003o_:O4o`000003okRQ`@04o`000?nbWL?o/Yg3ok:M``;o00001?nYU<40
1Ol0003oXY32oj:@`_nRT<;o000000?oVhg300Go0000oi>8aOnCR<GoThS5o`000004oh^4aP04o`00
0?n1OlSo0000ojG3k`Go00001OnU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_
ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000001?l0
000Yooooo`03o`000?oooooooooo013ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?ok^k^odA4A?l000001_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00cooooo0ol00002ojG3k`?o00000_nU`nl3o`0000?oWMgm
0_l000001OngmkKo0000o`000?l0003od?bg00;o000000CohOfko`000?l0003oj?^n0ol000002Oo`
mL3o0000oo3b`Oo`l/7o0000oo7^`ol0003ol>[3o`000003onoUa003o`000?o/glCo000000;oj][4
00Go0000onCCa_oTdlKoi=?6o`000004on3<a@;o000000?of<C6o`000?oD_L@00ooD_L@00ol0003o
bkC3ol^d``02ol^d``;o00001?o1Z/<2o`0000Go^:7100Go0000ok:M`ol0003o[iRoo`000004ojVD
`@05o`000?nRT<;oXY32oj:@`_l000000_nKSL<?o`0000;oMg_:0ol00003ojG3k`?o00001OnU`nl0
1?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3k`Co0000
0_nU`nl00ol0003oYL?_ojG3k`03ojG3k`;o00000onU`nl00ol0003oYL?_o`00000Xooooo`03o`00
0?oooooooooo013ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool01Oooool2o`0003Sooooo00?o0000oooooooo
ool02?ooool3o`0000;oYL?_0ol000000onU`noo0000ojG3k`02o`0000?oYL?_00Co0000oigMoOl0
003o/?WX1?l000000oo@o;Oo0000omkm^P02o`000005onGl_?l0003o0000o`000?o^mkl00_l00002
oo3b`@03o`000?oak/?o000000;ol>[300Ko0000onoUa?o_iLCo0000oncOa?l00003on[Ja0;o0000
00?oi=?6o`000?oPc<D00ooPc<D01?l0003og<K3omc6`ol00004omBma003o`000?o?]l;o000000;o
bkC300Co0000olJ^`Oo6[/7o00000_o1Z/<00ol0003o_JC0o`000005okRQ`@;o00000on_V;l00ol0
003oZIC1ojVD`@02ojVD`@03o`000?nRT<;oXY3200?o00000_nKRKl01Ol0003oU8G1oiB5`OnDQL7o
000000CoSH;200?o0000ohEna?n5O/@01?l000000omgNl[o0000o`000002o`0000?oVmgm00Co0000
ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000ojG3kol000000_l000000onU`noo
0000ojG3k`04ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl3o`0002So
oooo0_l0000@ooooo`00:_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo
0ol00002ojG3k`?o00001?nU`nl2o`0000GoYL?_0_l000000on`nNSo0000o`000004o`00000?omkm
^_l0003o0000onGl_?l0003ok?Vmo`000?o^mkoo0000oo3e`?l0003ol?;1o`000?oak/?o000000;o
l>[300Co0000onoUa?o_iLCo00000_o/gl@01?l0003oj][4on[Ja?l00002onKD``;o00000ooPc<D0
1Ol0003og<K3omc6`ooLa/?o000000?oe;g400Ko0000olng`_o?]l;o0000ol^d`ol00003olJ^`@03
o`000?o1Z/?o000000?o_JC000Oo0000okRQ`OnhXL7o^:71o`000?neW;ko000000Co[iRo00Wo0000
ojVD`OnYU<7oZIC1o`000?nRT<;o0000oj6=__l000001?nKRKl01Ol0003oU8G1oiB5`OnDQL7o0000
00CoSH;200Co0000ohEna?n5O/Co00000_mlN/D4o`0000?oVmgm1Ol00002ojG3k`03o`000?nU`noo
YL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_0_l00005ojG3k`03o`000?nU`noo
YL?_00?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3kol000001?l0
000Yooooo`03o`000?oooooooooo00kooooo000Zooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool00ol00002ojG3k`?o00000_nU`nl00ol0003oYL?_o`000002o`0000;oYL?_00Go0000
ojG3konU`nooYL?_o`000002ok3ij0Go000000?ofofjo`000?l000000ol000001_o/nKgo0000onkg
_ol0003ol?G0o`0000;ol?;100Go0000oo7^`ol0003ol>[3o`000003onoUa003o`000?o/glCo0000
00?oj][400So0000onKD`ooVe<?o0000on?>`ol0003oh<c5o`0000?og<K300Go0000omRo`_l0003o
e;g4o`000004olng`P03o`000?o6[/7oaZk100?oaZk100?o0000okfT`?nmY<000onmY<000ol0003o
^:71o`000003okFL_P05o`000?n_V;oo[iRoojnH_ol000000_nYU<43o`0000?oXHfn00Go0000oi^9
_onKRKooVhVoo`000003oiB5`@03o`000?n=P/;oSH;200;oSH;200Go0000ohEna?n5O/CoQGk4o`00
0002ogaja@03o`000?mcM/OoLgK700?o000000?oH77=o`000?l000001OnU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3
k`04ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl01?l0003oYL?_ojG3
konU`nl3o`0000CoYL?_0_l0000Xooooo`03o`000?oooooooooo00kooooo000Zooooo`03o`000?oo
oooooooo03[ooooo0ol00003ojG3k`Co00000_nU`nl4o`0000GoYL?_00?o0000ojG3kol000000_n`
nNP4o`0000;ofofj1?l000001ooZn[co0000o`000?o^mkoo0000oo3e`?l000000_o`l/400ol0003o
lNk3o`000002oo3Z``06o`000?o_iLCoknG4o`000?o/glCo00000ooZf/@01?l0003oi]C3onKD`ol0
0003on?>``05o`000?oLa/?og<K3omc6`ol000000ooH_l800ol0003ockO2olng`P03olng`P03o`00
0?o6[/7oaZk100?oaZk100?o0000okfT`?nmY<001?nmY<000ol0003o]IbnokFL_P02okFL_P04o`00
0?n_V;oo[iRoojnH_`?o00000_nWT;d01Ol0003oXHfnoj6=__nQSKko000000CoVhVo00Go0000oiB5
`OnDQL7oU8G1o`000003ohf2`P05o`000?n5O/CoQGk4ohEna?l000000omlN/D01Ol0003oLgK7og=f
aol0003oJW;900;o000000?oDfc>o`000?nU`nl00_nU`nl3o`0000GoYL?_00Co0000ojG3konU`noo
YL?_0ol00005ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl01_l0003o
YL?_o`000?l0003oYL?_o`0000GoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0000X
ooooo`03o`000?oooooooooo00gooooo000Zooooo`;o0000>?ooool3o`0000?oYL?_0ol00003ojG3
k`?o00001?nU`nl01?l0003oYL?_ojG3konU`nl8o`000003omWm^ol0003ofofj00;o000000?oj?^l
o`000?oZn[`00_l00002onkg_`03o`000?o`mL3o000000_o000000Gok=o4o`000?oZf/Coj][4o`00
0002onKD``03o`000?oSc/?ohlk300;ohlk30_l000000ooLa/?o0000omRo`P03omRo`P03o`000?o?
]l;ockO200;ockO200?o0000ol^a`?l000000oo6[/400ol0003o`ZRoo`000004okfT`0;o00001?ne
W;h01_l0003o[iRoojnH_ol0003o[I>lo`0000CoYi2m00Go0000oj6=__nQSKkoXHfno`000003oi^9
_`05o`000?nDQL7oU8G1oiB5`Ol000001?n=P/801?l0003oQGk4ohEna?l00003ogaja@05o`000?mc
M/OoLgK7og=faol000000_mZL/T5o`0000;oRNCi00?o0000ojG3konU`nl00onU`nl4o`0000?oYL?_
00Co0000ojG3konU`nooYL?_0ol00005ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0
003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_00?o0000ojG3kol000001?l0000Xoooo
o`03o`000?oooooooooo00gooooo000Zooooo`03o`000?oooooooooo03Gooooo0_l00002ojG3k`Co
000000?oYL?_o`000?nU`nl00ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`07
o`000?o:olco0000o`000?oIoK_o0000om_m^P02o`000007onSk_?l0003oj_Zlo`000?o/nKgo0000
onkg_`04o`000004oo;`_ol0003ol^c0o`0000;olNS100Go0000oo3T`Oo`i<7o0000onkO`P03o`00
0005on[Ja?l0003oi]C3onKD`ol000000ooSc/<01?l0003oglO2omo7`_l00004omRo`P03o`000?oC
^L7o000000;ockO200Oo0000ol^a`?o;/L3obk70o`000?o6[/7o000000?o`ZRo00Co0000okfT`?nm
Y<3o00000_njWkd00ol0003o]IbnokFL_P02okFL_P;o00000on]Tk`01Ol0003oYi2mojN@_OnWT;go
000000?oXHfn00?o0000oi^9_onKRKl04_l00003og=fa`05o`000?mZL/WoJW;9o`000?mPKl/00_l0
00000om7Iloo0000o`000002o`000006ojG3kol0003o0000o`000?nU`noo00001OnU`nl4o`0000;o
YL?_00?o0000ojG3konU`nl00onU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001?nU`nl2o`0002Sooooo00?o0000ooooooooool03?ooool002[o
oooo00?o0000ooooooooool0<_ooool3o`0000;oYL?_1?l00002ojG3k`Co00001OnU`nl01?l0003o
YL?_o`000?l00002ojG3k`08o`000?nU`nooYL?_ojG3kol0003ob_o<o`000?oHo/42o`000005om_m
^_l0003oiOblo`000?oXnk`00_l000000oo/nKgo0000o`000002o`000006oo7b__l0003ol_2oo`00
0?obk<3o00000_oaj<401?l0003ol>C1oo3T`Ol00002onkO`P03o`000?o[f/;ojm[200;o000000?o
i]C3o`000?oSc/<00_oSc/<01Ol0003oglO2omo7`_oOal;o000000?of;o200Ko0000om>i`OoC^L7o
0000olng`_l00005ol^a`003o`000?o2Z;oo`ZRo00;o`ZRo00?o0000okfT`?l000000onjWkd01?l0
003o]IbnokFL__neW;h2o`0000Co[I>l00Go0000ojN@_OnWT;goYi2mo`000003oj6=_P?o00000_nK
Q[`01Ol0003oUH>moiF3_OnEPkgo000000?oSh2o00Go0000ohQm`?n8OL3oR7g0o`000002oh5j`PGo
00000omZL/T00ol0003oH6o;of1_b`02o`0000;oAfO?0ol00004ojG3k`03o`000?nU`noo000000;o
000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00Co
YL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_ojG3
k`?o0000:?ooool00ol0003oooooooooo`0;ooooo`00:Oooool00ol0003oooooooooo`0`ooooo`?o
00000_nU`nl3o`0000?oYL?_0ol00004ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001OnU`nl00ol0
003oYL?_o`000002o`000003omSn`Ol0003ofOfk00;o000000?oiOblo`000?oXnk`01Ol000001_o`
mKgo0000oo7b__l0003ol_2oo`0000;ol^c000?o0000oo7X`Ol000000_o`i<401?l0003ok]o2onkO
`_l00003on_J`P03o`000?oXe<7o000000?ohlk300Wo0000omo7`_oOal;oglO2o`000?oK`/7o0000
omRo`_l000001?oC^L400ol0003obk70ol^a`003ol^a`0;o00001?o2Z;l2o`0000Co^Ynm00Ko0000
okFL__neW;ko0000ok:G_?l00004ojfC_003o`000?nWT;goYi2m00;oYi2m0ol000000onPRK_o0000
oi^6_002oi^6_003o`000?nEPkgoUH>m00;oUH>m00Go0000ohn0_on?P;ooSh2oo`000003ohQm`004
o`000?n1N/;oPG[2o`0000;oNWO30ol000001_mZL/Wo0000of1_bomPKl_o0000oeI/c@?o00000_lj
Hm000ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`00
0?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl01_l0003oYL?_o`000?l0003oYL?_o`00
00GoYL?_1?l000000onU`noo0000o`00000Xooooo`03o`000?oooooooooo00_ooooo000Yooooo`?o
0000;Oooool3o`0000;oYL?_0ol00002ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3
konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`000006ojG3kol0003o0000
omWm^ol0003ohobl0_l000002?oXnkco0000o`000?l0003okoNmo`000?o`mKgo00000_oal[h2o`00
00;ol^c000Ko0000oo7X`Ooaj<7o0000oo3T`Ol00002onkO`P05o`000?o[f/;ojm[2on_J`_l00000
0_oXe<42o`000003on?>`ol0003oglO200;oglO200Go0000om_2`OoK`/7ofl;1o`000004om>i`@03
o`000?o?/koo000000?obk7000Co0000olN[__o7Zkko00000_o2Z;l00ol0003o_Z:mo`000005okZO
_@;o00000onbUk`00ol0003o[I>lojfC_002ojfC_003o`000?nWT;go000000;o00000onPRK/00ol0
003oVhJloi^6_002oi^6_005o`000?nEPkgoUH>moiF3_Ol000000on?P;l01Ol0003oR7g0ohQm`?n8
OL3o000000?oPG[200Go0000ogYg`omjMl?o0000og9da@02o`0000?oH6o;00Co0000oeI/cOmFK<go
EVc=0_l000000oljHm3o0000o`000003oh;TmP03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`04
o`000?nU`nooYL?_ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o0000
ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`;o0000:?ooool00ol0003oooooooooo`0:
ooooo`00:Oooool00ol0003oooooooooo`0Zooooo`?o00000_nU`nl3o`000004ojG3kol0003oYL?_
ojG3k`Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_00Co
0000ojG3kol0003o00000onU`nl01Ol0003of?k1o`000?l0003ohobl00;o00000_oXnk`2o`00000;
onog_Ol0003ol?Fmoo3e_Ol0003olO:no`000?obl;oo0000oo;/`?l000000_oaj<401?l0003ol>C1
oo3T`Ol00002onkO`P04o`000?o[f/;ojm[2o`0000;oj=C100?o0000onG?`OoUcl400_l00003omo7
`P05o`000?oK`/7ofl;1om_2`Ol000000ooC^L401ol0003ock>oolnc_oo?/koo0000ol^a`?l00000
0oo7Zkh00ol0003o`ZRoo`000003okjR_@04o`000?njWkgo^YnmokZO_@;o00001?nbUk`01?l0003o
[I>lojfC_?n]Tk`3o`0000;oYHfk00?o0000oj29^onPRK/00_nPRK/01Ol0003oVhJloi^6_?nKQ[co
000000?oUH>m00Go0000ohn0_on?P;ooSh2oo`000003ohQm`005o`000?n1N/;oPG[2oh5j`_l00000
0omjMl<00ol0003oLWC5og9da@02o`0000;oH6o;00Go0000oeI/cOmFK<go0000odaYc`02o`000003
obiOdOl0003o000000?o000000GoYL?_o`000?l0003oYL?_o`000005ojG3k`Co00000_nU`nl00ol0
003oYL?_ojG3k`03ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3
konU`nooYL?_0ol0000Vooooo`?o00002oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oo
oooooooo02Oooooo0ol00002ojG3k`?o00001?nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl00ol0
0005ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl01?l0003of?k1o`000?oRoL<7o`0000;o
koNm00Oo0000oo3e_Ol0003olO:no`000?obl;oo000000;ol^c01?l000001Oo`i<7o0000onkO`_o^
gl;o000000;ojm[200Co0000onSD`OoXe<7o00000ooUcl401Ol0003ohLW0o`000?oOal;o000000?o
fl;100Go0000omJl_ol0003odkW1o`000005olnc_`03o`000?o7Zkkoaj^n00?oaj^n00?o0000okjR
_OnnX[d00_nnX[d01_l0003o^YnmokZO_Ol0003o]YZko`0000Co/YNl00Ko0000ojfC_?n]Tkco0000
ojZ@^_l00004ojF=^`05o`000?nPRK_oX8Vkoj29^ol000000onKQ[`00ol0003oUH>moiF3_@02oiF3
_@05o`000?n?P;ooSh2oohn0_ol000000on8OL001?l0003oPG[2oh5j`_l00003ogYg``05o`000?mb
M<GoLWC5o`000?m[LLL00ol00003oeI/c@03o`000?m<JLooC6W?00;o000000?o;UoAo`000?lSGM80
0_l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00?oYL?_
1?l000001?nU`noo0000ojG3kol0000Rooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`00
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool09Oooool2
o`0000;oYL?_0ol00002ojG3k`03o`000?nU`noo000000;o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00001?nU`nl00ol0003oYL?_o`000002
o`000003on;m`ol0003o000000;o00000_o/nK`2o`000004onog_Ol0003ol?Fmo`0000;olO:n1_l0
00000oobikoo0000oo3S`005o`000003on_J`_l0003oj=C100;oj=C100Co0000onG?`OoUcl7o0000
0ooQbL001Ol0003ofl;1om_2`OoK`/7o000000?oe[bo00?o0000olnc_oo?/kl01?o?/kl00ol0003o
aj^nolN[_P03olN[_P03o`000?nnX[go_Z:m00;o_Z:m00?o0000okZO_Ol000000onfV[/00ol0003o
/YNlok:G_002ok:G_0;o00000_nZT;X00ol0003oYHfkojF=^`02ojF=^`05o`000?nPRK_oX8Vkoj29
^ol000001?nKQ[`00ol0003oUH>mo`00000<o`000005oh5j`_l0003oNWO3ogYg`ol000000ombM<D0
1?l0003oJg77of]aaom[LLL2o`000006oeI/cOl0003oC6W?odaYcol0003o@VOA0ol000000olSGM;o
0000o`000002ojG3k`?o00001OnU`nl01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3
kol000000_l000000onU`noo0000ojG3k`03ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`00
0?nU`nl00onU`nl3o`0001kooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0004o`0000;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02;ooooo1?l000000onU`noo0000o`000002
o`0000;oYL?_1?l00005ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l000001OoRoL?o0000
o`000?oZn[go000000;ok?Vl0_l000001?o_mkgo0000oo3e_Oo`mKd3o`000007oo?^__l0003ol^^o
oo;[_ol0003ol^Noo`000002oo3S`005o`000?o_gl3okmo0o`000?o/f/000ol000001OoXe<7o0000
onG?`OoUcl7o000000CohLW000Go0000om_2`OoK`/7ofl;1o`000003omJl_`03o`000?o?/koock>o
00?ock>o00?o0000ol^^_Ol000000oo7Zkh00ol0003o`jJlo`000003okjR_@;o00001?nfV[/01?l0
003o/YNlok:G_?nbUk`2o`0000CoZY2j00Go0000ojF=^onUSK_oYHfko`000004oj29^`03o`000?nK
Q[co000000?o00000_nFPK/01Ol0003oT7jloi1n_?n@O[co000000?oRgbm00?o0000ohEi__n5NKh0
1?l000001OmjMl?o0000og9daOmbM<Go000000?oJg7700Co0000of=_b_l0003o00000om<JLl01?l0
003o@VOAod9WdOl00002ob=MdP?o00000on;i?/00ol0003oYL?_ojG3k`02ojG3k`Co00000onU`nl0
1?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU
`noo000000Co00006_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Q
onk^kP05ooooo`?o00008?ooool3o`0000;oYL?_0ol00002ojG3k`Co00001?nU`nl01?l0003oYL?_
ojG3konU`nl3o`0000GoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`noo000000;o
00000_nU`nl01_l0003oh_g3o`000?l0003oj_Zmo`0000;ok?Vl0_l00002onog_@Co000000?ol_6m
o`000?l000000_objkl00ol0003ol^Noo`000002oo3S`004o`000?o_gl3okmo0o`0000;ok=[000Co
0000on[E`?oZeL3o00000ooUcl402Ol0003ohLW0on79`?oQbL3o0000omg4`?l0003ofl;1o`000003
omJl_`03o`000?oB][ko000000?ock>o00Co0000ol^^_Oo;[[go00000_o7Zkh01?l0003o`jJlol>V
_?l00002okjR_@03o`000?nkW[_o000000Co]YZk00Ko0000ok:G_?l0003o0000ojnC^_l00004ojZ@
^P03o`000?nUSK_oYHfk00;oYHfk00?o0000oj29^ol000000ol00002oi^4^P05o`000?nFPK_oUX6k
oiJ1^ol000000on@O[`01Ol0003oRgbmoh]l_On;O;go000000?oQGVn00?o0000ogmg`?moMl001Ol0
0004of]aa`03o`000?mSKl[oHfo:00;o000000?oC6W?o`000?m2Im400_m2Im43o`000003oaULdol0
003o000000Co000000GoYL?_o`000?l0003oYL?_o`000005ojG3k`Co00000_nU`nl00ol0003oYL?_
ojG3k`03ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_0_l0000Fooooo`?o0000
3?ooool00ol0003oooooooooo`09ooooo`001_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool07Oooool3o`0000;oYL?_0ol00002ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Co
00000onU`nl01?l0003oYL?_ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`0:o`000?oRoL?o0000onOjcOl0003oj_Zmo`000?o/nKco0000onkh_0Co000000Kol_>mo`000?ob
lKgo0000oo?^__l00002oo;[_`;o00000oo`hl001_l0003okmo0onoO`?l0003ok=[0o`0000?oj]G0
0_l000000ooUcl7o0000on79`002on79`005o`000?oMa<3ogLC0omg4`?l000000ooF_;l01ol0003o
d[Jnom:f__oB][ko0000olnc_ol000000oo;[[d00ol0003oaj^no`000003ol>V_003o`000?nnX[go
000000?o^ijk00Co0000okJJ^onfV[_o]YZk0_l00004ojnC^P05o`000?nZT;[oZY2jojZ@^_l00000
0onUSK/3o`0000;oWhNi00Go0000oi^4^_nKQ;[oVhBjo`000004oiJ1^`05o`000?n@O[coT7jloi1n
_?l000000on;O;d01Ol0003oQGVnohEi__n5NKko000000;oOgO000?o0000ogYe`_mjML800ol00002
of]aa`05o`000?mSKl[oHfo:o`000?mKKL`00_l00003od9Wd@04o`000?liIM?o0000o`0000;o6EcC
1Ol00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_
o`000002o`000003ojG3kol0003oYL?_00CoYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_
0ol0000Booooo`?o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06_ooool4o`000007ojG3kol0003o0000o`000?nU`noo0000ojG3k`02
o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU
`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU
`noo000000;o000000Coio[=o`000?oZn[go00000_o/nK`3o`000008oo7e_Ol0003ol_>mo`000?ob
lKgo0000oo?^__l00002oo;[_`03o`000?obikoo000000;ol>?000Co0000onoO`?o_gl3o00000_o/
f/001?l0003oj]G0on[E`?l00002onO@`0;o00000ooQbL001Ol0003ogLC0omg4`?oMa<3o000000?o
e[bo00?o0000om:f__oB][h00_oB][h00ol0003objjmol^^_@03ol^^_@03o`000?o3Y[co`jJl00?o
`jJl00?o0000ok^N^onkW[/00_nkW[/01_l0003o]YZkokJJ^ol0003o/iJio`0000Co[i>j00?o0000
ojZ@^_nZT;X00_nZT;X3o`000003ojB9^?l0003oWhNi00?oWhNi00Go0000oi^4^_nKQ;[oVhBjo`00
0003oiJ1^`05o`000?n@O[coT7jloi1n_?l000000on;O;d01Ol0003oQGVnohEi__n5NKko000000?o
OgO000Go0000ogYe`_mjML;o0000og=ca003o`0000?oHfo:00?o0000oe]]c?mKKL`00_l00002od9W
d@03o`000?liIM?o000000?o6EcC1Ol00002ojG3k`Co00001?nU`nl01?l0003oYL?_ojG3konU`nl3
o`0000GoYL?_00?o0000ojG3kol000000_l000000onU`noo0000ojG3k`03ojG3k`03o`000?nU`noo
000000Co00003_ooool4o`0001?ooooo00?o0000ooooooooool02?ooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool05oooool3o`0000;oYL?_0ol00003ojG3k`?o0000
1OnU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003o
YL?_ojG3k`03ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`00
0003ojG3kol0003oio[=00;o00000_o/nK`02ol0003okoJmo`000?oamKgo0000oo;c_Ol0003ol_6m
o`000?ock[ko000000;ol^^o00?o0000oo;W_ol000000_o`hl001?l0003okmo0onoO`?l00002oncJ
`005o`000?oZeL3oj]G0on[E`?l000000_oWd<001Ol0003ohl_0o`000?oQbL3o000000?ogLC000Go
0000omVn_ol0003oe[boo`000005om:f_P03o`000?o;[[gobjjm00;objjm0_l00004ol>V_0;o0000
1?nkW[/00ol0003o]YZko`000003ok>F^@05o`000?n_Tk[o[i>jojnC^_l000000onZT;X2o`0000?o
Y8Vh00?o0000oin7^OnOQkT00_nOQkT01Ol0003oVhBjoi^4^_nKQ;[o000000?oUX6k00Go0000oi1n
_?n@O[coT7jlo`000003oh]l_@05o`000?n5NKkoQGVnohEi__l000000omoMl001Ol0003oNWG2ogYe
`_mjML;o000000?oLg?40_l000001_mSKl[o0000oe]]c?mKKLco0000oe=/c`?o00000_liIM<2o`00
0003oaULdol0003o4UcD00;o000000?o04?1o`000?l000001?nIgOh00ol0003oYL?_ojG3k`05o`00
00?oYL?_00Co0000ojG3konU`nooYL?_0ol00005ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl2
o`0000[ooooo0ol0000Gooooo`03o`000?oooooooooo00Sooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c005ooooo`;o00005_ooool2o`0000;oYL?_0ol00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`02ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co0000ojG3konU`noo
YL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000?oYL?_00Co0000onOjcOl0003oj_Zm0ol00000
1_o_m[go0000oo7e_Ol0003ol_>mo`0000;ol_6m00?o0000oo?^__l000000_objkl4o`000007oo3S
`?l0003okmo0onoO`?l0003ok=[0o`000003on[E`004o`000?oWd<3oim30o`0000?ohl_000Go0000
omg4`?oMa<3ogLC0o`000003omVn_`03o`000?oB][kod[Jn00?od[Jn00?o0000olja_Ol000000_o;
[[d01?l0003oaZVlolJY_?l00002ol>V_004o`000?noXK_o_j6ko`0000Co^ijk00?o0000ok>F^Onc
U[T00_ncU[T00ol0003o[i>jojnC^P02ojnC^P?o000000?oZ8bho`000?nTRKP00onTRKP01Ol0003o
WhNioin7^OnOQkWo000000?oVhBj00?o0000oiJ1^onFPK/00_nFPK/01Ol0003oT7jloi1n_?n@O[co
000000?oRgbm00Go0000ohEi__n5NKkoQGVno`000002ogmg`005o`000?mjML;oNWG2ogYe`_l00000
0omcLl@01?l0003oKG;7o`000?l00003oe]]c004o`000?mCK<ooDfc?oe=/c`?o000000Go<FGEo`00
0?l0003o0000oa9Le004o`0000?oVMgn1?l00002ojG3k`03o`000?nU`nooYL?_00?oYL?_1?l00003
ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl01?l0003oYL?_ojG3konU`nl3o`0000Kooooo
0ol0000Jooooo`03o`000?oooooooooo00Sooooo000Xooooo`03o`000?oooooooooo01;ooooo1ol0
00000onU`noo0000ojG3k`02o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl01?l0003oYL?_o`00
0?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_
1?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oio[=o`000003o`000005onkh
_Ol0003o0000oo7e_Ol000000_oblkd00ol0003ol_6mo`000005o`000004oo;W__l0003olN>ooo7S
_`Go000000Gok=[0o`000?oZeL3oj]G0o`000002onO@`003o`000?oSbl3ohl_000;ohl_000Go0000
omg4`?oMa<3ogLC0o`000003omVn_`;o00000ooB][h01_l0003oc[6molja_Ol0003objjmo`0000?o
aZVl00?o0000ol>V_?l000000onoXK/01?l0003o^ijkok^N^onkW[/2o`0000Co/iJi00Co0000ojnC
^_n_Tk[o[i>j0_l00004ojR<^005o`000?nTRKSoY8VhojB9^?l000001?nOQkT01_l0003oVhBjoi^4
^_nKQ;[o0000oiJ1^a7o000000?oOgO0o`000?mjML800_mjML801Ol0003oLg?4og=ca?mcLlCo0000
00;oKG;71?l00003oe=/c`04o`000?m<K=;o0000o`0000?o<FGE2Ol000000olo^nko0000ojG3k`03
ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl4o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl4o`000005ojG3kol0003oYL?_o`000?ooool01?l0000Mooooo`03o`000?oo
oooooooo00Sooooo000Xooooo`03o`000?oooooooooo00kooooo1?l00002ojG3k`?o00000_nU`nl4
o`0000CoYL?_00Co0000ojG3konU`nooYL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_
00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00?o
YL?_0ol00003ojG3k`0:o`000?nU`nooYL?_ojG3kol0003oio[=o`000?oRkMSo0000onkh_@;o0000
0_oamKd00ol0003ol_>mo`000003o`000004oo?]__l0003olnZnoo?Z_P;o00000ooahkl01Ol0003o
kmnoonoO_ol0003okM^o00?o000000Goj]G0o`000?oWd<3oim30o`000003on?;`005o`000?oOa[oo
0000omg4`?l000000ooI_[l01_l0003oeKVnomFi__l0003od[Jno`0000Coc[6m00?o0000olJY_?o6
ZK`00oo6ZK`00ol0003o_j6koknQ^`02oknQ^`04o`000?nkW[_o^ijko`0000;o]iVi00?o0000ok>F
^OncU[T00_ncU[T3o`000003ojb?^?l0003oZ8bh00?oZ8bh00Go0000ojB9^?nTRKSoY8Vho`000003
oin7^@Oo00000_nFOkP01Ol0003oTWfioi9m^OnBOKWo000000?oSW^j00Go0000ohUi_?n9NKcoRGVl
o`000002ohAh_@Ko00000omcLl@01?l0003oKG;7ofebaol00002ofMab@?o00000_mCK<l00ol0003o
C6cBo`000003oc5Ue@04o`000?l[ImSo0000o`eOe`?o000000?o04W3o`000?l000000_l00002ojG3
k`?o00001OnU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00CoYL?_1?l000000onU
`noo0000ojG3k`03ojG3k`?o00008Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`0<ooooo`?o00000onU`nl3o`0000;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Go
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl00ol0003oYL?_o`000002o`000007
on;]f?l0003ok_Rmo`000?o_m[go0000oo7e_@04o`000004oo?__Ol0003olnfno`0000;olnZn00?o
0000oo;W__l000000_oahkl01?l0003okmnoonoO_ol00002ongK_`03o`000?o[ekoojmNo00;o0000
00?oim30o`000?oSbl000_oSbl001Ol0003oglJoomo6_ooOa[oo000000?ofKjo00?o0000omFi__oE
^Kh00_oE^Kh00ol0003oc[6molja_@03olja_@03o`000?o6ZKcoaZVl00?oaZVl00?o0000oknQ^ono
XK/00onoXK/2o`0000?o]iVi00Co0000ok>F^OncU[Wo/iJi0_l00004ojb?^005o`000?nXS;SoZ8bh
ojR<^?l000001?nTRKP3o`000003oij4]ol0003oVh:h00;oVh:h00Go0000oiIo^?nFOkSoUWnho`00
0003oi9m^@05o`000?n>Nk[oSW^johik^_l000000on9NK`01Ol0003oQ7RmohAh_On4N;go000000?o
OgJo1Ol00003ofeba`05o`000?mWLLWoIg79o`000?mQLLd00ol00002oda/dP;o00000_laIMD00ol0
003o:fOHo`000002o`eOe`So00000onRd?P01?l0003oYL?_ojG3konU`nl3o`0000GoYL?_00?o0000
ojG3konU`nl00ol00005ojG3k`03o`000?nU`noo000000Co00008Oooool00ol0003oooooooooo`08
ooooo`009oooool2o`0000_ooooo0_l00002ojG3k`Co000000?oYL?_o`000?nU`nl00_l00002ojG3
k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00?oYL?_0ol00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3
konU`nooYL?_1Ol000001OoRkMSo0000onkh_Ol0003okoJm00Co000000Col_6mo`000?ockkgo0000
0_ockKh01Ol0003olnZno`000?obikko000000?olN>o00?o0000onoO_ol000000_o]fkl01_l0003o
jmNoon_G_oo[ekoo0000onSB_`;o00000ooSbl001?l0003oglJoomo6_ooOa[l2o`000003omVn_ol0
003oeKVn00CoeKVn00?o0000olja_Oo>/Kd00_o>/Kd00ol0003obZblo`000003olJY_003o`000?o2
Y;_o000000Co_j6k00?o0000okNI^OngVKT00_ngVKT01_l0003o/iJiok>F^Ol0003o/9:ho`0000Co
[8nh00?o0000ojR<^?nXS;P00_nXS;P00ol0003oY8Vho`000002o`0000?oWXBg00Go0000oi^2^?nK
P[SoVh:ho`000004oiIo^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVlohUi_?n9
NKco000000?oQ7Rm00Go0000ogmf_omoM[ooOgJoo`000002og]e`P?o000000?oKG;7o`000?mWLLT0
0_mWLLT01?l0003oHG7=of5acOl00002oda/dP03o`000?m5KMGo000000;o00000_l[ImP2o`000004
o`eOeol0003o0000o`1Hd@Co00000_nRd?P5o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`00
00?oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`;o00008Oooool00ol0003oooooooooo`07
ooooo`009oooool00ol0003oooooooooo`07ooooo`Co000000?oYL?_o`000?l000000_l00002ojG3
k`Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000
ojG3kol000000_l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Go00000onU`nl00ol0003oh^gHo`000002
onkh_@?o000000ColO>mo`000?oblKgo00000_ockkd01Ol0003olnfno`000?ocj[ko000000;ol^Nn
00Ko0000oo7S_ooahkoo0000onoO_ol00003ongK_`04o`000?o[ekoojmNoo`0000;oj=:o00Go0000
onG=_ol0003ohl_0o`000003omo6_`04o`000?oL`Koog<6oo`0000GoeKVn00?o0000om6d_Ol00000
0_o>/Kd01?l0003obZblolZ/_?l00002olJY_004o`000?o2Y;_o`ZBko`0000?o_j6k0_l00005okNI
^@;o00000_n`T[P00ol0003o[8nhojb?^002ojb?^004o`000?nXS;SoZ8bhojR<^0?o00000_nSQkL0
0ol0003oWXBgoij4]`02oij4]`05o`000?nKP[SoVh:hoi^2^?l000000onFOkP01Ol0003oTWfioi9m
^OnBOKWo000000?oSW^j00Go0000ohUi_?n9NKcoRGVlo`000003ohAh_@03o`000?moM[ooOgJo00;o
OgJo00Go0000og]e`_mkML;o0000ogIda002o`0000?oIg7900Co0000of5acOmQLLgoHG7=0_l00000
0om<K=;o0000odE]e@02odE]e@?o000000Co9V[Ko`000?l0003o36GJ0_l000000ol0H=Co0000o`00
0002o`0000;oM]Cn00?o0000ojG3konU`nl00onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_1?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`?o00008?ooool00ol0003ooooo
ooooo`07ooooo`009oooool00ol0003oooooooooo`04ooooo`?o00000_nU`nl3o`0000;oYL?_1?l0
0004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000GoYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00Go0000ojG3konU`nooYL?_o`000002on;]
f007o`000?o^n;go0000oo3e_Ol0003olO>mo`000002oo;a_@05o`000?ockkgo0000oo?]__l00000
0_ocj[h00ol0003ol^Nno`000002oo7S_`04o`000?o_gkookmnoo`0000;okM^o00Co0000on_G_oo[
ekoo00000_oXd[l01Ol0003oiLfoonG=_ooUcKoo000000?oglJo00Go0000omc1_ooL`Koog<6oo`00
0004omFi_P06o`000?oA];godKBmo`000?o>/Kgo00000oo:[;`00ol0003oaZVlo`000003ol:T^`04
o`000?noXK_o_j6ko`0000;o^ifi00Co0000okNI^OngVKWo]iVi0_l00004ok2B^003o`000?n/SkSo
[8nh00;o[8nh0ol000000onVRKKo0000oj>7]`02oj>7]`03o`000?nNQ;OoWXBg00;oWXBg00Go0000
oi^2^?nKP[SoVh:ho`000003oiIo^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVl
ohUi_?n9NKco000000CoQ7Rm00Go0000ogmf_omoM[ooOgJoo`000003og]e`P03o`000?mfM<CoMWC4
00;o00000_mWLLT01Ol0003oHG7=of5acOl0003oFg7@00;o00000om5KMD01?l0003o@6oIo`000?l0
0002obIZf`04o`000?l<IM[o36GJo`0000;o063D1_l00003ojG3k`?o00001OnU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000GoYL?_1?l000000onU`noo0000o`00000Pooooo`03o`000?oooooooooo
00Oooooo000Wooooo`03o`000?oooooooooo00;ooooo0_l00002ojG3k`?o00000_nU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04
o`000?nU`nooYL?_ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3
kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`03o`000?nU`noo000000;oh^gH0ol00000
2Oo`mKgo0000oo7c_Ooalkgo0000oo;a_Ol0003olnnmo`000002oo?]_P03o`000?ocj[ko000000;o
l^Nn00Ko0000oo7S_ooahkoo0000onoO_ol00002ongK_`04o`000?o[ekoojmNoo`0000?oj=:o00Go
0000onG=_ooUcKooiLfoo`000003omo6_`06o`000?oL`Koog<6oo`000?oH_;ko00000ooE^Kh01Ol0
003odKBmom6d_OoA];go000000GobZbl00?o0000ol:T^oo2Y;/00oo2Y;/2o`0000?o^ifi00Ko0000
okNI^OngVKWo0000okBF^?l00004ok2B^004o`000?n/SkSo[8nhojb?^0;o00000onVRKH00ol0003o
XhNgoj>7]`02oj>7]`05o`000?nNQ;OoWXBgoij4]ol000000onKP[P00ol0003oUWnhoiIo^002oiIo
^005o`000?nBOKWoTWfioi9m^Ol000000on>NkX01Ol0003oRGVlohUi_?n9NKco000000?oQ7Rm00Go
0000ogmf_omoM[ooOgJoo`000003og]e`P05o`000?mfM<CoMWC4o`000?maM<L00ol00003of5ac@03
o`000?mKLM3oFg7@00;o00000_m5KMD00ol0003o@6oIod1_f@02o`000004obIZfol0003o0000o`aU
fP;o000000Go063Do`000?l0003o0000obbQk`04o`0000?oYL?_00Co0000ojG3konU`nooYL?_0ol0
0004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl00onU`nl2o`0001oooooo00?o
0000ooooooooool01oooool002Oooooo2Ol000000onU`noo0000ojG3k`02o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU
`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01ol000002?o>d]go0000oo3e
_Ol0003olO>mo`000?oblKgo00000_ockkd?o`000005ongK_ol0003ojmNoon_G_ol000000_oXd[l0
2Ol0003oiLfoonG=_ooUcKoo0000on78_ol0003oglJoo`000002omc1_`07o`000?oH_;kof;bnomRl
__l0003oeKVno`000004om6d_@03o`000?o:[;cobZbl00;obZbl0_l00005ol:T^`03o`000?nkWKWo
^ifi00;o^ifi00?o0000okNI^Ol000000_ndU[P00ol0003o/9:hok2B^002ok2B^006o`000?n/SkSo
[8nho`000?nZS;Ko00001?nVRKH01Ol0003oXhNgoj>7]onSQkOo000000?oWXBg00?o0000oi^2^?nK
P[P00_nKP[P00ol0003oUWnho`00000Bo`0000CoOgJo00Co0000og]e`_mkML;o00000omfM<@01?l0
003oLGC7og5daomaM<L4o`0000;oFg7@00?o0000oeIcdol000000_l00002od1_f@05o`000?llL]co
0000o`000?lUKml02_l00005ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00Co
0000ojG3konU`nooYL?_0ol0000Nooooo`03o`000?oooooooooo00Oooooo000Vooooo`?o000000?o
YL?_o`000?l000000_l00002ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000Co
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`08o`000?o>d]goc];Mo`000?o`mKgo0000oo7c_Ol0
0002oo;a_@Co000000Colnbno`000?ocj[ko00000_obikh01_l0003olNBooo7T_ol0003ol>2oo`00
00;ok]bo0_l000001Oo[ekoo0000onSB_ooXd[oo000000?oiLfo00Go0000on78_ooQb;oohLRoo`00
0003omc1_`03o`000?oH_;kof;bn00;of;bn00?o0000om6d_OoA];d00_oA];d00ol0003ocK2lo`00
0002olZ/_004o`000?o6Z;_oaZRko`0000?o`ZBk0_l00005ok^M^@03o`000?ndU[So]9Jh00;o]9Jh
00?o0000ok2B^?n`T[P00_n`T[P2o`0000;oZXbf00?o0000ojJ9]_nVRKH00_nVRKH01Ol0003oXhNg
oj>7]onSQkOo000000CoWXBg00?o0000oi^2^?l000000ol00002oiMn]P05o`000?nCOKOoTgfgoi=m
]ol000000on@NkP01Ol0003oS7Zjohaj^_n<N[[o000000?oR7Vk2?l000001OmkML;o0000ogIda?mf
M<Co000000?oLGC700?o0000ofaeb_m/MLX00ol000000omKLM3o0000oeIcd`02oeIcd`;o000000Go
@6oIo`000?llL]co?7;Lo`000003obE_g`;o000000?o3VgNo`000?l000000ol000001_nU`noo0000
o`000?l0003oV]cmo`0000GoYL?_0ol00003ojG3k`04o`000?nU`nooYL?_ojG3k`Go000000CoYL?_
o`000?nU`noo00007Oooool00ol0003oooooooooo`07ooooo`007?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo1?l00003ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_o`00
0002o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`00
0?nU`nooYL?_00;oYL?_0ol00003ojG3k`05o`000?nU`nooYL?_ojG3kol000000oo>d]d2o`0000;o
lO>m1?l000001_ockkko0000oo?/__l0003olnZno`0000;ol^Nn00Ko0000oo7T_ooai;oo0000oo3P
_ol00003onkL_`03o`000?o/f<3o000000;o000000Goj=:oo`000?oUcKooiLfoo`000004on78_`;o
000000?og<6oo`000?oH_;h01?oH_;h01Ol0003odKBmom6d_OoA];go000000;ocK2l00?o0000olZ/
_?l000000oo6Z;/01?l0003o`ZBkol:T^ol00002okjP^P04o`000?nkWKWo^ifiok^M^@;o00001?nd
U[P01?l0003o/9:hok2B^?n`T[P2o`0000CoZXbf00Go0000ojJ9]_nVRKKoYXVfo`000004oj>7]`03
o`000?nNQ;Oo000000?o00000_nKP;H01Ol0003oUgjfoiMn]_nGO[Ko000000?oTgfg00Go0000oi1k
^?n@NkSoT7^ho`000004ohaj^P05o`000?n8NK_oR7VkohQi^ol000000on5N;d00ol0003oPGNooh5g
_`03o`000003ogIda?l0003oLGC700?oLGC700Go0000ofaeb_m/ML[o0000ofQfcP02o`0000?oEW?C
00Co0000oe5ef?l0003o00000ollL]`2o`000003obE_gol0003o9WOS00So00001?nJg?d00ol0003o
YL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;o
YL?_0ol0000Looooo`03o`000?oooooooooo00Oooooo000Looooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`000003ooooool0003oYL?_00;o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o
00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000Co
YL?_00?o0000ojG3konU`nl01?l00005ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003o
YL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00?o0000ojG3kol000000oo>d]d00ol0
003ol?Fmo`000003o`000006oo;a__l0003olnnno`000?ock;ko00000_ocj[h01_l0003ol^Nnoo;W
__l0003olNBoo`0000;ol>2o00Co0000onkL_oo^g;oo00000_o/f<001?l0003ojMC0onWD`?l00003
onG=_`05o`000?oQb;oohLRoon78_ol000000_oNa;l00ol0003of;bnomRl_P03omRl_P05o`000?oD
]kgo0000om6d_Ol000001?o=/;`00ol0003oaZRkolJX^`02olJX^`03o`000?o2Y;_o000000?o_Z2j
00Ko0000ok^M^OnkWKWo0000okRI^?l00004okBF^006o`000?n`T[So/9:ho`000?n]SkKo00001?nZ
S;H01Ol0003oYXVfojJ9]_nVRKKo000000?oXhNg0ol00002oij3]@05o`000?nKP;KoVh2foi^0]_l0
00001?nGO[H01Ol0003oTgfgoi=m]onCOKOo000000?oT7^h00Go0000ohaj^_n<N[[oS7Zjo`000004
ohQi^`04o`000?n5N;goQGRmo`0000?oPGNo00?o0000ogeg`_l000000_l00003og5da`05o`000?m/
ML[oK7G:ofaeb_l000000_mXM/h2o`0000;oEW?C00?o0000oe5ef?mAMMP00_l000000ollL]co0000
oc]hh@03o`0000?o9WOS1?l000000ol7N^7o0000o`000004o`0000GoYL?_00Ko0000ojG3kol0003o
0000ojG3kol00005ojG3k`03o`000?nU`noo000000Co00007Oooool00ol0003oooooooooo`06oooo
o`007?ooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000ooooool0003o00001?nU`nl0
1?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0003o0000
0_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o0000
1?nU`nl01?l0003oYL?_ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`nooYL?_00Co00000_o>d]d4o`000006onWXc_l0003ol_6no`000?ockkko00000_ock;h0
0ol0003olnZno`000002oo;W_P03o`000?oai;oo000000;ol>2o00Oo0000onkL_oo^g;ook]boo`00
0?o/f<3o000000?ojMC00_l000000ooUcKoo0000on78_`02on78_`04o`000?oNa;oog/Boomk4_`;o
00000ooH_;h01Ol0003oe;NmomBg_OoD]kgo000000GocK2l00?o0000olJX^oo6Z;/00oo6Z;/00ol0
003o_Z2jokjP^P02okjP^P03o`000?nkWKWo000000?o^9Vh00?o0000okBF^?ndU[P00_ndU[P2o`00
00;o[Hnf00?o0000ojZ<]_nZS;H00_nZS;H00ol0003oYXVfojJ9]P02ojJ9]P?o000000?oXHFeo`00
0?nNPkD00_nNPkD00ol0003oVh2foi^0]P02oi^0]P05o`000?nGO[KoUgjfoiMn]_l000000onCOKL0
1Ol0003oT7^hoi1k^?n@NkSo000000CoS7Zj00Go0000ohQi^on8NK_oR7Vko`000003ohEh_@04o`00
0?n1MkooPGNoo`0000?oOGO21Ol00003ofaebP05o`000?mXM/koJ7K>o`000?mTN=400ol00002oe5e
f003o`000?m?NMco000000;o00000olkN>42o`000003obIghol0003o:h3X00Go00001?m]`Oh01?l0
003oYL?_ojG3konU`nl3o`0000CoYL?_00Co0000ojG3konU`nooYL?_0ol00003ojG3k`03o`000?nU
`noo000001cooooo00?o0000ooooooooool01_ooool001cooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;oYL?_1?l00004ojG3k`03o`000?nU`nooYL?_00Co0000
1?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0
003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`03ojG3
k`?o00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00_o0000olkBgOl0003o/LKYo`000?oY
j<ko0000oo;a__l0003olnnno`000002oo?/_P03o`000?ocj[ko000000;ol^Nn00Ko0000oo7T_ooa
i;oo0000oo3P_ol00003onkL_`03o`000?o/f<3o000000?ojMC000?o0000onK?`?oVcl000_l00003
on78_`04o`000?oNa;oog/Boo`0000;of[nn00?o0000omRl__l000001?oD]kd00ol0003ocK2lolf`
_002olf`_003o`000?o9Zkco000000?oaZRk0_l00005okjP^P03o`000?nhVKSo^9Vh00;o^9Vh00Co
0000okBF^?ndU[So]9Jh0_l00004ojf?]P03o`000?nZS;KoZXbf00;oZXbf00?o0000ojJ9]_l00000
0_l00003oj65]@03o`000?nNPkGoWX>e00;oWX>e00Go0000oi^0]_nKP;KoVh2fo`000003oiMn]P05
o`000?nCOKOoTgfgoi=m]ol000000on@NkP00ol0003oS7Zjohaj^P02ohaj^P05o`000?n8NK_oR7Vk
ohQi^ol000000on5N;d01Ol0003oPGNooh5g_on1Mkoo000000;oOGO200Co0000ogUga?miMlCoNGO4
1Ol00003ofQfcP04o`000?mTN=7oI7SAofAhd@;o000000?oDGGHo`000?m?NM`00_m?NM`2o`000003
oc]hhOl0003o?7oV00?o00000_l[P>P;o`0000?oXlce00?o0000ojG3konU`nl01Ol00003ojG3k`03
o`000?nU`nooYL?_00?o00007?ooool00ol0003oooooooooo`06ooooo`007?ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool00_l00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04
o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`00
0003ojG3kol0003oYL?_00CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00?o000000Ko/LKYo`00
0?oYj<ko0000oo;a__l00002oo?__P06o`000?ock;kolnbno`000?ocj[ko00000_obikh00ol0003o
lNBoo`000002oo3P_`04o`000?o^g;ook]boo`0000;ok=S000Go0000onWD`?oYe<3ojMC0o`000002
onK?`005o`000?oSbl3o0000on78_ol000000_oNa;l00ol0003of[nnomZo_P02omZo_P03o`000?oD
]kgoe;Nm00;oe;Nm00?o0000om2c_Ol000000_o=/;`01?l0003obJ^lolV[_?l00002olJX^`04o`00
0?o2Xk[o`Z>jo`0000?o_Z2j0_l00004okRI^006o`000?ndU[So]9Jho`000?naT[Oo00001?n]SkH0
1?l0003oZXbfojZ<]_nZS;H3o`0000;oYHNe00?o0000oj65]OnQQKD00_nQQKD01Ol0003oWX>eoij3
]OnNPkGo000000?oVh2f00?o0000oiMn]_nGO[H00_nGO[H01Ol0003oTgfgoi=m]onCOKOo000000?o
T7^h00Go0000ohaj^_n<N[[oS7Zjo`000004ohQi^`04o`000?n5N;goQGRmo`0000?oPGNo00Go0000
ogeg`_mmMl;oOGO2o`000003ogUga003o`000?mfN<OoMWS700?o00000_mXM/h01Ol0003oI7SAofAh
dOl0003oHG[F00;o00000om?NM`00ol0003oCWkQo`000002o`0000;o?7oV1Ol00002oc><kPKo0000
0onSc?D4o`0000;oYL?_00?o0000ojG3konU`nl00onU`nl3o`0000;oYL?_0_l0000Kooooo`03o`00
0?oooooooooo00Kooooo000Looooo`05oa0@4?ooooooooooooooool@41002_ooool2o`000003oooo
ool0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`00
0?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl0
1?l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?nU`nl01?nU`nl3o`0000?o/LKY
00?o0000onWXc_l000000_oblKh00ol0003olnnno`000002oo?/_Pgo000000Cok]boo`000?o/f<3o
00000ooYe<001?l0003oi/o0onK?`?l00003on?;`005o`000?oNa;oog/Boomk4_ol000001?oJ_kh0
1Ol0003oe;NmomBg_OoD]kgo000000;od;>m00?o0000olf`_?l000000oo9Zk`00ol0003oaZRko`00
0003ol:S^P04o`000?nnX;[o_Z2jo`0000;o^ibi00?o0000okRI^?nhVKP00_nhVKP2o`0000?o/I:g
00Go0000ojf?]_n]SkKo[Hnfo`000002ojZ<]P03o`000?nXRKGo000000?oYHNe00?o0000oj65]OnQ
QKD00_nQQKD01Ol0003oWX>eoij3]OnNPkGo000000CoVh2f00?o0000oiMn]_l000005Ol000001On5
N;go0000oh5g_on1Mkoo000000?oOGO200?o0000ogUga?miMl@00_miMl@01Ol0003oMWS7ogIhaol0
003oLWW;00?o00000omTN=400ol0003oHG[Fof5jeP05o`0000?oCWkQ1?l00002od28j`Ko00000_ln
VO<4o`0000;oT/gl00?o0000ojG3konU`nl00_nU`nl00ol0003oYL?_o`000002o`000003ojG3kol0
003oYL?_00?oYL?_0_l0000Jooooo`03o`000?oooooooooo00Kooooo000Looooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03
o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU
`nl01?l00004ojG3k`03o`000?nU`noo000000;o000000?oYL?_o`000?naa^T00_naa^T01Ol0003o
jNS>onWXc_l0003ol_6n00Oo000000Ool^Zoo`000?obikool^Noo`000?oai;oo000000;ol>7000?o
0000onkM`?o^gL001?l00002onWD`004o`000?oVcl3oi/o0o`0000Cohl_00_l000000ooNa;oo0000
omZo_P03omZo_P05o`000?oF^kko0000omBg_Ol000001?o@/kd00ol0003obJ^lolV[_003olV[_003
o`000?o2Xk[o`Z>j00;o`Z>j00?o0000okjP^_l000000onkW;T01?l0003o^9VhokRI^?nhVKP2o`00
00Co/I:g00?o0000ojf?]_n]SkH00_n]SkH2o`0000;oZ8Ve00?o0000ojF7]OnUQkD00_nUQkD01Ol0
003oXHFeoj65]OnQQKGo000000CoWX>e00?o0000oi^0]_l000000ol00002oiQn]@05o`000?nEO;Ko
UGbfoiEl]_l000000onBNkL00ol0003oSgZhohmj^002ohmj^005o`000?n<NKWoS7Viohai^Ol00000
0_n9NK/4o`000005oh5g_ol0003oOGO2ogeg`_l000001?miMl@01Ol0003oMWS7ogIhaomfN<Oo0000
00?oLWW;1?l00002of5jeP04o`000?mNO][oGWkJoeinfP?o000000CoCWkQo`000?m>QNKoCXGV1_l0
0002odJBl0Ko00001?nBcO`00ol0003oYL?_ojG3k`03o`0000GoYL?_00?o0000ojG3kol000000ol0
000Jooooo`03o`000?oooooooooo00Kooooo000Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool01?l0003oooooo`000?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00;o
YL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000Co
YL?_00?o0000ok76jOl000000_oYj<h4o`000007oo7^`Ol0003ol^booo;/_ol0003ol^Zoo`000002
oo;W_`03o`000?oai;oo000000;ol>7000_o0000onkM`?o^gL3ok]g0o`000?o/f/7o0000on[F`Ol0
003ojMC0o`000002onK?`005o`000?oSbl3ohl_0on?;`?l000000_oOa[l00ol0003of[nnomZo_P02
omZo_P05o`000?oF^kkoe[^nomJk__l000001Oo@/kd00ol0003obJ^lolV[_002olV[_0;o00001Oo2
XkX00ol0003o^ibiok^L^@02ok^L^@06o`000?nhVKSo^9Vho`000?ndUKOo00001?naT[L01?l0003o
[Hnfojf?]_n]SkH2o`0000CoZ8Ve00Go0000ojF7]OnUQkGoYHNeo`000004oj65]@03o`000?nNPkGo
000000?o00000_nKOk@01Ol0003oV7jeoiQn]OnHO[Go000000?oUGbf00?o0000oi9k]onBNkL00_nB
NkL01Ol0003oSgZhohmj^?n?N[So000000?oS7Vi00Go0000ohUi^on9NK_oRGVko`000002ohIi_@[o
00000omfN<L01Ol0003oLWW;og9ibombNL_o000000;oL7c?0ol000000omQN]Ko0000oeinfP02oein
fP03o`000?mMQ=oo000000;o00000_m>QNH01?l0003oDHk[oe6>jomAS^/3o`000003odJBl?l0003o
D9kd00;oD9kd2?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`?o00000onU`nl2o`0001Wooooo00?o
0000ooooooooool01_ooool002oooooo00Co0000oooooooooooo00000_nU`nl4o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03
o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Oo000000CoblWHo`000?oa
k/7o00000_obk;l00ol0003ol^Zoo`000002oo;W_`04o`000?oai;oolNBoo`0000;ol>7000Ko0000
onkM`?o^gL3o0000oncJ`Ol00003on[F`@;o000000?oi/o0o`000?oSbl000_oSbl001?l0003oglJo
omo6_ooOa[l2o`0000?of[nn00Go0000omJk__oF^kkoe[^no`000004om2c_@03o`000?o<[[co0000
00;obJ^l00Co0000olFW^oo5Yk_o00000oo2XkX2o`0000Go^ibi0_l00003okBE]`03o`000?naT[Oo
/I:g00;o/I:g0ol000000on[S;Go0000ojR9]@03ojR9]@05o`000?nUQkGoYHNeojF7]Ol000000onQ
QKD3o`0000;oWH6d00Go0000oi]o]?nKOkCoVgndo`000004oiQn]@05o`000?nEO;KoUGbfoiEl]_l0
00000onBNkL00ol0003oSgZhohmj^002ohmj^005o`000?n<NKWoS7Viohai^Ol000000_n9NK/01Ol0
003oQWVmohIi_On6NKgo000000?oPgVo00Co0000oh5j`_n1N/;oPG[21Ol00004og9ib`05o`000?m`
O<ooL7c?o`000?m]Om<00ol00003oeinfP04o`000?mMQ=ooGHCOoef4g`Co00000omAS^/00ol0003o
EiO`o`000002o`0000CoD9kd00Go0000og^lnomk_?_oNkcko`000003ojG3k`Go00000_nU`nl01?l0
003oYL?_ojG3konU`nl3o`0001Wooooo00?o0000ooooooooool01Oooool0033ooooo0_l000000ooo
oooo0000o`000004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000
ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0004ojG3k`04o`000?o;bMSoblWHo`0000;olNk100?o0000oo;/_oobk;l00_l00002oo;W_`04o`00
0?oai;oolNBoo`0000;ol>7000Co0000onkM`?o^gL3o00000_o/f/401_l0003oj]K1on[F`OoZe/7o
0000onOB`@;o00000ooSbl001?l0003oglJoomo6_ol00002omc2_`03o`000?oJ_kko000000?oe[^n
00?o0000om:f__l000000_o@/kd01_l0003oc:jlolb^_?l0003obJ^lo`0000?oaJNk00Co0000ol:S
^_o2Xk[o00000_nnWkT01?l0003o^ibiok^L^OnkW;T2o`0000Co]9Fg00Co0000ok6B]onaT[Oo/I:g
0_l00003oj^<]@03o`000?nXRKGoZ8Ve00;oZ8Ve00?o0000ojF7]OnUQkD00_nUQkD3o`000003oj23
]?l0003oWH6d00;oWH6d00?o0000oi]o]?nKOk@00_nKOk@01Ol0003oV7jeoiQn]OnHO[Go000000?o
UGbf00?o0000oi9k]onBNkL00_nBNkL01Ol0003oSgZhohmj^?n?N[So000000?oS7Vi00Go0000ohUi
^on9NK_oRGVko`000003ohIi_@05o`000?n3NKooPgVooh=i_ol000000on1N/800ol0003oOW_5ogik
a@03o`0000;oLWW;00Go0000og1lcom`O<ooL7c?o`000003ofeod`Co00000omMQ=l00ol0003oGX[T
oej:i006o`0000?oEiO`3?l00002oj?<m@03o`000?nU`nooYL?_00;oYL?_1?l000001?nU`noo0000
ojG3kol0000Hooooo`03o`000?oooooooooo00Gooooo000booooo`03o`000?oooooo000000CoYL?_
0ol00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_
00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_
o`000?l00002ojG3k`05o`000?nU`nooYL?_ojG3kol000000oo;bMP00ol0003olNk1o`000002oo;/
_`03o`000?obj[oo000000;ol^No00?o0000oo7T_ol000000_o`hL001?l0003ok]g0onkM`?l00002
oncJ`@05o`000?oZe/7oj]K1on[F`Ol000000_oWd/401Ol0003oi<k1o`000?oSbl3o000000;oglJo
00?o0000omc2_ooL`[l00_oL`[l01Ol0003oe[^nomJk__oF^kko000000;od[Jn00?o0000om2c_Ol0
00001?o<[[`00ol0003oaJNkolFW^`02olFW^`03o`000?o2Xk[o000000?o_Yni00Ko0000ok^L^Onk
W;Wo0000okNH^?l00004okBE]`06o`000?naT[Oo/I:go`000?n^SkKo00001?n[S;D01Ol0003oZ8Ve
ojR9]OnXRKGo000000?oYHNe0_l00003oj23]003o`000?nMPKCoWH6d00;oWH6d00Go0000oi]o]?nK
OkCoVgndo`000003oiQn]@05o`000?nEO;KoUGbfoiEl]_l000001?nBNkL01Ol0003oSgZhohmj^?n?
N[So000000?oS7Vi00Go0000ohUi^on9NK_oRGVko`000003ohIi_@05o`000?n3NKooPgVooh=i_ol0
00001?n1N/801Ol0003oOW_5ogikaOl0003oO7g900?o00000om`O<l01Ol0003oKGoCofeodom]Om?o
000000;oK8?H1_l00002oej:i004o`000?mQT^WoHI;Yof6Bj@Ko00000omOX_@01Ol0003oJjohof^_
n?m[[oSo000000GoXlce00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00005oooool00ol0
003oooooooooo`05ooooo`00<oooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3
konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3
konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00CoYL?_00?o0000ojG3kol000000oo;bMP02?l0003olNk1oo7^`Ol0003ol^boo`000?obj[oo0000
0_obikl01?l0003olNBooo7T_ol00002oo3Q`003o`000?o^gL3o000000;ok=[100Go0000on[F`OoZ
e/7oj]K1o`000002onOB`@05o`000?oTc/7oi<k1onC>`Ol000000ooOa[l00ol0003og<:oomc2_`02
omc2_`05o`000?oF^kkoe[^nomJk__l000000ooB][h00ol0003oc:jlolb^_003olb^_003o`000?o5
Yk_oaJNk00?oaJNk00?o0000okjO^OnnWkT00_nnWkT00ol0003o^ibio`000003okNH^003o`000?nd
UKOo]9Fg00;o]9Fg0_l00002ojj?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojR9]OnXRKD00_nX
RKD3o`000003oj>5]?l0003oX8>d00?oX8>d00Go0000oif1]?nMPKCoWH6do`000003oi]o]005o`00
0?nHO[GoV7jeoiQn]Ol000000onEO;H00ol0003oTW^goi9k]`02oi9k]`03o`000?n?N[SoSgZh00;o
SgZh00Go0000ohai^On<NKWoS7Vio`000002ohUi^`05o`000?n6NKgoQWVmohIi_Ol000001?n3NKl0
1Ol0003oPG[2oh5j`_n1N/;o000000?oOW_500Co0000ogambOmlOLWoO7g91?l00004ofeod`04o`00
0?m/PmSoK8?Ho`0000?oJhSM1Ol00003of6Bj@04o`000?mUVnkoII_^ofFKkP[o00000onSc?D3o`00
00CoYL?_00?o0000ojG3kol000001?l0000Gooooo`03o`000?oooooooooo00Gooooo000dooooo`04
o`000?oooooo0000o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o
0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU
`nooYL?_00Co00000_o;bMP01?l0003olNk1oo7^`Ol00002oo;/_`oo000000?ok=[1o`000?oZe/40
0_oZe/400ol0003oim;1o`000004onC>`@;o000000?oglJoo`000?oL`[l00ooL`[l01Ol0003of;jo
o`000?oF^kko000000Cod[Jn00?o0000olb^_?o<[[`00_o<[[`00ol0003ob:Zlo`000003olFW^`;o
00001OnnWkT00ol0003o]iRhokNH^002okNH^004o`000?ndUKOo]9FgokBE]`;o00001?n^SkH01Ol0
003oZhbeoj^<]On[S;Go000000?oZ8Ve0_l00003oj>5]003o`000?nPPkCoX8>d00;oX8>d00Go0000
oif1]?nMPKCoWH6do`000003oi]o]003o`000?nHO[GoV7je00;oV7je00Go0000oiEl]_nEO;KoUGbf
o`000002oi9k]`go000000?oRGVko`000?n6NKd00_n6NKd01Ol0003oPgVooh=i_on3NKoo000000?o
PG[200Go0000ogikaOmnNlGoOW_5o`000003ogamb@03o`000?mjOlgoNWo=00Ko00000om/PmP01Ol0
003oJhSMof^8gOm[R=go000000;oK8kR1_l00004ofFKkP04o`000?m/YO?oK:Gco`0000?oLjkf1?l0
0003oiO5m`03o`000?nU`nooYL?_00?o00001?nU`nl2o`0001Kooooo00?o0000ooooooooool01Ooo
ool003Gooooo0_l000001?oooooo0000ojG3konU`nl4o`0000CoYL?_00?o0000ojG3konU`nl01?l0
0004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_
o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oblWHo`000002oo7^`@?o000000GolN_1o`000?oaj<7olNS1o`000002oo3V
`@06o`000?o_hl7okn?1o`000?o^gl;o00000_o/g<83o`000005on[F`Ol0003oim;1onOB`Ol00000
0ooTc/401?l0003ohLW1on79`Ol00004omc2_`05o`000?oH_[oof;joomRn_ol000001?oB][h00ol0
003oc[:mo`000002olb^_004o`000?o8Z[cob:Zlo`0000;oaJNk00Co0000ol6S^_o1Xk[o00001?nn
WkT00ol0003o]iRhokNH^002okNH^006o`000?ndUKOo]9Fgo`000?naT[Ko00001?n^SkH00ol0003o
Zhbeoj^<]@02oj^<]@?o000000?oYXNdo`000?nSQK@00onSQK@01Ol0003oX8>doj23]?nPPkCo0000
00?oWH6d00?o0000oi]o]?nKOk@00_nKOk@00ol0003oV7jeo`000008o`0000;oU7^e00Go0000oi9k
]_nBNkKoTW^fo`000003ohmj^003o`000?n=N[WoSGZi00[o00001?n1N/801?l0003oOW_5ogikaOl0
0004ogamb@04o`000?mjOlgoNWo=o`0000?oN8?A1Ol00004of^8g@04o`000?m/S^;oK8kRo`0000?o
KYKW2_l00004og>^mP04o`000?nGaOOoUlGgoiO5m`Co00000onU`nl01?l0003oYL?_ojG3konU`nl3
o`0001Gooooo00?o0000ooooooooool01Oooool003Oooooo00Co0000ooooool0003o00001?nU`nl0
0ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`noo
YL?_00Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00;oYL?_1_l000000ooHdM;o0000o`000002oo7X`@04o`000?o`
i/7ol>K1o`0000;okn?100?o0000onkO`_l000000oo/g<800ol0003oj]S2on[H`P02o`000003onOB
`Ol0003oi<k100;oi<k100Go0000on79`OoQbL7ohLW1o`000003omc2_`03o`000?oH_[oof;jo00;o
f;jo00Go0000om:f__oB][kod[Jno`000002oljb_@03o`000?o<[[co000000?ob:Zl00?o0000olFW
^ol000001?o1XkX01_l0003o_YniokjO^Ol0003o^Ybio`0000Co]iRh0_l00003ok6B]P05o`000?n^
SkKo[Xnfojj?]_l000000on[S;D2o`0000?oYXNd00?o0000oj>5]?nSQK@00_nSQK@01Ol0003oX8>d
oj23]?nPPkCo000000CoWH6d00?o0000oi]o]?l000000ol00002oiUm/`05o`000?nFO;CoUWbdoiIl
]?l000001?nDNkD01Ol0003oTW^foi9k]_nBNkKo000000?oSgZh00Go0000ohej^On=N[WoSGZio`00
0003oh]j^`04o`000?n9NkgoRG^mohUk_@So000000?oOW_5o`000?mlOLT00_mlOLT01Ol0003oNWo=
ogYocOmjOlgo000000?oN8?A00?o0000ogN7e_mgQmH02_l00003ofjFi`03o`000?mbW^coLYk/00;o
LYk/00?o0000ogNWl?mgYo002Ol00003ohjmmP03o`000?nU`nooYL?_00Go000000CoYL?_o`000?nU
`noo00005?ooool00ol0003oooooooooo`05ooooo`00>?ooool00ol0003oooooo`000004ojG3k`?o
00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03
o`000?nU`nooYL?_00Co00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_00Co0000ojG3kol0003o00000_nU`nl01ol0003of=7BomSAd_oHdM;o0000oo7[`Ol00000
0_oaj<401_l0003ol>K1oo3V`Ol0003okn?1o`0000;ok]o200Co0000oncL`_o/g<;o00000ooZf<80
1?l0003oj=C2o`000?l00003onC>`@08o`000?oQbL7ohLW1o`000?oMaL7o0000omc2_ol00004omRn
_`05o`000?oD^Koo0000om:f__l000001?o>/[d00ol0003ob:ZlolRZ_003olRZ_003o`000?o1Xk[o
`J>j00?o`J>j00?o0000okjO^Ol000000_njW;T00ol0003o]iRhokNH^002okNH^003o`000?naT[Ko
/I:f00;o/I:f00?o0000ojj?]_n^SkH00_n^SkH3o`000003ojR:]?l0003oYXNd00?oYXNd00Go0000
oj>5]?nSQKCoXhFdo`000004oj23]003o`000?nMPKCo000000?o00000_nKO[<00ol0003oVGfcoiUm
/`02oiUm/`05o`000?nFO;CoUWbdoiIl]?l000001?nDNkD01Ol0003oTW^foi9k]_nBNkKo000000?o
SgZh00Co0000ohej^On=N[Wo00001?n;N[/01Ol0003oRG^mohUk_On9Nkgo000000?oQgc000?o0000
ohEn`on5O/<01_l00003ogYoc@03o`000?mhPm7oN8?A00;oN8?A00Co0000ogN7e_mgQmKo00001?mg
S=/00ol0003oN9;PogRBh006o`0000CoLYk/00Go0000ogNWl?mgYo3oMjO`o`000004ogf`m004o`00
0?n>_OKoS[gfohjmmPCo00000_nSao800ol0003oYL?_ojG3k`02ojG3k`?o00005?ooool00ol0003o
ooooooooo`04ooooo`00>Oooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co
00001?nU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_00?o0000ojG3konU`nl00ol00003ojG3k`07
o`000?oHdM;of=7BomSAd_l0003olN_1o`000002oo7X`@06o`000?o`i/7ol>K1o`000?o_hl7o0000
0_o^gl801Ol0003ok=c2oncL`_o/g<;o000000;oj]S200So0000onSD`_oXe<;o0000onG@`_l0003o
i<k1o`0000;ohLW100Co0000omg5`OoMaL7ogLG10_l00003omRn_`05o`000?oD^Kooe;VoomBi_ol0
00001Oo>/[d00ol0003ob:ZlolRZ_003olRZ_003o`000?o1Xk[o`J>j00Co`J>j00?o0000okZL^Onj
W;T00_njW;T00ol0003o]iRhokNH^002o`0000Go/I:f00Go0000ojj?]_n^SkKo[Xnfo`000003ojR:
]003o`000?nVQkCoYXNd00;oYXNd00Go0000oj>5]?nSQKCoXhFdo`000003oj23]0?o00000_nMP;<0
0ol0003oVgjcoi]n/`02oi]n/`05o`000?nIOK?oVGfcoiUm/ol000000onFO;@00ol0003oU7^eoiAk
]@02oiAk]@05o`000?nBNkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZiohej^On=N[Wo000000?o
RgZk00?o0000ohUk_On9Nkd00_n9Nkd01Ol0003oQgc0ohMl`?n7O<3o000000;oQGk300Co0000ohB0
aon4P<OoQ8372_l00003ogN7eP03o`000?mgS=_oMhcK00;oMhcK00Co0000ogRBh?mhT^3o00000omi
VNDBo`0000;oRkSd00?o0000oj?7l_nSao800_nSao800ol0003oYL?_o`000004o`0001Cooooo00?o
0000ooooooooool01?ooool003[ooooo1?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o
0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000CoYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_
o`000003omSAdP03o`000?oajl7o000000;olNS100Co0000oo3V`Oo`i/7o00000_o_hl400ol0003o
k]o2o`000003oncL`P04o`000?oZf<;oj]S2o`0000;oj=C200Go0000onG@`_oUd<;oiM32o`000003
on79`@09o`000?oMaL7ogLG1omg5`Ol0003of/71o`000?oH_[oo000000Coe;Vo00?o0000oljb_Oo>
/[d00_o>/[d00ol0003objjmo`000003olRZ_003o`000?o4Y[_o000000Co`J>j0_l00004okZL^@03
o`000?ngV;So000000;o]9Fg00?o0000ok6B]_naT[H00_naT[H00ol0003o[Xnfojj?]P02o`0000Co
Z8Zd00Go0000ojJ7]?nVQkCoYXNdo`000004oj>5]0?o000000?oWh6co`000?nMP;<00onMP;<01Ol0
003oVgjcoi]n/onKO[?o000000?oVGfc00Go0000oiIl]?nFO;CoUWbdo`000004oiAk]@05o`000?nB
NkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZiohej^On=N[Wo000000CoRgZk00Go0000ohUk_On9
NkgoRG^mo`000003ohMl`005o`000?n5O/?oQGk3ohEn`ol000000on4P<L01Ol0003oPX?;oh:3bon2
Pl_o000000?oPHK?1Ol00004ogN<f`05o`000?mhT^3oN9;PogRBh?l000000omiVND00ol0003oO:7Y
ogbQj@02ogbQj@05o`000?n0Z>koP:S^oh2Xk_l000001On5/?400ol0003oRkSdoh^hm002oh^hm003
o`000?nSao;oXlOb00?o00000onU`nl00ol0003oYL?_o`00000Cooooo`03o`000?oooooooooo00Co
oooo000looooo`03o`000?oooooo000000;oYL?_1?l00004ojG3k`04o`000?nU`noo0000o`0000;o
YL?_00?o0000ojG3konU`nl00_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00;oYL?_0ol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000ooHdM800ol0003olN_1o`000002oo7X`@06o`000?o`i/7ol>K1o`000?o_hl7o00000_o^
gl801?l0003ok=c2oncL`_l00002on[H`P05o`000?oXe<;oj=C2onSD`_l000000ooUd<82o`000003
on79`Ol0003ogLG100;ogLG100Go0000om[1`OoJ`L7of/71o`000004omBi_`03o`000?oA]Koo0000
00;oc[:m00Oo0000ol^^_Oo;[[gobjjmo`000?o8Z[co000000?oa:Jk00Co0000ol6S^_o1Xk[o0000
0_nmWkX00ol0003o^YbiokZL^@02okZL^@05o`000?ndUKOo]9FgokBE]ol000001?naT[H00ol0003o
[Xnfo`000002oj^<]@05o`000?nXR[CoZ8ZdojR:]?l000001?nVQk@00ol0003oXhFdo`000002o`00
00CoWh6c00Go0000oif0/onMP;?oWH2co`000003oi]n/`03o`000?nIOK?oVGfc00;oVGfc00Go0000
oiIl]?nFO;CoUWbdo`000003oiAk]@05o`000?nBNkKoTW^foi9k]_l000000on?N[P01Ol0003oSGZi
ohej^On=N[Wo000000CoRgZk00Go0000ohUk_On9NkgoRG^mo`000003ohMl`005o`000?n5O/?oQGk3
ohEn`ol000001?n4P<L01Ol0003oPX?;oh:3bon2Pl_o000000?oPHK?00?o0000oh6:don1R]<03ol0
0004ogbQj@05o`000?n0Z>koP:S^oh2Xk_l000000on5/?49o`0000?oW/;a00?o0000ojG3konU`nl0
0ol0000Cooooo`03o`000?oooooooooo00Cooooo000mooooo`04o`000?oooooo0000o`0000CoYL?_
00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02
ojG3k`?o00001?nU`nl00ol0003of=7Bo`00000?o`000005oncL`_l0003oj]S2on[H`_l000000_oX
e<801Ol0003oiM32onG@`_oUd<;o000000;oh/g300Go0000omg5`OoMaL7ogLG1o`000004om[1`@05
o`000?oD^Kooe;VoomBi_ol000000_oA]Kl00ol0003oc[:mo`000004ol^^_@03o`000?o8Z[co0000
00?oa:Jk00?o0000ol6S^_l000000onmWkX01?l0003o^YbiokZL^OnjW;T2o`0000Co]9Fg00Co0000
ok6B]_naT[Ko/I:f0_l00003oj^<]@05o`000?nXR[CoZ8ZdojR:]?l000000onVQk@3o`0000;oXX>c
00?o0000oin1/onOPK<00_nOPK<01Ol0003oWH2coif0/onMP;?o000000CoVgjc00Go0000oiUm/onI
OK?oVGfco`000003oiIl]003o`000?nDNkGoU7^e00;oU7^e00Go0000oi9k]_nBNkKoTW^fo`000003
ohmj^005o`000?n=N[WoSGZiohej^Ol000000on;N[/00ol0003oRG^mohUk_@02ohUk_@05o`000?n7
O<3oQgc0ohMl`?l000000_n5O/<00ol0003oQ837ohB0a`02ohB0a`05o`000?n2Pl_oPX?;oh:3bol0
00001?n1Q/l01?l0003oPH[Coh6:dol00004oh6?f005o`000?n2UMgoPYGMoh:EgOl000000on3W>8=
o`0000;oSK7_00?o0000oi6hlOnA^?400_nA^?401?l0003oW/;aoik2lOnN`_44o`0000;oYL?_0_l0
000Booooo`03o`000?oooooooooo00Cooooo000nooooo`04o`000?ooooooooooo`0000;oYL?_1?l0
0004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl3o`000005ok;6jOl0003ofm?@om_Cd?l000000_o`il<00ol0003oknG3o`000002onkRa003
o`000?o/g/Cok=k400;o000000Goj]S2o`000?oXe<;oj=C2o`000003onG@`P04o`000?oRcL?oh/g3
on;=``;o000000?ogLG1o`000?oJ`L400ooJ`L401Ol0003oe[g1o`000?oD^Koo000000CodKFo00?o
0000ol^^_Oo;[[d01?o;[[d00ol0003oa:JkolBV^`03olBV^`03o`000?nmWk[o_Inj00;o_Inj00Ko
0000okZL^OnjW;Wo0000okNH^?l00004okBE]`06o`000?naT[Ko/I:fo`000?n^SkKo00001?n[S;D0
1?l0003oZ8ZdojR:]?nXR[@3o`000003ojB5/ol0003oXX>c00?oXX>c00Go0000oin1/onOPK?oWh6c
o`000004oif0/`05o`000?nKO[?oVgjcoi]n/ol000000onIOK<01Ol0003oUWbdoiIl]?nFO;Co0000
00;oU7^e9?l00003oh:3b`03o`000?n1Q/ooPHK?00;oPHK?00Go0000oh6:don1R]?oPH[Co`000004
oh6?f005o`000?n2UMgoPYGMoh:EgOl000000on3W>801Ol0003oQJ?WohFSion5XnOo000000GoRJ[[
00?o0000ohfakon=/Nl00_n=/Nl00ol0003oTKSaoi6hl@05o`0000;oWKo`00Co0000ojG3konU`noo
YL?_0ol0000Aooooo`03o`000?oooooooooo00Cooooo000oooooo`03o`000?oooooooooo00;o0000
1?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`00
0?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Co0000ojG3kol0003o
00000onba^T01?l0003ofm?@om_Cd?l00002oo3W``03o`000?o_iL?o000000;ok^;400Ko0000oncN
a?o/g/Cok=k4o`000?oZfl@3o`000005onSD`_l0003oiM32onG@`_l000000ooRcL<01?l0003oglS3
omo8`ol00004om[1`@05o`000?oF_L7oe[g1omJm`Ol000001OoA]Kl00ol0003objjmol^^_@03ol^^
_@;o00001?o4Y[/2o`0000Go_Inj0_l00003okNH^007o`000?ndUKOo]9FgokBE]ol0003o/I:fo`00
0002ojj?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojR:]?nXR[@00_l00004ojB5/`05o`000?nR
Pk?oXX>coj:3/ol000001?nOPK<01Ol0003oWH2coif0/onMP;?o000000?oVgjc00?o0000oiUm/onI
OK<02?l00002oiIl]005o`000?nDNkGoU7^eoiAk]Ol000000onCNkH01Ol0003oTGbhoi5l^?nAO;So
000000CoT7bj00Go0000ohim_?n>OKcoSWflo`000003ohen_P05o`000?n<P<;oS832ohb0`_l00000
0on;PlD>o`0000CoPHoH00Go0000oh:EgOn2UMgoPYGMo`000004oh>LhP05o`000?n5XnOoQJ?WohFS
iol000000on9Z^/9o`0000?oUkS_00?o0000oifol?nM_o001Ol000001?nT`noo0000ojC3kol0000@
ooooo`03o`000?oooooooooo00Cooooo0010ooooo`;o000000?oooooo`000?nU`nl00onU`nl3o`00
00?oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?o//KY00Co0000om_C
d?oKdm3o00000_o`il<00ol0003oknG3o`000003onkRa004o`000?o/g/Cok=k4o`0000;oj]_400?o
0000onSGa?oXel@00_l000000ooUd<;o0000on;=``02on;=``04o`000?oOb<?oglS3omo8``;o0000
0ooJ`L401Ol0003oe[g1omJm`OoF_L7o000000CodKFo00?o0000olfa_ol000000oo;[[d01?l0003o
aZZmolJZ_Ol00002olBV^`04o`000?o0Xk_o`:>ko`0000?o_Inj0_l00004okNH^004o`000?ndUKOo
]9FgokBE]`;o00001?n^SkH02Ol0003oZhbeoj^<]On[S;Go0000ojR:]?l0003oYXNdo`000004ojB5
/`05o`000?nRPk?oXX>coj:3/ol000001?nOPK<01Ol0003oWH2coif0/onMP;?o000000;oVgjc1?l0
0002oiUm/P05o`000?nHO;?oV7bcoiQl/ol000000onFO;@01Ol0003oU7^eoiAk]OnDNkGo000000?o
Tg^f00?o0000oi5l^?nAO;P00_nAO;P01Ol0003oT7bjoi1l^_n@O;[o000000CoSWfl00Go0000ohen
__n=O[koSGjno`000003ohb0`P05o`000?n;PlGoRh?5oh^3aOl000000on:Q/T00ol0003oRHW=ohV9
c@02ohV9c@03o`000?n9S]7oRHkA01Ko00000_n@[>T00ol0003oTk;/oi>bk002oi>bk004o`000?nG
^>ooUkS_oiNhk`Co00000_nN_^l00ol0003oY<?_ojC3k`02ojC3k`?o00004?ooool00ol0003ooooo
ooooo`03ooooo`00@_ooool01?l0003oooooo`000?nU`nl2o`0000;oYL?_00?o0000ojG3konU`nl0
0_nU`nl01_l0003oYL?_o`000?l0003oYL?_o`0000CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_
00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ok;6jOl000000_oKdm001?l0
003ol>O3oo3W`ol00002onoU``04o`000?o^h/Cok^;4o`0000;ok=k400Co0000on[Ka?oZflCo0000
0ooXel@01?l0003oiM?5o`000?l00003on;=``04o`000?oOb<?oglS3o`0000;oflG300?o0000om[1
`Ol000000ooF_L400ol0003odkW1o`000002om6e_`07o`000?o=/KoocK6oolfa_ol0003objjmo`00
0003olJZ_@03o`000?o4Y[_o000000?o`:>k00Ko0000okfO^_nmWk[o0000okVK^Ol00004okNH^006
o`000?ndUKOo]9Fgo`000?n`T[Oo00001?n^SkH01?l0003oZhbeoj^<]On[S;D2o`0000?oYXNd00Go
0000ojB5/onTQK?oY8Fco`000004oj:3/`05o`000?nOPK?oWh6coin1/ol000000_nMP;<4o`0000;o
Vgjb00Go0000oiUm/_nIOK;oVGfbo`000003oiQl/`03o`000?nFO;CoUWbd00;oUWbd00Go0000oiAk
]OnDNkGoU7^eo`000003oi=k]P05o`000?nAO;SoTGbhoi5l^?l000001?n@O;X01Ol0003oSWflohim
_?n>OKco000000?oSGjn00Go0000ohb0`_n<P<;oS832o`000004oh^3a@05o`000?n:Q/WoRXK9ohZ6
bOl000001?n9RLd01?l0003oRHkAohV>dOl00004ohVBeP05o`000?n:V=_oRYSKohZHfol000001?n<
W^001Ol0003oSZGUohjUiOn>YNGo000000GoT:cY00?o0000oi>bk?nC/^`01Ol00002oi^ik@03o`00
0?nN_^ooW[k_00;oW[k_00?o0000ojC3kol000001?l0000@ooooo`03o`000?oooooooooo00?ooooo
0013ooooo`04o`000?oooooo0000o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`00
0?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000CoYL?_00?o0000ojG3konU`nl00ol00003om_Cd003o`000?o`il?o000000;o
knG300Co0000onkRa?o^h/Co00000_o/g/@01?l0003oj]_4on[Ka?l00003onSGa008o`000?oUdlGo
iM?5o`000?oSd<Go0000on;=`ol00002omo8``03o`000?oKaL?oflG300;oflG300Go0000omJm`OoF
_L7oe[g1o`000002om>i`@03o`000?oA]Koo000000GocK6o00?o0000olJZ_Oo6Z[d00oo6Z[d00ol0
003o`:>kol2S^`02ol2S^`03o`000?nmWk[o000000?o^I^i00?o0000okNH^?ngV;P00_ngV;P2o`00
00?o/9:g00Go0000ojj?]_n^SkKo[Xnfo`000002oj^<]@03o`000?nYR[Co000000?oYXNd00?o0000
ojB5/onTQK<00_nTQK<01Ol0003oXX>coj:3/onRPk?o000000?oWh6c0ol00002oieo/P05o`000?nK
O[;oVgjboi]n/_l000001?nIOK801Ol0003oV7bcoiQl/onHO;?o000000?oUWbd00Go0000oiAk]OnD
NkGoU7^eo`000003oi=k]P03o`000?nAO;SoTGbh00;oTGbh00Go0000oi1l^_n@O;[oT7bjo`000003
ohim_005o`000?n=O[koSGjnohen__l000001?n<P<801Ol0003oRh?5oh^3aOn;PlGo000000?oRXK9
00?o0000ohV9cOn9RLd00_n9RLd01Ol0003oRHkAohV>dOn9S]7o000000CoRI;F00Go0000ohZHfon:
V=_oRYSKo`000004ohbNh005o`000?n>YNGoSZGUohjUiOl000000on@[>T4o`0000;oVK?Z00?o0000
oi^ikOnK^Nd00onK^Nd00ol0003oW[k_oijnk`03o`0000?oY<;_00?o0000ojC2kol000003oooool0
0ol0003oooooooooo`03ooooo`00A?ooool01?l0003oooooooooool00002ojG3k`Co00001?nU`nl0
0ol0003oYL?_ojG3k`03o`0000CoYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3
k`02ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl3o`0000?oYL?_
00?o0000om_Cd?l000001ol000001?o^h/Co0000oncNa?l00003on[Ka004o`000?oXelCoj=O4o`00
00;oiM?500Go0000on?@aOoSd<Gohm35o`000003omo8``03o`000?oKaL?oflG300;oflG300Go0000
omJm`OoF_L7oe[g1o`000003om>i`@03o`000?o=/KoocK6o00CocK6o00?o0000olJZ_Oo6Z[d00_o6
Z[d2o`0000Go`:>k00?o0000okVK^OniVkT00_niVkT01?l0003o]iRhokNH^?ngV;P2o`0000Co/9:g
00?o0000ojj?]_n^SkH00_n^SkH2o`0000;oZHZd00Go0000ojJ7]?nVQkCoYXNdo`000004ojB5/`06
o`000?nRPk?oXX>coj:3/ol0003oWh6c0_l000000onNP;;o0000oieo/P02oieo/P03o`000?nKO[;o
Vgjb00;oVgjb00Go0000oiUm/_nIOK;oVGfbo`000003oiQl/`05o`000?nFO;CoUWbdoiIl]?l00000
0onDNkD01Ol0003oTg^foi=k]_nCNkKo000000CoTGbh00Go0000oi1l^_n@O;[oT7bjo`000004ohim
_005o`000?n=O[koSGjnohen__l000000on<P<801Ol0003oRh?5oh^3aOn;PlGo000000?oRXK900?o
0000ohV9cOn9RLd00_n9RLd01Ol0003oRHkAohV>dOn9S]7o000000CoRI;F00?o0000ohZHfon:V=/0
3_l00002oiN]iP03o`000?nI/n[oVK?Z00;oVK?Z00Co0000oi^ikOnK^NgoVkW]1?l00003oj6nkP03
o`000?nT`^ooY<;_00?o00003oooool00ol0003oooooooooo`03ooooo`00AOooool2o`000003oooo
ool0003o000000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
1?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3
k`?o000000Go]/KWo`000?oIdM7ofM7Ao`000002ongTa`Go000000?oj]_4o`000?oXel@00_oXel@0
0ol0003oiM?5o`000004on?@a@;o000000?oglS3o`000?oKaL<00ooKaL<01Ol0003of<73o`000?oF
_L7o000000CodkW100?o0000olfa_oo=/Kl00oo=/Kl00ol0003obJjoo`000002olJZ_@04o`000?o2
Y[go`ZJmo`0000?o`:>k0_l00004okVK^@06o`000?ngV;So]iRho`000?ncUKSo00001?n`T[L01?l0
003o[Xnfojj?]_n^SkH2o`0000CoZHZd00Go0000ojJ7]?nVQkCoYXNdo`000003ojB5/`03o`000?nR
Pk?oXX>c00?o00000onNP;800ol0003oWGnboieo/P02oieo/P05o`000?nKO[;oVgjboi]n/_l00000
0onIOK801Ol0003oV7bcoiQl/onHO;?o000000?oUWbd00?o0000oiAk]OnDNkD00_nDNkD01Ol0003o
Tg^foi=k]_nCNkKo000000?oTGbh00?o0000oi1l^_n@O;X00_n@O;X00ol0003oSWflo`00000Ro`00
00;oTY_I00?o0000oi>Qg_nCXMh00_nCXMh01Ol0003oUJORoiFWh_nEYn;o000000GoUjgV00?o0000
oiVcj_nI/nX01Ol00002oinjj`04o`000?nQ_^koXKk^oj6nkPCo00000_nT`^h2o`0000kooooo00?o
0000ooooooooool00oooool004Oooooo00Co0000oooooooooooo00000_nU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3
k`03o`0000CoYL?_00Co0000ojG3kol0003o00000onfa^L01?l0003ofM7AomWAdOl00003ongTa`03
o`000?o[hLOo000000;ojMk70ol000001OoXelCo0000onGCaOoUdlGo000000?ohm3500?o0000omo<
aOoOc<D00_l00003om_5``05o`000?oH`L?of<73omS1`ol000001?oC^L400ol0003ockG1o`000003
olfa_`06o`000?o9[[oobJjoo`000?o6Z[go00000oo2Y[d01?l0003o`:>kol2S^ol00002okbO^`03
o`000?niVkWo^I^i00;o^I^i0_l00003ok>E^003o`000?n`T[Oo/9:g00;o/9:g0ol000000on[S;Go
0000ojV:]003ojV:]005o`000?nVQkCoYXNdojJ7]?l000000onTQK<3o`0000;oX8:b00?o0000oij0
/_nNP;800_nNP;801Ol0003oWGnboieo/_nMOk;o000000?oVgjb00Go0000oiUm/_nIOK;oVGfbo`00
0003oiQl/`03o`000?nFO;CoUWbd00;oUWbd00?o0000oiAk]Ol000004?l00002oi=o^`05o`000?nB
PKgoTX6moi:1_Ol000001?nBPl001Ol0003oTHK3oi66`onAQ/?o000000?oTHW700?o0000oi6<bonA
S</00_nAS</01Ol0003oTI7?oi6AconATLoo000000CoTIKD00?o0000oi:KfOnBVmT00_nBVmT00ol0
003oTj7Noi>QgP02oi>QgP05o`000?nEYn;oUJORoiFWh_l000000onG[NH4o`0000?oW[GX00?o0000
oinjjonO^^/01Ol00003oj>ok@03o`000?nT`^koY<;^00?o00003Oooool00ol0003oooooooooo`03
ooooo`00B?ooool00ol0003oooooooooo`02o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3
k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003okK6i`05o`000?oIdM7ofM7AomWAdOl000000_o]i<L00ol0003ojn77o`000003
onWNa`03o`000?oWflOoim_700;o000000?oiM?5o`000?oSd<D00_oSd<D02Ol0003oglc5omo<aOoO
c<Go0000omc8aOl0003oflG3o`000004omS1``05o`000?oC^L7odkW1om>i`Ol000000oo?]L400ol0
003ocK6oo`000004olV^_`03o`000?o2Y[go`ZJm00;o`ZJm00?o0000ol2S^ol000000onlWk/01?l0
003o^I^iokVK^OniVkT2o`0000Co/iFh00Co0000ok2B]on`T[Oo/9:g0_l00003oj^<]@03o`000?nY
R[CoZHZd00;oZHZd00Ko0000ojJ7]?nVQkCoYXNdo`000?nTQK<2o`000003oj:3/_l0003oX8:b00;o
X8:b00?o0000oij0/_nNP;800_nNP;801Ol0003oWGnboieo/_nMOk;o000000?oVgjb00?o0000oiUm
/_nIOK800_nIOK801_l0003oV7bcoiQl/onHO;?o0000oiIl]0Co00000_nGO;@01Ol0003oUWbeoiIl
]OnFO;Go000000CoU7fg00Go0000oiAn^OnDO[WoU7jio`000003oi=o^`05o`000?nBPKgoTX6moi:1
_Ol000001OnBPl001Ol0003oTHK3oi66`onAQ/?o000000?oTHW700?o0000oi6<bonAS</00_nAS</0
1Ol0003oTI7?oi6AconATLoo000000CoTIKD00Go0000oi:KfOnBVmWoTY_Io`000003oi>QgPWo0000
0_nL[nD00ol0003oW[GXoijej002oijej0?o00000_nS_>/00ol0003oXko]oj>ok@03oj>ok@?o0000
00CoYL?_o`000?nU`noo00003?ooool00ol0003oooooooooo`03ooooo`00BOooool01?l0003ooooo
ooooool00003ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00001?nU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nfa^Oo000000?o
fM7A00Ko0000ongTaoo]i<Oo0000on_Qaol00003onWNa`06o`000?oWflOoim_7onOKaol0003oiMO8
0ol000000ooSd<Go0000omo<a@02omo<a@05o`000?oLb<Gog<S5omc8aOl000001?oH`L<01Ol0003o
e;g3o`000?oC^L7o000000GockG100?o0000olV^_oo9[[l00oo9[[l00ol0003o`ZJmol:V_@03ol:V
_@03o`000?nlWk_o_9nk00;o_9nk00Ko0000okVK^OniVkWo0000okJH^Ol00004ok>E^006o`000?n`
T[Oo/9:go`000?n]SkKo00001?n[S;D01Ol0003oZHZdojV:]?nYR[Co000000?oYXNd0_l00003oj:3
/P03o`000?nPP[;oX8:b00;oX8:b00Go0000oij0/_nNP;;oWX2bo`000003oieo/P03o`000?nKO[;o
Vgjb00;oVgjb00?o0000oiUm/_l000001ol00002oiQl/`05o`000?nGO;CoUgbdoiMl]?l000001?nF
O;D01Ol0003oU7fgoiAm]onDOKOo000000?oU7ji00?o0000oi=o^onCOk/00_nCOk/01Ol0003oTX6m
oi:1_OnBPKgo000000CoTX?000Go0000oi66`onAQ/?oTHK3o`000003oi69a`03o`000?nAS<_oTHc;
00;oTHc;00Go0000oi6AconATLooTI7?o`000004oi6Fe003o`000?nBVmWoTY_I00Go00000_nJXm`0
1Ol0003oVjWPoi^Yh?nKZN3o000000GoW:oU1?l000000onR^NWo0000oj>lj`03oj>lj`03o`000?nS
_ngo000000;o000000?oYL?_o`000?nU`nl00_nU`nl3o`0000cooooo00?o0000ooooooooool00_oo
ool004[ooooo0_l000001?oooooo0000ojG3kol00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co
0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`02ojG3k`?o00000onU`nl00ol0003oYL?_
ojG3k`04o`0000CoYL?_00?o0000ojG3konU`nl01?l00002omWAd@04o`000?o]i<OokNC7o`0000;o
jn7700Co0000onWNaooYg/Oo00000ooWflL01?l0003oiMO8onGGb?l00002on?Cb005o`000?oOc<Go
glc5omo<aOl000001?oLb<D01Ol0003of<73omS1`ooH`L?o000000?oe;g300?o0000olne`Oo?]L40
0oo?]L42o`0000CobJjo00?o0000olFZ_ol000000oo2Y[d2o`0000Go_9nk0_l00003okJH^@03o`00
0?ncUKSo/iFh00;o/iFh0_l00002ojf?]P03o`000?n[S;GoZhbe00;oZhbe00?o0000ojV:]?nYR[@0
0_nYR[@3o`000003ojB5/ol0003oXX>b00?oXX>b00Go0000oj22/_nPP[;oX8:bo`000003oij0/P03
o`000?nMOk;oWGnb00;oWGnb00?o0000oi]n/_l000000ol00002oiYm/P05o`000?nIO;;oVGbboiUl
/_l000000onHO;<00ol0003oUgbdoiMl]002oiMl]005o`000?nFO;GoUWbeoiIl]Ol000001?nDOKL0
1Ol0003oU7jioiAn^OnDO[Wo000000?oTgnk00Go0000oi:1_OnBPKgoTX6mo`000004oi:3`005o`00
0?nAQ/?oTHK3oi66`ol000000onARLL00ol0003oTHc;oi6<b`02oi6<b`03o`000?nATLooTI7?00Wo
00000_nIW]L00ol0003oVZ?LoiZSg002oiZSg003o`000?nKZN3oVjWP00;oVjWP00?o0000oib_iOnL
[nD00ol00005oj:ij@03o`000?nS_>_oXkc[00?o00001OnU`nl6o`0000cooooo00?o0000oooooooo
ool00_ooool004cooooo00?o0000ooooool000001?nU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_
00Co0000ojG3kol0003o00000_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o0000ojG3
konU`nl01?l00004ojG3k`05o`000?oIdM7o0000ongTaol000000_o[hLL01Ol0003ojMk7onWNaooY
g/Oo000000;oim_700Co0000onGGb?oUelSo00000ooSdlP2o`000003omo<aOl0003og<S500?og<S5
00Go0000omW4aOl0003of<73o`000003omBm``03o`000?o@^L?o000000?ockG100Co0000ol^a`Oo;
/L7o00000_o9[[l01?l0003oaJZoolFZ_ol00002ol:V_@04o`000?nnXkgo_Z>mo`0000?o_9nk0_l0
0004okJH^@04o`000?ncUKSo/iFhok>E^0;o00001?n]SkH01Ol0003oZhbeoj^<]On[S;Go000000?o
ZHZd0_l00003ojB5/`03o`000?nRPk;oXX>b00;oXX>b00Go0000oj22/_nPP[;oX8:bo`000003oij0
/P04o`000?nMOk;oWGnboieo/P?o00000_nKOK401Ol0003oVWfboiYm/_nJOK;o000000?oVGbb00?o
0000oiQl/onHO;<00_nHO;<01Ol0003oUgbdoiMl]?nGO;Co000000?oUWbe00?o0000oiAm]onDOKL0
0_nDOKL01Ol0003oU7jioiAn^OnDO[Wo000000?oTgnk00Go0000oi:1_OnBPKgoTX6mo`000005oi:3
`006o`000?nAQ/?oTHK3oi66`ol0003oTHW72Ol00002oiRDcP03o`000?nIV=;oVISB00;oVISB00?o
0000oiVNeonIW]L00_nIW]L00ol0003oVZ?LoiZSg002oiZSg003o`000?nKZN3oVjWP00Co00000onR
]>H01?l0003oX[WYoj:ijOnR^NT4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`;o0000
2oooool00ol0003oooooooooo`02ooooo`00COooool00ol0003oooooo`000002ojG3k`Co00001?nU
`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_00?o0000ojG3kol000000_nU`nl00ol0003oYL?_ojG3
k`02ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`02ojG3k`Wo000000GojMk7o`000?oWflOoim_7
o`000002onGGb005o`000?oSdlSohm?8on?Cb?l000000_oPd<P2o`0000?og<S500Go0000omW4aOoI
a<GofLC5o`000003omBm``07o`000?o@^L?od;W3om2i`ol0003ockG1o`000003ol^a`@03o`000?o9
[[oo000000?oaJZo00?o0000ol:V_Ol000000onnXkd01_l0003o_9nkokbO^ol0003o^9bko`0000Co
]YRi00Ko0000ok>E^?ncUKSo0000ok2B^?l00004ojf?]P03o`000?n[S;GoZhbe00;oZhbe0ol00000
0onVQkCo0000ojB5/`03ojB5/`05o`000?nRPk;oXX>boj:3/_l000000onPP[800ol0003oWX2boij0
/P02oij0/P?o000000?oW7jao`000?nKOK400_nKOK400ol0003oVWfboiYm/P02oiYm/P05o`000?nI
O;;oVGbboiUl/_l000000onHO;<01Ol0003oUgbdoiMl]?nGO;Co000000CoUWbe00Go0000oiAm]onD
OKOoU7fgo`000003oiAn^@03o`000?nCOk_oTgnk00;oTgnk00Go0000oi:1_OnBPKgoTX6mo`000002
oi:3`0So00000_nGS<D00ol0003oV8o9oiR?b@02oiR?b@03o`000?nHU<koV9C>00;oV9C>00?o0000
oiVHd_nIV=800_nIV=801Ol0003oVIkGoiVNeonIW]Oo000000;oVZ?L1Ol00003oj6`hP03o`000?nR
]>KoX[CV00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00Co0000ojG3konU`noo
YL?_0ol0000:ooooo`03o`000?oooooooooo00;ooooo001>ooooo`04o`000?oooooo0000o`0000Co
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003o
YL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_00Co0000ojG3kol0003o00000_nca^P0
1Ol0003od/_Com;;dooBbm?o000000;oj>;;0_l000000ooWflOo0000onGGb002onGGb004o`000?oS
dlSohm?8o`0000?oh=3800Go0000omg<b?l0003og<S5o`000004omW4a@;o000000?oe;g3o`000?o@
^L<01?o@^L<00ol0003obk71ol^a`@03ol^a`@03o`000?o5Z[ooaJZo00?oaJZo00?o0000okjS_Onn
Xkd00_nnXkd00ol0003o_9nko`000003okRL^`03o`000?nfV;Wo]YRi00;o]YRi0_l00002ok2B^003
o`000?n]SkKo[Hnf00;o[Hnf00Co0000oj^<]On[S;GoZhbe0_l00003ojJ7]003o`000?nTQK?oY8Fc
00;oY8Fc00Go0000oj:3/_nRPk;oXX>bo`000004oj22/P03o`000?nNP;;o000000;o00000onLO[40
0ol0003oVgfaoi]m/@02oi]m/@05o`000?nJOK;oVWfboiYm/_l000000onIO;801Ol0003oV7bcoiQl
/onHO;?o000000?oUgbd00?o0000oiIl]OnFO;D00_nFO;D00ol0003oU7fgoiAm]`02oiAm]`06o`00
0?nDO[WoU7jioiAn^Ol0003oTgnk2Ol00002oiN6_`05o`000?nGR<;oUhS2oiN8`_l000001?nGS<D0
0ol0003oV8o9oiR?b@02oiR?b@05o`000?nHU<koV9C>oiRDc_l000001?nIV=800ol0003oVIkGoiVN
e`04o`0000;oXJ_N00?o0000oj6`h_nQ/>800onQ/>83o`0000?oYL?_00?o0000ojG3konU`nl01Ol0
0003ojG3k`03o`000?nU`nooYL?_00Go000000?oYL?_o`000?l000002_ooool00ol0003ooooooooo
o`02ooooo`00Coooool2o`000004ooooool0003oYL?_ojG3k`Co00001?nU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00000onc
a^P01Ol0003od/_Com;;dooBbm?o000000?oj>;;00?o0000onONbol000000_l000000ooUelSo0000
on?Cb002on?Cb004o`000?oPd<Soh=38o`0000?ogLc800?o0000omW4aOoIa<D00_oIa<D01?l0003o
e/76omK1a_l00006om2i``03o`000?o;/L7obk7100;obk710_l00004olFZ_`;o00001OnnXkd00ol0
003o^9bkokRL^`02okRL^`04o`000?nfV;Wo]YRiokJH^@;o00001?n`T[P00ol0003o[Hnfojf?]P02
ojf?]P?o000000?oZ8Zeo`000?nVQk@00onVQk@01Ol0003oY8FcojB5/onTQK?o000000CoXX>b00?o
0000oj22/_l000000ol00002oiio/@03o`000?nLO[7oW7ja00;oW7ja00Go0000oi]m/OnKOK7oVgfa
o`000003oiYm/P05o`000?nIO;;oVGbboiUl/_l000000onHO;<00ol0003oUgbdoiMl]002oiMl]005
o`000?nFO;GoUWbeoiIl]Ol000000_nDOKL8o`0000;oUh:j00Go0000oiN3_?nGPkcoUh>lo`000005
oiN6_`05o`000?nGR<;oUhS2oiN8`_l000001?nGS<D01Ol0003oV8o9oiR?bOnHSlWo000000;oV9C>
2Ol00002oj2VfP03o`000?nQZmkoXJ_N00;oXJ_N00?o0000oj6`h_l000000_l000000onU`noo0000
ojG3k`03ojG3k`?o00000onU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU
`nl00ol00009ooooo`03o`000?oooooooooo00;ooooo001Aooooo`04o`000?oooooo0000o`0000Co
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ok?6j?l000000ooBbm<01Ol0003oj>;;onSRbooXh/_o0000
00;oimk;00?o0000onGKbooUfl/00ol000001OoSdlSo0000on3@b?oPd<So000000CogLc800Go0000
omW4aOoIa<GofLC5o`000003omK1aP03o`000?o@^L?od;W300?od;W300?o0000olfe`ol000000_o;
/L401?l0003oajk1olN^`Ol00002olFZ_`04o`000?o1Y[oo`JJoo`0000?o_Z>m0_l00004okRL^`06
o`000?nfV;Wo]YRio`000?nbUKWo00001?n`T[P01?l0003o[Hnfojf?]_n]SkH2o`0000?oZ8Ze00?o
0000ojJ7]?nVQk@00_nVQk@01Ol0003oY8FcojB5/onTQK?o000000?oXX>b0ol00002oin1/P05o`00
0?nNOk7oWWnaoiio/Ol000001?nLO[401Ol0003oVgfaoi]m/OnKOK7o000000?oVWfb00Go0000oiUl
/_nIO;;oVGbbo`000004oiQl/`03o`000?nGO;Co000000So00000_nHOkH01Ol0003oV82hoiR0^?nH
P;So000000?oUh:j00?o0000oiN3_?nGPk`00_nGPk`00ol0003oUhJooiN6_`02oiN6_`05o`000?nG
R<;oUhS2oiN8`_l000001?nGS<D00ol0003oV8o9oiR?b@04o`0000;oWigB00?o0000oinRe_nOX]H0
0_nOX]H00ol0003oX:KJoj2VfP02oj2VfP03o`000?nQZmkoXJ_N00?o00001OnU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000CoYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol000001?nU
`noo0000ojG3kol00008ooooo`03o`000?oooooooooo00;ooooo001Booooo`03o`000?oooooo0000
00CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003om;;d`04o`000?oXh/_oj>;;o`0000;oimk;00Go0000
onGKbooUfl_oiM_;o`000002on;Gc0;o000000?oh=38o`000?oMc<P00ooMc<P01Ol0003of/S8o`00
0?oIa<Go000000?oe/7600?o0000om:ma_l000000oo@^L<01_l0003ocKG3olfe`ol0003obk71o`00
00?oajk100?o0000olFZ_ol000000oo1Y[l01?l0003o_Z>mokjS_Ol00002okZO_@03o`000?nhW;_o
^9bk00;o^9bk0_l00003ok:E^@05o`000?n`T[So/9:hok2B^?l000000_n]SkH00ol0003oZXbfo`00
0004ojR:]@05o`000?nVQkCoYXNdojJ7]?l000001?nTQK<3o`000003oj62/_l0003oWh6b00;oWh6b
00?o0000oiio/OnNOk400_nNOk401Ol0003oW7jaoian/OnLO[7o000000?oVgfa00Go0000oiYm/_nJ
OK;oVWfbo`000004oiUl/P03o`000?nHO;?o000000?o00000_nIOK<00ol0003oV7jdoiQn]002oiQn
]005o`000?nHOkKoV7nfoiQo]_l000000onHP;P00ol0003oUh:joiN2^P02oiN2^P05o`000?nGPkco
Uh>loiN3_?l000001?nGQ[l01Ol0003oUhS2oiN8`_nGR<;o000000?oUhc51?l00002oijIcP03o`00
0?nOWM;oWigB00;oWigB00?o0000oinRe_nOX]H00_nOX]H00ol0003oX:KJoj2VfP04o`0000?oYL?_
00Co0000ojG3konU`nooYL?_0ol00004ojG3k`06o`000?nU`noo0000o`000?nU`noo00001OnU`nl4
o`000003ojG3kol0003oYL?_00;oYL?_0ol00008ooooo`03o`000?oooooooooo007ooooo001Coooo
o`04o`000?oooooo0000ojG3k`;o00000_nU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?nU`nl00ol0003od/_Co`00
0002onSRb`04o`000?oWg/_oimk;o`0000?oiM_;00Co0000on;Gc?oRelco00000_oOe<`2o`0000?o
gLc800Go0000om[8b?oJb<Sof/S8o`000003omK1aP07o`000?oB_LKod[g6om:ma_l0003od;W3o`00
0004olfe``03o`000?o7[/7oajk100?oajk100?o0000ol6V_oo1Y[l00_o1Y[l00ol0003o_Z>mo`00
0003okZO_@04o`000?nhW;_o^9bkokRL^`;o00001?nbUKT00ol0003o/9:hok2B^002ok2B^0;o0000
0_nZS;H00ol0003oZ8ZeojR:]@02ojR:]@05o`000?nVQkCoYXNdojJ7]?l000000onTQK<2o`0000?o
XH:b00?o0000oin1/_nOPK800_nOPK801Ol0003oWWnaoiio/OnNOk7o000000?oW7ja00Go0000oi]m
/OnKOK7oVgfao`000004oiYm/P03o`000?nIO;;o000000?o00000_nIOK800ol0003oVGfcoiUm/`02
oiUm/`05o`000?nHO[CoV7jdoiQn]?l000001?nHOkH01Ol0003oV82hoiR0^?nHP;So000000?oUh:j
00?o0000oiN3_?nGPk`00_nGPk`00ol0003oUhJooiN6_`02oiN6_`03o`000?nGR<;o000000Co0000
0_nNUL/00ol0003oWYW>oijIcP02oijIcP05o`000?nOWM;oWigBoinMd_l000000onOX]H4o`0000?o
YL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`?o00001?nU`nl00ol0
003oYL?_ojG3k`03o`0000GoYL?_1_l00008ooooo`03o`000?oooooooooo007ooooo001Dooooo`Co
00001?nU`nl00ol0003oYL?_o`000002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00004ojG3k`03
o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oYL?_ojG3k`07o`000003onONbol0003oiM_;00;o
iM_;00Co0000on;Gc?oRelco00000ooOe<`01Ol0003ogM3<o`000?oMc<So000000?of/S800Go0000
omK5bOl0003oe/76o`000005om:maP03o`000?o=]L?ocKG300;ocKG30_l00004olN^`@;o00001?o1
Y[l2o`0000Co^Ynm00Ko0000okRL^onhW;_o0000okBH^ol00004ok:E^@04o`000?n`T[So/9:hok2B
^0;o00001?nZS;H01Ol0003oZ8ZeojR:]OnXR[Go000000CoYXNd0ol000000onRQ;?o0000oj62/P03
oj62/P05o`000?nOPK;oWh6boin1/_l000000onNOk401Ol0003oW7jaoian/OnLO[7o000000CoVgfa
00?o0000oiYm/_l000000ol00002oiYm/P05o`000?nIOK;oVGfboiUm/_l000001?nIOK<00ol0003o
V7jdoiQn]002oiQn]005o`000?nHOkKoV7nfoiQo]_l000000onHP;P01Ol0003oUh:joiN2^_nGP[[o
000000CoUh>l00?o0000oiN6_onGQ[l01?l00002oifBb003o`000?nNUL_oWYG;00?oWYG;00Go0000
oijIc_nNVLkoWYW>o`000002oinMdPGo00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_
00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003o
YL?_ojG3k`03o`0000CoYL?_0_l00007ooooo`03o`000?oooooooooo007ooooo001Fooooo`03o`00
0?oooooo000000;oYL?_0ol00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU
`nl00_nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojW4k@04o`000?o9b=WobLSIolW8
f@?o000000GoiM_;o`000?oRelcoh]O<o`000003omoDc005o`000?oMd<cogM3<omg@c?l000000ooJ
b<P01Ol0003oe/G9omK5bOoFaLWo000000God[g60_l00003olfe``04o`000?o9//CobK;4o`0000;o
ajk100Co0000ol>Z`Oo3Z/7o00000_o1Y[l00ol0003o_J>oo`000005okZO_@;o00000ondV;/00ol0
003o/YFiok:E^@02ok:E^@?o000000?o[8nho`000?nZS;H00onZS;H01Ol0003oZ8ZeojR:]OnXR[Go
000000?oYXNd0_l00003oj:4/`03o`000?nQP[;oXH:b00;oXH:b00Go0000oin1/_nOPK;oWh6bo`00
0003oiio/@03o`000?nLO[7oW7ja00;oW7ja00?o0000oi]m/Ol000000ol00002oi]m/@05o`000?nJ
OK;oVWfboiYm/_l000001?nIOK801Ol0003oVGfcoiUm/onIOK?o000000CoV7jd00Go0000oiQo]_nH
OkKoV7nfo`000003oiR0^003o`000?nGP[[oUh:j00;oUh:j00?o0000oiN3_?nGPk`01?l00002oif?
a@03o`000?nMT/SoWI;800;oWI;800?o0000oijEbonNUL/00_nNUL/01?l0003oWYW>oijIc_nNVLh3
o`0000;oYL?_00?o0000ojG3konU`nl00_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl00ol00007ooooo`03o`000?oooooooooo007ooooo001Gooooo`04o`000?oooooo
0000o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`06o`000?nU`noo0000o`000?nU`noo
00001?nU`nl3o`0000CoYL?_00?o0000ojW4kOl000001?o9b=T00ol0003ogm_BomoKdP02o`000003
on;Gc?l0003ogmC<00;ogmC<00Wo0000omg@c?oMd<cogM3<o`000?oJcLco0000om[8b?l000000ooF
aLT00ol0003od/79o`000003om:maP06o`000?o>^LKoc[W6o`000?o=]L?o00000oo9//@00ol0003o
ajk1o`000003ol>Z`@03o`000?o1Y[oo000000?o_J>o00Co0000okZO_OnjWkgo^Ynm0_l00004okBH
^`04o`000?nbUKWo/YFiok:E^@;o00000on/SkP00ol0003oZXbfojZ<]P02ojZ<]P03o`000?nXR[Go
Z8Ze00;oZ8Ze0ol000000onTQKCo0000oj:4/`03oj:4/`05o`000?nQP[;oXH:boj62/_l000000onO
PK800ol0003oWWnaoiio/@02oiio/@03o`000?nLO[7o000000?o00000_nKOK401Ol0003oVgfaoi]m
/OnKOK7o000000CoVWfb00Go0000oiUm/_nIOK;oVGfbo`000004oiUm/`05o`000?nHO[CoV7jdoiQn
]?l000001?nHOkH01_l0003oV82hoiR0^?nHP;So0000oiN2^PGo00000_nMSL800ol0003oWHo5oif?
a@02oif?a@05o`000?nMT/SoWI;8oifBb?l000001?nNUL/01_l0003oWYW>o`000?l0003oYL?_o`00
00CoYL?_00Ko0000ojG3kol0003o0000ojG3kol00005ojG3k`?o00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU
`nl2o`0000Kooooo00?o0000ooooooooool00Oooool005Sooooo00?o0000ooooool000000_nU`nl4
o`0000CoYL?_00?o0000ojG3konU`nl00ol00004ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o
0000ojG3konU`nl00_nU`nl2o`0000CobLSI00Ko0000omoKd_oOfm;ogm_Bo`000?oQfm03o`000003
omoDc?l0003ogM3<00;ogM3<00Go0000om[=c?oJcLcof/g<o`000003omK5b@07o`000?oB`LWod/79
om;1bOl0003od[g6o`000004oljiaP03o`000?o9//CobK;400;obK;40_l00005ol>Z`@03o`000?nm
Xkoo_J>o00;o_J>o00Ko0000okZO_OnjWkgo0000okJL_Ol00004okBH^`06o`000?nbUKWo/YFio`00
0?n^T[Wo00001?n/SkP01Ol0003oZXbfojZ<]_nZS;Ko000000?oZ8Ze0_l00003ojB5]003o`000?nR
Q;?oXXBc00;oXXBc00Go0000oj62/_nQP[;oXH:bo`000004oin1/P03o`000?nNOk7o000000?o0000
0_nLO[401Ol0003oVgfaoi]m/OnKOK7o000000CoVgfa00Go0000oiYm/_nJOK;oVWfbo`000003oiUm
/P03o`000?nIOK?oVGfc00;oVGfc00?o0000oiQn]?nHO[@00_nHO[@00ol0003oV7nfo`000007o`00
00;oWH_000?o0000oif=`_nMSL800onMSL801Ol0003oWHo5oif?aOnMSlGo000000?oWI;800Co0000
oijEbonNUL_oWYG;0ol00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003oYL?_o`00
0002o`000003ojG3kol0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ooooo`03o`00
0?oooooooooo007ooooo001Iooooo`Co00001?nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00004ojG3k`06o`000?nU`noo0000o`000?nU`noo00000oo9b=T01Ol0003o
gm_BomoKd_oOfm;o000000;ohM_@00Co0000omkHd?oNf=3o00000ooMd<`00ol0003of/g<om[=c002
om[=c0;o000000?oe/G9o`000?oB`LT01?oB`LT00ol0003oc[W6oljiaP02oljiaP;o00000oo9//@0
0ol0003oaJk4o`000004ol>Z`@;o00001?nmXkl00ol0003o^Ynmo`000003okJL_@03o`000?ndV;_o
]9Rk00;o]9Rk0_l00002ojjB^@03o`000?n/SkSo[8nh00;o[8nh00?o0000ojZ<]_nZS;H00_nZS;H3
o`000003ojF7]Ol0003oY8Fd00?oY8Fd00Go0000oj:4/onRQ;?oXXBco`000003oj62/P04o`000?nO
PK;oWh6boin1/P?o00000_nMO[401Ol0003oW7jaoian/OnLO[7o000000CoVgfa00Go0000oi]m/OnK
OK7oVgfao`000003oiYm/P05o`000?nIOK;oVGfboiUm/_l000001?nIOK<00ol0003oV7jdoiQn]004
o`0000;oW8Nl00Go0000oib9__nLRKkoW8Vno`000004oif;`003o`000?nMSL;oWHg200;oWHg200Go
0000oif?aOnMSlGoWHo5o`000002oifBb0Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?o
YL?_00?o0000ojG3konU`nl00ol00005ojG3k`Co000000?oYL?_o`000?nU`nl00onU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000_nU`nl2o`00
00Cooooo00?o0000ooooooooool00Oooool005_ooooo00?o0000ooooool000000_nU`nl4o`0000?o
YL?_00?o0000ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl00ol0003o
bLSIo`000003omoKdP04o`000?oQfm3ohM_@o`0000?og]S@0_l000000ooMd<co0000om[=c003om[=
c004o`000?oFbLgoe/W=o`0000God/790_l00003oljiaP06o`000?o:]/Oob[K7o`000?o9//Co0000
0oo5[/@01?l0003o`j[1ol>Z`Ol00002okjW`P04o`000?nmXkoo_J>ookfS_`;o00001?nfW;d01?l0
003o]9RkokBH^ondV;/2o`0000Co[Y:i00Go0000ojb?^?n/SkSo[8nho`000003ojZ<]P;o00000onU
QkD00ol0003oY8FdojB5]002ojB5]005o`000?nRQ;?oXXBcoj:4/ol000001?nQP[83o`000003oiio
/Ol0003oWGja00;oWGja00?o0000oian/OnLO[400_nLO[401Ol0003oVgfaoi]m/OnKOK7o000000?o
Vgfa00Go0000oiYm/_nJOK;oVWfbo`000004oiUm/P03o`000?nIOK?oVGfc00Co00000_nLQ[/01Ol0
003oW8Nloib7_?nLQkco000000CoW8Vn00?o0000oif;`?nMRl000_nMRl001Ol0003oWHg2oif=`_nM
SL;o000000;oWHo51?l00003ojG3k`03o`000?nU`nooYL?_00Go00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`Co000000?oYL?_o`000?nU`nl00onU
`nl3o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`?o0000
1?ooool1o`00007ooooo0Oooool005cooooo00Co0000ooooool0003o00001?nU`nl00ol0003oYL?_
ojG3k`03o`0000CoYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Go0000
00Gogm_Bo`000?oQfm3ohM_@o`000003omkHd003o`000?oLe=7og=CA00;o00000ooJcL`01?l0003o
e/W=omK9cOoFbLd2o`0000?od/7900Ko0000olnnbOo?_/Wo0000oljia_l00004olZfa`03o`000?o5
[/CoaJk400;oaJk400?o0000ol>Z`Ol000000onnYl801_l0003o_J>ookfS_ol0003o^:2oo`0000Co
]Ybm00Ko0000okBH^ol0003o0000ok2E^ol00004ojjB^@03o`000?n/SkSo[8nh00;o[8nh0ol00000
0onWR[Ko0000ojF7]@03ojF7]@05o`000?nTQKCoY8FdojB5]?l000001?nRQ;<00ol0003oXH:bo`00
0002o`0000?oWWna00?o0000oien/OnMO[400_nMO[401Ol0003oW7jaoian/OnLO[7o000000?oVgfa
00Go0000oi]m/OnKOK7oVgfao`000004oiYm/P03o`000?nIOK;o000000Co00000_nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000CoW8Nl00Go0000oib9__nLRKkoW8Vno`000004oif;`003o`000?nMSL;o
WHg200Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3konU`nooYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_1?l0
00000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`05o`000003ojG3kol0
003o000000Cooooo0Ol00001ooooo`7ooooo001Mooooo`04o`000?ooooooooooo`0000;oYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000CoYL?_0ol0
00000ooQfm3o0000omkHd002omkHd004o`000?oLe=7og=CAo`0000;ofM7A00?o0000om[=c?l00000
0ooFbLd01_l0003odlG=om?5cOl0003od/79o`0000Cockk900?o0000olZfaoo:]/L00_o:]/L2o`00
00CoaJk40_l00004okjW`P03o`000?nmXkoo000000?o^:2o00Co0000okJL_OnfW;go]Ybm0_l00004
ok2E^`05o`000?n^T[Wo[Y:iojjB^Ol000000on/SkP2o`0000?oYhZf00?o0000ojF7]OnUQkD00_nU
QkD01Ol0003oY8FdojB5]?nTQKCo000000?oXXBc0ol00002oin1/P03o`000?nNOk7oWWna00;oWWna
00Go0000oien/OnMO[7oWGjao`000003oian/@05o`000?nKOK7oVgfaoi]m/Ol000001?nKOK400ol0
003oVWfbo`000003o`0000;oWHBi00?o0000oif5^_nMQKX00_nMQKX00ol0003oW8Jkoib6^`02oib6
^`05o`000?nLQkcoW8Nloib7_?l000000onLRKh00ol0003oWH_0oif;`002oif;`0?o00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`000?nU`noo
YL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0005ojG3k`Co000000?oYL?_o`000?nU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0003ooooo`7o00000Oooool1ooooo`00G_ooool2o`000003ooooool0003o000000?oYL?_00?o0000
ojG3konU`nl01?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003oYL?_o`000?l0
0002okk7h@Co000000Gog]S@o`000?oLe=7og=CAo`000004omWAd@05o`000?oFbLgoe/W=omK9cOl0
00001?oCaLd00ol0003ockk9olnnb@02olnnb@;o00000oo:]/L01?l0003oa[?7olJcaol00002olF^
a003o`000?o0ZlGo000000Co_ZO20_l00004okRP_`06o`000?nfW;go]Ybmo`000?nbVKgo00001?n`
UK/00ol0003o[Y:iojjB^@02ojjB^@?o000000?oZHfho`000?nWR[H00onWR[H01Ol0003oYHNeojF7
]OnUQkGo000000CoY8Fd0ol000000onPP[?o0000oin1/P02oin1/P03o`000?nNOk7oWWna00;oWWna
00Go0000oien/OnMO[7oWGjao`000003oian/@03o`000?nKOK7oVgfa00;oVgfa00?o0000oi]m/Ol0
00000ol00002oif4^003o`000?nMQ;WoWHBi00;oWHBi00?o0000oif5^_nMQKX00_nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000?oW8Nl00?o0000oib9__nLRKh00_nLRKh4o`000003ojG3kol0003oYL?_
00?oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`05o`00
00;oYL?_00Co0000ojG3konU`nooYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000_nU`nl2
o`0000;ooooo0Ol00001ooooo`7ooooo001Pooooo`03o`000?oooooo000000;oYL?_1?l00004ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?o_/OQ00?o0000om7@
f?oAd=P00_oAd=P2o`000003omcDdOl0003ofM7A00?ofM7A00Go0000omK=dOl0003oe/W=o`000004
om?5c@;o00000oo?_/T01_l0003obk[:ol^jb_l0003ob[K7o`0000?oa[?700?o0000olF^a?l00000
0oo0ZlD01_l0003o_ZO2okjW`_l0003o^ZC2o`0000Co^:2o00?o0000okJL_Ol000000onbVKd01Ol0
003o/9Fkok2E^on`UK_o000000?o[Y:i0_l00003ojV=^003o`000?nWR[KoYhZf00;oYhZf00?o0000
ojF7]OnUQkD00_nUQkD00ol0003oY8Fdo`000002o`0000?oX8:c00?o0000oin1/_nOPK800_nOPK80
1Ol0003oWWnaoiio/OnNOk7o000000?oWGja00Go0000oian/OnLO[7oW7jao`000003oi]m/@?o0000
0_nMQ;L00ol0003oWHBhoif4^002oif4^005o`000?nMQ;WoWHBioif4^Ol000001?nMQKX01Ol0003o
W8Jkoib6^onLQ[_o000000CoW8Nl00?o0000oib9__l000000_l00005ojG3k`Co000000?oYL?_o`00
0?nU`nl00onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001OnU`nl4o`000003ojG3kol0003oYL?_00;oYL?_0ol00000
0ooooooo0000ooooo`01ooooo`00HOooool01?l0003oooooo`000?l00004ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000okk7hOl000001?oAd=P0
0ol0003of]WFom[IeP02o`0000?ofM7A00?o0000omK=dOoFcM400ol00003om?5c@06o`000?o?`/ko
cl;>o`000?o?_/Wo00000oo;^/X2o`0000Goa[?700?o0000ol2[aOo0ZlD00_o0ZlD00ol0003o_ZO2
o`000003okZT`P03o`000?nhX;oo^:2o00;o^:2o00?o0000ok:I_OnbVKd00_nbVKd00ol0003o/9Fk
ok2E^`02ok2E^`?o000000?oZXnjo`000?nYSKP00onYSKP01Ol0003oYhZfojN:]_nWR[Ko000000?o
YHNe0ol00002oj64]003o`000?nPP[?oX8:c00;oX8:c00Go0000oin1/_nOPK;oWh6bo`000003oiio
/@05o`000?nMO[7oWGjaoien/Ol000001?nLO[43o`000003oij4]ol0003oWHBg00;oWHBg00?o0000
oif4^?nMQ;P00_nMQ;P00ol0003oWHBioif4^@02oif4^@05o`000?nMQK[oWHFjoif5^_l000001?nL
Q[/00ol0003oW8Nlo`000003o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`06o`000?nU
`noo0000o`000?nU`noo00001?nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl4o`000005ojG3kol0003o0000
ooooool000000_ooool006;ooooo00?o0000ooooool000001?nU`nl3o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000ooAd=P01?l0003of]WFom[Ie_l00002
omOEeP03o`000?oIdM7o000000;oe/gA00Oo0000om;:d_oBb];od/[Bo`000?oCaLgo000000?ocl;>
0_l00003ol^jbP04o`000?o7]l_oakO;o`0000?oa[?70_l00005ol2[a@03o`000?njY<;o^ZC200?o
^ZC200?o0000okRP_onhX;l00_l00004ok:I_@04o`000?n`UK_o/9Fkok2E^`;o00001?nZSkX01Ol0
003oZHfhojV=^?nYSKSo000000CoYhZf0ol000000onSQKGo0000oj64]002oj64]003o`000?nPP[?o
X8:c00;oX8:c00Go0000oin1/_nOPK;oWh6bo`000003oiio/@03o`000?nMO[7oWGja00;oWGja00?o
0000oian/Ol000000_l00003oij4]`03o`000?nMQ;OoWHBg00;oWHBg00?o0000oif4^?nMQ;P00_nM
Q;P01Ol0003oWHBioif4^OnMQ;Wo000000CoWHFj00?o0000oib6^ol000000ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000onU`nl01?l0003oYL?_ojG3konU`nl3o`0000CoYL?_00Ko0000ojG3kol0
003o0000ojG3kol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000
ojG3konU`nl01Ol00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00000_ooool006?ooooo
0ol000001OnU`noo0000o`000?nU`noo000000CoYL?_0ol00004ojG3k`03o`000?nU`nooYL?_00?o
00001?nU`nl00ol0003odM3Ho`000002om[IeP04o`000?oGeMKoemGFomOEeP?o000000?oe/gAo`00
0?oBb]800ooBb]82o`0000?ocl;>00Ko0000ol^oc_o;_lko0000ol^jb_l00004olNgb`03o`000?o6
/lOo000000;o`Zo800Co0000ol2[aOo0ZlGo`:_50_l00005okZT`P03o`000?nhX;oo000000;o]9g0
00?o0000ok:I_OnbVKd00_nbVKd3o`000003ojbB_?l0003oZXnj00?oZXnj00Go0000ojV=^?nYSKSo
ZHfho`000003ojN:]P;o00000onSQKD00ol0003oXHBdoj64]002oj64]005o`000?nPP[?oX8:coj22
/ol000000onOPK800ol0003oWWnaoiio/@02oiio/@03o`000?nMO[7o000000?o00000_nNQ;L00ol0
003oWXBgoij4]`02oij4]`05o`000?nMQ;OoWHBgoif4]ol000001?nMQ;P01Ol0003oWHBioif4^OnM
Q;Wo000000;oWHFj1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`06o`000?nU`noo0000o`000?nU
`noo00001?nU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004
ojG3k`03o`000?nU`noo000000?o00000Oooool1o`00007ooooo001Uooooo`?o00000onU`nl01?l0
003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00;oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co000000?of]WFo`000?oGeMH00_oGeMH01?l0003oe=;GomCBeooDd]L2o`0000?od/[B00Ko
0000olo6d_o?a];o0000olo2c_l00004ol^ocP03o`000?o7]l_oakO;00?oakO;0_l00004ol:_b003
o`000?o0ZlGo000000;o_:S500?o0000okZT`_njY<800_njY<82o`0000Co]9g000?o0000ok:I_Onb
VKd00_l00004ojbB_005o`000?nZSk[oZXnjojZ?^_l000001?nYSKP3o`000003ojB8]_l0003oXhFe
00?oXhFe00Go0000oj64]?nQQ;CoXHBdo`000003oj22/`03o`000?nOPK;oWh6b00;oWh6b00?o0000
oiio/Ol000000ol00002oij5]`05o`000?nNQ;OoWXBgoij4]ol000001?nNQ;L01Ol0003oWHBgoif4
]onMQ;Oo000000CoWHBh00?o0000oif4^OnMQ;T01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`04o`00
0?nU`nooYL?_ojG3k`?o00001?nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002ojG3
k`04o`000?nU`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_0ol00001
ooooo`00I_ooool00ol0003oooooo`000002ojG3k`?o00001?nU`nl01_l0003oYL?_o`000?l0003o
YL?_o`0000CoYL?_0ol00003ok35j@Co000000?oemGFo`000?oDd]L00_oDd]L01_l0003odLkGom7>
eol0003od/[Bo`0000?oclKB0_l00004ol^ocP03o`000?o7^loo000000?oakO;00?o0000ol>dc?l0
00001?o2[lP2o`0000Co_:S500Ko0000okZT`_l0003o0000okJQ`ol00004okBM`005o`000?nbVKgo
0000ojjF__l000001?n/T[`00ol0003oZXnjojZ?^P02ojZ?^P03o`000?nYSKSo000000;o00000onT
R;H00ol0003oXhFeoj>5]@02oj>5]@05o`000?nQQ;CoXHBdoj64]?l000001?nPP[<00ol0003oWh6b
o`000003o`0000;oWhFh00Go0000oij5]onNQKOoWXFgo`000004oij4]`05o`000?nNQ;OoWXBgoij4
]ol000000onMQ;L00ol0003oWHBhoif4^002oif4^0?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_0ol00004ojG3k`?o00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol0
0001ooooo`00Ioooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU
`nl01?l0003oYL?_o`000?l00003ojG3k`03o`000?n`aNWo000000Co`/SN00Go0000omCBeooDd]Oo
e=;Go`000004om7>e`07o`000?o?a];oclKBolo6d_l0003obl?Co`000003ol^ocP07o`000?o7^loo
ak_?olNkcol0003oakO;o`000003ol>dc006o`000?o2[lSo`Zo8o`000?nm[LWo00001?nlZ<D2o`00
00Co]Z7300Co0000okBM`?ndWL3o]9g00_l00003ojjF_P05o`000?n/T[co[9:lojbB_?l000000onZ
SkX3o`0000;oYHZh00?o0000ojB8]_nTR;H00_nTR;H01Ol0003oXhFeoj>5]OnSQKGo000000?oXHBd
00Co0000oj22/onPP[?oX8:c0ol00002oj26^005o`000?nOQKSoWhFhoin5^?l000001?nNQKL01Ol0
003oWXBgoij4]onNQ;Oo000000?oWXBg00?o0000oif4]onMQ;L00_nMQ;L4o`0000;oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Go00000_nU`nl0
0ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01Ol00002
ojG3k`04o`000?nU`nooYL?_ojG3k`Oo00000Oooool006Sooooo00?o0000ooooool000000_nU`nl4
o`0000?oYL?_00?o0000ojG3konU`nl01?l00004ojG3k`;o00001?o2b=h01Ol0003ocmCMo`000?oD
d]Oo000000CodLkG00Go0000olg;eol0003oclKBo`000003ol_3d`03o`000?o;_lko000000Coak_?
0_l00004ol>dc003o`000?o2[lSo000000?o_Jg900Ko0000okbXaOnlZ<Go0000okNUa_l00004okJQ
``06o`000?ndWL3o]9g0o`000?n_V/7o00000on^U[h00ol0003o[9:lojbB_002ojbB_0?o000000?o
YXfjo`000?nUR[P00_nUR[P00ol0003oY8RfojB8]P02ojB8]P05o`000?nSQKGoXhFeoj>5]Ol00000
1?nQQ;@3o`000003oj67^Ol0003oX8Jh00;oX8Jh00?o0000oin5^?nOQKP00_nOQKP01Ol0003oWXFg
oij5]onNQKOo000000?oWXBg00?o0000oij4]onNQ;L00_nNQ;L00ol0003oWHBgo`000002o`0000Go
YL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003o
YL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Wo
00001?ooool006Wooooo1?l00004ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01_l0003oYL?_
o`000?l0003oYL?_o`0000?o`/SN00Co0000oloDgOo?e=gocmCM0_l00003om7>e`05o`000?o=bmOo
cL_Golg;eol000001Oo;`m<2o`0000?oak_?00?o0000ol>id?l000001?o3]<`2o`0000Co_Jg900?o
0000okbXaOl000000ongYLH01ol0003o]Z73okJQ`onfXL?o0000okBM`?l000000on_V/401Ol0003o
[YJnojjF__n^U[ko000000;o[9:l0_l00003ojJ=^P03o`000?nUR[SoYHZh00;oYHZh00Go0000ojB8
]_nTR;KoY8Rfo`000004oj>5]@03o`000?nQQ;Co000000;o00000onQQkT00ol0003oX8Jhoj26^002
oj26^005o`000?nOQKSoWhFhoin5^?l000000onNQKL00ol0003oWXBgoij4]`02oij4]`03o`000?nN
Q;Oo000000?o00000onU`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00?oYL?_0ol0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`02ojG3k`Co00000_nU`nl01?l0003oYL?_ojG3
konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o00002?ooool006_ooooo00?o
0000ooooool000000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`03o`000?o2
b=ko000000?ocmCM00Ko0000olkBgOo>d]go0000om7>eol00003olg;e`03o`000?o:amSo000000?o
bl?C00Ko0000olO0doo7`=?o0000olNkcol00003ol>id006o`000?o3]<co`kC<o`000?nn/Lgo0000
1?nm[LT2o`0000Co]jG600Co0000okJQ`onfXL?o]Z730_l00004ojnJ`@09o`000?n^U[ko[YJnojjF
__l0003o[9:lo`000?nXT;co000000CoYXfj00Go0000ojF:^?nUR[SoYHZho`000004ojB8]P03o`00
0?nSQKGo000000?o00000_nQRKX00ol0003oXHNioj67^@02oj67^@05o`000?nPQ[SoX8Jhoj26^?l0
00000onOQKP00ol0003oWXFgoij5]`02oij5]`03o`000?nNQ;Oo000000?o00000onU`nl00ol0003o
YL?_ojG3k`03o`0000GoYL?_1?l000000onU`noo0000ojG3k`03ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`Co
00000_nU`nl00ol0003oYL?_ojG3k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00002oooo
o`Co00002oooool006cooooo00Co0000ooooool0003o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01Ol000000oo?e=go0000olkBg@02olkBg@;o00000oo=bmL01ol0
003ob/OHol[7f?o:amSo0000ol_3dol000000oo7`=<2o`0000Co`kW@00?o0000ol>dc?l000000onn
/Ld01_l0003o_Jg9o`000?l0003o^JW:o`0000Co]jG600Ko0000okJQ`ol0003o0000ok6Na?l00004
ojnJ`@04o`000?n^U[ko[YJnojjF_P;o00000onXT;`01Ol0003oYXfjojJ=^_nVSK[o000000?oYHZh
00Co0000ojB8]_nTR;KoY8Rf0ol00002oj:;^`03o`000?nQRK[oXHVj00;oXHVj00Go0000oj67^OnQ
QkWoXHNio`000003oj26^003o`000?nOQKSoWhFh00;oWhFh00?o0000oij5]ol000000ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000GoYL?_1?l00002ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00Ko0000ojG3kol0003o0000ojG3kol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3
k`05o`0000;ooooo1?l0000?ooooo`00KOooool00ol0003oooooo`000002ojG3k`Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000CoYL?_0_l00003olkBg@06o`000?o;cmgobloMo`000?o=bmOo0000
1?o:amP2o`0000?oal3C00?o0000ol>me?l000001?o3^M02o`0000Co_[7=0_l00004okVYbP04o`00
0?ngYLKo]jG6okNUaP;o00001?naW/@00ol0003o[i[1ojnJ`@02ojnJ`@?o000000?oZI>oo`000?nX
T;`00_nXT;`01Ol0003oYXfjojJ=^_nVSK[o000000CoYHZh0ol000000onSSKgo0000oj:;^`03oj:;
^`05o`000?nQRK[oXHVjoj69^_l000000onQQkT00ol0003oX8Jhoj26^002oj26^003o`000?nOQKSo
000000?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001OnU`nl3o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl01?l0003oYL?_o`00
0?l00002ojG3k`03o`000?nU`nooYL?_00Co00000oooool4o`0001?ooooo001^ooooo`Co00001?nU
`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_00Co0000ojG3kol0003o00000_nda^L00ol0003oc];M
o`000003ol_?g@?o00000oo:amP01_l0003oa/CHolK4f?l0003oal3Co`0000?o`kgD00Ko0000ol>i
d?l0003o0000oknfdOl00003okjac@03o`000?nj[/ko000000Co^JW:00Ko0000okNUa_l0003o0000
ok>Raol00004ok6Na004o`000?n_V/7o[i[1ojnJ`@;o00001?nYTkl01Ol0003oZ92lojR@_?nXT;co
000000?oYXfj00?o0000ojF:^?l000000_l00003oj>=_@03o`000?nRRk_oXX^k00;oXX^k00Go0000
oj69^_nQRK[oXHVjo`000004oj67^@03o`000?nPQ[So000000?o00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_o`000002o`000003ojG3kol0003oYL?_00;oYL?_1?l00002ojG3k`04o`000?nU
`nooYL?_ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_
0ol00004ooooo`?o00005oooool0073ooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_00?o
0000ojG3konU`nl00ol00004okC6i`?o000000?obloMo`000?l000000oo7c=d00ol0003ob/OHo`00
0003olK4f0;o00001?o3_M@2o`0000Co_kKA00?o0000okjacOl000000onj[/h01?l0003o^JW:okVY
b_niZLX2o`0000Co/j;700Ko0000ok6Na?naW/Co/Ik4o`000?n_V/42o`000003oj^G`_l0003oZI>o
00?oZI>o00Go0000ojR@_?nXT;coZ92lo`000002ojJ=^P?o00000_nTSkl00ol0003oXhfmoj>=_@02
oj>=_@05o`000?nRRk_oXX^koj:;^ol000001?nQRKX00ol0003oXHNio`000003o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00005ojG3k`?o00000_nU`nl00ol0003oYL?_ojG3
k`05o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00002ojG3k`04o`000?nU`nooYL?_ojG3k`Co
00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`04o`000?nU`noo0000o`0000?ooooo1?l0000Jooooo`00LOooool01?l0003oooooo`000?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl01?l0003o]<KWo`000?l00003okk9h`;o00001?o7
c=d2o`0000?oa/CH00?o0000ol;1fOl000000oo3_M@00ol0003o_k[Eo`000004oknfd@;o00001?nj
[/h01_l0003o^JW:o`000?l0003o]:O;o`0000Co/j;700?o0000ok6Na?naW/@00ol00004oj^G`P05
o`000?nYTkooZI>oojVC_ol000000onXT;`3o`000003ojFA`Ol0003oY8no00?oY8no00Go0000oj>=
_OnSSKgoXhfmo`000004oj:;^`03o`000?nQRK[o000000?o00000onU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00004ojG3k`?o00000onU`nl0
0ol0003oYL?_ojG3k`05o`0000;oYL?_00?o0000ojG3konU`nl01Ol00002ojG3k`03o`000?nU`noo
YL?_00Go00000_nU`nl01?l0003oYL?_ojG3konU`nl4o`0000;oYL?_00Co0000ojG3konU`nooYL?_
0ol000000ooooooo0000o`000002o`0001kooooo001booooo`03o`000?oooooo000000;oYL?_1?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000onnbN<01Ol0003oa<oSolC?hol0003oalcM00;o0000
0_o4b=h00ol0003oa/CHo`000003ol;1f@03o`000?o3_MCo000000?o_k[E00Ko0000oknfdOl0003o
0000okZcd_l00004okZ^cP;o00001?ndYl/01?l0003o/j;7ok>RaoncX/L3o`0000;o[9_500?o0000
oj^G`_n[Ul800_n[Ul800ol0003oZI>oojVC_`02ojVC_`?o000000?oYYC3o`000?nUTL400_nUTL40
1Ol0003oY8noojB?_onTSkoo000000?oXhfm00Co0000oj:;^onRRk_oXX^k0ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00Co0000ojG3kol0003o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`05o`0000;o
YL?_00?o0000ojG3konU`nl02Ol0000Rooooo`00Loooool4o`0000CoYL?_00?o0000ojG3konU`nl0
0ol00004ojG3k`03o`000?nnbN?o000000?oa<oS0_l00004olC8gP;o00001?o2`MT2o`0000Co_k[E
0_l00004okZcdP06o`000?nj[/ko0000o`000?ne[<oo00001?ndYl/01_l0003o/j;7o`000?l0003o
[Yo9o`0000Co[9_500Go0000oj^G`_n[Ul;oZiO2o`000002ojVC_`?o00001?nVU<<01?l0003oYI71
ojFA`Ol00003ojB?_`03o`000?nSSKgoXhfm00;oXhfm0ol00002ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl00ol00004ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`000003
ooooool0003o000000;o00009_ooool007Gooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_
00?o0000ojG3konU`nl01?l000000oo4cn?o0000o`000002ol3<h`04o`000?o4b=ko0000o`0000;o
`<GN00Co0000ol;1fOl0003o00000_nn_]X01?l0003o_k[Eo`000?l00002okZhe`04o`000?nj/m;o
^[?BokZcdP;o00001?ne[<l01?l0003o]:O;okBWbondYl/2o`0000Co[Yo900Go0000ojbKaOn/VlGo
[9_5o`000003oj^G`P?o00000_nWV<H00ol0003oYYC3ojJD``02ojJD``05o`000?nUTL7oYI71ojFA
`Ol000000onTSkl00ol0003oXhfmo`000002o`0000CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3
kol0003o00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo0ol0000Z
ooooo`00M_ooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onW`nh2
o`0000Co`<cS0ol00003ol35gP?o00000onn_]X2o`0000Go^[SG00Go0000okZcd_l0003o][3Do`00
0004okF/c`06o`000?ndYl_o0000o`000?n_Y<go00001?n^WlT01_l0003o[9_5ojbKaOn/VlGo0000
oj^G`P;o000000?oZ9_9o`000?nWV<H00onWV<H01Ol0003oYYC3ojJD`onVU<?o000000?oYI7100?o
0000ojB?_onTSkl00ol00003ojG3k`04o`000?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl0
1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`03o`0000CoYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000;Oooool007Oooooo00?o
0000ooooool000000_nU`nl4o`0000?oYL?_00Co0000ojO3k_l0003o00000_n`aNT01?l0003o`<cS
o`000?l00003okg9h`03o`000?o0aMko000000?o_<?O00?o0000okjnf_l000000_nj_=/00ol0003o
^[SGokZhe`02okZhe`;o00000onf/=@01?l0003o]Jc?okF/cone[<l2o`0000Co[jC=00Go0000ojjO
bOn^WlWo[Yo9o`000002ojbKa@?o00001?nXVlT01Ol0003oYiS6ojNHa_nWV<Ko000000CoYYC300?o
0000ojFA`Ol000000ol00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl3o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3
k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000<Oooool007Sooooo1?l0
0004ojG3k`03o`000?nU`nooYL?_00?o00000on`aNT3o`0000Co_LWS0_l00004okc3g`;o00001?nj
_=/01_l0003o^[SGo`000?l0003o][GHo`0000Co][3D00Go0000okF/col0003o/:WAo`000004ojnT
c@03o`000?n^WlWo[Yo900Co00000_nXWl`00ol0003oZ9_9ojRKb@02ojRKb@05o`000?nWV<KoYiS6
ojNHa_l000000_nVU<<4o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
000000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000CoYL?_0ol00003ojG3k`03o`000?nU`noo
YL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l0000eooooo`00N_ooool00ol0
003oooooo`000002ojG3k`Co00000onU`nl00ol0003o/<GYo`000003okG8j004o`000?nmbN?o0000
o`0000;o^LKT00Ko0000okc3gol0003o0000okS0h?l00004okZlf`;o00001?nf]MP00ol0003o][3D
okJ`e003o`0000?o/:WA00Co0000ojnTcOn_Y<go[jC=0ol00002ojVSd003o`000?nXWlcoZ9o<00;o
Z9o<00Go0000ojRKbOnXVlWoZ9_9o`000002ojNHaPCo00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`000?nU`noo0000
o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000oooool3
o`0003Wooooo001kooooo`04o`000?oooooo0000o`0000?oYL?_00?o0000ojG3konU`nl00ol00004
okG8j0;o00001?nia^@2o`0000Co^<3P00Ko0000okZlfol0003o0000okFjgOl00004okJef0?o0000
0_n`[]H00ol0003o/:WAok2Yd@02ok2Yd@05o`000?n_Y<go0000ojZWe?l000001?nYXm001Ol0003o
Z9o<ojROc?nXWlco000000;oZ9_91?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3kol000000onU`nl00ol0003oYL?_ojG3k`03o`00
00?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00?o00001?nU`nl3o`0000;oYL?_00Co0000ojG3konU`nooYL?_1?l00003ooooo`Co0000??ooool0
07cooooo00?o0000ooooool000000_nU`nl4o`0000?oYL?_00Co0000okG8j?l0003o00000_nfbNP0
1_l0003o^LKTo`000?l0003o]/CUo`0000Co^<3P0_l00004okFjg@06o`000?nf]MSo0000o`000?n`
/m[o00001?n`[]H00ol0003o/:WAok2Yd@03o`0000?oZZOD00Go0000ojVSd?nYXm3oZJ?@o`000002
ojROc0Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00?o00001?nU`nl3o`0000;oYL?_00?o0000ojG3konU`nl01?l00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl01_l0003oYL?_o`000?l0
003oYL?_o`0000;oYL?_1Ol00003ooooo`Co0000@?ooool007gooooo1?l00003ojG3k`03o`000?nU
`nooYL?_00?o00001?nfbNP2o`0000Co]/CU00Co0000okS0h?l0003o00000_nd_^800ol0003o]K[M
okFjg@03o`0000Co/;?J00?o0000ok2^e_n`[]H01?l00002oj^/f005o`000?nZYmCoZZODojZWe?l0
00000_nYXm04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00Co0000ojG3kol0003o00000_nU`nl00ol0
003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000_nU`nl4o`0000Cooooo1?l00014ooooo`00Ooooool00ol0003o
ooooo`000002ojG3k`?o00000onW`nh01?l0003o]/WXo`000?l00002ok;6j@03o`000?nfa>Go]/CU
00?o00001?nd_^83o`0000;o/;SO00?o0000ok2cf_n`/mX00_n`/mX3o`0000;oZk3L00?o0000oj^/
f?n[[=P00_n[[=P00ol0003oZZODojZWe003o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`?o00001Oooool3o`0004Sooooo0020ooooo`04
o`000?oooooo0000o`0000?oYL?_00?o0000ojO3k_nW`nh00ol00003ok;6j@?o00000onb`NH01_l0
003o];kRo`000?l0003o[kcSo`0000Co/;SO00Ko0000ok2cf_l0003o0000oj^dh?l00004oj^`g003
o`000?n[[=SoZjcH00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003o
YL?_ojG3k`04o`0000;oYL?_00Co0000ojG3kol0003o00001?ooool4o`0004_ooooo0021ooooo`03
o`000?oooooo000000;oYL?_1?l00003oj[4k003o`000?nba^Wo000000?o[lCY00?o0000ok;1i_nb
`NH00ol00003ojnlh`03o`000?n`^=oo/;SO00?o00001?n[]>000ol0003oZk3Loj^`g004o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03
o`000?nU`nooYL?_00?o00000_ooool4o`0004oooooo0022ooooo`Co00000onU`nl00ol0003oZ/C/
oj[4k004o`0000;o[lCY1?l00003ojjoi`03o`000?n__>?o[kcS00?o00000on[^N<00ol0003oZkCP
oj^dh004o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`04o`00
0?nU`noo0000o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o
00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03
o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`000003ooooool0003o000000;o
0000Doooool008Cooooo0_l00002ojG3k`Co00000on[aN`3o`0000?o[<;Z00?o0000ojjoion^_nL0
1?l00003ojZli`03o`000?n[^N?oZkWS00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ooooo`?o0000
Eoooool008Gooooo0ol00003ojG3k`04o`000?n[aNco0000o`0000;oZLC]00?o0000ojc2j_n/`^X0
1?l00003ojVoj@03o`000?nZ_>OoZ[cW00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_
00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_
ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`Co00000onU`nl00ol0003oYL?_
ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l000000ooooooo0000
o`000002o`0005[ooooo0026ooooo`03o`000?oooooo000000;oYL?_0ol00003ojW4k@?o00000onX
`N`00ol0003oZKoYojVoj@04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU
`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl3o`0000?oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o
0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co000000?oooooo`000?l000000_l0
001Nooooo`00Qoooool4o`0000?oYL?^00?o0000ojW4kOl000000onW`nd00ol0003oZ<7/ojS1k003
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl0
0ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`noo
YL?_00Co00000_nU`nl01?l0003oYL?_o`000?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU
`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`000003ooooool0003o000000;o0000H_oo
ool008Wooooo0_l00002ojG3kPCo00000_nW`nd4o`0000?oYL?_00?o0000ojG3konU`nl00ol00003
ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co000000?ooooo
o`000?l000000_l0001Vooooo`00R_ooool3o`0000;oYL?^1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`00
00;ooooo0ol0001Zooooo`00Roooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3
konU`nl01?l00002ojG3k`Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3
konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`00
00;ooooo1?l0001]ooooo`00S?ooool2o`000004ooooool0003oYL?_ojG3k`?o00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00002ojG3
k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l0001aoooo
o`00S_ooool01?l0003oooooo`000?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0
003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`000?nU`nooYL?_
00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00003ojG3
k`03o`000?nU`nooYL?_00?o00000_ooool4o`0007Gooooo002?ooooo`03o`000?oooooo000000;o
YL?_1?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl3o`0000?o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003o
YL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o0000NOooool0093ooooo
00Co0000ooooool0003o00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_ooool4o`0007co
oooo002Aooooo`03o`000?oooooo000000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_00?o0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`Co0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o0000ojG3konU`nl01?l00003ojG3k`03o`00
0?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;ooooo1?l00020ooooo`00T_oo
ool4o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_0ol00003ojG3k`03o`000?nU`nooYL?_00Co00000onU
`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU
`nooYL?_00Co00000_ooool4o`0008Cooooo002Dooooo`;o00000_nU`nl4o`0000?oYL?_00?o0000
ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl4o`0000;oYL?_00?o0000
ojG3konU`nl01?l00003ojG3k`03o`000?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04
o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ooooo`?o0000R?ooool009Gooooo0ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000_nU`nl7o`0000;oYL?_1?l00003ojG3k`03o`000?nU`nooYL?_
00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3
k`03o`000?nU`nooYL?_00Co00000_ooool4o`0008_ooooo002Fooooo`03o`000?oooooo000000;o
YL?_0ol00002ojG3k`Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU
`nl01?l00003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;o
YL?_00?o0000ojG3konU`nl01?l00002ooooo`Co0000Soooool009Oooooo1?l00002ojG3k`?o0000
0onU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl00ol00003ojG3k`03o`00
0?nU`nooYL?_00Co00000_nU`nl00ol0003oYL?_ojG3k`04o`0000?oYL?_00?o0000ojG3konU`nl0
0ol00002ooooo`Co0000Toooool009Wooooo00Co0000ooooool0003o00000onU`nl00ol0003oYL?_
ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU`nooYL?_00Co0000
0onU`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ooooo`?o0000
Uoooool009[ooooo00?o0000ooooool000000_nU`nl4o`0000;oYL?_00?o0000ojG3konU`nl01?l0
0003ojG3k`03o`000?nU`nooYL?_00?o00000onU`nl00ol0003oYL?_ojG3k`04o`0000;oYL?_00?o
0000ojG3konU`nl01?l00002ooooo`Co0000V_ooool009_ooooo00Co0000ooooool0003o00000onU
`nl00ol0003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`03o`000?nU
`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03o`0000;ooooo1?l0002Nooooo`00W?ooool3
o`0000;oYL?_1?l00002ojG3k`03o`000?nU`nooYL?_00Co00000onU`nl00ol0003oYL?_ojG3k`03
o`0000;oYL?_2?l000000ooooooo0000o`000002o`000:;ooooo002Nooooo`?o00000onU`nl00ol0
003oYL?_ojG3k`03o`0000?oYL?_00?o0000ojG3konU`nl01?l00002ojG3k`?o00001Oooool4o`00
0:Kooooo002Oooooo`;o00000_nU`nl4o`0000?oYL?_00?o0000ojG3konU`nl00ol00002ojG3k`Co
00001Oooool3o`000:[ooooo002Pooooo`?o00000_nU`nl8o`0000;oYL?_0ol00005ooooo`Co0000
[Oooool00:7ooooo1?l00003ojG3k`03o`000?nU`nooYL?_00Co00001?ooool4o`000;7ooooo002S
ooooo`03o`000?oooooo000000;oYL?_0ol00004ooooo`Co0000]Oooool00:Cooooo00Co0000oooo
ool0003o00001?ooool3o`000;Wooooo002Uooooo`;o000000?oooooo`000?l000000_l0002loooo
o`00Y_ooool2o`000<3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002nooooo`?o000000?o410@ooooooooool0Y?ooool009cooooo00?o^[Zjoc8b<_ooool0
3Oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Fooooo`00WOooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Gooooo`00Voooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1gooooo`00Voooool0
1ol0003oZJVYoeEEEOnHV9SoEEEEokZj^_l000000_ooool00ol0003oooooooooo`05ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMg
MgOooooo002Kooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0ol00008ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo
00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go410@oooooooo
oooooooooa0@401gooooo`00Voooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool0
0ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo00GoIVIVohN7QoooooooV9RH
oeEEE@05ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1eooooo`00Voooool01oo^k^ko0000
ooooool0003oooooofIVI_n7QhL02_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMg
oc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`000?oooooo
oooo01;ooooo00Go0000ohN7QoooooooZJVYo`000009ooooo`05o`000?ooooooooooooooool00000
Moooool009_ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`08ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`07ooooo`05oa0@4?ooooooooooooooool@4100Moooool009kooooo00?oIVIVohN7
Qoooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`1gooooo`00W_ooool00onYZJWoA4A4ooooo`0;ooooo`;o00006_ooool2o`00
02;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1gooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.115432, 0.0207698, \
0.00372262, 0.00372262}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.01787 .30422 -36 -2.77537 ]
[.01787 .30422 0 6.22463 ]
[.00698 .37251 -6 -2.83328 ]
[.00698 .37251 0 6.16672 ]
[-0.00441 .44387 -30 -2.89407 ]
[-0.00441 .44387 0 6.10593 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03013 .29952 m
.03625 .29717 L
s
[(-0.005)] .01787 .30422 1 -0.38325 Mshowa
.01928 .36795 m
.02543 .36568 L
s
[(0)] .00698 .37251 1 -0.37038 Mshowa
.00795 .43946 m
.01413 .43725 L
s
[(0.005)] -0.00441 .44387 1 -0.35687 Mshowa
.125 Mabswid
.028 .31297 m
.03167 .31157 L
s
.02585 .32654 m
.02953 .32515 L
s
.02368 .34022 m
.02736 .33884 L
s
.02149 .35403 m
.02518 .35265 L
s
.01706 .382 m
.02075 .38064 L
s
.01481 .39618 m
.01851 .39483 L
s
.01254 .41047 m
.01624 .40913 L
s
.01026 .4249 m
.01396 .42357 L
s
.03224 .28618 m
.03591 .28477 L
s
.03434 .27296 m
.03801 .27154 L
s
.03641 .25985 m
.04008 .25842 L
s
.00562 .45414 m
.00933 .45283 L
s
.00328 .46896 m
.00699 .46766 L
s
.00091 .48392 m
.00462 .48262 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.656 .751 .92 r
.39528 .69613 .4017 .70174 .41244 .69871 .40605 .69308 Metetra
.656 .751 .92 r
.40605 .69308 .41244 .69871 .42323 .69567 .41687 .69002 Metetra
.656 .751 .92 r
.41687 .69002 .42323 .69567 .43406 .69261 .42773 .68694 Metetra
.656 .751 .92 r
.42773 .68694 .43406 .69261 .44494 .68954 .43863 .68385 Metetra
.656 .751 .92 r
.43863 .68385 .44494 .68954 .45586 .68647 .44958 .68075 Metetra
.656 .751 .92 r
.44958 .68075 .45586 .68647 .46682 .68337 .46057 .67763 Metetra
.656 .751 .92 r
.46057 .67763 .46682 .68337 .47783 .68027 .47161 .67451 Metetra
.656 .751 .92 r
.47161 .67451 .47783 .68027 .48889 .67715 .48269 .67137 Metetra
.656 .751 .92 r
.48269 .67137 .48889 .67715 .49998 .67402 .49382 .66821 Metetra
.656 .751 .92 r
.49382 .66821 .49998 .67402 .51113 .67088 .50499 .66505 Metetra
.656 .751 .92 r
.50499 .66505 .51113 .67088 .52232 .66773 .51621 .66187 Metetra
.656 .751 .92 r
.51621 .66187 .52232 .66773 .53355 .66456 .52747 .65868 Metetra
.656 .751 .92 r
.52747 .65868 .53355 .66456 .54483 .66138 .53878 .65547 Metetra
.656 .751 .92 r
.53878 .65547 .54483 .66138 .55616 .65819 .55014 .65226 Metetra
.656 .751 .92 r
.55014 .65226 .55616 .65819 .56753 .65498 .56154 .64902 Metetra
.656 .751 .92 r
.56154 .64902 .56753 .65498 .57895 .65176 .573 .64578 Metetra
.656 .751 .92 r
.573 .64578 .57895 .65176 .59042 .64853 .5845 .64252 Metetra
.656 .751 .92 r
.5845 .64252 .59042 .64853 .60193 .64528 .59604 .63925 Metetra
.656 .751 .92 r
.59604 .63925 .60193 .64528 .6135 .64202 .60764 .63596 Metetra
.656 .751 .92 r
.60764 .63596 .6135 .64202 .62511 .63875 .61928 .63267 Metetra
.656 .751 .92 r
.61928 .63267 .62511 .63875 .63677 .63546 .63097 .62935 Metetra
.656 .751 .92 r
.63097 .62935 .63677 .63546 .64847 .63216 .64271 .62603 Metetra
.656 .751 .92 r
.64271 .62603 .64847 .63216 .66023 .62884 .6545 .62269 Metetra
.656 .751 .92 r
.6545 .62269 .66023 .62884 .67204 .62551 .66634 .61933 Metetra
.656 .751 .92 r
.66634 .61933 .67204 .62551 .68389 .62217 .67823 .61596 Metetra
.656 .751 .92 r
.67823 .61596 .68389 .62217 .6958 .61881 .69017 .61258 Metetra
.656 .751 .92 r
.69017 .61258 .6958 .61881 .70775 .61544 .70216 .60918 Metetra
.656 .751 .92 r
.70216 .60918 .70775 .61544 .71976 .61206 .7142 .60577 Metetra
.656 .751 .92 r
.7142 .60577 .71976 .61206 .73181 .60866 .72629 .60234 Metetra
.656 .751 .92 r
.72629 .60234 .73181 .60866 .74392 .60524 .73844 .5989 Metetra
.656 .751 .92 r
.73844 .5989 .74392 .60524 .75608 .60182 .75063 .59545 Metetra
.656 .751 .92 r
.75063 .59545 .75608 .60182 .76829 .59837 .76288 .59198 Metetra
.656 .751 .92 r
.76288 .59198 .76829 .59837 .78056 .59491 .77518 .58849 Metetra
.656 .751 .92 r
.77518 .58849 .78056 .59491 .79287 .59144 .78754 .58499 Metetra
.656 .751 .92 r
.78754 .58499 .79287 .59144 .80524 .58795 .79994 .58148 Metetra
.656 .751 .92 r
.79994 .58148 .80524 .58795 .81766 .58445 .8124 .57795 Metetra
.656 .751 .92 r
.8124 .57795 .81766 .58445 .83014 .58093 .82492 .5744 Metetra
.656 .751 .92 r
.82492 .5744 .83014 .58093 .84267 .5774 .83748 .57084 Metetra
.656 .751 .92 r
.83748 .57084 .84267 .5774 .85525 .57385 .85011 .56726 Metetra
.656 .751 .92 r
.85011 .56726 .85525 .57385 .86789 .57029 .86278 .56367 Metetra
.656 .751 .92 r
.86278 .56367 .86789 .57029 .88058 .56671 .87552 .56006 Metetra
.656 .751 .92 r
.87552 .56006 .88058 .56671 .89333 .56312 .88831 .55644 Metetra
.656 .751 .92 r
.88831 .55644 .89333 .56312 .90613 .55951 .90115 .5528 Metetra
.656 .751 .92 r
.90115 .5528 .90613 .55951 .91899 .55588 .91405 .54915 Metetra
.656 .751 .92 r
.91405 .54915 .91899 .55588 .93191 .55224 .92701 .54547 Metetra
.656 .751 .92 r
.92701 .54547 .93191 .55224 .94488 .54858 .94002 .54179 Metetra
.656 .751 .92 r
.94002 .54179 .94488 .54858 .95791 .54491 .9531 .53808 Metetra
.656 .751 .92 r
.9531 .53808 .95791 .54491 .971 .54122 .96623 .53436 Metetra
.656 .751 .92 r
.96623 .53436 .971 .54122 .98415 .53751 .97942 .53063 Metetra
.656 .751 .92 r
.38881 .69049 .39528 .69613 .40605 .69308 .39961 .68741 Metetra
.656 .751 .92 r
.39961 .68741 .40605 .69308 .41687 .69002 .41045 .68433 Metetra
.656 .751 .92 r
.41045 .68433 .41687 .69002 .42773 .68694 .42134 .68123 Metetra
.656 .751 .92 r
.42134 .68123 .42773 .68694 .43863 .68385 .43227 .67811 Metetra
.656 .751 .92 r
.43227 .67811 .43863 .68385 .44958 .68075 .44325 .67499 Metetra
.656 .751 .92 r
.44325 .67499 .44958 .68075 .46057 .67763 .45427 .67185 Metetra
.656 .751 .92 r
.45427 .67185 .46057 .67763 .47161 .67451 .46534 .6687 Metetra
.656 .751 .92 r
.46534 .6687 .47161 .67451 .48269 .67137 .47645 .66554 Metetra
.656 .751 .92 r
.47645 .66554 .48269 .67137 .49382 .66821 .4876 .66236 Metetra
.656 .751 .92 r
.4876 .66236 .49382 .66821 .50499 .66505 .4988 .65917 Metetra
.656 .751 .92 r
.4988 .65917 .50499 .66505 .51621 .66187 .51005 .65597 Metetra
.656 .751 .92 r
.51005 .65597 .51621 .66187 .52747 .65868 .52135 .65275 Metetra
.656 .751 .92 r
.52135 .65275 .52747 .65868 .53878 .65547 .53269 .64952 Metetra
.656 .751 .92 r
.53269 .64952 .53878 .65547 .55014 .65226 .54408 .64628 Metetra
.656 .751 .92 r
.54408 .64628 .55014 .65226 .56154 .64902 .55551 .64302 Metetra
.656 .751 .92 r
.55551 .64302 .56154 .64902 .573 .64578 .567 .63975 Metetra
.656 .751 .92 r
.567 .63975 .573 .64578 .5845 .64252 .57853 .63647 Metetra
.656 .751 .92 r
.57853 .63647 .5845 .64252 .59604 .63925 .5901 .63317 Metetra
.656 .751 .92 r
.5901 .63317 .59604 .63925 .60764 .63596 .60173 .62986 Metetra
.656 .751 .92 r
.60173 .62986 .60764 .63596 .61928 .63267 .61341 .62654 Metetra
.656 .751 .92 r
.61341 .62654 .61928 .63267 .63097 .62935 .62513 .6232 Metetra
.656 .751 .92 r
.62513 .6232 .63097 .62935 .64271 .62603 .63691 .61985 Metetra
.656 .751 .92 r
.63691 .61985 .64271 .62603 .6545 .62269 .64873 .61648 Metetra
.656 .751 .92 r
.64873 .61648 .6545 .62269 .66634 .61933 .6606 .6131 Metetra
.656 .751 .92 r
.6606 .6131 .66634 .61933 .67823 .61596 .67253 .60971 Metetra
.656 .751 .92 r
.67253 .60971 .67823 .61596 .69017 .61258 .6845 .6063 Metetra
.656 .751 .92 r
.6845 .6063 .69017 .61258 .70216 .60918 .69653 .60287 Metetra
.656 .751 .92 r
.69653 .60287 .70216 .60918 .7142 .60577 .7086 .59943 Metetra
.656 .751 .92 r
.7086 .59943 .7142 .60577 .72629 .60234 .72073 .59598 Metetra
.656 .751 .92 r
.72073 .59598 .72629 .60234 .73844 .5989 .73291 .59251 Metetra
.656 .751 .92 r
.73291 .59251 .73844 .5989 .75063 .59545 .74514 .58903 Metetra
.656 .751 .92 r
.74514 .58903 .75063 .59545 .76288 .59198 .75743 .58553 Metetra
.656 .751 .92 r
.75743 .58553 .76288 .59198 .77518 .58849 .76977 .58202 Metetra
.656 .751 .92 r
.76977 .58202 .77518 .58849 .78754 .58499 .78216 .57849 Metetra
.656 .751 .92 r
.78216 .57849 .78754 .58499 .79994 .58148 .7946 .57495 Metetra
.656 .751 .92 r
.7946 .57495 .79994 .58148 .8124 .57795 .8071 .57139 Metetra
.656 .751 .92 r
.8071 .57139 .8124 .57795 .82492 .5744 .81965 .56781 Metetra
.656 .751 .92 r
.81965 .56781 .82492 .5744 .83748 .57084 .83226 .56423 Metetra
.656 .751 .92 r
.83226 .56423 .83748 .57084 .85011 .56726 .84492 .56062 Metetra
.656 .751 .92 r
.84492 .56062 .85011 .56726 .86278 .56367 .85764 .557 Metetra
.656 .751 .92 r
.85764 .557 .86278 .56367 .87552 .56006 .87041 .55336 Metetra
.656 .751 .92 r
.87041 .55336 .87552 .56006 .88831 .55644 .88324 .54971 Metetra
.656 .751 .92 r
.88324 .54971 .88831 .55644 .90115 .5528 .89613 .54604 Metetra
.656 .751 .92 r
.89613 .54604 .90115 .5528 .91405 .54915 .90907 .54235 Metetra
.656 .751 .92 r
.90907 .54235 .91405 .54915 .92701 .54547 .92207 .53865 Metetra
.656 .751 .92 r
.92207 .53865 .92701 .54547 .94002 .54179 .93512 .53494 Metetra
.656 .751 .92 r
.93512 .53494 .94002 .54179 .9531 .53808 .94824 .5312 Metetra
.656 .751 .92 r
.94824 .5312 .9531 .53808 .96623 .53436 .96141 .52745 Metetra
.656 .751 .92 r
.96141 .52745 .96623 .53436 .97942 .53063 .97465 .52368 Metetra
.656 .751 .92 r
.38229 .6848 .38881 .69049 .39961 .68741 .39312 .6817 Metetra
.656 .751 .92 r
.39312 .6817 .39961 .68741 .41045 .68433 .40399 .67859 Metetra
.656 .751 .92 r
.40399 .67859 .41045 .68433 .42134 .68123 .41491 .67547 Metetra
.656 .751 .92 r
.41491 .67547 .42134 .68123 .43227 .67811 .42587 .67233 Metetra
.656 .751 .92 r
.42587 .67233 .43227 .67811 .44325 .67499 .43687 .66919 Metetra
.656 .751 .92 r
.43687 .66919 .44325 .67499 .45427 .67185 .44792 .66602 Metetra
.656 .751 .92 r
.44792 .66602 .45427 .67185 .46534 .6687 .45902 .66285 Metetra
.656 .751 .92 r
.45902 .66285 .46534 .6687 .47645 .66554 .47016 .65966 Metetra
.656 .751 .92 r
.47016 .65966 .47645 .66554 .4876 .66236 .48134 .65646 Metetra
.656 .751 .92 r
.48134 .65646 .4876 .66236 .4988 .65917 .49257 .65325 Metetra
.656 .751 .92 r
.49257 .65325 .4988 .65917 .51005 .65597 .50385 .65002 Metetra
.656 .751 .92 r
.50385 .65002 .51005 .65597 .52135 .65275 .51518 .64678 Metetra
.656 .751 .92 r
.51518 .64678 .52135 .65275 .53269 .64952 .52655 .64353 Metetra
.656 .751 .92 r
.52655 .64353 .53269 .64952 .54408 .64628 .53797 .64026 Metetra
.656 .751 .92 r
.53797 .64026 .54408 .64628 .55551 .64302 .54943 .63698 Metetra
.656 .751 .92 r
.54943 .63698 .55551 .64302 .567 .63975 .56095 .63368 Metetra
.656 .751 .92 r
.56095 .63368 .567 .63975 .57853 .63647 .57251 .63037 Metetra
.656 .751 .92 r
.57251 .63037 .57853 .63647 .5901 .63317 .58412 .62705 Metetra
.656 .751 .92 r
.58412 .62705 .5901 .63317 .60173 .62986 .59578 .62372 Metetra
.656 .751 .92 r
.59578 .62372 .60173 .62986 .61341 .62654 .60749 .62036 Metetra
.656 .751 .92 r
.60749 .62036 .61341 .62654 .62513 .6232 .61925 .617 Metetra
.656 .751 .92 r
.61925 .617 .62513 .6232 .63691 .61985 .63105 .61362 Metetra
.656 .751 .92 r
.63105 .61362 .63691 .61985 .64873 .61648 .64291 .61023 Metetra
.656 .751 .92 r
.64291 .61023 .64873 .61648 .6606 .6131 .65482 .60682 Metetra
.656 .751 .92 r
.65482 .60682 .6606 .6131 .67253 .60971 .66678 .6034 Metetra
.656 .751 .92 r
.66678 .6034 .67253 .60971 .6845 .6063 .67879 .59996 Metetra
.656 .751 .92 r
.67879 .59996 .6845 .6063 .69653 .60287 .69085 .59651 Metetra
.656 .751 .92 r
.69085 .59651 .69653 .60287 .7086 .59943 .70296 .59305 Metetra
.656 .751 .92 r
.70296 .59305 .7086 .59943 .72073 .59598 .71512 .58957 Metetra
.656 .751 .92 r
.71512 .58957 .72073 .59598 .73291 .59251 .72734 .58607 Metetra
.656 .751 .92 r
.72734 .58607 .73291 .59251 .74514 .58903 .73961 .58256 Metetra
.656 .751 .92 r
.73961 .58256 .74514 .58903 .75743 .58553 .75193 .57903 Metetra
.656 .751 .92 r
.75193 .57903 .75743 .58553 .76977 .58202 .7643 .57549 Metetra
.656 .751 .92 r
.7643 .57549 .76977 .58202 .78216 .57849 .77673 .57194 Metetra
.656 .751 .92 r
.77673 .57194 .78216 .57849 .7946 .57495 .78922 .56837 Metetra
.656 .751 .92 r
.78922 .56837 .7946 .57495 .8071 .57139 .80175 .56478 Metetra
.656 .751 .92 r
.80175 .56478 .8071 .57139 .81965 .56781 .81434 .56118 Metetra
.656 .751 .92 r
.81434 .56118 .81965 .56781 .83226 .56423 .82699 .55756 Metetra
.656 .751 .92 r
.82699 .55756 .83226 .56423 .84492 .56062 .83969 .55392 Metetra
.656 .751 .92 r
.83969 .55392 .84492 .56062 .85764 .557 .85245 .55027 Metetra
.656 .751 .92 r
.85245 .55027 .85764 .557 .87041 .55336 .86526 .54661 Metetra
.656 .751 .92 r
.86526 .54661 .87041 .55336 .88324 .54971 .87813 .54292 Metetra
.656 .751 .92 r
.87813 .54292 .88324 .54971 .89613 .54604 .89106 .53922 Metetra
.656 .751 .92 r
.89106 .53922 .89613 .54604 .90907 .54235 .90404 .53551 Metetra
.656 .751 .92 r
.90404 .53551 .90907 .54235 .92207 .53865 .91709 .53178 Metetra
.656 .751 .92 r
.91709 .53178 .92207 .53865 .93512 .53494 .93019 .52803 Metetra
.656 .751 .92 r
.93019 .52803 .93512 .53494 .94824 .5312 .94334 .52426 Metetra
.656 .751 .92 r
.94334 .52426 .94824 .5312 .96141 .52745 .95656 .52048 Metetra
.656 .751 .92 r
.95656 .52048 .96141 .52745 .97465 .52368 .96984 .51668 Metetra
.656 .751 .92 r
.37573 .67907 .38229 .6848 .39312 .6817 .38658 .67595 Metetra
.656 .751 .92 r
.38658 .67595 .39312 .6817 .40399 .67859 .39748 .67282 Metetra
.656 .751 .92 r
.39748 .67282 .40399 .67859 .41491 .67547 .40843 .66967 Metetra
.656 .751 .92 r
.40843 .66967 .41491 .67547 .42587 .67233 .41941 .66651 Metetra
.656 .751 .92 r
.41941 .66651 .42587 .67233 .43687 .66919 .43045 .66334 Metetra
.656 .751 .92 r
.43045 .66334 .43687 .66919 .44792 .66602 .44152 .66015 Metetra
.656 .751 .92 r
.44152 .66015 .44792 .66602 .45902 .66285 .45265 .65695 Metetra
.656 .751 .92 r
.45265 .65695 .45902 .66285 .47016 .65966 .46382 .65374 Metetra
.656 .751 .92 r
.46382 .65374 .47016 .65966 .48134 .65646 .47503 .65052 Metetra
.656 .751 .92 r
.47503 .65052 .48134 .65646 .49257 .65325 .48629 .64728 Metetra
.656 .751 .92 r
.48629 .64728 .49257 .65325 .50385 .65002 .4976 .64403 Metetra
.656 .751 .92 r
.4976 .64403 .50385 .65002 .51518 .64678 .50896 .64076 Metetra
.656 .751 .92 r
.50896 .64076 .51518 .64678 .52655 .64353 .52036 .63748 Metetra
.656 .751 .92 r
.52036 .63748 .52655 .64353 .53797 .64026 .53181 .63419 Metetra
.656 .751 .92 r
.53181 .63419 .53797 .64026 .54943 .63698 .54331 .63088 Metetra
.656 .751 .92 r
.54331 .63088 .54943 .63698 .56095 .63368 .55485 .62756 Metetra
.656 .751 .92 r
.55485 .62756 .56095 .63368 .57251 .63037 .56645 .62423 Metetra
.656 .751 .92 r
.56645 .62423 .57251 .63037 .58412 .62705 .57809 .62088 Metetra
.656 .751 .92 r
.57809 .62088 .58412 .62705 .59578 .62372 .58978 .61752 Metetra
.656 .751 .92 r
.58978 .61752 .59578 .62372 .60749 .62036 .60153 .61414 Metetra
.656 .751 .92 r
.60153 .61414 .60749 .62036 .61925 .617 .61332 .61075 Metetra
.656 .751 .92 r
.61332 .61075 .61925 .617 .63105 .61362 .62516 .60735 Metetra
.656 .751 .92 r
.62516 .60735 .63105 .61362 .64291 .61023 .63705 .60393 Metetra
.656 .751 .92 r
.63705 .60393 .64291 .61023 .65482 .60682 .64899 .60049 Metetra
.656 .751 .92 r
.64899 .60049 .65482 .60682 .66678 .6034 .66098 .59704 Metetra
.656 .751 .92 r
.66098 .59704 .66678 .6034 .67879 .59996 .67303 .59358 Metetra
.656 .751 .92 r
.67303 .59358 .67879 .59996 .69085 .59651 .68512 .5901 Metetra
.656 .751 .92 r
.68512 .5901 .69085 .59651 .70296 .59305 .69727 .58661 Metetra
.656 .751 .92 r
.69727 .58661 .70296 .59305 .71512 .58957 .70947 .5831 Metetra
.656 .751 .92 r
.70947 .5831 .71512 .58957 .72734 .58607 .72172 .57958 Metetra
.656 .751 .92 r
.72172 .57958 .72734 .58607 .73961 .58256 .73403 .57604 Metetra
.656 .751 .92 r
.73403 .57604 .73961 .58256 .75193 .57903 .74639 .57249 Metetra
.656 .751 .92 r
.74639 .57249 .75193 .57903 .7643 .57549 .7588 .56892 Metetra
.656 .751 .92 r
.7588 .56892 .7643 .57549 .77673 .57194 .77127 .56533 Metetra
.656 .751 .92 r
.77127 .56533 .77673 .57194 .78922 .56837 .78379 .56173 Metetra
.656 .751 .92 r
.78379 .56173 .78922 .56837 .80175 .56478 .79636 .55811 Metetra
.656 .751 .92 r
.79636 .55811 .80175 .56478 .81434 .56118 .80899 .55448 Metetra
.656 .751 .92 r
.80899 .55448 .81434 .56118 .82699 .55756 .82168 .55083 Metetra
.656 .751 .92 r
.82168 .55083 .82699 .55756 .83969 .55392 .83442 .54717 Metetra
.656 .751 .92 r
.83442 .54717 .83969 .55392 .85245 .55027 .84722 .54349 Metetra
.656 .751 .92 r
.84722 .54349 .85245 .55027 .86526 .54661 .86007 .53979 Metetra
.656 .751 .92 r
.86007 .53979 .86526 .54661 .87813 .54292 .87298 .53608 Metetra
.656 .751 .92 r
.87298 .53608 .87813 .54292 .89106 .53922 .88595 .53235 Metetra
.656 .751 .92 r
.88595 .53235 .89106 .53922 .90404 .53551 .89898 .52861 Metetra
.656 .751 .92 r
.89898 .52861 .90404 .53551 .91709 .53178 .91206 .52484 Metetra
.656 .751 .92 r
.91206 .52484 .91709 .53178 .93019 .52803 .9252 .52106 Metetra
.656 .751 .92 r
.9252 .52106 .93019 .52803 .94334 .52426 .93841 .51727 Metetra
.656 .751 .92 r
.93841 .51727 .94334 .52426 .95656 .52048 .95167 .51346 Metetra
.656 .751 .92 r
.95167 .51346 .95656 .52048 .96984 .51668 .96499 .50962 Metetra
.656 .751 .92 r
.36912 .6733 .37573 .67907 .38658 .67595 .38 .67016 Metetra
.656 .751 .92 r
.38 .67016 .38658 .67595 .39748 .67282 .39092 .667 Metetra
.656 .751 .92 r
.39092 .667 .39748 .67282 .40843 .66967 .40189 .66383 Metetra
.656 .751 .92 r
.40189 .66383 .40843 .66967 .41941 .66651 .41291 .66064 Metetra
.656 .751 .92 r
.41291 .66064 .41941 .66651 .43045 .66334 .42397 .65745 Metetra
.656 .751 .92 r
.42397 .65745 .43045 .66334 .44152 .66015 .43508 .65424 Metetra
.656 .751 .92 r
.43508 .65424 .44152 .66015 .45265 .65695 .44623 .65101 Metetra
.656 .751 .92 r
.44623 .65101 .45265 .65695 .46382 .65374 .45743 .64778 Metetra
.656 .751 .92 r
.45743 .64778 .46382 .65374 .47503 .65052 .46868 .64453 Metetra
.656 .751 .92 r
.46868 .64453 .47503 .65052 .48629 .64728 .47997 .64126 Metetra
.656 .751 .92 r
.47997 .64126 .48629 .64728 .4976 .64403 .49131 .63799 Metetra
.656 .751 .92 r
.49131 .63799 .4976 .64403 .50896 .64076 .50269 .6347 Metetra
.656 .751 .92 r
.50269 .6347 .50896 .64076 .52036 .63748 .51412 .63139 Metetra
.656 .751 .92 r
.51412 .63139 .52036 .63748 .53181 .63419 .52561 .62808 Metetra
.656 .751 .92 r
.52561 .62808 .53181 .63419 .54331 .63088 .53714 .62474 Metetra
.656 .751 .92 r
.53714 .62474 .54331 .63088 .55485 .62756 .54871 .6214 Metetra
.656 .751 .92 r
.54871 .6214 .55485 .62756 .56645 .62423 .56034 .61804 Metetra
.656 .751 .92 r
.56034 .61804 .56645 .62423 .57809 .62088 .57202 .61466 Metetra
.656 .751 .92 r
.57202 .61466 .57809 .62088 .58978 .61752 .58374 .61127 Metetra
.656 .751 .92 r
.58374 .61127 .58978 .61752 .60153 .61414 .59551 .60787 Metetra
.656 .751 .92 r
.59551 .60787 .60153 .61414 .61332 .61075 .60734 .60445 Metetra
.656 .751 .92 r
.60734 .60445 .61332 .61075 .62516 .60735 .61921 .60102 Metetra
.656 .751 .92 r
.61921 .60102 .62516 .60735 .63705 .60393 .63114 .59758 Metetra
.656 .751 .92 r
.63114 .59758 .63705 .60393 .64899 .60049 .64312 .59411 Metetra
.656 .751 .92 r
.64312 .59411 .64899 .60049 .66098 .59704 .65514 .59064 Metetra
.656 .751 .92 r
.65514 .59064 .66098 .59704 .67303 .59358 .66722 .58715 Metetra
.656 .751 .92 r
.66722 .58715 .67303 .59358 .68512 .5901 .67935 .58364 Metetra
.656 .751 .92 r
.67935 .58364 .68512 .5901 .69727 .58661 .69154 .58012 Metetra
.656 .751 .92 r
.69154 .58012 .69727 .58661 .70947 .5831 .70377 .57658 Metetra
.656 .751 .92 r
.70377 .57658 .70947 .5831 .72172 .57958 .71606 .57303 Metetra
.656 .751 .92 r
.71606 .57303 .72172 .57958 .73403 .57604 .72841 .56947 Metetra
.656 .751 .92 r
.72841 .56947 .73403 .57604 .74639 .57249 .7408 .56588 Metetra
.656 .751 .92 r
.7408 .56588 .74639 .57249 .7588 .56892 .75325 .56229 Metetra
.656 .751 .92 r
.75325 .56229 .7588 .56892 .77127 .56533 .76576 .55867 Metetra
.656 .751 .92 r
.76576 .55867 .77127 .56533 .78379 .56173 .77832 .55504 Metetra
.656 .751 .92 r
.77832 .55504 .78379 .56173 .79636 .55811 .79093 .5514 Metetra
.656 .751 .92 r
.79093 .5514 .79636 .55811 .80899 .55448 .8036 .54774 Metetra
.656 .751 .92 r
.8036 .54774 .80899 .55448 .82168 .55083 .81633 .54406 Metetra
.656 .751 .92 r
.81633 .54406 .82168 .55083 .83442 .54717 .82911 .54036 Metetra
.656 .751 .92 r
.82911 .54036 .83442 .54717 .84722 .54349 .84195 .53665 Metetra
.656 .751 .92 r
.84195 .53665 .84722 .54349 .86007 .53979 .85484 .53293 Metetra
.656 .751 .92 r
.85484 .53293 .86007 .53979 .87298 .53608 .86779 .52918 Metetra
.656 .751 .92 r
.86779 .52918 .87298 .53608 .88595 .53235 .8808 .52542 Metetra
.656 .751 .92 r
.8808 .52542 .88595 .53235 .89898 .52861 .89387 .52165 Metetra
.656 .751 .92 r
.89387 .52165 .89898 .52861 .91206 .52484 .907 .51785 Metetra
.656 .751 .92 r
.907 .51785 .91206 .52484 .9252 .52106 .92018 .51404 Metetra
.656 .751 .92 r
.92018 .51404 .9252 .52106 .93841 .51727 .93343 .51022 Metetra
.656 .751 .92 r
.93343 .51022 .93841 .51727 .95167 .51346 .94673 .50637 Metetra
.656 .751 .92 r
.94673 .50637 .95167 .51346 .96499 .50962 .9601 .50251 Metetra
.656 .751 .92 r
.36245 .66748 .36912 .6733 .38 .67016 .37336 .66432 Metetra
.656 .751 .92 r
.37336 .66432 .38 .67016 .39092 .667 .38432 .66113 Metetra
.656 .751 .92 r
.38432 .66113 .39092 .667 .40189 .66383 .39531 .65794 Metetra
.656 .751 .92 r
.39531 .65794 .40189 .66383 .41291 .66064 .40636 .65473 Metetra
.656 .751 .92 r
.40636 .65473 .41291 .66064 .42397 .65745 .41745 .65151 Metetra
.656 .751 .92 r
.41745 .65151 .42397 .65745 .43508 .65424 .42858 .64828 Metetra
.656 .751 .92 r
.42858 .64828 .43508 .65424 .44623 .65101 .43977 .64503 Metetra
.656 .751 .92 r
.43977 .64503 .44623 .65101 .45743 .64778 .45099 .64177 Metetra
.656 .751 .92 r
.45099 .64177 .45743 .64778 .46868 .64453 .46227 .63849 Metetra
.656 .751 .92 r
.46227 .63849 .46868 .64453 .47997 .64126 .47359 .6352 Metetra
.656 .751 .92 r
.47359 .6352 .47997 .64126 .49131 .63799 .48496 .6319 Metetra
.656 .751 .92 r
.48496 .6319 .49131 .63799 .50269 .6347 .49638 .62859 Metetra
.656 .751 .92 r
.49638 .62859 .50269 .6347 .51412 .63139 .50784 .62526 Metetra
.656 .751 .92 r
.50784 .62526 .51412 .63139 .52561 .62808 .51935 .62191 Metetra
.656 .751 .92 r
.51935 .62191 .52561 .62808 .53714 .62474 .53091 .61855 Metetra
.656 .751 .92 r
.53091 .61855 .53714 .62474 .54871 .6214 .54252 .61518 Metetra
.656 .751 .92 r
.54252 .61518 .54871 .6214 .56034 .61804 .55418 .6118 Metetra
.656 .751 .92 r
.55418 .6118 .56034 .61804 .57202 .61466 .56589 .6084 Metetra
.656 .751 .92 r
.56589 .6084 .57202 .61466 .58374 .61127 .57765 .60498 Metetra
.656 .751 .92 r
.57765 .60498 .58374 .61127 .59551 .60787 .58946 .60155 Metetra
.656 .751 .92 r
.58946 .60155 .59551 .60787 .60734 .60445 .60131 .59811 Metetra
.656 .751 .92 r
.60131 .59811 .60734 .60445 .61921 .60102 .61322 .59465 Metetra
.656 .751 .92 r
.61322 .59465 .61921 .60102 .63114 .59758 .62518 .59117 Metetra
.656 .751 .92 r
.62518 .59117 .63114 .59758 .64312 .59411 .63719 .58769 Metetra
.656 .751 .92 r
.63719 .58769 .64312 .59411 .65514 .59064 .64926 .58418 Metetra
.656 .751 .92 r
.64926 .58418 .65514 .59064 .66722 .58715 .66137 .58066 Metetra
.656 .751 .92 r
.66137 .58066 .66722 .58715 .67935 .58364 .67354 .57713 Metetra
.656 .751 .92 r
.67354 .57713 .67935 .58364 .69154 .58012 .68576 .57358 Metetra
.656 .751 .92 r
.68576 .57358 .69154 .58012 .70377 .57658 .69803 .57002 Metetra
.656 .751 .92 r
.69803 .57002 .70377 .57658 .71606 .57303 .71036 .56644 Metetra
.656 .751 .92 r
.71036 .56644 .71606 .57303 .72841 .56947 .72274 .56284 Metetra
.656 .751 .92 r
.72274 .56284 .72841 .56947 .7408 .56588 .73517 .55923 Metetra
.656 .751 .92 r
.73517 .55923 .7408 .56588 .75325 .56229 .74766 .5556 Metetra
.656 .751 .92 r
.74766 .5556 .75325 .56229 .76576 .55867 .7602 .55196 Metetra
.656 .751 .92 r
.7602 .55196 .76576 .55867 .77832 .55504 .7728 .5483 Metetra
.656 .751 .92 r
.7728 .5483 .77832 .55504 .79093 .5514 .78545 .54462 Metetra
.656 .751 .92 r
.78545 .54462 .79093 .5514 .8036 .54774 .79816 .54093 Metetra
.656 .751 .92 r
.79816 .54093 .8036 .54774 .81633 .54406 .81093 .53723 Metetra
.656 .751 .92 r
.81093 .53723 .81633 .54406 .82911 .54036 .82375 .5335 Metetra
.656 .751 .92 r
.82375 .5335 .82911 .54036 .84195 .53665 .83663 .52976 Metetra
.656 .751 .92 r
.83663 .52976 .84195 .53665 .85484 .53293 .84957 .526 Metetra
.656 .751 .92 r
.84957 .526 .85484 .53293 .86779 .52918 .86256 .52223 Metetra
.656 .751 .92 r
.86256 .52223 .86779 .52918 .8808 .52542 .87561 .51844 Metetra
.656 .751 .92 r
.87561 .51844 .8808 .52542 .89387 .52165 .88872 .51463 Metetra
.656 .751 .92 r
.88872 .51463 .89387 .52165 .907 .51785 .90189 .51081 Metetra
.656 .751 .92 r
.90189 .51081 .907 .51785 .92018 .51404 .91512 .50696 Metetra
.656 .751 .92 r
.91512 .50696 .92018 .51404 .93343 .51022 .92841 .5031 Metetra
.656 .751 .92 r
.92841 .5031 .93343 .51022 .94673 .50637 .94176 .49923 Metetra
.656 .751 .92 r
.94176 .49923 .94673 .50637 .9601 .50251 .95517 .49533 Metetra
.656 .751 .92 r
.35574 .66162 .36245 .66748 .37336 .66432 .36668 .65843 Metetra
.656 .751 .92 r
.36668 .65843 .37336 .66432 .38432 .66113 .37766 .65523 Metetra
.656 .751 .92 r
.37766 .65523 .38432 .66113 .39531 .65794 .38868 .65201 Metetra
.656 .751 .92 r
.38868 .65201 .39531 .65794 .40636 .65473 .39976 .64877 Metetra
.656 .751 .92 r
.39976 .64877 .40636 .65473 .41745 .65151 .41088 .64553 Metetra
.656 .751 .92 r
.41088 .64553 .41745 .65151 .42858 .64828 .42204 .64227 Metetra
.656 .751 .92 r
.42204 .64227 .42858 .64828 .43977 .64503 .43325 .639 Metetra
.656 .751 .92 r
.43325 .639 .43977 .64503 .45099 .64177 .44451 .63571 Metetra
.656 .751 .92 r
.44451 .63571 .45099 .64177 .46227 .63849 .45581 .63241 Metetra
.656 .751 .92 r
.45581 .63241 .46227 .63849 .47359 .6352 .46717 .6291 Metetra
.656 .751 .92 r
.46717 .6291 .47359 .6352 .48496 .6319 .47857 .62577 Metetra
.656 .751 .92 r
.47857 .62577 .48496 .6319 .49638 .62859 .49001 .62243 Metetra
.656 .751 .92 r
.49001 .62243 .49638 .62859 .50784 .62526 .50151 .61907 Metetra
.656 .751 .92 r
.50151 .61907 .50784 .62526 .51935 .62191 .51305 .6157 Metetra
.656 .751 .92 r
.51305 .6157 .51935 .62191 .53091 .61855 .52464 .61232 Metetra
.656 .751 .92 r
.52464 .61232 .53091 .61855 .54252 .61518 .53629 .60892 Metetra
.656 .751 .92 r
.53629 .60892 .54252 .61518 .55418 .6118 .54798 .60551 Metetra
.656 .751 .92 r
.54798 .60551 .55418 .6118 .56589 .6084 .55972 .60208 Metetra
.656 .751 .92 r
.55972 .60208 .56589 .6084 .57765 .60498 .57151 .59864 Metetra
.656 .751 .92 r
.57151 .59864 .57765 .60498 .58946 .60155 .58335 .59518 Metetra
.656 .751 .92 r
.58335 .59518 .58946 .60155 .60131 .59811 .59524 .59171 Metetra
.656 .751 .92 r
.59524 .59171 .60131 .59811 .61322 .59465 .60719 .58822 Metetra
.656 .751 .92 r
.60719 .58822 .61322 .59465 .62518 .59117 .61918 .58472 Metetra
.656 .751 .92 r
.61918 .58472 .62518 .59117 .63719 .58769 .63123 .58121 Metetra
.656 .751 .92 r
.63123 .58121 .63719 .58769 .64926 .58418 .64332 .57767 Metetra
.656 .751 .92 r
.64332 .57767 .64926 .58418 .66137 .58066 .65547 .57413 Metetra
.656 .751 .92 r
.65547 .57413 .66137 .58066 .67354 .57713 .66768 .57057 Metetra
.656 .751 .92 r
.66768 .57057 .67354 .57713 .68576 .57358 .67993 .56699 Metetra
.656 .751 .92 r
.67993 .56699 .68576 .57358 .69803 .57002 .69224 .56339 Metetra
.656 .751 .92 r
.69224 .56339 .69803 .57002 .71036 .56644 .70461 .55979 Metetra
.656 .751 .92 r
.70461 .55979 .71036 .56644 .72274 .56284 .71702 .55616 Metetra
.656 .751 .92 r
.71702 .55616 .72274 .56284 .73517 .55923 .72949 .55252 Metetra
.656 .751 .92 r
.72949 .55252 .73517 .55923 .74766 .5556 .74202 .54886 Metetra
.656 .751 .92 r
.74202 .54886 .74766 .5556 .7602 .55196 .7546 .54519 Metetra
.656 .751 .92 r
.7546 .54519 .7602 .55196 .7728 .5483 .76724 .5415 Metetra
.656 .751 .92 r
.76724 .5415 .7728 .5483 .78545 .54462 .77993 .5378 Metetra
.656 .751 .92 r
.77993 .5378 .78545 .54462 .79816 .54093 .79268 .53408 Metetra
.656 .751 .92 r
.79268 .53408 .79816 .54093 .81093 .53723 .80549 .53034 Metetra
.656 .751 .92 r
.80549 .53034 .81093 .53723 .82375 .5335 .81835 .52658 Metetra
.656 .751 .92 r
.81835 .52658 .82375 .5335 .83663 .52976 .83127 .52281 Metetra
.656 .751 .92 r
.83127 .52281 .83663 .52976 .84957 .526 .84425 .51902 Metetra
.656 .751 .92 r
.84425 .51902 .84957 .526 .86256 .52223 .85728 .51522 Metetra
.656 .751 .92 r
.85728 .51522 .86256 .52223 .87561 .51844 .87038 .51139 Metetra
.656 .751 .92 r
.87038 .51139 .87561 .51844 .88872 .51463 .88353 .50756 Metetra
.656 .751 .92 r
.88353 .50756 .88872 .51463 .90189 .51081 .89674 .5037 Metetra
.656 .751 .92 r
.89674 .5037 .90189 .51081 .91512 .50696 .91001 .49982 Metetra
.656 .751 .92 r
.91001 .49982 .91512 .50696 .92841 .5031 .92335 .49593 Metetra
.656 .751 .92 r
.92335 .49593 .92841 .5031 .94176 .49923 .93674 .49202 Metetra
.656 .751 .92 r
.93674 .49202 .94176 .49923 .95517 .49533 .95019 .48809 Metetra
.656 .751 .92 r
.34897 .65572 .35574 .66162 .36668 .65843 .35994 .6525 Metetra
.656 .751 .92 r
.35994 .6525 .36668 .65843 .37766 .65523 .37095 .64927 Metetra
.656 .751 .92 r
.37095 .64927 .37766 .65523 .38868 .65201 .382 .64603 Metetra
.656 .751 .92 r
.382 .64603 .38868 .65201 .39976 .64877 .3931 .64277 Metetra
.656 .751 .92 r
.3931 .64277 .39976 .64877 .41088 .64553 .40425 .6395 Metetra
.656 .751 .92 r
.40425 .6395 .41088 .64553 .42204 .64227 .41545 .63622 Metetra
.656 .751 .92 r
.41545 .63622 .42204 .64227 .43325 .639 .42669 .63292 Metetra
.656 .751 .92 r
.42669 .63292 .43325 .639 .44451 .63571 .43797 .62961 Metetra
.656 .751 .92 r
.43797 .62961 .44451 .63571 .45581 .63241 .44931 .62628 Metetra
.656 .751 .92 r
.44931 .62628 .45581 .63241 .46717 .6291 .46069 .62294 Metetra
.656 .751 .92 r
.46069 .62294 .46717 .6291 .47857 .62577 .47212 .61959 Metetra
.656 .751 .92 r
.47212 .61959 .47857 .62577 .49001 .62243 .4836 .61622 Metetra
.656 .751 .92 r
.4836 .61622 .49001 .62243 .50151 .61907 .49513 .61284 Metetra
.656 .751 .92 r
.49513 .61284 .50151 .61907 .51305 .6157 .5067 .60944 Metetra
.656 .751 .92 r
.5067 .60944 .51305 .6157 .52464 .61232 .51833 .60603 Metetra
.656 .751 .92 r
.51833 .60603 .52464 .61232 .53629 .60892 .53 .60261 Metetra
.656 .751 .92 r
.53 .60261 .53629 .60892 .54798 .60551 .54172 .59917 Metetra
.656 .751 .92 r
.54172 .59917 .54798 .60551 .55972 .60208 .5535 .59571 Metetra
.656 .751 .92 r
.5535 .59571 .55972 .60208 .57151 .59864 .56532 .59224 Metetra
.656 .751 .92 r
.56532 .59224 .57151 .59864 .58335 .59518 .5772 .58876 Metetra
.656 .751 .92 r
.5772 .58876 .58335 .59518 .59524 .59171 .58912 .58526 Metetra
.656 .751 .92 r
.58912 .58526 .59524 .59171 .60719 .58822 .6011 .58175 Metetra
.656 .751 .92 r
.6011 .58175 .60719 .58822 .61918 .58472 .61313 .57822 Metetra
.656 .751 .92 r
.61313 .57822 .61918 .58472 .63123 .58121 .62521 .57467 Metetra
.656 .751 .92 r
.62521 .57467 .63123 .58121 .64332 .57767 .63734 .57111 Metetra
.656 .751 .92 r
.63734 .57111 .64332 .57767 .65547 .57413 .64953 .56754 Metetra
.656 .751 .92 r
.64953 .56754 .65547 .57413 .66768 .57057 .66177 .56395 Metetra
.656 .751 .92 r
.66177 .56395 .66768 .57057 .67993 .56699 .67406 .56034 Metetra
.656 .751 .92 r
.67406 .56034 .67993 .56699 .69224 .56339 .68641 .55672 Metetra
.656 .751 .92 r
.68641 .55672 .69224 .56339 .70461 .55979 .69881 .55308 Metetra
.656 .751 .92 r
.69881 .55308 .70461 .55979 .71702 .55616 .71126 .54943 Metetra
.656 .751 .92 r
.71126 .54943 .71702 .55616 .72949 .55252 .72377 .54576 Metetra
.656 .751 .92 r
.72377 .54576 .72949 .55252 .74202 .54886 .73634 .54207 Metetra
.656 .751 .92 r
.73634 .54207 .74202 .54886 .7546 .54519 .74896 .53837 Metetra
.656 .751 .92 r
.74896 .53837 .7546 .54519 .76724 .5415 .76163 .53465 Metetra
.656 .751 .92 r
.76163 .53465 .76724 .5415 .77993 .5378 .77436 .53091 Metetra
.656 .751 .92 r
.77436 .53091 .77993 .5378 .79268 .53408 .78715 .52716 Metetra
.656 .751 .92 r
.78715 .52716 .79268 .53408 .80549 .53034 .8 .52339 Metetra
.656 .751 .92 r
.8 .52339 .80549 .53034 .81835 .52658 .8129 .51961 Metetra
.656 .751 .92 r
.8129 .51961 .81835 .52658 .83127 .52281 .82586 .5158 Metetra
.656 .751 .92 r
.82586 .5158 .83127 .52281 .84425 .51902 .83888 .51198 Metetra
.656 .751 .92 r
.83888 .51198 .84425 .51902 .85728 .51522 .85196 .50815 Metetra
.656 .751 .92 r
.85196 .50815 .85728 .51522 .87038 .51139 .8651 .50429 Metetra
.656 .751 .92 r
.8651 .50429 .87038 .51139 .88353 .50756 .87829 .50042 Metetra
.656 .751 .92 r
.87829 .50042 .88353 .50756 .89674 .5037 .89155 .49653 Metetra
.656 .751 .92 r
.89155 .49653 .89674 .5037 .91001 .49982 .90487 .49262 Metetra
.656 .751 .92 r
.90487 .49262 .91001 .49982 .92335 .49593 .91824 .4887 Metetra
.656 .751 .92 r
.91824 .4887 .92335 .49593 .93674 .49202 .93168 .48476 Metetra
.656 .751 .92 r
.93168 .48476 .93674 .49202 .95019 .48809 .94518 .4808 Metetra
.656 .751 .92 r
.34216 .64977 .34897 .65572 .35994 .6525 .35315 .64653 Metetra
.656 .751 .92 r
.35315 .64653 .35994 .6525 .37095 .64927 .36419 .64327 Metetra
.656 .751 .92 r
.36419 .64327 .37095 .64927 .382 .64603 .37527 .64001 Metetra
.656 .751 .92 r
.37527 .64001 .382 .64603 .3931 .64277 .3864 .63672 Metetra
.656 .751 .92 r
.3864 .63672 .3931 .64277 .40425 .6395 .39758 .63343 Metetra
.656 .751 .92 r
.39758 .63343 .40425 .6395 .41545 .63622 .4088 .63012 Metetra
.656 .751 .92 r
.4088 .63012 .41545 .63622 .42669 .63292 .42007 .6268 Metetra
.656 .751 .92 r
.42007 .6268 .42669 .63292 .43797 .62961 .43139 .62346 Metetra
.656 .751 .92 r
.43139 .62346 .43797 .62961 .44931 .62628 .44275 .62011 Metetra
.656 .751 .92 r
.44275 .62011 .44931 .62628 .46069 .62294 .45417 .61674 Metetra
.656 .751 .92 r
.45417 .61674 .46069 .62294 .47212 .61959 .46563 .61336 Metetra
.656 .751 .92 r
.46563 .61336 .47212 .61959 .4836 .61622 .47714 .60997 Metetra
.656 .751 .92 r
.47714 .60997 .4836 .61622 .49513 .61284 .48869 .60656 Metetra
.656 .751 .92 r
.48869 .60656 .49513 .61284 .5067 .60944 .5003 .60314 Metetra
.656 .751 .92 r
.5003 .60314 .5067 .60944 .51833 .60603 .51196 .5997 Metetra
.656 .751 .92 r
.51196 .5997 .51833 .60603 .53 .60261 .52366 .59625 Metetra
.656 .751 .92 r
.52366 .59625 .53 .60261 .54172 .59917 .53542 .59278 Metetra
.656 .751 .92 r
.53542 .59278 .54172 .59917 .5535 .59571 .54723 .5893 Metetra
.656 .751 .92 r
.54723 .5893 .5535 .59571 .56532 .59224 .55909 .5858 Metetra
.656 .751 .92 r
.55909 .5858 .56532 .59224 .5772 .58876 .57099 .58229 Metetra
.656 .751 .92 r
.57099 .58229 .5772 .58876 .58912 .58526 .58295 .57876 Metetra
.656 .751 .92 r
.58295 .57876 .58912 .58526 .6011 .58175 .59497 .57522 Metetra
.656 .751 .92 r
.59497 .57522 .6011 .58175 .61313 .57822 .60703 .57166 Metetra
.656 .751 .92 r
.60703 .57166 .61313 .57822 .62521 .57467 .61915 .56809 Metetra
.656 .751 .92 r
.61915 .56809 .62521 .57467 .63734 .57111 .63131 .5645 Metetra
.656 .751 .92 r
.63131 .5645 .63734 .57111 .64953 .56754 .64354 .5609 Metetra
.656 .751 .92 r
.64354 .5609 .64953 .56754 .66177 .56395 .65581 .55728 Metetra
.656 .751 .92 r
.65581 .55728 .66177 .56395 .67406 .56034 .66814 .55364 Metetra
.656 .751 .92 r
.66814 .55364 .67406 .56034 .68641 .55672 .68052 .54999 Metetra
.656 .751 .92 r
.68052 .54999 .68641 .55672 .69881 .55308 .69296 .54632 Metetra
.656 .751 .92 r
.69296 .54632 .69881 .55308 .71126 .54943 .70545 .54264 Metetra
.656 .751 .92 r
.70545 .54264 .71126 .54943 .72377 .54576 .718 .53894 Metetra
.656 .751 .92 r
.718 .53894 .72377 .54576 .73634 .54207 .7306 .53522 Metetra
.656 .751 .92 r
.7306 .53522 .73634 .54207 .74896 .53837 .74326 .53149 Metetra
.656 .751 .92 r
.74326 .53149 .74896 .53837 .76163 .53465 .75598 .52774 Metetra
.656 .751 .92 r
.75598 .52774 .76163 .53465 .77436 .53091 .76875 .52397 Metetra
.656 .751 .92 r
.76875 .52397 .77436 .53091 .78715 .52716 .78158 .52019 Metetra
.656 .751 .92 r
.78158 .52019 .78715 .52716 .8 .52339 .79447 .51639 Metetra
.656 .751 .92 r
.79447 .51639 .8 .52339 .8129 .51961 .80741 .51257 Metetra
.656 .751 .92 r
.80741 .51257 .8129 .51961 .82586 .5158 .82041 .50874 Metetra
.656 .751 .92 r
.82041 .50874 .82586 .5158 .83888 .51198 .83348 .50489 Metetra
.656 .751 .92 r
.83348 .50489 .83888 .51198 .85196 .50815 .8466 .50102 Metetra
.656 .751 .92 r
.8466 .50102 .85196 .50815 .8651 .50429 .85978 .49713 Metetra
.656 .751 .92 r
.85978 .49713 .8651 .50429 .87829 .50042 .87301 .49323 Metetra
.656 .751 .92 r
.87301 .49323 .87829 .50042 .89155 .49653 .88631 .48931 Metetra
.656 .751 .92 r
.88631 .48931 .89155 .49653 .90487 .49262 .89967 .48537 Metetra
.656 .751 .92 r
.89967 .48537 .90487 .49262 .91824 .4887 .9131 .48141 Metetra
.656 .751 .92 r
.9131 .48141 .91824 .4887 .93168 .48476 .92658 .47743 Metetra
.656 .751 .92 r
.92658 .47743 .93168 .48476 .94518 .4808 .94012 .47344 Metetra
.656 .751 .92 r
.33529 .64378 .34216 .64977 .35315 .64653 .34631 .64051 Metetra
.656 .751 .92 r
.34631 .64051 .35315 .64653 .36419 .64327 .35738 .63723 Metetra
.656 .751 .92 r
.35738 .63723 .36419 .64327 .37527 .64001 .36849 .63394 Metetra
.656 .751 .92 r
.36849 .63394 .37527 .64001 .3864 .63672 .37965 .63063 Metetra
.656 .751 .92 r
.37965 .63063 .3864 .63672 .39758 .63343 .39085 .62731 Metetra
.656 .751 .92 r
.39085 .62731 .39758 .63343 .4088 .63012 .4021 .62397 Metetra
.656 .751 .92 r
.4021 .62397 .4088 .63012 .42007 .6268 .4134 .62062 Metetra
.656 .751 .92 r
.4134 .62062 .42007 .6268 .43139 .62346 .42475 .61726 Metetra
.656 .751 .92 r
.42475 .61726 .43139 .62346 .44275 .62011 .43615 .61388 Metetra
.656 .751 .92 r
.43615 .61388 .44275 .62011 .45417 .61674 .44759 .61049 Metetra
.656 .751 .92 r
.44759 .61049 .45417 .61674 .46563 .61336 .45908 .60708 Metetra
.656 .751 .92 r
.45908 .60708 .46563 .61336 .47714 .60997 .47062 .60366 Metetra
.656 .751 .92 r
.47062 .60366 .47714 .60997 .48869 .60656 .48221 .60023 Metetra
.656 .751 .92 r
.48221 .60023 .48869 .60656 .5003 .60314 .49385 .59678 Metetra
.656 .751 .92 r
.49385 .59678 .5003 .60314 .51196 .5997 .50554 .59331 Metetra
.656 .751 .92 r
.50554 .59331 .51196 .5997 .52366 .59625 .51728 .58983 Metetra
.656 .751 .92 r
.51728 .58983 .52366 .59625 .53542 .59278 .52907 .58634 Metetra
.656 .751 .92 r
.52907 .58634 .53542 .59278 .54723 .5893 .54091 .58283 Metetra
.656 .751 .92 r
.54091 .58283 .54723 .5893 .55909 .5858 .5528 .57931 Metetra
.656 .751 .92 r
.5528 .57931 .55909 .5858 .57099 .58229 .56474 .57577 Metetra
.656 .751 .92 r
.56474 .57577 .57099 .58229 .58295 .57876 .57674 .57221 Metetra
.656 .751 .92 r
.57674 .57221 .58295 .57876 .59497 .57522 .58878 .56864 Metetra
.656 .751 .92 r
.58878 .56864 .59497 .57522 .60703 .57166 .60088 .56505 Metetra
.656 .751 .92 r
.60088 .56505 .60703 .57166 .61915 .56809 .61303 .56145 Metetra
.656 .751 .92 r
.61303 .56145 .61915 .56809 .63131 .5645 .62524 .55784 Metetra
.656 .751 .92 r
.62524 .55784 .63131 .5645 .64354 .5609 .6375 .5542 Metetra
.656 .751 .92 r
.6375 .5542 .64354 .5609 .65581 .55728 .64981 .55055 Metetra
.656 .751 .92 r
.64981 .55055 .65581 .55728 .66814 .55364 .66217 .54689 Metetra
.656 .751 .92 r
.66217 .54689 .66814 .55364 .68052 .54999 .67459 .54321 Metetra
.656 .751 .92 r
.67459 .54321 .68052 .54999 .69296 .54632 .68707 .53951 Metetra
.656 .751 .92 r
.68707 .53951 .69296 .54632 .70545 .54264 .6996 .5358 Metetra
.656 .751 .92 r
.6996 .5358 .70545 .54264 .718 .53894 .71219 .53206 Metetra
.656 .751 .92 r
.71219 .53206 .718 .53894 .7306 .53522 .72483 .52832 Metetra
.656 .751 .92 r
.72483 .52832 .7306 .53522 .74326 .53149 .73753 .52455 Metetra
.656 .751 .92 r
.73753 .52455 .74326 .53149 .75598 .52774 .75028 .52077 Metetra
.656 .751 .92 r
.75028 .52077 .75598 .52774 .76875 .52397 .76309 .51698 Metetra
.656 .751 .92 r
.76309 .51698 .76875 .52397 .78158 .52019 .77596 .51316 Metetra
.656 .751 .92 r
.77596 .51316 .78158 .52019 .79447 .51639 .78889 .50933 Metetra
.656 .751 .92 r
.78889 .50933 .79447 .51639 .80741 .51257 .80188 .50548 Metetra
.656 .751 .92 r
.80188 .50548 .80741 .51257 .82041 .50874 .81492 .50161 Metetra
.656 .751 .92 r
.81492 .50161 .82041 .50874 .83348 .50489 .82802 .49773 Metetra
.656 .751 .92 r
.82802 .49773 .83348 .50489 .8466 .50102 .84119 .49383 Metetra
.656 .751 .92 r
.84119 .49383 .8466 .50102 .85978 .49713 .85441 .48991 Metetra
.656 .751 .92 r
.85441 .48991 .85978 .49713 .87301 .49323 .86769 .48597 Metetra
.656 .751 .92 r
.86769 .48597 .87301 .49323 .88631 .48931 .88103 .48202 Metetra
.656 .751 .92 r
.88103 .48202 .88631 .48931 .89967 .48537 .89444 .47804 Metetra
.656 .751 .92 r
.89444 .47804 .89967 .48537 .9131 .48141 .90791 .47405 Metetra
.656 .751 .92 r
.90791 .47405 .9131 .48141 .92658 .47743 .92143 .47004 Metetra
.656 .751 .92 r
.92143 .47004 .92658 .47743 .94012 .47344 .93502 .46602 Metetra
.656 .751 .92 r
.32837 .63774 .33529 .64378 .34631 .64051 .33942 .63444 Metetra
.656 .751 .92 r
.33942 .63444 .34631 .64051 .35738 .63723 .35051 .63114 Metetra
.656 .751 .92 r
.35051 .63114 .35738 .63723 .36849 .63394 .36165 .62782 Metetra
.656 .751 .92 r
.36165 .62782 .36849 .63394 .37965 .63063 .37284 .62449 Metetra
.656 .751 .92 r
.37284 .62449 .37965 .63063 .39085 .62731 .38407 .62114 Metetra
.656 .751 .92 r
.38407 .62114 .39085 .62731 .4021 .62397 .39536 .61778 Metetra
.656 .751 .92 r
.39536 .61778 .4021 .62397 .4134 .62062 .40668 .6144 Metetra
.656 .751 .92 r
.40668 .6144 .4134 .62062 .42475 .61726 .41806 .61101 Metetra
.656 .751 .92 r
.41806 .61101 .42475 .61726 .43615 .61388 .42949 .60761 Metetra
.656 .751 .92 r
.42949 .60761 .43615 .61388 .44759 .61049 .44096 .60419 Metetra
.656 .751 .92 r
.44096 .60419 .44759 .61049 .45908 .60708 .45248 .60076 Metetra
.656 .751 .92 r
.45248 .60076 .45908 .60708 .47062 .60366 .46406 .59731 Metetra
.656 .751 .92 r
.46406 .59731 .47062 .60366 .48221 .60023 .47568 .59385 Metetra
.656 .751 .92 r
.47568 .59385 .48221 .60023 .49385 .59678 .48735 .59037 Metetra
.656 .751 .92 r
.48735 .59037 .49385 .59678 .50554 .59331 .49907 .58688 Metetra
.656 .751 .92 r
.49907 .58688 .50554 .59331 .51728 .58983 .51084 .58337 Metetra
.656 .751 .92 r
.51084 .58337 .51728 .58983 .52907 .58634 .52266 .57985 Metetra
.656 .751 .92 r
.52266 .57985 .52907 .58634 .54091 .58283 .53454 .57631 Metetra
.656 .751 .92 r
.53454 .57631 .54091 .58283 .5528 .57931 .54646 .57276 Metetra
.656 .751 .92 r
.54646 .57276 .5528 .57931 .56474 .57577 .55844 .56919 Metetra
.656 .751 .92 r
.55844 .56919 .56474 .57577 .57674 .57221 .57047 .56561 Metetra
.656 .751 .92 r
.57047 .56561 .57674 .57221 .58878 .56864 .58255 .56201 Metetra
.656 .751 .92 r
.58255 .56201 .58878 .56864 .60088 .56505 .59468 .55839 Metetra
.656 .751 .92 r
.59468 .55839 .60088 .56505 .61303 .56145 .60687 .55476 Metetra
.656 .751 .92 r
.60687 .55476 .61303 .56145 .62524 .55784 .61911 .55112 Metetra
.656 .751 .92 r
.61911 .55112 .62524 .55784 .6375 .5542 .6314 .54745 Metetra
.656 .751 .92 r
.6314 .54745 .6375 .5542 .64981 .55055 .64375 .54377 Metetra
.656 .751 .92 r
.64375 .54377 .64981 .55055 .66217 .54689 .65616 .54008 Metetra
.656 .751 .92 r
.65616 .54008 .66217 .54689 .67459 .54321 .66861 .53637 Metetra
.656 .751 .92 r
.66861 .53637 .67459 .54321 .68707 .53951 .68113 .53264 Metetra
.656 .751 .92 r
.68113 .53264 .68707 .53951 .6996 .5358 .6937 .5289 Metetra
.656 .751 .92 r
.6937 .5289 .6996 .5358 .71219 .53206 .70632 .52513 Metetra
.656 .751 .92 r
.70632 .52513 .71219 .53206 .72483 .52832 .719 .52136 Metetra
.656 .751 .92 r
.719 .52136 .72483 .52832 .73753 .52455 .73174 .51756 Metetra
.656 .751 .92 r
.73174 .51756 .73753 .52455 .75028 .52077 .74453 .51375 Metetra
.656 .751 .92 r
.74453 .51375 .75028 .52077 .76309 .51698 .75739 .50992 Metetra
.656 .751 .92 r
.75739 .50992 .76309 .51698 .77596 .51316 .7703 .50607 Metetra
.656 .751 .92 r
.7703 .50607 .77596 .51316 .78889 .50933 .78327 .50221 Metetra
.656 .751 .92 r
.78327 .50221 .78889 .50933 .80188 .50548 .79629 .49833 Metetra
.656 .751 .92 r
.79629 .49833 .80188 .50548 .81492 .50161 .80938 .49443 Metetra
.656 .751 .92 r
.80938 .49443 .81492 .50161 .82802 .49773 .82252 .49051 Metetra
.656 .751 .92 r
.82252 .49051 .82802 .49773 .84119 .49383 .83573 .48658 Metetra
.656 .751 .92 r
.83573 .48658 .84119 .49383 .85441 .48991 .849 .48263 Metetra
.656 .751 .92 r
.849 .48263 .85441 .48991 .86769 .48597 .86232 .47866 Metetra
.656 .751 .92 r
.86232 .47866 .86769 .48597 .88103 .48202 .87571 .47467 Metetra
.656 .751 .92 r
.87571 .47467 .88103 .48202 .89444 .47804 .88916 .47066 Metetra
.656 .751 .92 r
.88916 .47066 .89444 .47804 .90791 .47405 .90267 .46664 Metetra
.656 .751 .92 r
.90267 .46664 .90791 .47405 .92143 .47004 .91624 .46259 Metetra
.656 .751 .92 r
.91624 .46259 .92143 .47004 .93502 .46602 .92988 .45853 Metetra
.652 .75 .922 r
.32139 .63165 .32837 .63774 .33942 .63444 .33246 .62844 Metetra
.645 .752 .927 r
.33246 .62844 .33942 .63444 .35051 .63114 .34357 .6254 Metetra
.638 .76 .937 r
.34357 .6254 .35051 .63114 .36165 .62782 .35472 .62248 Metetra
.628 .772 .949 r
.35472 .62248 .36165 .62782 .37284 .62449 .36591 .6197 Metetra
.615 .789 .965 r
.36591 .6197 .37284 .62449 .38407 .62114 .37715 .61704 Metetra
.596 .81 .982 r
.37715 .61704 .38407 .62114 .39536 .61778 .38844 .61449 Metetra
.567 .833 .995 r
.38844 .61449 .39536 .61778 .40668 .6144 .39977 .61201 Metetra
.524 .852 .997 r
.39977 .61201 .40668 .6144 .41806 .61101 .41116 .60957 Metetra
.462 .855 .975 r
.41116 .60957 .41806 .61101 .42949 .60761 .4226 .6071 Metetra
.383 .836 .922 r
.4226 .6071 .42949 .60761 .44096 .60419 .4341 .60458 Metetra
.296 .793 .84 r
.4341 .60458 .44096 .60419 .45248 .60076 .44566 .60196 Metetra
.216 .738 .747 r
.44566 .60196 .45248 .60076 .46406 .59731 .45728 .59918 Metetra
.45728 .59918 .46406 .59731 .47568 .59385 .46895 .59623 Metetra
.46895 .59623 .47568 .59385 .48735 .59037 .48068 .59306 Metetra
.48068 .59306 .48735 .59037 .49907 .58688 .49246 .58966 Metetra
.49246 .58966 .49907 .58688 .51084 .58337 .5043 .58601 Metetra
.5043 .58601 .51084 .58337 .52266 .57985 .51619 .58211 Metetra
.51619 .58211 .52266 .57985 .53454 .57631 .52812 .57797 Metetra
.325 .805 .754 r
.52812 .57797 .53454 .57631 .54646 .57276 .54011 .57358 Metetra
.435 .875 .851 r
.54011 .57358 .54646 .57276 .55844 .56919 .55214 .56898 Metetra
.543 .921 .931 r
.55214 .56898 .55844 .56919 .57047 .56561 .56421 .56418 Metetra
.627 .926 .973 r
.56421 .56418 .57047 .56561 .58255 .56201 .57633 .55923 Metetra
.677 .896 .976 r
.57633 .55923 .58255 .56201 .59468 .55839 .58848 .55414 Metetra
.699 .848 .954 r
.58848 .55414 .59468 .55839 .60687 .55476 .60068 .54897 Metetra
.704 .796 .922 r
.60068 .54897 .60687 .55476 .61911 .55112 .61292 .54376 Metetra
.7 .748 .889 r
.61292 .54376 .61911 .55112 .6314 .54745 .6252 .53854 Metetra
.692 .707 .859 r
.6252 .53854 .6314 .54745 .64375 .54377 .63753 .53337 Metetra
.683 .673 .834 r
.63753 .53337 .64375 .54377 .65616 .54008 .64991 .52827 Metetra
.673 .645 .814 r
.64991 .52827 .65616 .54008 .66861 .53637 .66233 .52329 Metetra
.665 .623 .798 r
.66233 .52329 .66861 .53637 .68113 .53264 .67481 .51846 Metetra
.657 .606 .785 r
.67481 .51846 .68113 .53264 .6937 .5289 .68735 .51381 Metetra
.65 .592 .776 r
.68735 .51381 .6937 .5289 .70632 .52513 .69995 .50936 Metetra
.644 .582 .77 r
.69995 .50936 .70632 .52513 .719 .52136 .71261 .50513 Metetra
.639 .575 .766 r
.71261 .50513 .719 .52136 .73174 .51756 .72534 .50111 Metetra
.635 .571 .765 r
.72534 .50111 .73174 .51756 .74453 .51375 .73814 .49731 Metetra
.632 .57 .767 r
.73814 .49731 .74453 .51375 .75739 .50992 .75101 .49372 Metetra
.629 .571 .77 r
.75101 .49372 .75739 .50992 .7703 .50607 .76396 .49032 Metetra
.627 .575 .776 r
.76396 .49032 .7703 .50607 .78327 .50221 .77699 .48708 Metetra
.626 .582 .785 r
.77699 .48708 .78327 .50221 .79629 .49833 .79009 .48397 Metetra
.625 .591 .795 r
.79009 .48397 .79629 .49833 .80938 .49443 .80327 .48095 Metetra
.626 .604 .808 r
.80327 .48095 .80938 .49443 .82252 .49051 .81651 .47798 Metetra
.627 .62 .823 r
.81651 .47798 .82252 .49051 .83573 .48658 .82983 .475 Metetra
.629 .638 .84 r
.82983 .475 .83573 .48658 .849 .48263 .84322 .47198 Metetra
.632 .657 .857 r
.84322 .47198 .849 .48263 .86232 .47866 .85667 .46887 Metetra
.635 .678 .873 r
.85667 .46887 .86232 .47866 .87571 .47467 .87017 .46562 Metetra
.639 .699 .889 r
.87017 .46562 .87571 .47467 .88916 .47066 .88373 .46222 Metetra
.643 .717 .902 r
.88373 .46222 .88916 .47066 .90267 .46664 .89733 .45864 Metetra
.647 .732 .911 r
.89733 .45864 .90267 .46664 .91624 .46259 .91099 .4549 Metetra
.651 .744 .918 r
.91099 .4549 .91624 .46259 .92988 .45853 .92469 .45098 Metetra
.652 .75 .922 r
.31437 .62551 .32139 .63165 .33246 .62844 .32546 .62227 Metetra
.628 .744 .931 r
.32546 .62227 .33246 .62844 .34357 .6254 .33658 .61963 Metetra
.613 .754 .945 r
.33658 .61963 .34357 .6254 .35472 .62248 .34773 .61726 Metetra
.59 .767 .964 r
.34773 .61726 .35472 .62248 .36591 .6197 .35891 .6152 Metetra
.556 .784 .984 r
.35891 .6152 .36591 .6197 .37715 .61704 .37014 .61344 Metetra
.506 .801 .998 r
.37014 .61344 .37715 .61704 .38844 .61449 .38142 .61193 Metetra
.43 .807 .992 r
.38142 .61193 .38844 .61449 .39977 .61201 .39275 .61061 Metetra
.321 .785 .94 r
.39275 .61061 .39977 .61201 .41116 .60957 .40414 .60938 Metetra
.188 .719 .827 r
.40414 .60938 .41116 .60957 .4226 .6071 .41559 .60814 Metetra
.41559 .60814 .4226 .6071 .4341 .60458 .42711 .60678 Metetra
.042 0 0 r
.42711 .60678 .4341 .60458 .44566 .60196 .4387 .6052 Metetra
.107 0 0 r
.4387 .6052 .44566 .60196 .45728 .59918 .45036 .60331 Metetra
.141 0 0 r
.45036 .60331 .45728 .59918 .46895 .59623 .46209 .60103 Metetra
.149 0 0 r
.46209 .60103 .46895 .59623 .48068 .59306 .47388 .59827 Metetra
.135 0 0 r
.47388 .59827 .48068 .59306 .49246 .58966 .48573 .59501 Metetra
.1 0 0 r
.48573 .59501 .49246 .58966 .5043 .58601 .49765 .5912 Metetra
.04 0 0 r
.49765 .5912 .5043 .58601 .51619 .58211 .50961 .58683 Metetra
.50961 .58683 .51619 .58211 .52812 .57797 .52163 .5819 Metetra
.52163 .5819 .52812 .57797 .54011 .57358 .53368 .57646 Metetra
.343 .799 .669 r
.53368 .57646 .54011 .57358 .55214 .56898 .54577 .57053 Metetra
.52 .916 .824 r
.54577 .57053 .55214 .56898 .56421 .56418 .5579 .56418 Metetra
.66 .965 .923 r
.5579 .56418 .56421 .56418 .57633 .55923 .57005 .55749 Metetra
.736 .941 .951 r
.57005 .55749 .57633 .55923 .58848 .55414 .58223 .55053 Metetra
.76 .881 .933 r
.58223 .55053 .58848 .55414 .60068 .54897 .59444 .5434 Metetra
.757 .815 .898 r
.59444 .5434 .60068 .54897 .61292 .54376 .60668 .53619 Metetra
.743 .755 .863 r
.60668 .53619 .61292 .54376 .6252 .53854 .61894 .52899 Metetra
.726 .706 .832 r
.61894 .52899 .6252 .53854 .63753 .53337 .63124 .52192 Metetra
.709 .667 .806 r
.63124 .52192 .63753 .53337 .64991 .52827 .64357 .51505 Metetra
.693 .635 .786 r
.64357 .51505 .64991 .52827 .66233 .52329 .65596 .50848 Metetra
.679 .609 .77 r
.65596 .50848 .66233 .52329 .67481 .51846 .66839 .50227 Metetra
.666 .589 .759 r
.66839 .50227 .67481 .51846 .68735 .51381 .68088 .49648 Metetra
.655 .573 .75 r
.68088 .49648 .68735 .51381 .69995 .50936 .69343 .49117 Metetra
.645 .56 .745 r
.69343 .49117 .69995 .50936 .71261 .50513 .70606 .48637 Metetra
.636 .551 .742 r
.70606 .48637 .71261 .50513 .72534 .50111 .71877 .48209 Metetra
.628 .545 .742 r
.71877 .48209 .72534 .50111 .73814 .49731 .73157 .47832 Metetra
.62 .541 .744 r
.73157 .47832 .73814 .49731 .75101 .49372 .74446 .47504 Metetra
.614 .541 .748 r
.74446 .47504 .75101 .49372 .76396 .49032 .75745 .47222 Metetra
.609 .543 .755 r
.75745 .47222 .76396 .49032 .77699 .48708 .77053 .46978 Metetra
.604 .548 .764 r
.77053 .46978 .77699 .48708 .79009 .48397 .78371 .46766 Metetra
.601 .557 .776 r
.78371 .46766 .79009 .48397 .80327 .48095 .79699 .46577 Metetra
.599 .569 .791 r
.79699 .46577 .80327 .48095 .81651 .47798 .81035 .464 Metetra
.599 .585 .808 r
.81035 .464 .81651 .47798 .82983 .475 .8238 .46226 Metetra
.601 .604 .827 r
.8238 .46226 .82983 .475 .84322 .47198 .83732 .46042 Metetra
.604 .627 .847 r
.83732 .46042 .84322 .47198 .85667 .46887 .85091 .45841 Metetra
.61 .652 .867 r
.85091 .45841 .85667 .46887 .87017 .46562 .86455 .45612 Metetra
.617 .678 .886 r
.86455 .45612 .87017 .46562 .88373 .46222 .87823 .4535 Metetra
.625 .703 .902 r
.87823 .4535 .88373 .46222 .89733 .45864 .89195 .45053 Metetra
.632 .724 .914 r
.89195 .45053 .89733 .45864 .91099 .4549 .9057 .44723 Metetra
.648 .745 .921 r
.9057 .44723 .91099 .4549 .92469 .45098 .91946 .44336 Metetra
.656 .751 .92 r
.30728 .61933 .31437 .62551 .32546 .62227 .31842 .61596 Metetra
.616 .738 .933 r
.31842 .61596 .32546 .62227 .33658 .61963 .32954 .6136 Metetra
.587 .738 .948 r
.32954 .6136 .33658 .61963 .34773 .61726 .34068 .6118 Metetra
.552 .748 .968 r
.34068 .6118 .34773 .61726 .35891 .6152 .35186 .61047 Metetra
.5 .757 .987 r
.35186 .61047 .35891 .6152 .37014 .61344 .36308 .6096 Metetra
.426 .76 .996 r
.36308 .6096 .37014 .61344 .38142 .61193 .37434 .60914 Metetra
.323 .747 .974 r
.37434 .60914 .38142 .61193 .39275 .61061 .38566 .60896 Metetra
.192 .701 .899 r
.38566 .60896 .39275 .61061 .40414 .60938 .39705 .60894 Metetra
.054 .619 .768 r
.39705 .60894 .40414 .60938 .41559 .60814 .4085 .60891 Metetra
.06 0 0 r
.4085 .60891 .41559 .60814 .42711 .60678 .42004 .60872 Metetra
.135 0 0 r
.42004 .60872 .42711 .60678 .4387 .6052 .43165 .6082 Metetra
.173 0 0 r
.43165 .6082 .4387 .6052 .45036 .60331 .44335 .6072 Metetra
.182 0 0 r
.44335 .6072 .45036 .60331 .46209 .60103 .45513 .60559 Metetra
.166 0 0 r
.45513 .60559 .46209 .60103 .47388 .59827 .46698 .60327 Metetra
.128 0 0 r
.46698 .60327 .47388 .59827 .48573 .59501 .47891 .60015 Metetra
.066 0 0 r
.47891 .60015 .48573 .59501 .49765 .5912 .4909 .59619 Metetra
.4909 .59619 .49765 .5912 .50961 .58683 .50294 .59136 Metetra
.50294 .59136 .50961 .58683 .52163 .5819 .51503 .58567 Metetra
.51503 .58567 .52163 .5819 .53368 .57646 .52716 .57918 Metetra
.487 .887 .738 r
.52716 .57918 .53368 .57646 .54577 .57053 .53932 .57194 Metetra
.648 .969 .855 r
.53932 .57194 .54577 .57053 .5579 .56418 .5515 .56405 Metetra
.754 .981 .913 r
.5515 .56405 .5579 .56418 .57005 .55749 .5637 .55564 Metetra
.8 .94 .92 r
.5637 .55564 .57005 .55749 .58223 .55053 .57592 .54682 Metetra
.807 .88 .899 r
.57592 .54682 .58223 .55053 .59444 .5434 .58814 .53775 Metetra
.796 .818 .869 r
.58814 .53775 .59444 .5434 .60668 .53619 .60038 .52857 Metetra
.777 .763 .84 r
.60038 .52857 .60668 .53619 .61894 .52899 .61264 .51943 Metetra
.756 .717 .815 r
.61264 .51943 .61894 .52899 .63124 .52192 .62492 .5105 Metetra
.736 .678 .795 r
.62492 .5105 .63124 .52192 .64357 .51505 .63722 .5019 Metetra
.717 .647 .778 r
.63722 .5019 .64357 .51505 .65596 .50848 .64956 .49376 Metetra
.699 .62 .766 r
.64956 .49376 .65596 .50848 .66839 .50227 .66195 .48621 Metetra
.682 .599 .756 r
.66195 .48621 .66839 .50227 .68088 .49648 .6744 .47933 Metetra
.667 .581 .749 r
.6744 .47933 .68088 .49648 .69343 .49117 .68692 .47319 Metetra
.653 .567 .745 r
.68692 .47319 .69343 .49117 .70606 .48637 .69952 .46785 Metetra
.639 .555 .744 r
.69952 .46785 .70606 .48637 .71877 .48209 .71221 .46332 Metetra
.627 .547 .744 r
.71221 .46332 .71877 .48209 .73157 .47832 .72501 .4596 Metetra
.615 .541 .747 r
.72501 .4596 .73157 .47832 .74446 .47504 .73792 .45664 Metetra
.605 .538 .753 r
.73792 .45664 .74446 .47504 .75745 .47222 .75094 .45439 Metetra
.595 .538 .76 r
.75094 .45439 .75745 .47222 .77053 .46978 .76408 .45275 Metetra
.587 .541 .77 r
.76408 .45275 .77053 .46978 .78371 .46766 .77734 .4516 Metetra
.58 .548 .783 r
.77734 .4516 .78371 .46766 .79699 .46577 .79071 .45081 Metetra
.574 .558 .799 r
.79071 .45081 .79699 .46577 .81035 .464 .80419 .45023 Metetra
.571 .573 .816 r
.80419 .45023 .81035 .464 .8238 .46226 .81776 .44968 Metetra
.571 .593 .836 r
.81776 .44968 .8238 .46226 .83732 .46042 .83141 .44902 Metetra
.575 .616 .856 r
.83141 .44902 .83732 .46042 .85091 .45841 .84513 .44808 Metetra
.581 .643 .877 r
.84513 .44808 .85091 .45841 .86455 .45612 .8589 .44674 Metetra
.591 .671 .895 r
.8589 .44674 .86455 .45612 .87823 .4535 .8727 .44491 Metetra
.603 .699 .911 r
.8727 .44491 .87823 .4535 .89195 .45053 .88654 .44257 Metetra
.614 .723 .923 r
.88654 .44257 .89195 .45053 .9057 .44723 .9004 .43976 Metetra
.653 .755 .925 r
.9004 .43976 .9057 .44723 .91946 .44336 .91418 .43568 Metetra
.656 .751 .92 r
.30014 .6131 .30728 .61933 .31842 .61596 .31131 .60971 Metetra
.621 .742 .933 r
.31131 .60971 .31842 .61596 .32954 .6136 .32246 .6072 Metetra
.56 .719 .947 r
.32246 .6072 .32954 .6136 .34068 .6118 .3336 .606 Metetra
.512 .722 .968 r
.3336 .606 .34068 .6118 .35186 .61047 .34476 .6054 Metetra
.443 .722 .985 r
.34476 .6054 .35186 .61047 .36308 .6096 .35596 .60542 Metetra
.345 .71 .985 r
.35596 .60542 .36308 .6096 .37434 .60914 .36721 .60598 Metetra
.218 .676 .947 r
.36721 .60598 .37434 .60914 .38566 .60896 .37851 .60693 Metetra
.073 .611 .855 r
.37851 .60693 .38566 .60896 .39705 .60894 .38989 .6081 Metetra
0 .525 .718 r
.38989 .6081 .39705 .60894 .4085 .60891 .40134 .60927 Metetra
.157 0 0 r
.40134 .60927 .4085 .60891 .42004 .60872 .41289 .61024 Metetra
.21 0 0 r
.41289 .61024 .42004 .60872 .43165 .6082 .42452 .61077 Metetra
.226 0 0 r
.42452 .61077 .43165 .6082 .44335 .6072 .43626 .61067 Metetra
.212 0 0 r
.43626 .61067 .44335 .6072 .45513 .60559 .44808 .60975 Metetra
.174 0 0 r
.44808 .60975 .45513 .60559 .46698 .60327 .45999 .60788 Metetra
.111 0 0 r
.45999 .60788 .46698 .60327 .47891 .60015 .47199 .60493 Metetra
.02 0 0 r
.47199 .60493 .47891 .60015 .4909 .59619 .48405 .60083 Metetra
.48405 .60083 .4909 .59619 .50294 .59136 .49618 .59556 Metetra
.49618 .59556 .50294 .59136 .51503 .58567 .50835 .58914 Metetra
.44 .85 .676 r
.50835 .58914 .51503 .58567 .52716 .57918 .52056 .58162 Metetra
.615 .951 .792 r
.52056 .58162 .52716 .57918 .53932 .57194 .53279 .5731 Metetra
.745 .992 .867 r
.53279 .5731 .53932 .57194 .5515 .56405 .54503 .56371 Metetra
.817 .977 .893 r
.54503 .56371 .5515 .56405 .5637 .55564 .55729 .55361 Metetra
.842 .93 .887 r
.55729 .55361 .5637 .55564 .57592 .54682 .56954 .54298 Metetra
.84 .873 .867 r
.56954 .54298 .57592 .54682 .58814 .53775 .58179 .53201 Metetra
.825 .817 .843 r
.58179 .53201 .58814 .53775 .60038 .52857 .59404 .52091 Metetra
.804 .768 .82 r
.59404 .52091 .60038 .52857 .61264 .51943 .6063 .50989 Metetra
.781 .725 .8 r
.6063 .50989 .61264 .51943 .62492 .5105 .61856 .49915 Metetra
.759 .689 .784 r
.61856 .49915 .62492 .5105 .63722 .5019 .63084 .48887 Metetra
.738 .658 .771 r
.63084 .48887 .63722 .5019 .64956 .49376 .64315 .47924 Metetra
.717 .632 .761 r
.64315 .47924 .64956 .49376 .66195 .48621 .65551 .4704 Metetra
.697 .609 .754 r
.65551 .4704 .66195 .48621 .6744 .47933 .66793 .46247 Metetra
.678 .59 .749 r
.66793 .46247 .6744 .47933 .68692 .47319 .68041 .45555 Metetra
.66 .574 .747 r
.68041 .45555 .68692 .47319 .69952 .46785 .69299 .44971 Metetra
.643 .561 .747 r
.69299 .44971 .69952 .46785 .71221 .46332 .70567 .44496 Metetra
.626 .55 .748 r
.70567 .44496 .71221 .46332 .72501 .4596 .71847 .4413 Metetra
.61 .542 .752 r
.71847 .4413 .72501 .4596 .73792 .45664 .73139 .43867 Metetra
.595 .536 .759 r
.73139 .43867 .73792 .45664 .75094 .45439 .74445 .43699 Metetra
.58 .534 .767 r
.74445 .43699 .75094 .45439 .76408 .45275 .75765 .43613 Metetra
.567 .534 .778 r
.75765 .43613 .76408 .45275 .77734 .4516 .77098 .43594 Metetra
.555 .539 .792 r
.77098 .43594 .77734 .4516 .79071 .45081 .78444 .43623 Metetra
.546 .548 .808 r
.78444 .43623 .79071 .45081 .80419 .45023 .79803 .4368 Metetra
.54 .562 .826 r
.79803 .4368 .80419 .45023 .81776 .44968 .81172 .43742 Metetra
.538 .582 .846 r
.81172 .43742 .81776 .44968 .83141 .44902 .8255 .43789 Metetra
.541 .606 .867 r
.8255 .43789 .83141 .44902 .84513 .44808 .83935 .43801 Metetra
.55 .634 .888 r
.83935 .43801 .84513 .44808 .8589 .44674 .85324 .4376 Metetra
.563 .665 .906 r
.85324 .4376 .8589 .44674 .8727 .44491 .86717 .43656 Metetra
.578 .695 .922 r
.86717 .43656 .8727 .44491 .88654 .44257 .88112 .43487 Metetra
.609 .73 .931 r
.88112 .43487 .88654 .44257 .9004 .43976 .89504 .43214 Metetra
.656 .754 .922 r
.89504 .43214 .9004 .43976 .91418 .43568 .90886 .42794 Metetra
.656 .751 .92 r
.29295 .60682 .30014 .6131 .31131 .60971 .30414 .6034 Metetra
.642 .748 .926 r
.30414 .6034 .31131 .60971 .32246 .6072 .31535 .60033 Metetra
.532 .695 .943 r
.31535 .60033 .32246 .6072 .3336 .606 .32647 .59976 Metetra
.473 .693 .963 r
.32647 .59976 .3336 .606 .34476 .6054 .33762 .5999 Metetra
.387 .681 .976 r
.33762 .5999 .34476 .6054 .35596 .60542 .3488 .60078 Metetra
.269 .654 .967 r
.3488 .60078 .35596 .60542 .36721 .60598 .36003 .60233 Metetra
.123 .602 .916 r
.36003 .60233 .36721 .60598 .37851 .60693 .37131 .60439 Metetra
0 .525 .814 r
.37131 .60439 .37851 .60693 .38989 .6081 .38267 .60672 Metetra
.154 0 0 r
.38267 .60672 .38989 .6081 .40134 .60927 .39412 .60908 Metetra
.234 0 0 r
.39412 .60908 .40134 .60927 .41289 .61024 .40567 .61118 Metetra
.269 0 0 r
.40567 .61118 .41289 .61024 .42452 .61077 .41732 .61276 Metetra
.267 0 0 r
.41732 .61276 .42452 .61077 .43626 .61067 .42908 .61356 Metetra
.234 0 0 r
.42908 .61356 .43626 .61067 .44808 .60975 .44095 .61335 Metetra
.173 0 0 r
.44095 .61335 .44808 .60975 .45999 .60788 .45291 .61194 Metetra
.082 0 0 r
.45291 .61194 .45999 .60788 .47199 .60493 .46497 .60917 Metetra
.46497 .60917 .47199 .60493 .48405 .60083 .47711 .60498 Metetra
.47711 .60498 .48405 .60083 .49618 .59556 .48932 .59931 Metetra
.381 .811 .639 r
.48932 .59931 .49618 .59556 .50835 .58914 .50157 .59219 Metetra
.566 .924 .749 r
.50157 .59219 .50835 .58914 .52056 .58162 .51386 .58369 Metetra
.717 .987 .828 r
.51386 .58369 .52056 .58162 .53279 .5731 .52617 .57393 Metetra
.813 .994 .865 r
.52617 .57393 .53279 .5731 .54503 .56371 .53848 .56309 Metetra
.858 .963 .87 r
.53848 .56309 .54503 .56371 .55729 .55361 .5508 .55135 Metetra
.87 .915 .857 r
.5508 .55135 .55729 .55361 .56954 .54298 .5631 .53897 Metetra
.863 .863 .838 r
.5631 .53897 .56954 .54298 .58179 .53201 .57538 .52617 Metetra
.846 .815 .819 r
.57538 .52617 .58179 .53201 .59404 .52091 .58765 .51323 Metetra
.825 .771 .801 r
.58765 .51323 .59404 .52091 .6063 .50989 .59992 .50039 Metetra
.802 .732 .787 r
.59992 .50039 .6063 .50989 .61856 .49915 .61217 .48792 Metetra
.779 .698 .774 r
.61217 .48792 .61856 .49915 .63084 .48887 .62444 .47604 Metetra
.756 .669 .765 r
.62444 .47604 .63084 .48887 .64315 .47924 .63673 .46498 Metetra
.734 .643 .758 r
.63673 .46498 .64315 .47924 .65551 .4704 .64906 .45492 Metetra
.712 .62 .753 r
.64906 .45492 .65551 .4704 .66793 .46247 .66145 .44601 Metetra
.69 .6 .751 r
.66145 .44601 .66793 .46247 .68041 .45555 .67392 .43837 Metetra
.668 .582 .75 r
.67392 .43837 .68041 .45555 .69299 .44971 .68648 .43207 Metetra
.647 .567 .751 r
.68648 .43207 .69299 .44971 .70567 .44496 .69915 .42714 Metetra
.626 .554 .754 r
.69915 .42714 .70567 .44496 .71847 .4413 .71195 .42355 Metetra
.605 .544 .759 r
.71195 .42355 .71847 .4413 .73139 .43867 .72489 .42126 Metetra
.584 .536 .767 r
.72489 .42126 .73139 .43867 .74445 .43699 .73799 .42015 Metetra
.564 .53 .776 r
.73799 .42015 .74445 .43699 .75765 .43613 .75124 .42006 Metetra
.545 .529 .788 r
.75124 .42006 .75765 .43613 .77098 .43594 .76464 .42081 Metetra
.528 .531 .802 r
.76464 .42081 .77098 .43594 .78444 .43623 .7782 .42215 Metetra
.514 .538 .819 r
.7782 .42215 .78444 .43623 .79803 .4368 .79188 .42383 Metetra
.504 .551 .837 r
.79188 .42383 .79803 .4368 .81172 .43742 .80569 .4256 Metetra
.5 .57 .858 r
.80569 .4256 .81172 .43742 .8255 .43789 .81959 .42717 Metetra
.503 .595 .879 r
.81959 .42717 .8255 .43789 .83935 .43801 .83357 .4283 Metetra
.513 .626 .9 r
.83357 .4283 .83935 .43801 .85324 .4376 .84759 .4288 Metetra
.529 .659 .919 r
.84759 .4288 .85324 .4376 .86717 .43656 .86163 .42855 Metetra
.548 .693 .934 r
.86163 .42855 .86717 .43656 .88112 .43487 .8757 .42753 Metetra
.62 .748 .938 r
.8757 .42753 .88112 .43487 .89504 .43214 .88962 .42436 Metetra
.656 .751 .92 r
.88962 .42436 .89504 .43214 .90886 .42794 .90349 .42012 Metetra
.656 .751 .92 r
.2857 .60049 .29295 .60682 .30414 .6034 .29692 .59704 Metetra
.656 .751 .92 r
.29692 .59704 .30414 .6034 .31535 .60033 .30818 .59358 Metetra
.529 .699 .947 r
.30818 .59358 .31535 .60033 .32647 .59976 .31933 .59298 Metetra
.436 .66 .955 r
.31933 .59298 .32647 .59976 .33762 .5999 .33045 .59385 Metetra
.336 .638 .964 r
.33045 .59385 .33762 .5999 .3488 .60078 .3416 .59558 Metetra
.202 .596 .946 r
.3416 .59558 .3488 .60078 .36003 .60233 .3528 .5981 Metetra
.044 .53 .885 r
.3528 .5981 .36003 .60233 .37131 .60439 .36406 .60122 Metetra
0 .448 .78 r
.36406 .60122 .37131 .60439 .38267 .60672 .3754 .60468 Metetra
.226 0 0 r
.3754 .60468 .38267 .60672 .39412 .60908 .38684 .60819 Metetra
.294 0 0 r
.38684 .60819 .39412 .60908 .40567 .61118 .39838 .61141 Metetra
.315 0 0 r
.39838 .61141 .40567 .61118 .41732 .61276 .41004 .61403 Metetra
.298 0 0 r
.41004 .61403 .41732 .61276 .42908 .61356 .42183 .61573 Metetra
.246 0 0 r
.42183 .61573 .42908 .61356 .44095 .61335 .43373 .61622 Metetra
.161 0 0 r
.43373 .61622 .44095 .61335 .45291 .61194 .44575 .61529 Metetra
.041 0 0 r
.44575 .61529 .45291 .61194 .46497 .60917 .45787 .61274 Metetra
.45787 .61274 .46497 .60917 .47711 .60498 .47008 .60848 Metetra
.47008 .60848 .47711 .60498 .48932 .59931 .48237 .60245 Metetra
.503 .893 .73 r
.48237 .60245 .48932 .59931 .50157 .59219 .49471 .59468 Metetra
.674 .973 .806 r
.49471 .59468 .50157 .59219 .51386 .58369 .50708 .58525 Metetra
.792 .998 .846 r
.50708 .58525 .51386 .58369 .52617 .57393 .51947 .57433 Metetra
.858 .982 .855 r
.51947 .57433 .52617 .57393 .53848 .56309 .53185 .5621 Metetra
.885 .944 .846 r
.53185 .5621 .53848 .56309 .5508 .55135 .54423 .54882 Metetra
.888 .899 .831 r
.54423 .54882 .5508 .55135 .5631 .53897 .55659 .53475 Metetra
.878 .853 .814 r
.55659 .53475 .5631 .53897 .57538 .52617 .56891 .52022 Metetra
.862 .811 .798 r
.56891 .52022 .57538 .52617 .58765 .51323 .58121 .50552 Metetra
.842 .772 .785 r
.58121 .50552 .58765 .51323 .59992 .50039 .59349 .49096 Metetra
.82 .738 .774 r
.59349 .49096 .59992 .50039 .61217 .48792 .60576 .47685 Metetra
.797 .707 .766 r
.60576 .47685 .61217 .48792 .62444 .47604 .61802 .46347 Metetra
.773 .679 .76 r
.61802 .46347 .62444 .47604 .63673 .46498 .6303 .45108 Metetra
.75 .654 .755 r
.6303 .45108 .63673 .46498 .64906 .45492 .64262 .43988 Metetra
.726 .632 .753 r
.64262 .43988 .64906 .45492 .66145 .44601 .65499 .43006 Metetra
.701 .611 .753 r
.65499 .43006 .66145 .44601 .67392 .43837 .66743 .42176 Metetra
.676 .592 .754 r
.66743 .42176 .67392 .43837 .68648 .43207 .67998 .41505 Metetra
.651 .575 .757 r
.67998 .41505 .68648 .43207 .69915 .42714 .69265 .40997 Metetra
.625 .56 .762 r
.69265 .40997 .69915 .42714 .71195 .42355 .70546 .4065 Metetra
.599 .547 .768 r
.70546 .4065 .71195 .42355 .72489 .42126 .71843 .40456 Metetra
.572 .536 .776 r
.71843 .40456 .72489 .42126 .73799 .42015 .73156 .40401 Metetra
.546 .528 .787 r
.73156 .40401 .73799 .42015 .75124 .42006 .74486 .40468 Metetra
.52 .523 .799 r
.74486 .40468 .75124 .42006 .76464 .42081 .75833 .40633 Metetra
.497 .523 .814 r
.75833 .40633 .76464 .42081 .7782 .42215 .77197 .40869 Metetra
.477 .528 .831 r
.77197 .40869 .7782 .42215 .79188 .42383 .78576 .41146 Metetra
.463 .539 .85 r
.78576 .41146 .79188 .42383 .80569 .4256 .79968 .41432 Metetra
.456 .558 .87 r
.79968 .41432 .80569 .4256 .81959 .42717 .8137 .41695 Metetra
.458 .584 .892 r
.8137 .41695 .81959 .42717 .83357 .4283 .82779 .41907 Metetra
.47 .617 .913 r
.82779 .41907 .83357 .4283 .84759 .4288 .84193 .42045 Metetra
.489 .653 .932 r
.84193 .42045 .84759 .4288 .86163 .42855 .8561 .42098 Metetra
.511 .689 .948 r
.8561 .42098 .86163 .42855 .8757 .42753 .87029 .42064 Metetra
.648 .777 .942 r
.87029 .42064 .8757 .42753 .88962 .42436 .88416 .41652 Metetra
.656 .751 .92 r
.88416 .41652 .88962 .42436 .90349 .42012 .89808 .41224 Metetra
.656 .751 .92 r
.27839 .59411 .2857 .60049 .29692 .59704 .28964 .59064 Metetra
.656 .751 .92 r
.28964 .59064 .29692 .59704 .30818 .59358 .30093 .58715 Metetra
.573 .727 .947 r
.30093 .58715 .30818 .59358 .31933 .59298 .31216 .58559 Metetra
.401 .625 .943 r
.31216 .58559 .31933 .59298 .33045 .59385 .32325 .58719 Metetra
.291 .594 .947 r
.32325 .58719 .33045 .59385 .3416 .59558 .33438 .58974 Metetra
.146 .54 .923 r
.33438 .58974 .3416 .59558 .3528 .5981 .34555 .59318 Metetra
0 .465 .857 r
.34555 .59318 .3528 .5981 .36406 .60122 .35678 .59731 Metetra
0 .381 .754 r
.35678 .59731 .36406 .60122 .3754 .60468 .36809 .60186 Metetra
.278 0 0 r
.36809 .60186 .3754 .60468 .38684 .60819 .3795 .60648 Metetra
.337 0 0 r
.3795 .60648 .38684 .60819 .39838 .61141 .39104 .6108 Metetra
.349 0 0 r
.39104 .6108 .39838 .61141 .41004 .61403 .4027 .61443 Metetra
.319 0 0 r
.4027 .61443 .41004 .61403 .42183 .61573 .4145 .61701 Metetra
.249 0 0 r
.4145 .61701 .42183 .61573 .43373 .61622 .42644 .61822 Metetra
.139 0 0 r
.42644 .61822 .43373 .61622 .44575 .61529 .43851 .61778 Metetra
.43851 .61778 .44575 .61529 .45787 .61274 .45069 .61548 Metetra
.45069 .61548 .45787 .61274 .47008 .60848 .46297 .61119 Metetra
.421 .854 .735 r
.46297 .61119 .47008 .60848 .48237 .60245 .47533 .60485 Metetra
.614 .953 .807 r
.47533 .60485 .48237 .60245 .49471 .59468 .48775 .5965 Metetra
.756 .995 .844 r
.48775 .5965 .49471 .59468 .50708 .58525 .50021 .58622 Metetra
.842 .992 .851 r
.50021 .58622 .50708 .58525 .51947 .57433 .51268 .5742 Metetra
.885 .963 .841 r
.51268 .5742 .51947 .57433 .53185 .5621 .52515 .56068 Metetra
.9 .924 .825 r
.52515 .56068 .53185 .5621 .54423 .54882 .53759 .54594 Metetra
.899 .882 .808 r
.53759 .54594 .54423 .54882 .55659 .53475 .55001 .53031 Metetra
.889 .843 .793 r
.55001 .53031 .55659 .53475 .56891 .52022 .56239 .51414 Metetra
.874 .807 .781 r
.56239 .51414 .56891 .52022 .58121 .50552 .57472 .49779 Metetra
.855 .773 .771 r
.57472 .49779 .58121 .50552 .59349 .49096 .58703 .48163 Metetra
.834 .743 .763 r
.58703 .48163 .59349 .49096 .60576 .47685 .59931 .466 Metetra
.812 .715 .758 r
.59931 .466 .60576 .47685 .61802 .46347 .61158 .45122 Metetra
.789 .69 .755 r
.61158 .45122 .61802 .46347 .6303 .45108 .62386 .43759 Metetra
.765 .666 .754 r
.62386 .43759 .6303 .45108 .64262 .43988 .63616 .42535 Metetra
.739 .644 .754 r
.63616 .42535 .64262 .43988 .65499 .43006 .64852 .41471 Metetra
.712 .623 .756 r
.64852 .41471 .65499 .43006 .66743 .42176 .66096 .40581 Metetra
.684 .603 .759 r
.66096 .40581 .66743 .42176 .67998 .41505 .67351 .39876 Metetra
.655 .585 .764 r
.67351 .39876 .67998 .41505 .69265 .40997 .68618 .39358 Metetra
.624 .568 .771 r
.68618 .39358 .69265 .40997 .70546 .4065 .699 .39025 Metetra
.591 .552 .779 r
.699 .39025 .70546 .4065 .71843 .40456 .71199 .38867 Metetra
.558 .538 .789 r
.71199 .38867 .71843 .40456 .73156 .40401 .72516 .38869 Metetra
.524 .526 .8 r
.72516 .38869 .73156 .40401 .74486 .40468 .73852 .3901 Metetra
.491 .518 .813 r
.73852 .3901 .74486 .40468 .75833 .40633 .75206 .39263 Metetra
.459 .514 .827 r
.75206 .39263 .75833 .40633 .77197 .40869 .76578 .39597 Metetra
.432 .516 .844 r
.76578 .39597 .77197 .40869 .78576 .41146 .77966 .39978 Metetra
.413 .525 .862 r
.77966 .39978 .78576 .41146 .79968 .41432 .79368 .40368 Metetra
.403 .543 .882 r
.79368 .40368 .79968 .41432 .8137 .41695 .80782 .40732 Metetra
.404 .57 .904 r
.80782 .40732 .8137 .41695 .82779 .41907 .82203 .41039 Metetra
.418 .605 .925 r
.82203 .41039 .82779 .41907 .84193 .42045 .83629 .41263 Metetra
.441 .645 .944 r
.83629 .41263 .84193 .42045 .8561 .42098 .85058 .41392 Metetra
.529 .718 .959 r
.85058 .41392 .8561 .42098 .87029 .42064 .86474 .4129 Metetra
.656 .755 .923 r
.86474 .4129 .87029 .42064 .88416 .41652 .87864 .4086 Metetra
.656 .751 .92 r
.87864 .4086 .88416 .41652 .89808 .41224 .89261 .40428 Metetra
.656 .751 .92 r
.27103 .58769 .27839 .59411 .28964 .59064 .2823 .58418 Metetra
.656 .751 .92 r
.2823 .58418 .28964 .59064 .30093 .58715 .29363 .58066 Metetra
.641 .748 .926 r
.29363 .58066 .30093 .58715 .31216 .58559 .30497 .57752 Metetra
.37 .589 .929 r
.30497 .57752 .31216 .58559 .32325 .58719 .31604 .57983 Metetra
.253 .551 .929 r
.31604 .57983 .32325 .58719 .33438 .58974 .32713 .58317 Metetra
.102 .489 .9 r
.32713 .58317 .33438 .58974 .34555 .59318 .33826 .58748 Metetra
0 .408 .833 r
.33826 .58748 .34555 .59318 .35678 .59731 .34946 .59259 Metetra
0 .325 .736 r
.34946 .59259 .35678 .59731 .36809 .60186 .36074 .59817 Metetra
0 .261 .636 r
.36074 .59817 .36809 .60186 .3795 .60648 .37213 .60385 Metetra
.365 0 0 r
.37213 .60385 .3795 .60648 .39104 .6108 .38365 .60921 Metetra
.37 0 0 r
.38365 .60921 .39104 .6108 .4027 .61443 .39531 .61382 Metetra
.328 0 0 r
.39531 .61382 .4027 .61443 .4145 .61701 .40712 .61728 Metetra
.241 0 0 r
.40712 .61728 .4145 .61701 .42644 .61822 .41909 .6192 Metetra
.104 0 0 r
.41909 .6192 .42644 .61822 .43851 .61778 .43119 .61927 Metetra
.43119 .61927 .43851 .61778 .45069 .61548 .44343 .61725 Metetra
.31 .797 .756 r
.44343 .61725 .45069 .61548 .46297 .61119 .45577 .61298 Metetra
.529 .921 .829 r
.45577 .61298 .46297 .61119 .47533 .60485 .46821 .6064 Metetra
.702 .984 .863 r
.46821 .6064 .47533 .60485 .48775 .5965 .48071 .59753 Metetra
.812 .995 .864 r
.48071 .59753 .48775 .5965 .50021 .58622 .49326 .58648 Metetra
.873 .974 .848 r
.49326 .58648 .50021 .58622 .51268 .5742 .50581 .57347 Metetra
.901 .94 .827 r
.50581 .57347 .51268 .5742 .52515 .56068 .51836 .55876 Metetra
.909 .903 .807 r
.51836 .55876 .52515 .56068 .53759 .54594 .53088 .54268 Metetra
.906 .867 .789 r
.53088 .54268 .53759 .54594 .55001 .53031 .54336 .5256 Metetra
.896 .833 .776 r
.54336 .5256 .55001 .53031 .56239 .51414 .5558 .50792 Metetra
.882 .802 .766 r
.5558 .50792 .56239 .51414 .57472 .49779 .56818 .49006 Metetra
.866 .774 .758 r
.56818 .49006 .57472 .49779 .58703 .48163 .58052 .47241 Metetra
.847 .748 .754 r
.58052 .47241 .58703 .48163 .59931 .466 .59283 .45538 Metetra
.826 .723 .751 r
.59283 .45538 .59931 .466 .61158 .45122 .60511 .43933 Metetra
.803 .7 .751 r
.60511 .43933 .61158 .45122 .62386 .43759 .6174 .42458 Metetra
.778 .678 .753 r
.6174 .42458 .62386 .43759 .63616 .42535 .62971 .41141 Metetra
.752 .656 .756 r
.62971 .41141 .63616 .42535 .64852 .41471 .64207 .40004 Metetra
.723 .636 .76 r
.64207 .40004 .64852 .41471 .66096 .40581 .6545 .39063 Metetra
.692 .616 .766 r
.6545 .39063 .66096 .40581 .67351 .39876 .66705 .3833 Metetra
.658 .596 .774 r
.66705 .3833 .67351 .39876 .68618 .39358 .67973 .37806 Metetra
.622 .577 .782 r
.67973 .37806 .68618 .39358 .699 .39025 .69257 .3749 Metetra
.583 .558 .792 r
.69257 .3749 .699 .39025 .71199 .38867 .70559 .37369 Metetra
.541 .541 .803 r
.70559 .37369 .71199 .38867 .72516 .38869 .7188 .37428 Metetra
.498 .525 .815 r
.7188 .37428 .72516 .38869 .73852 .3901 .73221 .37642 Metetra
.455 .512 .828 r
.73221 .37642 .73852 .3901 .75206 .39263 .74582 .3798 Metetra
.414 .503 .842 r
.74582 .3798 .75206 .39263 .76578 .39597 .75962 .38408 Metetra
.379 .501 .857 r
.75962 .38408 .76578 .39597 .77966 .39978 .77359 .38887 Metetra
.352 .508 .873 r
.77359 .38887 .77966 .39978 .79368 .40368 .78772 .39377 Metetra
.338 .525 .892 r
.78772 .39377 .79368 .40368 .80782 .40732 .80196 .39837 Metetra
.34 .553 .913 r
.80196 .39837 .80782 .40732 .82203 .41039 .81628 .40234 Metetra
.355 .59 .934 r
.81628 .40234 .82203 .41039 .83629 .41263 .83066 .4054 Metetra
.38 .633 .954 r
.83066 .4054 .83629 .41263 .85058 .41392 .84507 .40745 Metetra
.58 .765 .966 r
.84507 .40745 .85058 .41392 .86474 .4129 .85913 .40495 Metetra
.656 .751 .92 r
.85913 .40495 .86474 .4129 .87864 .4086 .87308 .40061 Metetra
.656 .751 .92 r
.87308 .40061 .87864 .4086 .89261 .40428 .8871 .39626 Metetra
.656 .751 .92 r
.2636 .58121 .27103 .58769 .2823 .58418 .27491 .57767 Metetra
.656 .751 .92 r
.27491 .57767 .2823 .58418 .29363 .58066 .28626 .57413 Metetra
.656 .751 .92 r
.28626 .57413 .29363 .58066 .30497 .57752 .29766 .57057 Metetra
.411 .647 .954 r
.29766 .57057 .30497 .57752 .31604 .57983 .30881 .57173 Metetra
.222 .51 .909 r
.30881 .57173 .31604 .57983 .32713 .58317 .31987 .57582 Metetra
.07 .443 .878 r
.31987 .57582 .32713 .58317 .33826 .58748 .33096 .58096 Metetra
0 .36 .812 r
.33096 .58096 .33826 .58748 .34946 .59259 .34212 .58696 Metetra
0 .28 .725 r
.34212 .58696 .34946 .59259 .36074 .59817 .35337 .59351 Metetra
0 .223 .639 r
.35337 .59351 .36074 .59817 .37213 .60385 .36473 .60019 Metetra
.379 0 0 r
.36473 .60019 .37213 .60385 .38365 .60921 .37623 .60655 Metetra
.377 0 0 r
.37623 .60655 .38365 .60921 .39531 .61382 .38788 .61212 Metetra
.326 0 0 r
.38788 .61212 .39531 .61382 .40712 .61728 .39969 .61642 Metetra
.221 0 0 r
.39969 .61642 .40712 .61728 .41909 .6192 .41167 .61905 Metetra
.056 0 0 r
.41167 .61905 .41909 .6192 .43119 .61927 .42381 .61965 Metetra
.166 .705 .779 r
.42381 .61965 .43119 .61927 .44343 .61725 .4361 .61793 Metetra
.41 .861 .862 r
.4361 .61793 .44343 .61725 .45577 .61298 .44851 .61373 Metetra
.619 .957 .9 r
.44851 .61373 .45577 .61298 .46821 .6064 .46102 .60697 Metetra
.763 .988 .896 r
.46102 .60697 .46821 .6064 .48071 .59753 .4736 .59767 Metetra
.846 .978 .87 r
.4736 .59767 .48071 .59753 .49326 .58648 .48623 .58595 Metetra
.889 .95 .84 r
.48623 .58595 .49326 .58648 .50581 .57347 .49887 .57206 Metetra
.908 .917 .813 r
.49887 .57206 .50581 .57347 .51836 .55876 .5115 .55628 Metetra
.913 .884 .791 r
.5115 .55628 .51836 .55876 .53088 .54268 .5241 .53898 Metetra
.91 .853 .774 r
.5241 .53898 .53088 .54268 .54336 .5256 .53665 .52059 Metetra
.901 .824 .762 r
.53665 .52059 .54336 .5256 .5558 .50792 .54915 .50155 Metetra
.889 .798 .753 r
.54915 .50155 .5558 .50792 .56818 .49006 .56159 .48231 Metetra
.874 .774 .748 r
.56159 .48231 .56818 .49006 .58052 .47241 .57397 .46334 Metetra
.857 .752 .746 r
.57397 .46334 .58052 .47241 .59283 .45538 .58631 .44505 Metetra
.838 .73 .746 r
.58631 .44505 .59283 .45538 .60511 .43933 .59862 .42786 Metetra
.816 .71 .748 r
.59862 .42786 .60511 .43933 .6174 .42458 .61092 .41211 Metetra
.791 .69 .752 r
.61092 .41211 .6174 .42458 .62971 .41141 .62324 .39812 Metetra
.764 .67 .758 r
.62324 .39812 .62971 .41141 .64207 .40004 .63561 .38612 Metetra
.734 .65 .766 r
.63561 .38612 .64207 .40004 .6545 .39063 .64806 .37629 Metetra
.7 .63 .775 r
.64806 .37629 .6545 .39063 .66705 .3833 .66061 .36874 Metetra
.662 .609 .785 r
.66061 .36874 .66705 .3833 .67973 .37806 .67331 .3635 Metetra
.619 .588 .796 r
.67331 .3635 .67973 .37806 .69257 .3749 .68617 .36053 Metetra
.572 .566 .808 r
.68617 .36053 .69257 .3749 .70559 .37369 .69922 .35972 Metetra
.521 .544 .82 r
.69922 .35972 .70559 .37369 .7188 .37428 .71247 .36087 Metetra
.466 .523 .832 r
.71247 .36087 .7188 .37428 .73221 .37642 .72593 .36371 Metetra
.411 .504 .844 r
.72593 .36371 .73221 .37642 .74582 .3798 .73961 .36792 Metetra
.358 .49 .855 r
.73961 .36792 .74582 .3798 .75962 .38408 .75349 .37309 Metetra
.312 .483 .867 r
.75349 .37309 .75962 .38408 .77359 .38887 .76755 .37882 Metetra
.278 .486 .88 r
.76755 .37882 .77359 .38887 .78772 .39377 .78177 .38465 Metetra
.261 .501 .896 r
.78177 .38465 .78772 .39377 .80196 .39837 .79612 .39016 Metetra
.262 .529 .915 r
.79612 .39016 .80196 .39837 .81628 .40234 .81055 .39498 Metetra
.279 .569 .936 r
.81055 .39498 .81628 .40234 .83066 .4054 .82505 .39883 Metetra
.327 .627 .959 r
.82505 .39883 .83066 .4054 .84507 .40745 .83954 .40128 Metetra
.648 .806 .959 r
.83954 .40128 .84507 .40745 .85913 .40495 .85347 .39693 Metetra
.656 .751 .92 r
.85347 .39693 .85913 .40495 .87308 .40061 .86747 .39256 Metetra
.656 .751 .92 r
.86747 .39256 .87308 .40061 .8871 .39626 .88154 .38816 Metetra
.656 .751 .92 r
.25612 .57467 .2636 .58121 .27491 .57767 .26745 .57111 Metetra
.656 .751 .92 r
.26745 .57111 .27491 .57767 .28626 .57413 .27884 .56754 Metetra
.656 .751 .92 r
.27884 .56754 .28626 .57413 .29766 .57057 .29027 .56395 Metetra
.545 .717 .952 r
.29027 .56395 .29766 .57057 .30881 .57173 .30158 .56286 Metetra
.198 .473 .89 r
.30158 .56286 .30881 .57173 .31987 .57582 .3126 .56765 Metetra
.049 .403 .857 r
.3126 .56765 .31987 .57582 .33096 .58096 .32365 .57355 Metetra
0 .32 .795 r
.32365 .57355 .33096 .58096 .34212 .58696 .33477 .58039 Metetra
0 .244 .718 r
.33477 .58039 .34212 .58696 .35337 .59351 .34598 .58784 Metetra
0 .193 .646 r
.34598 .58784 .35337 .59351 .36473 .60019 .3573 .59545 Metetra
0 .178 .598 r
.3573 .59545 .36473 .60019 .37623 .60655 .36878 .60275 Metetra
.371 0 0 r
.36878 .60275 .37623 .60655 .38788 .61212 .38041 .60922 Metetra
.31 0 0 r
.38041 .60922 .38788 .61212 .39969 .61642 .39222 .61434 Metetra
0 .403 .682 r
.39222 .61434 .39969 .61642 .41167 .61905 .40421 .61767 Metetra
.003 .571 .783 r
.40421 .61767 .41167 .61905 .42381 .61965 .41638 .6188 Metetra
.248 .754 .883 r
.41638 .6188 .42381 .61965 .4361 .61793 .42871 .61743 Metetra
.494 .894 .94 r
.42871 .61743 .4361 .61793 .44851 .61373 .44117 .61335 Metetra
.682 .961 .941 r
.44117 .61335 .44851 .61373 .46102 .60697 .45375 .60647 Metetra
.799 .971 .909 r
.45375 .60647 .46102 .60697 .4736 .59767 .46641 .59683 Metetra
.863 .952 .868 r
.46641 .59683 .4736 .59767 .48623 .58595 .47912 .58456 Metetra
.896 .924 .831 r
.47912 .58456 .48623 .58595 .49887 .57206 .49185 .5699 Metetra
.91 .894 .801 r
.49185 .5699 .49887 .57206 .5115 .55628 .50456 .55318 Metetra
.914 .865 .778 r
.50456 .55318 .5115 .55628 .5241 .53898 .51725 .53482 Metetra
.911 .839 .761 r
.51725 .53482 .5241 .53898 .53665 .52059 .52988 .51527 Metetra
.904 .816 .75 r
.52988 .51527 .53665 .52059 .54915 .50155 .54245 .49502 Metetra
.894 .794 .743 r
.54245 .49502 .54915 .50155 .56159 .48231 .55494 .47457 Metetra
.881 .774 .74 r
.55494 .47457 .56159 .48231 .57397 .46334 .56738 .45442 Metetra
.866 .756 .739 r
.56738 .45442 .57397 .46334 .58631 .44505 .57976 .43502 Metetra
.848 .737 .741 r
.57976 .43502 .58631 .44505 .59862 .42786 .5921 .41683 Metetra
.827 .72 .746 r
.5921 .41683 .59862 .42786 .61092 .41211 .60443 .40023 Metetra
.804 .702 .753 r
.60443 .40023 .61092 .41211 .62324 .39812 .61677 .38553 Metetra
.776 .684 .762 r
.61677 .38553 .62324 .39812 .63561 .38612 .62916 .373 Metetra
.745 .665 .773 r
.62916 .373 .63561 .38612 .64806 .37629 .64162 .36284 Metetra
.708 .645 .785 r
.64162 .36284 .64806 .37629 .66061 .36874 .65419 .35515 Metetra
.665 .624 .799 r
.65419 .35515 .66061 .36874 .67331 .3635 .66691 .34996 Metetra
.615 .601 .813 r
.66691 .34996 .67331 .3635 .68617 .36053 .6798 .34723 Metetra
.559 .575 .827 r
.6798 .34723 .68617 .36053 .69922 .35972 .69288 .34682 Metetra
.495 .548 .84 r
.69288 .34682 .69922 .35972 .71247 .36087 .70618 .34853 Metetra
.427 .521 .851 r
.70618 .34853 .71247 .36087 .72593 .36371 .71969 .35205 Metetra
.356 .494 .86 r
.71969 .35205 .72593 .36371 .73961 .36792 .73344 .35704 Metetra
.289 .472 .866 r
.73344 .35704 .73961 .36792 .75349 .37309 .74739 .36307 Metetra
.231 .458 .872 r
.74739 .36307 .75349 .37309 .76755 .37882 .76154 .36967 Metetra
.19 .456 .879 r
.76154 .36967 .76755 .37882 .78177 .38465 .77585 .37638 Metetra
.169 .469 .891 r
.77585 .37638 .78177 .38465 .79612 .39016 .7903 .38273 Metetra
.17 .497 .907 r
.7903 .38273 .79612 .39016 .81055 .39498 .80484 .38835 Metetra
.189 .539 .926 r
.80484 .38835 .81055 .39498 .82505 .39883 .81945 .39296 Metetra
.422 .709 .983 r
.81945 .39296 .82505 .39883 .83954 .40128 .83379 .39323 Metetra
.656 .751 .92 r
.83379 .39323 .83954 .40128 .85347 .39693 .84777 .38884 Metetra
.656 .751 .92 r
.84777 .38884 .85347 .39693 .86747 .39256 .86181 .38443 Metetra
.656 .751 .92 r
.86181 .38443 .86747 .39256 .88154 .38816 .87592 .38 Metetra
.656 .751 .92 r
.24858 .56809 .25612 .57467 .26745 .57111 .25994 .5645 Metetra
.656 .751 .92 r
.25994 .5645 .26745 .57111 .27884 .56754 .27135 .5609 Metetra
.656 .751 .92 r
.27135 .5609 .27884 .56754 .29027 .56395 .28281 .55728 Metetra
.656 .751 .92 r
.28281 .55728 .29027 .56395 .30158 .56286 .29433 .55364 Metetra
.194 .462 .883 r
.29433 .55364 .30158 .56286 .3126 .56765 .30533 .55863 Metetra
.035 .369 .838 r
.30533 .55863 .3126 .56765 .32365 .57355 .31634 .56524 Metetra
0 .289 .781 r
.31634 .56524 .32365 .57355 .33477 .58039 .32741 .57284 Metetra
0 .217 .713 r
.32741 .57284 .33477 .58039 .34598 .58784 .33858 .5811 Metetra
0 .171 .654 r
.33858 .5811 .34598 .58784 .3573 .59545 .34986 .58957 Metetra
0 .162 .621 r
.34986 .58957 .3573 .59545 .36878 .60275 .3613 .59774 Metetra
0 .197 .625 r
.3613 .59774 .36878 .60275 .38041 .60922 .37292 .60506 Metetra
0 .281 .67 r
.37292 .60506 .38041 .60922 .39222 .61434 .38472 .61097 Metetra
0 .417 .757 r
.38472 .61097 .39222 .61434 .40421 .61767 .39672 .61497 Metetra
.066 .596 .866 r
.39672 .61497 .40421 .61767 .41638 .6188 .4089 .61665 Metetra
.321 .773 .955 r
.4089 .61665 .41638 .6188 .42871 .61743 .42126 .61564 Metetra
.555 .893 .983 r
.42126 .61564 .42871 .61743 .44117 .61335 .43378 .61174 Metetra
.719 .941 .957 r
.43378 .61174 .44117 .61335 .45375 .60647 .44642 .60483 Metetra
.816 .942 .908 r
.44642 .60483 .45375 .60647 .46641 .59683 .45915 .59494 Metetra
.869 .922 .86 r
.45915 .59494 .46641 .59683 .47912 .58456 .47194 .58222 Metetra
.896 .897 .82 r
.47194 .58222 .47912 .58456 .49185 .5699 .48476 .56693 Metetra
.908 .872 .79 r
.48476 .56693 .49185 .5699 .50456 .55318 .49756 .54943 Metetra
.912 .849 .767 r
.49756 .54943 .50456 .55318 .51725 .53482 .51033 .53016 Metetra
.911 .827 .751 r
.51033 .53016 .51725 .53482 .52988 .51527 .52304 .50962 Metetra
.905 .808 .741 r
.52304 .50962 .52988 .51527 .54245 .49502 .53568 .48833 Metetra
.897 .791 .735 r
.53568 .48833 .54245 .49502 .55494 .47457 .54824 .46683 Metetra
.886 .775 .733 r
.54824 .46683 .55494 .47457 .56738 .45442 .56074 .44566 Metetra
.873 .759 .734 r
.56074 .44566 .56738 .45442 .57976 .43502 .57317 .42533 Metetra
.857 .745 .738 r
.57317 .42533 .57976 .43502 .5921 .41683 .58555 .40629 Metetra
.838 .73 .745 r
.58555 .40629 .5921 .41683 .60443 .40023 .59791 .38896 Metetra
.815 .715 .754 r
.59791 .38896 .60443 .40023 .61677 .38553 .61029 .37369 Metetra
.788 .699 .766 r
.61029 .37369 .61677 .38553 .62916 .373 .6227 .36075 Metetra
.755 .682 .781 r
.6227 .36075 .62916 .373 .64162 .36284 .63519 .35034 Metetra
.715 .663 .797 r
.63519 .35034 .64162 .36284 .65419 .35515 .64779 .34258 Metetra
.667 .641 .815 r
.64779 .34258 .65419 .35515 .66691 .34996 .66053 .33749 Metetra
.61 .616 .832 r
.66053 .33749 .66691 .34996 .6798 .34723 .67345 .33502 Metetra
.541 .586 .849 r
.67345 .33502 .6798 .34723 .69288 .34682 .68657 .33503 Metetra
.462 .553 .862 r
.68657 .33503 .69288 .34682 .70618 .34853 .69991 .33729 Metetra
.376 .516 .87 r
.69991 .33729 .70618 .34853 .71969 .35205 .71349 .34148 Metetra
.287 .479 .873 r
.71349 .34148 .71969 .35205 .73344 .35704 .72729 .34721 Metetra
.203 .446 .87 r
.72729 .34721 .73344 .35704 .74739 .36307 .74132 .35404 Metetra
.134 .423 .866 r
.74132 .35404 .74739 .36307 .76154 .36967 .75555 .36146 Metetra
.085 .415 .864 r
.75555 .36146 .76154 .36967 .77585 .37638 .76996 .36898 Metetra
.062 .426 .869 r
.76996 .36898 .77585 .37638 .7903 .38273 .7845 .37611 Metetra
.065 .455 .882 r
.7845 .37611 .7903 .38273 .80484 .38835 .79915 .38247 Metetra
.087 .497 .9 r
.79915 .38247 .80484 .38835 .81945 .39296 .81386 .3878 Metetra
.556 .806 .992 r
.81386 .3878 .81945 .39296 .83379 .39323 .82798 .38511 Metetra
.656 .751 .92 r
.82798 .38511 .83379 .39323 .84777 .38884 .842 .38068 Metetra
.656 .751 .92 r
.842 .38068 .84777 .38884 .86181 .38443 .8561 .37623 Metetra
.656 .751 .92 r
.8561 .37623 .86181 .38443 .87592 .38 .87026 .37176 Metetra
.656 .751 .92 r
.24097 .56145 .24858 .56809 .25994 .5645 .25236 .55784 Metetra
.656 .751 .92 r
.25236 .55784 .25994 .5645 .27135 .5609 .26381 .5542 Metetra
.656 .751 .92 r
.26381 .5542 .27135 .5609 .28281 .55728 .2753 .55055 Metetra
.656 .751 .92 r
.2753 .55055 .28281 .55728 .29433 .55364 .28684 .54689 Metetra
.334 .622 .956 r
.28684 .54689 .29433 .55364 .30533 .55863 .29806 .54877 Metetra
.028 .342 .821 r
.29806 .54877 .30533 .55863 .31634 .56524 .30902 .55601 Metetra
0 .264 .769 r
.30902 .55601 .31634 .56524 .32741 .57284 .32005 .56429 Metetra
0 .196 .71 r
.32005 .56429 .32741 .57284 .33858 .5811 .33117 .57328 Metetra
0 .155 .662 r
.33117 .57328 .33858 .5811 .34986 .58957 .34242 .58253 Metetra
0 .151 .642 r
.34242 .58253 .34986 .58957 .3613 .59774 .35382 .5915 Metetra
0 .191 .658 r
.35382 .5915 .3613 .59774 .37292 .60506 .36541 .59959 Metetra
0 .281 .716 r
.36541 .59959 .37292 .60506 .38472 .61097 .3772 .60625 Metetra
0 .422 .811 r
.3772 .60625 .38472 .61097 .39672 .61497 .38919 .61091 Metetra
.125 .6 .918 r
.38919 .61091 .39672 .61497 .4089 .61665 .40139 .61313 Metetra
.376 .765 .988 r
.40139 .61313 .4089 .61665 .42126 .61564 .41378 .61252 Metetra
.59 .868 .994 r
.41378 .61252 .42126 .61564 .43378 .61174 .42634 .60884 Metetra
.735 .906 .954 r
.42634 .60884 .43378 .61174 .44642 .60483 .43903 .60197 Metetra
.82 .907 .9 r
.43903 .60197 .44642 .60483 .45915 .59494 .45183 .59194 Metetra
.867 .891 .851 r
.45183 .59194 .45915 .59494 .47194 .58222 .4647 .5789 Metetra
.892 .872 .811 r
.4647 .5789 .47194 .58222 .48476 .56693 .4776 .56312 Metetra
.904 .852 .781 r
.4776 .56312 .48476 .56693 .49756 .54943 .49049 .54499 Metetra
.909 .833 .759 r
.49049 .54499 .49756 .54943 .51033 .53016 .50334 .52498 Metetra
.909 .816 .743 r
.50334 .52498 .51033 .53016 .52304 .50962 .51613 .50361 Metetra
.906 .801 .734 r
.51613 .50361 .52304 .50962 .53568 .48833 .52885 .48146 Metetra
.9 .788 .728 r
.52885 .48146 .53568 .48833 .54824 .46683 .54149 .4591 Metetra
.891 .775 .727 r
.54149 .4591 .54824 .46683 .56074 .44566 .55405 .43709 Metetra
.879 .763 .73 r
.55405 .43709 .56074 .44566 .57317 .42533 .56653 .41598 Metetra
.865 .751 .735 r
.56653 .41598 .57317 .42533 .58555 .40629 .57897 .39625 Metetra
.848 .74 .744 r
.57897 .39625 .58555 .40629 .59791 .38896 .59137 .37835 Metetra
.826 .728 .757 r
.59137 .37835 .59791 .38896 .61029 .37369 .60379 .36263 Metetra
.799 .715 .772 r
.60379 .36263 .61029 .37369 .6227 .36075 .61623 .34938 Metetra
.765 .7 .79 r
.61623 .34938 .6227 .36075 .63519 .35034 .62875 .33882 Metetra
.722 .683 .811 r
.62875 .33882 .63519 .35034 .64779 .34258 .64138 .33106 Metetra
.668 .661 .833 r
.64138 .33106 .64779 .34258 .66053 .33749 .65416 .32613 Metetra
.601 .633 .855 r
.65416 .32613 .66053 .33749 .67345 .33502 .66712 .32396 Metetra
.518 .598 .874 r
.66712 .32396 .67345 .33502 .68657 .33503 .68028 .3244 Metetra
.42 .556 .885 r
.68028 .3244 .68657 .33503 .69991 .33729 .69367 .3272 Metetra
.311 .507 .887 r
.69367 .3272 .69991 .33729 .71349 .34148 .7073 .33202 Metetra
.201 .456 .877 r
.7073 .33202 .71349 .34148 .72729 .34721 .72117 .33846 Metetra
.1 .41 .86 r
.72117 .33846 .72729 .34721 .74132 .35404 .73528 .34602 Metetra
.02 .378 .842 r
.73528 .34602 .74132 .35404 .75555 .36146 .74959 .3542 Metetra
0 .364 .83 r
.74959 .3542 .75555 .36146 .76996 .36898 .76408 .36246 Metetra
0 .372 .828 r
.76408 .36246 .76996 .36898 .7845 .37611 .77872 .37032 Metetra
0 .401 .838 r
.77872 .37032 .7845 .37611 .79915 .38247 .79346 .37736 Metetra
.121 .551 .919 r
.79346 .37736 .79915 .38247 .81386 .3878 .80811 .38136 Metetra
.649 .802 .956 r
.80811 .38136 .81386 .3878 .82798 .38511 .82212 .37692 Metetra
.656 .751 .92 r
.82212 .37692 .82798 .38511 .842 .38068 .83619 .37245 Metetra
.656 .751 .92 r
.83619 .37245 .842 .38068 .8561 .37623 .85034 .36795 Metetra
.656 .751 .92 r
.85034 .36795 .8561 .37623 .87026 .37176 .86455 .36344 Metetra
.656 .751 .92 r
.23331 .55476 .24097 .56145 .25236 .55784 .24473 .55112 Metetra
.656 .751 .92 r
.24473 .55112 .25236 .55784 .26381 .5542 .2562 .54745 Metetra
.656 .751 .92 r
.2562 .54745 .26381 .5542 .2753 .55055 .26772 .54377 Metetra
.656 .751 .92 r
.26772 .54377 .2753 .55055 .28684 .54689 .27929 .54008 Metetra
.586 .731 .943 r
.27929 .54008 .28684 .54689 .29806 .54877 .2908 .53808 Metetra
.026 .319 .806 r
.2908 .53808 .29806 .54877 .30902 .55601 .30172 .54588 Metetra
0 .245 .759 r
.30172 .54588 .30902 .55601 .32005 .56429 .3127 .55475 Metetra
0 .182 .707 r
.3127 .55475 .32005 .56429 .33117 .57328 .32377 .56439 Metetra
0 .145 .669 r
.32377 .56439 .33117 .57328 .34242 .58253 .33497 .57432 Metetra
0 .144 .658 r
.33497 .57432 .34242 .58253 .35382 .5915 .34634 .584 Metetra
0 .187 .683 r
.34634 .584 .35382 .5915 .36541 .59959 .35789 .59281 Metetra
0 .279 .747 r
.35789 .59281 .36541 .59959 .3772 .60625 .36966 .60015 Metetra
0 .419 .842 r
.36966 .60015 .3772 .60625 .38919 .61091 .38164 .60545 Metetra
.175 .587 .939 r
.38164 .60545 .38919 .61091 .40139 .61313 .39385 .6082 Metetra
.411 .736 .992 r
.39385 .6082 .40139 .61313 .41378 .61252 .40626 .60801 Metetra
.606 .829 .985 r
.40626 .60801 .41378 .61252 .42634 .60884 .41885 .60461 Metetra
.737 .866 .941 r
.41885 .60461 .42634 .60884 .43903 .60197 .4316 .59787 Metetra
.815 .87 .888 r
.4316 .59787 .43903 .60197 .45183 .59194 .44446 .5878 Metetra
.86 .861 .84 r
.44446 .5878 .45183 .59194 .4647 .5789 .4574 .57455 Metetra
.885 .847 .802 r
.4574 .57455 .4647 .5789 .4776 .56312 .47038 .55843 Metetra
.898 .833 .773 r
.47038 .55843 .4776 .56312 .49049 .54499 .48335 .53983 Metetra
.905 .819 .752 r
.48335 .53983 .49049 .54499 .50334 .52498 .49629 .51925 Metetra
.907 .806 .737 r
.49629 .51925 .50334 .52498 .51613 .50361 .50917 .49724 Metetra
.905 .795 .728 r
.50917 .49724 .51613 .50361 .52885 .48146 .52197 .47441 Metetra
.901 .785 .724 r
.52197 .47441 .52885 .48146 .54149 .4591 .53468 .45137 Metetra
.894 .775 .723 r
.53468 .45137 .54149 .4591 .55405 .43709 .54731 .4287 Metetra
.885 .767 .727 r
.54731 .4287 .55405 .43709 .56653 .41598 .55986 .40698 Metetra
.872 .758 .734 r
.55986 .40698 .56653 .41598 .57897 .39625 .57235 .38673 Metetra
.856 .75 .745 r
.57235 .38673 .57897 .39625 .59137 .37835 .58481 .36839 Metetra
.836 .741 .76 r
.58481 .36839 .59137 .37835 .60379 .36263 .59726 .35236 Metetra
.809 .732 .779 r
.59726 .35236 .60379 .36263 .61623 .34938 .60975 .33892 Metetra
.774 .72 .801 r
.60975 .33892 .61623 .34938 .62875 .33882 .62231 .3283 Metetra
.728 .704 .827 r
.62231 .3283 .62875 .33882 .64138 .33106 .63498 .32061 Metetra
.668 .683 .855 r
.63498 .32061 .64138 .33106 .65416 .32613 .6478 .31589 Metetra
.588 .652 .881 r
.6478 .31589 .65416 .32613 .66712 .32396 .6608 .31405 Metetra
.486 .61 .9 r
.6608 .31405 .66712 .32396 .68028 .3244 .67401 .31492 Metetra
.364 .555 .907 r
.67401 .31492 .68028 .3244 .69367 .3272 .68745 .31826 Metetra
.228 .49 .895 r
.68745 .31826 .69367 .3272 .7073 .33202 .70114 .32369 Metetra
.095 .421 .867 r
.70114 .32369 .7073 .33202 .72117 .33846 .71508 .33078 Metetra
0 .362 .831 r
.71508 .33078 .72117 .33846 .73528 .34602 .72925 .33903 Metetra
0 .32 .797 r
.72925 .33903 .73528 .34602 .74959 .3542 .74364 .3479 Metetra
0 .303 .774 r
.74364 .3479 .74959 .3542 .76408 .36246 .75821 .35683 Metetra
0 .31 .767 r
.75821 .35683 .76408 .36246 .77872 .37032 .77294 .36534 Metetra
0 .339 .775 r
.77294 .36534 .77872 .37032 .79346 .37736 .78778 .37301 Metetra
.349 .729 .986 r
.78778 .37301 .79346 .37736 .80811 .38136 .80215 .37313 Metetra
.656 .751 .92 r
.80215 .37313 .80811 .38136 .82212 .37692 .8162 .36865 Metetra
.656 .751 .92 r
.8162 .36865 .82212 .37692 .83619 .37245 .83033 .36414 Metetra
.656 .751 .92 r
.83033 .36414 .83619 .37245 .85034 .36795 .84452 .35961 Metetra
.656 .751 .92 r
.84452 .35961 .85034 .36795 .86455 .36344 .85879 .35505 Metetra
.656 .751 .92 r
.22558 .54802 .23331 .55476 .24473 .55112 .23703 .54434 Metetra
.656 .751 .92 r
.23703 .54434 .24473 .55112 .2562 .54745 .24853 .54065 Metetra
.656 .751 .92 r
.24853 .54065 .2562 .54745 .26772 .54377 .26008 .53694 Metetra
.656 .751 .92 r
.26008 .53694 .26772 .54377 .27929 .54008 .27169 .53321 Metetra
.656 .751 .92 r
.27169 .53321 .27929 .54008 .2908 .53808 .28334 .52947 Metetra
.103 .431 .873 r
.28334 .52947 .2908 .53808 .30172 .54588 .29442 .53489 Metetra
0 .231 .75 r
.29442 .53489 .30172 .54588 .3127 .55475 .30535 .54426 Metetra
0 .172 .706 r
.30535 .54426 .3127 .55475 .32377 .56439 .31638 .55444 Metetra
0 .138 .675 r
.31638 .55444 .32377 .56439 .33497 .57432 .32753 .56496 Metetra
0 .14 .67 r
.32753 .56496 .33497 .57432 .34634 .584 .33886 .57527 Metetra
0 .184 .7 r
.33886 .57527 .34634 .584 .35789 .59281 .35037 .58472 Metetra
0 .275 .765 r
.35037 .58472 .35789 .59281 .36966 .60015 .36211 .5927 Metetra
.003 .408 .854 r
.36211 .5927 .36966 .60015 .38164 .60545 .37408 .59859 Metetra
.213 .563 .937 r
.37408 .59859 .38164 .60545 .39385 .6082 .38629 .60187 Metetra
.431 .699 .977 r
.38629 .60187 .39385 .6082 .40626 .60801 .39871 .60212 Metetra
.609 .785 .965 r
.39871 .60212 .40626 .60801 .41885 .60461 .41134 .59904 Metetra
.73 .824 .923 r
.41134 .59904 .41885 .60461 .4316 .59787 .42412 .59249 Metetra
.805 .835 .874 r
.42412 .59249 .4316 .59787 .44446 .5878 .43704 .58248 Metetra
.849 .833 .83 r
.43704 .58248 .44446 .5878 .4574 .57455 .45005 .56917 Metetra
.876 .825 .794 r
.45005 .56917 .4574 .57455 .47038 .55843 .4631 .55285 Metetra
.891 .815 .767 r
.4631 .55285 .47038 .55843 .48335 .53983 .47615 .53394 Metetra
.9 .806 .747 r
.47615 .53394 .48335 .53983 .49629 .51925 .48917 .51297 Metetra
.903 .797 .733 r
.48917 .51297 .49629 .51925 .50917 .49724 .50214 .49051 Metetra
.904 .789 .724 r
.50214 .49051 .50917 .49724 .52197 .47441 .51502 .46719 Metetra
.901 .782 .72 r
.51502 .46719 .52197 .47441 .53468 .45137 .52781 .44364 Metetra
.896 .776 .721 r
.52781 .44364 .53468 .45137 .54731 .4287 .54051 .4205 Metetra
.889 .771 .725 r
.54051 .4205 .54731 .4287 .55986 .40698 .55313 .39835 Metetra
.878 .765 .734 r
.55313 .39835 .55986 .40698 .57235 .38673 .56569 .37773 Metetra
.864 .761 .747 r
.56569 .37773 .57235 .38673 .58481 .36839 .5782 .35911 Metetra
.845 .755 .764 r
.5782 .35911 .58481 .36839 .59726 .35236 .59071 .34289 Metetra
.819 .749 .787 r
.59071 .34289 .59726 .35236 .60975 .33892 .60325 .32938 Metetra
.783 .741 .814 r
.60325 .32938 .60975 .33892 .62231 .3283 .61586 .31879 Metetra
.733 .728 .846 r
.61586 .31879 .62231 .3283 .63498 .32061 .62858 .31125 Metetra
.664 .707 .879 r
.62858 .31125 .63498 .32061 .6478 .31589 .64144 .30677 Metetra
.569 .673 .909 r
.64144 .30677 .6478 .31589 .6608 .31405 .65449 .30528 Metetra
.443 .621 .927 r
.65449 .30528 .6608 .31405 .67401 .31492 .66775 .30661 Metetra
.29 .548 .922 r
.66775 .30661 .67401 .31492 .68745 .31826 .68124 .31046 Metetra
.126 .461 .889 r
.68124 .31046 .68745 .31826 .70114 .32369 .69499 .31647 Metetra
0 .373 .835 r
.69499 .31647 .70114 .32369 .71508 .33078 .70899 .32417 Metetra
0 .301 .777 r
.70899 .32417 .71508 .33078 .72925 .33903 .72323 .33304 Metetra
0 .254 .729 r
.72323 .33304 .72925 .33903 .74364 .3479 .73769 .34253 Metetra
0 .236 .7 r
.73769 .34253 .74364 .3479 .75821 .35683 .75235 .35206 Metetra
0 .244 .691 r
.75235 .35206 .75821 .35683 .77294 .36534 .76717 .36114 Metetra
0 .277 .701 r
.76717 .36114 .77294 .36534 .78778 .37301 .7821 .36934 Metetra
.6 .881 .992 r
.7821 .36934 .78778 .37301 .80215 .37313 .79613 .36483 Metetra
.656 .751 .92 r
.79613 .36483 .80215 .37313 .8162 .36865 .81024 .3603 Metetra
.656 .751 .92 r
.81024 .3603 .8162 .36865 .83033 .36414 .82441 .35575 Metetra
.656 .751 .92 r
.82441 .35575 .83033 .36414 .84452 .35961 .83866 .35118 Metetra
.656 .751 .92 r
.83866 .35118 .84452 .35961 .85879 .35505 .85297 .34658 Metetra
.656 .751 .92 r
.21779 .54122 .22558 .54802 .23703 .54434 .22927 .53751 Metetra
.656 .751 .92 r
.22927 .53751 .23703 .54434 .24853 .54065 .2408 .53379 Metetra
.656 .751 .92 r
.2408 .53379 .24853 .54065 .26008 .53694 .25238 .53005 Metetra
.656 .751 .92 r
.25238 .53005 .26008 .53694 .27169 .53321 .26402 .52629 Metetra
.656 .751 .92 r
.26402 .52629 .27169 .53321 .28334 .52947 .2757 .52252 Metetra
.434 .67 .962 r
.2757 .52252 .28334 .52947 .29442 .53489 .28713 .52308 Metetra
0 .221 .743 r
.28713 .52308 .29442 .53489 .30535 .54426 .29802 .53287 Metetra
0 .166 .704 r
.29802 .53287 .30535 .54426 .31638 .55444 .309 .5435 Metetra
0 .136 .679 r
.309 .5435 .31638 .55444 .32753 .56496 .32011 .55451 Metetra
0 .139 .679 r
.32011 .55451 .32753 .56496 .33886 .57527 .33138 .56534 Metetra
0 .183 .71 r
.33138 .56534 .33886 .57527 .35037 .58472 .34286 .57535 Metetra
0 .27 .772 r
.34286 .57535 .35037 .58472 .36211 .5927 .35457 .58389 Metetra
.042 .394 .852 r
.35457 .58389 .36211 .5927 .37408 .59859 .36652 .59034 Metetra
.24 .536 .922 r
.36652 .59034 .37408 .59859 .38629 .60187 .37872 .59414 Metetra
.441 .66 .954 r
.37872 .59414 .38629 .60187 .39871 .60212 .39115 .59483 Metetra
.605 .742 .942 r
.39115 .59483 .39871 .60212 .41134 .59904 .40379 .59212 Metetra
.719 .785 .904 r
.40379 .59212 .41134 .59904 .42412 .59249 .41662 .58584 Metetra
.792 .802 .861 r
.41662 .58584 .42412 .59249 .43704 .58248 .42958 .57599 Metetra
.837 .806 .821 r
.42958 .57599 .43704 .58248 .45005 .56917 .44265 .56273 Metetra
.866 .804 .788 r
.44265 .56273 .45005 .56917 .4631 .55285 .45577 .54636 Metetra
.883 .799 .762 r
.45577 .54636 .4631 .55285 .47615 .53394 .4689 .52732 Metetra
.894 .794 .743 r
.4689 .52732 .47615 .53394 .48917 .51297 .482 .50613 Metetra
.899 .789 .73 r
.482 .50613 .48917 .51297 .50214 .49051 .49504 .4834 Metetra
.902 .784 .722 r
.49504 .4834 .50214 .49051 .51502 .46719 .50801 .45978 Metetra
.901 .78 .718 r
.50801 .45978 .51502 .46719 .52781 .44364 .52088 .43593 Metetra
.898 .777 .719 r
.52088 .43593 .52781 .44364 .54051 .4205 .53366 .41249 Metetra
.892 .774 .725 r
.53366 .41249 .54051 .4205 .55313 .39835 .54636 .39008 Metetra
.883 .772 .735 r
.54636 .39008 .55313 .39835 .56569 .37773 .55898 .36926 Metetra
.871 .771 .749 r
.55898 .36926 .56569 .37773 .5782 .35911 .57156 .3505 Metetra
.853 .77 .77 r
.57156 .3505 .5782 .35911 .59071 .34289 .58413 .33423 Metetra
.827 .767 .796 r
.58413 .33423 .59071 .34289 .60325 .32938 .59673 .32074 Metetra
.79 .763 .828 r
.59673 .32074 .60325 .32938 .61586 .31879 .60939 .31027 Metetra
.736 .753 .866 r
.60939 .31027 .61586 .31879 .62858 .31125 .62216 .30294 Metetra
.656 .733 .906 r
.62216 .30294 .62858 .31125 .64144 .30677 .63507 .29876 Metetra
.541 .694 .939 r
.63507 .29876 .64144 .30677 .65449 .30528 .64817 .29766 Metetra
.385 .627 .949 r
.64817 .29766 .65449 .30528 .66775 .30661 .66148 .29943 Metetra
.197 .53 .922 r
.66148 .29943 .66775 .30661 .68124 .31046 .67504 .30378 Metetra
.007 .417 .858 r
.67504 .30378 .68124 .31046 .69499 .31647 .68884 .31033 Metetra
0 .312 .776 r
.68884 .31033 .69499 .31647 .70899 .32417 .70291 .31859 Metetra
0 .233 .701 r
.70291 .31859 .70899 .32417 .72323 .33304 .71721 .32802 Metetra
0 .186 .646 r
.71721 .32802 .72323 .33304 .73769 .34253 .73175 .33805 Metetra
0 .17 .616 r
.73175 .33805 .73769 .34253 .75235 .35206 .74649 .34811 Metetra
0 .182 .609 r
.74649 .34811 .75235 .35206 .76717 .36114 .76138 .35769 Metetra
.028 .543 .868 r
.76138 .35769 .76717 .36114 .7821 .36934 .77598 .361 Metetra
.656 .751 .92 r
.77598 .361 .7821 .36934 .79613 .36483 .79006 .35645 Metetra
.656 .751 .92 r
.79006 .35645 .79613 .36483 .81024 .3603 .80422 .35189 Metetra
.656 .751 .92 r
.80422 .35189 .81024 .3603 .82441 .35575 .81844 .34729 Metetra
.656 .751 .92 r
.81844 .34729 .82441 .35575 .83866 .35118 .83273 .34268 Metetra
.656 .751 .92 r
.83273 .34268 .83866 .35118 .85297 .34658 .8471 .33804 Metetra
.656 .751 .92 r
.20993 .53436 .21779 .54122 .22927 .53751 .22144 .53063 Metetra
.656 .751 .92 r
.22144 .53063 .22927 .53751 .2408 .53379 .233 .52687 Metetra
.656 .751 .92 r
.233 .52687 .2408 .53379 .25238 .53005 .24462 .5231 Metetra
.656 .751 .92 r
.24462 .5231 .25238 .53005 .26402 .52629 .25628 .51931 Metetra
.656 .751 .92 r
.25628 .51931 .26402 .52629 .2757 .52252 .268 .51551 Metetra
.656 .751 .92 r
.268 .51551 .2757 .52252 .28713 .52308 .27977 .51169 Metetra
0 .257 .767 r
.27977 .51169 .28713 .52308 .29802 .53287 .29069 .52065 Metetra
0 .164 .703 r
.29069 .52065 .29802 .53287 .309 .5435 .30163 .53162 Metetra
0 .136 .682 r
.30163 .53162 .309 .5435 .32011 .55451 .31269 .54302 Metetra
0 .14 .684 r
.31269 .54302 .32011 .55451 .33138 .56534 .32392 .55428 Metetra
0 .183 .715 r
.32392 .55428 .33138 .56534 .34286 .57535 .33536 .56476 Metetra
0 .265 .773 r
.33536 .56476 .34286 .57535 .35457 .58389 .34704 .5738 Metetra
.074 .38 .843 r
.34704 .5738 .35457 .58389 .36652 .59034 .35896 .58075 Metetra
.259 .509 .902 r
.35896 .58075 .36652 .59034 .37872 .59414 .37114 .58504 Metetra
.443 .622 .928 r
.37114 .58504 .37872 .59414 .39115 .59483 .38357 .5862 Metetra
.595 .702 .918 r
.38357 .5862 .39115 .59483 .40379 .59212 .39623 .58389 Metetra
.704 .749 .886 r
.39623 .58389 .40379 .59212 .41662 .58584 .40908 .57794 Metetra
.777 .772 .848 r
.40908 .57794 .41662 .58584 .42958 .57599 .42209 .56835 Metetra
.824 .782 .812 r
.42209 .56835 .42958 .57599 .44265 .56273 .4352 .55526 Metetra
.855 .785 .782 r
.4352 .55526 .44265 .56273 .45577 .54636 .44839 .53899 Metetra
.874 .784 .758 r
.44839 .53899 .45577 .54636 .4689 .52732 .46159 .51996 Metetra
.887 .783 .741 r
.46159 .51996 .4689 .52732 .482 .50613 .47477 .49873 Metetra
.895 .781 .728 r
.47477 .49873 .482 .50613 .49504 .4834 .48789 .47592 Metetra
.899 .779 .721 r
.48789 .47592 .49504 .4834 .50801 .45978 .50094 .45219 Metetra
.9 .778 .718 r
.50094 .45219 .50801 .45978 .52088 .43593 .5139 .42821 Metetra
.899 .778 .719 r
.5139 .42821 .52088 .43593 .53366 .41249 .52676 .40466 Metetra
.895 .778 .725 r
.52676 .40466 .53366 .41249 .54636 .39008 .53953 .38217 Metetra
.888 .78 .737 r
.53953 .38217 .54636 .39008 .55898 .36926 .55223 .3613 Metetra
.876 .782 .753 r
.55223 .3613 .55898 .36926 .57156 .3505 .56488 .34255 Metetra
.859 .784 .776 r
.56488 .34255 .57156 .3505 .58413 .33423 .57751 .32634 Metetra
.834 .786 .806 r
.57751 .32634 .58413 .33423 .59673 .32074 .59017 .31299 Metetra
.795 .786 .844 r
.59017 .31299 .59673 .32074 .60939 .31027 .60289 .30273 Metetra
.736 .78 .889 r
.60289 .30273 .60939 .31027 .62216 .30294 .61572 .29567 Metetra
.642 .76 .934 r
.61572 .29567 .62216 .30294 .63507 .29876 .62869 .29184 Metetra
.501 .712 .966 r
.62869 .29184 .63507 .29876 .64817 .29766 .64184 .29113 Metetra
.308 .623 .959 r
.64184 .29113 .64817 .29766 .66148 .29943 .65521 .29335 Metetra
.086 .496 .899 r
.65521 .29335 .66148 .29943 .67504 .30378 .66882 .29818 Metetra
0 .359 .8 r
.66882 .29818 .67504 .30378 .68884 .31033 .68269 .30523 Metetra
0 .244 .695 r
.68269 .30523 .68884 .31033 .70291 .31859 .69681 .31399 Metetra
0 .165 .611 r
.69681 .31399 .70291 .31859 .71721 .32802 .71119 .32392 Metetra
.428 0 0 r
.71119 .32392 .71721 .32802 .73175 .33805 .7258 .33441 Metetra
.448 0 0 r
.7258 .33441 .73175 .33805 .74649 .34811 .7406 .34491 Metetra
.441 0 0 r
.7406 .34491 .74649 .34811 .76138 .35769 .75558 .35492 Metetra
.42 .825 .978 r
.75558 .35492 .76138 .35769 .77598 .361 .76981 .35259 Metetra
.656 .751 .92 r
.76981 .35259 .77598 .361 .79006 .35645 .78394 .348 Metetra
.656 .751 .92 r
.78394 .348 .79006 .35645 .80422 .35189 .79814 .34339 Metetra
.656 .751 .92 r
.79814 .34339 .80422 .35189 .81844 .34729 .81242 .33876 Metetra
.656 .751 .92 r
.81242 .33876 .81844 .34729 .83273 .34268 .82676 .3341 Metetra
.656 .751 .92 r
.82676 .3341 .83273 .34268 .8471 .33804 .84117 .32942 Metetra
.656 .751 .92 r
.20202 .52745 .20993 .53436 .22144 .53063 .21355 .52368 Metetra
.656 .751 .92 r
.21355 .52368 .22144 .53063 .233 .52687 .22515 .5199 Metetra
.656 .751 .92 r
.22515 .5199 .233 .52687 .24462 .5231 .23679 .5161 Metetra
.656 .751 .92 r
.23679 .5161 .24462 .5231 .25628 .51931 .24848 .51228 Metetra
.656 .751 .92 r
.24848 .51228 .25628 .51931 .268 .51551 .26023 .50844 Metetra
.656 .751 .92 r
.26023 .50844 .268 .51551 .27977 .51169 .27203 .50459 Metetra
.22 .558 .935 r
.27203 .50459 .27977 .51169 .29069 .52065 .28338 .50768 Metetra
0 .164 .703 r
.28338 .50768 .29069 .52065 .30163 .53162 .29427 .51889 Metetra
0 .138 .685 r
.29427 .51889 .30163 .53162 .31269 .54302 .30529 .53057 Metetra
0 .143 .688 r
.30529 .53057 .31269 .54302 .32392 .55428 .31648 .54217 Metetra
0 .183 .717 r
.31648 .54217 .32392 .55428 .33536 .56476 .32788 .55303 Metetra
0 .26 .769 r
.32788 .55303 .33536 .56476 .34704 .5738 .33951 .56249 Metetra
.1 .366 .831 r
.33951 .56249 .34704 .5738 .35896 .58075 .35141 .56989 Metetra
.271 .484 .881 r
.35141 .56989 .35896 .58075 .37114 .58504 .36357 .57464 Metetra
.441 .589 .903 r
.36357 .57464 .37114 .58504 .38357 .5862 .37599 .57626 Metetra
.584 .667 .896 r
.37599 .57626 .38357 .5862 .39623 .58389 .38865 .57438 Metetra
.689 .716 .87 r
.38865 .57438 .39623 .58389 .40908 .57794 .40152 .56883 Metetra
.762 .744 .837 r
.40152 .56883 .40908 .57794 .42209 .56835 .41456 .55959 Metetra
.81 .759 .805 r
.41456 .55959 .42209 .56835 .4352 .55526 .42772 .54679 Metetra
.843 .767 .778 r
.42772 .54679 .4352 .55526 .44839 .53899 .44096 .53074 Metetra
.865 .771 .756 r
.44096 .53074 .44839 .53899 .46159 .51996 .45423 .51189 Metetra
.88 .773 .739 r
.45423 .51189 .46159 .51996 .47477 .49873 .46748 .4908 Metetra
.89 .774 .728 r
.46748 .4908 .47477 .49873 .48789 .47592 .48068 .46808 Metetra
.896 .775 .721 r
.48068 .46808 .48789 .47592 .50094 .45219 .49381 .44441 Metetra
.899 .777 .718 r
.49381 .44441 .50094 .45219 .5139 .42821 .50685 .4205 Metetra
.899 .779 .72 r
.50685 .4205 .5139 .42821 .52676 .40466 .51979 .39702 Metetra
.896 .782 .727 r
.51979 .39702 .52676 .40466 .53953 .38217 .53264 .3746 Metetra
.891 .787 .74 r
.53264 .3746 .53953 .38217 .55223 .3613 .54542 .35384 Metetra
.881 .792 .758 r
.54542 .35384 .55223 .3613 .56488 .34255 .55814 .33524 Metetra
.865 .799 .784 r
.55814 .33524 .56488 .34255 .57751 .32634 .57085 .31921 Metetra
.84 .806 .818 r
.57085 .31921 .57751 .32634 .59017 .31299 .58357 .3061 Metetra
.798 .811 .861 r
.58357 .3061 .59017 .31299 .60289 .30273 .59636 .29613 Metetra
.731 .808 .912 r
.59636 .29613 .60289 .30273 .61572 .29567 .60924 .2894 Metetra
.62 .786 .961 r
.60924 .2894 .61572 .29567 .62869 .29184 .62227 .28595 Metetra
.446 .723 .985 r
.62227 .28595 .62869 .29184 .64184 .29113 .63549 .28565 Metetra
.211 .604 .949 r
.63549 .28565 .64184 .29113 .65521 .29335 .64892 .28831 Metetra
0 .445 .847 r
.64892 .28831 .65521 .29335 .66882 .29818 .66259 .2936 Metetra
0 .291 .717 r
.66259 .2936 .66882 .29818 .68269 .30523 .67652 .3011 Metetra
0 .176 .603 r
.67652 .3011 .68269 .30523 .69681 .31399 .69071 .31031 Metetra
.457 0 0 r
.69071 .31031 .69681 .31399 .71119 .32392 .70515 .32065 Metetra
.496 0 0 r
.70515 .32065 .71119 .32392 .7258 .33441 .71982 .33154 Metetra
.506 0 0 r
.71982 .33154 .7258 .33441 .7406 .34491 .7347 .3424 Metetra
.279 0 0 r
.7347 .3424 .7406 .34491 .75558 .35492 .74946 .34871 Metetra
.646 .816 .965 r
.74946 .34871 .75558 .35492 .76981 .35259 .76358 .3441 Metetra
.656 .751 .92 r
.76358 .3441 .76981 .35259 .78394 .348 .77776 .33947 Metetra
.656 .751 .92 r
.77776 .33947 .78394 .348 .79814 .34339 .79201 .33482 Metetra
.656 .751 .92 r
.79201 .33482 .79814 .34339 .81242 .33876 .80634 .33014 Metetra
.656 .751 .92 r
.80634 .33014 .81242 .33876 .82676 .3341 .82073 .32544 Metetra
.656 .751 .92 r
.82073 .32544 .82676 .3341 .84117 .32942 .8352 .32072 Metetra
.656 .751 .92 r
.19403 .52048 .20202 .52745 .21355 .52368 .2056 .51668 Metetra
.656 .751 .92 r
.2056 .51668 .21355 .52368 .22515 .5199 .21722 .51287 Metetra
.656 .751 .92 r
.21722 .51287 .22515 .5199 .23679 .5161 .2289 .50903 Metetra
.656 .751 .92 r
.2289 .50903 .23679 .5161 .24848 .51228 .24062 .50518 Metetra
.656 .751 .92 r
.24062 .50518 .24848 .51228 .26023 .50844 .2524 .50132 Metetra
.656 .751 .92 r
.2524 .50132 .26023 .50844 .27203 .50459 .26423 .49743 Metetra
.636 .746 .928 r
.26423 .49743 .27203 .50459 .28338 .50768 .27608 .49407 Metetra
0 .166 .703 r
.27608 .49407 .28338 .50768 .29427 .51889 .28693 .50543 Metetra
0 .142 .687 r
.28693 .50543 .29427 .51889 .30529 .53057 .29791 .51728 Metetra
0 .147 .691 r
.29791 .51728 .30529 .53057 .31648 .54217 .30905 .5291 Metetra
0 .185 .718 r
.30905 .5291 .31648 .54217 .32788 .55303 .32041 .54025 Metetra
0 .256 .764 r
.32041 .54025 .32788 .55303 .33951 .56249 .332 .55006 Metetra
.12 .354 .817 r
.332 .55006 .33951 .56249 .35141 .56989 .34386 .55785 Metetra
.279 .461 .861 r
.34386 .55785 .35141 .56989 .36357 .57464 .356 .56303 Metetra
.437 .56 .881 r
.356 .56303 .36357 .57464 .37599 .57626 .36841 .56509 Metetra
.571 .636 .877 r
.36841 .56509 .37599 .57626 .38865 .57438 .38107 .56367 Metetra
.673 .687 .855 r
.38107 .56367 .38865 .57438 .40152 .56883 .39395 .55857 Metetra
.746 .719 .827 r
.39395 .55857 .40152 .56883 .41456 .55959 .40701 .54975 Metetra
.796 .739 .799 r
.40701 .54975 .41456 .55959 .42772 .54679 .42021 .53734 Metetra
.831 .751 .775 r
.42021 .53734 .42772 .54679 .44096 .53074 .43349 .52166 Metetra
.856 .758 .754 r
.43349 .52166 .44096 .53074 .45423 .51189 .44682 .50314 Metetra
.872 .763 .739 r
.44682 .50314 .45423 .51189 .46748 .4908 .46014 .48234 Metetra
.884 .767 .728 r
.46014 .48234 .46748 .4908 .48068 .46808 .47342 .45988 Metetra
.892 .771 .722 r
.47342 .45988 .48068 .46808 .49381 .44441 .48662 .43647 Metetra
.896 .776 .72 r
.48662 .43647 .49381 .44441 .50685 .4205 .49974 .41279 Metetra
.898 .781 .723 r
.49974 .41279 .50685 .4205 .51979 .39702 .51276 .38954 Metetra
.897 .787 .731 r
.51276 .38954 .51979 .39702 .53264 .3746 .52569 .36736 Metetra
.893 .794 .744 r
.52569 .36736 .53264 .3746 .54542 .35384 .53855 .34685 Metetra
.884 .803 .764 r
.53855 .34685 .54542 .35384 .55814 .33524 .55135 .32852 Metetra
.869 .814 .793 r
.55135 .32852 .55814 .33524 .57085 .31921 .56413 .31281 Metetra
.843 .826 .831 r
.56413 .31281 .57085 .31921 .58357 .3061 .57693 .30003 Metetra
.798 .835 .88 r
.57693 .30003 .58357 .3061 .59636 .29613 .58978 .29041 Metetra
.72 .835 .936 r
.58978 .29041 .59636 .29613 .60924 .2894 .60273 .28408 Metetra
.585 .807 .984 r
.60273 .28408 .60924 .2894 .62227 .28595 .61583 .28103 Metetra
.372 .722 .988 r
.61583 .28103 .62227 .28595 .63549 .28565 .62911 .28116 Metetra
.1 .566 .911 r
.62911 .28116 .63549 .28565 .64892 .28831 .6426 .28425 Metetra
0 .381 .769 r
.6426 .28425 .64892 .28831 .66259 .2936 .65633 .28996 Metetra
0 .223 .624 r
.65633 .28996 .66259 .2936 .67652 .3011 .67032 .29787 Metetra
.455 0 0 r
.67032 .29787 .67652 .3011 .69071 .31031 .68457 .30746 Metetra
.518 0 0 r
.68457 .30746 .69071 .31031 .70515 .32065 .69907 .31814 Metetra
.545 0 0 r
.69907 .31814 .70515 .32065 .71982 .33154 .71381 .32934 Metetra
.547 0 0 r
.71381 .32934 .71982 .33154 .7347 .3424 .72876 .34047 Metetra
.191 .703 .893 r
.72876 .34047 .7347 .3424 .74946 .34871 .74313 .34018 Metetra
.656 .751 .92 r
.74313 .34018 .74946 .34871 .76358 .3441 .75729 .33553 Metetra
.656 .751 .92 r
.75729 .33553 .76358 .3441 .77776 .33947 .77152 .33086 Metetra
.656 .751 .92 r
.77152 .33086 .77776 .33947 .79201 .33482 .78582 .32617 Metetra
.656 .751 .92 r
.78582 .32617 .79201 .33482 .80634 .33014 .8002 .32145 Metetra
.656 .751 .92 r
.8002 .32145 .80634 .33014 .82073 .32544 .81464 .3167 Metetra
.656 .751 .92 r
.81464 .3167 .82073 .32544 .8352 .32072 .82916 .31194 Metetra
.656 .751 .92 r
.18598 .51346 .19403 .52048 .2056 .51668 .19758 .50962 Metetra
.656 .751 .92 r
.19758 .50962 .2056 .51668 .21722 .51287 .20923 .50578 Metetra
.656 .751 .92 r
.20923 .50578 .21722 .51287 .2289 .50903 .22094 .50191 Metetra
.656 .751 .92 r
.22094 .50191 .2289 .50903 .24062 .50518 .23269 .49803 Metetra
.656 .751 .92 r
.23269 .49803 .24062 .50518 .2524 .50132 .2445 .49413 Metetra
.656 .751 .92 r
.2445 .49413 .2524 .50132 .26423 .49743 .25637 .49021 Metetra
.656 .751 .92 r
.25637 .49021 .26423 .49743 .27608 .49407 .26829 .48628 Metetra
.059 .439 .875 r
.26829 .48628 .27608 .49407 .28693 .50543 .27959 .49133 Metetra
0 .148 .69 r
.27959 .49133 .28693 .50543 .29791 .51728 .29053 .50326 Metetra
0 .153 .694 r
.29053 .50326 .29791 .51728 .30905 .5291 .30164 .51521 Metetra
0 .188 .717 r
.30164 .51521 .30905 .5291 .32041 .54025 .31295 .52655 Metetra
.01 .254 .758 r
.31295 .52655 .32041 .54025 .332 .55006 .32451 .53661 Metetra
.136 .343 .805 r
.32451 .53661 .332 .55006 .34386 .55785 .33633 .54473 Metetra
.284 .442 .843 r
.33633 .54473 .34386 .55785 .356 .56303 .34844 .5503 Metetra
.431 .535 .862 r
.34844 .5503 .356 .56303 .36841 .56509 .36083 .55279 Metetra
.558 .609 .86 r
.36083 .55279 .36841 .56509 .38107 .56367 .37348 .55184 Metetra
.657 .661 .843 r
.37348 .55184 .38107 .56367 .39395 .55857 .38636 .54723 Metetra
.73 .697 .819 r
.38636 .54723 .39395 .55857 .40701 .54975 .39944 .5389 Metetra
.782 .72 .795 r
.39944 .5389 .40701 .54975 .42021 .53734 .41266 .52699 Metetra
.819 .736 .772 r
.41266 .52699 .42021 .53734 .43349 .52166 .42599 .51179 Metetra
.846 .746 .754 r
.42599 .51179 .43349 .52166 .44682 .50314 .43937 .49374 Metetra
.864 .755 .74 r
.43937 .49374 .44682 .50314 .46014 .48234 .45275 .47338 Metetra
.878 .761 .73 r
.45275 .47338 .46014 .48234 .47342 .45988 .46609 .45135 Metetra
.887 .768 .724 r
.46609 .45135 .47342 .45988 .48662 .43647 .47937 .42835 Metetra
.894 .775 .723 r
.47937 .42835 .48662 .43647 .49974 .41279 .49257 .40507 Metetra
.897 .782 .726 r
.49257 .40507 .49974 .41279 .51276 .38954 .50567 .38221 Metetra
.897 .791 .735 r
.50567 .38221 .51276 .38954 .52569 .36736 .51868 .36042 Metetra
.894 .802 .75 r
.51868 .36042 .52569 .36736 .53855 .34685 .53162 .34031 Metetra
.886 .814 .772 r
.53162 .34031 .53855 .34685 .55135 .32852 .5445 .32238 Metetra
.871 .829 .803 r
.5445 .32238 .55135 .32852 .56413 .31281 .55735 .30707 Metetra
.844 .846 .845 r
.55735 .30707 .56413 .31281 .57693 .30003 .57022 .29471 Metetra
.794 .86 .899 r
.57022 .29471 .57693 .30003 .58978 .29041 .58315 .28553 Metetra
.701 .86 .958 r
.58315 .28553 .58978 .29041 .60273 .28408 .59617 .27963 Metetra
.536 .82 .998 r
.59617 .27963 .60273 .28408 .61583 .28103 .60934 .27702 Metetra
.281 .702 .97 r
.60934 .27702 .61583 .28103 .62911 .28116 .62268 .27758 Metetra
0 .51 .845 r
.62268 .27758 .62911 .28116 .6426 .28425 .63624 .28108 Metetra
0 .312 .677 r
.63624 .28108 .6426 .28425 .65633 .28996 .65003 .28718 Metetra
.419 0 0 r
.65003 .28718 .65633 .28996 .67032 .29787 .66408 .29545 Metetra
.512 0 0 r
.66408 .29545 .67032 .29787 .68457 .30746 .6784 .30534 Metetra
.56 0 0 r
.6784 .30534 .68457 .30746 .69907 .31814 .69296 .31629 Metetra
.578 .006 0 r
.69296 .31629 .69907 .31814 .71381 .32934 .70776 .3277 Metetra
.463 0 0 r
.70776 .3277 .71381 .32934 .72876 .34047 .7226 .33625 Metetra
.615 .873 .99 r
.7226 .33625 .72876 .34047 .74313 .34018 .73674 .33158 Metetra
.656 .751 .92 r
.73674 .33158 .74313 .34018 .75729 .33553 .75095 .32689 Metetra
.656 .751 .92 r
.75095 .32689 .75729 .33553 .77152 .33086 .76523 .32217 Metetra
.656 .751 .92 r
.76523 .32217 .77152 .33086 .78582 .32617 .77958 .31743 Metetra
.656 .751 .92 r
.77958 .31743 .78582 .32617 .8002 .32145 .794 .31267 Metetra
.656 .751 .92 r
.794 .31267 .8002 .32145 .81464 .3167 .8085 .30788 Metetra
.656 .751 .92 r
.8085 .30788 .81464 .3167 .82916 .31194 .82307 .30307 Metetra
.656 .751 .92 r
.17786 .50637 .18598 .51346 .19758 .50962 .18949 .50251 Metetra
.656 .751 .92 r
.18949 .50251 .19758 .50962 .20923 .50578 .20118 .49863 Metetra
.656 .751 .92 r
.20118 .49863 .20923 .50578 .22094 .50191 .21291 .49473 Metetra
.656 .751 .92 r
.21291 .49473 .22094 .50191 .23269 .49803 .2247 .49082 Metetra
.656 .751 .92 r
.2247 .49082 .23269 .49803 .2445 .49413 .23654 .48688 Metetra
.656 .751 .92 r
.23654 .48688 .2445 .49413 .25637 .49021 .24844 .48293 Metetra
.656 .751 .92 r
.24844 .48293 .25637 .49021 .26829 .48628 .26039 .47896 Metetra
.586 .73 .943 r
.26039 .47896 .26829 .48628 .27959 .49133 .27226 .47674 Metetra
0 .155 .694 r
.27226 .47674 .27959 .49133 .29053 .50326 .28316 .48864 Metetra
0 .159 .696 r
.28316 .48864 .29053 .50326 .30164 .51521 .29423 .50061 Metetra
0 .192 .717 r
.29423 .50061 .30164 .51521 .31295 .52655 .30551 .51204 Metetra
.03 .252 .753 r
.30551 .51204 .31295 .52655 .32451 .53661 .31702 .52228 Metetra
.148 .334 .794 r
.31702 .52228 .32451 .53661 .33633 .54473 .32881 .53066 Metetra
.286 .426 .828 r
.32881 .53066 .33633 .54473 .34844 .5503 .34089 .53656 Metetra
.423 .513 .846 r
.34089 .53656 .34844 .5503 .36083 .55279 .35325 .53947 Metetra
.544 .585 .846 r
.35325 .53947 .36083 .55279 .37348 .55184 .36588 .53899 Metetra
.641 .639 .832 r
.36588 .53899 .37348 .55184 .38636 .54723 .37876 .5349 Metetra
.714 .677 .812 r
.37876 .5349 .38636 .54723 .39944 .5389 .39185 .52713 Metetra
.768 .703 .791 r
.39185 .52713 .39944 .5389 .41266 .52699 .40509 .5158 Metetra
.807 .722 .771 r
.40509 .5158 .41266 .52699 .42599 .51179 .41845 .50118 Metetra
.835 .736 .754 r
.41845 .50118 .42599 .51179 .43937 .49374 .43187 .48372 Metetra
.856 .746 .741 r
.43187 .48372 .43937 .49374 .45275 .47338 .4453 .46395 Metetra
.871 .756 .732 r
.4453 .46395 .45275 .47338 .46609 .45135 .45871 .4425 Metetra
.882 .765 .728 r
.45871 .4425 .46609 .45135 .47937 .42835 .47206 .42006 Metetra
.89 .774 .727 r
.47206 .42006 .47937 .42835 .49257 .40507 .48533 .39734 Metetra
.895 .784 .731 r
.48533 .39734 .49257 .40507 .50567 .38221 .49851 .37502 Metetra
.896 .795 .741 r
.49851 .37502 .50567 .38221 .51868 .36042 .5116 .35377 Metetra
.894 .809 .757 r
.5116 .35377 .51868 .36042 .53162 .34031 .52462 .33418 Metetra
.887 .825 .781 r
.52462 .33418 .53162 .34031 .5445 .32238 .53758 .31676 Metetra
.872 .844 .814 r
.53758 .31676 .5445 .32238 .55735 .30707 .55051 .30196 Metetra
.842 .865 .86 r
.55051 .30196 .55735 .30707 .57022 .29471 .56346 .2901 Metetra
.784 .882 .917 r
.56346 .2901 .57022 .29471 .58315 .28553 .57646 .28141 Metetra
.673 .88 .975 r
.57646 .28141 .58315 .28553 .59617 .27963 .58956 .27598 Metetra
.472 .82 .998 r
.58956 .27598 .59617 .27963 .60934 .27702 .60279 .27382 Metetra
.179 .664 .926 r
.60279 .27382 .60934 .27702 .62268 .27758 .6162 .27481 Metetra
0 .445 .762 r
.6162 .27481 .62268 .27758 .63624 .28108 .62983 .27871 Metetra
.341 0 0 r
.62983 .27871 .63624 .28108 .65003 .28718 .64369 .28516 Metetra
.475 0 0 r
.64369 .28516 .65003 .28718 .66408 .29545 .6578 .29372 Metetra
.55 0 0 r
.6578 .29372 .66408 .29545 .6784 .30534 .67217 .30385 Metetra
.587 .014 0 r
.67217 .30385 .6784 .30534 .69296 .31629 .68679 .31498 Metetra
.598 .027 0 r
.68679 .31498 .69296 .31629 .70776 .3277 .70165 .32652 Metetra
.006 .576 .776 r
.70165 .32652 .70776 .3277 .7226 .33625 .71609 .32761 Metetra
.656 .751 .92 r
.71609 .32761 .7226 .33625 .73674 .33158 .73028 .3229 Metetra
.656 .751 .92 r
.73028 .3229 .73674 .33158 .75095 .32689 .74454 .31816 Metetra
.656 .751 .92 r
.74454 .31816 .75095 .32689 .76523 .32217 .75887 .3134 Metetra
.656 .751 .92 r
.75887 .3134 .76523 .32217 .77958 .31743 .77328 .30862 Metetra
.656 .751 .92 r
.77328 .30862 .77958 .31743 .794 .31267 .78775 .30381 Metetra
.656 .751 .92 r
.78775 .30381 .794 .31267 .8085 .30788 .8023 .29898 Metetra
.656 .751 .92 r
.8023 .29898 .8085 .30788 .82307 .30307 .81693 .29412 Metetra
.656 .751 .92 r
.16968 .49923 .17786 .50637 .18949 .50251 .18134 .49533 Metetra
.656 .751 .92 r
.18134 .49533 .18949 .50251 .20118 .49863 .19305 .49142 Metetra
.656 .751 .92 r
.19305 .49142 .20118 .49863 .21291 .49473 .20482 .48749 Metetra
.656 .751 .92 r
.20482 .48749 .21291 .49473 .2247 .49082 .21664 .48354 Metetra
.656 .751 .92 r
.21664 .48354 .2247 .49082 .23654 .48688 .22851 .47957 Metetra
.656 .751 .92 r
.22851 .47957 .23654 .48688 .24844 .48293 .24044 .47559 Metetra
.656 .751 .92 r
.24044 .47559 .24844 .48293 .26039 .47896 .25242 .47159 Metetra
.656 .751 .92 r
.25242 .47159 .26039 .47896 .27226 .47674 .26446 .46757 Metetra
.051 .395 .853 r
.26446 .46757 .27226 .47674 .28316 .48864 .27579 .47355 Metetra
0 .167 .7 r
.27579 .47355 .28316 .48864 .29423 .50061 .28683 .48544 Metetra
0 .197 .718 r
.28683 .48544 .29423 .50061 .30551 .51204 .29807 .49688 Metetra
.047 .252 .749 r
.29807 .49688 .30551 .51204 .31702 .52228 .30955 .5072 Metetra
.158 .328 .785 r
.30955 .5072 .31702 .52228 .32881 .53066 .3213 .51577 Metetra
.286 .413 .816 r
.3213 .51577 .32881 .53066 .34089 .53656 .33335 .52196 Metetra
.416 .495 .832 r
.33335 .52196 .34089 .53656 .35325 .53947 .34568 .52525 Metetra
.531 .564 .834 r
.34568 .52525 .35325 .53947 .36588 .53899 .35829 .52524 Metetra
.626 .619 .824 r
.35829 .52524 .36588 .53899 .37876 .5349 .37116 .52168 Metetra
.698 .659 .807 r
.37116 .52168 .37876 .5349 .39185 .52713 .38424 .51451 Metetra
.753 .688 .788 r
.38424 .51451 .39185 .52713 .40509 .5158 .3975 .50383 Metetra
.794 .709 .771 r
.3975 .50383 .40509 .5158 .41845 .50118 .41088 .48991 Metetra
.824 .726 .756 r
.41088 .48991 .41845 .50118 .43187 .48372 .42433 .47314 Metetra
.847 .739 .744 r
.42433 .47314 .43187 .48372 .4453 .46395 .43781 .45408 Metetra
.864 .751 .736 r
.43781 .45408 .4453 .46395 .45871 .4425 .45127 .43335 Metetra
.877 .762 .732 r
.45127 .43335 .45871 .4425 .47206 .42006 .46469 .41162 Metetra
.886 .773 .732 r
.46469 .41162 .47206 .42006 .48533 .39734 .47803 .38959 Metetra
.892 .786 .737 r
.47803 .38959 .48533 .39734 .49851 .37502 .49128 .36795 Metetra
.895 .8 .748 r
.49128 .36795 .49851 .37502 .5116 .35377 .50445 .34736 Metetra
.893 .816 .765 r
.50445 .34736 .5116 .35377 .52462 .33418 .51755 .32841 Metetra
.886 .836 .791 r
.51755 .32841 .52462 .33418 .53758 .31676 .53059 .31162 Metetra
.87 .859 .827 r
.53059 .31162 .53758 .31676 .55051 .30196 .5436 .29741 Metetra
.836 .884 .876 r
.5436 .29741 .55051 .30196 .56346 .2901 .55663 .28612 Metetra
.768 .902 .935 r
.55663 .28612 .56346 .2901 .57646 .28141 .56971 .27796 Metetra
.633 .891 .986 r
.56971 .27796 .57646 .28141 .58956 .27598 .58288 .27305 Metetra
.395 .803 .98 r
.58288 .27305 .58956 .27598 .60279 .27382 .59619 .27136 Metetra
.077 .611 .863 r
.59619 .27136 .60279 .27382 .6162 .27481 .60967 .27276 Metetra
0 .381 .677 r
.60967 .27276 .6162 .27481 .62983 .27871 .62336 .27702 Metetra
.401 0 0 r
.62336 .27702 .62983 .27871 .64369 .28516 .63728 .28378 Metetra
.513 0 0 r
.63728 .28378 .64369 .28516 .6578 .29372 .65145 .29257 Metetra
.574 0 0 r
.65145 .29257 .6578 .29372 .67217 .30385 .66588 .30286 Metetra
.602 .032 0 r
.66588 .30286 .67217 .30385 .68679 .31498 .68056 .31409 Metetra
.54 0 0 r
.68056 .31409 .68679 .31498 .70165 .32652 .69537 .32363 Metetra
.572 .897 .985 r
.69537 .32363 .70165 .32652 .71609 .32761 .70953 .31889 Metetra
.656 .751 .92 r
.70953 .31889 .71609 .32761 .73028 .3229 .72377 .31414 Metetra
.656 .751 .92 r
.72377 .31414 .73028 .3229 .74454 .31816 .73808 .30936 Metetra
.656 .751 .92 r
.73808 .30936 .74454 .31816 .75887 .3134 .75246 .30455 Metetra
.656 .751 .92 r
.75246 .30455 .75887 .3134 .77328 .30862 .76692 .29973 Metetra
.656 .751 .92 r
.76692 .29973 .77328 .30862 .78775 .30381 .78144 .29487 Metetra
.656 .751 .92 r
.78144 .29487 .78775 .30381 .8023 .29898 .79605 .29 Metetra
.656 .751 .92 r
.79605 .29 .8023 .29898 .81693 .29412 .81072 .28509 Metetra
.656 .751 .92 r
.16143 .49202 .16968 .49923 .18134 .49533 .17312 .48809 Metetra
.656 .751 .92 r
.17312 .48809 .18134 .49533 .19305 .49142 .18486 .48415 Metetra
.656 .751 .92 r
.18486 .48415 .19305 .49142 .20482 .48749 .19665 .48019 Metetra
.656 .751 .92 r
.19665 .48019 .20482 .48749 .21664 .48354 .20851 .4762 Metetra
.656 .751 .92 r
.20851 .4762 .21664 .48354 .22851 .47957 .22041 .4722 Metetra
.656 .751 .92 r
.22041 .4722 .22851 .47957 .24044 .47559 .23237 .46819 Metetra
.656 .751 .92 r
.23237 .46819 .24044 .47559 .25242 .47159 .24439 .46415 Metetra
.656 .751 .92 r
.24439 .46415 .25242 .47159 .26446 .46757 .25646 .46009 Metetra
.57 .724 .946 r
.25646 .46009 .26446 .46757 .27579 .47355 .26842 .45815 Metetra
0 .176 .704 r
.26842 .45815 .27579 .47355 .28683 .48544 .27943 .46986 Metetra
0 .203 .72 r
.27943 .46986 .28683 .48544 .29807 .49688 .29064 .4812 Metetra
.061 .254 .747 r
.29064 .4812 .29807 .49688 .30955 .5072 .30209 .49153 Metetra
.165 .323 .779 r
.30209 .49153 .30955 .5072 .3213 .51577 .3138 .50021 Metetra
.286 .402 .806 r
.3138 .50021 .3213 .51577 .33335 .52196 .32581 .50662 Metetra
.408 .479 .822 r
.32581 .50662 .33335 .52196 .34568 .52525 .33811 .51025 Metetra
.518 .547 .825 r
.33811 .51025 .34568 .52525 .35829 .52524 .35069 .5107 Metetra
.61 .601 .817 r
.35069 .5107 .35829 .52524 .37116 .52168 .36354 .50769 Metetra
.683 .642 .803 r
.36354 .50769 .37116 .52168 .38424 .51451 .37662 .50116 Metetra
.739 .674 .787 r
.37662 .50116 .38424 .51451 .3975 .50383 .38988 .49119 Metetra
.781 .697 .772 r
.38988 .49119 .3975 .50383 .41088 .48991 .40327 .47802 Metetra
.813 .716 .758 r
.40327 .47802 .41088 .48991 .42433 .47314 .41675 .46206 Metetra
.838 .732 .748 r
.41675 .46206 .42433 .47314 .43781 .45408 .43027 .44383 Metetra
.856 .746 .74 r
.43027 .44383 .43781 .45408 .45127 .43335 .44378 .42393 Metetra
.87 .759 .737 r
.44378 .42393 .45127 .43335 .46469 .41162 .45725 .40303 Metetra
.881 .773 .738 r
.45725 .40303 .46469 .41162 .47803 .38959 .47066 .38182 Metetra
.888 .788 .744 r
.47066 .38182 .47803 .38959 .49128 .36795 .48398 .36098 Metetra
.892 .804 .756 r
.48398 .36098 .49128 .36795 .50445 .34736 .49723 .34117 Metetra
.891 .824 .775 r
.49723 .34117 .50445 .34736 .51755 .32841 .5104 .32296 Metetra
.884 .847 .802 r
.5104 .32296 .51755 .32841 .53059 .31162 .52352 .30688 Metetra
.866 .873 .841 r
.52352 .30688 .53059 .31162 .5436 .29741 .53662 .29335 Metetra
.826 .9 .893 r
.53662 .29335 .5436 .29741 .55663 .28612 .54973 .28269 Metetra
.744 .917 .95 r
.54973 .28269 .55663 .28612 .56971 .27796 .56288 .27512 Metetra
.582 .892 .989 r
.56288 .27512 .56971 .27796 .58288 .27305 .57613 .27073 Metetra
.309 .771 .946 r
.57613 .27073 .58288 .27305 .59619 .27136 .58951 .26951 Metetra
0 .551 .792 r
.58951 .26951 .59619 .27136 .60967 .27276 .60306 .27132 Metetra
.277 0 0 r
.60306 .27132 .60967 .27276 .62336 .27702 .61682 .2759 Metetra
.442 0 0 r
.61682 .2759 .62336 .27702 .63728 .28378 .6308 .28291 Metetra
.537 0 0 r
.6308 .28291 .63728 .28378 .65145 .29257 .64504 .29186 Metetra
.588 .013 0 r
.64504 .29186 .65145 .29257 .66588 .30286 .65952 .30224 Metetra
.61 .04 0 r
.65952 .30224 .66588 .30286 .68056 .31409 .67426 .31347 Metetra
0 .519 .704 r
.67426 .31347 .68056 .31409 .69537 .32363 .6887 .31487 Metetra
.656 .751 .92 r
.6887 .31487 .69537 .32363 .70953 .31889 .70291 .3101 Metetra
.656 .751 .92 r
.70291 .3101 .70953 .31889 .72377 .31414 .7172 .3053 Metetra
.656 .751 .92 r
.7172 .3053 .72377 .31414 .73808 .30936 .73156 .30047 Metetra
.656 .751 .92 r
.73156 .30047 .73808 .30936 .75246 .30455 .74599 .29562 Metetra
.656 .751 .92 r
.74599 .29562 .75246 .30455 .76692 .29973 .7605 .29075 Metetra
.656 .751 .92 r
.7605 .29075 .76692 .29973 .78144 .29487 .77508 .28585 Metetra
.656 .751 .92 r
.77508 .28585 .78144 .29487 .79605 .29 .78973 .28093 Metetra
.656 .751 .92 r
.78973 .28093 .79605 .29 .81072 .28509 .80446 .27598 Metetra
.656 .751 .92 r
.1531 .48476 .16143 .49202 .17312 .48809 .16482 .4808 Metetra
.656 .751 .92 r
.16482 .4808 .17312 .48809 .18486 .48415 .1766 .47682 Metetra
.656 .751 .92 r
.1766 .47682 .18486 .48415 .19665 .48019 .18842 .47282 Metetra
.656 .751 .92 r
.18842 .47282 .19665 .48019 .20851 .4762 .20031 .46881 Metetra
.656 .751 .92 r
.20031 .46881 .20851 .4762 .22041 .4722 .21224 .46477 Metetra
.656 .751 .92 r
.21224 .46477 .22041 .4722 .23237 .46819 .22423 .46072 Metetra
.656 .751 .92 r
.22423 .46072 .23237 .46819 .24439 .46415 .23628 .45665 Metetra
.656 .751 .92 r
.23628 .45665 .24439 .46415 .25646 .46009 .24839 .45256 Metetra
.656 .751 .92 r
.24839 .45256 .25646 .46009 .26842 .45815 .26055 .44845 Metetra
.111 .423 .868 r
.26055 .44845 .26842 .45815 .27943 .46986 .27201 .45401 Metetra
.002 .21 .723 r
.27201 .45401 .27943 .46986 .29064 .4812 .2832 .46516 Metetra
.073 .256 .746 r
.2832 .46516 .29064 .4812 .30209 .49153 .29462 .47541 Metetra
.171 .32 .774 r
.29462 .47541 .30209 .49153 .3138 .50021 .3063 .48412 Metetra
.284 .394 .799 r
.3063 .48412 .3138 .50021 .32581 .50662 .31827 .4907 Metetra
.4 .467 .814 r
.31827 .4907 .32581 .50662 .33811 .51025 .33054 .49463 Metetra
.506 .532 .817 r
.33054 .49463 .33811 .51025 .35069 .5107 .34309 .4955 Metetra
.595 .585 .812 r
.34309 .4955 .35069 .5107 .36354 .50769 .35592 .49305 Metetra
.668 .628 .8 r
.35592 .49305 .36354 .50769 .37662 .50116 .36898 .48718 Metetra
.724 .661 .787 r
.36898 .48718 .37662 .50116 .38988 .49119 .38223 .47796 Metetra
.768 .687 .773 r
.38223 .47796 .38988 .49119 .40327 .47802 .39564 .46562 Metetra
.802 .708 .761 r
.39564 .46562 .40327 .47802 .41675 .46206 .40914 .45054 Metetra
.828 .725 .752 r
.40914 .45054 .41675 .46206 .43027 .44383 .42268 .43322 Metetra
.848 .741 .746 r
.42268 .43322 .43027 .44383 .44378 .42393 .43623 .41425 Metetra
.863 .757 .743 r
.43623 .41425 .44378 .42393 .45725 .40303 .44975 .39429 Metetra
.875 .773 .745 r
.44975 .39429 .45725 .40303 .47066 .38182 .46322 .37401 Metetra
.883 .79 .752 r
.46322 .37401 .47066 .38182 .48398 .36098 .47661 .35409 Metetra
.888 .809 .765 r
.47661 .35409 .48398 .36098 .49723 .34117 .48993 .33515 Metetra
.887 .831 .786 r
.48993 .33515 .49723 .34117 .5104 .32296 .50318 .31778 Metetra
.879 .857 .815 r
.50318 .31778 .5104 .32296 .52352 .30688 .51638 .3025 Metetra
.858 .886 .857 r
.51638 .3025 .52352 .30688 .53662 .29335 .52955 .2897 Metetra
.811 .915 .909 r
.52955 .2897 .53662 .29335 .54973 .28269 .54274 .27972 Metetra
.713 .927 .963 r
.54274 .27972 .54973 .28269 .56288 .27512 .55597 .27276 Metetra
.521 .881 .981 r
.55597 .27276 .56288 .27512 .57613 .27073 .5693 .26892 Metetra
.224 .728 .901 r
.5693 .26892 .57613 .27073 .58951 .26951 .58275 .26816 Metetra
0 .494 .723 r
.58275 .26816 .58951 .26951 .60306 .27132 .59637 .27035 Metetra
.326 0 0 r
.59637 .27035 .60306 .27132 .61682 .2759 .6102 .27523 Metetra
.469 0 0 r
.6102 .27523 .61682 .2759 .6308 .28291 .62425 .28242 Metetra
.55 0 0 r
.62425 .28242 .6308 .28291 .64504 .29186 .63854 .29147 Metetra
.593 .019 0 r
.63854 .29147 .64504 .29186 .65952 .30224 .65308 .30185 Metetra
.537 0 0 r
.65308 .30185 .65952 .30224 .67426 .31347 .66777 .31083 Metetra
.563 .9 .98 r
.66777 .31083 .67426 .31347 .6887 .31487 .68196 .30604 Metetra
.656 .751 .92 r
.68196 .30604 .6887 .31487 .70291 .3101 .69623 .30121 Metetra
.656 .751 .92 r
.69623 .30121 .70291 .3101 .7172 .3053 .71057 .29637 Metetra
.656 .751 .92 r
.71057 .29637 .7172 .3053 .73156 .30047 .72498 .2915 Metetra
.656 .751 .92 r
.72498 .2915 .73156 .30047 .74599 .29562 .73946 .28661 Metetra
.656 .751 .92 r
.73946 .28661 .74599 .29562 .7605 .29075 .75402 .28169 Metetra
.656 .751 .92 r
.75402 .28169 .7605 .29075 .77508 .28585 .76865 .27674 Metetra
.656 .751 .92 r
.76865 .27674 .77508 .28585 .78973 .28093 .78335 .27177 Metetra
.656 .751 .92 r
.78335 .27177 .78973 .28093 .80446 .27598 .79814 .26678 Metetra
.656 .751 .92 r
.14471 .47743 .1531 .48476 .16482 .4808 .15646 .47344 Metetra
.656 .751 .92 r
.15646 .47344 .16482 .4808 .1766 .47682 .16826 .46942 Metetra
.656 .751 .92 r
.16826 .46942 .1766 .47682 .18842 .47282 .18012 .46539 Metetra
.656 .751 .92 r
.18012 .46539 .18842 .47282 .20031 .46881 .19204 .46134 Metetra
.656 .751 .92 r
.19204 .46134 .20031 .46881 .21224 .46477 .204 .45728 Metetra
.656 .751 .92 r
.204 .45728 .21224 .46477 .22423 .46072 .21603 .45319 Metetra
.656 .751 .92 r
.21603 .45319 .22423 .46072 .23628 .45665 .22811 .44908 Metetra
.656 .751 .92 r
.22811 .44908 .23628 .45665 .24839 .45256 .24025 .44496 Metetra
.656 .751 .92 r
.24025 .44496 .24839 .45256 .26055 .44845 .25244 .44081 Metetra
.603 .736 .938 r
.25244 .44081 .26055 .44845 .27201 .45401 .26458 .43805 Metetra
.017 .219 .727 r
.26458 .43805 .27201 .45401 .2832 .46516 .27574 .44892 Metetra
.084 .261 .747 r
.27574 .44892 .2832 .46516 .29462 .47541 .28714 .45899 Metetra
.176 .32 .772 r
.28714 .45899 .29462 .47541 .3063 .48412 .29879 .46767 Metetra
.282 .388 .794 r
.29879 .46767 .3063 .48412 .31827 .4907 .31073 .47435 Metetra
.392 .456 .808 r
.31073 .47435 .31827 .4907 .33054 .49463 .32296 .47853 Metetra
.493 .519 .812 r
.32296 .47853 .33054 .49463 .34309 .4955 .33548 .4798 Metetra
.581 .572 .808 r
.33548 .4798 .34309 .4955 .35592 .49305 .34828 .47789 Metetra
.653 .615 .799 r
.34828 .47789 .35592 .49305 .36898 .48718 .36132 .47268 Metetra
.71 .649 .787 r
.36132 .47268 .36898 .48718 .38223 .47796 .37457 .46424 Metetra
.755 .677 .775 r
.37457 .46424 .38223 .47796 .39564 .46562 .38797 .45277 Metetra
.79 .7 .765 r
.38797 .45277 .39564 .46562 .40914 .45054 .40148 .43863 Metetra
.817 .719 .757 r
.40148 .43863 .40914 .45054 .42268 .43322 .41505 .4223 Metetra
.839 .737 .752 r
.41505 .4223 .42268 .43322 .43623 .41425 .42863 .40436 Metetra
.856 .755 .751 r
.42863 .40436 .43623 .41425 .44975 .39429 .44219 .38543 Metetra
.868 .772 .754 r
.44219 .38543 .44975 .39429 .46322 .37401 .45571 .36617 Metetra
.877 .792 .762 r
.45571 .36617 .46322 .37401 .47661 .35409 .46916 .34725 Metetra
.882 .813 .776 r
.46916 .34725 .47661 .35409 .48993 .33515 .48255 .32927 Metetra
.881 .838 .798 r
.48255 .32927 .48993 .33515 .50318 .31778 .49587 .31282 Metetra
.872 .866 .83 r
.49587 .31282 .50318 .31778 .51638 .3025 .50915 .29839 Metetra
.847 .897 .873 r
.50915 .29839 .51638 .3025 .52955 .2897 .5224 .28639 Metetra
.791 .925 .925 r
.5224 .28639 .52955 .2897 .54274 .27972 .53567 .27713 Metetra
.674 .929 .971 r
.53567 .27713 .54274 .27972 .55597 .27276 .54898 .2708 Metetra
.456 .86 .965 r
.54898 .2708 .55597 .27276 .5693 .26892 .56238 .26751 Metetra
.146 .68 .853 r
.56238 .26751 .5693 .26892 .58275 .26816 .57591 .2672 Metetra
.151 0 0 r
.57591 .2672 .58275 .26816 .59637 .27035 .5896 .26974 Metetra
.359 0 0 r
.5896 .26974 .59637 .27035 .6102 .27523 .60349 .27485 Metetra
.485 0 0 r
.60349 .27485 .6102 .27523 .62425 .28242 .6176 .28217 Metetra
.555 0 0 r
.6176 .28217 .62425 .28242 .63854 .29147 .63195 .29124 Metetra
.592 .018 0 r
.63195 .29124 .63854 .29147 .65308 .30185 .64655 .30153 Metetra
0 .567 .719 r
.64655 .30153 .65308 .30185 .66777 .31083 .66092 .30196 Metetra
.656 .751 .92 r
.66092 .30196 .66777 .31083 .68196 .30604 .67517 .29712 Metetra
.656 .751 .92 r
.67517 .29712 .68196 .30604 .69623 .30121 .68948 .29225 Metetra
.656 .751 .92 r
.68948 .29225 .69623 .30121 .71057 .29637 .70387 .28736 Metetra
.656 .751 .92 r
.70387 .28736 .71057 .29637 .72498 .2915 .71833 .28244 Metetra
.656 .751 .92 r
.71833 .28244 .72498 .2915 .73946 .28661 .73286 .2775 Metetra
.656 .751 .92 r
.73286 .2775 .73946 .28661 .75402 .28169 .74747 .27254 Metetra
.656 .751 .92 r
.74747 .27254 .75402 .28169 .76865 .27674 .76216 .26755 Metetra
.656 .751 .92 r
.76216 .26755 .76865 .27674 .78335 .27177 .77692 .26253 Metetra
.656 .751 .92 r
.77692 .26253 .78335 .27177 .79814 .26678 .79175 .25749 Metetra
.656 .751 .92 r
.13624 .47004 .14471 .47743 .15646 .47344 .14803 .46602 Metetra
.656 .751 .92 r
.14803 .46602 .15646 .47344 .16826 .46942 .15986 .46197 Metetra
.656 .751 .92 r
.15986 .46197 .16826 .46942 .18012 .46539 .17175 .4579 Metetra
.656 .751 .92 r
.17175 .4579 .18012 .46539 .19204 .46134 .1837 .45382 Metetra
.656 .751 .92 r
.1837 .45382 .19204 .46134 .204 .45728 .1957 .44971 Metetra
.656 .751 .92 r
.1957 .44971 .204 .45728 .21603 .45319 .20775 .44559 Metetra
.656 .751 .92 r
.20775 .44559 .21603 .45319 .22811 .44908 .21987 .44145 Metetra
.656 .751 .92 r
.21987 .44145 .22811 .44908 .24025 .44496 .23204 .43729 Metetra
.656 .751 .92 r
.23204 .43729 .24025 .44496 .25244 .44081 .24426 .43311 Metetra
.656 .751 .92 r
.24426 .43311 .25244 .44081 .26458 .43805 .25655 .42891 Metetra
.232 .518 .913 r
.25655 .42891 .26458 .43805 .27574 .44892 .26826 .43262 Metetra
.094 .268 .75 r
.26826 .43262 .27574 .44892 .28714 .45899 .27964 .44244 Metetra
.18 .321 .771 r
.27964 .44244 .28714 .45899 .29879 .46767 .29127 .451 Metetra
.28 .384 .791 r
.29127 .451 .29879 .46767 .31073 .47435 .30317 .45772 Metetra
.384 .448 .804 r
.30317 .45772 .31073 .47435 .32296 .47853 .31537 .46209 Metetra
.481 .508 .809 r
.31537 .46209 .32296 .47853 .33548 .4798 .32786 .46372 Metetra
.567 .56 .806 r
.32786 .46372 .33548 .4798 .34828 .47789 .34063 .46232 Metetra
.638 .604 .799 r
.34063 .46232 .34828 .47789 .36132 .47268 .35365 .45778 Metetra
.695 .639 .789 r
.35365 .45778 .36132 .47268 .37457 .46424 .36687 .45012 Metetra
.741 .668 .779 r
.36687 .45012 .37457 .46424 .38797 .45277 .38027 .43955 Metetra
.777 .692 .77 r
.38027 .43955 .38797 .45277 .40148 .43863 .39378 .4264 Metetra
.806 .714 .763 r
.39378 .4264 .40148 .43863 .41505 .4223 .40736 .41113 Metetra
.829 .733 .759 r
.40736 .41113 .41505 .4223 .42863 .40436 .42097 .39427 Metetra
.847 .753 .759 r
.42097 .39427 .42863 .40436 .44219 .38543 .43457 .37644 Metetra
.861 .772 .763 r
.43457 .37644 .44219 .38543 .45571 .36617 .44813 .35829 Metetra
.87 .793 .772 r
.44813 .35829 .45571 .36617 .46916 .34725 .46164 .34043 Metetra
.875 .817 .788 r
.46164 .34043 .46916 .34725 .48255 .32927 .47509 .32349 Metetra
.874 .844 .812 r
.47509 .32349 .48255 .32927 .49587 .31282 .48848 .30802 Metetra
.863 .874 .845 r
.48848 .30802 .49587 .31282 .50915 .29839 .50183 .2945 Metetra
.833 .907 .889 r
.50183 .2945 .50915 .29839 .5224 .28639 .51516 .28333 Metetra
.766 .932 .94 r
.51516 .28333 .5224 .28639 .53567 .27713 .5285 .27481 Metetra
.63 .924 .975 r
.5285 .27481 .53567 .27713 .54898 .2708 .54189 .26913 Metetra
.39 .832 .944 r
.54189 .26913 .54898 .2708 .56238 .26751 .55537 .26637 Metetra
.08 .635 .808 r
.55537 .26637 .56238 .26751 .57591 .2672 .56897 .2665 Metetra
.194 0 0 r
.56897 .2665 .57591 .2672 .5896 .26974 .58274 .26934 Metetra
.38 0 0 r
.58274 .26934 .5896 .26974 .60349 .27485 .59669 .27464 Metetra
.491 0 0 r
.59669 .27464 .60349 .27485 .6176 .28217 .61087 .28202 Metetra
.553 0 0 r
.61087 .28202 .6176 .28217 .63195 .29124 .62527 .29102 Metetra
.453 0 0 r
.62527 .29102 .63195 .29124 .64655 .30153 .6398 .29786 Metetra
.6 .888 .99 r
.6398 .29786 .64655 .30153 .66092 .30196 .65402 .293 Metetra
.656 .751 .92 r
.65402 .293 .66092 .30196 .67517 .29712 .66831 .28811 Metetra
.656 .751 .92 r
.66831 .28811 .67517 .29712 .68948 .29225 .68267 .2832 Metetra
.656 .751 .92 r
.68267 .2832 .68948 .29225 .70387 .28736 .69711 .27827 Metetra
.656 .751 .92 r
.69711 .27827 .70387 .28736 .71833 .28244 .71162 .2733 Metetra
.656 .751 .92 r
.71162 .2733 .71833 .28244 .73286 .2775 .72621 .26832 Metetra
.656 .751 .92 r
.72621 .26832 .73286 .2775 .74747 .27254 .74087 .2633 Metetra
.656 .751 .92 r
.74087 .2633 .74747 .27254 .76216 .26755 .75561 .25826 Metetra
.656 .751 .92 r
.75561 .25826 .76216 .26755 .77692 .26253 .77042 .2532 Metetra
.656 .751 .92 r
.77042 .2532 .77692 .26253 .79175 .25749 .78531 .24811 Metetra
.656 .751 .92 r
.12771 .46259 .13624 .47004 .14803 .46602 .13952 .45853 Metetra
.656 .751 .92 r
.13952 .45853 .14803 .46602 .15986 .46197 .15139 .45445 Metetra
.656 .751 .92 r
.15139 .45445 .15986 .46197 .17175 .4579 .16331 .45035 Metetra
.656 .751 .92 r
.16331 .45035 .17175 .4579 .1837 .45382 .17528 .44623 Metetra
.656 .751 .92 r
.17528 .44623 .1837 .45382 .1957 .44971 .18732 .44209 Metetra
.656 .751 .92 r
.18732 .44209 .1957 .44971 .20775 .44559 .19941 .43793 Metetra
.656 .751 .92 r
.19941 .43793 .20775 .44559 .21987 .44145 .21155 .43375 Metetra
.656 .751 .92 r
.21155 .43375 .21987 .44145 .23204 .43729 .22375 .42956 Metetra
.656 .751 .92 r
.22375 .42956 .23204 .43729 .24426 .43311 .23602 .42534 Metetra
.656 .751 .92 r
.23602 .42534 .24426 .43311 .25655 .42891 .24833 .4211 Metetra
.656 .751 .92 r
.24833 .4211 .25655 .42891 .26826 .43262 .26071 .41684 Metetra
.114 .291 .765 r
.26071 .41684 .26826 .43262 .27964 .44244 .27211 .4259 Metetra
.184 .324 .773 r
.27211 .4259 .27964 .44244 .29127 .451 .28372 .43426 Metetra
.278 .382 .79 r
.28372 .43426 .29127 .451 .30317 .45772 .2956 .44095 Metetra
.376 .443 .802 r
.2956 .44095 .30317 .45772 .31537 .46209 .30777 .44546 Metetra
.47 .5 .807 r
.30777 .44546 .31537 .46209 .32786 .46372 .32022 .44739 Metetra
.553 .551 .806 r
.32022 .44739 .32786 .46372 .34063 .46232 .33296 .44648 Metetra
.623 .594 .8 r
.33296 .44648 .34063 .46232 .35365 .45778 .34594 .44258 Metetra
.681 .63 .792 r
.34594 .44258 .35365 .45778 .36687 .45012 .35915 .43572 Metetra
.727 .66 .783 r
.35915 .43572 .36687 .45012 .38027 .43955 .37253 .42606 Metetra
.765 .686 .775 r
.37253 .42606 .38027 .43955 .39378 .4264 .38604 .41393 Metetra
.795 .709 .77 r
.38604 .41393 .39378 .4264 .40736 .41113 .39962 .39974 Metetra
.818 .73 .767 r
.39962 .39974 .40736 .41113 .42097 .39427 .41325 .38402 Metetra
.837 .751 .768 r
.41325 .38402 .42097 .39427 .43457 .37644 .42688 .36735 Metetra
.852 .772 .773 r
.42688 .36735 .43457 .37644 .44813 .35829 .44048 .35035 Metetra
.862 .795 .784 r
.44048 .35035 .44813 .35829 .46164 .34043 .45404 .33362 Metetra
.867 .82 .801 r
.45404 .33362 .46164 .34043 .47509 .32349 .46755 .31777 Metetra
.864 .849 .826 r
.46755 .31777 .47509 .32349 .48848 .30802 .481 .30332 Metetra
.85 .881 .862 r
.481 .30332 .48848 .30802 .50183 .2945 .49442 .29074 Metetra
.814 .913 .906 r
.49442 .29074 .50183 .2945 .51516 .28333 .50783 .28043 Metetra
.736 .934 .953 r
.50783 .28043 .51516 .28333 .5285 .27481 .52125 .27267 Metetra
.582 .912 .975 r
.52125 .27267 .5285 .27481 .54189 .26913 .53471 .26764 Metetra
.329 .8 .921 r
.53471 .26764 .54189 .26913 .55537 .26637 .54826 .2654 Metetra
.028 .596 .773 r
.54826 .2654 .55537 .26637 .56897 .2665 .56194 .26592 Metetra
.223 0 0 r
.56194 .26592 .56897 .2665 .58274 .26934 .57577 .26903 Metetra
.389 0 0 r
.57577 .26903 .58274 .26934 .59669 .27464 .58979 .27445 Metetra
.488 0 0 r
.58979 .27445 .59669 .27464 .61087 .28202 .60403 .28182 Metetra
.544 0 0 r
.60403 .28182 .61087 .28202 .62527 .29102 .61849 .29068 Metetra
.184 .717 .813 r
.61849 .29068 .62527 .29102 .6398 .29786 .63277 .28887 Metetra
.656 .751 .92 r
.63277 .28887 .6398 .29786 .65402 .293 .64704 .28396 Metetra
.656 .751 .92 r
.64704 .28396 .65402 .293 .66831 .28811 .66138 .27903 Metetra
.656 .751 .92 r
.66138 .27903 .66831 .28811 .68267 .2832 .6758 .27407 Metetra
.656 .751 .92 r
.6758 .27407 .68267 .2832 .69711 .27827 .69029 .26909 Metetra
.656 .751 .92 r
.69029 .26909 .69711 .27827 .71162 .2733 .70485 .26408 Metetra
.656 .751 .92 r
.70485 .26408 .71162 .2733 .72621 .26832 .71949 .25904 Metetra
.656 .751 .92 r
.71949 .25904 .72621 .26832 .74087 .2633 .7342 .25398 Metetra
.656 .751 .92 r
.7342 .25398 .74087 .2633 .75561 .25826 .74899 .24889 Metetra
.656 .751 .92 r
.74899 .24889 .75561 .25826 .77042 .2532 .76386 .24378 Metetra
.656 .751 .92 r
.76386 .24378 .77042 .2532 .78531 .24811 .7788 .23864 Metetra
.656 .751 .92 r
.1191 .45508 .12771 .46259 .13952 .45853 .13094 .45098 Metetra
.656 .751 .92 r
.13094 .45098 .13952 .45853 .15139 .45445 .14284 .44686 Metetra
.656 .751 .92 r
.14284 .44686 .15139 .45445 .16331 .45035 .15479 .44273 Metetra
.656 .751 .92 r
.15479 .44273 .16331 .45035 .17528 .44623 .1668 .43857 Metetra
.656 .751 .92 r
.1668 .43857 .17528 .44623 .18732 .44209 .17886 .4344 Metetra
.656 .751 .92 r
.17886 .4344 .18732 .44209 .19941 .43793 .19099 .4302 Metetra
.656 .751 .92 r
.19099 .4302 .19941 .43793 .21155 .43375 .20316 .42599 Metetra
.656 .751 .92 r
.20316 .42599 .21155 .43375 .22375 .42956 .2154 .42175 Metetra
.656 .751 .92 r
.2154 .42175 .22375 .42956 .23602 .42534 .2277 .4175 Metetra
.656 .751 .92 r
.2277 .4175 .23602 .42534 .24833 .4211 .24005 .41323 Metetra
.656 .751 .92 r
.24005 .41323 .24833 .4211 .26071 .41684 .25246 .40893 Metetra
.417 .658 .959 r
.25246 .40893 .26071 .41684 .27211 .4259 .26454 .40951 Metetra
.187 .33 .777 r
.26454 .40951 .27211 .4259 .28372 .43426 .27613 .41761 Metetra
.276 .383 .792 r
.27613 .41761 .28372 .43426 .2956 .44095 .28799 .42419 Metetra
.369 .44 .803 r
.28799 .42419 .2956 .44095 .30777 .44546 .30013 .42877 Metetra
.459 .494 .808 r
.30013 .42877 .30777 .44546 .32022 .44739 .31256 .43096 Metetra
.539 .543 .807 r
.31256 .43096 .32022 .44739 .33296 .44648 .32526 .43049 Metetra
.609 .586 .802 r
.32526 .43049 .33296 .44648 .34594 .44258 .33821 .42721 Metetra
.666 .622 .795 r
.33821 .42721 .34594 .44258 .35915 .43572 .35139 .42112 Metetra
.713 .653 .788 r
.35139 .42112 .35915 .43572 .37253 .42606 .36475 .41238 Metetra
.751 .68 .782 r
.36475 .41238 .37253 .42606 .38604 .41393 .37825 .40127 Metetra
.782 .704 .777 r
.37825 .40127 .38604 .41393 .39962 .39974 .39184 .38819 Metetra
.807 .726 .776 r
.39184 .38819 .39962 .39974 .41325 .38402 .40548 .37363 Metetra
.826 .749 .778 r
.40548 .37363 .41325 .38402 .42688 .36735 .41913 .35816 Metetra
.841 .772 .784 r
.41913 .35816 .42688 .36735 .44048 .35035 .43276 .34234 Metetra
.852 .796 .796 r
.43276 .34234 .44048 .35035 .45404 .33362 .44637 .32679 Metetra
.856 .823 .815 r
.44637 .32679 .45404 .33362 .46755 .31777 .45992 .31205 Metetra
.852 .853 .842 r
.45992 .31205 .46755 .31777 .481 .30332 .47344 .29865 Metetra
.835 .886 .878 r
.47344 .29865 .481 .30332 .49442 .29074 .48692 .28705 Metetra
.792 .917 .923 r
.48692 .28705 .49442 .29074 .50783 .28043 .5004 .27761 Metetra
.703 .931 .964 r
.5004 .27761 .50783 .28043 .52125 .27267 .51389 .2706 Metetra
.534 .895 .973 r
.51389 .2706 .52125 .27267 .53471 .26764 .52743 .2662 Metetra
.276 .768 .902 r
.52743 .2662 .53471 .26764 .54826 .2654 .54106 .26447 Metetra
0 .567 .75 r
.54106 .26447 .54826 .2654 .56194 .26592 .5548 .26534 Metetra
.237 0 0 r
.5548 .26534 .56194 .26592 .57577 .26903 .5687 .26866 Metetra
.388 0 0 r
.5687 .26866 .57577 .26903 .58979 .27445 .58279 .27414 Metetra
.478 0 0 r
.58279 .27414 .58979 .27445 .60403 .28182 .59708 .28142 Metetra
.235 0 0 r
.59708 .28142 .60403 .28182 .61849 .29068 .61144 .28472 Metetra
.643 .836 .975 r
.61144 .28472 .61849 .29068 .63277 .28887 .62569 .27979 Metetra
.656 .751 .92 r
.62569 .27979 .63277 .28887 .64704 .28396 .64 .27483 Metetra
.656 .751 .92 r
.64 .27483 .64704 .28396 .66138 .27903 .65439 .26985 Metetra
.656 .751 .92 r
.65439 .26985 .66138 .27903 .6758 .27407 .66886 .26485 Metetra
.656 .751 .92 r
.66886 .26485 .6758 .27407 .69029 .26909 .6834 .25982 Metetra
.656 .751 .92 r
.6834 .25982 .69029 .26909 .70485 .26408 .69801 .25476 Metetra
.656 .751 .92 r
.69801 .25476 .70485 .26408 .71949 .25904 .7127 .24968 Metetra
.656 .751 .92 r
.7127 .24968 .71949 .25904 .7342 .25398 .72747 .24457 Metetra
.656 .751 .92 r
.72747 .24457 .7342 .25398 .74899 .24889 .74231 .23943 Metetra
.656 .751 .92 r
.74231 .23943 .74899 .24889 .76386 .24378 .75724 .23427 Metetra
.656 .751 .92 r
.75724 .23427 .76386 .24378 .7788 .23864 .77223 .22908 Metetra
.656 .751 .92 r
.11041 .4475 .1191 .45508 .13094 .45098 .12229 .44336 Metetra
.656 .751 .92 r
.12229 .44336 .13094 .45098 .14284 .44686 .13421 .43921 Metetra
.656 .751 .92 r
.13421 .43921 .14284 .44686 .15479 .44273 .1462 .43504 Metetra
.656 .751 .92 r
.1462 .43504 .15479 .44273 .1668 .43857 .15824 .43085 Metetra
.656 .751 .92 r
.15824 .43085 .1668 .43857 .17886 .4344 .17034 .42664 Metetra
.656 .751 .92 r
.17034 .42664 .17886 .4344 .19099 .4302 .18249 .42241 Metetra
.656 .751 .92 r
.18249 .42241 .19099 .4302 .20316 .42599 .1947 .41816 Metetra
.656 .751 .92 r
.1947 .41816 .20316 .42599 .2154 .42175 .20697 .41388 Metetra
.656 .751 .92 r
.20697 .41388 .2154 .42175 .2277 .4175 .2193 .40959 Metetra
.656 .751 .92 r
.2193 .40959 .2277 .4175 .24005 .41323 .23169 .40528 Metetra
.656 .751 .92 r
.23169 .40528 .24005 .41323 .25246 .40893 .24414 .40095 Metetra
.656 .751 .92 r
.24414 .40095 .25246 .40893 .26454 .40951 .25664 .3966 Metetra
.289 .46 .857 r
.25664 .3966 .26454 .40951 .27613 .41761 .2685 .40116 Metetra
.274 .387 .796 r
.2685 .40116 .27613 .41761 .28799 .42419 .28034 .40757 Metetra
.363 .439 .805 r
.28034 .40757 .28799 .42419 .30013 .42877 .29246 .41216 Metetra
.448 .49 .81 r
.29246 .41216 .30013 .42877 .31256 .43096 .30485 .41456 Metetra
.526 .537 .81 r
.30485 .41456 .31256 .43096 .32526 .43049 .31752 .41448 Metetra
.594 .579 .806 r
.31752 .41448 .32526 .43049 .33821 .42721 .33045 .41177 Metetra
.652 .615 .8 r
.33045 .41177 .33821 .42721 .35139 .42112 .3436 .40643 Metetra
.699 .647 .794 r
.3436 .40643 .35139 .42112 .36475 .41238 .35693 .39859 Metetra
.738 .674 .789 r
.35693 .39859 .36475 .41238 .37825 .40127 .37041 .38849 Metetra
.769 .7 .786 r
.37041 .38849 .37825 .40127 .39184 .38819 .384 .37653 Metetra
.795 .723 .785 r
.384 .37653 .39184 .38819 .40548 .37363 .39764 .36314 Metetra
.815 .747 .789 r
.39764 .36314 .40548 .37363 .41913 .35816 .41131 .34887 Metetra
.83 .771 .796 r
.41131 .34887 .41913 .35816 .43276 .34234 .42497 .33427 Metetra
.84 .797 .81 r
.42497 .33427 .43276 .34234 .44637 .32679 .43861 .3199 Metetra
.843 .825 .83 r
.43861 .3199 .44637 .32679 .45992 .31205 .45221 .3063 Metetra
.838 .856 .858 r
.45221 .3063 .45992 .31205 .47344 .29865 .46579 .29397 Metetra
.817 .889 .895 r
.46579 .29397 .47344 .29865 .48692 .28705 .47933 .28334 Metetra
.767 .917 .938 r
.47933 .28334 .48692 .28705 .5004 .27761 .49287 .27477 Metetra
.667 .923 .974 r
.49287 .27477 .5004 .27761 .51389 .2706 .50644 .26851 Metetra
.488 .875 .97 r
.50644 .26851 .51389 .2706 .52743 .2662 .52005 .26472 Metetra
.234 .741 .888 r
.52005 .26472 .52743 .2662 .54106 .26447 .53374 .26345 Metetra
0 .548 .741 r
.53374 .26345 .54106 .26447 .5548 .26534 .54756 .26463 Metetra
.24 0 0 r
.54756 .26463 .5548 .26534 .5687 .26866 .56153 .2681 Metetra
.377 0 0 r
.56153 .2681 .5687 .26866 .58279 .27414 .57567 .27357 Metetra
.452 0 0 r
.57567 .27357 .58279 .27414 .59708 .28142 .59002 .28055 Metetra
.477 .891 .92 r
.59002 .28055 .59708 .28142 .61144 .28472 .60424 .2756 Metetra
.656 .751 .92 r
.60424 .2756 .61144 .28472 .62569 .27979 .61853 .27062 Metetra
.656 .751 .92 r
.61853 .27062 .62569 .27979 .64 .27483 .6329 .26562 Metetra
.656 .751 .92 r
.6329 .26562 .64 .27483 .65439 .26985 .64734 .26059 Metetra
.656 .751 .92 r
.64734 .26059 .65439 .26985 .66886 .26485 .66185 .25554 Metetra
.656 .751 .92 r
.66185 .25554 .66886 .26485 .6834 .25982 .67645 .25046 Metetra
.656 .751 .92 r
.67645 .25046 .6834 .25982 .69801 .25476 .69111 .24536 Metetra
.656 .751 .92 r
.69111 .24536 .69801 .25476 .7127 .24968 .70585 .24022 Metetra
.656 .751 .92 r
.70585 .24022 .7127 .24968 .72747 .24457 .72067 .23506 Metetra
.656 .751 .92 r
.72067 .23506 .72747 .24457 .74231 .23943 .73557 .22988 Metetra
.656 .751 .92 r
.73557 .22988 .74231 .23943 .75724 .23427 .75055 .22467 Metetra
.656 .751 .92 r
.75055 .22467 .75724 .23427 .77223 .22908 .7656 .21943 Metetra
.656 .751 .92 r
.10165 .43985 .11041 .4475 .12229 .44336 .11356 .43568 Metetra
.656 .751 .92 r
.11356 .43568 .12229 .44336 .13421 .43921 .12552 .4315 Metetra
.656 .751 .92 r
.12552 .4315 .13421 .43921 .1462 .43504 .13753 .42729 Metetra
.656 .751 .92 r
.13753 .42729 .1462 .43504 .15824 .43085 .14961 .42306 Metetra
.656 .751 .92 r
.14961 .42306 .15824 .43085 .17034 .42664 .16174 .41881 Metetra
.656 .751 .92 r
.16174 .41881 .17034 .42664 .18249 .42241 .17392 .41454 Metetra
.656 .751 .92 r
.17392 .41454 .18249 .42241 .1947 .41816 .18617 .41025 Metetra
.656 .751 .92 r
.18617 .41025 .1947 .41816 .20697 .41388 .19847 .40595 Metetra
.656 .751 .92 r
.19847 .40595 .20697 .41388 .2193 .40959 .21084 .40162 Metetra
.656 .751 .92 r
.21084 .40162 .2193 .40959 .23169 .40528 .22326 .39727 Metetra
.656 .751 .92 r
.22326 .39727 .23169 .40528 .24414 .40095 .23574 .3929 Metetra
.656 .751 .92 r
.23574 .3929 .24414 .40095 .25664 .3966 .24828 .3885 Metetra
.622 .741 .932 r
.24828 .3885 .25664 .3966 .2685 .40116 .2608 .38505 Metetra
.274 .392 .802 r
.2608 .38505 .2685 .40116 .28034 .40757 .27264 .39122 Metetra
.357 .44 .81 r
.27264 .39122 .28034 .40757 .29246 .41216 .28473 .39576 Metetra
.439 .488 .814 r
.28473 .39576 .29246 .41216 .30485 .41456 .29711 .39829 Metetra
.514 .533 .814 r
.29711 .39829 .30485 .41456 .31752 .41448 .30974 .39855 Metetra
.58 .574 .811 r
.30974 .39855 .31752 .41448 .33045 .41177 .32264 .39637 Metetra
.637 .61 .806 r
.32264 .39637 .33045 .41177 .3436 .40643 .33575 .39174 Metetra
.684 .641 .801 r
.33575 .39174 .3436 .40643 .35693 .39859 .34906 .38476 Metetra
.723 .67 .797 r
.34906 .38476 .35693 .39859 .37041 .38849 .36253 .37566 Metetra
.755 .696 .795 r
.36253 .37566 .37041 .38849 .384 .37653 .3761 .36479 Metetra
.781 .72 .796 r
.3761 .36479 .384 .37653 .39764 .36314 .38974 .35258 Metetra
.802 .745 .8 r
.38974 .35258 .39764 .36314 .41131 .34887 .40342 .33951 Metetra
.817 .77 .809 r
.40342 .33951 .41131 .34887 .42497 .33427 .4171 .32612 Metetra
.826 .797 .824 r
.4171 .32612 .42497 .33427 .43861 .3199 .43077 .31294 Metetra
.829 .826 .845 r
.43077 .31294 .43861 .3199 .45221 .3063 .44442 .30048 Metetra
.821 .857 .875 r
.44442 .30048 .45221 .3063 .46579 .29397 .45804 .28921 Metetra
.795 .888 .912 r
.45804 .28921 .46579 .29397 .47933 .28334 .47165 .27955 Metetra
.739 .913 .953 r
.47165 .27955 .47933 .28334 .49287 .27477 .48525 .27183 Metetra
.63 .911 .982 r
.48525 .27183 .49287 .27477 .50644 .26851 .49888 .26629 Metetra
.448 .853 .968 r
.49888 .26629 .50644 .26851 .52005 .26472 .51256 .26308 Metetra
.204 .719 .882 r
.51256 .26308 .52005 .26472 .53374 .26345 .52633 .26222 Metetra
0 .539 .744 r
.52633 .26222 .53374 .26345 .54756 .26463 .54021 .26366 Metetra
.23 0 0 r
.54021 .26366 .54756 .26463 .56153 .2681 .55424 .26722 Metetra
.356 0 0 r
.55424 .26722 .56153 .2681 .57567 .27357 .56844 .27261 Metetra
.179 .71 .842 r
.56844 .27261 .57567 .27357 .59002 .28055 .58269 .27139 Metetra
.656 .751 .92 r
.58269 .27139 .59002 .28055 .60424 .2756 .59696 .26639 Metetra
.656 .751 .92 r
.59696 .26639 .60424 .2756 .61853 .27062 .61131 .26137 Metetra
.656 .751 .92 r
.61131 .26137 .61853 .27062 .6329 .26562 .62572 .25632 Metetra
.656 .751 .92 r
.62572 .25632 .6329 .26562 .64734 .26059 .64021 .25124 Metetra
.656 .751 .92 r
.64021 .25124 .64734 .26059 .66185 .25554 .65478 .24614 Metetra
.656 .751 .92 r
.65478 .24614 .66185 .25554 .67645 .25046 .66942 .24101 Metetra
.656 .751 .92 r
.66942 .24101 .67645 .25046 .69111 .24536 .68414 .23586 Metetra
.656 .751 .92 r
.68414 .23586 .69111 .24536 .70585 .24022 .69894 .23068 Metetra
.656 .751 .92 r
.69894 .23068 .70585 .24022 .72067 .23506 .71381 .22547 Metetra
.656 .751 .92 r
.71381 .22547 .72067 .23506 .73557 .22988 .72876 .22023 Metetra
.656 .751 .92 r
.72876 .22023 .73557 .22988 .75055 .22467 .74379 .21497 Metetra
.656 .751 .92 r
.74379 .21497 .75055 .22467 .7656 .21943 .7589 .20968 Metetra
.656 .751 .92 r
.09282 .43214 .10165 .43985 .11356 .43568 .10475 .42794 Metetra
.656 .751 .92 r
.10475 .42794 .11356 .43568 .12552 .4315 .11675 .42371 Metetra
.656 .751 .92 r
.11675 .42371 .12552 .4315 .13753 .42729 .12879 .41947 Metetra
.656 .751 .92 r
.12879 .41947 .13753 .42729 .14961 .42306 .1409 .4152 Metetra
.656 .751 .92 r
.1409 .4152 .14961 .42306 .16174 .41881 .15306 .41092 Metetra
.656 .751 .92 r
.15306 .41092 .16174 .41881 .17392 .41454 .16528 .40661 Metetra
.656 .751 .92 r
.16528 .40661 .17392 .41454 .18617 .41025 .17756 .40228 Metetra
.656 .751 .92 r
.17756 .40228 .18617 .41025 .19847 .40595 .1899 .39794 Metetra
.656 .751 .92 r
.1899 .39794 .19847 .40595 .21084 .40162 .20229 .39357 Metetra
.656 .751 .92 r
.20229 .39357 .21084 .40162 .22326 .39727 .21475 .38918 Metetra
.656 .751 .92 r
.21475 .38918 .22326 .39727 .23574 .3929 .22727 .38477 Metetra
.656 .751 .92 r
.22727 .38477 .23574 .3929 .24828 .3885 .23984 .38034 Metetra
.656 .751 .92 r
.23984 .38034 .24828 .3885 .2608 .38505 .25248 .37589 Metetra
.502 .668 .938 r
.25248 .37589 .2608 .38505 .27264 .39122 .26487 .37525 Metetra
.352 .445 .816 r
.26487 .37525 .27264 .39122 .28473 .39576 .27695 .37967 Metetra
.43 .489 .819 r
.27695 .37967 .28473 .39576 .29711 .39829 .2893 .38228 Metetra
.502 .532 .819 r
.2893 .38228 .29711 .39829 .30974 .39855 .30192 .38281 Metetra
.567 .571 .817 r
.30192 .38281 .30974 .39855 .32264 .39637 .31478 .38111 Metetra
.623 .606 .813 r
.31478 .38111 .32264 .39637 .33575 .39174 .32786 .37713 Metetra
.67 .637 .809 r
.32786 .37713 .33575 .39174 .34906 .38476 .34115 .37097 Metetra
.709 .666 .806 r
.34115 .37097 .34906 .38476 .36253 .37566 .35458 .36283 Metetra
.741 .692 .805 r
.35458 .36283 .36253 .37566 .3761 .36479 .36814 .35303 Metetra
.767 .718 .806 r
.36814 .35303 .3761 .36479 .38974 .35258 .38178 .34196 Metetra
.787 .743 .812 r
.38178 .34196 .38974 .35258 .40342 .33951 .39546 .33008 Metetra
.802 .769 .822 r
.39546 .33008 .40342 .33951 .4171 .32612 .40916 .31789 Metetra
.811 .796 .838 r
.40916 .31789 .4171 .32612 .43077 .31294 .42286 .30588 Metetra
.812 .825 .861 r
.42286 .30588 .43077 .31294 .44442 .30048 .43654 .29454 Metetra
.801 .856 .891 r
.43654 .29454 .44442 .30048 .45804 .28921 .45021 .28432 Metetra
.771 .885 .927 r
.45021 .28432 .45804 .28921 .47165 .27955 .46387 .27561 Metetra
.709 .904 .965 r
.46387 .27561 .47165 .27955 .48525 .27183 .47753 .26871 Metetra
.595 .896 .988 r
.47753 .26871 .48525 .27183 .49888 .26629 .49122 .26385 Metetra
.415 .832 .967 r
.49122 .26385 .49888 .26629 .51256 .26308 .50497 .26117 Metetra
.186 .703 .884 r
.50497 .26117 .51256 .26308 .52633 .26222 .5188 .26068 Metetra
0 .54 .759 r
.5188 .26068 .52633 .26222 .54021 .26366 .53275 .26232 Metetra
.208 0 0 r
.53275 .26232 .54021 .26366 .55424 .26722 .54684 .26589 Metetra
0 .558 .762 r
.54684 .26589 .55424 .26722 .56844 .27261 .56106 .26716 Metetra
.637 .852 .982 r
.56106 .26716 .56844 .27261 .58269 .27139 .5753 .26214 Metetra
.656 .751 .92 r
.5753 .26214 .58269 .27139 .59696 .26639 .58962 .2571 Metetra
.656 .751 .92 r
.58962 .2571 .59696 .26639 .61131 .26137 .60401 .25203 Metetra
.656 .751 .92 r
.60401 .25203 .61131 .26137 .62572 .25632 .61848 .24693 Metetra
.656 .751 .92 r
.61848 .24693 .62572 .25632 .64021 .25124 .63302 .24181 Metetra
.656 .751 .92 r
.63302 .24181 .64021 .25124 .65478 .24614 .64764 .23665 Metetra
.656 .751 .92 r
.64764 .23665 .65478 .24614 .66942 .24101 .66234 .23148 Metetra
.656 .751 .92 r
.66234 .23148 .66942 .24101 .68414 .23586 .67711 .22627 Metetra
.656 .751 .92 r
.67711 .22627 .68414 .23586 .69894 .23068 .69196 .22104 Metetra
.656 .751 .92 r
.69196 .22104 .69894 .23068 .71381 .22547 .70688 .21578 Metetra
.656 .751 .92 r
.70688 .21578 .71381 .22547 .72876 .22023 .72189 .21049 Metetra
.656 .751 .92 r
.72189 .21049 .72876 .22023 .74379 .21497 .73698 .20518 Metetra
.656 .751 .92 r
.73698 .20518 .74379 .21497 .7589 .20968 .75214 .19983 Metetra
.656 .751 .92 r
.08391 .42436 .09282 .43214 .10475 .42794 .09587 .42012 Metetra
.656 .751 .92 r
.09587 .42012 .10475 .42794 .11675 .42371 .1079 .41586 Metetra
.656 .751 .92 r
.1079 .41586 .11675 .42371 .12879 .41947 .11998 .41158 Metetra
.656 .751 .92 r
.11998 .41158 .12879 .41947 .1409 .4152 .13211 .40727 Metetra
.656 .751 .92 r
.13211 .40727 .1409 .4152 .15306 .41092 .14431 .40295 Metetra
.656 .751 .92 r
.14431 .40295 .15306 .41092 .16528 .40661 .15656 .39861 Metetra
.656 .751 .92 r
.15656 .39861 .16528 .40661 .17756 .40228 .16887 .39424 Metetra
.656 .751 .92 r
.16887 .39424 .17756 .40228 .1899 .39794 .18124 .38986 Metetra
.656 .751 .92 r
.18124 .38986 .1899 .39794 .20229 .39357 .19368 .38545 Metetra
.656 .751 .92 r
.19368 .38545 .20229 .39357 .21475 .38918 .20617 .38102 Metetra
.656 .751 .92 r
.20617 .38102 .21475 .38918 .22727 .38477 .21872 .37657 Metetra
.656 .751 .92 r
.21872 .37657 .22727 .38477 .23984 .38034 .23133 .3721 Metetra
.656 .751 .92 r
.23133 .3721 .23984 .38034 .25248 .37589 .244 .36761 Metetra
.656 .751 .92 r
.244 .36761 .25248 .37589 .26487 .37525 .25674 .36309 Metetra
.459 .577 .886 r
.25674 .36309 .26487 .37525 .27695 .37967 .2691 .364 Metetra
.422 .492 .827 r
.2691 .364 .27695 .37967 .2893 .38228 .28144 .36662 Metetra
.491 .532 .826 r
.28144 .36662 .2893 .38228 .30192 .38281 .29402 .36736 Metetra
.554 .569 .824 r
.29402 .36736 .30192 .38281 .31478 .38111 .30686 .36607 Metetra
.608 .603 .821 r
.30686 .36607 .31478 .38111 .32786 .37713 .31992 .36269 Metetra
.655 .634 .817 r
.31992 .36269 .32786 .37713 .34115 .37097 .33317 .35729 Metetra
.694 .663 .815 r
.33317 .35729 .34115 .37097 .35458 .36283 .34658 .35007 Metetra
.726 .689 .815 r
.34658 .35007 .35458 .36283 .36814 .35303 .36012 .34129 Metetra
.752 .715 .818 r
.36012 .34129 .36814 .35303 .38178 .34196 .37375 .33132 Metetra
.772 .741 .824 r
.37375 .33132 .38178 .34196 .39546 .33008 .38743 .32059 Metetra
.786 .767 .836 r
.38743 .32059 .39546 .33008 .40916 .31789 .40114 .30956 Metetra
.794 .794 .852 r
.40114 .30956 .40916 .31789 .42286 .30588 .41486 .2987 Metetra
.793 .823 .876 r
.41486 .2987 .42286 .30588 .43654 .29454 .42858 .28845 Metetra
.779 .852 .906 r
.42858 .28845 .43654 .29454 .45021 .28432 .44229 .27924 Metetra
.745 .879 .941 r
.44229 .27924 .45021 .28432 .46387 .27561 .45599 .27144 Metetra
.678 .893 .975 r
.45599 .27144 .46387 .27561 .47753 .26871 .46971 .26532 Metetra
.562 .878 .992 r
.46971 .26532 .47753 .26871 .49122 .26385 .48346 .2611 Metetra
.39 .813 .969 r
.48346 .2611 .49122 .26385 .50497 .26117 .49727 .2589 Metetra
.181 .694 .893 r
.49727 .2589 .50497 .26117 .5188 .26068 .51117 .25872 Metetra
0 .55 .785 r
.51117 .25872 .5188 .26068 .53275 .26232 .52518 .26048 Metetra
0 .497 .741 r
.52518 .26048 .53275 .26232 .54684 .26589 .53933 .26292 Metetra
.58 .901 .984 r
.53933 .26292 .54684 .26589 .56106 .26716 .55355 .25788 Metetra
.656 .751 .92 r
.55355 .25788 .56106 .26716 .5753 .26214 .56784 .25281 Metetra
.656 .751 .92 r
.56784 .25281 .5753 .26214 .58962 .2571 .58221 .24771 Metetra
.656 .751 .92 r
.58221 .24771 .58962 .2571 .60401 .25203 .59665 .2426 Metetra
.656 .751 .92 r
.59665 .2426 .60401 .25203 .61848 .24693 .61117 .23745 Metetra
.656 .751 .92 r
.61117 .23745 .61848 .24693 .63302 .24181 .62576 .23228 Metetra
.656 .751 .92 r
.62576 .23228 .63302 .24181 .64764 .23665 .64043 .22707 Metetra
.656 .751 .92 r
.64043 .22707 .64764 .23665 .66234 .23148 .65518 .22185 Metetra
.656 .751 .92 r
.65518 .22185 .66234 .23148 .67711 .22627 .67 .21659 Metetra
.656 .751 .92 r
.67 .21659 .67711 .22627 .69196 .22104 .68491 .21131 Metetra
.656 .751 .92 r
.68491 .21131 .69196 .22104 .70688 .21578 .69989 .206 Metetra
.656 .751 .92 r
.69989 .206 .70688 .21578 .72189 .21049 .71495 .20066 Metetra
.656 .751 .92 r
.71495 .20066 .72189 .21049 .73698 .20518 .73009 .19529 Metetra
.656 .751 .92 r
.73009 .19529 .73698 .20518 .75214 .19983 .74531 .18989 Metetra
.656 .751 .92 r
.07492 .41652 .08391 .42436 .09587 .42012 .08691 .41224 Metetra
.656 .751 .92 r
.08691 .41224 .09587 .42012 .1079 .41586 .09897 .40794 Metetra
.656 .751 .92 r
.09897 .40794 .1079 .41586 .11998 .41158 .11108 .40362 Metetra
.656 .751 .92 r
.11108 .40362 .11998 .41158 .13211 .40727 .12325 .39928 Metetra
.656 .751 .92 r
.12325 .39928 .13211 .40727 .14431 .40295 .13548 .39492 Metetra
.656 .751 .92 r
.13548 .39492 .14431 .40295 .15656 .39861 .14776 .39053 Metetra
.656 .751 .92 r
.14776 .39053 .15656 .39861 .16887 .39424 .16011 .38613 Metetra
.656 .751 .92 r
.16011 .38613 .16887 .39424 .18124 .38986 .17251 .3817 Metetra
.656 .751 .92 r
.17251 .3817 .18124 .38986 .19368 .38545 .18498 .37726 Metetra
.656 .751 .92 r
.18498 .37726 .19368 .38545 .20617 .38102 .19751 .37279 Metetra
.656 .751 .92 r
.19751 .37279 .20617 .38102 .21872 .37657 .21009 .3683 Metetra
.656 .751 .92 r
.21009 .3683 .21872 .37657 .23133 .3721 .22274 .36379 Metetra
.656 .751 .92 r
.22274 .36379 .23133 .3721 .244 .36761 .23545 .35926 Metetra
.656 .751 .92 r
.23545 .35926 .244 .36761 .25674 .36309 .24822 .3547 Metetra
.656 .751 .92 r
.24822 .3547 .25674 .36309 .2691 .364 .26106 .35012 Metetra
.457 .544 .857 r
.26106 .35012 .2691 .364 .28144 .36662 .27349 .35139 Metetra
.481 .535 .835 r
.27349 .35139 .28144 .36662 .29402 .36736 .28606 .35228 Metetra
.542 .57 .832 r
.28606 .35228 .29402 .36736 .30686 .36607 .29887 .35133 Metetra
.595 .602 .829 r
.29887 .35133 .30686 .36607 .31992 .36269 .3119 .34848 Metetra
.64 .632 .827 r
.3119 .34848 .31992 .36269 .33317 .35729 .32513 .34379 Metetra
.678 .66 .825 r
.32513 .34379 .33317 .35729 .34658 .35007 .33852 .33741 Metetra
.71 .687 .826 r
.33852 .33741 .34658 .35007 .36012 .34129 .35204 .3296 Metetra
.736 .713 .83 r
.35204 .3296 .36012 .34129 .37375 .33132 .36565 .32068 Metetra
.755 .738 .837 r
.36565 .32068 .37375 .33132 .38743 .32059 .37933 .31105 Metetra
.769 .765 .849 r
.37933 .31105 .38743 .32059 .40114 .30956 .39305 .30114 Metetra
.775 .792 .867 r
.39305 .30114 .40114 .30956 .41486 .2987 .40679 .29137 Metetra
.772 .819 .89 r
.40679 .29137 .41486 .2987 .42858 .28845 .42053 .28217 Metetra
.755 .846 .92 r
.42053 .28217 .42858 .28845 .44229 .27924 .43427 .27393 Metetra
.717 .869 .953 r
.43427 .27393 .44229 .27924 .45599 .27144 .44803 .26698 Metetra
.648 .878 .983 r
.44803 .26698 .45599 .27144 .46971 .26532 .4618 .26159 Metetra
.534 .859 .996 r
.4618 .26159 .46971 .26532 .48346 .2611 .47561 .25796 Metetra
.373 .796 .973 r
.47561 .25796 .48346 .2611 .49727 .2589 .48948 .25617 Metetra
.186 .69 .907 r
.48948 .25617 .49727 .2589 .51117 .25872 .50343 .25623 Metetra
.01 .566 .818 r
.50343 .25623 .51117 .25872 .52518 .26048 .5175 .25806 Metetra
.524 .889 .974 r
.5175 .25806 .52518 .26048 .53933 .26292 .5317 .25359 Metetra
.656 .751 .92 r
.5317 .25359 .53933 .26292 .55355 .25788 .54597 .2485 Metetra
.656 .751 .92 r
.54597 .2485 .55355 .25788 .56784 .25281 .56031 .24338 Metetra
.656 .751 .92 r
.56031 .24338 .56784 .25281 .58221 .24771 .57473 .23824 Metetra
.656 .751 .92 r
.57473 .23824 .58221 .24771 .59665 .2426 .58922 .23307 Metetra
.656 .751 .92 r
.58922 .23307 .59665 .2426 .61117 .23745 .60379 .22788 Metetra
.656 .751 .92 r
.60379 .22788 .61117 .23745 .62576 .23228 .61843 .22265 Metetra
.656 .751 .92 r
.61843 .22265 .62576 .23228 .64043 .22707 .63315 .2174 Metetra
.656 .751 .92 r
.63315 .2174 .64043 .22707 .65518 .22185 .64795 .21212 Metetra
.656 .751 .92 r
.64795 .21212 .65518 .22185 .67 .21659 .66283 .20682 Metetra
.656 .751 .92 r
.66283 .20682 .67 .21659 .68491 .21131 .67779 .20148 Metetra
.656 .751 .92 r
.67779 .20148 .68491 .21131 .69989 .206 .69282 .19612 Metetra
.656 .751 .92 r
.69282 .19612 .69989 .206 .71495 .20066 .70794 .19073 Metetra
.656 .751 .92 r
.70794 .19073 .71495 .20066 .73009 .19529 .72314 .18531 Metetra
.656 .751 .92 r
.72314 .18531 .73009 .19529 .74531 .18989 .73842 .17986 Metetra
.656 .751 .92 r
.06585 .4086 .07492 .41652 .08691 .41224 .07788 .40428 Metetra
.656 .751 .92 r
.07788 .40428 .08691 .41224 .09897 .40794 .08996 .39995 Metetra
.656 .751 .92 r
.08996 .39995 .09897 .40794 .11108 .40362 .10211 .39559 Metetra
.656 .751 .92 r
.10211 .39559 .11108 .40362 .12325 .39928 .11431 .39121 Metetra
.656 .751 .92 r
.11431 .39121 .12325 .39928 .13548 .39492 .12657 .38681 Metetra
.656 .751 .92 r
.12657 .38681 .13548 .39492 .14776 .39053 .13889 .38239 Metetra
.656 .751 .92 r
.13889 .38239 .14776 .39053 .16011 .38613 .15127 .37794 Metetra
.656 .751 .92 r
.15127 .37794 .16011 .38613 .17251 .3817 .16371 .37348 Metetra
.656 .751 .92 r
.16371 .37348 .17251 .3817 .18498 .37726 .17621 .36899 Metetra
.656 .751 .92 r
.17621 .36899 .18498 .37726 .19751 .37279 .18877 .36448 Metetra
.656 .751 .92 r
.18877 .36448 .19751 .37279 .21009 .3683 .20139 .35995 Metetra
.656 .751 .92 r
.20139 .35995 .21009 .3683 .22274 .36379 .21407 .3554 Metetra
.656 .751 .92 r
.21407 .3554 .22274 .36379 .23545 .35926 .22682 .35083 Metetra
.656 .751 .92 r
.22682 .35083 .23545 .35926 .24822 .3547 .23963 .34623 Metetra
.656 .751 .92 r
.23963 .34623 .24822 .3547 .26106 .35012 .2525 .34161 Metetra
.656 .751 .92 r
.2525 .34161 .26106 .35012 .27349 .35139 .26544 .33697 Metetra
.482 .55 .849 r
.26544 .33697 .27349 .35139 .28606 .35228 .27802 .33763 Metetra
.53 .572 .842 r
.27802 .33763 .28606 .35228 .29887 .35133 .29081 .33695 Metetra
.581 .603 .839 r
.29081 .33695 .29887 .35133 .3119 .34848 .30382 .33456 Metetra
.625 .632 .837 r
.30382 .33456 .3119 .34848 .32513 .34379 .31702 .3305 Metetra
.663 .659 .836 r
.31702 .3305 .32513 .34379 .33852 .33741 .33038 .3249 Metetra
.694 .685 .837 r
.33038 .3249 .33852 .33741 .35204 .3296 .34388 .31799 Metetra
.719 .711 .842 r
.34388 .31799 .35204 .3296 .36565 .32068 .35748 .31006 Metetra
.737 .736 .85 r
.35748 .31006 .36565 .32068 .37933 .31105 .37116 .30147 Metetra
.75 .761 .862 r
.37116 .30147 .37933 .31105 .39305 .30114 .38488 .29261 Metetra
.754 .788 .88 r
.38488 .29261 .39305 .30114 .40679 .29137 .39863 .28388 Metetra
.749 .814 .903 r
.39863 .28388 .40679 .29137 .42053 .28217 .4124 .27566 Metetra
.73 .838 .932 r
.4124 .27566 .42053 .28217 .43427 .27393 .42618 .26833 Metetra
.689 .857 .962 r
.42618 .26833 .43427 .27393 .44803 .26698 .43997 .26218 Metetra
.619 .861 .989 r
.43997 .26218 .44803 .26698 .4618 .26159 .45379 .25746 Metetra
.511 .84 .998 r
.45379 .25746 .4618 .26159 .47561 .25796 .46765 .25434 Metetra
.366 .782 .978 r
.46765 .25434 .47561 .25796 .48948 .25617 .48158 .2529 Metetra
.202 .691 .925 r
.48158 .2529 .48948 .25617 .50343 .25623 .49559 .25314 Metetra
.512 .87 .987 r
.49559 .25314 .50343 .25623 .5175 .25806 .50975 .24928 Metetra
.656 .767 .931 r
.50975 .24928 .5175 .25806 .5317 .25359 .52399 .24417 Metetra
.656 .751 .92 r
.52399 .24417 .5317 .25359 .54597 .2485 .53831 .23904 Metetra
.656 .751 .92 r
.53831 .23904 .54597 .2485 .56031 .24338 .5527 .23387 Metetra
.656 .751 .92 r
.5527 .23387 .56031 .24338 .57473 .23824 .56717 .22868 Metetra
.656 .751 .92 r
.56717 .22868 .57473 .23824 .58922 .23307 .58171 .22346 Metetra
.656 .751 .92 r
.58171 .22346 .58922 .23307 .60379 .22788 .59633 .21821 Metetra
.656 .751 .92 r
.59633 .21821 .60379 .22788 .61843 .22265 .61103 .21294 Metetra
.656 .751 .92 r
.61103 .21294 .61843 .22265 .63315 .2174 .6258 .20763 Metetra
.656 .751 .92 r
.6258 .20763 .63315 .2174 .64795 .21212 .64065 .2023 Metetra
.656 .751 .92 r
.64065 .2023 .64795 .21212 .66283 .20682 .65559 .19695 Metetra
.656 .751 .92 r
.65559 .19695 .66283 .20682 .67779 .20148 .6706 .19156 Metetra
.656 .751 .92 r
.6706 .19156 .67779 .20148 .69282 .19612 .68569 .18614 Metetra
.656 .751 .92 r
.68569 .18614 .69282 .19612 .70794 .19073 .70086 .1807 Metetra
.656 .751 .92 r
.70086 .1807 .70794 .19073 .72314 .18531 .71611 .17522 Metetra
.656 .751 .92 r
.71611 .17522 .72314 .18531 .73842 .17986 .73145 .16972 Metetra
.656 .751 .92 r
.0567 .40061 .06585 .4086 .07788 .40428 .06876 .39626 Metetra
.656 .751 .92 r
.06876 .39626 .07788 .40428 .08996 .39995 .08088 .39188 Metetra
.656 .751 .92 r
.08088 .39188 .08996 .39995 .10211 .39559 .09305 .38749 Metetra
.656 .751 .92 r
.09305 .38749 .10211 .39559 .11431 .39121 .10529 .38307 Metetra
.656 .751 .92 r
.10529 .38307 .11431 .39121 .12657 .38681 .11758 .37863 Metetra
.656 .751 .92 r
.11758 .37863 .12657 .38681 .13889 .38239 .12993 .37417 Metetra
.656 .751 .92 r
.12993 .37417 .13889 .38239 .15127 .37794 .14235 .36968 Metetra
.656 .751 .92 r
.14235 .36968 .15127 .37794 .16371 .37348 .15482 .36518 Metetra
.656 .751 .92 r
.15482 .36518 .16371 .37348 .17621 .36899 .16735 .36065 Metetra
.656 .751 .92 r
.16735 .36065 .17621 .36899 .18877 .36448 .17995 .3561 Metetra
.656 .751 .92 r
.17995 .3561 .18877 .36448 .20139 .35995 .19261 .35153 Metetra
.656 .751 .92 r
.19261 .35153 .20139 .35995 .21407 .3554 .20533 .34694 Metetra
.656 .751 .92 r
.20533 .34694 .21407 .3554 .22682 .35083 .21811 .34232 Metetra
.656 .751 .92 r
.21811 .34232 .22682 .35083 .23963 .34623 .23096 .33768 Metetra
.656 .751 .92 r
.23096 .33768 .23963 .34623 .2525 .34161 .24387 .33302 Metetra
.656 .751 .92 r
.24387 .33302 .2525 .34161 .26544 .33697 .25684 .32834 Metetra
.656 .751 .92 r
.25684 .32834 .26544 .33697 .27802 .33763 .26988 .32363 Metetra
.524 .582 .855 r
.26988 .32363 .27802 .33763 .29081 .33695 .28267 .323 Metetra
.568 .605 .85 r
.28267 .323 .29081 .33695 .30382 .33456 .29566 .32099 Metetra
.611 .633 .848 r
.29566 .32099 .30382 .33456 .31702 .3305 .30883 .31748 Metetra
.647 .659 .847 r
.30883 .31748 .31702 .3305 .33038 .3249 .32217 .31258 Metetra
.677 .684 .849 r
.32217 .31258 .33038 .3249 .34388 .31799 .33565 .30649 Metetra
.701 .709 .854 r
.33565 .30649 .34388 .31799 .35748 .31006 .34924 .29947 Metetra
.719 .733 .862 r
.34924 .29947 .35748 .31006 .37116 .30147 .36291 .29184 Metetra
.73 .758 .875 r
.36291 .29184 .37116 .30147 .38488 .29261 .37663 .28397 Metetra
.733 .782 .893 r
.37663 .28397 .38488 .29261 .39863 .28388 .3904 .2762 Metetra
.725 .806 .915 r
.3904 .2762 .39863 .28388 .4124 .27566 .40418 .2689 Metetra
.703 .828 .942 r
.40418 .2689 .4124 .27566 .42618 .26833 .41799 .26241 Metetra
.662 .842 .969 r
.41799 .26241 .42618 .26833 .43997 .26218 .43182 .25699 Metetra
.594 .843 .992 r
.43182 .25699 .43997 .26218 .45379 .25746 .44569 .25287 Metetra
.494 .821 1 r
.44569 .25287 .45379 .25746 .46765 .25434 .4596 .25019 Metetra
.366 .769 .984 r
.4596 .25019 .46765 .25434 .48158 .2529 .47358 .24904 Metetra
.552 .868 .995 r
.47358 .24904 .48158 .2529 .49559 .25314 .48771 .24496 Metetra
.655 .783 .942 r
.48771 .24496 .49559 .25314 .50975 .24928 .50193 .23983 Metetra
.656 .751 .92 r
.50193 .23983 .50975 .24928 .52399 .24417 .51622 .23467 Metetra
.656 .751 .92 r
.51622 .23467 .52399 .24417 .53831 .23904 .53058 .22948 Metetra
.656 .751 .92 r
.53058 .22948 .53831 .23904 .5527 .23387 .54502 .22426 Metetra
.656 .751 .92 r
.54502 .22426 .5527 .23387 .56717 .22868 .55954 .21902 Metetra
.656 .751 .92 r
.55954 .21902 .56717 .22868 .58171 .22346 .57413 .21375 Metetra
.656 .751 .92 r
.57413 .21375 .58171 .22346 .59633 .21821 .5888 .20845 Metetra
.656 .751 .92 r
.5888 .20845 .59633 .21821 .61103 .21294 .60355 .20313 Metetra
.656 .751 .92 r
.60355 .20313 .61103 .21294 .6258 .20763 .61838 .19777 Metetra
.656 .751 .92 r
.61838 .19777 .6258 .20763 .64065 .2023 .63328 .19239 Metetra
.656 .751 .92 r
.63328 .19239 .64065 .2023 .65559 .19695 .64827 .18698 Metetra
.656 .751 .92 r
.64827 .18698 .65559 .19695 .6706 .19156 .66334 .18154 Metetra
.656 .751 .92 r
.66334 .18154 .6706 .19156 .68569 .18614 .67848 .17607 Metetra
.656 .751 .92 r
.67848 .17607 .68569 .18614 .70086 .1807 .69371 .17057 Metetra
.656 .751 .92 r
.69371 .17057 .70086 .1807 .71611 .17522 .70902 .16504 Metetra
.656 .751 .92 r
.70902 .16504 .71611 .17522 .73145 .16972 .72441 .15948 Metetra
.656 .751 .92 r
.04747 .39256 .0567 .40061 .06876 .39626 .05956 .38816 Metetra
.656 .751 .92 r
.05956 .38816 .06876 .39626 .08088 .39188 .07171 .38375 Metetra
.656 .751 .92 r
.07171 .38375 .08088 .39188 .09305 .38749 .08392 .37931 Metetra
.656 .751 .92 r
.08392 .37931 .09305 .38749 .10529 .38307 .09618 .37486 Metetra
.656 .751 .92 r
.09618 .37486 .10529 .38307 .11758 .37863 .10851 .37038 Metetra
.656 .751 .92 r
.10851 .37038 .11758 .37863 .12993 .37417 .1209 .36587 Metetra
.656 .751 .92 r
.1209 .36587 .12993 .37417 .14235 .36968 .13334 .36135 Metetra
.656 .751 .92 r
.13334 .36135 .14235 .36968 .15482 .36518 .14585 .35681 Metetra
.656 .751 .92 r
.14585 .35681 .15482 .36518 .16735 .36065 .15842 .35224 Metetra
.656 .751 .92 r
.15842 .35224 .16735 .36065 .17995 .3561 .17105 .34765 Metetra
.656 .751 .92 r
.17105 .34765 .17995 .3561 .19261 .35153 .18375 .34303 Metetra
.656 .751 .92 r
.18375 .34303 .19261 .35153 .20533 .34694 .1965 .3384 Metetra
.656 .751 .92 r
.1965 .3384 .20533 .34694 .21811 .34232 .20932 .33374 Metetra
.656 .751 .92 r
.20932 .33374 .21811 .34232 .23096 .33768 .22221 .32906 Metetra
.656 .751 .92 r
.22221 .32906 .23096 .33768 .24387 .33302 .23515 .32435 Metetra
.656 .751 .92 r
.23515 .32435 .24387 .33302 .25684 .32834 .24817 .31962 Metetra
.656 .751 .92 r
.24817 .31962 .25684 .32834 .26988 .32363 .26124 .31487 Metetra
.656 .751 .92 r
.26124 .31487 .26988 .32363 .28267 .323 .27439 .3101 Metetra
.575 .629 .868 r
.27439 .3101 .28267 .323 .29566 .32099 .28741 .30781 Metetra
.597 .635 .859 r
.28741 .30781 .29566 .32099 .30883 .31748 .30056 .30477 Metetra
.632 .659 .859 r
.30056 .30477 .30883 .31748 .32217 .31258 .31389 .30049 Metetra
.661 .683 .861 r
.31389 .30049 .32217 .31258 .33565 .30649 .32735 .29513 Metetra
.683 .707 .866 r
.32735 .29513 .33565 .30649 .34924 .29947 .34092 .28893 Metetra
.7 .73 .874 r
.34092 .28893 .34924 .29947 .36291 .29184 .35458 .28219 Metetra
.709 .753 .887 r
.35458 .28219 .36291 .29184 .37663 .28397 .36831 .27521 Metetra
.71 .776 .904 r
.36831 .27521 .37663 .28397 .3904 .2762 .38208 .26833 Metetra
.701 .798 .925 r
.38208 .26833 .3904 .2762 .40418 .2689 .39589 .26187 Metetra
.678 .816 .949 r
.39589 .26187 .40418 .2689 .41799 .26241 .40972 .25613 Metetra
.636 .826 .974 r
.40972 .25613 .41799 .26241 .43182 .25699 .42359 .25136 Metetra
.572 .824 .993 r
.42359 .25136 .43182 .25699 .44569 .25287 .4375 .24776 Metetra
.482 .803 1 r
.4375 .24776 .44569 .25287 .4596 .25019 .45146 .24546 Metetra
.614 .867 .99 r
.45146 .24546 .4596 .25019 .47358 .24904 .46557 .24062 Metetra
.655 .778 .939 r
.46557 .24062 .47358 .24904 .48771 .24496 .47976 .23546 Metetra
.656 .751 .92 r
.47976 .23546 .48771 .24496 .50193 .23983 .49402 .23028 Metetra
.656 .751 .92 r
.49402 .23028 .50193 .23983 .51622 .23467 .50836 .22507 Metetra
.656 .751 .92 r
.50836 .22507 .51622 .23467 .53058 .22948 .52278 .21983 Metetra
.656 .751 .92 r
.52278 .21983 .53058 .22948 .54502 .22426 .53727 .21456 Metetra
.656 .751 .92 r
.53727 .21456 .54502 .22426 .55954 .21902 .55184 .20927 Metetra
.656 .751 .92 r
.55184 .20927 .55954 .21902 .57413 .21375 .56648 .20395 Metetra
.656 .751 .92 r
.56648 .20395 .57413 .21375 .5888 .20845 .5812 .1986 Metetra
.656 .751 .92 r
.5812 .1986 .5888 .20845 .60355 .20313 .596 .19322 Metetra
.656 .751 .92 r
.596 .19322 .60355 .20313 .61838 .19777 .61088 .18781 Metetra
.656 .751 .92 r
.61088 .18781 .61838 .19777 .63328 .19239 .62584 .18238 Metetra
.656 .751 .92 r
.62584 .18238 .63328 .19239 .64827 .18698 .64088 .17691 Metetra
.656 .751 .92 r
.64088 .17691 .64827 .18698 .66334 .18154 .656 .17141 Metetra
.656 .751 .92 r
.656 .17141 .66334 .18154 .67848 .17607 .67121 .16589 Metetra
.656 .751 .92 r
.67121 .16589 .67848 .17607 .69371 .17057 .68649 .16034 Metetra
.656 .751 .92 r
.68649 .16034 .69371 .17057 .70902 .16504 .70186 .15475 Metetra
.656 .751 .92 r
.70186 .15475 .70902 .16504 .72441 .15948 .71731 .14914 Metetra
.656 .751 .92 r
.03816 .38443 .04747 .39256 .05956 .38816 .05028 .38 Metetra
.656 .751 .92 r
.05028 .38 .05956 .38816 .07171 .38375 .06246 .37554 Metetra
.656 .751 .92 r
.06246 .37554 .07171 .38375 .08392 .37931 .0747 .37107 Metetra
.656 .751 .92 r
.0747 .37107 .08392 .37931 .09618 .37486 .087 .36657 Metetra
.656 .751 .92 r
.087 .36657 .09618 .37486 .10851 .37038 .09936 .36205 Metetra
.656 .751 .92 r
.09936 .36205 .10851 .37038 .1209 .36587 .11178 .35751 Metetra
.656 .751 .92 r
.11178 .35751 .1209 .36587 .13334 .36135 .12426 .35294 Metetra
.656 .751 .92 r
.12426 .35294 .13334 .36135 .14585 .35681 .1368 .34836 Metetra
.656 .751 .92 r
.1368 .34836 .14585 .35681 .15842 .35224 .14941 .34375 Metetra
.656 .751 .92 r
.14941 .34375 .15842 .35224 .17105 .34765 .16207 .33911 Metetra
.656 .751 .92 r
.16207 .33911 .17105 .34765 .18375 .34303 .1748 .33446 Metetra
.656 .751 .92 r
.1748 .33446 .18375 .34303 .1965 .3384 .1876 .32978 Metetra
.656 .751 .92 r
.1876 .32978 .1965 .3384 .20932 .33374 .20045 .32508 Metetra
.656 .751 .92 r
.20045 .32508 .20932 .33374 .22221 .32906 .21337 .32035 Metetra
.656 .751 .92 r
.21337 .32035 .22221 .32906 .23515 .32435 .22636 .3156 Metetra
.656 .751 .92 r
.22636 .3156 .23515 .32435 .24817 .31962 .23941 .31083 Metetra
.656 .751 .92 r
.23941 .31083 .24817 .31962 .26124 .31487 .25253 .30604 Metetra
.656 .751 .92 r
.25253 .30604 .26124 .31487 .27439 .3101 .26571 .30121 Metetra
.656 .751 .92 r
.26571 .30121 .27439 .3101 .28741 .30781 .27896 .29637 Metetra
.626 .683 .884 r
.27896 .29637 .28741 .30781 .30056 .30477 .29221 .29238 Metetra
.617 .661 .87 r
.29221 .29238 .30056 .30477 .31389 .30049 .30551 .28863 Metetra
.644 .683 .872 r
.30551 .28863 .31389 .30049 .32735 .29513 .31896 .28392 Metetra
.665 .706 .877 r
.31896 .28392 .32735 .29513 .34092 .28893 .33252 .27846 Metetra
.68 .727 .886 r
.33252 .27846 .34092 .28893 .35458 .28219 .34618 .2725 Metetra
.688 .749 .898 r
.34618 .2725 .35458 .28219 .36831 .27521 .3599 .26633 Metetra
.688 .769 .914 r
.3599 .26633 .36831 .27521 .38208 .26833 .37368 .26024 Metetra
.677 .788 .933 r
.37368 .26024 .38208 .26833 .39589 .26187 .38751 .25454 Metetra
.653 .802 .955 r
.38751 .25454 .39589 .26187 .40972 .25613 .40137 .24947 Metetra
.613 .81 .976 r
.40137 .24947 .40972 .25613 .42359 .25136 .41527 .24527 Metetra
.589 .819 .987 r
.41527 .24527 .42359 .25136 .4375 .24776 .42924 .24141 Metetra
.647 .832 .972 r
.42924 .24141 .4375 .24776 .45146 .24546 .44333 .23626 Metetra
.656 .759 .925 r
.44333 .23626 .45146 .24546 .46557 .24062 .4575 .23108 Metetra
.656 .751 .92 r
.4575 .23108 .46557 .24062 .47976 .23546 .47173 .22587 Metetra
.656 .751 .92 r
.47173 .22587 .47976 .23546 .49402 .23028 .48605 .22064 Metetra
.656 .751 .92 r
.48605 .22064 .49402 .23028 .50836 .22507 .50043 .21538 Metetra
.656 .751 .92 r
.50043 .21538 .50836 .22507 .52278 .21983 .5149 .21009 Metetra
.656 .751 .92 r
.5149 .21009 .52278 .21983 .53727 .21456 .52944 .20477 Metetra
.656 .751 .92 r
.52944 .20477 .53727 .21456 .55184 .20927 .54406 .19942 Metetra
.656 .751 .92 r
.54406 .19942 .55184 .20927 .56648 .20395 .55875 .19405 Metetra
.656 .751 .92 r
.55875 .19405 .56648 .20395 .5812 .1986 .57353 .18865 Metetra
.656 .751 .92 r
.57353 .18865 .5812 .1986 .596 .19322 .58838 .18321 Metetra
.656 .751 .92 r
.58838 .18321 .596 .19322 .61088 .18781 .60331 .17775 Metetra
.656 .751 .92 r
.60331 .17775 .61088 .18781 .62584 .18238 .61833 .17226 Metetra
.656 .751 .92 r
.61833 .17226 .62584 .18238 .64088 .17691 .63342 .16674 Metetra
.656 .751 .92 r
.63342 .16674 .64088 .17691 .656 .17141 .6486 .16119 Metetra
.656 .751 .92 r
.6486 .16119 .656 .17141 .67121 .16589 .66386 .15561 Metetra
.656 .751 .92 r
.66386 .15561 .67121 .16589 .68649 .16034 .6792 .15 Metetra
.656 .751 .92 r
.6792 .15 .68649 .16034 .70186 .15475 .69462 .14436 Metetra
.656 .751 .92 r
.69462 .14436 .70186 .15475 .71731 .14914 .71013 .13869 Metetra
.656 .751 .92 r
.02876 .37623 .03816 .38443 .05028 .38 .04092 .37176 Metetra
.656 .751 .92 r
.04092 .37176 .05028 .38 .06246 .37554 .05313 .36726 Metetra
.656 .751 .92 r
.05313 .36726 .06246 .37554 .0747 .37107 .0654 .36275 Metetra
.656 .751 .92 r
.0654 .36275 .0747 .37107 .087 .36657 .07773 .35821 Metetra
.656 .751 .92 r
.07773 .35821 .087 .36657 .09936 .36205 .09013 .35365 Metetra
.656 .751 .92 r
.09013 .35365 .09936 .36205 .11178 .35751 .10258 .34906 Metetra
.656 .751 .92 r
.10258 .34906 .11178 .35751 .12426 .35294 .1151 .34446 Metetra
.656 .751 .92 r
.1151 .34446 .12426 .35294 .1368 .34836 .12767 .33983 Metetra
.656 .751 .92 r
.12767 .33983 .1368 .34836 .14941 .34375 .14031 .33518 Metetra
.656 .751 .92 r
.14031 .33518 .14941 .34375 .16207 .33911 .15301 .3305 Metetra
.656 .751 .92 r
.15301 .3305 .16207 .33911 .1748 .33446 .16578 .3258 Metetra
.656 .751 .92 r
.16578 .3258 .1748 .33446 .1876 .32978 .17861 .32108 Metetra
.656 .751 .92 r
.17861 .32108 .1876 .32978 .20045 .32508 .1915 .31634 Metetra
.656 .751 .92 r
.1915 .31634 .20045 .32508 .21337 .32035 .20446 .31157 Metetra
.656 .751 .92 r
.20446 .31157 .21337 .32035 .22636 .3156 .21748 .30677 Metetra
.656 .751 .92 r
.21748 .30677 .22636 .3156 .23941 .31083 .23057 .30196 Metetra
.656 .751 .92 r
.23057 .30196 .23941 .31083 .25253 .30604 .24373 .29712 Metetra
.656 .751 .92 r
.24373 .29712 .25253 .30604 .26571 .30121 .25695 .29225 Metetra
.656 .751 .92 r
.25695 .29225 .26571 .30121 .27896 .29637 .27024 .28736 Metetra
.656 .751 .92 r
.27024 .28736 .27896 .29637 .29221 .29238 .28359 .28244 Metetra
.655 .73 .904 r
.28359 .28244 .29221 .29238 .30551 .28863 .29702 .2775 Metetra
.642 .7 .888 r
.29702 .2775 .30551 .28863 .31896 .28392 .31049 .27288 Metetra
.648 .705 .888 r
.31049 .27288 .31896 .28392 .33252 .27846 .32404 .26805 Metetra
.661 .724 .896 r
.32404 .26805 .33252 .27846 .34618 .2725 .33769 .26278 Metetra
.667 .744 .907 r
.33769 .26278 .34618 .2725 .3599 .26633 .35142 .25733 Metetra
.666 .762 .922 r
.35142 .25733 .3599 .26633 .37368 .26024 .36521 .25194 Metetra
.654 .777 .939 r
.36521 .25194 .37368 .26024 .38751 .25454 .37905 .24689 Metetra
.639 .791 .956 r
.37905 .24689 .38751 .25454 .40137 .24947 .39295 .2422 Metetra
.653 .808 .958 r
.39295 .2422 .40137 .24947 .41527 .24527 .40693 .23705 Metetra
.655 .784 .943 r
.40693 .23705 .41527 .24527 .42924 .24141 .421 .23188 Metetra
.656 .751 .92 r
.421 .23188 .42924 .24141 .44333 .23626 .43513 .22667 Metetra
.656 .751 .92 r
.43513 .22667 .44333 .23626 .4575 .23108 .44934 .22144 Metetra
.656 .751 .92 r
.44934 .22144 .4575 .23108 .47173 .22587 .46363 .21619 Metetra
.656 .751 .92 r
.46363 .21619 .47173 .22587 .48605 .22064 .47799 .2109 Metetra
.656 .751 .92 r
.47799 .2109 .48605 .22064 .50043 .21538 .49243 .20559 Metetra
.656 .751 .92 r
.49243 .20559 .50043 .21538 .5149 .21009 .50694 .20025 Metetra
.656 .751 .92 r
.50694 .20025 .5149 .21009 .52944 .20477 .52153 .19488 Metetra
.656 .751 .92 r
.52153 .19488 .52944 .20477 .54406 .19942 .5362 .18948 Metetra
.656 .751 .92 r
.5362 .18948 .54406 .19942 .55875 .19405 .55095 .18405 Metetra
.656 .751 .92 r
.55095 .18405 .55875 .19405 .57353 .18865 .56577 .17859 Metetra
.656 .751 .92 r
.56577 .17859 .57353 .18865 .58838 .18321 .58068 .17311 Metetra
.656 .751 .92 r
.58068 .17311 .58838 .18321 .60331 .17775 .59567 .16759 Metetra
.656 .751 .92 r
.59567 .16759 .60331 .17775 .61833 .17226 .61073 .16205 Metetra
.656 .751 .92 r
.61073 .16205 .61833 .17226 .63342 .16674 .62588 .15647 Metetra
.656 .751 .92 r
.62588 .15647 .63342 .16674 .6486 .16119 .64112 .15087 Metetra
.656 .751 .92 r
.64112 .15087 .6486 .16119 .66386 .15561 .65643 .14523 Metetra
.656 .751 .92 r
.65643 .14523 .66386 .15561 .6792 .15 .67183 .13956 Metetra
.656 .751 .92 r
.67183 .13956 .6792 .15 .69462 .14436 .68731 .13387 Metetra
.656 .751 .92 r
.68731 .13387 .69462 .14436 .71013 .13869 .70288 .12814 Metetra
.656 .751 .92 r
.01928 .36795 .02876 .37623 .04092 .37176 .03147 .36344 Metetra
.656 .751 .92 r
.03147 .36344 .04092 .37176 .05313 .36726 .04371 .35891 Metetra
.656 .751 .92 r
.04371 .35891 .05313 .36726 .0654 .36275 .05602 .35435 Metetra
.656 .751 .92 r
.05602 .35435 .0654 .36275 .07773 .35821 .06838 .34977 Metetra
.656 .751 .92 r
.06838 .34977 .07773 .35821 .09013 .35365 .08081 .34517 Metetra
.656 .751 .92 r
.08081 .34517 .09013 .35365 .10258 .34906 .0933 .34054 Metetra
.656 .751 .92 r
.0933 .34054 .10258 .34906 .1151 .34446 .10585 .33589 Metetra
.656 .751 .92 r
.10585 .33589 .1151 .34446 .12767 .33983 .11846 .33122 Metetra
.656 .751 .92 r
.11846 .33122 .12767 .33983 .14031 .33518 .13113 .32653 Metetra
.656 .751 .92 r
.13113 .32653 .14031 .33518 .15301 .3305 .14387 .32181 Metetra
.656 .751 .92 r
.14387 .32181 .15301 .3305 .16578 .3258 .15667 .31707 Metetra
.656 .751 .92 r
.15667 .31707 .16578 .3258 .17861 .32108 .16954 .3123 Metetra
.656 .751 .92 r
.16954 .3123 .17861 .32108 .1915 .31634 .18247 .30751 Metetra
.656 .751 .92 r
.18247 .30751 .1915 .31634 .20446 .31157 .19546 .3027 Metetra
.656 .751 .92 r
.19546 .3027 .20446 .31157 .21748 .30677 .20852 .29786 Metetra
.656 .751 .92 r
.20852 .29786 .21748 .30677 .23057 .30196 .22165 .293 Metetra
.656 .751 .92 r
.22165 .293 .23057 .30196 .24373 .29712 .23485 .28811 Metetra
.656 .751 .92 r
.23485 .28811 .24373 .29712 .25695 .29225 .24811 .2832 Metetra
.656 .751 .92 r
.24811 .2832 .25695 .29225 .27024 .28736 .26144 .27827 Metetra
.656 .751 .92 r
.26144 .27827 .27024 .28736 .28359 .28244 .27483 .2733 Metetra
.656 .751 .92 r
.27483 .2733 .28359 .28244 .29702 .2775 .2883 .26832 Metetra
.656 .751 .92 r
.2883 .26832 .29702 .2775 .31049 .27288 .30183 .2633 Metetra
.655 .743 .914 r
.30183 .2633 .31049 .27288 .32404 .26805 .31544 .25826 Metetra
.655 .739 .911 r
.31544 .25826 .32404 .26805 .33769 .26278 .32911 .2532 Metetra
.656 .745 .916 r
.32911 .2532 .33769 .26278 .35142 .25733 .34286 .24811 Metetra
.656 .755 .923 r
.34286 .24811 .35142 .25733 .36521 .25194 .35668 .24299 Metetra
.656 .763 .929 r
.35668 .24299 .36521 .25194 .37905 .24689 .37057 .23785 Metetra
.656 .762 .928 r
.37057 .23785 .37905 .24689 .39295 .2422 .38453 .23267 Metetra
.656 .751 .92 r
.38453 .23267 .39295 .2422 .40693 .23705 .39856 .22748 Metetra
.656 .751 .92 r
.39856 .22748 .40693 .23705 .421 .23188 .41267 .22225 Metetra
.656 .751 .92 r
.41267 .22225 .421 .23188 .43513 .22667 .42686 .217 Metetra
.656 .751 .92 r
.42686 .217 .43513 .22667 .44934 .22144 .44111 .21172 Metetra
.656 .751 .92 r
.44111 .21172 .44934 .22144 .46363 .21619 .45545 .20641 Metetra
.656 .751 .92 r
.45545 .20641 .46363 .21619 .47799 .2109 .46986 .20107 Metetra
.656 .751 .92 r
.46986 .20107 .47799 .2109 .49243 .20559 .48434 .1957 Metetra
.656 .751 .92 r
.48434 .1957 .49243 .20559 .50694 .20025 .49891 .19031 Metetra
.656 .751 .92 r
.49891 .19031 .50694 .20025 .52153 .19488 .51355 .18489 Metetra
.656 .751 .92 r
.51355 .18489 .52153 .19488 .5362 .18948 .52827 .17944 Metetra
.656 .751 .92 r
.52827 .17944 .5362 .18948 .55095 .18405 .54307 .17395 Metetra
.656 .751 .92 r
.54307 .17395 .55095 .18405 .56577 .17859 .55795 .16844 Metetra
.656 .751 .92 r
.55795 .16844 .56577 .17859 .58068 .17311 .5729 .1629 Metetra
.656 .751 .92 r
.5729 .1629 .58068 .17311 .59567 .16759 .58795 .15733 Metetra
.656 .751 .92 r
.58795 .15733 .59567 .16759 .61073 .16205 .60307 .15173 Metetra
.656 .751 .92 r
.60307 .15173 .61073 .16205 .62588 .15647 .61827 .1461 Metetra
.656 .751 .92 r
.61827 .1461 .62588 .15647 .64112 .15087 .63356 .14044 Metetra
.656 .751 .92 r
.63356 .14044 .64112 .15087 .65643 .14523 .64893 .13474 Metetra
.656 .751 .92 r
.64893 .13474 .65643 .14523 .67183 .13956 .66439 .12902 Metetra
.656 .751 .92 r
.66439 .12902 .67183 .13956 .68731 .13387 .67993 .12326 Metetra
.656 .751 .92 r
.67993 .12326 .68731 .13387 .70288 .12814 .69556 .11748 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003oooooo`[ooooo00Go
0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?ooooooooooooooool00000
F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@401Jooooo`00oooo
ool3o`000003ooooool0003ooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Jooooo`00oOoo
ool2o`0000Cooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_ooool00?[ooooo0ol0
0005ooooo`;o000000?oooooo`000?ooool0HOooool00?Sooooo0_l00009ooooo`03o`000?oooooo
000006;ooooo003eooooo`?o00002oooool01?l0003oooooooooool0001Qooooo`00loooool2o`00
00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000063ooooo003`oooo
o`?o00004?ooool01Ol0003ooooooooooooooooo0000063ooooo003]ooooo`?o00004oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo003[ooooo`;o00005oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05cooooo002dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Nooooo`?o000000?oooooo`00
0?ooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo002dooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06oooool2o`00
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
05_ooooo002dooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Goooo
o`?o00007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo002dooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o00008Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo002dooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo1?l0000Rooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0FOooool00;Cooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo01Cooooo0_l00003ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01?ooool2o`0005_ooooo002dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0Aooooo`?o0000:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05Sooooo001looooo`;o00000_ooool2o`0003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00003_ooool2o`0002_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1G
ooooo`00O?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgE;ooooo0ol0000]ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool007gooooo00CogMgMo`000?l@413oc<c<DOoo
ool2o`0000;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Kooooo001mooooo`04onk^k_lQ8B7o410@onk^kTkooooo0ol0000booooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0EOooool007gooooo00Co8B4QogMgMomgMgOo<S8bBooo
ool3o`0003Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`00O?ooool2
o`0000;ooooo0_l00018ooooo`;o0000>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo05Cooooo0037ooooo`Go0000>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05?ooooo0035ooooo`;o00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Doooool00<;ooooo0ol00010ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0D_ooool00<3ooooo0_l00013ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0DOooool00;gooooo0ol00015ooooo`03o`000?oooooooooo00_ooooo0_l0001C
ooooo`00^oooool2o`0000?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo053ooooo002hooooo`?o0000B_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04oooooo002fooooo`;o0000COooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04oooooo002<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0004oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`00S?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg023ooooo0_l00002ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`00S?ooool01Ol@413ooooooooooooooooo410@01gooooo
0ol0001Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool008cooooo00Go
0000ooooooooooooooooo`00000Jooooo`?o0000Eoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo002<ooooo`05o`000?ooooooooooooooool000006?ooool2o`0005[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`00S?ooool01Ol@413ooooooooo
oooooooo410@01Gooooo0ol00002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1;ooooo`00S?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo
0_l0001Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool008cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000H?ooool2o`0001Gooooo00?o0000ooooooooool0
B_ooool009oooooo0_l0001Pooooo`?o000000?oYl3[o`000?l000005?ooool2o`0004_ooooo002L
ooooo`?o000000?oooooo`000?ooool0GOooool2o`0000GoYl3[0_l0000Eooooo`03o`000?oooooo
oooo04Sooooo002Jooooo`;o0000H?ooool3o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`00
01Cooooo00?o0000ooooooooool0B?ooool009Oooooo0ol0001Pooooo`;o00001_nW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003ooooo01Cooooo00?o0000ooooooooool0Aoooool009Gooooo
0_l0001Pooooo`?o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00000_nW`>/01?l0003oYl3[
ojO0jol0000Eooooo`03o`000?oooooooooo04Kooooo002Booooo`Co0000G_ooool3o`0000KoYl3[
00?o0000ojO0jol000000_l000001OnW`>_o0000ojO0jonW`>_o000000;oYl3[00?o0000oooooooo
ool04oooool00ol0003oooooooooo`16ooooo`00T?ooool2o`0000Cooooo00?o0000ooooooooool0
Eoooool4o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jol00000
0_nW`>/2o`0001Gooooo00?o0000ooooooooool0AOooool008gooooo0ol0001Mooooo`?o000000?o
Yl3[o`000?nW`>/01OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ooooo`0Eooooo`03o`000?oooooooooo04Cooooo002;
ooooo`;o0000G_ooool2o`0000GoYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000
ojO0jonW`>_oYl3[1?l00004ojO0j`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0A?oo
ool008Sooooo1Ol0001Looooo`;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[0_l00004ojO0j`;o00005Oooool0
0ol0003oooooooooo`13ooooo`00QOooool3o`0005oooooo0_l00005ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000
ojO0jol000000_l000000onW`>_o0000ooooo`0Eooooo`03o`000?oooooooooo04;ooooo0023oooo
o`;o0000Goooool3o`000003ojO0jol0003oYl3[00CoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[
00?oYl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`03o`000?oooooooooo
01;ooooo0_l00014ooooo`00B_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd08?ooool3o`0005oooooo0_l00005ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00?o0000ojO0jol000001?l00005ojO0j`;o00005Oooool00ol0003oooooooooo`11
ooooo`00B_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01gooooo0_l000000ooooooo0000ooooo`1Looooo`?o000000?oYl3[o`000?nW`>/01?nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0003ojO0j`04o`000?nW`>_o0000ojO0j`?o000000?oYl3[o`000?ooool05Oooool00ol0003ooooo
ooooo`10ooooo`00@_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo01Wooooo0ol0001Nooooo`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0
jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[
1?l00003ojO0j`05o`000?nW`>_oYl3[o`000?nW`>/00_l00005ojO0j`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0@?ooool004[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo01Sooooo0_l0001Mooooo`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o
00001OnW`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001_nW`>/01_l0003oYl3[o`000?l0003oYl3[
o`0000KoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0?oooool004[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool3o`0005cooooo0ol000000onW`>_o0000
ojO0j`04ojO0j`03o`000?nW`>_o000000;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`00
0?nW`>_o000000;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001?nW`>/00ol0003oYl3[
ojO0j`03ojO0j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001Gooooo00?o0000oooooooo
ool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd08_ooool004[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo01Kooooo0_l000000ooooooo0000ooooo`1Jooooo`;o00001OnW`>/00ol0003oYl3[ojO0j`02
ojO0j`;o00001_nW`>/00ol0003oYl3[ojO0j`03o`0000KoYl3[00?o0000ojO0jol000000_l00000
0onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000CoYl3[o`000?nW`>_o00000onW
`>/4o`0000;oYl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08Oooool004[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01?ooooo0ol0001Mooooo`;o0000
0_nW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000ojO0jonW
`>_oYl3[0ol00005ojO0j`Go000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo023ooooo001:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo0_l0001N
ooooo`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW
`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00_nW
`>/2o`0001Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool08Oooool006cooooo0ol0001Mooooo`?o000000?oYl3[o`000?nW`>/01?nW
`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[
0ol00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08_ooool006[ooooo0_l00002ooooo`03o`000?oooooooooo05So
oooo0ol00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?o
Yl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00004ojO0j`;o00000onW`>/3o`0000Go
Yl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Tooooo`00Ioooool3o`0005_ooooo1?l00003ojO0j`03
o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0
003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW
`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/00onW`>/5o`00
00;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0001Cooooo0_l00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0;ooooo`?o000000?o410@ooooooooool04oooool0
06Cooooo0ol0001Looooo`;o00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003ooooo01;ooooo00?o0000ooooool000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l0000<ooooo`03oa0@4?nj^[[ooooo01Cooooo001Rooooo`;o0000GOoo
ool2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0j`06o`000?nW`>_o0000o`000?nW
`>_o00001_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00002ojO0j`03o`000?nW`>_o
Yl3[00?oYl3[0_l00002ojO0j`04o`000?nW`>_oYl3[o`0000CoYl3[0_l00005ojO0j`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool08_ooool00onHV9So<S8booooo`0Dooooo`00Goooool3
o`000003ooooool0003ooooo05Wooooo0ol000000onW`>_o0000ojO0j`04ojO0j`Co00000_nW`>/0
0ol0003oYl3[ojO0j`03ojO0j`;o00001?nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/0
0ol0003oYl3[ojO0j`03o`0000KoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`03o`00
0?nW`>_o000000;o00000_nW`>/00ol0003oYl3[o`000002ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/01?nW`>/2o`0001Cooooo00?o0000ooooooooool08_ooool00ooMgMgo0000
okZj^P0Dooooo`00GOooool2o`0000Gooooo00?o0000ooooooooool0E?ooool3o`0000GoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[0ol0
0003ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0
0006ojO0j`;o000000CoYl3[o`000?l0003o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0
jol0003ooooo01Cooooo00?o0000ooooooooool08Oooool00omEEEGoMgMgodA4A00Dooooo`00F_oo
ool3o`0005[ooooo1?l00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`03o`000?nW
`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ojO0j`04ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?o
Yl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool005Sooooo0_l0001Kooooo`;o
000000?oYl3[o`000?nW`>/01OnW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00?o0000ojO0jol000000_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00002ojO0
j`03o`000?nW`>_oYl3[00?oYl3[0_l00005ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0
j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`;o00005?oo
ool00ol0003oooooooooo`0Oooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool005Gooooo0ol0
0002ooooo`03o`000?oooooooooo05Kooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0
0005ojO0j`03o`000?nW`>_oYl3[00?o00001_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`03o`00
0?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/0
0onW`>/2o`0000CoYl3[0_l00003ojO0j`?o00001OnW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
01Gooooo00?o0000ooooooooool07Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
017ooooo001Cooooo`;o0000Foooool3o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol0
00000_l000000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`03ojO0j`;o
00001OnW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0
j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`00
0003ojO0jol0003oYl3[00?oYl3[1Ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0
j`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo013ooooo000[ooooo`Co000000?o410@ooooooooool07_ooool3o`00
05_ooooo0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002
o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04
ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`02
ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW
`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Gooooo000]ooooo`03o`000?oooooo
oooo01kooooo0ol0001Kooooo`;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/0
0ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o
0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`04o`000?nW`>_o0000o`0000;oYl3[
00?o0000ojO0jonW`>/00onW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;o
Yl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l00002ojO0j`04o`000?nW`>_oYl3[o`00
00CoYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0003oooooooooo`0d
ooooo`008_ooool6o`0000Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o0000oooo
ooooool0EOooool3o`0000GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`03
ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o
0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co
0000ojO0jonW`>_oYl3[0ol00005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00_nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00;oYl3[00Co0000ojO0jol0
003oYl3[0ol000000onW`>_o0000ojO0j`04ojO0j`Co00000_nW`>/00ol0003oooooooooo`0Aoooo
o`?o0000=Oooool002gooooo00?o0000ooooooooool06Oooool2o`0005[ooooo1?l00002ojO0j`03
o`000?nW`>_oYl3[00?oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001OnW`>/01?l0
003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l00000
0onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005
ojO0j`03o`000?nW`>_oYl3[00Co00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003o
Yl3[00CoYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0cooooo`00;Oooool00ol0
003oooooooooo`0Fooooo`?o0000F_ooool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYl3[o`000002o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o0000ojO0
jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000
ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02
ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW
`>/3o`0001Cooooo00?o0000ooooooooool0<_ooool002gooooo00?o0000ooooooooool04oooool3
o`000003ooooool0003ooooo05Oooooo0ol00005ojO0j`03o`000?nW`>_oYl3[00?o00001_nW`>/0
1?l0003oYl3[o`000?l00002ojO2k003o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l0
00000onW`>_o0000ojO0j`04ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[
00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`08o`000?nW`>_o0000o`000?nW
`>_o0000ojO0jol00003ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4
o`0000;oYl3[00?o0000ooooooooool04oooool00ol0003oooooooooo`0aooooo`00;Oooool00ol0
003oooooooooo`0Aooooo`;o0000FOooool4o`0000;oYl?]00?o0000ojO0jonW`>/00onW`>/3o`00
00?oYlSa00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl;/00?o0000ojO0jonW`>/00ol00005ojO0
j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0
j`02ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/00ol0003oYl3[ojO0
j`02ojO0j`;o00001?nW`>/2o`0000;oYl3[0ol00005ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo037ooooo000[
ooooo`03oeEEEOmVIVKo0000013ooooo0ol0001Iooooo`;o00000_nW`nd00ol0003oYl?]ojO3k@02
ojO3k@03o`000?nW`>_o000000;o00000_nWc_D00ol0003oYlSaojO8l@02ojO8l@03o`000?nW`>_o
000000;o000000?oYMCho`000?nW`^`01?nW`^`3o`0000?oYlO`00?o0000ojO0jonW`>/00_nW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[
o`000002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000
ojO0j`03ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/01?l0003oYl3[
ojO0jonW`>/3o`0001Cooooo00?o0000ooooooooool0<?ooool003cooooo0_l0001Jooooo`;o0000
1OnW`nd00ol0003oYl?]ojO3k@04o`0000GoYlke00?o0000ojO8lOnWb?401?l00004ojGDn003o`00
0?nW`^co000000;o000000?oWMgmo`000?nWao001?nWao001?l0003oYl3[o`000?l00002ojO8l@03
o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`04ojO0j`Co
00000_nW`>/00ol0003oYl3[ojO0j`03ojO0j`;o00001OnW`>/00ol0003oYl3[ojO0j`03o`0000Go
Yl3[00Co0000ojO0jonW`>_oYl3[0ol00005ojO0j`05o`000?nW`>_o0000o`000?nW`>/00_l00004
ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/4o`0000;oYl3[00?o0000
ooooooooool04oooool00ol0003oooooooooo`0_ooooo`00>Oooool3o`0000;ooooo00?o0000oooo
ooooool0E?ooool3o`0000;oYl7/00?o0000ojO3kOnW`nd00_nW`nd3o`0000CoXl[d00Co0000ojO>
mOnWc_GoYlke1?l00004oiKAo003o`000?nUe?SoYMCh00Go00000onMgOd01?l0003oYlO`ojO7l?nW
ao03o`0000GoYlSa00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_o000000;o000000?o
Yl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[0ol0
0002ojO0j`03o`000?nW`>_oYl3[00?oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0
0002ojO0j`;o000000CoYl3[o`000?nW`>_oYl3[0ol00005ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/01?nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo
000gooooo`;o0000FOooool3o`0000KoYl7/00Co0000ojO3kOl0003o00000_nWa_000ol0003oXl[d
oj?:m002oj?:m0Co00000onLcoT01?l0003oU]7loiKAo?nFdO`4o`0000?oNlgo2Ol00003ohgNoP04
o`000?nWb?7oYlSaojO8l@Co00000onWa>h00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/01?l0
003oYl3[ojO0jonW`>/3o`0000GoYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`03
ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003oYl3[o`000002
o`000007ojO0jol0003o0000o`000?nW`>_o0000ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/0
0_nW`>/2o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0000Dooooo`03o`000?oooooooooo02ko
oooo000dooooo`?o0000F?ooool3o`0000?oYkkZ00?o0000ojO1k?nW`N`00onW`N`2o`0000GoYlK`
00Co0000oj?:m?l0003o00000onWcO@00ol0003oW<oioic?n@05o`0000?oT];n1?l00003ogkBo`04
o`000?mMa?_oGLCkoeg4n`Wo00000_n3g_`00ol0003oYlC^ojO4kP03ojO4kP04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2
o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o000000Oo
Yl3[o`000?l0003o0000ojO0jol0003oYl3[00?o000000?oYl3[o`000?nW`>/01?nW`>/01_l0003o
Yl3[o`000?l0003oYl3[o`0000GoYl3[1?l00002ojO0j`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0;Oooool003?ooooo0_l0001Hooooo`;o00000_nW_NT00ol0003oYkkZojNnjP02ojNn
jP03o`000?nW`Nco000000;o000000?oZ/?/o`000?nWa_001?nWa_02o`0000GoYlgd0ol00004oj;C
n@04o`000?nBd_ko0000o`0000?oV=Om00?o0000ogkBoomnd_l01Ol00002oeg8nP_o00000onWa>h3
o`0000GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW
`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW
`>/4o`000004ojO0jol0003o0000o`0000CoYl3[0_l00003ojO0j`03o`000?nW`>_o000000?oYl3[
0ol00004ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/00ol0003ooooo
ooooo`0Aooooo`;o0000;oooool003?ooooo0ol0001Eooooo`;o00001OnW_NT00ol0003oYkkZojNn
jP03o`0000GoZ/?/00?o0000ojO6l?l000000_l00002ojg9kP03o`000?nWcOCo000000;o00000_n]
d?801?l0003oX]?ioj;CnOnRdoT4o`0000?oV=Om1?l00003oh;Go`Co00000omOboT;o`0000;oQ^?i
00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`00
0?nW`>_o000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002ojO0j`?o
00000_nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[1Ol00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[0_l00005ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0
003oooooooooo`0/ooooo`00<_ooool2o`0000;ooooo00?o0000ooooooooool0Coooool3o`000003
ojNnjOl0003oYkgY00CoYkgY0ol00003ojZnj003o`000?nZ`ncoZ/?/00;oZ/?/0ol00004ojg9kP?o
00001?n]d?84o`0000?oZMOh1?l00003oikLo@Co00000_n8foh5o`0000;oHm3h3Ol000001_nW`>_o
0000o`000?l0003oU>Kko`0000GoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l00005
ojO0j`04o`000?nW`>_oYl3[ojO0j`?o000000KoYl3[o`000?l0003o0000ojO0jol00002ojO0j`?o
00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00CoYl3[00Ko0000ojO0jol0
003o0000ojO0jol00005ojO0j`Co00000_nW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02cooooo000cooooo`05o`000?ooooooooooooooool00000COooool3o`0000GoYkkY00?o0000
ojNmjOl000000_l000000onY^NGo0000ojZnj004ojZnj004o`000?nZ`nco0000o`0000?o/<CY00Co
0000ojg9k_l0003o00000oncc>`01?l0003o[M3bo`000?l00003ok?Cl@04o`000?nYeoSo0000o`00
00?o/=_f00Co0000oikLoOl0003o00000onUh?/3o`0000?oSn3m1?l00003of[Dma7o000000KoYl3[
o`000?l0003o0000oj?Jnol00005ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW
`>/00_nW`>/4o`000004ojO0jol0003o0000o`0000CoYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00000onW`>/00ol0003oYl3[o`000003ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002
o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo0ol00003ojO0
j`03o`000?nW_^WoYkkY00;oYkkY0_l00005ojVii@03o`000?nZ_^SoZ[kX00;oZ[kX0ol00004ok34
j@;o00001Oncc>`2o`0000Go/m?a0ol00004ok3KmPCo000000?oYN3ko`000?l000000_n]i?T4o`00
00;oV>Gl1ol00002ogcOn0oo00001?nSf_/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00Go0000
ojO0jol0003o0000ojO0j`04o`0000;oYl3[00?o0000ojO0jol000000_l000000onW`>_o0000ojO0
j`03ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`Go00000_nW`>/00ol0003oYl3[ojO0
j`02ojO0j`;o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0001Cooooo00?o0000ooooooooool0
:_ooool003;ooooo0_l00005ooooo`03o`000?oooooooooo04Cooooo0_l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000ojNnjOl0003o00000_nU]><00ol0003oZKWUojVii@02ojVii@03o`00
0?nZ_^So000000;o00000on`_nD01?l0003o/<CYo`000?l00002okG6i`05o`000?ncc>co/lc/ok?<
k?l000000_nic^X01Ol0003o/m?aok?ClOncdo7o000000?o^]K^00Co0000ok3Km_l0003o00000ong
g_<2o`0000?o[NCi00Co0000okGWmoneioOo]NOg0ol000001?nQjO_o0000o`000?l00002oj[/n@?o
000000?oR>Gio`000?l000000ol00002oj7/n@Co000000CoM=cgo`000?l0003o00000_nSf_/5o`00
00;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`000003ojO0jol0003o000000;o00000onW`>/3o`00
00GoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[1?l00002ojO0j`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:_oo
ool003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`?o00001OnW`>/0
0ol0003oYl3[ojO0j`03o`0000GoYKCS00?o0000ojViiOnY^ND00ol00006ok2oi@;o00001Onea^L0
0ol0003o/lc/o`000004okW>jP03o`000?ncdo7o000000Co^]K^0_l00003okONl`;o00000_nnhO00
0ol0003o[NCio`000003okGWm`03o`000?nmjO?o_NWc00Co000000?oZ^cio`000?l000000_nck_H6
o`000003oj7/nOl0003o000000?o[>gh2_l00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[
o`000?l000000onW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_o000000?oYl3[0ol00005ojO0j`06o`000?nW`>_o
0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo
000booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool4o`0000;oYl3[00?o
0000ojO0jonW`>/00onW`>/3o`0000?oY;?S00?o0000ojFdhonU]><00_nU]><3o`0000?o[[[R00Co
0000ok2oiOn`_nGo/;oU0_l000000one`>?o0000okG6i`04okG6i`;o00001Onic^X2o`0000?o^]K^
0_l00002ol7Hj`03o`000?ngg_?o000000Co_^7`1?l000001OneioOo0000okgYlonmjO?o000000?o
a>[`0ol000001?nck_Ko0000o`000?nlko<2o`0000;oa>k`0ol000001_n/kOSo0000o`000?l0003o
]^gfo`0000;o_^[c0ol00002oj;To0;o00000onW`>/3o`000007ojO0jol0003o0000o`000?nW`>_o
0000ojO0j`02o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[o`000002o`000003
ojO0jol0003oYl3[00CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1Ol00002ojO0j`03
o`000?nW`>_oYl3[00?oYl3[0_l00004ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00005?ooool00ol0
003oooooooooo`0Xooooo`00<_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03So
oooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_l000000onW^^Oo
0000ojBch`04ojBch`06o`000?nU]>?o0000o`000?nZ]>3o00001On^^^800ol0003o/;oUo`000004
okG0h`03o`000?nea^Oo000000;o00000_nkb>@00ol0003o^LkZo`000002o`0000;o_m3W00?o0000
ok[Fk_l000001?o1f>/4o`000003okkQl?l0003o000000?oaN;]0ol000001?nmjO?o0000olCZl?o4
j_02o`0000;ob^[/0ol000000onlko?o0000olC^l002olC^l003o`000?o:k>cob^c/00Co000000Go
]^gfo`000?nnj_?o_^[co`000002olCVk`?o00000_n/hOT7o`0000?oYl3[0ol00005ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[
00?o0000ojO0jol000001?l00005ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/0
0onW`>/4o`0000;oYl3[00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`00<_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Gooooo0_l00005ojO0j`03o`000?nW
`>_oYl3[00?o00001OnW^^L00ol0003oY;?SojBch`02ojBch`;o00001?nZ]>000ol0003o[[[Rojjj
hP02ojjjhP;o00001One`><2o`0000Go^lST0_l00005oko@i`?o00000oo1f>/01?l0003oam[WolOJ
ioo7f^L2o`0000?oaN;]0_l00002ol_Sj@?o000000?oa>[`o`000?o:j^`00_o:j^`01?l0003od>WW
om3Yioo@jNL3o`000005olC^l?l0003ob^c/ol[/k?l000000oo?j^P3o`000005okkZlol0003oa>K_
olCVkol000000_o8hNX00ol0003o[>7io`00000:o`0000;oY=Ki00?o0000ojO0jonW`>/00onW`>/3
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_o000000?oYl3[0ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1OnW`>/00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo000aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0<_ooool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW
`>/3o`0000?oYl3[00?o0000ojNjionW^^L00_nW^^L00ol0003oY;?So`000002o`000003ojB^gol0
003oZ[CP00CoZ[CP00Co0000ojjjh_l0003o00000_nc^]l01Ol0003o]L3SokG0hone`>?o000000;o
^/;O00Go0000ok_8i?nkb>Co^lSTo`000002ol79h@05o`000?nod>Oo_m3Woko@iol000000oo5dN<0
0ol0003o`MS[o`000003olOJi`06o`000?o=fnCocM_To`000?o5h^go00000oo;hnT01?l0003odN?U
om7SiOoAhnD3o`000003ol[Zk?l0003od>WW00;od>WW00Co0000omGXhooEj>?oeNSS0_l000001?o:
k>co0000oloZj?o?j^P2o`0000?odnKT0_l000000oo4i^oo0000olSQjP02olSQjPKo00000onheNl4
o`0000?oY=Ki00?o0000ojO0jol000000_l000000onW`>_o0000ojO0j`03ojO0j`03o`000?nW`>_o
000000;o000000?oYl3[o`000?nW`>/01?nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[1Ol0
0003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001?o
oooo0_l0000Xooooo`00<Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02kooooo
1?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003o
Yk[WojNji`03o`0000GoY:kO00?o0000ojZdh?nZ]>000_nZ]>02o`0000Go/k[O00?o0000okG0hol0
00001?nj`]l00ol0003o^lSTo`000004ol79h@03o`000?nod>Oo000000CoaM7S0_l00003olOJi`03
o`000?o=fnCocM_T00;ocM_T0ol000000oo;hnWo0000om7Si@02om7Si@05o`000?oEh^3oeN;PomGR
h?l000000oo@jNL01Ol0003oeNSSomGXhooEj>?o000000;of>GO0_l000000oo?j^So0000om?Vi003
om?Vi004o`000?oFh^3oe^;Po`0000;ob>7Z0ol000000oo;g>Ko0000o`000005okSEk`?o000000?o
W/Wfo`000?l000000ol00005ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000ol00005ojO0j`Co00000_nW
`>/00ol0003oYl3[ojO0j`02ojO0j`Co00000onW`>/00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Kooooo000aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool3
o`0000CoYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_oYl3[00Co00000_nMZMh0
0ol0003oY:kOojB^g`03ojB^g`03o`000?nZ]>3o000000;o000000?o[[CMo`000?nc^]l01?nc^]l2
o`0000Go^/;O0_l00005ol79h@;o00000oo5dN<2o`0000;obm;P00?o0000olOJiol000001?o=fn@0
0ol0003od]_Oom;Kg`02o`0000?odN?U00Wo0000omGRh?oEh^3oeN;Po`000?oIhMco0000om3Yiol0
00000ooEj><01?l0003of>GOomSUgol00002om_Rf`;o00000ooCi^@00ol0003oe^;PomKRh005o`00
00;obmcV00Go0000olcEhOo<eN7o0000okSEk`03o`0000;o^lkY00?o0000oik9m_nNbOH01?l00005
ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0003ojO0j`;o000000KoYl3[o`000?l0003o0000ojO0jol00005ojO0j`06o`000?nW`>_o0000o`00
0?nW`>_o00001OnW`>/2o`0001?ooooo00?o0000ooooooooool09Oooool0037ooooo0_l0000>oooo
o`03o`000?oooooooooo02Kooooo0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0
j`03o`000?nW`>_oYl3[00;oYl3[0ol00002oj2^hP03o`000?nMZMkoWJWN00;oWJWN00?o0000ojB^
gonT[]l00_nT[]l2o`0000Go[[CM00?o0000ok>jgol000000_l000000onh^mco0000ok[2g`02ok[2
g`;o000000?o_l;Lo`000?o1bN400_o1bN42o`0000;oa/[M00?o0000olGAhol000001?o;d^03o`00
00?ocM_T00Co0000om;KgooBfmoo00000_oFfm/00ol0003odN?Uo`000003omGRh004o`000?oIhMco
fN7LomWQg0?o000000GoeNSSo`000?oHiMoof>GOo`000003om_Rf`06o`000?oMgmOo0000om?Vi?l0
003oe^;P0ol00002omOMg0;o000000?obmcVo`000?o<eN400_o<eN43o`0000Co^lkY0ol00003ojC2
k`;o000000KoYl3[o`000?l0003o0000oiWSoOl00005ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`03ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0jonW`>/3o`0000GoYl3[00Co0000ojO0jonW`>_o
Yl3[0ol00004ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?ooool04oooool00ol0003o
ooooooooo`0Tooooo`00<?ooool2o`00013ooooo00?o0000ooooooooool08_ooool3o`0000KoYl3[
00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`00
0?nW`>_o00001?nP[^800ol0003oWJWNoifYgP02oifYgP04o`000?nT[]oo0000o`0000;oZJkL00?o
0000ojjdgOn^]=d00_n^]=d2o`0000Go^;_L00?o0000ok[2gol000001?no`]`00ol0003o`LWQo`00
0004olK:g@?o00000oo;d^001ol0003ocm?LoloCg?o?dmco0000olgKi?l000000_oBfml00ol0003o
e]_KomKKf`02omKKf`?o000000?oeN;Po`000?oIhM`00_oIhM`00ol0003og=oHomcOf003o`000003
omSUgol0003ofn;K00;ofn;K00?o0000omgOeooMgmL01Ol00003omOMg004o`000?oHf=Sof=SHo`00
00?oc=GQ00Ko0000olc?g?o<cmcoc<oLo`000?nkc^T2o`0000;o_<OS00?o0000ojC2konT`^l01Ol0
0004oiWSo@03o`000?nW`>_o000000;o000000?oYl3[o`000?nW`>/00onW`>/00ol0003oYl3[o`00
0002o`000003ojO0jol0003oYl3[00CoYl3[00?o0000ojO0jol000000ol00005ojO0j`Co00000_nW
`>/00ol0003oYl3[ojO0j`02ojO0j`;o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Cooooo000aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool3
o`0000?oYl3[00?o0000ojO0jonW`>/00onW`>/2o`0000GoYl3[00?o0000ojO0jonW`>/00ol00004
ojO0j`03o`000?nP[^;oX:kR00;oX:kR00?o0000oifYg_nMZMh00ol00005ojV^g006o`000?n^]=go
0000o`000?nc]M[o00001Onh^m`2o`0000Go_l;L0ol00003olK:g@07o`000?o;bm[obl_Jol_;f_l0
003obm;Po`000004oloCg0?o000000?od]_Oo`000?oFfm/00ooFfm/01Ol0003of][Gom[JeooJf]Oo
000000?ofN7L00Co0000omcOf?oLgmSo00000ooOgM@01Ol0003ofn;Kom_RfooKh]_o000000;ogMoG
0ol000000ooNfm?o0000omOMg002omOMg008o`000?oHf=Sof=SHo`000?oGdmCo0000olcEhOl00004
olc?g0;o00001?nlan<3o`0000;oYk_W00?o0000ohZal?n:/O001_l00005ojO0j`03o`000?nW`>_o
Yl3[00?o00001OnW`>/01?l0003oYl3[ojO0jonW`>/3o`0000?oYl3[0_l000001_nW`>_o0000o`00
0?l0003oYl3[o`0000GoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`;o00004oooool0
0ol0003oooooooooo`0Sooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo013ooooo0_l0000Looooo`;o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o000000;o000000?oYl3[o`000?nW
`>/01?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oX:kRoj2^hP04o`0000?o
XJSK00?o0000ojV^g?nY[]`00_nY[]`2o`0000Co/kGJ00Go0000okRkg?nh^mco^;_Lo`000002okbl
f@05o`000?no`]co_l;Loko2g?l000000oo4`mT00ol0003oa/[Mo`000005ol_;fP;o00000oo?dm`0
1?l0003oe=?HomCCf?oDdmP2o`0000?oe]_K00Wo0000om[JeooJf]Oof][Go`000?oMfM?o0000omWQ
g?l000000_oLgmP00ol0003ogmgDomoMe002omoMe0;o000000?ofn;Ko`000?l000000_l00004omkK
d`;o000000GoemgLo`000?oHf=Sof=SHo`000003omOCe003o`000?o<cmcoc<oL00;oc<oL00?o0000
ol_9f?l000000onlan<00ol0003o_<3Mo`000004ojNki`03o`000?n:/O3oR[7`00Go00001OnW`>/3
o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00005
ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0
003ooooo01?ooooo00?o0000ooooooooool08_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Fooooo`?o00001OnW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jol0
00000_l000000onW`>_o0000ojO0j`04ojO0j`03o`000?nW`>_oYl3[00Co00000_nHX]/00ol0003o
XJSKoj6Xf`03oj6Xf`06o`000?nY[]co0000o`000?n][mWo00001Onc]MX00ol0003o^;_Lo`000004
okblf@03o`000?no`]co000000Goa<?I00?o0000ol_;f_o;bmX00oo;bmX01_l0003ocl_Folo;e_l0
003ocm?Lo`0000Coe=?H00Go0000omOCe?l0003oe]_Ko`000003om[Je`04o`000?oMfM?ogMWComgI
d`;o000000?og=oHo`000?oOgM@00ooOgM@00ol0003ohM_@o`000002o`000003omgOeol0003og]_C
00?og]_C00?o0000omoHd?oOf=000_l000000ooHf=So0000omOCe003omOCe005o`000?o<cmcoc<oL
olc?g?l000000oo;bMP00ol0003o_<OSo`000003okc0g@03o`000?nW^nOoYk_W00Co00000_nA[>P0
1Ol0003oLIk]og6NkOl0003oYl3[00?o000000?oT>Kjo`000?nW`>/01?nW`>/01_l0003oYl3[o`00
0?l0003oYl3[o`0000GoYl3[0ol000000onW`>_o0000o`000005ojO0j`Co00000onW`>/00ol0003o
Yl3[ojO0j`03o`0000GoYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`00
1?l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00;ooooo0_l0000E
ooooo`03o`000?oooooooooo01;ooooo0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00004
ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oTj7N00?o
0000oiRRfonHX]/00_nHX]/00ol0003oXJSKoj6Xf`02oj6Xf`;o00001?n][mT00ol0003o/kGJok>e
fP02ok>efP;o00001Onl_=T2o`0000Goa<?I00?o0000olW4e_l000000oo;bmX00ol0003ocl_Folo;
eP02olo;eP03o`000?oDdmSoe=?H00;oe=?H00Go0000omOCe?oGdmCoem?Do`000003om[Je`03o`00
0?oMfM?ogMWC00;ogMWC00Co0000omoHcol0003o00000ooOgM@3o`000003on7Kd?l0003oh]S=00;o
00000ooNfm<01ol0003ogmS@omoHd?oOf=3o0000omkDcOl000001?oGdm@01Ol0003oelkAo`000?o<
cmco000000CoblWH0_l00004okc0g@?o00000onY]>401Ol0003oTJcXoi6/j?nA[>So000000;oLIk]
0_l00004oi3VnP04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003
ojO0jol0003oYl3[00;oYl3[0_l000001_nW`>_o0000o`000?l0003oYl3[o`0000GoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_l0000Cooooo`03o`000?oooooooooo027ooooo0006oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0?ooooo`;o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/00_nW`>/4o`0000;oYl3[00?o0000oi>Qg_nCXMh00_nCXMh00ol0003oV:;KoiRRf`02oiRRf`06
o`000?nQZ=_o0000o`000?nUZ=So00001On][mT01?l0003o/kGJo`000?l00002okRfe`05o`000?nl
_=Wo_;cIokblfOl000000_o1_=H01Ol0003oa<?IolC3fOo4`mWo000000?obLCF00?o0000ol_;f_l0
00001?o?bmH2o`0000?oe=?H00Wo0000omOCe?oGdmCoem?Do`000?oKd]3o0000om[Jeol000001?oM
fM<01Ol0003ogmS?omoHcol0003ohMK<00?o00000ooQfm002?l0003oh]S=on;HcOl0003oh]K:o`00
0?oNfm?o00000ooOf=001?l0003og]C=omkDcOl00003omOCe004o`000?oGc]7oelkAomO>d@;o0000
0oo;bMP01Ol0003ob/?Col[3dol0003o_<3M00;o000000?o^k[Ho`000?nY]>400onY]>4Ao`0000?o
Yl3[00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[00?o0000ojO0jol000000_l000000onW`>_o
0000ooooo`0Cooooo`03o`000?oooooooooo023ooooo0006ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo0ol00005ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`00
0?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`05o`000?nCXMkoTj7Noi>Qg_l000000onHX]/3o`0000CoYJSH00?o0000ojf_
fOn][mT00_n][mT2o`0000Go^;KG00?o0000okblfOl000001?o1_=H00ol0003oa<?Io`000004olW4
eP;o00001?o?bmH01_l0003odlcBom?<d_l0003oe=?Ho`0000?oem?D00Co0000om_Bd?oKd]3ofm;@
0_l00003omgId`03o`000?oOf<oogmS?00?o000000?ohMK<o`000?oQfm000_oQfm001?l0003oh]S=
on;HcOl00003on;FbP05o`000?oOf=3ogmS@omoHd?l000000_oNe<d01Ol0003og]3;o`000?oGdmCo
000000?oelkA00Ko0000omG9c_oEbLko0000ol_9f?l00004ol[3d`03o`000?nk^]So^k[H00;o^k[H
00Ko0000ojVdhOl0003o0000oj^^f_l00003oiJVh@05o`000?mlW>KoO9cVogbLi_l000000omMS^P2
o`0000GoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol000001?nW`>_o0000ojO0jol0
0003ojO0j`?o00001OnW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ooooooooool04?oo
ool2o`0002;ooooo0006ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`?o00000onW`>/00ol0003o
Yl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ojO0jonW
`>/01?l00004ojO0j`05o`000?nW`>_oYl3[ojO0jol000000_nCXMh5o`0000;oW:;I00?o0000ojFX
f?nUZ=P00_nUZ=P00ol0003o[JoIo`000002o`000003ok6_e_l0003o^;KG00Co^;KG0_l00005ol6l
eP;o00001?o9a=H00ol0003ocLCBo`000003olo;eP03o`000?oCc=;odlcB00;odlcB00Go0000omOC
e?oGdmCoem?Do`000004om_Bd004o`000?oMdLgo0000omgId`Co00001?oQe/`2o`000005on7Kd?l0
003oh]S=on;HcOl000001?oRe/X2o`000005omoHd?l0003og]C=omkDcOl000000ooNd</01Ol0003o
elkAomO>dOoGc]7o000000CoeLW>00?o0000ol[3doo:`m<00_o:`m<2o`0000Co^k[H0_l00004oj^^
fP05o`000?nFY^7oUZKQoiJVhOl000000omlW>H01?l0003oGHkXoef>j?mMS^P2o`000006ojO0jol0
003o0000o`000?nBiOco00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00;o
Yl3[1Ol00002ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00004oooool00ol0003oooooooooo`0Oooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?oo
ool2o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00004ojO0j`03o`00
0?nW`>_oYl3[00So00000_nAV]T00ol0003oW:;IoibRf@03oibRf@04o`000?nUZ=SoYJSHojFXf0;o
00001Ona[mH00ol0003o^;KGokRfe`02o`000003okbfe?l0003o`KcF00;o`KcF0_l000000oo5_M;o
0000olW4eP02olW4eP07o`000?o=a=;ocLCBolg4d_l0003ocl_Fo`000004om?<dP05o`000?oGc<oo
0000omOCe?l000001?oKd]000ol0003ogM7=omgAc@03o`0000;ogmS?00Go0000on7Fc?oQe/cohMK<
o`000002on?Db@;o000000?oh]S=o`000?oRe/X00ooRe/X00ol0003ohm?7on?Ca`02o`000003omkD
cOl0003og]3;00?og]3;0_l000000ooGc]7o0000omG9cP03omG9cP;o00000oo:`m<01Ol0003ob;g@
olRmd?l0003o^k[H00;o000000?o^[CCo`000?n[[]X00on[[]X00ol0003oUZKQoiJVh@0=o`0000Co
T^Gl00?o0000ojO0jonW`>/00ol00005ojO0j`03o`000?nW`>_o000000?o00001OnW`>/00ol0003o
Yl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[1?l00002ojO0j`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l00004
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00ol00005ojO0j`03o`000?nW`>_o
Yl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co
0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/01Ol0003oQYCJ
ohJDf_n6U=[o000000CoTI[I00?o0000oibRfOnLX]T00_nLX]T01_l0003oYJSHo`000?l0003oZJSF
o`0000Go/JoF00?o0000okRfeol000001?nl]]@00ol0003o`KcFo`000004olFmdP03o`000?o9a=Ko
000000GocLCB0_l00003om?<dP04o`000?oGc<ooelc?omO<c`;o00000ooKd]000ol0003ogM7=o`00
0002o`000004omoAbOl0003ogmS?o`0000?ohMK<00Ko0000on?DbOoSe<WohmC9o`000?oTd/H2o`00
00?oh]K:00Oo0000on?CaooSdlOohm?7o`000?oRd<Go000000Cog]3;00?o0000omg<b?oMc<P00_l0
0003omG9cP06o`000?oCa<_odlC;o`000?o:`m?o00001?o8_M000ol0003o^[CCokZdd`02okZdd`03
o`000?n[[][oZjkJ00Co00000_nIX]X01Ol0003oQ9WOohBIgon4VMoo000000?oJhkR2_l00003ojO0
j`04o`000?nW`>_oYl3[ojO0j`?o00000onW`>/2o`0000?oYl3[0ol00005ojO0j`06o`000?nW`>_o
0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
1?l000000ol@413oooooooooo`0@ooooo`00;oooool00ol0003oooooooooo`0Jooooo`?o00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o
0000ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00Go0000ojO0jonW`>_o
Yl3[o`000003ohJDfP03o`000?nAV]WoTI[I00;oTI[I00?o0000oibRfOnLX]T00ol00004ojVXeP03
o`000?na[mKo/JoF00;o/JoF0_l00006okbfe003o`000?o5_M;oaKgB00CoaKgB00?o0000olg4d_o=
a=800oo=a=801_l0003odLG?om75col0003odlcBo`0000Coelc?00Co0000om[;bol0003ofm;@0ol0
00000ooMdLgo0000omoAb@02omoAb@05o`000?oQe/cohMK<on7Fc?l000000ooSe<T02?l0003oi=;6
onCBa_l0003oi=33o`000?oRe/[o00000ooSdlL01?l0003oh]35on;@aOl00003omk@b`09o`000?oM
c<SogLc8omg<b?l0003oflS6o`000?oEbLko000000CodlC;00?o0000olRmd?o8_M000_o8_M02o`00
00Co^[CC0ol00002oj^Ye@03o`000?nIX][oVJ;J00;oVJ;J00Go0000ohBIgon4VMooQ9WOo`000003
of^>hP04o`000?m?PN?o0000o`0000;o66_M0_l00004ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0
jonW`>/5o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo000_ooooo`03
o`000?oooooooooo01Sooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0
003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0
j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00Go0000ojO0jonW`>_oYl3[o`000003
ohJDfP03o`000?nAV]WoTI[I00Co00000_nOXMH00ol0003oZJSFojVXeP03ojVXeP06o`000?na[mKo
0000o`000?ne[m?o00001Onl]]@2o`0000GoaKgB00?o0000olVncol000000oo=a=800ol0003odLG?
om75c`02om75c`03o`000?oGc<ooelc?00;oelc?00?o0000om[;bol000000_l00003omgAc@03o`00
0?oOdLWogm7900;ogm790_l000000ooQe/co0000on?Db@02on?Db@04o`000?oTd/Koi=;6o`0000?o
i=3300Go0000on?CaooSdlOohm?7o`000002on;@a@05o`000?oRcL?o0000omk@bol000000ooMc<P0
1Ol0003oflS6om_8a_oKb<Ko000000CodlC;0_l00003olRmd004o`000?o6^<goa[S=o`0000;o^[CC
00?o0000okR^col000001?n[ZMD01Ol0003oVJ;JoiVRf_nIX][o000000?oQ9WO00?o0000of^>h_m[
S^800_m[S^800ol0003oCh7Sodn1h`03o`000003o`1Le?l0003oYl3[00;o000000?oWMomo`000?nW
`>/01?nW`>/00ol0003oYl3[o`000003o`0000GoYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00;o
Yl3[1?l00002ojO0j`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0Eooooo`?o00001OnW`>/00ol0003oYl3[
ojO0j`04o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/00_nW`>/;o`0000;oU9[F00?o0000oinQe_nOXMH00_nOXMH00ol0003oZJSFojVXeP02ojVX
eP;o00001?ne[m<01Ol0003o_;KDokbfe?nl]]Co000000;o`;OA00Go0000olFmd_o5_M;oaKgBo`00
0003olVnc`03o`000?o=a=;o000000CodLG?0_l00003omO<c`?o00000_oJbl/2o`000003omgAcOl0
003ogm7900?ogm7900?o0000on7@a_oQd<H00_l00003on?Db@04o`000?oTd/Koi=;6o`0000?oi=33
0_l000001OoSdlOo0000on;@aOoRd<Go000000?oh/g300Go0000omg<b?oMc<SogLc8o`000004om_8
aP05o`000?oCa<_odlC;om?4bol000000_oA_lT00ol0003ob;g@o`000003olJhc@03o`000?nj]=?o
000000?o^:k?00Co0000oj^YeOn[ZMGoZjWE4Ol000001?lcM>3o0000o`000?l0G=@2o`0000?oWMom
00Co0000ojO0jonW`>_oYl3[0ol00003ojO0j`;o000000KoYl3[o`000?l0003o0000ojO0jol00005
ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04_ooool002kooooo0ol0000Cooooo`?o00000onW
`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o
0000ojO0jonW`>/00ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/01_l0003o
Yl3[o`000?l0003oYl3[o`0000?oNhcI00Go0000ohNBeon7T]OoQi;Go`000004oiBJeP03o`000?nO
XMKoWj7F00;oWj7F00Ko0000ojVXe_l0003o0000ojfXdol00005okF_d`03o`000?nl]]Co000000Co
`;OA00?o0000olFmd_l000001?o9_/l2o`0000CodLG?00?o0000omC5booDaL/00ol00004om[;b`03
o`000?oLblSog<_800;o00000ooOdLT02Ol0003ohM36on7@a_oQd<Ko0000on??`ol0003ohmC9o`00
0002onCBaP05o`000?oTd<?oi=33onC@`ol000000_oTcl401Ol0003oh]35on;@aOoRd<Go000000?o
h/g30_l000000ooMc<So0000om_8aP03om_8aP05o`000?oJaLGo0000om?4bol000001?oA_lT00ol0
003oa[S=olJhc@02olJhc@;o00001?nh[/l01_l0003oZjWEo`000?l0003oZZC@o`0000?oW9gD00Go
0000ohZFfOn:U]WoRYKIo`000004ogJ=g004o`000?mPQ=ko0000o`0000;o<gCP0_l000000ol0G=Co
0000o`000005o`0000?oYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`04o`000?nW`>_oYl3[ojO0
j`?o00001?nW`>/01?l0003oYl3[ojO0jonW`>/3o`0001?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0@ooooo`;o00000_nW`>/00ol0
003oYl3[ojO0j`02ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3
o`0000;oYl3[00?o0000ojO0jonW`>/00onW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol0
0004ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/01Ol0003oNhcIog^<fOmkS=Wo000000?o
Qi;G00?o0000oiBJe_nDV]H00_nDV]H01?l0003oWj7FoinQe_nOXMH2o`0000Co[JSC00?o0000okF_
done[m<00_ne[m<2o`0000Go`;OA0_l00004olVnc`03o`000?o=_/co000000?odLG?1?l000000ooD
aL_o0000o`000003om[;b`09o`000?oLblSog<_8omc;b?l0003og/_5o`000?oOdLWo000000?ohM36
00Go0000on??`ooScl?ohlo3o`000002onCBaP05o`000?oTd<?oi=33onC@`ol000000ooTcl42o`00
0003on;@aOl0003oh/g300;oh/g300Co0000on7:`_oQb/;o00001?oKb<H01Ol0003of/G5om[5aOoJ
aLGo000000CodKo90_l00003olJhc@03o`000?o3/l[o000000Co^:k?0_l00004ojZTd005o`000?nL
WMCoW9gDoibMe?l000000on:U]T00ol0003oMXgLogJ=g002ogJ=g003o`000?mPQ=koH8CN00[o0000
1OnW`>/3o`000003ojO0jol0003o000000GoYl3[1?l00002ojO0j`04o`000?nW`>_oYl3[ojO0j`Go
00000_nW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool002kooooo00?o0000ooooooooool03_ooool3o`0000GoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/00ol0003oYl3[o`000002o`00
0003ojO0jol0003oYl3[00?oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[1?l00003ojO0
j`05o`000?nW`>_oYl3[ojO0jol000000omkS=T01Ol0003oQi;GohNBeon7T]Oo000000CoU9[F00Ko
0000oinQe_l0003o0000oj>Qdol00005ojfXd`06o`000?ne[m?o0000o`000?ni/=3o00000oo0]m42
o`000003olBgc_l0003obKk?00;obKk?00Co0000olfnc?o=_/cocKk<1?l00004omC5b`05o`000?oG
aLSo0000om[;bol000000ooLblP01Ol0003og/_5omk;aOoNblGo000000?ohM3600?o0000on??`ooS
cl<00_oScl<2o`000005onCBa_l0003oi=33onC@`ol000000ooTcl401?l0003oi<foonC=_ol00003
on;=``04o`000?oQb/;ohL[2on7:`P;o00000ooKb<H01Ol0003of/G5om[5aOoJaLGo000000?odKo9
00Ko0000olnkaoo?^lOo0000olJhcOl00003ol>cbP06o`000?nh[/oo0000o`000?ngZLco00001?nZ
Y=000ol0003oW9gDoibMe00;o`0000;oH8CN00?o0000odUjgom9N]l00ol000000olIJ=co0000o`00
0002o`000006ojO0jol0003o0000o`000?nUd?Oo00000onW`>/2o`000006ojO0jol0003o0000o`00
0?nW`>_o00001?nW`>/4o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/2o`0001;ooooo0_l00007
ooooo`03o`000?oooooooooo01;ooooo000^ooooo`03o`000?oooooooooo00_ooooo0ol00003ojO0
j`03o`000?nW`>_oYl3[00;oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/00ol0
003oYl3[ojO0j`04o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02
ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/5o`0000?oNhcI00Go
0000ohNBeon7T]OoQi;Go`000003oiBJeP?o00001?nSXM<00ol0003o[JSCojfXd`02ojfXd`;o0000
1?ni/=000ol0003o`;OAo`000004olBgcP03o`000?o9_/oo000000;ocKk<1?l00005omC5b`05o`00
0?oGaLSoelG8omO5b?l000000ooLblP00ol0003og/_5omk;a@02omk;a@05o`000?oQd<KohM36on7@
a_l000000ooScl<01?l0003oi<g1onC=`Ol00003onC@``05o`000?oTcl7oi<o1onC?`Ol000000_oT
cKl01Ol0003oh/g3on;=`ooRcL?o000000;ohL[200Ko0000on38`?oPb<3o0000om_8a_l00003om[5
a@05o`000?oH`L?o0000om6obOl000001?o?^lL00ol0003o`k?:ol>cbP03ol>cbP03o`000?ngZLco
]jW<00;o]jW<00Co0000ojZTd?nZY=3oZZC@0ol00002oifId005o`000?n?Tm?oSi?CohnCdol00000
0omnS=L5o`0000;oBG[O00Go0000oc=bg_l0003o0000o`EPe`03o`0000GoYM3g00?o0000ojO0jonW
`>/00ol00005ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/01_l0003oYl3[o`000?l0
003oYl3[o`00017ooooo00Co0000oooooooooooo00001?ooool00omEEEGoIVIVo`00000Dooooo`00
;_ooool2o`0000[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`06
o`000?nW`>_o0000o`000?nW`>_o00000_mdRm/<o`0000;oV9[D00?o0000oj>QdonSXM<00_nSXM<0
0ol0003o[JSCojfXd`02o`000003ok6Yd?l0003o^K3@00?o^K3@0_l00006olBgcPCo00000oo=_/`2
o`0000?oe<G;00?o0000omO5b?oGaLP00_oGaLP01Ol0003og<_8omc;b?oLblSo000000?og/_500Go
0000on3:`ol0003ohM36o`000003on??``04o`000?oTcL7oi<g1onC=`@;o000000?oi=33o`000?oT
cl400_oTcl402?l0003oi<foonC=_ol0003oi<^no`000?oRcL?o00000_oQb/800ol0003oh<S0on38
`002on38`005o`000?oJaLGof/G5om[5aOl000000ooH`L<00ol0003ock_7olnka`02olnka`;o0000
1?o3/lX2o`0000Co]jW<00Ko0000ojZTd?l0003o0000ojZOc?l00004oifId005o`000?n?Tm?oSi?C
ohnCdol000000omnS=L00ol0003oKHGIoff5f@03o`000009odUjgol0003o<g;Noc=bg_l0003o1F3G
o`000?l0CLKo000000?oYM3g1?l000001?nW`>_o0000ojO0jol00003ojO0j`?o00001?nW`>/01?l0
003oYl3[ojO0jonW`>/3o`0000CoYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`00;_ooool00ol0003oooooooooo`06ooooo`Co00001?nW`>/00ol0003oYl3[ojO0j`04o`00
00CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[
00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[
00?o0000ojO0jonW`>/00ol00004ojO0j`04o`000?mdRm_oM8_Ko`0000?oNhSE00Go0000ohZAe?n:
TMCoRY7Do`000005oiRJe007o`000?nSXM?oXj7Coj>Qdol0003o[JSCo`000004ok6Yd006o`000?ni
/=3o^K3@o`000?nm/Lko00001Oo4]lh2o`0000GocKk<00Ko0000om2obOo@_lWo0000omC5bol00004
omO5b005o`000?oJaLGo0000omc;b?l000000ooNblD01?l0003oh<[3on3:`ooPb/<2o`0000?ohlo3
00Co0000onC=`OoTcL7o00000_oUc;l2o`0000;oi<o100Go0000onC=_ooTcKooi<foo`000002onC;
_P05o`000?oQb/;ohL[2on7:`_l000001?oPb<02o`000003om[5aOl0003of<7300?of<7300Go0000
olnkaoo?^lOock_7o`000002olbga@04o`000?o3/l[o`k?:o`0000;o`Jk700Co0000okNYc?ngZLco
]jW<0_l00004ojZOc005o`000?nMVM3oWIW@oifId?l000000on?Tm<00ol0003oOXcGogj<e`02ogj<
e`05o`000?m]QMWoKHGIo`000?mKO]`00_l00003oc=bgPOo00000_m[doX01?l0003oYl3[ojO0jonW
`>/5o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
000Cooooo`03o`000?oooooooooo01Sooooo000^ooooo`03o`000?oooooooooo00?ooooo0ol00004
ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000
ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW
`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[00Co0000ogB;fomdRm_o00000omkR=D01Ol0003oRY7DohZAe?n:TMCo0000
00CoV9[D00?o0000oj>QdonSXM<00ol00005ok6Yd003o`000?ni/=3o000000?o_K7>00?o0000olBg
c_l000000_l00002olNhb`05o`000?o=_/cocKk<olfnc?l000001?o@_lT00ol0003oelG8omO5b002
omO5b005o`000?oJaLGof/G5om[5aOl000000ooNblD00ol0003oh<[3on3:``02on3:``05o`000?oR
b/3o0000on??`ol000000_oTcL402Ol0003oiLboonG<_ooUc;oo0000onG;_Ol0003oi<o1o`000002
onC=_`04o`000?oTbkkoi<^nonC;_P;o000000?ohL[2o`000?oPb<000ooPb<001?l0003og/Foomk5
_ol00004omS1``05o`000?oF_L;o0000olnkaol000000oo<]lD00ol0003o`k?:o`000003ol6^a`06
o`000?ngZLco0000o`000?neYLSo00001?nZWl`01Ol0003oWIW@oifId?nMVM3o000000;oSi?C1ol0
0003off5f@03o`000?mKO]coFgkL00;o000000?o<g;No`000?lRK=d02Ol000000onW`>_o0000o`00
0002o`0000GoYl3[00Ko0000ojO0jol0003o0000ojO0jol00005ojO0j`?o00000_nW`>/00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Oooooo000^ooooo`04o`000?ooooooooooooooo`;o
00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03
o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00Go0000ojO0jonW`>_oYl3[o`000003ogB;f`05o`000?mkR=GoNhSEog^8eOl000000on:
TM@00ol0003oV9[DoiRJe004o`0000;oYj;A00?o0000ok6Yd?naZM000onaZM02o`0000?o_K7>0ol0
00000oo4]lko0000olNhb`03olNhb`03o`000?o=_/co000000Cod;o90_l00003omO5b003o`000?oJ
aLGof/G500;of/G500Go0000omk;aOoNblGog/_5o`000003on3:``05o`000?oRb/3oh/[0on;:`?l0
00000ooTcL401?l0003oiLboonG<_ol00003onG;_@04o`000?oTcKooi<foo`0000?oi<^n00Co0000
onC9_OoTbKgo00001?oPb<001Ol0003og/Foomk5_ooNaKoo000000?of<7300Go0000omJm`_oF_L;o
e[g2o`000005olbga@03o`000?o1[/Oo`Jk700?o`Jk700?o0000okFUb?neYLP00_neYLP01Ol0003o
ZYo<ojZOc?nZWlco000000;oWIW@1?l00002oi:@cP04o`000?n5Rm7oQH_AohF;d@Go00000_mKO]`0
0ol0003oBGSMo`000002o`0000;o8VcM0_l000000ol0GMCo0000o`000003o`0000?oYl3[0_l00003
ojO0j`?o00001?nW`>/00ol0003oYl3[o`000002o`000003ojO0jol0003oYl3[00?oYl3[00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`00;Oooool6o`0000CoYl3[00Co0000ojO0
jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/0
1?l00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`0:o`0000?oNhSE
00?o0000ohZAe?n:TM@01?l00002oi^JdP03o`000?nWX]7oYj;A00;oYj;A00Ko0000ok6Yd?naZM3o
/JW@o`000?neZ/h4o`0000?o_K7>00?o0000olNhboo7^</01?o7^</00ol0003od;o9om2ob@02om2o
b@06o`000?oC_lOodko7o`000?oGaLSo00001?oJaLD01Ol0003og<G3o`000?oNblGo000000?oh<[3
00?o0000on;:`?oRb/000_oRb/02o`000005onC=`Ol0003oiLboonG<_ol000001?oUbkd2o`000005
onC=_ol0003oi<^nonC;__l000000ooTbKd2o`0000?oh<S000So0000omk5_ooNaKoo0000omg2_ol0
003of<73o`0000Coe[g200?o0000olbgaOo<]lD00_o<]lD2o`0000Co`Jk70_l00004okFUb003o`00
0?nZWlcoZYo<00Co00000_nNU//00ol0003oTY3>oi:@cP02oi:@cP05o`000?n5Rm7oQH_AohF;dOl0
00000_mgQM@5o`0000?oBGSM0ol000000olEJ]go0000o`000004o`0000?oYl3[1Ol00003ojO0j`03
o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[ojO0j`03o`0001?ooooo00?o0000oooooooo
ool05_ooool002gooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`05o`000?meTn;oMI?R
ogFCh_l000000_m/OM<7o`0000;oSI7B00?o0000oi^Jd_nKV]800_nKV]800ol0003oYj;AojNRd@02
ojNRd@03o`000?naZM3o000000Co00001?nm/Lh2o`0000GoakS;0_l00003om2ob@03o`000?oC_lOo
dko700;odko700?o0000om[5aOoJaLD00_oJaLD01?l0003og<G3omc5`ooLaL<2o`0000?oh<[300Go
0000on;:`?oRb/3oh/[0o`000002on?9_P05o`000?oUc;ooiLboonG<_ol000000ooUbkd01?l0003o
iLZlonG:_?l00003onC;_P04o`000?oTbKgoi<Vmo`0000;ohlNl00?o0000on38`?l000000_oNaKl0
1Ol0003ogL:oomg2_ooM`[oo000000Coe[g200?o0000om>j`Ol000000_o<]lD01?l0003obK;4olVb
a?l00002ol6^a`04o`000?nnZ/Go_Z[5o`0000?o]JG80ol00002ojVKb003o`000?nNU/_oWYK;00;o
WYK;00Go0000oi:@c_nBT<koTY3>o`000004ohF;d@04o`000?mgQMCoMhGDo`0000;oJH7H0ol00000
0om9N=go0000oc]eg`02o`0000?o5F[M1?l000000onW`>_o0000o`000002o`0000GoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00?oYl3[0ol00003ojO0j`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05Oooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o00001?nW`>/3
o`0000?oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00_l00005
ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o0000
0onW`>/01Ol0003oYl3[ojO0jonW`>_o000000?oMI?R00Co0000ofamdom/OM?o00000ommR=<00ol0
003oSI7BohfAdP02ohfAdP03o`000?nKV];oVi[B00;oVi[B00Co0000ojNRdOnWX]7oYj;A0ol00004
okFZcP04o`000?nm/Lko_K7>o`0000;o`K;;00Go0000olNhboo7^<_oakS;o`000002ol^ib003o`00
0?o@_lWo000000Godko70_l00003om[5a@09o`000?oLaL?og<G3omc5`ol0003og/G1o`000?oPb/?o
000000?oh/[000Co0000on?9__oSbKkohlVn0_l000000ooUc;oo0000onG;_@02onG;_@04o`000?oU
b[coiLZlonG:_0;o000000?oi<^no`000?oTbKd00_oTbKd01Ol0003ohlNlon?7_?oSakco000000?o
g/Fo00Go0000omg2_ooM`[oogL:oo`000003omJm`P06o`000?oC^/7odk[1o`000?o<]lGo00000oo9
//@00ol0003o`Jk7o`000003okjZa@06o`000?neYLSo]JG8o`000?ncXLKo00001?nYVlP01Ol0003o
WYK;oijFbonNU/_o000000?oTY3>00?o0000ohF;dOn5Rm400_n5Rm401Ol0003oMhGDogN5e?mgQMCo
000000;oJH7H00?o0000oe]mf_l000000_l00002oc]eg`;o000000?o5F[Mo`000?l?KMh01?l00002
oiWQo@;o000000KoYl3[o`000?l0003o0000ojO0jol00004ojO0j`03o`000?nW`>_o000000;o0000
00?oYl3[o`000?nW`>/00onW`>/2o`0001;ooooo00?o0000ooooooooool05Oooool002;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`04o`000?oooooo0000ojO0j`;o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`00
00;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0
j`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000GoYl3[00?o
0000ojO0jonW`>/00ol000000omeTn;o0000ofamd`02ofamd`05o`000?mmR=?oOHSCogf8dol00000
0on=TM800ol0003oVi[Boi^JdP02oi^JdPCo000000?oZj??o`000?neZ/h01?neZ/h00ol0003o_K7>
o`000004ol6bb`03o`000?o7^<_o000000CobkW800?o0000om>oaooC_lL00ooC_lL01_l0003oe/34
omK0a?l0003of/G5o`0000?og<G300Go0000omk5`OoNaL7og/G1o`000003on;:`005o`000?oSbKko
hlVnon?9__l000000_oTbK`01Ol0003oiL^monG;_OoUbkgo000000?oiLZl00Co0000onG9^ooUbK_o
00000ooTbKd00ol0003ohlNlon?7_002on?7_0;o000000?og/Foo`000?oM`[l00_oM`[l01Ol0003o
fknno`000?oF_L;o000000Codk[100?o0000olVba?o9//@00oo9//@00ol0003o_Z[5okjZa@02okjZ
a@03o`000?neYLSo000000?o/j7600Go0000ojVKb?nYVlSoZI_8o`000002oijFb`oo00000omYPMP0
1?l0003oFggJoe]mf_mKOMX3o`000004oc1dhOl0003o0000o`0000;o3fgN1ol00005ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/4o`000003ojO0jol0003ooooo01;ooooo00?o0000ooooooooool0
5?ooool002;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00;o0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0
j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000
ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0003oYl3[ojO0jonW
`>/4o`000003oh2[l?l0003oFW7@00;o00000om/OM<01Ol0003oOHSCogf8dommR=?o000000?oSI7B
00?o0000oi^Jd_nKV]801?l00004oj^Sc`03o`000?neZ/ko]J[>00;o]J[>0_l00005ol6bb`;o0000
1Oo;^LP2o`0000?odko700?o0000omK0a?oF`<@00_oF`<@01Ol0003og<G3omc5`ooLaL?o000000Co
g/G100Go0000on;:`?oRb/3oh/[0o`000003on?9_P04o`000?oTbKcoi<Vlo`0000?oiL^m00Go0000
onG:_?oUb[coiLZlo`000002onG9^`04o`000?oTbKgoi<Vmo`0000CohlNl00Co0000on;5_?oRaKco
00000ooM`[l01Ol0003ofknnom^o__oK_kko000000Godk[100?o0000olVba?o9//@00_o9//@2o`00
00Co_Z[50_l00004ok>QaP04o`000?nYVlSoZI_8ojVKb0?o00000_nOTlP01Ol0003oUHk:oiF>b_nE
S/[o000000CoRX[=00?o0000ogn6d?moQ]001Ol00003oe]mfP04o`000?m?Nmgo0000o`0000?o<7CQ
0_l000000ol?KMko0000o`000005o`0000?oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00?o0000
1OnW`>/00ol0003oooooooooo`0?ooooo`03o`000?oooooo000001Gooooo000Rooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?nW`>_oYl3[00Co0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`05o`000?n0Zo3oP:_`oh2[
l?l000000_mJLM04o`0000?oOHSC00?o0000ohfAd_n=TM801Ol00002oinKd003o`000?n[XlooZj??
00;oZj??00?o0000okFZc_l000000_l000000oniZlco0000ol6bb`03ol6bb`03o`000?o4/lWo0000
00CobkW800Ko0000oljia_o>^LKo0000om>oaol00005omK0a005o`000?oLaL?og<G3omc5`ol00000
0ooNaL401Ol0003oglFno`000?oRb/3o000000?ohlVn00So0000onC9_?oTbKco0000onG8^ol0003o
iL^mo`0000?oiLZl00So0000onG9^ooUbK_o0000onG8^_l0003oi<Vmo`0000?ohlNl00Go0000on;5
_?oRaKcoh/Flo`000003omg2_`05o`000?oK_kkofknnom^o__l000001?oC^/400ol0003od;O1o`00
0002olVba004o`000?o6[l?oaZo3o`0000;o_Z[500?o0000ok^Va?l000001?ncXLH01_l0003oZI_8
o`000?l0003oZ9S6o`0000CoWi?800Go0000oiF>b_nES/[oUHk:o`000004ohZ:c@04o`000?moQ]3o
OhK@o`0000;oM8?C1_l00002odmkg@Oo000000Co47CQo`000?l0003o7Xg[1Ol00002ojK=m003o`00
0?nW`>_oYl3[00;oYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00004_ooool00ol0003o
ooooooooo`0Cooooo`008_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l00005ooooo`;o
00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000Co
Yl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW
`>_oYl3[00;oYl3[00Co0000oh2[l?n0Zo3o00000_mJLM000ol0003oKWgAofimd@0:o`0000GoWi_@
00Co0000oj^Scon[XlooZj??0_l00005okV[c004o`000?o1//_o`K;;o`0000?oa;?900Co0000ol^i
b?o;^LSo00001?o>^LH00ol0003oe/34omK0a003omK0a005o`000?oH`<;o0000omc5`ol000001?oN
aL400ol0003oglFnomo5_P02o`0000;ohlVn00Go0000onC9_?oTbKcoi<Vlo`000002onG8^`;o0000
0_oUb[`01Ol0003oiLVkonG9^ooUbK_o000000;oiLRj00Go0000on?7_?oSakcohlNlo`000003on;5
_005o`000?oP`k_o0000omg2_ol000000ooK_kh00ol0003ofKfno`000002om>j`@06o`000?o@]l7o
d;O1o`000?o9//Co00000oo6[l<00ol0003o_Z[5o`000003ok^Va004o`000?ncXLKo/j76ok>QaP;o
00001?nXV<H01Ol0003oWi?8oinCb?nOTlSo000000?oUHk:00?o0000ohZ:cOn:R/d00_n:R/d01Ol0
003oOhK@ogn6d?moQ]3o000000;oM8?C00Co0000ofV0eomYP=OoJH3G1?l00003odMlh@Go000000?o
47CQo`000?l000000ol00004ojK=m006o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/4o`0000;o
Yl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`008_ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool01Oooool00ol0003oYl3[ojO0j`02ojO0j`04
o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[
00?o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ojO0jonW`>/01?l000001On0Zo3o0000oeYad?mJLM3o000000;oKWgA00?o0000oh28dOl000000_l0
0004oi6Bd@03o`000?nOVm3oWi_@00;oWi_@00Ko0000oj^Scon[Xloo0000ojnTcOl00005okV[c003
o`000?o1//_o000000Coa;?900?o0000ol^ib?l000001Oo>^LH00ol0003oe/34omK0a002omK0a005
o`000?oH`<;of<32omS0`_l000001?oNaL402Ol0003oglFnomo5__oOaKko0000on75_?l0003ohlVn
o`000002onC9_009o`000?oUb;_oiLRkonG8^ol0003oiLRio`000?oUb[co000000;oiLVk00Co0000
onG8^_oUb;[oiLRj0_l000000ooSakco0000on;5_003on;5_004o`000?oP`k_oh<>ko`0000?ofknn
00Ko0000omVm__oI_Kko0000om>j`Ol00004om2g`@03o`000?o6[l?oaZo300?oaZo300?o0000ok^V
a?nkY/@00_nkY/@01_l0003o/j76o`000?l0003o/Ig4o`0000CoZ9S600Go0000oinCb?nOTlSoWi?8
o`000003oiF>bP03o`000?n:R/goRX[=00;oRX[=00Go0000ogn6d?moQ]3oOhK@o`000003ogB3d`06
o`000?mYP=OoJH3GofV0eol0003oHH3K0_l00003odMlh@03o`000?m2P>Go000000Co000000?o5WoV
o`000?l000001_l00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001OnW`>/00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo000Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02
ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004
ojO0j`03o`000?nW`>_oYl3[00Co00000_nO_Nh01?l0003oAVC=o`000?l00003oeYad0Co00000on0
R=400ol0003oTI;Aoi6Bd@02oi6Bd@07o`000?nOVm3oWi_@oinKd?l0003oZj??o`000003ojnTc@03
o`000?niZlco^J_<00;o^J_<0_l00006olBcb@03o`000?o>^LKoc[W600?oc[W600?o0000om6ja?l0
00000_oF`<@00ol0003of<32omS0`P02omS0`P;o00000_oNaL401Ol0003oglFnomo5__oOaKko0000
00?ohLFl00Co0000onC9_?oTbKco00000ooUb;/01Ol0003oiLRionG8^OoUb;Wo000000;oiLVk00Go
0000onG8^_oUb;[oiLRjo`000002onG7^@03o`000?oRaKcoh/Fl00;oh/Fl00Go0000on33^ooP`k_o
h<>ko`000003om^o_P05o`000?oI_KkofKfnomVm__l000001?o@]l42o`0000CoaZo30_l00004ok^V
a0;o00001?naWL@01Ol0003oZ9S6ojRHa_nXV<Ko000000;oWi?84ol00004ofV0e`03o`000?mQP=_o
HH3K00Go00000_m2P>D2o`000003ob]oj?l0003o000000?o00000on>c_d01?l0003oYl3[ojO0jonW
`>/3o`0000CoYl3[00Co0000ojO0jonW`>_oYl3[0ol0000Booooo`03o`000?oooooooooo017ooooo
000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`07ooooo`;o0000
1?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`04o`00
0?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW
`>_oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oWkg^oinmk_l00002
odITc@Co00000om^OM401Ol0003oP8SAoh28dOn0R=7o000000?oTI;A00?o0000oinKd?nOVm000ol0
0005ojnTc@06o`000?niZlco^J_<o`000?nl[<Wo00001Oo4/lT00ol0003ob;C6o`000003oljiaP06
o`000?oA^/CodK[4o`000?oF`<Co00001?oH`<801_l0003ofl70om_1`?l0003og/G1o`0000;oglFn
00?o0000on75_?oQaK`00_oQaK`2o`000003onC9_?l0003oiLRk00;oiLRk00Co0000onG8^OoUb;Wo
iLRi0_l000000ooUbK_o0000onG8^P02onG8^P03o`000?oUakWoiLNi00;o00000_oRaK`02Ol0003o
h<>kon33^ooP`k_o0000omo2^ol0003ofknno`000004omVm_P05o`000?o@]l7od;O1om2g`Ol00000
0_o=/l001?l0003oaZo3olJ_`ol00002ol>[`P06o`000?nkY/Co^jK4o`000?niX/;o00001?naWL@0
1?l0003oZ9S6ojRHa_nXV<H3o`0000;oWi7500Go0000oiN=aonGSLOoUhg7o`000004ohj9b@05o`00
0?n6Q/coQXK<ohJ6c?l000000_mmQ=06o`0000;oHH3K00Co0000oeZ2gomJP]ooFX;O1?l000000om3
Qn[o0000o`000002o`000003oc29kOl0003o000000Ko00000onW`>/00ol0003oYl3[ojO0j`05o`00
00;oYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`00;?ooool2o`0000Wo
oooo00?o0000ojO0jonW`>/00_nW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03
o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[
00;oYl3[00?o0000ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`02ojO0j`?o000000CoWkg^o`000?l0003o00000_mKL<l5o`0000?oP8SA00?o0000
oi6BdOnAT]401?l00002oj>LcP03o`000?n_Y<go[jC=00?o[jC=00?o0000okV[c?l000000onl[<T0
1Ol0003oa;?9olBcbOo4/lWo000000?ob;C600?o0000oljia_l000001?oA^/@00ol0003of<32omS0
`P02omS0`P03o`000?oK`L3ofl7000;ofl7000Go0000omo5__oOaKkoglFno`000003on75_004o`00
0?oRaK_oh/Fko`0000?oiLRk00Go0000onG8^OoUb;WoiLRio`000002onG7^@05o`000?oUb;[oiLRj
onG8^_l000000_oUakT01_l0003oi<JionC6^Ol0003oh/Flo`0000?oh<>k00Co0000omo2^ooO`[_o
00001?oI_Kh01Ol0003oe[Zno`000?o@]l7o000000?ocK?000?o0000olJ_`ol000000oo3Zl800ol0
003o^jK4o`000003okVR`P06o`000?naWLCo/Ig4ok6Ma?l0003oZ9S60_l000000onWUL?o0000oinA
a@03oinAa@05o`000?nGSLOoUhg7oiN=aol000001?n>RLT01Ol0003oQXK<ohJ6c?n6Q/co000000;o
OHC@00Co0000ogF3domePm?oMH?C1Ol00003oeZ2g`04o`000?mFQ^Co0000o`0000?o@hOZ1Ol00002
ofben`03o`000?nW`>_oYl3[00?oYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0_l0000C
ooooo`03o`000?oooooooooo00oooooo000/ooooo`03o`000?oooooooooo00Wooooo00Co0000ojO0
jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/0
1?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[00Go0000ojO0jol0003o0000
ojO0j`04o`0000;oAVC=00Co0000oe]`comKL<oo00000_m`O=07o`0000;oU9;?00?o0000oj>Lc_nS
W<h00_nSW<h00ol0003o[jC=ojnTc@02ojnTc@;o00001Onl[<T00ol0003oa;?9o`000005olRdaP03
o`000?oA^/CodK[400?odK[40_l00003omS0`P03o`000?oK`L3ofl7000;ofl700_l000000ooOaKko
0000on75_002on75_005o`000?oRaK_oh/Fkon;5^ol000000_oUb;/00ol0003oiLRionG8^@02onG8
^@04o`000?oUakWoiLNio`0000;oiLRj00Go0000onG7^OoUakWoiLNio`000003onC6^@05o`000?oP
`k_oh<>kon33^ol000000ooO`[/01Ol0003ofKfnomVm__oI_Kko000000?oe[Zn00?o0000olfc`?o=
/l000oo=/l000ol0003o`j_2ol>[`P03ol>[`P03o`000?niX/;o^J;200;o^J;200Co0000ok6Ma?na
WLCo/Ig40_l00004ojNE``05o`000?nOTLGoWi75oinAaOl000000onGSLL00ol0003oSXW9ohj9b@02
ohj9b@05o`000?n6Q/coQXK<ohJ6c?l000000ommQ=001Ol0003oMH?CogF3domePm?o000000;oKXCH
0ol00002oeZ2g`03o`000?mFQ^CoEXKT00Go00000_m7TNl5o`000006ojO0jol0003o0000o`000?nU
c_Go00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0001?ooooo00?o0000ooooooooool03ooo
ool002cooooo00?o0000ooooooooool02_ooool2o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0
jol00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00Ko0000
00CoYl3[o`000?m9MM_oBGGK0ol00003oe]`c`04o`000?m`O=3oL7c@o`0000?oPhS@00?o0000oiBB
conDT/l00_nDT/l00ol0003oXic>oj>LcP02oj>LcP06o`000?n_Y<go0000o`000?nbYL_o00001Onl
[<T2o`0000Gob;C60_l00004om6ja006o`000?oD^l;oe;_2o`000?oH`<;o00001?oK`L001?l0003o
g<6nomc1__l00003on75_009o`000?oRaK_oh/Fkon;5^ol0003ohlJjo`000?oUb;_o000000?oiLRi
00So0000onG7^OoUakWo0000onK7^?l0003oiLRjo`0000;oiLNi00?o0000onC6^OoTa[T00_oTa[T0
1?l0003oh<>kon33^ol00003omo2^`05o`000?oM`;co0000omVm__l000001?oF^[h00ol0003ocK?0
olfc`002olfc`0;o00001?o3Zl82o`0000Co^J;200Ko0000ok6Ma?l0003o0000ojnJ`_l00004ojNE
``05o`000?nOTLGoWi75oinAaOl000000onGSLL00ol0003oSXW9ohj9b@02ohj9b@05o`000?n6Q/co
QXK<ohJ6c?l000000ommQ=000ol0003oMH?CogF3d`02ogF3d`05o`000?m^Q=SoKXCHo`000?mYQ]`0
0ol00002oeJ6i004o`000?mGSNWoEhgYoeN=j@Go00000_mCX?D2o`0000GoYLke00?o0000ojO0jonW
`>/00ol00004ojO0j`03o`000?oooooooooo013ooooo0_l0000@ooooo`00:oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?nW`>_oYl3[00Co00000onW`>/01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0
j`?o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`07o`00
0005ojO0jol0003oYl3[ojO0jol000000_m9MM/00ol0003oAV?;o`000003oe]`c`05o`000?m`O=3o
L7c@og1ld?l000000on3R=001Ol0003oU9;?oiBBconDT/oo000000CoXic>0_l00004ok:Ub`03o`00
0?nl[<Wo_:c900;o000000?o`:k8o`000?o8]<H00oo8]<H01?l0003obkG5ol^eaOl00002om6ja003
o`000?oD^l;oe;_200;oe;_200?o0000om_1`?oK`L000_oK`L001Ol0003og<6nomc1__oL`Kko0000
00?ohLFl00Go0000on;5^ooRaK_oh/Fko`000002on?6^P;o00000_oUb;T01Ol0003oiLNionG7^OoU
akWo000000;oi/Nh00Co0000onG7^OoUakWo00001?oTa[T01Ol0003ohlFio`000?oP`k_o000000;o
gl:k00Go0000omg0_?oM`;cogL2lo`000004omJj_P03o`000?oC^;ko000000;ocK?000Co0000olZ`
`?o:/<3o00000_o3Zl801?l0003o`:O1ol2W`Ol00003okVR`P;o00001?n_V/801Ol0003oYiG3ojNE
`onWUL?o000000?oWi755ol00003ofj4f004o`000?mYQ]coJHKLofV6g0Co00000omGSNT2o`000003
oeZGkol0003o000000Co00000_nUc_D5o`0000?oYl3[00?o0000ojO0jonW`>/00ol0000Booooo`03
o`000?oooooooooo00kooooo000[ooooo`;o00003oooool2o`0000CoYl3[00?o0000ojO0jonW`>/0
0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00000_nW`>/2
o`0000CoYl3[1_l000000om9MM_o0000odISb`04o`0000?oL7c@00Go0000oh>8d?n3R=3oPhS@o`00
0003oiBBc`03o`000?nSW<ko000000;o000000?oYYg<o`000?nbYL/00onbYL/00ol0003o_:c9o`00
0004ol2^b004o`000?o8]<Kob;C6o`0000?obkG500?o0000om6ja?l000001?oD^l82o`0000?ofl70
00Wo0000omc1__oL`Kkog<6no`000?oN`[co0000on75_?l000000ooRaK/02Ol0003ohlJjon?6^_oS
a[[o0000onC6^Ol0003oiLRio`000002onG7^@04o`000?oVakSoi/NhonK7^0;o000000?oiLNio`00
0?oTa[T00ooTa[T01?l0003ohlFion?5^Ol00003omo2^`05o`000?oM`;cogL2lomg0_?l000000ooF
^[h01_l0003odkRnom>h__l0003ocK?0o`0000?ob[3000?o0000ol>[`_l000000oo0Yl401_l0003o
^J;2okVR`_l0003o]Yo1o`0000Co[i[200?o0000ojNE`onWUL<00_nWUL<3o`000003oin?`ol0003o
VHc400;oVHc400?o0000oi:9a_nBRLH00_nBRLH01Ol0003oRhO9oh^7bOn;QlWo000000?oQHG<00Co
0000ogn5d?moQM3oOhG@1Ol00003ofV6g003o`000?mWRn7oIh_Q00Oo00000_mJUnl00ol0003oHJ;d
of6Rm003o`0000?oU<?g00Co0000ojO0jonW`>_oYl3[1?l00003ojO0j`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03Oooool002_ooooo00?o0000ooooooooool03oooool00ol0003oYl3[
ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`?o
00000_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000;oJZSe00Ko0000obmDa_l0003o0000odIS
bol00002oea`cPGo00000on3R=000ol0003oU9;?oiBBc`03o`0000GoYYg<00Co0000ok:UbonbYL_o
/ZG;0_l00005ol2^b003o`000?o8]<Ko000000GobkG500?o0000omBk`_oD^l800_oD^l801_l0003o
e[c0omJl`?l0003ofl70o`0000Cog<6n00Co0000omk2_?oN`[co00001?oRaK/01?l0003ohlJjon?6
^_l00003onC6^@05o`000?oUakWoiLNionG7^Ol000000_oVakP01?l0003oi/NhonK7^?l00004onC6
^@04o`000?oSaKWohlFion?5^@;o000000?ogl:ko`000?oM`;`00_oM`;`00ol0003ofkjlo`000002
omJj_P05o`000?oC^;kodkRnom>h__l000001Oo:/<000ol0003o`:O1ol2W`@02ol2W`@03o`000?ni
X/;o000000?o]Yo100Go0000ojnJ`_n_V/;o[i[2o`000002ojNE``?o00001?nOSl<01Ol0003oVHc4
oiV<a?nIS<Co000000CoTXW600Go0000oh^7bOn;QlWoRhO9o`000003ohF5c005o`000?moQM3oOhG@
ogn5d?l000000_mjQm@4o`000005ofV6g?l0003oIh_QofN;hOl000000omWTNL:o`0000;oU<?g1Ol0
0002ojO1k003o`000?nW`>_oYl3[00;oYl3[0_l0000Booooo`03o`000?oooooooooo00cooooo000[
ooooo`03o`000?oooooooooo013ooooo00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o0000
0onW`>/00ol0003oYl3[ojO0j`02ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[
00?o0000ojO0jonW`>/01ol000001?nW`>_o0000ojO0jonW`>/3o`0000CoYl3[00Ko0000ofZXmOmZ
Z?Go0000obmDa_l00002odISb`04o`000?mLL<koG73>o`0000;oLWg?1ol00002oiRDcP03o`000?nV
WLcoYYg<00?oYYg<00Ko0000ok:UbonbYL_o0000okJWbOl00006ol2^b003o`000?o;]LGobkG500Co
bkG500Go0000omBk`_oD^l;oe;_2o`000004omJl`003o`000?oL`Kkog<6n00;og<6n00Co0000omk2
_?oN`[cog/:l0_l00002on;5^`05o`000?oSa[[ohlJjon?6^_l000000ooTa[T01?l0003oiLNionG7
^Ol00003onK7^003o`000?oVakSoi/Nh00;o00000_oTa[T01Ol0003ohlFion?5^OoSaKWo000000;o
h/Bj00Go0000omg0_?oM`;cogL2lo`000002om^n_003o`000?oF^[ko000000CodkRn00?o0000olZ`
`?o:/<000_o:/<02o`0000Co`:O10_l00004okJO`@04o`000?n_V/;o[i[2ojnJ`P?o00000_nVTl40
0ol0003oWho3oin?``02oin?``03o`000?nIS<CoVHc400;oVHc400Go0000oi:9a_nBRLKoTXW6o`00
0003oh^7b@05o`000?n5QLcoQHG<ohF5c?l000001?moQM001?l0003oNXODogZ7e?l00002ogJ9f@Ko
00000omWTNL2o`0000;oJi[/00Co0000og2UlOm`YO7oL:Ga0ol00002ohNgm@03o`000?nW`NcoYl7/
00?oYl7/1?l000000onW`>_o0000ooooo`0Aooooo`03o`000?oooooooooo00cooooo000[ooooo`03
o`000?oooooooooo017ooooo0_l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0
jonW`>/00_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003
ojO0j`03o`000?nW`>_oYl3[00Co000000?oYl3[o`000?l000000_l00002ojO0j`Co00000onW`>/0
0ol0003oYl3[ojO0j`05o`0000;o;eC60_l000001Om6Hl_o0000oea`c_mLL<ko000000;oLWg?00Go
0000ohJ9con6RLooQXW?o`000004oiRDcP03o`000?nVWLcoYYg<00;oYYg<00?o0000ok:Ubol00000
0onfYlT00ol0003o`:k8ol2^b002ol2^b0;o00001Oo;]LD01Ol0003oc[K3o`000?oD^l;o000000Go
e[c00_l00002omc1_P05o`000?oN`[cog/:lomk2_?l000000_oP`k/00ol0003oh/Fko`000002on?6
^P09o`000?oTa[Woi<JionC6^Ol0003oiLJho`000?oUakWo000000;oi/Nh00Co0000onK7^?oVakSo
00000_oUa[P00ol0003oi<Jio`000003on?5^@04o`000?oRa;[oh/Bjo`0000?ogL2l00Go0000om^n
_?oK_[cofkjlo`000004om>h_P03o`000?o@]Koo000000;ob[3000Co0000olN]`?o7[L3o00000_o0
Yl400ol0003o_JC1o`000004okJO`@06o`000?n_V/;o0000o`000?n]Ul7o00001?nVTl401Ol0003o
Who3oin?`onOSl?o000000CoVHc400Go0000oi:9a_nBRLKoTXW6o`000003oh^7b@05o`000?n5QLco
QHG<ohF5c?l000001?moQM001Ol0003oNXODogZ7e?mjQmCo000000;oMXWI00Co0000ogB>g_mdS]ko
M8kN2_l00003og2Ul@03o`000?n7]oGoQkOe00;oQkOe00?o0000ojO1k?nW`N`00ol00005ojO0j`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool002_ooooo00?o0000ooooooooool0
4oooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`06o`00
0?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000;oYl3[0ol00003ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000;oYl3[00Oo0000oae:`ol0003o0000obmDa_l0003oAV;:00;o00000_mL
L<h01Ol0003oLWg?og9mcombOLoo000000?oQXW?00?o0000oiRDc_nHU<h00_nHU<h01?l0003oYYg<
ojJMc?nVWL`2o`0000Go]ZO900Co0000ol2^b?o0[/So00000_o3[lH01Ol0003obkG5ol^eaOo;]LGo
000000?oc[K300?o0000omJl`?oF_<000ooF_<001_l0003ofKfnomVm__l0003og<6no`0000?og/:l
00Go0000on33^ooP`k_oh<>ko`000002on?6^P05o`000?oTa[Woi<JionC6^Ol000000ooUa[P01?l0
003oi/NhonK7^?l00003onK7^005o`000?oUa[SoiLJhonG6^?l000000ooSaKT02?l0003oh/Bjon;4
^_l0003ohL>jo`000?oM`;co00001?oK_[`01Ol0003odkRnom>h__oC^;ko000000;od;Fo00?o0000
olZ``?l000000oo7[L000ol0003o`:O1o`000003okfT`@04o`000?nfWl7o]Yo1okJO`@;o00001?n]
Ul401Ol0003oYY?1ojJC`OnVTl7o000000CoWho300?o0000oiV<a?nIS<@05ol00003ogJ9f@05o`00
0?mdS]koM8kNogB>g_l000000omeUN@01?l0003oN9gYo`000?mhWNT<o`0000?oYLKa00Co0000ojO0
jonW`>_oYl3[0ol0000Booooo`03o`000?oooooooooo00[ooooo000Zooooo`;o00005_ooool2o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0
003oYl3[o`000?l00002ojO0j`?o00000_nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00003ojO0j`07o`000?nW`>_oYl3[ojO0jol0003o7D[3o`000002obmDaP03o`000?m6H/[oAV;:
00;o000000?oG73>o`000?mbOLl00_mbOLl01Ol0003oQXW?ohJ9con6RLoo000000?oV9C>00Ko0000
ojJMc?l0003o0000ojZObol00005okJWb@03o`000?o0[/So000000Co`jo600?o0000ol^eaOl00000
1?o>]/<00ol0003oe[c0omJl`002omJl`003o`000?oI_KkofKfn00;ofKfn00Go0000omk2_?oN`[co
g/:lo`000004on33^`;o000000?ohlJjo`000?oTa[T00_oTa[T01?l0003oiLJhonG6^?oUa[P2o`00
0005onK7^?l0003oi/NhonK7^?l000001?oUa[P01?l0003ohlFion?5^Ol00003on;4^P04o`000?oQ
`k[ohL>jo`0000Cofkjl00Go0000omVl_Ol0003odkRno`000004om2e_`03o`000?o7[L3oajg000?o
ajg000?o0000okfT`OnmY<400_nmY<401_l0003o]Yo1okJO`Ol0003o/ic0o`0000Co[IO100Go0000
ojJC`OnVTl7oYY?1o`000002oin?``Go00000_nJRl801Ol0003oUHW4oiF9a?nERLCo000000?oT8O6
00Go0000oh^7bOn;QlWoRhO9o`000004ohN7c@03o`000?n3RM7oPhWA00Go00001?mdS]h01?l0003o
MIGTogFEi?meUN@2o`0000;oN9gY00?o0000ogfWk_mmYnh00_mmYnh00ol0003oP[3boh:`lP02oh:`
lP03o`000?nUa_7oYLKa00Go00000_nW`>/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00[ooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ojO0jonW`>/00_nW`>/3o`0000Co
Yl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Oo000000CoYl3[o`000?nW
`>_oYl3[0ol00004ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/0
1_l0003oYl3[ojO0jonW`>_o0000oae:``?o00000_m6H/X01?l0003oGW3=o`000?l00003og9mc`05
o`000?n6RLooQXW?ohJ9col000000_nHU<h3o`0000CoZYo;00?o0000okJWbOnfYlT00_nfYlT2o`00
00Go`jo60_l00004oljf``03o`000?oA^<7o000000?oe[c000?o0000omVm__oI_Kh00_oI_Kh01?l0
003og/:lomk2_?l00004on33^`04o`000?oQ`k[ohL>jo`0000?oi<Ji00Go0000onG6^?oUa[SoiLJh
o`000002onK6]`05o`000?oVakSoi/NhonK7^?l000000ooUa[P01Ol0003oiLJho`000?oSaKWo0000
00;oh/Bj00Go0000on73^_oQ`k[ohL>jo`000003om^n_005o`000?oI_;gofKbmomVl_Ol000001Oo@
]Kl00ol0003oajg0olN]`002olN]`0;o00001?nmY<400ol0003o]Yo1o`000003ok>L`005o`000?n]
Ul7o[IO1ojfG`Ol000000onVTl43o`0000;oX8g100?o0000oiZ;`_nJRl800onJRl801Ol0003oUHW4
oiF9a?nERLCo000000?oT8O600Go0000oh^7bOn;QlWoRhO9o`000004ohN7c@04o`000?n3RM7oPhWA
o`0000;oPHgF3ol00002ogfWkPWo00000_nN_o000ol0003oYl3[ojO0j`02ojO0j`;o00004_ooool0
0ol0003oooooooooo`09ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`04o`000?nW`>_o0000
o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[0ol0
00000onW`>_o0000o`000002o`0000;oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW
`>/00ol0003oYl3[ojO0j`06o`000004oae:`ol0003o;e;5o`0000?oAV;:00?o0000oei`cOmNL<d0
2_l00002oi^Fc@03o`000?nZWl_oZYo;00?oZYo;00Ko0000okJWbOnfYlWo0000okZXb?l00004ol>_
aP03o`000?o6/LGo000000?oc[K300Oo0000om6h`OoA^<7odKS1o`000?oF_<3o000000CofKfn00Go
0000om^n_Ol0003og/:lo`000003on33^`05o`000?oQ`k[ohL>jon73^_l000000ooTa[T01Ol0003o
iLJhonG6^?oUa[So000000;oi/Jg00Co0000onK7^?oVakSo00001?oUa[P01?l0003oiLJhonG6^?l0
0002on;4^P07o`000?oQ`k[ohL>jon73^_l0003ogl:ko`000002om^n_005o`000?oI_;gofKbmomVl
_Ol000001?o@]Kl00ol0003ocK?0o`000002olN]`004o`000?o3Z/7o`j[1o`0000?o_JC10_l00004
ok>L`003o`000?n]Ul7o[IO100;o[IO10ol000000onUTL3o0000oj2=`@03oj2=`@03o`000?nJRl;o
VX_200;oVX_200Go0000oiF9a?nERLCoUHW4o`000003oi27aP05o`000?n;QlWoRhO9oh^7bOl00000
1?n7Qld01Ol0003oPhWAoh>9dOn3RM7o000000;oPHgF00?o0000ognAfomoTM/00_moTM/02?l0003o
P9SQoh2HhOn0V>7o0000oh>Pi_l0003oPj3V0ol00002ohNXj`03o`000?n</NooS;7_00;oS;7_00?o
0000oijol?nN_o000_nN_o001_l0003oYl3[o`000?l0003oYl7/o`00017ooooo0ol0000:ooooo`00
:_ooool00ol0003oooooooooo`0Gooooo`;o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00Co0000ojO0jol0003oYl3[0ol00003ojO0j`?o00001?nW`>/00ol0
003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`07o`000?lkQ>Wo0000
o`000?lMB/?o0000obmBa@02o`000005odIRb_l0003oGW3=oei`cOl000000omeO/h01Ol0003oRH_>
ohV;c_n9Rlko000000CoViK=00?o0000ojZObonZWl/00_nZWl/00ol0003o]ZO9o`000003okZXb004
o`000?o3[lKo`jo6o`0000?oa[7500Co0000oljf`oo>]/?o00001?oA^<400ol0003ofKfnomVm_P02
omVm_P05o`000?oK_[gofkjmom^n_Ol000000ooP`k/02Ol0003ohL>jon73^_oQ`k[o0000on?4^Ol0
003oi<Jio`000003onG6^008o`000?oVa[Ooi/Jgo`000?oVakOo0000onK7^?l00003onG6^004o`00
0?oUa[SoiLJhonG6^0;o000000?oh/Bjo`000?oQ`kX00_oQ`kX01Ol0003ogl:ko`000?oK_[co0000
00?ofKbm00?o0000omJj__l000000_o@]Kl01_l0003ocK?0olfc`?l0003oajg0o`0000?o`j[100Ko
0000okfT`OnmY<7o0000okVQ`?l00004ok>L`004o`000?n]Ul7o[IO1ojfG`@;o00001?nUTL001Ol0
003oX8g1oj2=`OnPSL7o000000CoVX_200Go0000oiF9a?nERLCoUHW4o`000003oi27aP05o`000?n;
QlWoRhO9oh^7bOl000001?n7Qld01Ol0003oPhWAoh>9dOn3RM7o000000?oPHgF00?o0000ognAfomo
TM/00_moTM/01?l0003oP9SQoh2HhOn0V>42o`0000?oPj3V00Go0000ohNXjon7Z>_oQjS[o`000002
ohbak`So00001?nW`N`00ol0003oooooooooo`0;ooooo`?o00000_ooool00ol0003oooooooooo`08
ooooo`00:_ooool2o`0001[ooooo00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nW`>_oYl3[
00Go00000_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00?o000000Oo>hCY
o`000?l0003o0000obmBaOl0003oAf7:00;o00000omNL<d01Ol0003oMGk>ogEnc_meO/ko000000?o
RH_>00Go0000oi^FcOnKU/goViK=o`000004ojZOb`;o00001?njZ<P00ol0003o`jo6o`000004olJa
a@03o`000?o>]/?o000000GodKS100Go0000omVm__oI_KkofKfno`000004om^n_@05o`000?oP`k_o
h<>kon33^ol000000ooQ`kX01?l0003ohlBion?4^Ol00004onG6^004o`000?oVa[Ooi/Jgo`0000;o
i/Ng0_l00002onG6^005o`000?oUa[SoiLJhonG6^?l000000_oTa[T01Ol0003ohL>jon73^_oQ`k[o
000000?ogl:k00Go0000omVl_OoI_;gofKbmo`000002omJj_P03o`000?o@]Koo000000CocK?000?o
0000ol>Z`Oo3Z/400_o3Z/400ol0003o_JC1o`000003okVQ`003o`000?ncW<3o/ic000;o/ic00ol0
00000on[U;oo0000ojFA`003ojFA`005o`000?nPSL7oX8g1oj2=`Ol000001OnJRl800ol0003oUHW4
o`00000Zo`0000;oTk7/00?o0000oi^jk_nK^^h00onK^^h00ol0003oYl7/ojO1k003o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo00Sooooo000Yooooo`;o00007?ooool2o`0000CoYl3[00?o
0000ojO0jonW`>/02?l00002ojO0j`Co00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000Co
Yl3[00Co0000ojO0jol0003o00000_nW`>/01?l0003oYl3[ojO0jonW`>/3o`0000;oV[c`0_l00000
0olkQ>Wo0000o`000002obmBa@03o`000?m7HL[oAf7:00;o000000?oGW3=o`000?meO/h00_meO/h0
1Ol0003oRH_>ohV;c_n9Rlko000000?oViK=00?o0000ojZObol000000_l000000on^XL[o0000okZX
b003okZXb0;o00001_o6/LD00ol0003odKS1om6h`@03om6h`@05o`000?oC^L3o0000omVm__l00000
1?oK_[d01Ol0003ogL2lo`000?oP`k_o000000?ohL>j00Co0000on?4^OoSa;WohlBi0_l00002onG6
^004o`000?oVa[Ooi/Jgo`0000?oi/Ng00Go0000onK7]ol0003oiLJho`000003onG6^004o`000?oT
a[Woi<Jio`0000;ohL>j00?o0000omo2^ooO`[/00_oO`[/01Ol0003ofKbmomVl_OoI_;go000000?o
e[Zn00?o0000olfc`?o=/l000oo=/l000ol0003o`j[1ol>Z`@03ol>Z`@03o`000?niXL3o^J7000;o
^J7000Co0000ok>L`?ncW<3o/ic00_l00004oj^D_`05o`000?nUTL3oYI70ojFA`?l000001?nPSL40
0ol0003oVX_2oiZ;`P04o`0000;oV8W200Go0000oiB8a?nDR<CoU8S4o`000003oi68a`03o`000?n>
RL[oSXW:00;oSXW:00Go0000oh^<c_n;S<koRhc>o`000003ohZ?d`03o`000?n9U=SoRICH00;oRICH
00Oo0000ohZKgOn:VmgoRY_Mo`000?n<X^?o000000;oS:;S00Go0000oi2Zion@Z^OoT:[Wo`000004
oi>ak004o`000?nK^^koVk[^oi^jkPCo00000onW`N`00ol0003oooooooooo`02ooooo`Co00002?oo
ool00ol0003oooooooooo`08ooooo`0000?o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003oYl3[ojO0j`02ojO0j`?o
000000CoYl3[o`000?l0003o00000_nW`>/4o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0
j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[o`000002ojO0j`04o`000?nJ_?3oV[c`
oiZll0?o000000Co64Boo`000?l0003o00000_m7HLX01?l0003oH77=o`000?l00003ogEncP05o`00
0?n9RlkoRH_>ohV;c_l000000_nKU/d3o`0000Go[Z7:00Ko0000okZXb?njZ<So0000okf[aol00005
olJaa@03o`000?o:/l?o000000?odKS100Go0000om>i`?oC^L3odkW0o`000005om^n_@04o`000?oM
`;cogL2lo`0000CohL>j00Co0000on?4^OoSa;Wo00000_oTaKP00ol0003oiLJho`000002onK6]`04
o`000?oVakOoi/Ngo`0000?oi/Ng00Go0000onG6^?oUa[SoiLJho`000002onC6^@05o`000?oTa[[o
0000on73^_l000000ooO`[/01Ol0003ogL6mo`000?oI_;go000000Coe[Zn00?o0000olfc`?o=/l00
0_o=/l000ol0003obK31o`000003ol>Z`@;o00001?niXL001_l0003o/ic0o`000?l0003o/9W0o`00
00CoZiBo00?o0000ojFA`?nUTL000_nUTL000ol0003oX8g1o`000004o`0000;oW8[000?o0000oiR9
`_nHRL800_nHRL801Ol0003oU8S4oiB8a?nDR<Co000000?oTHS700?o0000ohj9b_n>RLX00_n>RLX0
1Ol0003oRhc>oh^<c_n;S<ko000000?oRXoC00?o0000ohVDf?n9U=P00_n9U=P01ol0003oRY_MohZK
gOn:Vmgo0000ohbRhol000000_n<X^<01Ol0003oT:[Woi2Zion@Z^Oo000000;oTk7/1Ol00002oifi
k004o`000?nW`NcoYl7/ojO1k0Ko00003?ooool00ol0003oooooooooo`08ooooo`0000?ooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00Go
0000ojO0jol0003o0000ojO0j`03o`0000;oYl3[0ol00004ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`09o`00
0?nJ_?3oV[c`o`000?l4>;[o0000oaQ4_ol0003o;U;500;o00000_m7HLX00ol0003oH77=of1ac@0:
o`0000;oWiS<00?o0000ojjQb_n^XLX00on^XLX00ol0003o^ZS8o`000003okf[a`05o`000?o6/LGo
a[75olJaaOl000000oo:/l<00ol0003odKS1o`000004om>i`003o`000?oK_[gofkjm00;ofkjm00Co
0000omg0_?oM`;cogL2l0_l00002on73^P05o`000?oSa;WohlBion?4^Ol000000ooTaKP01?l0003o
i/JgonK6]ol00003onK7]`05o`000?oVakOoi/NgonK7]ol000000_oUa[P01Ol0003oi<JionC6^OoT
a[Wo000000;oi<Jj00Go0000omo2^ooO`[_ogl:ko`000003omg1_@03o`000?oF^[koe[Zn00;oe[Zn
00?o0000om>i`?l000000_o=/l001?l0003obK31olV``Ol00002ol>Z`@04o`000?noYl7o_jO1o`00
00?o^J700_l00004ok2I`005o`000?n[U;ooZiBooj^D_ol000000_nUTL04o`0000;oX8bo00?o0000
oib:`?nLR/000onLR/001Ol0003oV8W2oiR9`_nHRL;o000000?oU8S400Go0000oi68aonAR<OoTHS7
o`000004ohj9bP05o`000?n;S<koRhc>oh^<c_l000000on:Sm<00ol0003oRICHohVDf002ohVDf006
o`000?n:VmgoRY_MohZKgOl0003oS:;S2_l00003oiZbj@03o`000?nM^NcoWKW/00Go00000_nU_^/0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0002ooooo`03oa0@4?oooooooooo
00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo1?l00002ojO0j`03o`000?nW
`>_o000000;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00Co0000ojO0jonW`>_oYl3[
0ol00004ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`000003oiZl
l?l0003o13Rj00?o000000Go;U;5o`000?m7HL[oAf7:o`000002of1ac@05o`000?mhOlkoN7o>ogQo
c_l000000on=SLh00ol0003oWiS<oinHc002oinHc003o`000?n^XL[o[Z7:00;o[Z7:0_l00005okf[
a`03o`000?o6/LGo000000Gob[?300?o0000om>i`?oC^L000_oC^L000ol0003oe[^oo`000002om^n
_@05o`000?oM`;cogL2lomg0_?l000000_oN`K/00ol0003ohL>jo`000002on?4^@03o`000?oTaKSo
i<Fh00;oi<Fh0_l000001OoVa[Oo0000onK7]ooVakOo000000?oi/Ng00Go0000onK8^?l0003oiLJh
o`000002onC6^@05o`000?oTa[[oi<JjonC6^_l000000ooO`[/01Ol0003ogL6momg1_OoM`Kgo0000
00?oe[Zn00Ko0000om>i`?oC^L3o0000olfc`?l00003olV``@03o`000?o3Z/7o000000?o_jO100Ko
0000okVQ`?niXL3o0000okJN`?l00004ok2I`004o`000?n[U;ooZiBooj^D_`?o00000_nTSkl00ol0
003oX8booj2<_`02oj2<_`03o`000?nLR/3oW8[000;oW8[000Go0000oiR9`_nHRL;oV8W2o`000003
oiB8a005o`000?nAR<OoTHS7oi68aol000001?n>RLX00ol0003oRhc>oh^<cP0Bo`000003oiBTh?l0
003oUj_U00CoUj_U00?o0000oiZbjOnJ/^T01?l00002oj6ij@03o`000?nU_^_oYKk[00?oYKk[00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`000_ooool00ol0003oooooooooo`09
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oooooo
00?oMgMgoc8b<_ooool01?ooool2o`0001gooooo0ol000001?oooooo0000ojO0jonW`>/3o`0000Co
Yl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW`>_o0000
00;oYl3[00?o0000ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`?o000000?o13Rjo`000?lE@[l00_l000001Ol^D/Go0000o`000?m7HL[o000000;oH77=00Go0000
ogQoc_mhOlkoN7o>o`000003ohf=cP03o`000?nOV<coWiS<00;oWiS<00Ko0000ojjQb_n^XL[o0000
ok6SbOl00006okf[a`03o`000?o:/l?ob[?300?ob[?30_l00003om>i`007o`000?oF^kooe[^oomJk
_ol0003ofkjmo`000003omg0_005o`000?oN`K_og/6komk1^ol000000_oSa;T00ol0003oi<FhonC5
^002onC5^004o`000?oUa[SoiLJho`0000;oi/Ng00Go0000onK7]ooVakOoi/Ngo`000003onK8^004
o`000?oTa[Woi<Jio`0000?oi<Jj00Go0000on;6^ol0003ogl:ko`000003omg1_@05o`000?oK`;ko
0000omJj__l000001?oC^L000ol0003obK31olV``@03olV``@03o`000?noYl7o_jO100;o_jO100?o
0000okVQ`?l000000onfW/001_l0003o/9W0ok2I`?n`VL3o0000oj^D_`;o000000?oZ9:oo`000?nT
Skl00onTSkl00ol0003oX8booj2<_`02oj2<_`05o`000?nLR/3oW8[0oib:`?l000001?nHRL800ol0
003oU8S4o`00000<o`0000;oTXk<00Go0000oi:Bd?nBT]3oTY;@o`000004oi:GeP05o`000?nCWM_o
TigKoi>Mfol000000_nDY>000ol0003oU:CPo`000003oiN[i@Co00000_nO/nH00ol0003oXKWYoj6i
j@02oj6ij@03o`000?nU_^_oYKk[00?o00003oooool00ol0003oooooooooo`07ooooo`000_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Wo
oooo0ol00005ooooo`;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000
ojO0jonW`>/00_nW`>/02_l0003o76cNo`000?l4>;[o0000oaE2_ol0003o;U;5o`000?m7H/X2o`00
00?oH77=00Co0000ogQoc_mhOlko00001?n=SLh01ol0003oWiS<oinHc?nOV<co0000ojjQb_l00000
0onaXlT00ol0003o_J_7okf[a`02okf[a`;o00001?o:/l<01?l0003ocKG2olfe`_l00002om>i`003
o`000?oF^kooe[^o00;oe[^o00Go0000omg0_?oM`;cogL2lo`000004omk1^`;o000000?ohlBio`00
0?oTaKP00_oTaKP01?l0003oiLJhonG6^?oUa[P2o`000003onK7]ol0003oi/Ng00;oi/Ng00Co0000
onK8^?oVb;Soi/Rh0_l000000ooTa[Wo0000onC6^P02onC6^P04o`000?oRa[_oh/Jko`0000?ogL6m
00Go0000om_0__oK`;kofl2no`000004om>i`0;o00001?o9/<42o`0000Co_jO10_l00004okJN`004
o`000?n`VL3o/9W0ok2I`0;o00001?nXT[l01Ol0003oY8noojB?_onTSkoo000000CoX8bo00?o0000
oib:`?nLR/002?l00002oiR9`P05o`000?nFR/GoUX[5oiJ:aOl000001?nDS<P00ol0003oTXk<oi:>
c002oi:>c005o`000?nBT]3oTY;@oi:Bd?l000000onBUmH00ol0003oTigKoi>Mf`02oi>Mf`03o`00
0?nDY>3oU:CP00Go00000_nM[N800ol0003oWk?VoinciP02oinciP03o`000?nQ^NWoXKWY00Co0000
0onV_^/00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo0002ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`03
o`000?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYl3[ojO0j`06o`0000;o5D:o00?o0000obiBaOl000000_m7H/X4o`0000?oN7o>00Go0000ohf=
c_n=SLkoSHg>o`000002oinHc0?o00001OnaXlT01?l0003o_J_7okf[aol00002ol6]aP04o`000?o:
/l?ob[?3o`0000?ocKG200?o0000om>i`?l000001OoF^kl01?l0003ogL2lomg0_?l00004omk1^`04
o`000?oP`[[oh<:jo`0000?oi<Fh00Go0000onG6^?oUa[SoiLJho`000002onK7^005o`000?oVakOo
i/NgonK7]ol000000ooVb;P01?l0003oi/RionK8^Ol00003onC6^P05o`000?oRa[_oh/Jkon;6^ol0
00000ooM`Kd01Ol0003ofl2nom_0__oK`;ko000000?odkW000Co0000olng`_o?]l;o00000_o9/<40
1?l0003oaJg2olF]`_l00002oknW`@03o`000?nkY<;o000000Co]Yk000Ko0000ok2I`?l0003o0000
ojfG_ol00004ojRB_`05o`000?nTSkooY8noojB?_ol000001?nPS;l3o`0000;oWHZo00Go0000oiZ9
`?nJRL3oVXW0o`000004oiR9`P05o`000?nFR/GoUX[5oiJ:aOl000001?nDS<P01Ol0003oTXk<oi:>
c?nBS/co000000?oTY;@00?o0000oi:Ge_nBUmH00_nBUmH00ol0003oTigKoi>Mf`05o`000003oibV
gOl0003oWJgR00CoWJgR00?o0000oinci_nO/nH01?l00003ojFkj@03o`000?nV_^_oY[k[00?o0000
3Oooool00ol0003oooooooooo`07ooooo`0000?ooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool2o`0000kooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/00ol0003oYl3[ojO0j`04o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03
o`000?nW`>_oYl3[00Co00000_nA^O801?l0003o76cNo`000?l00002oaE2_`?o00000_m7H/X00ol0
003oHW;=of9bc@05o`0000;oSHg>1?l00002oj>Jc003o`000?naXlWo/J?900?o/J?900?o0000okf[
aol000000oo1[LH00ol0003ob[?3o`000005olfe`P03o`000?oF^kooe[^o00?oe[^o00Go0000omRm
__l0003ogL2lo`000004omk1^`04o`000?oP`[[oh<:jo`0000?oi<Fh00Go0000onG6^?oUa[SoiLJh
o`000002onK7^005o`000?oVakOoi/NgonK7]ol000000ooVb;P01?l0003oi/RionK8^Ol00002onC6
^P09o`000?oRa[_oh/Jkon;6^ol0003ohLJmo`000?oM`Kgo000000?ofl2n00Go0000omRo`Ol0003o
dkW0o`000003olng`P03o`000?o9/<7o000000?oaJg200?o0000oknW`Ol000000onkY<801?l0003o
]Yk0okJN`?nfW/02o`0000Co[INo00Go0000ojRB_onXT[ooZ9:oo`000004ojB?_`Co000000?oX8bn
o`000?nMR[l00onMR[l01Ol0003oVXW0oiZ9`?nJRL3o000000?oV8W200Go0000oiJ:aOnFR/GoUX[5
o`000004oiB<b005o`000?nBS/coTXk<oi:>c?l000000_nBT]09o`0000;oVZ3H00Ko0000oibVgOnL
Y]go0000oibVgOl00002oif]hPGo00000_nT]nH00ol0003oYK_YojFkj@02ojFkj@?o00000onW`>/0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00000ol0003o<S8bonk^kP0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0
0005ooooo`03o`000?oooooooooo01;ooooo0ol0000@ooooo`03o`000?nW`>_oYl3[00;oYl3[0ol0
0003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001?nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`04o`000?nA^O;oTKWboi6ilP;o000000Co03Fio`000?l0
003o5D:o0_l00003odMRbP04o`000?mRL/goHW;=o`0000;oNh;?0ol00002oi6?cP03o`000?nSV/co
Xi[<00;oXi[<00?o0000ok6SbOnaXlT00_naXlT2o`0000Go`Jg600?o0000olfe`_o=]L801?o=]L80
0ol0003oe[^oomJk_`02omJk_`05o`000?oH_Kkof;fnomRm__l000001?oN`K/02?l0003oh<:jon32
^_l0003oh/Bjo`000?oTaKSo00000ooUa[P02?l0003oi/NhonK7^?l0003oi/Rho`000?oVakOo0000
0ooVb;P02?l0003oi/RionK8^Ol0003oi/Vjo`000?oTa[[o00000_oRa[/01Ol0003ohLJmon76_OoQ
a[go000000?ofl2n00Go0000omRo`OoH_l7of;o1o`000005olng`P03o`000?o5[L;oaJg200?oaJg2
00?o0000ok^T`_nkY<800_nkY<801_l0003o]Yk0okJN`?l0003o/Y_1o`0000Co[INo00?o0000ojRB
_onXT[l00_nXT[l00ol0003oY8noo`000002o`0000GoX8bn00Go0000oif:_onMR[ooWHZoo`000003
oiZ9`005o`000?nHRL;oV8W2oiR9`_l000000onFR/D01?l0003oU8c8oiB<b?nDS<P8o`0000;oVIG>
00Go0000oiVJdonIV]?oVI[Co`000005oiZPf003o`000?nLY]goW:KM00Co00000_nS/^<00ol0003o
Y;OVojBgiP03ojBgiPCo000000?oYl3[o`000?nW`>/00onW`>/2o`0000_ooooo00?o0000oooooooo
ool01oooool002Sooooo0_l0000@ooooo`?o00005?ooool01?l0003oYl3[o`000?l00002ojO0j`03
o`000?nW`>_oYl3[00;oYl3[00?o0000ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`02ojO0j`?o
00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l000001_nA^O;o
0000o`000?l0=KWo0000oa91_P;o000000Go;E75o`000?l0003oAf;:o`000003of9bc@04o`000?mk
P/ooNh;?o`0000CoTHo>00Go0000oj>Jc?nSV/coXi[<o`000002ok6Sb@;o000000?o]JK9o`000?o1
[LH00oo1[LH2o`0000GocKG200?o0000om2g`_l000000_oF^kl00ol0003of;fnomRm_P02omRm_P;o
00000_oN`K/01Ol0003oh<:jon32^_oP`[[o000000;oh/Bj00?o0000onG6^?oUa[P00_oUa[P01?l0
003oi/NhonK7^?l00002onK8^0;o00000_oVb;P01Ol0003oi/RionK8^OoVb;Wo000000;oi/Vj00Go
0000on;6^ooRa[_oh/Jko`000003on76_@;o000000?ofl2no`000?oH_l400ooH_l400ol0003ockO2
olng`P02olng`P;o00001?o5[L82o`0000Co^jC200?o0000okJN`?l000000onbVl401Ol0003o[INo
ojfG_on]Ukoo000000?oZ9:o0ol00002oj>>_P03o`000?nPS;koX8bn00?oX8bn00Go0000oif:_onM
R[ooWHZoo`000003oiZ9`003o`000?nHRL;oV8W200;oV8W200?o0000oiJ:aOl000001?l00002oiV>
aP05o`000?nITL[oVI7:oiVAb_l000001?nIULh01Ol0003oVI[CoiVJdonIV]?o000000?oVZ3H1?l0
00000onR[Moo0000o`000004oj>bh`03o`000?nT]nKoY;OV00?o00001OnW`>/4o`000003ojO0jol0
003ooooo00_ooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool03?ooool3
o`0001Sooooo0_l00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00003ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00000onW`>/3o`000009
o`0]]?l0003o0000o`000?lB@Kko0000obeAaOl0003oB6?;00;o00000omRL/d01Ol0003oNh;?og^2
comkP/oo000000?oTHo>00Oo0000oj>Jc?nSV/coXi[<o`000?naXlWo000000Co]JK900Co0000ol6]
a_o1[LKo00000_o4[lD01Ol0003ocKG2olfe`_o=]L;o000000;od;O200?o0000omJk_ol000001?oH
_Kh01_l0003ofkjmom^n_Ol0003og/6ko`0000;oh<:j00Co0000on;4^_oRa;[oh/Bj0_l00002onG6
^004o`000?oVakSoi/Nho`0000?oi/Rh00Go0000onO9^Ol0003oi/Rho`000002onK8^@04o`000?oV
bK[oi/VjonK9^P;o000000?oh/Jko`000?oQa[d00_oQa[d01?l0003oglJoomo6_ol00004omRo`@03
o`000?oE_/?o000000;ockO200Co0000olbda?o<]<Co00000_o5[L801?l0003o`J_3ol6[`ol00003
ok^T`P;o00001?nbVl400ol0003o[INoojfG_`02ojfG_`?o000000?oYi6no`000?nSS[h00onSS[h0
0ol0003oX8bnoj2<_P02oj2<_P03o`000?nMR[ooWHZo00;oWHZo00?o0000oiZ9`?l000001ol00002
oiZ<``03o`000?nIS/KoVHk600?oVHk600Go0000oiVAb_nITL[oVI7:o`000003oiVEcP03o`000?nI
V]?oVI[C00Go00000_nQZ=/01_l0003oXZgOoj:]gol0003oXZgOo`0000;oXk;S1?l00003ojO0j`03
o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Ko
oooo000Xooooo`03o`000?oooooooooo00Wooooo0ol0000Mooooo`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003o
Yl3[ojO0j`02ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/00_nW`>/01Ol0003o
3FGJo`000?l0003o03>h00;o000000Co4T6no`000?l0003o00000_m8Hl/4o`0000?oNh;?00Go0000
oi6?c_nASlkoTHo>o`000002oj>Jc0?o00001OneY/T00ol0003o`Jg6o`000004olB_a@03o`000?o=
]L;o000000Cod;O200?o0000omRm__oH_Kh00_oH_Kh00ol0003ofkjmom^n_@02om^n_@05o`000?oP
`[[oh<:jon32^_l000000_oRa;X01_l0003ohlJjon?6^_l0003oiLJho`0000;oi/Nh00Co0000onK8
^?oVb;So00000ooWbKT01?l0003oi/RionK8^Ol00003onK9^P04o`000?oUb[coiLZlo`0000?ohLJm
00Go0000omo6_ooOa[ooglJoo`000003omRo`@06o`000?oE_/?oeKk3o`000?o?]l;o00000oo<]<@0
0ol0003oaJg2o`000003ol6[``06o`000?nkY<;o^jC2o`000?ngXL;o00001?nbVl401?l0003o[INo
ojfG_on]Ukl2o`0000CoYi6n00Go0000oj>>__nSS[koXhjno`000005oj2<_P03o`000?nMR[oo0000
00?o00000_nMR[l01Ol0003oVh_1oi^;`OnKRl7o000000CoVXc300?o0000oiV>a_nIS/H00_nIS/H0
1Ol0003oVI7:oiVAb_nITL[o000000;oVIG>1?l00002oj6Se`03o`000?nQZ=_oXJSK00?oXJSK00?o
0000oj:]gonR[Ml01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`03o`0000_ooooo00?o0000ooooooooool01_ooool002Sooooo00?o0000ooooooooool01_ooool3
o`00027ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00001?nW`>/00ol0003oYl3[ojO0j`03
o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00Co000000Oo02fd
o`000?l0<kSo0000oa91__l0003o:e7600;o000000CoB6?;o`000?mTM<koI7C>1Ol00002oi6?cPCo
00000_nWWL`00ol0003o]JK9okFVb@03okFVb@;o00001Oo4[lD2o`0000God;O20_l00003omRm_P03
o`000?oK_[gofkjm00;ofkjm00Co0000on32^_oP`[[o00000ooRa;X01Ol0003ohlJjon?6^_oSa[[o
000000;oi/Nh00Go0000onK8^?oVb;Soi/Rho`000003onO9^@;o000000?oi/Rio`000?oVbKX00_oV
bKX01?l0003oiLZlonG:_?l00003on76_@08o`000?oOa[ooglJoo`000?oMa/;o0000omRo`Ol00004
omFn``03o`000?o<]<Coc;C400?oc;C400?o0000ol6[`oo1Zl<00_o1Zl<00ol0003o^jC2o`000003
okNQ`P03o`000?nbVl7o/Y_100;o/Y_10ol000000onZU;oo0000ojNA_P03ojNA_P03o`000?nSS[ko
Xhjn00;oXhjn00Co0000oj2<__nPS;koX8bn0ol00002oij:_P03o`000?nMR[ooWHZo00;oWHZo00Go
0000oi^;`OnKRl7oVh_1o`000003oiZ<``03o`000?nIS/KoVHk600;oVHk600?o0000oiVAb_nITLX0
1?l00002oj2NdP03o`000?nQXmOoXJ?G00;oXJ?G00Co0000oj6XfonQZ=_oXJSK1?l000000onW`>_o
0000o`000004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`06ooooo`00:?ooool00ol0003oooooooooo`03ooooo`?o0000
9_ooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oU[[a00Co0000o`eUf_l0003o
00000_l0<kP01Ol0003o4T6no`000?l[DLKo000000;oB6?;00Co0000ofAdc_mTM<ko00000_mnQ<l3
o`0000;oU9;>00?o0000ojNMc?nWWL`00_nWWL`01ol0003o]JK9okFVbOneY/Wo0000okVYbOl00000
1?o4[lD00ol0003oak;5o`000004om2g`P06o`000?oB^L7od[W1o`000?oH_Kko00001?oK_[d01Ol0
003ogL6mo`000?oP`[[o000000;oh/Bj00?o0000on?6^_oSa[X00_oSa[X2o`000005onK7^?l0003o
i/RhonK8^?l000000ooWbKT01?l0003oil^jonO;^_l00003onK9^P08o`000?oUb[coiLZlo`000?oT
bkko0000on76_Ol00002omo6_`05o`000?oMa/;ogLK2omg6`_l000001OoE_/<2o`0000?oc;C40_l0
0004ol6[``;o00001?ngXL801?l0003o/Y_1ok:K`OnbVl42o`0000CoZYBo00?o0000ojNA__nWTKh0
0_nWTKh01_l0003oXhjnoj>>__nSS[ko0000oj2<_P;o000000?oX8^mo`000?nNR[h00onNR[h01Ol0
003oWHZooif:_onMR[oo000000?oVh_100Go0000oiZ<`onJS<?oVXc3o`000003oiV>aPCo00000_nP
V/h00ol0003oX9kBoj2NdP02oj2NdP06o`000?nQXmOoXJ?Goj6Seol0003oXJSK0_l000000onW`>_o
0000ojO0j`02ojO0j`03o`000?nW`>_o000000?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?o
Yl3[00?o0000ojO0jonW`>/00ol00009ooooo`03o`000?oooooooooo00Kooooo000Wooooo`;o0000
0_ooool3o`0002[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00004ojO0j`03o`000?nF^_7oU[[a00?o0000
0_l0<kP00ol0003o4T6no`000002ob]AaP;o000000GoB6?;o`000?mTM<koI7C>o`000002ogj4c`03
o`000?nDT/koU9;>00;oU9;>00?o0000ojNMc?nWWL`00_nWWL`00ol0003o]JK9o`000003okVYb@04
o`000?o4[lGoa:o5o`0000?oak;500Co0000om2g`_o@]l;o00001?oB^L400ol0003ofkjmom^n_@02
om^n_@05o`000?oM`KgogL6momg1_Ol000000_oRa;X00ol0003ohlJjon?6^P02on?6^P04o`000?oU
ak[oiLNjo`0000;oi/Rh00?o0000onO9^OoWbKT00_oWbKT01?l0003oil^jonO;^_l00002onK9^P05
o`000?oUb[coiLZlonG:_?l000000_oTbkh01Ol0003oglJoomo6_ooOa[oo000000?ogLK20_l00003
omFn``06o`000?oA_<KodKc6o`000?o<]<Co00000_o7//H01_l0003o`J_3ol6[`ol0003o_:S5o`00
00Co]j7200Ko0000ok:K`Ol0003o0000ojjI`Ol00004ojZD_`03o`000?nWTKkoYi6n00;oYi6n00?o
0000oj>>__nSS[h00ol00004oj2;_@05o`000?nNR[koWXZnoij:__l000000onMR[l01Ol0003oVh_1
oi^;`OnKRl7o000000;oVXc31Ol00002oinGb`03o`000?nPV/koX9[>00;oX9[>00Go0000oj2Nd_nP
W];oX9kBo`000002oj6Se`?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[1?l000000onW
`>_o0000ojO0j`03ojO0j`?o00000onW`>/00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo000Wooooo`Co0000;Oooool00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/01?l0003o
Yl3[ojO0jonW`>/3o`0000CoYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[
00Ko000000Co02Zco`000?l0003o03>h0_l00002ob]AaP04o`000?m8I<co0000o`0000;oI7C>00Go
0000ogj4comnQ<ooOXC?o`000004oiBBcP04o`000?nWWLcoYig<ojNMc0;o00001?niZLT00ol0003o
a:o5o`000004olNba@03o`000?o@]l;o000000God[W100Go0000om^n_OoK_[gofkjmo`000004omg1
_@;o000000?oh/Bjo`000?oSa[X00ooSa[X00ol0003oiLNjonG7^P02o`000003onK8^?l0003oilVi
00;oilVi00So0000onO;^_oWbk[o0000onO=^ol0003oi/Vjo`0000;oiLZl00Co0000onC;__oTbkko
i<^n0_l000000ooOa[oo0000omg6`P02omg6`P06o`000?oJaLGof/G5o`000?oE_/?o00001?oA_<H0
1ol0003oak;6olNba_o7//Ko0000ol6[`ol000000onlZ<D01?l0003o]j72okNQ`_ngXL82o`0000Co
[YW100Go0000ojZD_onZU;ooZYBoo`000003ojNA_PCo00000_nRSKd00ol0003oX8^moj2;_@02oj2;
_@05o`000?nNR[koWXZnoij:__l000001?nMR[l00ol0003oVh_1o`000003o`0000;oX9C800?o0000
oinGbonOUl/00onOUl/01Ol0003oX9[>oj2Jc_nPV/ko000000;oX9kB1?l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/2o`0000;oYl3[0ol00005ojO0j`Co000000?oYl3[o`000?nW`>/00onW
`>/2o`0000Oooooo00?o0000ooooooooool01_ooool002Oooooo0_l0000`ooooo`04o`000?nW`>_o
0000o`0000;oYl3[00?o0000ojO0jonW`>/00_nW`>/00ol0003oYl3[o`000002ojO0j`03o`000?nW
`>_oYl3[00;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/2o`000004o`0W/Ol0
003o0000o`0b]`Co00000_l[DLH00ol0003oB6C<odQTc003o`0000?oOXC?00?o0000oiBBc_nDT/h0
0_nDT/h01_l0003oYig<o`000?l0003oZj3<o`0000Go^JW900?o0000olNbaOo7//D01?o7//D00ol0
003od[W1om:i`@03om:i`@05o`000?oE_<7o0000om^n_Ol000001?oM`Kd01?l0003ogl>momo3_Ol0
0004on?6^P04o`000?oUak[oiLNjo`0000;oi/Vj0_l00002onO9^@05o`000?oWbk[oil^jonO;^_l0
00000_oWcK/01?l0003oiLZlonG:_?l00003onC;_P04o`000?oSc<3ohlc0o`0000CogLK200Go0000
om[5aOoJaLGof/G5o`000004om6laP;o00001?o7//H00ol0003o_:S5okbXa@02okbXa@06o`000?ng
XL;o0000o`000?nbW/Co00001?n^VL401?l0003oZYBoojZD_onZU;l4o`0000;oYHnn00?o0000oj:=
_OnRSKd00_nRSKd01Ol0003oX8^moj2;_OnPRkgo000000CoWXZn00?o0000oif:_ol000000ol00002
oj2CaP03o`000?nPU<SoX9C800;oX9C800?o0000oinGbonOUl/00_nOUl/01?l0003oX9[>oj2Jc_nP
V/h3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[1?l000000onW`>_o0000ooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Yooooo`03o`000?oooooooooo02kooooo0_l00004ojO0j`03o`000?nW`>_o
Yl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`00
0?nW`>_oYl3[00Go000000Go02Rbo`000?l0<[Oo0000o`m1_`02o`000006ob]Aa_l0003oB6C<odQT
c?l0003oIWO@0_l00002ogj4c`04o`000?nDT/koU9;>oiBBcP?o00001?n[X<`01?l0003o^JW9okVY
bOniZLT2o`0000Koak;500?o0000om:i`OoB^L400_oB^L401Ol0003oeKc1omFl`OoE_<7o000000Co
gL6m00Co0000omo3_OoO`kgogl>m0_l00002on?6^P05o`000?oUak[oiLNjonG7^_l000000_oVbKX0
1Ol0003oilbko`000?oWbKWo000000;oil^j00Co0000onO=^ooWcK_oilfk0_l000001OoUb[co0000
onC;__oTbkko000000?ohlc00_l00002omg6`P03o`000?oJaLGof/G500;of/G500Go0000om6la_oA
_<KodKc6o`000002olfkb@03o`000?o7//Koak;600;o00001OnlZ<D00ol0003o/Yk4ok:Na002ok:N
a006o`000?n^VL7o[YW1ojjI`Ol0003oZYBo0_l000000onWT[oo0000ojF?_P04ojF?_P05o`000?nR
SKgoXXfmoj:=_Ol000001?nPRkd00ol0003oWXZno`000003o`0000;oXI;500?o0000oj2Ca_nPTlH0
0_nPTlH01Ol0003oX9C8oj2Db?nPU<So000000CoWiO;00Ko0000oj2Jc_l0003o0000ojO0jol00004
ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`000004ojO0jol0003oYl3[o`0000;oYl3[1?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo000Zooooo`03o`000?oooooooooo02oooooo00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00002oj:nk@;o000000Go02F`o`000?l0:;;o0000o`0b]`02o`000003obYBaol0003o000000?o
B6C<00?o0000ofIgd?l000001_l00002oiREc`03o`000?n[X<coZj3<00;oZj3<00Co0000okVYbOni
ZLWo00000_nm[<T00ol0003oak;5olNba@02olNba@03o`000?o;]LGo000000?od[W100Co0000omFl
`OoE_<7oeKc10_l00003omg1_@04o`000?oO`kgogl>mo`0000;ohLFm00?o0000on?6^_l000000_oU
akX01?l0003oi/VjonK9^_l00003onO<^`04o`000?oWbk[oil^jo`0000?oilfk00Co0000onO>_OoW
c[go00000ooTbkh01?l0003ohlc0on?<`?l00002on7=a003o`000?oMa/;o000000?of/G500Go0000
omO5b?l0003odKc6o`000003olfkb@03o`000?o7//Ko000000;o`[3800Co0000okbXaOnlZ<Go_:S5
0_l00004ok:Na004o`000?n^VL7o[YW1ojjI`@;o00001?nWT[l00ol0003oYHnnojF?_P02ojF?_P05
o`000?nRSKgoXXfmoj:=_Ol000000onPRkd3o`0000;oXI7400?o0000oj6BaOnQT/D00_nQT/D01Ol0
003oX9?6oj2Ca_nPTlKo000000?oX9C800Co0000oinGbonOUl_oWiO;0ol00004ojO0j`06o`000?nW
`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000Oooooo00?o0000oooooooo
ool01Oooool002_ooooo00?o0000ooooooooool0;oooool2o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/01?l0003oYl3[o`000?l00002ojO0j`04
o`000?nR_^goX[k]oj:nk@;o000000?o02F`o`000?l0:;801?l00002obYBa`;o000000CoB6C<o`00
0?mVMm3o00000on1R=400ol0003oV9G?oiREc`03oiREc`07o`000?n[X<coZj3<oj^Pc?l0003o^JW9
o`000004okf/b@04o`000?o7//Goak;5o`0000?obkG500?o0000om:i`Ol000000ooE_<401_l0003o
f;k1omRn`Ol0003ogL6mo`0000?ogl>m00Go0000on75_OoQaKgohLFmo`000002onG7^P05o`000?oV
bK[oi/VjonK9^_l000000ooWc;/2o`000005onO;^_l0003oilfkonO=^ol000000ooWc[d2o`000005
onC;__l0003ohlc0on?<`?l000001?oQcL@01Ol0003of/G5om[5aOoJaLGo000000?oelG800?o0000
olfkbOo=^lT00_o=^lT2o`0000Co`[3800?o0000okbXaOl000000_ngYLL01_l0003o/Yk4ok:Na?nb
W/Co0000ojjI`@;o000000?oZYK2o`000?nWT[l00onWT[l00ol0003oYHnnojF?_P02ojF?_P03o`00
0?nRSKgoXXfm00;oXXfm0ol000000onRT/?o0000oj6Aa003oj6Aa005o`000?nQT/GoXI;5oj6BaOl0
00000onPTlH00ol0003oX9C8oj2Db005o`0000;oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0
j`Co000000?oYl3[o`000?nW`>/00onW`>/3o`000003ojO0jol0003o000000?oYl3[1?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo000/ooooo`;o0000<Oooool00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01ol0003oX[k]oj:nkOl0003o02Zc
o`000?l09K000_l000001ol0<[Oo0000o`000?l0003o:U;7o`000?m9I/h00_l00002ofIgd005o`00
0?n1R=7oPHSAoh68dOl000001?nHULl01?l0003oZj3<oj^Pc?n[X<`2o`0000Go_Jc900?o0000olNb
aOl000001?o;]LD2o`0000?oeKc100?o0000omRn`OoH_/400_oH_/401Ol0003ogl>momo3_OoO`kgo
000000CohLFm0_l000001OoUak[o0000onK9^_oVbK[o000000?oilbk00Co0000onS>_?oXc[co0000
0ooWcK/01?l0003oiljmonO>_Ol00002onO@_`05o`000?oSc<3ohlc0on?<`?l000001?oQcL@2o`00
0003om[5aOl0003oelG800?oelG800Oo0000olfkbOo=^lWocK_9o`000?o7^Lco000000Co`[380_l0
0004okNUa`03o`000?nbW/Co/Yk400;o00001?nZU/800ol0003oYi:oojNB_`02ojNB_`03o`000?nU
SkkoYHnn00;oYHnn00?o0000oj:=_Ol000000_l00004oj:B``05o`000?nQTLCoXI74oj6Aa?l00000
0onQT/D00ol0003oX9?6oj2CaP04o`0000?oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`00
0?nW`>_oYl3[00?o00001OnW`>/4o`000003ojO0jol0003oYl3[00;oYl3[1?l00002ojO0j`03o`00
0?nW`>_oYl3[00;oYl3[0ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`?o00001Oooool00ol0003o
ooooooooo`05ooooo`00;_ooool00ol0003oooooooooo`0_ooooo`;o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Go0000
0_l0:[<2o`000005o`0X/_l0003o0000o`a0_ol000000_lZD/L00ol0003oBFK>odUVcP02o`000003
ofIgd?l0003oPHSA00;oPHSA00Ko0000oiREconHULooV9G?o`000?n[X<`2o`000003ojjTcOl0003o
_Jc900Co_Jc90_l00004ol^ea@03o`000?o>^<Go000000?oeKc100?o0000omRn`OoH_/400_oH_/40
1?l0003ogl>momo3_Ol00004on75_@04o`000?oSb;gohlRmo`0000;oi/Vj00Go0000onO<^ooWc;_o
ilbko`000003onS>_0;o000000Goilfko`000?oWc[goiljmo`000003onO@_`;o000000?ohlc0o`00
0?oQcL@00ooQcL@01?l0003oglk7omo>aol00004omO5b005o`000?oCaLgo0000olfkbOl000000oo7
^L`01_l0003o`[38ol:`b?l0003o_:g;o`0000Co]jG700Go0000ok:Na?l0003o[I_5o`000004ojZF
`P03o`000?nWT[ooYi:o00;oYi:o00?o0000ojF?__nUSkh01?l00002oj>Ca003o`000?nRT/?oXY;3
00;oXY;300Go0000oj6Aa?nQTLCoXI74o`000002oj6Ba@Co00000onW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001OnW`>/5
o`0000GoYl3[1?l000000onW`>_o0000ojO0j`02ojO0j`Co00000_nW`>/00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo000_ooooo`03o`000?oooooooooo02kooooo00?o0000ojO0
jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000onW`>/00ol0003o>8k_o`000002o`000004o`0U/?l0003o0000o`0000;o342o0_l00000
1OlZD/Oo0000odUVc_l0003oJ7[B00;o00000on1R=400ol0003oV9G?oiREc`03o`0000Co[ZC=00Oo
0000okf/bOnm[<Wo_Jc9o`000?o0/<Wo000000?obkG500Oo0000oljhaOo>^<Goc[S5o`000?oE_<7o
000000Cof;k100Go0000om_2`Ol0003ogl>mo`000003on75_@04o`000?oSb;gohlRmon?8_@;o0000
00Goi/Vjo`000?oWc;_oilbko`000003onS>_004o`000?oXd;koj=2no`0000?oiljm00Co0000onO@
_ooWd;oo00000_oVd/<2o`0000?ohLg400Go0000omo>aooOc/Ooglk7o`000003omO5b005o`000?oC
aLgodlG=om?5cOl000001?o7^L`00ol0003o`[38o`000003okb]b`04o`000?ngYLOo]jG7okNUa`;o
00000on]VlD00ol0003oZYK2ojZF`P02ojZF`P04o`000?nWT[ooYi:oojNB_`?o00000_nTU<D00ol0
003oXi?4oj>Ca002oj>Ca005o`000?nRT/?oXY;3oj:B`ol000000onQTL@3o`0000;oYl3[00?o0000
ojO0jonW`>/00_nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[0_l00002ojO0j`?o00001OnW`>/3
o`000003ojO0jol0003oYl3[00?oYl3[0_l00004ooooo`03o`000?oooooooooo00Gooooo000`oooo
o`03o`000?oooooooooo02kooooo00Co0000ojO0jol0003o00000_nW`>/01?l0003oYl3[ojO0jonW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co000000?o
02Vco`000?l000000_l000001Ol0<KOo0000o`000?l0003o:5?800;o00000_m9I/h00ol0003oJ7[B
ofQjdP06o`0000;oW9WA00?o0000ojjTcOn^Y<d00on^Y<d00ol0003o_Jc9o`000003ol2`b@03o`00
0?o;]LGo000000Goc[S500?o0000omRn`OoH_/400_oH_/401Ol0003ofl;1om_2`OoK`/7o000000?o
hLFm00Go0000on?8_OoSb;gohlRmo`000002onC;_P05o`000?oWc;_oilbkonO<^ol000000ooXc[`0
0ol0003oj=2nonS@_P02o`000005onO>_Ol0003oim2oonO@_ol000000ooVd/<01Ol0003oiMG6o`00
0?oQcLCo000000?oglk700Go0000omc?c?l0003oelG8o`000003om?5c@;o00001?o7^L`2o`0000Co
_:g;00Ko0000okNUaol0003o0000ok6RbOl00004ojfKa@06o`000?nZU/;oZYK2ojZF`_l0003oYi:o
0_l000000onVUlKo0000ojBDa@03ojBDa@05o`000?nSTlCoXi?4oj>Ca?l000001?nRT/<3o`000003
ojO0jol0003oYl3[00?oYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0
jol00005ooooo`03o`000?oooooooooo00Cooooo000aooooo`03o`000?oooooooooo02kooooo0_l0
0004ojO0j`03o`000?nW`>_o000000;oYl3[00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`03o`00
0?nW`>_oYl3[00?o00000_nW`>/01?l0003o0474o`000?l0:K<2o`000004o`0W/Ol0003o0000o`M0
`0;o00000_lXDlP3o`0000;oJ7[B00Go0000ohB<don4S=?oQ8cCo`000004oibId@03o`000?n^Y<go
[ZC=00;o[ZC=0_l00005ol2`b@03o`000?o>^<Goc[S500Coc[S500Go0000omRn`OoH_/7of;k1o`00
0004om_2`@05o`000?oQaKgohLFmon75_Ol000000ooSb;d00ol0003oi<^nonC;_P02o`000003onO<
^ol0003oj<jl00;oj<jl00Co0000onS@__oXd;ko00000_oYdl001Ol0003oim2oonO@_ooWd;oo0000
00;oi];300Go0000onGEa_oUeLKoiMG6o`000003omo>a`05o`000?oLclcog<o<omc?c?l000000ooC
aLd01?l0003ocLCAolg4dOl00002olNic003o`000?o1]m3o000000Co_:g;0_l00004ok6Rb@05o`00
0?n]VlGo[I_5ojfKaOl000000_nZU/83o`0000CoYYO600Go0000ojBDaOnTU<GoY9C5o`000003oj>C
a003o`000?nRT/?oXY;300?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0
jol0003o0000ojO0jol00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/01?l000001?nW`>_o0000ojO0jol00002ojO0j`Co00000onW`>/00ol0003oYl3[
ojO0j`03o`0000CoYl3[00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`00<_oo
ool2o`00033ooooo00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_o000000;oYl3[00?o
0000ojO0jonW`>/00_nW`>/3o`0000;oYl3[00So0000ojO0jonW`>_oYl3[o`000?l0@LCo0000o`0Y
/`Go000000Oo1d30o`000?lXDlSo:5?8o`000?m9JM3o000000?oJ7[B00Go0000ohB<don4S=?oQ8cC
o`000003oibId@03o`000?n^Y<go000000;o000000?o/ZS>o`000?o0/<T00oo0/<T2o`0000Goc[S5
00Go0000om6laOl0003of;k1o`000004om_2`@05o`000?oMaL7o0000on75_Ol000000ooSb;d01?l0
003oi<^nonC;__l00002onK>_`;o00000_oXc[`01Ol0003oj=2nonS@__oXd;ko000000;ojM?00_l0
00001OoWd;oo0000onKB`ooVd/?o000000CoiMG60_l000000ooOc/Oo0000omc?c002omc?c005o`00
0?oHd=7o0000om?5cOl000000oo=a=400ol0003oakW<o`000003ol6gd006o`000?nl[L_o0000o`00
0?neZ/ko00001?naX/T01?l0003o[I_5ojfKaOn]VlD3o`0000;oZ9_800?o0000ojJGa_nVUlH00_nV
UlH01Ol0003oY9C5ojBDaOnTU<Go000000;oXi?41?l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0
j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?ooooo00?o0000oooo
ooooool01?ooool003Cooooo00?o0000ooooooooool0;_ooool2o`0000?oYl3[00?o0000ojO0jonW
`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/01_l0003oYl3[ojO0jonW
`>_o0000o`11a0Oo000000Ko1d30o`000?l0003o:5?8o`000?m9JM04o`0000?oQ8cC00?o0000oibI
dOnLVM400ol00005ok:XcP04o`000?o0/<Wo`;39o`0000;oa;?:00Go0000oljhaOo>^<Goc[S5o`00
0003om6la@03o`000?oK`/7ofl;100;ofl;100Co0000omg5`OoMaL7ogLG10_l00002on?8_@05o`00
0?oTbkkoi<^nonC;__l000000_oVc[l01Ol0003oim70o`000?oXc[co000000;oj=2n00Co0000onWC
`?oYdl3o00000_oYe/83o`000003onKB`ol0003oiMG600;oiMG600Co0000on?GbooSel_o00000ooL
cl`01Ol0003of=3AomS@dOoHd=7o000000CocLCA0_l00004ol6gd0;o00001?neZ/h01_l0003o/J;9
ok6RbOnaX/Wo0000ojfKa@;o000000?oZYo<o`000?nXVlP00onXVlP01Ol0003oYYO6ojJGa_nVUlKo
000000;oY9C51?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`06o`000?nW`>_o0000o`000?nW`>_o0000
1?nW`>/3o`0000;oYl3[00Co0000ojO0jonW`>_oYl3[1?l000000onW`>_o0000o`000003ojO0j`Co
00000_nW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oYl3[00Go0000ooooooooooooooooo`000006
ooooo`00=Oooool00ol0003oooooooooo`0^ooooo`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`03o`0000CoYl3[00?o0000ojO0jonW`>/03_l000000ol7@<3o0000obEEb`02o`00
0004odUYd?l0003oJWkDofYne0Oo00000_nPW]800ol0003o/ZS>ok:XcP03ok:XcP03o`000?o0/<Wo
000000Coa;?:00?o0000oljhaOl000001?oA_<D2o`0000?ofl;100Wo0000omg5`OoMaL7ogLG1o`00
0?oOb<;o0000on?8_Ol000000_oTbkh01?l0003oi/joonK>_ol00003onOA`004o`000?oXd;koj=2n
o`0000;ojM?000Go0000onWF`_oYe/;ojMK2o`000002onSJaP05o`000?oUeLKoiMG6onGEa_l00000
0_oSel/01Ol0003oh=[@o`000?oLclco000000?of=3A00Co0000om?Aeol0003ocLCA0_l000000oo6
`mOo0000ol6gd002ol6gd003o`000?ni]=Co000000Co]J[>00?o0000ok6RbOnaX/T00ol00004ojZO
c005o`000?nXVlSoZ9_8ojRKb?l000000onVUlH3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`04o`000?nW`>_oYl3[ojO0j`Co00000_nW`>/01?l0003oYl3[ojO0jonW`>/4o`0000;oYl3[
00Co0000ojO0jonW`>_oYl3[0ol00004ojO0j`Co000000?oYl3[o`000?nW`>/00_nW`>/4o`0000;o
Yl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`000?nW`>_oYl3[00Go00000_nW`>/00ol0003o
Yl3[ojO0j`03o`0000;ooooo00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool0
;_ooool2o`0000CoYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oKj_fofn[mP05o`000003o`0U/?l0003o032g00?o000000Go9EG;o`000?m9JM3o
BFW@o`000002ofYne005o`000?n7T=GoQi3EohN@eOl000001?nPW]800ol0003o/ZS>ok:XcP02ok:X
cP;o00001Oo4/lX2o`0000CodKc500Ko0000omC0a_oD`<Ko0000om_2`Ol00003omg5`@05o`000?oO
b<;oglS2omo8`_l000000_oTbkh01Ol0003oi/joonK>_ooVc[oo000000?oim700_l000001OoXd;ko
0000onWC`?oYdl3o000000;ojMK200Co0000onSJa_oXf/Koj=[60_l000001OoUeLKo0000on?GbooS
el_o000000?oh=[@00Go0000omS@dOoHd=7of=3Ao`000002om?Ae`;o00001?o6`mL00ol0003o`KO@
o`000003okVde004o`000?neZ/ko]J[>okFZcP?o00000_n/YM000ol0003oZYo<ojZOc002ojZOc006
o`000?nXVlSoZ9_8ojRKb?l0003oYYO60_l000000onW`>_o0000ojO0j`03ojO0j`?o00000_nW`>/0
0ol0003oYl3[ojO0j`05o`0000;oYl3[00?o0000ojO0jonW`>/01Ol00002ojO0j`03o`000?nW`>_o
Yl3[00Go00000_nW`>/00ol0003oYl3[ojO0j`03o`0000GoYl3[0ol000000onW`>_o0000ojO0j`03
ojO0j`?o000000CoYl3[o`000?nW`>_o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?oooooo000000Kooooo000gooooo`;o0000<?ooool00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_oYl3[00Ko000000Co02Vc
o`000?l0003o02F`0_l000001?l2@L;o0000o`000?lUEL/2o`000005odUYd?l0003oJWkDofYne?l0
00000on7T=D00ol0003oX9kBoj2NdP02oj2NdP06o`000?nbZ<ko0000o`000?nf[Loo00001?o4/lX0
0ol0003ob;S;o`000003om6la@03o`000?oD`<Koe<3600;oe<3600Go0000omg5`OoMaL7ogLG1o`00
0004omo8`P;o000000Goi<^no`000?oVc[ooi/joo`000003onOA`003o`000?oXeL;oj=G200;o0000
00GojM?0o`000?oYe/;ojMK2o`000003onSJaP03o`000?oWgLWoimg900;o000000?ohmO;o`000?oP
f]000_oPf]001Ol0003og=cFo`000?oHd=7o000000;odm7G00?o0000ol_Ag_l000001?o6`mL2o`00
00Co^KCD00Ko0000okFZc_l0003o0000ojj/eOl00004ojbUd005o`000?nZWlcoZYo<ojZOc?l00000
0_nXVlP3o`0000CoYl3[1?l000000onW`>_o0000ojO0j`02ojO0j`?o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00003ojO0
j`Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00006oooo
o`00>Oooool00ol0003oooooooooo`0^ooooo`;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?o
Yl3[00?o0000ojO0jonW`>/01?l00003ojO0j`[o000000Go0T72o`000?lUEL_o0000odU]d`02o`00
00?oJWkD00Go0000ohN@eOn7T=GoQi3Eo`000003oj2NdP;o00001?nf[Ll01?l0003oa;?:olBcb_l0
0003olRhb`03o`000?oA_<Go000000Goe<3600Go0000omg5`OoMaL7ogLG1o`000003omo8`P04o`00
0?oRc<?oh/c3o`0000;oi/jo00?o0000onOA`?oWdL000_oWdL001_l0003oj=G2onSE`_l0003ojMW4
o`0000?ojMK200Co0000onSJa_oXf/Ko00000ooWgLT00ol0003oi^7>o`000003on3Jd003o`000?oL
g=Kog=cF00?o000000?odm7Go`000?o;dMh00_o;dMh01_l0003oa/?Go`000?l0003o_/7Lo`0000Co
^KCD0_l00004ojj/e@05o`000?n/YM3o[:G@ojbUd?l000000_nZWl`4o`0000;oYl3[00?o0000ojO0
jonW`>/00ol00005ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`03o`000?nW`>_o000000?o00001?nW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?oooooo000000Gooooo000jooooo`03
o`000?oooooooooo02kooooo00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/00ol0003oYl3[ojO0j`05o`000003o`0Z]?l0003o000000?o00000_l2@L800ol0003o
9EG;o`000002odU]d`Co00000on7T=D01_l0003oX9kBo`000?l0003oY:?Do`0000Co]Zg?00?o0000
olBcb_l000001Oo8^</00ol0003oe<36omC0aP03omC0aP05o`000?oGa<Oo0000omg5`Ol000000ooO
b<801?l0003oh/c3on;<`ooRc<<2o`000003onK>_ol0003oim7000;oim7000Co0000onSE`_oXeL;o
00000_oYfL@2o`000003onWF`_l0003oj=[600;oj=[600Co0000onOMbOoWgLWo00000_oVhLh2o`00
0005on3Jd?l0003og=cFomcLe_l000000_oGgmd2o`0000Cobm7N0_l00004okk1g006o`000?ni]=Co
0000o`000?na]=_o00001?n^[=D00ol0003o[:G@ojbUd004o`0000;oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/2o`00
0005ojO0jol0003o0000ojO0jol000001?nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01?l00005
ooooo`00>oooool00ol0003oooooooooo`0^ooooo`;o00001?nW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002oiJkl@Co000000Go02Zdo`000?l0003o0000o`0_]`05
o`0000;oBFgC00?o0000ofb3f?m/PmP01_l00004ojBSe004o`000?nf[Loo]Zg?okJ]c`;o00001Oo8
^</00ol0003obkg<o`000003omC0aP04o`000?oGa<OoelC7omO4a`;o00000ooOb<801?l0003oh/c3
on;<`ol00002onC@a0;o00000_oWdL001?l0003oj=G2onSE`_l00002onWIa003o`000?oYgLOojMg7
00?o000000Goj=[6o`000?oWgLWoimg9o`000002onKQcP03o`000?oSi]CohnKD00;o000000Gog=cF
o`000?oGgmgoemoMo`000002olkQiP04o`000?o;dMko0000o`0000;o`M3U00?o0000okk1g?nn`M`0
0ol00004ok6df`03o`000?n^[=Go[ZcE00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW`>_oYl3[
ojO0j`?o00001?nW`>/4o`000003ojO0jol0003oYl3[00;oYl3[0ol00003ooooo`03o`000?oooooo
oooo00?ooooo000looooo`;o0000;oooool00ol0003oYl3[ojO0j`02ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`03o`0000?oYl3[00Co0000oiJklOnF^o7oU[_a0_l000000ol0>koo0000o`0Z]004
o`000004o`11`ol0003o0000o`0000?oBFgC00Co0000ofb3f?m/PmSo00000on;UMP00ol0003oY:?D
ojBSe002ojBSe004o`000?nf[Loo0000o`0000;o^[;A00Go0000olRhboo8^<_ob;S;o`000003ol^m
c003o`000?oD`<Ko000000CoelC700Go0000om[8b?l0003oglS2o`000002on;<``09o`000?oTd<Co
i=34onC@a?l0003oiMG5o`000?oWdL3o000000;oj=G200?o0000onWIa?l000000ooYgLL00ol0003o
jN;:onWRbP02o`000005onOMbOl0003oi^7>onKQc_l000000_oSi]@00ol0003og^[Ko`000002o`00
0003omOOgOl0003oc^7V00;oc^7V0_l00004ol7@i@?o00000onc_n<00ol0003o/KCKok6df`04o`00
00;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004ojO0j`06o`000?nW`>_o0000
o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW
`>_oYl3[ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`05o`000003ojO0jol0003o000000;oYl3[
0ol00005ojO0j`?o00001_ooool00ol0003oooooooooo`03ooooo`00?_ooool00ol0003ooooooooo
o`0]ooooo`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW
`>/01Ol000000ol6DLko0000o`000004o`000005o`0^]ol0003o0473o`000?lRElh01?l00003ofb3
f005o`000?n;UMSoRiGHoh^Ef?l000000onTXm@2o`0000Go^[;A00?o0000olRhbol000001?o;_L`2
o`0000CoelC700Go0000om[8b?oJb<Sof/S8o`000003on;<``04o`000?oTd<Coi=34o`0000?oiMG5
0_l000001OoXeL;o0000onWIa?oYfLCo000000;ojMg700Ko0000onWRb_oYh/[ojN;:o`000?oXilh2
o`000007onKQc_l0003ohnKDon?Ve?l0003og^[Ko`000002omO^h`?o000000?oc^7Vo`000?l00000
0_o2hNh01_l0003o`M3Uo`000?l0003o]<_/o`0000Co/koS0ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000ojO0
jol0003o0000ojO0jol00004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`05o`0000;oYl3[00?o
0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`03o`0000Sooooo00?o0000ooooooooool00oooool003oooooo00?o0000ooooooooool0;Oooool0
0ol0003oYl3[ojO0j`02ojO0j`06o`000?nW`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[
2_l000000ol0;[Oo0000o`11``02o`0000;oB77G1Ol00003oh^Ef006o`000?nTXmCo0000o`000?nX
ZMOo00001Onj/]42o`0000Cobkg<00?o0000olo2c_l000000ooGa<L02Ol0003of/S8om[8b?oJb<So
0000omg=bOl0003oh/c3o`000002onC@a005o`000?oUeLGoiMG5onGEaOl000000_oWf/L2o`000005
onWIa?l0003ojMg7onWMaol000000ooYh/X01Ol0003oj>O>onSWc_l0003oi^cC00;o000000CohnKD
o`000?oNj]_o00000_oGk^<00ol0003oc?3[olc`j`02o`0000Co`^7^0_l00004okC;k006o`000?nc
_n?o0000o`000?nW`>_o00001?nW`>/3o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03
o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/4o`000003ojO0jol0003oYl3[00;o
Yl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;o
Yl3[0_l00002ojO0j`Co00002oooool00ol0003oooooooooo`03ooooo`00@?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`00
00CoYl3[0ol000000ol7Em;o0000o`000004o`0000;o02jg0_l000001OlNF]7o0000odQaeom8LMOo
000000;oKXSL1_l00004ojRYe`07o`000?nj/]7o^[;AokZbdOl0003o_[SCo`000003ol^mc007o`00
0?o?`/kocl;>olo2c_l0003oelC7o`000003om[8b005o`000?oMcLWogLg9omg=bOl000000ooTd<@0
1?l0003oiMG5onGEaOl00003onOJa`06o`000?oXgl[o0000o`000?oYgLOo00000ooYh/X01ol0003o
j>O>onSWc_l0003oi^cCo`000?oRlMP01Ol000001OoGk^?o0000olc`joo<l>_o000000;o_?3c00Co
0000ol;Qk_l0003o00000_nbfO@00ol0003o]<_/okC;k003o`0000CoYl3[00Ko0000ojO0jol0003o
0000ojO0jol00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00;oYl3[00?o0000ojO0jonW`>/00ol00005ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00003oooool00ol0
003oooooooooo`03ooooo`00@Oooool2o`0002kooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000onW`>/02?l0003oYl3[o`000?l0003oYl3[o`000?laM^;o00000_l7Em89o`000005oaiJdOl0
003oB77GodQaeol000000_m^R=`01Ol0003oSY_LohjKg?n>Vmco000000GoZ:WG00?o0000okZbdOl0
00000onn^=<00ol0003obkg<o`000005olo2cP05o`000?oJb<Sof/S8om[8b?l000001?oMcLT2o`00
0005onC@a?l0003oiMG5onGEaOl000000ooWf/L01Ol0003oj=o:onSOb_l0003oj>C=00?o000000Wo
jN;:o`000?oXilkoj>O>o`000?oVk=?o0000on;af?l000000_oKm]h00ol0003odO[To`000002o`00
0004olc`jol0003o_?3cokc`l`Co00000_nbfO@4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00004
ojO0j`?o000000?oYl3[o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00002ojO0j`04o`000?nW`>_oYl3[ojO0j`Co000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`0]ooooo`03o`00
0?nW`>_oYl3[00?o00001?nW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000oc5fh_l00000
1?l000000ol08jco0000o`000003o`0000;o7U[A1?l00002ofj8g005o`000?n>VmcoSY_LohjKg?l0
00001?nXZML2o`0000Co_[SC0_l00005olo2cP05o`000?oBb<oo0000om[8b?l000001?oMcLT00ol0
003oh=?;on3Cb`02o`000003onGEaOl0003oim[700;oim[700Co0000onSOb_oXgl[o00000_oXi<d0
0ol0003oj>[@onSZd002o`000006onSWc_l0003oi^cCo`000?oRlMSo00000_oKm]h00ol0003odO[T
o`000002ol7kj@Go00000_n]iOT4o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00;o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0
j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0
jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`00
00CoYl3[00Ko0000ojO0jol0003o0000ojO0jol00002ojO0j`Go00001_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo0014ooooo`03o`000?oooooooooo02gooooo0_l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`08o`000005o`0S[?l0003o
0000o`000?l0@/@00ol00002odMfg0Go00000on>Vm`01_l0003oZ:WGo`000?l0003o[:oJo`0000?o
_[SC00Co0000ol>ne_o3_]Ko00000oo?`/h01?l0003od/S?om;8cooBb<l2o`0000?ogLg900Ko0000
on3CbooPdl_oh=?;o`000?oRf<d2o`0000?oim[700?o0000onSOb_l000000_oXi<d01_l0003oj>[@
onSZd?oXj]3o0000onK`d`Ko000000GofoKNo`000?oAn^Co0000ol7kj@04o`000003oj3]nOl0003o
000000;o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[
0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`03o`0000?oYl3[0ol0000;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool004Gooooo00?o0000ooooooooool0;Oooool00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/01?l00002oh^gl`?o000000?o25kFo`000?l000001_l000000olIGMCo0000o`00
0002odMfg003o`000?m_Sn7oKhoQ00Ko00001?n/[mX00ol0003o_[SCo`000004ol>neP03o`000?o?
`/ko000000Cod/S?00Go0000omK>d_l0003ogLg9o`000003on3Cb`08o`000?oRf<goh]S=o`000?oT
gloo0000onOJaol00002onSObP03o`000?oXi<go000000?oj>[@00So0000onK`dol0003oh_KGo`00
0?oKnm[o0000om3ng@_o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000Co
Yl3[00Ko0000ojO0jol0003o0000ojO0jol00004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00Co0000ojO0jol0003o00003oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo0016ooooo`03o`000?oooooooooo02gooooo0_l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/01_l0003oRkOcoh^glon;]o?o0000oc9ih`?o0000
00?o03:eo`000?l000000_l000001?l0@lGo0000oaUMe?l00003odMfg004o`000?m_Sn7oKhoQo`00
00?oTZ;P00?o0000ojb_f_n/[mX00_n/[mX2o`0000Go`kkF0_l00004om;8c`05o`000?oFc];oe/kB
omK>d_l000000ooPdl/01?l0003oh]S=on;HcOl00003onCOc`;o000000Coj=o:o`000?oXi<go0000
0ooXj]002?l0003oi_3Co`000?oRm]Oo0000om_kf_l0003od?kM2?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Ko0000
ojO0jol0003o0000ojO0jol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`03o`0001;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00Aooo
ool2o`0002oooooo00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00So000000Co
36OKo`000?l0003o03:e1?l000000ol0@lGo0000oaUMe004o`0000?oKhoQ00Ko0000oi:Rh?nBX^3o
TZ;Po`000?n/[mX2o`0000;o/;ON00Oo0000ol>ne_o3_]Ko`kkFo`000?o6aMWo000000?od/S?00?o
0000omK>d_oFc]800_oFc]82o`000005on3Cbol0003oh]S=on;HcOl000001?oTgll00ol0003oiNGA
o`000004o`000009onSZd?l0003oi_3Co`000?oRm]Oo0000om_kf_l0003od?kM00Ko000000?oYl3[
o`000?nW`>/00onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o
Yl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l0000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
04Wooooo00?o0000ooooooooool0;Oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0
j`07o`000?mYYOCoJJGdo`000?lhP^So0000o`aWf`0;o`000003odEkhOl0003o000000?o00000_nB
X^03o`0000Go/;ON00?o0000ol>ne_l000000oo6aMT00ol0003od/S?o`000004omK>dP04o`000?oI
eMCofMGDo`0000?oh]S=00Oo0000onCOcooTglooi=o?o`000?oUiM7o000000;oiNcD00?o0000on?c
eol000003_l00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/01_l0003oYl3[o`000?l0
003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0000Jooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool004[ooooo00?o0000ooooooooool0;Oooool00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/01Ol000000olhP^So0000o`000004o`000005o`0TZ?l0
003o0000o`000?lBHML00_l000001?m5Nn7o0000og2Fiom`U^L3o`0000;oUJ[U00?o0000ok2gg_n`
]mh00on`]mh2o`0000Coa/GI0ol00003omK>dP08o`000?oIeMCofMGDo`000?oLg=Oo0000on;HcOl0
0003onCOc`03o`000?oUiM7o000000;oiNcD00?o0000on?ceol000000_oOnMT00ol0003oeogIo`00
0007o`0000?oYl3[00?o0000ojO0jonW`>/00_l00004ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00_l00004ojO0j`06o`000?nW
`>_o0000o`000?nW`>_o00001?nW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00007oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo001;ooooo`03o`000?oooooooooo02gooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co0000
0_nT_nd00ol0003oGYK]o`000003o`000003oa5ah?l0003o000000;o000000Co02BXo`000?l0003o
00000_lBHML3o`0000;oL9KW00?o0000oiFZiOnEZ^D00_nEZ^D00ol0003o/;ONo`000002o`000003
okBoh_l0003oa/GI00;oa/GI00Oo0000ol[=g?o:cMcob/gLo`000?oFc];o000000;ofMGD00Co0000
omcLeooLg=Oog=cG0ol000001?oTgloo0000onGUdOl00002onG/e003o`000?oSlmOo000000;ogoWI
00?o0000omOmfOl000001?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/01_l0003oYl3[
o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00Co0000ojO0jol0003o00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0000Tooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00Oooool004cooooo0_l0000^ooooo`03o`000?nW`>_oYl3[
00Co00000onW`>/01Ol0003oY;o]ojBokOnT_ngo000000;oGYK]00?o0000od2=kOl000002ol00002
od:2iPCo00000_nEZ^D3o`0000Go];oR00?o0000olK5fOl000001?o:cM`3o`000003omWEe?l0003o
g=cG00;og=cG00Co0000omgTfOoMi=WogNCI1?l000001?oUk=Co0000on?ceol00002omoif@03o`00
0?oGoMWo000000?o000000CoYl3[o`000?nW`>_oYl3[1?l00003ojO0j`03o`000?nW`>_oYl3[00;o
00001?nW`>/01_l0003oYl3[o`000?l0003oYl3[o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_o
Yl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[0ol00002
ojO0j`03o`000?nW`>_oYl3[00Co0000:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo007ooooo001>ooooo`03o`000?oooooooooo02cooooo0_l00003ojO0j`03o`000?nW`>_oYl3[
01?o000000Co04K3o`000?l0003o00000_m2P^H00ol0003oLIo]o`000002o`0000?oV;?[00?o0000
okBoh_nd_n800_nd_n82o`0000?ob/gL0_l00003olkEg`05o`000?oLg=Oog=cGomcLeol000000ooM
i=T00ol0003og^cLo`000002omccgP[o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`03o`000?nW`>_oYl3[00?o00001?nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`00
0?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00Ko0000ojO0jol0003o0000ojO0jol00003ojO0j`?o0000;Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo007ooooo001?ooooo`03o`000?oooooooooo02gooooo00?o0000ojO0jonW
`>/00ol00003ojO0j`05o`000?nB^_;oT[[boi:jl_l000000_mVWo400ol0003oBYSbo`000007o`00
0003o`16`ol0003o2VCJ00Co00000_maWnd00ol0003oV;?[oiRcj`02oiRcj`04o`000?nd_n;o0000
o`0000;o^<SW00?o0000ol[=g?l000001?o>eMl01Ol0003od=kSo`000?oLg=Oo000000?ogNCI00?o
0000omk/g?l000000_oLlmh2o`0000;ocokM00?o0000ol7nf?l000001_l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
0004ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o
0000ojO0jonW`>/00ol00004ojO0j`?o0000<Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo001@ooooo`03o`000?oooooooooo02gooooo0_l00003ojO0j`03o`000?nW`>_o
Yl3[00co000000?o9H[/o`000?l000001_l00002ocf9k0Go00000_nH/n/3o`0000Co^<SW0ol00003
olkEg`03o`000?o@g^?od=kS00Co000000CogNCIo`000?oNk=co00000_oLlmh2o`0000;ocokM00?o
0000ol7nf?l000000ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`06o`000?nW`>_o0000o`000?nW`>_o
00000onW`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00?o0000=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo001Aooooo`;o0000;_ooool00ol0003oYl3[ojO0j`04o`0000?oYl3[00Co0000ohNbl_n7/_;o
00000om_Z?@<o`0000;o?HW/00?o0000og2Xm?m`Z?@00ol00003oiZml@04o`000?nhb>Oo0000o`00
00?o^];/00?o0000olkEgol000000_o@g^<01?l0003odNSVom7Xi_oAj>H5o`000003omccg_l0003o
000000Ko00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000CoYl3[00?o0000
ojO0jol000000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l0000gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
05?ooooo00?o0000ooooooooool0;?ooool2o`0000?oYl3[00?o0000ojO0jonW`>/03?l000000olc
V?;o0000o`000009o`0000?oL:Sd00?o0000oiZmlOnJ_O401?l00004ok[Bk0?o000000?od=kSo`00
0?oAj>H00_oAj>H00ol0003od?7Xo`000002olchj0;o00000_ncnm`3o`0000;oYl3[00?o0000ojO0
jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`04o`00
00;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/3o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol0000looooo`03o`000?oooooooooo
00Sooooo0Ol00001ooooo`7ooooo001Dooooo`03o`000?oooooooooo02cooooo00?o0000ojO0jonW
`>/01?l00002ojBok@05o`000?n8/O7oR;7aohRalOl000000omi/OH00ol0003oHjkio`00000Ao`00
00CoVlSg00Co0000ok[Bk?l0003o00000_nlgO04o`000004om7Xi_l0003od?7Xo`0000;oc?SX0_l0
0002ok?kg0?o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`00
0?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/0
1?l00010ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oo
oooooooo02cooooo0_l00003ojO0j`05o`000?nT_ngoY;o]ojBokOl000000_n8/O4Eo`0000?oK[;j
00?o0000oi_8monKb?L01?l000000onlgO3o0000o`000003okcWm0Go000000?oc?SXo`000?l00000
2?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[
ojO0j`02o`0000CoYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00015ooooo`03o`000?oooooooooo00Kooooo
0Ol00001ooooo`7ooooo001Fooooo`03o`000?oooooooooo02gooooo00?o0000ojO0jonW`>/01ol0
0003ohnhlP04o`000?n3^?OoPkSgo`0000;oLKSl2_l000000ol/U_3o0000o`000005o`0000;oVmCl
1?l000001_nlioCo0000o`000?l0003o^?3do`0000;o[_K`0_l000000on7jmCo0000o`000003o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/01?l0003oYl3[o`000?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00019ooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo001Gooooo`;o0000;_ooool2o`0000?oYl3[00Co0000oijm
k_nN_Nko00000_n?^?88o`0000;oOl7l00?o0000ofg2o_m]`_h03_l00002oiONoPGo000000?o^?3d
o`000?n^m_001Ol000001OnW`>_o0000ojO0jonW`>_o000000;oYl3[1?l00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol0
0003ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`02o`0000CoYl3[0ol0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0004kooooo00?o
0000ooooooooool01Oooool1o`00007ooooo0Oooool005Wooooo00?o0000ooooooooool0;?ooool0
0ol0003oYl3[ojO0j`07o`0000?oU[cb00?o0000ohfomon=_oL01ol00002oh7=o`Wo00000_mP`o`4
o`0000;oS^Ck1ol000001?nW`>_o0000o`000?l00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`04o`000?nW
`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000
Doooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00F_ooool00ol0003ooooooooo
o`0/ooooo`;o00000onW`>/01?l0003oWKc^oiflk_l00002oiJllPCo00000onGa?H00ol0003oS/Sk
ohk8n`04o`0000;oV<ok5_l00003ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/0
1?l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[
ojO0j`03o`0000CoYl3[0ol00002ojO0j`03o`000?nW`>_oYl3[00Co0000F?ooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool1ooooo`00Foooool00ol0003oooooooooo`0/ooooo`03o`000?nW
`>_oYl3[00So00000_nL`O47o`0000;oWLWg1?l00002ojO0j`03o`000?nW`>_oYl3[00So00000_nW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`?o00000onW`>/00ol0003oYl3[ojO0
j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`04o`000?nW
`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00ol0001Looooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00G?ooool2o`0002gooooo0_l00003ojJok003o`000?nP_^koX;k^00Co00000_nS
`^l00ol0003oX<Gboj35lP04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jol000000_nW
`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW
`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l0
0002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/4o`00063ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo001Nooooo`03o`000?oooooooooo02cooooo00?o0000ojJok?nV_n`00ol00003
ojG0k@03o`000?nS`^ooXl;_00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04
o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/0
0ol0003oYl3[ojO0j`03o`0000?oYl3[0ol0001Uooooo`03o`000?oooooooooo00;ooooo0Ol00001
ooooo`00Goooool00ol0003oooooooooo`0/ooooo`;o00000_nV_n`00ol0003oYL3]ojG0k@04o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`?o00000onW`>/00ol0
003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[
00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0
j`04o`000?nW`>_o0000o`0006Wooooo00Go0000ooooooooooooooooo`000001ooooo`00H?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?nV_ncoY[o/00?o00000onW`>/00ol0003oYl3[ojO0j`04
o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00Co0000ojO0jol0003o00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW
`>_oYl3[00?o0000Joooool01Ol0003ooooooooooooooooo0000007ooooo001Qooooo`;o0000;Ooo
ool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW
`>_oYl3[00?o00000_nW`>/4o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l0
0003ojO0j`03o`000?nW`>_oYl3[00?o0000Koooool01?l0003oooooooooool00001ooooo`00Hooo
ool00ol0003oooooooooo`0[ooooo`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`03o`000?nW
`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0007?ooooo00?o0000ooooool000000Ooo
ool006Cooooo00?o0000ooooooooool0:oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003
ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000
ojO0jonW`>/01?l00003ojO0j`03o`000?nW`>_o000000;oYl3[00?o0000ojO0jonW`>/01?l00002
ojO0j`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000
ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000Moooool00ol0003oooooooooo`01
o`000000IOooool00ol0003oooooooooo`0[ooooo`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0
003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[
00?o00000onW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0
j`03o`000?nW`>_oYl3[00?o0000O?ooool1o`00007ooooo0Ol0000006Kooooo0_l0000/ooooo`;o
00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[1?l00002ojO0j`03
o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000ojO0jonW
`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool2o`000000J?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?nW`>_oYl3[00Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/3o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[
ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00023ooooo`?o0000001Yooooo`03o`000?oo
oooooooo02[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00003ojO0j`?o00000_nW`>/00ol0003oYl3[ojO0
j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000onW
`>/00ol0003oYl3[ojO0j`03o`0008?ooooo1?l00003ooooo`00J_ooool00ol0003oooooooooo`0[
ooooo`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`04o`000?nW`>_o0000o`0000;oYl3[00?o0000ojO0jonW`>/00ol0
0003ojO0j`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o
0000ojO0jonW`>/01?l00023ooooo`?o00001oooool006_ooooo00?o0000ooooooooool0:oooool2
o`0000;oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[1?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW`>/0
0ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00023ooooo`Co00002_ooool0
06cooooo0_l0000/ooooo`03o`000?nW`>_oYl3[00?o00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000Poooool4o`00
00kooooo001^ooooo`03o`000?oooooooooo02[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[0ol00003ojO0j`03o`000?nW`>_oYl3[00Co
00000_nW`>/00ol0003oYl3[ojO0j`04o`0000;oYl3[00?o0000ojO0jonW`>/01?l00022ooooo`Co
00004_ooool006oooooo00?o0000ooooooooool0:_ooool00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00002ojO0j`Co00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[
00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000P_ooool4o`0001Kooooo
001`ooooo`03o`000?oooooooooo02[ooooo0_l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/3o`0000?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co00000_nW
`>/00ol0003oYl3[ojO0j`04o`0008;ooooo0ol0000Jooooo`00LOooool2o`0002_ooooo00?o0000
ojO0jonW`>/00ol00002ojO0j`Co00000_nW`>/00ol0003oYl3[ojO0j`04o`0000?oYl3[00?o0000
ojO0jonW`>/00ol00003ojO0j`03o`000?nW`>_oYl3[00?o0000P_ooool4o`0001gooooo001coooo
o`03o`000?oooooooooo02Wooooo0_l00002ojO0j`?o00000onW`>/00ol0003oYl3[ojO0j`03o`00
00?oYl3[00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000POooool4o`00
027ooooo001dooooo`03o`000?oooooooooo02[ooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00?o
00000onW`>/00ol0003oYl3[ojO0j`03o`0000?oYl3[00?o0000ojO0jonW`>/00ol00021ooooo`Co
00009Oooool007Gooooo00?o0000ooooooooool0:_ooool00ol0003oYl3[ojO0j`04o`0000;oYl3[
00?o0000ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool4o`0002Wooooo
001fooooo`;o0000:oooool2o`0000?oYl3[00?o0000ojO0jonW`>/00ol00003ojO0j`03o`000?nW
`>_oYl3[00?o0000POooool3o`0002gooooo001hooooo`03o`000?oooooooooo02Wooooo00?o0000
ojO0jonW`>/01?l00002ojO0j`03o`000?nW`>_oYl3[00Co0000P?ooool4o`00033ooooo001ioooo
o`03o`000?oooooooooo02Wooooo0_l00003ojO0j`03o`000?nW`>_oYl3[00?o0000P?ooool4o`00
03Cooooo001jooooo`03o`000?oooooooooo02Wooooo00?o0000ojO0jonW`>/01?l0001oooooo`Co
0000>?ooool007_ooooo00?o0000ooooooooool0:Oooool2o`00083ooooo0ol0000looooo`00O?oo
ool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0003oooooo001nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Moooool4o`0004?ooooo001oooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0Loooool4o`0004Oooooo0020ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0Koooool4o`0004_ooooo0021ooooo`;o00009?ooool00ol0003ooooo
ooooo`1/ooooo`?o0000Coooool008?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Xooooo`Co0000D_ooool008Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1T
ooooo`Co0000E_ooool008Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Poooo
o`Co0000F_ooool008Kooooo0_l0000Oooooo`03o`000?oooooooooo05cooooo1?l0001Nooooo`00
R?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo0ol0001Rooooo`00ROoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001Uooooo`00R_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001Yooooo`00Roooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0001]ooooo`00S?ooool2o`0001Wo
oooo00?o0000ooooooooool0B_ooool3o`00077ooooo002>ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool4o`0007Cooooo002?ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0@_ooool4o`0007Sooooo002@ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool4o`0007cooooo002Aooooo`;o00005?ooool00ol0003oooooooooo`0joooo
o`Co0000P?ooool009?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`?o
0000Q?ooool009Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000
Qoooool009Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Rooo
ool009Kooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002?ooooo`00V?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Cooooo`00VOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Fooooo`00V_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Jooooo`00Voooool2o`0000Wooooo00?o
0000ooooooooool07Oooool4o`0009kooooo002Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool4o`000:;ooooo002Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool3o`000:Kooooo002Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:Wooooo002Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000:gooooo002Qooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000/Ooo
ool00:?ooooo00Co0000oooooooooooo00002?ooool4o`000;Gooooo002Tooooo`03o`000?oooooo
000000Gooooo0ol0002iooooo`00YOooool2o`000003ooooool0003o000000;o0000_?ooool00:Ko
oooo0_l00030ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00_oooool3o`000003oa0@4?oooooooooo0:?ooooo002Looooo`03okZj^_lb<S;ooooo00gooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00Gooooo00?o410@okZj^_ooool01?ooool2o`0000Kooooo
00?o0000okZj^_ooool0UOooool009gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00[ooooo0_lb<S86ooooo`03oiRHV?lb<S;ooooo00Gooooo
00?o0000ooooooooool01?ooool2oc8b<YKooooo002Kooooo`05oiRHV?l@413o0000o`000?nYZJT0
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o
00000_ooool00on7QhOo0000okZj^P05ooooo`03omgMgOl0003o^[Zj00Gooooo00?o0000oooooooo
ool01?ooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool01oooool4o`000003oa0@4?oooooooooo07?ooooo002Kooooo`08o`000?nYZJWoEEEEoiRH
V?mEEEGo^[Zjooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool00omEEEGo
MgMgodA4A005ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001Oooool00ol0003oooooooooo`1eooooo`00Voooool01olb
<S;ok^k^oiRHV?mEEEGogMgMoa0@4?ooool00ol00007ooooo`03o`000?oooooooooo00?ooooo00Co
gMgMo`000?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Cooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0MOooool009_o
oooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o0000ooooooooool00oooool0
1?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED01?ooool00ol0003ooooo
ooooo`0Cooooo`06o`000?ooooooooooooooool0003ooooo1_l00005ooooo`03o`000?oooooooooo
07Gooooo002Kooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`0:ooooo`03o`000?oooooo
oooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oM
gMgooooo00;ooooo00?o0000ooooooooool04oooool01Ol0003oQhN7oooooonYZJWo000000cooooo
00?o0000ooooooooool0MOooool009_ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool01?l@413o0000
o`000?ooool2o`000005oa0@4?ooooooooooooooool000005?ooool00ol@413o0000ogMgM`02o`00
0003oiRHV?oooooooooo00[ooooo00?o0000ooooooooool0MOooool009kooooo00?oIVIVohN7Qooo
ool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0MOooool009kooooo00?oZJVYodA4A?ooool02oooool2o`0001[ooooo0_l0000Tooooo`03oeEE
EOmVIVKo000007Oooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.117061, 0.0205603, \
0.00372443, 0.00372443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.02388 .26659 -36 -2.74357 ]
[.02388 .26659 0 6.25643 ]
[.01027 .35187 -6 -2.81576 ]
[.01027 .35187 0 6.18424 ]
[-0.00411 .44201 -30 -2.89248 ]
[-0.00411 .44201 0 6.10752 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0361 .26182 m
.04221 .25944 L
s
[(-0.002)] .02388 .26659 1 -0.39032 Mshowa
.02256 .34727 m
.0287 .34497 L
s
[(0)] .01027 .35187 1 -0.37428 Mshowa
.00825 .4376 m
.01442 .43539 L
s
[(0.002)] -0.00411 .44201 1 -0.35723 Mshowa
.125 Mabswid
.03278 .28275 m
.03646 .28133 L
s
.02942 .30396 m
.0331 .30256 L
s
.02601 .32547 m
.0297 .32408 L
s
.01906 .36938 m
.02275 .36802 L
s
.0155 .3918 m
.0192 .39045 L
s
.0119 .41454 m
.0156 .4132 L
s
.00454 .46099 m
.00825 .45968 L
s
.00078 .48472 m
.0045 .48342 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.657 .749 .918 r
.39597 .67735 .40235 .68299 .41304 .67994 .40668 .67428 Metetra
.657 .749 .918 r
.40668 .67428 .41304 .67994 .42377 .67688 .41744 .67119 Metetra
.657 .749 .918 r
.41744 .67119 .42377 .67688 .43455 .6738 .42825 .66809 Metetra
.657 .749 .918 r
.42825 .66809 .43455 .6738 .44537 .67072 .43909 .66498 Metetra
.657 .749 .918 r
.43909 .66498 .44537 .67072 .45623 .66762 .44998 .66186 Metetra
.657 .749 .918 r
.44998 .66186 .45623 .66762 .46714 .6645 .46092 .65872 Metetra
.657 .749 .918 r
.46092 .65872 .46714 .6645 .47809 .66138 .4719 .65558 Metetra
.657 .749 .918 r
.4719 .65558 .47809 .66138 .48908 .65824 .48292 .65241 Metetra
.657 .749 .918 r
.48292 .65241 .48908 .65824 .50012 .65509 .49399 .64924 Metetra
.657 .749 .918 r
.49399 .64924 .50012 .65509 .5112 .65193 .5051 .64605 Metetra
.657 .749 .918 r
.5051 .64605 .5112 .65193 .52233 .64875 .51626 .64285 Metetra
.657 .749 .918 r
.51626 .64285 .52233 .64875 .5335 .64556 .52746 .63964 Metetra
.657 .749 .918 r
.52746 .63964 .5335 .64556 .54472 .64236 .53871 .63641 Metetra
.657 .749 .918 r
.53871 .63641 .54472 .64236 .55599 .63915 .55 .63318 Metetra
.657 .749 .918 r
.55 .63318 .55599 .63915 .5673 .63592 .56134 .62992 Metetra
.657 .749 .918 r
.56134 .62992 .5673 .63592 .57865 .63268 .57273 .62666 Metetra
.657 .749 .918 r
.57273 .62666 .57865 .63268 .59006 .62942 .58417 .62338 Metetra
.657 .749 .918 r
.58417 .62338 .59006 .62942 .60151 .62615 .59565 .62008 Metetra
.657 .749 .918 r
.59565 .62008 .60151 .62615 .61301 .62287 .60718 .61678 Metetra
.657 .749 .918 r
.60718 .61678 .61301 .62287 .62455 .61958 .61875 .61346 Metetra
.657 .749 .918 r
.61875 .61346 .62455 .61958 .63614 .61627 .63038 .61012 Metetra
.657 .749 .918 r
.63038 .61012 .63614 .61627 .64779 .61294 .64205 .60677 Metetra
.657 .749 .918 r
.64205 .60677 .64779 .61294 .65948 .60961 .65378 .60341 Metetra
.657 .749 .918 r
.65378 .60341 .65948 .60961 .67121 .60626 .66555 .60004 Metetra
.657 .749 .918 r
.66555 .60004 .67121 .60626 .683 .60289 .67737 .59665 Metetra
.657 .749 .918 r
.67737 .59665 .683 .60289 .69484 .59952 .68924 .59324 Metetra
.657 .749 .918 r
.68924 .59324 .69484 .59952 .70672 .59612 .70116 .58982 Metetra
.657 .749 .918 r
.70116 .58982 .70672 .59612 .71866 .59272 .71313 .58639 Metetra
.657 .749 .918 r
.71313 .58639 .71866 .59272 .73065 .5893 .72515 .58294 Metetra
.657 .749 .918 r
.72515 .58294 .73065 .5893 .74268 .58586 .73723 .57948 Metetra
.657 .749 .918 r
.73723 .57948 .74268 .58586 .75477 .58241 .74935 .576 Metetra
.657 .749 .918 r
.74935 .576 .75477 .58241 .76691 .57895 .76153 .57251 Metetra
.657 .749 .918 r
.76153 .57251 .76691 .57895 .7791 .57547 .77375 .569 Metetra
.657 .749 .918 r
.77375 .569 .7791 .57547 .79134 .57197 .78603 .56548 Metetra
.657 .749 .918 r
.78603 .56548 .79134 .57197 .80364 .56846 .79836 .56195 Metetra
.657 .749 .918 r
.79836 .56195 .80364 .56846 .81599 .56494 .81075 .55839 Metetra
.657 .749 .918 r
.81075 .55839 .81599 .56494 .82839 .5614 .82319 .55483 Metetra
.657 .749 .918 r
.82319 .55483 .82839 .5614 .84084 .55785 .83568 .55124 Metetra
.657 .749 .918 r
.83568 .55124 .84084 .55785 .85335 .55428 .84822 .54765 Metetra
.657 .749 .918 r
.84822 .54765 .85335 .55428 .86591 .55069 .86082 .54403 Metetra
.657 .749 .918 r
.86082 .54403 .86591 .55069 .87852 .54709 .87348 .5404 Metetra
.657 .749 .918 r
.87348 .5404 .87852 .54709 .89119 .54347 .88619 .53676 Metetra
.657 .749 .918 r
.88619 .53676 .89119 .54347 .90392 .53984 .89895 .5331 Metetra
.657 .749 .918 r
.89895 .5331 .90392 .53984 .9167 .53619 .91177 .52942 Metetra
.657 .749 .918 r
.91177 .52942 .9167 .53619 .92953 .53253 .92465 .52573 Metetra
.657 .749 .918 r
.92465 .52573 .92953 .53253 .94243 .52885 .93758 .52202 Metetra
.657 .749 .918 r
.93758 .52202 .94243 .52885 .95537 .52516 .95057 .51829 Metetra
.657 .749 .918 r
.95057 .51829 .95537 .52516 .96838 .52144 .96362 .51455 Metetra
.657 .749 .918 r
.96362 .51455 .96838 .52144 .98144 .51772 .97673 .51079 Metetra
.657 .749 .918 r
.38954 .67167 .39597 .67735 .40668 .67428 .40028 .66857 Metetra
.657 .749 .918 r
.40028 .66857 .40668 .67428 .41744 .67119 .41107 .66546 Metetra
.657 .749 .918 r
.41107 .66546 .41744 .67119 .42825 .66809 .4219 .66234 Metetra
.657 .749 .918 r
.4219 .66234 .42825 .66809 .43909 .66498 .43277 .65921 Metetra
.657 .749 .918 r
.43277 .65921 .43909 .66498 .44998 .66186 .44369 .65606 Metetra
.657 .749 .918 r
.44369 .65606 .44998 .66186 .46092 .65872 .45465 .6529 Metetra
.657 .749 .918 r
.45465 .6529 .46092 .65872 .4719 .65558 .46566 .64973 Metetra
.657 .749 .918 r
.46566 .64973 .4719 .65558 .48292 .65241 .47671 .64654 Metetra
.657 .749 .918 r
.47671 .64654 .48292 .65241 .49399 .64924 .48781 .64335 Metetra
.657 .749 .918 r
.48781 .64335 .49399 .64924 .5051 .64605 .49895 .64014 Metetra
.657 .749 .918 r
.49895 .64014 .5051 .64605 .51626 .64285 .51013 .63691 Metetra
.657 .749 .918 r
.51013 .63691 .51626 .64285 .52746 .63964 .52137 .63367 Metetra
.657 .749 .918 r
.52137 .63367 .52746 .63964 .53871 .63641 .53265 .63042 Metetra
.657 .749 .918 r
.53265 .63042 .53871 .63641 .55 .63318 .54397 .62716 Metetra
.657 .749 .918 r
.54397 .62716 .55 .63318 .56134 .62992 .55534 .62388 Metetra
.657 .749 .918 r
.55534 .62388 .56134 .62992 .57273 .62666 .56676 .62059 Metetra
.657 .749 .918 r
.56676 .62059 .57273 .62666 .58417 .62338 .57823 .61729 Metetra
.657 .749 .918 r
.57823 .61729 .58417 .62338 .59565 .62008 .58974 .61397 Metetra
.657 .749 .918 r
.58974 .61397 .59565 .62008 .60718 .61678 .6013 .61064 Metetra
.657 .749 .918 r
.6013 .61064 .60718 .61678 .61875 .61346 .61291 .60729 Metetra
.657 .749 .918 r
.61291 .60729 .61875 .61346 .63038 .61012 .62457 .60393 Metetra
.657 .749 .918 r
.62457 .60393 .63038 .61012 .64205 .60677 .63628 .60056 Metetra
.657 .749 .918 r
.63628 .60056 .64205 .60677 .65378 .60341 .64803 .59717 Metetra
.657 .749 .918 r
.64803 .59717 .65378 .60341 .66555 .60004 .65984 .59377 Metetra
.657 .749 .918 r
.65984 .59377 .66555 .60004 .67737 .59665 .67169 .59035 Metetra
.657 .749 .918 r
.67169 .59035 .67737 .59665 .68924 .59324 .6836 .58692 Metetra
.657 .749 .918 r
.6836 .58692 .68924 .59324 .70116 .58982 .69555 .58347 Metetra
.657 .749 .918 r
.69555 .58347 .70116 .58982 .71313 .58639 .70756 .58001 Metetra
.657 .749 .918 r
.70756 .58001 .71313 .58639 .72515 .58294 .71962 .57654 Metetra
.657 .749 .918 r
.71962 .57654 .72515 .58294 .73723 .57948 .73173 .57305 Metetra
.657 .749 .918 r
.73173 .57305 .73723 .57948 .74935 .576 .74389 .56954 Metetra
.657 .749 .918 r
.74389 .56954 .74935 .576 .76153 .57251 .7561 .56602 Metetra
.657 .749 .918 r
.7561 .56602 .76153 .57251 .77375 .569 .76836 .56249 Metetra
.657 .749 .918 r
.76836 .56249 .77375 .569 .78603 .56548 .78068 .55894 Metetra
.657 .749 .918 r
.78068 .55894 .78603 .56548 .79836 .56195 .79305 .55538 Metetra
.657 .749 .918 r
.79305 .55538 .79836 .56195 .81075 .55839 .80547 .5518 Metetra
.657 .749 .918 r
.80547 .5518 .81075 .55839 .82319 .55483 .81795 .5482 Metetra
.657 .749 .918 r
.81795 .5482 .82319 .55483 .83568 .55124 .83048 .54459 Metetra
.657 .749 .918 r
.83048 .54459 .83568 .55124 .84822 .54765 .84306 .54096 Metetra
.657 .749 .918 r
.84306 .54096 .84822 .54765 .86082 .54403 .8557 .53732 Metetra
.657 .749 .918 r
.8557 .53732 .86082 .54403 .87348 .5404 .86839 .53366 Metetra
.657 .749 .918 r
.86839 .53366 .87348 .5404 .88619 .53676 .88114 .52999 Metetra
.657 .749 .918 r
.88114 .52999 .88619 .53676 .89895 .5331 .89395 .5263 Metetra
.657 .749 .918 r
.89395 .5263 .89895 .5331 .91177 .52942 .90681 .52259 Metetra
.657 .749 .918 r
.90681 .52259 .91177 .52942 .92465 .52573 .91973 .51887 Metetra
.657 .749 .918 r
.91973 .51887 .92465 .52573 .93758 .52202 .9327 .51513 Metetra
.657 .749 .918 r
.9327 .51513 .93758 .52202 .95057 .51829 .94574 .51137 Metetra
.657 .749 .918 r
.94574 .51137 .95057 .51829 .96362 .51455 .95883 .5076 Metetra
.657 .749 .918 r
.95883 .5076 .96362 .51455 .97673 .51079 .97197 .50381 Metetra
.657 .749 .918 r
.38306 .66594 .38954 .67167 .40028 .66857 .39383 .66282 Metetra
.657 .749 .918 r
.39383 .66282 .40028 .66857 .41107 .66546 .40464 .65969 Metetra
.657 .749 .918 r
.40464 .65969 .41107 .66546 .4219 .66234 .4155 .65655 Metetra
.657 .749 .918 r
.4155 .65655 .4219 .66234 .43277 .65921 .4264 .65339 Metetra
.657 .749 .918 r
.4264 .65339 .43277 .65921 .44369 .65606 .43735 .65022 Metetra
.657 .749 .918 r
.43735 .65022 .44369 .65606 .45465 .6529 .44834 .64704 Metetra
.657 .749 .918 r
.44834 .64704 .45465 .6529 .46566 .64973 .45937 .64384 Metetra
.657 .749 .918 r
.45937 .64384 .46566 .64973 .47671 .64654 .47045 .64063 Metetra
.657 .749 .918 r
.47045 .64063 .47671 .64654 .48781 .64335 .48158 .63741 Metetra
.657 .749 .918 r
.48158 .63741 .48781 .64335 .49895 .64014 .49275 .63417 Metetra
.657 .749 .918 r
.49275 .63417 .49895 .64014 .51013 .63691 .50397 .63092 Metetra
.657 .749 .918 r
.50397 .63092 .51013 .63691 .52137 .63367 .51523 .62766 Metetra
.657 .749 .918 r
.51523 .62766 .52137 .63367 .53265 .63042 .52654 .62439 Metetra
.657 .749 .918 r
.52654 .62439 .53265 .63042 .54397 .62716 .53789 .6211 Metetra
.657 .749 .918 r
.53789 .6211 .54397 .62716 .55534 .62388 .5493 .6178 Metetra
.657 .749 .918 r
.5493 .6178 .55534 .62388 .56676 .62059 .56075 .61448 Metetra
.657 .749 .918 r
.56075 .61448 .56676 .62059 .57823 .61729 .57225 .61115 Metetra
.657 .749 .918 r
.57225 .61115 .57823 .61729 .58974 .61397 .58379 .60781 Metetra
.657 .749 .918 r
.58379 .60781 .58974 .61397 .6013 .61064 .59538 .60445 Metetra
.657 .749 .918 r
.59538 .60445 .6013 .61064 .61291 .60729 .60703 .60108 Metetra
.657 .749 .918 r
.60703 .60108 .61291 .60729 .62457 .60393 .61872 .59769 Metetra
.657 .749 .918 r
.61872 .59769 .62457 .60393 .63628 .60056 .63046 .59429 Metetra
.657 .749 .918 r
.63046 .59429 .63628 .60056 .64803 .59717 .64225 .59088 Metetra
.657 .749 .918 r
.64225 .59088 .64803 .59717 .65984 .59377 .65409 .58745 Metetra
.657 .749 .918 r
.65409 .58745 .65984 .59377 .67169 .59035 .66597 .584 Metetra
.657 .749 .918 r
.66597 .584 .67169 .59035 .6836 .58692 .67791 .58055 Metetra
.657 .749 .918 r
.67791 .58055 .6836 .58692 .69555 .58347 .6899 .57707 Metetra
.657 .749 .918 r
.6899 .57707 .69555 .58347 .70756 .58001 .70195 .57359 Metetra
.657 .749 .918 r
.70195 .57359 .70756 .58001 .71962 .57654 .71404 .57008 Metetra
.657 .749 .918 r
.71404 .57008 .71962 .57654 .73173 .57305 .72618 .56657 Metetra
.657 .749 .918 r
.72618 .56657 .73173 .57305 .74389 .56954 .73838 .56304 Metetra
.657 .749 .918 r
.73838 .56304 .74389 .56954 .7561 .56602 .75063 .55949 Metetra
.657 .749 .918 r
.75063 .55949 .7561 .56602 .76836 .56249 .76293 .55593 Metetra
.657 .749 .918 r
.76293 .55593 .76836 .56249 .78068 .55894 .77528 .55235 Metetra
.657 .749 .918 r
.77528 .55235 .78068 .55894 .79305 .55538 .78769 .54875 Metetra
.657 .749 .918 r
.78769 .54875 .79305 .55538 .80547 .5518 .80015 .54515 Metetra
.657 .749 .918 r
.80015 .54515 .80547 .5518 .81795 .5482 .81266 .54152 Metetra
.657 .749 .918 r
.81266 .54152 .81795 .5482 .83048 .54459 .82523 .53788 Metetra
.657 .749 .918 r
.82523 .53788 .83048 .54459 .84306 .54096 .83786 .53422 Metetra
.657 .749 .918 r
.83786 .53422 .84306 .54096 .8557 .53732 .85053 .53055 Metetra
.657 .749 .918 r
.85053 .53055 .8557 .53732 .86839 .53366 .86327 .52686 Metetra
.657 .749 .918 r
.86327 .52686 .86839 .53366 .88114 .52999 .87606 .52316 Metetra
.657 .749 .918 r
.87606 .52316 .88114 .52999 .89395 .5263 .8889 .51944 Metetra
.657 .749 .918 r
.8889 .51944 .89395 .5263 .90681 .52259 .90181 .5157 Metetra
.657 .749 .918 r
.90181 .5157 .90681 .52259 .91973 .51887 .91477 .51195 Metetra
.657 .749 .918 r
.91477 .51195 .91973 .51887 .9327 .51513 .92778 .50818 Metetra
.657 .749 .918 r
.92778 .50818 .9327 .51513 .94574 .51137 .94086 .50439 Metetra
.657 .749 .918 r
.94086 .50439 .94574 .51137 .95883 .5076 .95399 .50059 Metetra
.657 .749 .918 r
.95399 .50059 .95883 .5076 .97197 .50381 .96718 .49677 Metetra
.657 .749 .918 r
.37653 .66017 .38306 .66594 .39383 .66282 .38733 .65703 Metetra
.657 .749 .918 r
.38733 .65703 .39383 .66282 .40464 .65969 .39817 .65388 Metetra
.657 .749 .918 r
.39817 .65388 .40464 .65969 .4155 .65655 .40906 .65071 Metetra
.657 .749 .918 r
.40906 .65071 .4155 .65655 .4264 .65339 .41999 .64753 Metetra
.657 .749 .918 r
.41999 .64753 .4264 .65339 .43735 .65022 .43096 .64433 Metetra
.657 .749 .918 r
.43096 .64433 .43735 .65022 .44834 .64704 .44198 .64113 Metetra
.657 .749 .918 r
.44198 .64113 .44834 .64704 .45937 .64384 .45304 .63791 Metetra
.657 .749 .918 r
.45304 .63791 .45937 .64384 .47045 .64063 .46415 .63467 Metetra
.657 .749 .918 r
.46415 .63467 .47045 .64063 .48158 .63741 .47531 .63143 Metetra
.657 .749 .918 r
.47531 .63143 .48158 .63741 .49275 .63417 .48651 .62817 Metetra
.657 .749 .918 r
.48651 .62817 .49275 .63417 .50397 .63092 .49775 .62489 Metetra
.657 .749 .918 r
.49775 .62489 .50397 .63092 .51523 .62766 .50905 .62161 Metetra
.657 .749 .918 r
.50905 .62161 .51523 .62766 .52654 .62439 .52039 .61831 Metetra
.657 .749 .918 r
.52039 .61831 .52654 .62439 .53789 .6211 .53177 .61499 Metetra
.657 .749 .918 r
.53177 .61499 .53789 .6211 .5493 .6178 .54321 .61166 Metetra
.657 .749 .918 r
.54321 .61166 .5493 .6178 .56075 .61448 .55469 .60832 Metetra
.657 .749 .918 r
.55469 .60832 .56075 .61448 .57225 .61115 .56622 .60497 Metetra
.657 .749 .918 r
.56622 .60497 .57225 .61115 .58379 .60781 .57779 .6016 Metetra
.657 .749 .918 r
.57779 .6016 .58379 .60781 .59538 .60445 .58942 .59821 Metetra
.657 .749 .918 r
.58942 .59821 .59538 .60445 .60703 .60108 .60109 .59481 Metetra
.657 .749 .918 r
.60109 .59481 .60703 .60108 .61872 .59769 .61282 .5914 Metetra
.657 .749 .918 r
.61282 .5914 .61872 .59769 .63046 .59429 .62459 .58798 Metetra
.657 .749 .918 r
.62459 .58798 .63046 .59429 .64225 .59088 .63641 .58453 Metetra
.657 .749 .918 r
.63641 .58453 .64225 .59088 .65409 .58745 .64829 .58108 Metetra
.657 .749 .918 r
.64829 .58108 .65409 .58745 .66597 .584 .66021 .57761 Metetra
.657 .749 .918 r
.66021 .57761 .66597 .584 .67791 .58055 .67218 .57412 Metetra
.657 .749 .918 r
.67218 .57412 .67791 .58055 .6899 .57707 .68421 .57062 Metetra
.657 .749 .918 r
.68421 .57062 .6899 .57707 .70195 .57359 .69629 .56711 Metetra
.657 .749 .918 r
.69629 .56711 .70195 .57359 .71404 .57008 .70841 .56358 Metetra
.657 .749 .918 r
.70841 .56358 .71404 .57008 .72618 .56657 .72059 .56003 Metetra
.657 .749 .918 r
.72059 .56003 .72618 .56657 .73838 .56304 .73283 .55647 Metetra
.657 .749 .918 r
.73283 .55647 .73838 .56304 .75063 .55949 .74511 .5529 Metetra
.657 .749 .918 r
.74511 .5529 .75063 .55949 .76293 .55593 .75745 .54931 Metetra
.657 .749 .918 r
.75745 .54931 .76293 .55593 .77528 .55235 .76984 .5457 Metetra
.657 .749 .918 r
.76984 .5457 .77528 .55235 .78769 .54875 .78228 .54208 Metetra
.657 .749 .918 r
.78228 .54208 .78769 .54875 .80015 .54515 .79478 .53844 Metetra
.657 .749 .918 r
.79478 .53844 .80015 .54515 .81266 .54152 .80734 .53479 Metetra
.657 .749 .918 r
.80734 .53479 .81266 .54152 .82523 .53788 .81994 .53112 Metetra
.657 .749 .918 r
.81994 .53112 .82523 .53788 .83786 .53422 .83261 .52743 Metetra
.657 .749 .918 r
.83261 .52743 .83786 .53422 .85053 .53055 .84533 .52373 Metetra
.657 .749 .918 r
.84533 .52373 .85053 .53055 .86327 .52686 .8581 .52001 Metetra
.657 .749 .918 r
.8581 .52001 .86327 .52686 .87606 .52316 .87093 .51628 Metetra
.657 .749 .918 r
.87093 .51628 .87606 .52316 .8889 .51944 .88382 .51253 Metetra
.657 .749 .918 r
.88382 .51253 .8889 .51944 .90181 .5157 .89676 .50876 Metetra
.657 .749 .918 r
.89676 .50876 .90181 .5157 .91477 .51195 .90976 .50498 Metetra
.657 .749 .918 r
.90976 .50498 .91477 .51195 .92778 .50818 .92282 .50118 Metetra
.657 .749 .918 r
.92282 .50118 .92778 .50818 .94086 .50439 .93594 .49736 Metetra
.657 .749 .918 r
.93594 .49736 .94086 .50439 .95399 .50059 .94912 .49352 Metetra
.657 .749 .918 r
.94912 .49352 .95399 .50059 .96718 .49677 .96235 .48967 Metetra
.657 .749 .918 r
.36996 .65436 .37653 .66017 .38733 .65703 .38078 .6512 Metetra
.657 .749 .918 r
.38078 .6512 .38733 .65703 .39817 .65388 .39165 .64802 Metetra
.657 .749 .918 r
.39165 .64802 .39817 .65388 .40906 .65071 .40257 .64482 Metetra
.657 .749 .918 r
.40257 .64482 .40906 .65071 .41999 .64753 .41352 .64162 Metetra
.657 .749 .918 r
.41352 .64162 .41999 .64753 .43096 .64433 .42452 .6384 Metetra
.657 .749 .918 r
.42452 .6384 .43096 .64433 .44198 .64113 .43557 .63517 Metetra
.657 .749 .918 r
.43557 .63517 .44198 .64113 .45304 .63791 .44666 .63193 Metetra
.657 .749 .918 r
.44666 .63193 .45304 .63791 .46415 .63467 .4578 .62867 Metetra
.657 .749 .918 r
.4578 .62867 .46415 .63467 .47531 .63143 .46899 .6254 Metetra
.657 .749 .918 r
.46899 .6254 .47531 .63143 .48651 .62817 .48022 .62211 Metetra
.657 .749 .918 r
.48022 .62211 .48651 .62817 .49775 .62489 .49149 .61881 Metetra
.657 .749 .918 r
.49149 .61881 .49775 .62489 .50905 .62161 .50281 .6155 Metetra
.657 .749 .918 r
.50281 .6155 .50905 .62161 .52039 .61831 .51418 .61218 Metetra
.657 .749 .918 r
.51418 .61218 .52039 .61831 .53177 .61499 .5256 .60884 Metetra
.657 .749 .918 r
.5256 .60884 .53177 .61499 .54321 .61166 .53707 .60548 Metetra
.657 .749 .918 r
.53707 .60548 .54321 .61166 .55469 .60832 .54858 .60212 Metetra
.657 .749 .918 r
.54858 .60212 .55469 .60832 .56622 .60497 .56014 .59873 Metetra
.657 .749 .918 r
.56014 .59873 .56622 .60497 .57779 .6016 .57175 .59534 Metetra
.657 .749 .918 r
.57175 .59534 .57779 .6016 .58942 .59821 .58341 .59193 Metetra
.657 .749 .918 r
.58341 .59193 .58942 .59821 .60109 .59481 .59512 .5885 Metetra
.657 .749 .918 r
.59512 .5885 .60109 .59481 .61282 .5914 .60687 .58507 Metetra
.657 .749 .918 r
.60687 .58507 .61282 .5914 .62459 .58798 .61868 .58161 Metetra
.657 .749 .918 r
.61868 .58161 .62459 .58798 .63641 .58453 .63054 .57814 Metetra
.657 .749 .918 r
.63054 .57814 .63641 .58453 .64829 .58108 .64244 .57466 Metetra
.657 .749 .918 r
.64244 .57466 .64829 .58108 .66021 .57761 .6544 .57116 Metetra
.657 .749 .918 r
.6544 .57116 .66021 .57761 .67218 .57412 .66641 .56765 Metetra
.657 .749 .918 r
.66641 .56765 .67218 .57412 .68421 .57062 .67847 .56412 Metetra
.657 .749 .918 r
.67847 .56412 .68421 .57062 .69629 .56711 .69058 .56058 Metetra
.657 .749 .918 r
.69058 .56058 .69629 .56711 .70841 .56358 .70274 .55702 Metetra
.657 .749 .918 r
.70274 .55702 .70841 .56358 .72059 .56003 .71496 .55345 Metetra
.657 .749 .918 r
.71496 .55345 .72059 .56003 .73283 .55647 .72723 .54986 Metetra
.657 .749 .918 r
.72723 .54986 .73283 .55647 .74511 .5529 .73955 .54626 Metetra
.657 .749 .918 r
.73955 .54626 .74511 .5529 .75745 .54931 .75193 .54264 Metetra
.657 .749 .918 r
.75193 .54264 .75745 .54931 .76984 .5457 .76436 .539 Metetra
.657 .749 .918 r
.76436 .539 .76984 .5457 .78228 .54208 .77684 .53535 Metetra
.657 .749 .918 r
.77684 .53535 .78228 .54208 .79478 .53844 .78938 .53168 Metetra
.657 .749 .918 r
.78938 .53168 .79478 .53844 .80734 .53479 .80197 .528 Metetra
.657 .749 .918 r
.80197 .528 .80734 .53479 .81994 .53112 .81462 .5243 Metetra
.657 .749 .918 r
.81462 .5243 .81994 .53112 .83261 .52743 .82732 .52059 Metetra
.657 .749 .918 r
.82732 .52059 .83261 .52743 .84533 .52373 .84008 .51685 Metetra
.657 .749 .918 r
.84008 .51685 .84533 .52373 .8581 .52001 .85289 .51311 Metetra
.657 .749 .918 r
.85289 .51311 .8581 .52001 .87093 .51628 .86576 .50934 Metetra
.657 .749 .918 r
.86576 .50934 .87093 .51628 .88382 .51253 .87869 .50556 Metetra
.657 .749 .918 r
.87869 .50556 .88382 .51253 .89676 .50876 .89168 .50176 Metetra
.657 .749 .918 r
.89168 .50176 .89676 .50876 .90976 .50498 .90472 .49795 Metetra
.657 .749 .918 r
.90472 .49795 .90976 .50498 .92282 .50118 .91782 .49411 Metetra
.657 .749 .918 r
.91782 .49411 .92282 .50118 .93594 .49736 .93098 .49026 Metetra
.657 .749 .918 r
.93098 .49026 .93594 .49736 .94912 .49352 .9442 .4864 Metetra
.657 .749 .918 r
.9442 .4864 .94912 .49352 .96235 .48967 .95748 .48251 Metetra
.657 .749 .918 r
.36334 .64851 .36996 .65436 .38078 .6512 .37419 .64532 Metetra
.657 .749 .918 r
.37419 .64532 .38078 .6512 .39165 .64802 .38508 .64211 Metetra
.657 .749 .918 r
.38508 .64211 .39165 .64802 .40257 .64482 .39602 .6389 Metetra
.657 .749 .918 r
.39602 .6389 .40257 .64482 .41352 .64162 .40701 .63567 Metetra
.657 .749 .918 r
.40701 .63567 .41352 .64162 .42452 .6384 .41804 .63243 Metetra
.657 .749 .918 r
.41804 .63243 .42452 .6384 .43557 .63517 .42911 .62917 Metetra
.657 .749 .918 r
.42911 .62917 .43557 .63517 .44666 .63193 .44024 .6259 Metetra
.657 .749 .918 r
.44024 .6259 .44666 .63193 .4578 .62867 .4514 .62262 Metetra
.657 .749 .918 r
.4514 .62262 .4578 .62867 .46899 .6254 .46262 .61932 Metetra
.657 .749 .918 r
.46262 .61932 .46899 .6254 .48022 .62211 .47388 .61601 Metetra
.657 .749 .918 r
.47388 .61601 .48022 .62211 .49149 .61881 .48518 .61269 Metetra
.657 .749 .918 r
.48518 .61269 .49149 .61881 .50281 .6155 .49654 .60935 Metetra
.657 .749 .918 r
.49654 .60935 .50281 .6155 .51418 .61218 .50794 .606 Metetra
.657 .749 .918 r
.50794 .606 .51418 .61218 .5256 .60884 .51938 .60263 Metetra
.657 .749 .918 r
.51938 .60263 .5256 .60884 .53707 .60548 .53088 .59926 Metetra
.657 .749 .918 r
.53088 .59926 .53707 .60548 .54858 .60212 .54242 .59586 Metetra
.657 .749 .918 r
.54242 .59586 .54858 .60212 .56014 .59873 .55402 .59245 Metetra
.657 .749 .918 r
.55402 .59245 .56014 .59873 .57175 .59534 .56566 .58903 Metetra
.657 .749 .918 r
.56566 .58903 .57175 .59534 .58341 .59193 .57735 .5856 Metetra
.657 .749 .918 r
.57735 .5856 .58341 .59193 .59512 .5885 .58909 .58214 Metetra
.657 .749 .918 r
.58909 .58214 .59512 .5885 .60687 .58507 .60088 .57868 Metetra
.657 .749 .918 r
.60088 .57868 .60687 .58507 .61868 .58161 .61272 .5752 Metetra
.657 .749 .918 r
.61272 .5752 .61868 .58161 .63054 .57814 .62461 .5717 Metetra
.657 .749 .918 r
.62461 .5717 .63054 .57814 .64244 .57466 .63655 .56819 Metetra
.657 .749 .918 r
.63655 .56819 .64244 .57466 .6544 .57116 .64855 .56467 Metetra
.657 .749 .918 r
.64855 .56467 .6544 .57116 .66641 .56765 .66059 .56113 Metetra
.657 .749 .918 r
.66059 .56113 .66641 .56765 .67847 .56412 .67268 .55757 Metetra
.657 .749 .918 r
.67268 .55757 .67847 .56412 .69058 .56058 .68483 .554 Metetra
.657 .749 .918 r
.68483 .554 .69058 .56058 .70274 .55702 .69703 .55041 Metetra
.657 .749 .918 r
.69703 .55041 .70274 .55702 .71496 .55345 .70928 .54681 Metetra
.657 .749 .918 r
.70928 .54681 .71496 .55345 .72723 .54986 .72159 .5432 Metetra
.657 .749 .918 r
.72159 .5432 .72723 .54986 .73955 .54626 .73395 .53956 Metetra
.657 .749 .918 r
.73395 .53956 .73955 .54626 .75193 .54264 .74636 .53591 Metetra
.657 .749 .918 r
.74636 .53591 .75193 .54264 .76436 .539 .75883 .53225 Metetra
.657 .749 .918 r
.75883 .53225 .76436 .539 .77684 .53535 .77135 .52857 Metetra
.657 .749 .918 r
.77135 .52857 .77684 .53535 .78938 .53168 .78392 .52487 Metetra
.657 .749 .918 r
.78392 .52487 .78938 .53168 .80197 .528 .79656 .52116 Metetra
.657 .749 .918 r
.79656 .52116 .80197 .528 .81462 .5243 .80924 .51743 Metetra
.657 .749 .918 r
.80924 .51743 .81462 .5243 .82732 .52059 .82199 .51368 Metetra
.657 .749 .918 r
.82199 .51368 .82732 .52059 .84008 .51685 .83478 .50992 Metetra
.657 .749 .918 r
.83478 .50992 .84008 .51685 .85289 .51311 .84764 .50614 Metetra
.657 .749 .918 r
.84764 .50614 .85289 .51311 .86576 .50934 .86055 .50235 Metetra
.657 .749 .918 r
.86055 .50235 .86576 .50934 .87869 .50556 .87352 .49853 Metetra
.657 .749 .918 r
.87352 .49853 .87869 .50556 .89168 .50176 .88655 .4947 Metetra
.657 .749 .918 r
.88655 .4947 .89168 .50176 .90472 .49795 .89964 .49086 Metetra
.657 .749 .918 r
.89964 .49086 .90472 .49795 .91782 .49411 .91278 .48699 Metetra
.657 .749 .918 r
.91278 .48699 .91782 .49411 .93098 .49026 .92598 .48311 Metetra
.657 .749 .918 r
.92598 .48311 .93098 .49026 .9442 .4864 .93925 .47921 Metetra
.657 .749 .918 r
.93925 .47921 .9442 .4864 .95748 .48251 .95257 .4753 Metetra
.657 .749 .918 r
.35666 .64261 .36334 .64851 .37419 .64532 .36754 .63939 Metetra
.657 .749 .918 r
.36754 .63939 .37419 .64532 .38508 .64211 .37846 .63617 Metetra
.657 .749 .918 r
.37846 .63617 .38508 .64211 .39602 .6389 .38943 .63293 Metetra
.657 .749 .918 r
.38943 .63293 .39602 .6389 .40701 .63567 .40045 .62967 Metetra
.657 .749 .918 r
.40045 .62967 .40701 .63567 .41804 .63243 .4115 .6264 Metetra
.657 .749 .918 r
.4115 .6264 .41804 .63243 .42911 .62917 .42261 .62312 Metetra
.657 .749 .918 r
.42261 .62312 .42911 .62917 .44024 .6259 .43376 .61983 Metetra
.657 .749 .918 r
.43376 .61983 .44024 .6259 .4514 .62262 .44496 .61652 Metetra
.657 .749 .918 r
.44496 .61652 .4514 .62262 .46262 .61932 .4562 .6132 Metetra
.657 .749 .918 r
.4562 .6132 .46262 .61932 .47388 .61601 .46749 .60987 Metetra
.657 .749 .918 r
.46749 .60987 .47388 .61601 .48518 .61269 .47882 .60652 Metetra
.657 .749 .918 r
.47882 .60652 .48518 .61269 .49654 .60935 .49021 .60315 Metetra
.657 .749 .918 r
.49021 .60315 .49654 .60935 .50794 .606 .50164 .59978 Metetra
.657 .749 .918 r
.50164 .59978 .50794 .606 .51938 .60263 .51312 .59638 Metetra
.657 .749 .918 r
.51312 .59638 .51938 .60263 .53088 .59926 .52465 .59298 Metetra
.657 .749 .918 r
.52465 .59298 .53088 .59926 .54242 .59586 .53622 .58956 Metetra
.657 .749 .918 r
.53622 .58956 .54242 .59586 .55402 .59245 .54785 .58612 Metetra
.657 .749 .918 r
.54785 .58612 .55402 .59245 .56566 .58903 .55952 .58268 Metetra
.657 .749 .918 r
.55952 .58268 .56566 .58903 .57735 .5856 .57125 .57921 Metetra
.657 .749 .918 r
.57125 .57921 .57735 .5856 .58909 .58214 .58302 .57573 Metetra
.657 .749 .918 r
.58302 .57573 .58909 .58214 .60088 .57868 .59484 .57224 Metetra
.657 .749 .918 r
.59484 .57224 .60088 .57868 .61272 .5752 .60672 .56873 Metetra
.657 .749 .918 r
.60672 .56873 .61272 .5752 .62461 .5717 .61864 .56521 Metetra
.657 .749 .918 r
.61864 .56521 .62461 .5717 .63655 .56819 .63062 .56167 Metetra
.657 .749 .918 r
.63062 .56167 .63655 .56819 .64855 .56467 .64264 .55812 Metetra
.657 .749 .918 r
.64264 .55812 .64855 .56467 .66059 .56113 .65472 .55455 Metetra
.657 .749 .918 r
.65472 .55455 .66059 .56113 .67268 .55757 .66685 .55097 Metetra
.657 .749 .918 r
.66685 .55097 .67268 .55757 .68483 .554 .67904 .54737 Metetra
.657 .749 .918 r
.67904 .54737 .68483 .554 .69703 .55041 .69127 .54375 Metetra
.657 .749 .918 r
.69127 .54375 .69703 .55041 .70928 .54681 .70356 .54012 Metetra
.657 .749 .918 r
.70356 .54012 .70928 .54681 .72159 .5432 .7159 .53648 Metetra
.657 .749 .918 r
.7159 .53648 .72159 .5432 .73395 .53956 .7283 .53281 Metetra
.657 .749 .918 r
.7283 .53281 .73395 .53956 .74636 .53591 .74075 .52914 Metetra
.657 .749 .918 r
.74075 .52914 .74636 .53591 .75883 .53225 .75325 .52544 Metetra
.657 .749 .918 r
.75325 .52544 .75883 .53225 .77135 .52857 .76581 .52173 Metetra
.657 .749 .918 r
.76581 .52173 .77135 .52857 .78392 .52487 .77843 .518 Metetra
.657 .749 .918 r
.77843 .518 .78392 .52487 .79656 .52116 .7911 .51426 Metetra
.657 .749 .918 r
.7911 .51426 .79656 .52116 .80924 .51743 .80383 .5105 Metetra
.657 .749 .918 r
.80383 .5105 .80924 .51743 .82199 .51368 .81661 .50672 Metetra
.657 .749 .918 r
.81661 .50672 .82199 .51368 .83478 .50992 .82945 .50293 Metetra
.657 .749 .918 r
.82945 .50293 .83478 .50992 .84764 .50614 .84234 .49912 Metetra
.657 .749 .918 r
.84234 .49912 .84764 .50614 .86055 .50235 .8553 .49529 Metetra
.657 .749 .918 r
.8553 .49529 .86055 .50235 .87352 .49853 .86831 .49145 Metetra
.657 .749 .918 r
.86831 .49145 .87352 .49853 .88655 .4947 .88138 .48759 Metetra
.657 .749 .918 r
.88138 .48759 .88655 .4947 .89964 .49086 .89451 .48371 Metetra
.657 .749 .918 r
.89451 .48371 .89964 .49086 .91278 .48699 .9077 .47981 Metetra
.657 .749 .918 r
.9077 .47981 .91278 .48699 .92598 .48311 .92094 .4759 Metetra
.657 .749 .918 r
.92094 .4759 .92598 .48311 .93925 .47921 .93425 .47197 Metetra
.657 .749 .918 r
.93425 .47197 .93925 .47921 .95257 .4753 .94762 .46802 Metetra
.657 .749 .918 r
.34994 .63666 .35666 .64261 .36754 .63939 .36084 .63342 Metetra
.657 .749 .918 r
.36084 .63342 .36754 .63939 .37846 .63617 .37179 .63017 Metetra
.657 .749 .918 r
.37179 .63017 .37846 .63617 .38943 .63293 .38279 .62691 Metetra
.657 .749 .918 r
.38279 .62691 .38943 .63293 .40045 .62967 .39383 .62363 Metetra
.657 .749 .918 r
.39383 .62363 .40045 .62967 .4115 .6264 .40492 .62034 Metetra
.657 .749 .918 r
.40492 .62034 .4115 .6264 .42261 .62312 .41605 .61703 Metetra
.657 .749 .918 r
.41605 .61703 .42261 .62312 .43376 .61983 .42723 .61371 Metetra
.657 .749 .918 r
.42723 .61371 .43376 .61983 .44496 .61652 .43846 .61038 Metetra
.657 .749 .918 r
.43846 .61038 .44496 .61652 .4562 .6132 .44973 .60703 Metetra
.657 .749 .918 r
.44973 .60703 .4562 .6132 .46749 .60987 .46105 .60367 Metetra
.657 .749 .918 r
.46105 .60367 .46749 .60987 .47882 .60652 .47242 .6003 Metetra
.657 .749 .918 r
.47242 .6003 .47882 .60652 .49021 .60315 .48383 .59691 Metetra
.657 .749 .918 r
.48383 .59691 .49021 .60315 .50164 .59978 .49529 .5935 Metetra
.657 .749 .918 r
.49529 .5935 .50164 .59978 .51312 .59638 .5068 .59009 Metetra
.657 .749 .918 r
.5068 .59009 .51312 .59638 .52465 .59298 .51836 .58665 Metetra
.657 .749 .918 r
.51836 .58665 .52465 .59298 .53622 .58956 .52997 .58321 Metetra
.657 .749 .918 r
.52997 .58321 .53622 .58956 .54785 .58612 .54163 .57975 Metetra
.657 .749 .918 r
.54163 .57975 .54785 .58612 .55952 .58268 .55334 .57627 Metetra
.657 .749 .918 r
.55334 .57627 .55952 .58268 .57125 .57921 .56509 .57278 Metetra
.657 .749 .918 r
.56509 .57278 .57125 .57921 .58302 .57573 .5769 .56927 Metetra
.657 .749 .918 r
.5769 .56927 .58302 .57573 .59484 .57224 .58876 .56575 Metetra
.657 .749 .918 r
.58876 .56575 .59484 .57224 .60672 .56873 .60066 .56222 Metetra
.657 .749 .918 r
.60066 .56222 .60672 .56873 .61864 .56521 .61262 .55867 Metetra
.657 .749 .918 r
.61262 .55867 .61864 .56521 .63062 .56167 .62463 .5551 Metetra
.657 .749 .918 r
.62463 .5551 .63062 .56167 .64264 .55812 .63669 .55152 Metetra
.657 .749 .918 r
.63669 .55152 .64264 .55812 .65472 .55455 .64881 .54792 Metetra
.657 .749 .918 r
.64881 .54792 .65472 .55455 .66685 .55097 .66097 .54431 Metetra
.657 .749 .918 r
.66097 .54431 .66685 .55097 .67904 .54737 .67319 .54068 Metetra
.657 .749 .918 r
.67319 .54068 .67904 .54737 .69127 .54375 .68547 .53704 Metetra
.657 .749 .918 r
.68547 .53704 .69127 .54375 .70356 .54012 .69779 .53338 Metetra
.657 .749 .918 r
.69779 .53338 .70356 .54012 .7159 .53648 .71017 .5297 Metetra
.657 .749 .918 r
.71017 .5297 .7159 .53648 .7283 .53281 .72261 .52601 Metetra
.657 .749 .918 r
.72261 .52601 .7283 .53281 .74075 .52914 .73509 .5223 Metetra
.657 .749 .918 r
.73509 .5223 .74075 .52914 .75325 .52544 .74764 .51858 Metetra
.657 .749 .918 r
.74764 .51858 .75325 .52544 .76581 .52173 .76024 .51484 Metetra
.657 .749 .918 r
.76024 .51484 .76581 .52173 .77843 .518 .77289 .51108 Metetra
.657 .749 .918 r
.77289 .51108 .77843 .518 .7911 .51426 .7856 .50731 Metetra
.657 .749 .918 r
.7856 .50731 .7911 .51426 .80383 .5105 .79837 .50352 Metetra
.657 .749 .918 r
.79837 .50352 .80383 .5105 .81661 .50672 .81119 .49971 Metetra
.657 .749 .918 r
.81119 .49971 .81661 .50672 .82945 .50293 .82407 .49588 Metetra
.657 .749 .918 r
.82407 .49588 .82945 .50293 .84234 .49912 .83701 .49204 Metetra
.657 .749 .918 r
.83701 .49204 .84234 .49912 .8553 .49529 .85 .48818 Metetra
.657 .749 .918 r
.85 .48818 .8553 .49529 .86831 .49145 .86305 .48431 Metetra
.657 .749 .918 r
.86305 .48431 .86831 .49145 .88138 .48759 .87617 .48042 Metetra
.657 .749 .918 r
.87617 .48042 .88138 .48759 .89451 .48371 .88934 .4765 Metetra
.657 .749 .918 r
.88934 .4765 .89451 .48371 .9077 .47981 .90257 .47258 Metetra
.657 .749 .918 r
.90257 .47258 .9077 .47981 .92094 .4759 .91586 .46863 Metetra
.657 .749 .918 r
.91586 .46863 .92094 .4759 .93425 .47197 .92921 .46467 Metetra
.657 .749 .918 r
.92921 .46467 .93425 .47197 .94762 .46802 .94262 .46068 Metetra
.657 .749 .918 r
.34316 .63067 .34994 .63666 .36084 .63342 .3541 .62741 Metetra
.657 .749 .918 r
.3541 .62741 .36084 .63342 .37179 .63017 .36508 .62413 Metetra
.657 .749 .918 r
.36508 .62413 .37179 .63017 .38279 .62691 .3761 .62085 Metetra
.657 .749 .918 r
.3761 .62085 .38279 .62691 .39383 .62363 .38717 .61754 Metetra
.657 .749 .918 r
.38717 .61754 .39383 .62363 .40492 .62034 .39829 .61422 Metetra
.657 .749 .918 r
.39829 .61422 .40492 .62034 .41605 .61703 .40945 .61089 Metetra
.657 .749 .918 r
.40945 .61089 .41605 .61703 .42723 .61371 .42066 .60755 Metetra
.657 .749 .918 r
.42066 .60755 .42723 .61371 .43846 .61038 .43191 .60419 Metetra
.657 .749 .918 r
.43191 .60419 .43846 .61038 .44973 .60703 .44321 .60082 Metetra
.657 .749 .918 r
.44321 .60082 .44973 .60703 .46105 .60367 .45456 .59743 Metetra
.657 .749 .918 r
.45456 .59743 .46105 .60367 .47242 .6003 .46596 .59403 Metetra
.657 .749 .918 r
.46596 .59403 .47242 .6003 .48383 .59691 .47741 .59061 Metetra
.657 .749 .918 r
.47741 .59061 .48383 .59691 .49529 .5935 .4889 .58718 Metetra
.657 .749 .918 r
.4889 .58718 .49529 .5935 .5068 .59009 .50044 .58374 Metetra
.657 .749 .918 r
.50044 .58374 .5068 .59009 .51836 .58665 .51203 .58028 Metetra
.657 .749 .918 r
.51203 .58028 .51836 .58665 .52997 .58321 .52367 .57681 Metetra
.657 .749 .918 r
.52367 .57681 .52997 .58321 .54163 .57975 .53536 .57332 Metetra
.657 .749 .918 r
.53536 .57332 .54163 .57975 .55334 .57627 .5471 .56981 Metetra
.657 .749 .918 r
.5471 .56981 .55334 .57627 .56509 .57278 .55889 .5663 Metetra
.657 .749 .918 r
.55889 .5663 .56509 .57278 .5769 .56927 .57073 .56276 Metetra
.657 .749 .918 r
.57073 .56276 .5769 .56927 .58876 .56575 .58262 .55921 Metetra
.657 .749 .918 r
.58262 .55921 .58876 .56575 .60066 .56222 .59456 .55565 Metetra
.657 .749 .918 r
.59456 .55565 .60066 .56222 .61262 .55867 .60656 .55207 Metetra
.657 .749 .918 r
.60656 .55207 .61262 .55867 .62463 .5551 .6186 .54848 Metetra
.657 .749 .918 r
.6186 .54848 .62463 .5551 .63669 .55152 .6307 .54487 Metetra
.657 .749 .918 r
.6307 .54487 .63669 .55152 .64881 .54792 .64285 .54124 Metetra
.657 .749 .918 r
.64285 .54124 .64881 .54792 .66097 .54431 .65505 .5376 Metetra
.657 .749 .918 r
.65505 .5376 .66097 .54431 .67319 .54068 .66731 .53394 Metetra
.657 .749 .918 r
.66731 .53394 .67319 .54068 .68547 .53704 .67961 .53027 Metetra
.657 .749 .918 r
.67961 .53027 .68547 .53704 .69779 .53338 .69198 .52658 Metetra
.657 .749 .918 r
.69198 .52658 .69779 .53338 .71017 .5297 .70439 .52287 Metetra
.657 .749 .918 r
.70439 .52287 .71017 .5297 .72261 .52601 .71687 .51915 Metetra
.657 .749 .918 r
.71687 .51915 .72261 .52601 .73509 .5223 .72939 .51541 Metetra
.657 .749 .918 r
.72939 .51541 .73509 .5223 .74764 .51858 .74197 .51166 Metetra
.657 .749 .918 r
.74197 .51166 .74764 .51858 .76024 .51484 .75461 .50789 Metetra
.657 .749 .918 r
.75461 .50789 .76024 .51484 .77289 .51108 .7673 .5041 Metetra
.657 .749 .918 r
.7673 .5041 .77289 .51108 .7856 .50731 .78005 .5003 Metetra
.657 .749 .918 r
.78005 .5003 .7856 .50731 .79837 .50352 .79286 .49647 Metetra
.657 .749 .918 r
.79286 .49647 .79837 .50352 .81119 .49971 .80572 .49264 Metetra
.657 .749 .918 r
.80572 .49264 .81119 .49971 .82407 .49588 .81864 .48878 Metetra
.657 .749 .918 r
.81864 .48878 .82407 .49588 .83701 .49204 .83162 .48491 Metetra
.657 .749 .918 r
.83162 .48491 .83701 .49204 .85 .48818 .84466 .48102 Metetra
.657 .749 .918 r
.84466 .48102 .85 .48818 .86305 .48431 .85776 .47711 Metetra
.657 .749 .918 r
.85776 .47711 .86305 .48431 .87617 .48042 .87091 .47318 Metetra
.657 .749 .918 r
.87091 .47318 .87617 .48042 .88934 .4765 .88412 .46924 Metetra
.657 .749 .918 r
.88412 .46924 .88934 .4765 .90257 .47258 .8974 .46528 Metetra
.657 .749 .918 r
.8974 .46528 .90257 .47258 .91586 .46863 .91073 .4613 Metetra
.657 .749 .918 r
.91073 .4613 .91586 .46863 .92921 .46467 .92413 .4573 Metetra
.657 .749 .918 r
.92413 .4573 .92921 .46467 .94262 .46068 .93758 .45328 Metetra
.657 .749 .918 r
.33634 .62464 .34316 .63067 .3541 .62741 .3473 .62135 Metetra
.657 .749 .918 r
.3473 .62135 .3541 .62741 .36508 .62413 .3583 .61805 Metetra
.657 .749 .918 r
.3583 .61805 .36508 .62413 .3761 .62085 .36936 .61474 Metetra
.657 .749 .918 r
.36936 .61474 .3761 .62085 .38717 .61754 .38045 .61141 Metetra
.657 .749 .918 r
.38045 .61141 .38717 .61754 .39829 .61422 .3916 .60806 Metetra
.657 .749 .918 r
.3916 .60806 .39829 .61422 .40945 .61089 .40279 .60471 Metetra
.657 .749 .918 r
.40279 .60471 .40945 .61089 .42066 .60755 .41403 .60134 Metetra
.657 .749 .918 r
.41403 .60134 .42066 .60755 .43191 .60419 .42531 .59795 Metetra
.657 .749 .918 r
.42531 .59795 .43191 .60419 .44321 .60082 .43665 .59455 Metetra
.657 .749 .918 r
.43665 .59455 .44321 .60082 .45456 .59743 .44803 .59114 Metetra
.657 .749 .918 r
.44803 .59114 .45456 .59743 .46596 .59403 .45945 .58771 Metetra
.657 .749 .918 r
.45945 .58771 .46596 .59403 .47741 .59061 .47093 .58427 Metetra
.657 .749 .918 r
.47093 .58427 .47741 .59061 .4889 .58718 .48245 .58081 Metetra
.657 .749 .918 r
.48245 .58081 .4889 .58718 .50044 .58374 .49403 .57734 Metetra
.657 .749 .918 r
.49403 .57734 .50044 .58374 .51203 .58028 .50565 .57386 Metetra
.657 .749 .918 r
.50565 .57386 .51203 .58028 .52367 .57681 .51732 .57035 Metetra
.657 .749 .918 r
.51732 .57035 .52367 .57681 .53536 .57332 .52904 .56684 Metetra
.657 .749 .918 r
.52904 .56684 .53536 .57332 .5471 .56981 .54082 .56331 Metetra
.657 .749 .918 r
.54082 .56331 .5471 .56981 .55889 .5663 .55264 .55976 Metetra
.657 .749 .918 r
.55264 .55976 .55889 .5663 .57073 .56276 .56451 .5562 Metetra
.657 .749 .918 r
.56451 .5562 .57073 .56276 .58262 .55921 .57644 .55262 Metetra
.657 .749 .918 r
.57644 .55262 .58262 .55921 .59456 .55565 .58841 .54903 Metetra
.657 .749 .918 r
.58841 .54903 .59456 .55565 .60656 .55207 .60044 .54542 Metetra
.657 .749 .918 r
.60044 .54542 .60656 .55207 .6186 .54848 .61252 .5418 Metetra
.657 .749 .918 r
.61252 .5418 .6186 .54848 .6307 .54487 .62465 .53816 Metetra
.657 .749 .918 r
.62465 .53816 .6307 .54487 .64285 .54124 .63684 .53451 Metetra
.657 .749 .918 r
.63684 .53451 .64285 .54124 .65505 .5376 .64908 .53084 Metetra
.657 .749 .918 r
.64908 .53084 .65505 .5376 .66731 .53394 .66137 .52715 Metetra
.657 .749 .918 r
.66137 .52715 .66731 .53394 .67961 .53027 .67371 .52345 Metetra
.657 .749 .918 r
.67371 .52345 .67961 .53027 .69198 .52658 .68611 .51973 Metetra
.657 .749 .918 r
.68611 .51973 .69198 .52658 .70439 .52287 .69857 .51599 Metetra
.657 .749 .918 r
.69857 .51599 .70439 .52287 .71687 .51915 .71108 .51224 Metetra
.657 .749 .918 r
.71108 .51224 .71687 .51915 .72939 .51541 .72364 .50847 Metetra
.657 .749 .918 r
.72364 .50847 .72939 .51541 .74197 .51166 .73626 .50468 Metetra
.657 .749 .918 r
.73626 .50468 .74197 .51166 .75461 .50789 .74894 .50088 Metetra
.657 .749 .918 r
.74894 .50088 .75461 .50789 .7673 .5041 .76167 .49706 Metetra
.657 .749 .918 r
.76167 .49706 .7673 .5041 .78005 .5003 .77446 .49323 Metetra
.657 .749 .918 r
.77446 .49323 .78005 .5003 .79286 .49647 .78731 .48937 Metetra
.657 .749 .918 r
.78731 .48937 .79286 .49647 .80572 .49264 .80021 .4855 Metetra
.657 .749 .918 r
.80021 .4855 .80572 .49264 .81864 .48878 .81317 .48162 Metetra
.657 .749 .918 r
.81317 .48162 .81864 .48878 .83162 .48491 .82619 .47771 Metetra
.657 .749 .918 r
.82619 .47771 .83162 .48491 .84466 .48102 .83927 .47379 Metetra
.657 .749 .918 r
.83927 .47379 .84466 .48102 .85776 .47711 .85241 .46985 Metetra
.657 .749 .918 r
.85241 .46985 .85776 .47711 .87091 .47318 .86561 .46589 Metetra
.657 .749 .918 r
.86561 .46589 .87091 .47318 .88412 .46924 .87887 .46191 Metetra
.657 .749 .918 r
.87887 .46191 .88412 .46924 .8974 .46528 .89219 .45792 Metetra
.657 .749 .918 r
.89219 .45792 .8974 .46528 .91073 .4613 .90556 .4539 Metetra
.657 .749 .918 r
.90556 .4539 .91073 .4613 .92413 .4573 .919 .44987 Metetra
.657 .749 .918 r
.919 .44987 .92413 .4573 .93758 .45328 .93251 .44582 Metetra
.657 .749 .918 r
.32946 .61856 .33634 .62464 .3473 .62135 .34045 .61525 Metetra
.657 .749 .918 r
.34045 .61525 .3473 .62135 .3583 .61805 .35148 .61192 Metetra
.657 .749 .918 r
.35148 .61192 .3583 .61805 .36936 .61474 .36256 .60858 Metetra
.657 .749 .918 r
.36256 .60858 .36936 .61474 .38045 .61141 .37369 .60522 Metetra
.657 .749 .918 r
.37369 .60522 .38045 .61141 .3916 .60806 .38486 .60186 Metetra
.657 .749 .918 r
.38486 .60186 .3916 .60806 .40279 .60471 .39608 .59847 Metetra
.657 .749 .918 r
.39608 .59847 .40279 .60471 .41403 .60134 .40735 .59508 Metetra
.657 .749 .918 r
.40735 .59508 .41403 .60134 .42531 .59795 .41866 .59167 Metetra
.657 .749 .918 r
.41866 .59167 .42531 .59795 .43665 .59455 .43003 .58824 Metetra
.657 .749 .918 r
.43003 .58824 .43665 .59455 .44803 .59114 .44144 .5848 Metetra
.657 .749 .918 r
.44144 .5848 .44803 .59114 .45945 .58771 .45289 .58135 Metetra
.657 .749 .918 r
.45289 .58135 .45945 .58771 .47093 .58427 .4644 .57788 Metetra
.657 .749 .918 r
.4644 .57788 .47093 .58427 .48245 .58081 .47596 .57439 Metetra
.657 .749 .918 r
.47596 .57439 .48245 .58081 .49403 .57734 .48756 .57089 Metetra
.657 .749 .918 r
.48756 .57089 .49403 .57734 .50565 .57386 .49922 .56738 Metetra
.657 .749 .918 r
.49922 .56738 .50565 .57386 .51732 .57035 .51092 .56385 Metetra
.657 .749 .918 r
.51092 .56385 .51732 .57035 .52904 .56684 .52268 .56031 Metetra
.657 .749 .918 r
.52268 .56031 .52904 .56684 .54082 .56331 .53448 .55675 Metetra
.657 .749 .918 r
.53448 .55675 .54082 .56331 .55264 .55976 .54634 .55317 Metetra
.657 .749 .918 r
.54634 .55317 .55264 .55976 .56451 .5562 .55825 .54958 Metetra
.657 .749 .918 r
.55825 .54958 .56451 .5562 .57644 .55262 .5702 .54598 Metetra
.657 .749 .918 r
.5702 .54598 .57644 .55262 .58841 .54903 .58221 .54236 Metetra
.657 .749 .918 r
.58221 .54236 .58841 .54903 .60044 .54542 .59428 .53872 Metetra
.657 .749 .918 r
.59428 .53872 .60044 .54542 .61252 .5418 .60639 .53507 Metetra
.657 .749 .918 r
.60639 .53507 .61252 .5418 .62465 .53816 .61856 .5314 Metetra
.657 .749 .918 r
.61856 .5314 .62465 .53816 .63684 .53451 .63078 .52772 Metetra
.657 .749 .918 r
.63078 .52772 .63684 .53451 .64908 .53084 .64306 .52402 Metetra
.657 .749 .918 r
.64306 .52402 .64908 .53084 .66137 .52715 .65538 .5203 Metetra
.657 .749 .918 r
.65538 .5203 .66137 .52715 .67371 .52345 .66777 .51657 Metetra
.657 .749 .918 r
.66777 .51657 .67371 .52345 .68611 .51973 .6802 .51282 Metetra
.657 .749 .918 r
.6802 .51282 .68611 .51973 .69857 .51599 .6927 .50905 Metetra
.657 .749 .918 r
.6927 .50905 .69857 .51599 .71108 .51224 .70524 .50527 Metetra
.657 .749 .918 r
.70524 .50527 .71108 .51224 .72364 .50847 .71785 .50147 Metetra
.657 .749 .918 r
.71785 .50147 .72364 .50847 .73626 .50468 .73051 .49765 Metetra
.657 .749 .918 r
.73051 .49765 .73626 .50468 .74894 .50088 .74322 .49382 Metetra
.657 .749 .918 r
.74322 .49382 .74894 .50088 .76167 .49706 .75599 .48997 Metetra
.657 .749 .918 r
.75599 .48997 .76167 .49706 .77446 .49323 .76882 .4861 Metetra
.657 .749 .918 r
.76882 .4861 .77446 .49323 .78731 .48937 .78171 .48221 Metetra
.657 .749 .918 r
.78171 .48221 .78731 .48937 .80021 .4855 .79466 .47831 Metetra
.657 .749 .918 r
.79466 .47831 .80021 .4855 .81317 .48162 .80766 .47439 Metetra
.657 .749 .918 r
.80766 .47439 .81317 .48162 .82619 .47771 .82072 .47045 Metetra
.657 .749 .918 r
.82072 .47045 .82619 .47771 .83927 .47379 .83384 .4665 Metetra
.657 .749 .918 r
.83384 .4665 .83927 .47379 .85241 .46985 .84702 .46252 Metetra
.657 .749 .918 r
.84702 .46252 .85241 .46985 .86561 .46589 .86027 .45853 Metetra
.657 .749 .918 r
.86027 .45853 .86561 .46589 .87887 .46191 .87357 .45452 Metetra
.657 .749 .918 r
.87357 .45452 .87887 .46191 .89219 .45792 .88693 .45049 Metetra
.657 .749 .918 r
.88693 .45049 .89219 .45792 .90556 .4539 .90035 .44645 Metetra
.657 .749 .918 r
.90035 .44645 .90556 .4539 .919 .44987 .91384 .44238 Metetra
.657 .749 .918 r
.91384 .44238 .919 .44987 .93251 .44582 .92738 .4383 Metetra
.652 .748 .92 r
.32253 .61243 .32946 .61856 .34045 .61525 .33353 .60924 Metetra
.665 .756 .918 r
.33353 .60924 .34045 .61525 .35148 .61192 .34461 .60566 Metetra
.682 .753 .905 r
.34461 .60566 .35148 .61192 .36256 .60858 .35575 .60157 Metetra
.689 .733 .884 r
.35575 .60157 .36256 .60858 .37369 .60522 .36696 .59714 Metetra
.689 .706 .861 r
.36696 .59714 .37369 .60522 .38486 .60186 .3782 .59251 Metetra
.685 .678 .838 r
.3782 .59251 .38486 .60186 .39608 .59847 .3895 .58782 Metetra
.678 .652 .817 r
.3895 .58782 .39608 .59847 .40735 .59508 .40082 .58314 Metetra
.67 .629 .8 r
.40082 .58314 .40735 .59508 .41866 .59167 .41219 .57855 Metetra
.662 .61 .785 r
.41219 .57855 .41866 .59167 .43003 .58824 .42359 .57408 Metetra
.655 .594 .774 r
.42359 .57408 .43003 .58824 .44144 .5848 .43503 .56977 Metetra
.649 .582 .766 r
.43503 .56977 .44144 .5848 .45289 .58135 .4465 .56564 Metetra
.644 .573 .76 r
.4465 .56564 .45289 .58135 .4644 .57788 .45802 .56168 Metetra
.639 .566 .756 r
.45802 .56168 .4644 .57788 .47596 .57439 .46958 .55788 Metetra
.636 .562 .754 r
.46958 .55788 .47596 .57439 .48756 .57089 .48118 .55423 Metetra
.633 .559 .754 r
.48118 .55423 .48756 .57089 .49922 .56738 .49283 .55071 Metetra
.631 .559 .754 r
.49283 .55071 .49922 .56738 .51092 .56385 .50453 .54728 Metetra
.63 .559 .756 r
.50453 .54728 .51092 .56385 .52268 .56031 .51628 .54393 Metetra
.63 .561 .759 r
.51628 .54393 .52268 .56031 .53448 .55675 .52809 .54061 Metetra
.63 .564 .762 r
.52809 .54061 .53448 .55675 .54634 .55317 .53995 .53731 Metetra
.631 .568 .765 r
.53995 .53731 .54634 .55317 .55825 .54958 .55186 .53399 Metetra
.632 .571 .768 r
.55186 .53399 .55825 .54958 .5702 .54598 .56382 .53063 Metetra
.634 .575 .771 r
.56382 .53063 .5702 .54598 .58221 .54236 .57584 .5272 Metetra
.636 .579 .773 r
.57584 .5272 .58221 .54236 .59428 .53872 .58791 .52369 Metetra
.638 .581 .775 r
.58791 .52369 .59428 .53872 .60639 .53507 .60003 .5201 Metetra
.639 .583 .776 r
.60003 .5201 .60639 .53507 .61856 .5314 .6122 .5164 Metetra
.641 .584 .775 r
.6122 .5164 .61856 .5314 .63078 .52772 .62443 .5126 Metetra
.642 .584 .774 r
.62443 .5126 .63078 .52772 .64306 .52402 .6367 .50871 Metetra
.643 .583 .772 r
.6367 .50871 .64306 .52402 .65538 .5203 .64903 .50473 Metetra
.643 .581 .77 r
.64903 .50473 .65538 .5203 .66777 .51657 .6614 .50069 Metetra
.642 .578 .767 r
.6614 .50069 .66777 .51657 .6802 .51282 .67383 .49659 Metetra
.642 .574 .763 r
.67383 .49659 .6802 .51282 .6927 .50905 .68631 .49247 Metetra
.64 .57 .76 r
.68631 .49247 .6927 .50905 .70524 .50527 .69884 .48835 Metetra
.639 .567 .757 r
.69884 .48835 .70524 .50527 .71785 .50147 .71143 .48426 Metetra
.637 .563 .755 r
.71143 .48426 .71785 .50147 .73051 .49765 .72408 .48023 Metetra
.635 .561 .754 r
.72408 .48023 .73051 .49765 .74322 .49382 .73679 .47629 Metetra
.632 .559 .754 r
.73679 .47629 .74322 .49382 .75599 .48997 .74956 .47248 Metetra
.63 .558 .755 r
.74956 .47248 .75599 .48997 .76882 .4861 .76241 .46881 Metetra
.628 .559 .758 r
.76241 .46881 .76882 .4861 .78171 .48221 .77533 .4653 Metetra
.626 .562 .763 r
.77533 .4653 .78171 .48221 .79466 .47831 .78832 .46197 Metetra
.624 .567 .77 r
.78832 .46197 .79466 .47831 .80766 .47439 .8014 .45882 Metetra
.622 .575 .78 r
.8014 .45882 .80766 .47439 .82072 .47045 .81456 .45584 Metetra
.621 .586 .793 r
.81456 .45584 .82072 .47045 .83384 .4665 .8278 .453 Metetra
.621 .601 .809 r
.8278 .453 .83384 .4665 .84702 .46252 .84112 .45027 Metetra
.621 .621 .829 r
.84112 .45027 .84702 .46252 .86027 .45853 .85452 .44757 Metetra
.623 .646 .852 r
.85452 .44757 .86027 .45853 .87357 .45452 .86799 .44483 Metetra
.627 .676 .877 r
.86799 .44483 .87357 .45452 .88693 .45049 .88151 .44192 Metetra
.634 .708 .9 r
.88151 .44192 .88693 .45049 .90035 .44645 .89507 .4387 Metetra
.646 .738 .916 r
.89507 .4387 .90035 .44645 .91384 .44238 .90864 .43498 Metetra
.662 .756 .92 r
.90864 .43498 .91384 .44238 .92738 .4383 .92222 .43071 Metetra
.654 .749 .919 r
.31554 .60626 .32253 .61243 .33353 .60924 .32658 .60299 Metetra
.669 .751 .912 r
.32658 .60299 .33353 .60924 .34461 .60566 .33769 .59928 Metetra
.705 .755 .891 r
.33769 .59928 .34461 .60566 .35575 .60157 .34891 .59435 Metetra
.719 .736 .864 r
.34891 .59435 .35575 .60157 .36696 .59714 .3602 .58862 Metetra
.72 .706 .837 r
.3602 .58862 .36696 .59714 .3782 .59251 .37154 .58245 Metetra
.712 .675 .812 r
.37154 .58245 .3782 .59251 .3895 .58782 .38292 .5761 Metetra
.7 .645 .791 r
.38292 .5761 .3895 .58782 .40082 .58314 .39432 .5698 Metetra
.688 .619 .774 r
.39432 .5698 .40082 .58314 .41219 .57855 .40575 .5637 Metetra
.675 .597 .76 r
.40575 .5637 .41219 .57855 .42359 .57408 .41719 .55791 Metetra
.664 .579 .749 r
.41719 .55791 .42359 .57408 .43503 .56977 .42866 .5525 Metetra
.654 .564 .742 r
.42866 .5525 .43503 .56977 .4465 .56564 .44015 .5475 Metetra
.645 .553 .736 r
.44015 .5475 .4465 .56564 .45802 .56168 .45167 .54292 Metetra
.637 .544 .733 r
.45167 .54292 .45802 .56168 .46958 .55788 .46323 .53873 Metetra
.631 .538 .731 r
.46323 .53873 .46958 .55788 .48118 .55423 .47482 .53491 Metetra
.626 .535 .731 r
.47482 .53491 .48118 .55423 .49283 .55071 .48646 .53139 Metetra
.622 .533 .732 r
.48646 .53139 .49283 .55071 .50453 .54728 .49815 .52811 Metetra
.62 .533 .734 r
.49815 .52811 .50453 .54728 .51628 .54393 .50989 .52502 Metetra
.619 .534 .737 r
.50989 .52502 .51628 .54393 .52809 .54061 .52168 .52204 Metetra
.618 .537 .74 r
.52168 .52204 .52809 .54061 .53995 .53731 .53353 .51911 Metetra
.619 .541 .744 r
.53353 .51911 .53995 .53731 .55186 .53399 .54544 .51615 Metetra
.621 .545 .747 r
.54544 .51615 .55186 .53399 .56382 .53063 .5574 .51312 Metetra
.624 .55 .751 r
.5574 .51312 .56382 .53063 .57584 .5272 .56942 .50996 Metetra
.627 .554 .753 r
.56942 .50996 .57584 .5272 .58791 .52369 .58149 .50664 Metetra
.63 .558 .755 r
.58149 .50664 .58791 .52369 .60003 .5201 .59361 .50312 Metetra
.634 .561 .755 r
.59361 .50312 .60003 .5201 .6122 .5164 .60578 .4994 Metetra
.637 .563 .755 r
.60578 .4994 .6122 .5164 .62443 .5126 .618 .49547 Metetra
.639 .563 .753 r
.618 .49547 .62443 .5126 .6367 .50871 .63027 .49133 Metetra
.641 .562 .751 r
.63027 .49133 .6367 .50871 .64903 .50473 .64258 .48702 Metetra
.642 .56 .747 r
.64258 .48702 .64903 .50473 .6614 .50069 .65494 .48257 Metetra
.642 .557 .744 r
.65494 .48257 .6614 .50069 .67383 .49659 .66734 .47803 Metetra
.641 .554 .741 r
.66734 .47803 .67383 .49659 .68631 .49247 .67979 .47344 Metetra
.639 .549 .737 r
.67979 .47344 .68631 .49247 .69884 .48835 .6923 .46889 Metetra
.637 .545 .734 r
.6923 .46889 .69884 .48835 .71143 .48426 .70486 .46442 Metetra
.633 .541 .732 r
.70486 .46442 .71143 .48426 .72408 .48023 .71748 .46012 Metetra
.629 .537 .731 r
.71748 .46012 .72408 .48023 .73679 .47629 .73017 .45605 Metetra
.625 .534 .731 r
.73017 .45605 .73679 .47629 .74956 .47248 .74294 .45228 Metetra
.62 .532 .733 r
.74294 .45228 .74956 .47248 .76241 .46881 .7558 .44886 Metetra
.615 .531 .736 r
.7558 .44886 .76241 .46881 .77533 .4653 .76874 .44584 Metetra
.609 .531 .742 r
.76874 .44584 .77533 .4653 .78832 .46197 .78179 .44325 Metetra
.603 .534 .75 r
.78179 .44325 .78832 .46197 .8014 .45882 .79495 .4411 Metetra
.598 .54 .761 r
.79495 .4411 .8014 .45882 .81456 .45584 .80821 .43935 Metetra
.592 .549 .776 r
.80821 .43935 .81456 .45584 .8278 .453 .82159 .43796 Metetra
.587 .563 .795 r
.82159 .43796 .8278 .453 .84112 .45027 .83508 .43681 Metetra
.583 .583 .818 r
.83508 .43681 .84112 .45027 .85452 .44757 .84866 .43576 Metetra
.583 .611 .846 r
.84866 .43576 .85452 .44757 .86799 .44483 .86232 .43461 Metetra
.588 .646 .876 r
.86232 .43461 .86799 .44483 .88151 .44192 .87602 .43307 Metetra
.604 .689 .902 r
.87602 .43307 .88151 .44192 .89507 .4387 .88973 .4308 Metetra
.636 .731 .917 r
.88973 .4308 .89507 .4387 .90864 .43498 .90339 .42737 Metetra
.662 .752 .917 r
.90339 .42737 .90864 .43498 .92222 .43071 .91701 .42305 Metetra
.657 .749 .918 r
.3085 .60004 .31554 .60626 .32658 .60299 .31958 .59665 Metetra
.669 .749 .91 r
.31958 .59665 .32658 .60299 .33769 .59928 .33071 .59291 Metetra
.721 .759 .883 r
.33071 .59291 .33769 .59928 .34891 .59435 .342 .5873 Metetra
.745 .746 .853 r
.342 .5873 .34891 .59435 .3602 .58862 .35338 .58039 Metetra
.748 .72 .826 r
.35338 .58039 .3602 .58862 .37154 .58245 .36482 .57273 Metetra
.74 .69 .803 r
.36482 .57273 .37154 .58245 .38292 .5761 .37629 .56478 Metetra
.727 .661 .785 r
.37629 .56478 .38292 .5761 .39432 .5698 .38777 .55688 Metetra
.712 .635 .77 r
.38777 .55688 .39432 .5698 .40575 .5637 .39927 .54929 Metetra
.696 .612 .758 r
.39927 .54929 .40575 .5637 .41719 .55791 .41077 .5422 Metetra
.681 .592 .749 r
.41077 .5422 .41719 .55791 .42866 .5525 .42227 .5357 Metetra
.667 .576 .743 r
.42227 .5357 .42866 .5525 .44015 .5475 .43378 .52985 Metetra
.654 .562 .739 r
.43378 .52985 .44015 .5475 .45167 .54292 .44531 .52466 Metetra
.643 .552 .736 r
.44531 .52466 .45167 .54292 .46323 .53873 .45687 .5201 Metetra
.634 .544 .735 r
.45687 .5201 .46323 .53873 .47482 .53491 .46846 .51612 Metetra
.626 .539 .736 r
.46846 .51612 .47482 .53491 .48646 .53139 .48009 .51262 Metetra
.62 .536 .737 r
.48009 .51262 .48646 .53139 .49815 .52811 .49176 .50953 Metetra
.616 .535 .74 r
.49176 .50953 .49815 .52811 .50989 .52502 .50349 .50672 Metetra
.613 .536 .743 r
.50349 .50672 .50989 .52502 .52168 .52204 .51527 .5041 Metetra
.613 .539 .747 r
.51527 .5041 .52168 .52204 .53353 .51911 .52711 .50156 Metetra
.614 .543 .751 r
.52711 .50156 .53353 .51911 .54544 .51615 .53901 .49899 Metetra
.616 .548 .755 r
.53901 .49899 .54544 .51615 .5574 .51312 .55097 .49631 Metetra
.62 .554 .759 r
.55097 .49631 .5574 .51312 .56942 .50996 .56299 .49344 Metetra
.625 .56 .761 r
.56299 .49344 .56942 .50996 .58149 .50664 .57506 .49031 Metetra
.63 .565 .763 r
.57506 .49031 .58149 .50664 .59361 .50312 .58719 .48688 Metetra
.635 .569 .763 r
.58719 .48688 .59361 .50312 .60578 .4994 .59936 .48313 Metetra
.641 .572 .762 r
.59936 .48313 .60578 .4994 .618 .49547 .61158 .47905 Metetra
.645 .573 .76 r
.61158 .47905 .618 .49547 .63027 .49133 .62384 .47467 Metetra
.648 .573 .757 r
.62384 .47467 .63027 .49133 .64258 .48702 .63614 .47001 Metetra
.65 .571 .753 r
.63614 .47001 .64258 .48702 .65494 .48257 .64849 .46514 Metetra
.65 .568 .749 r
.64849 .46514 .65494 .48257 .66734 .47803 .66087 .46013 Metetra
.649 .564 .745 r
.66087 .46013 .66734 .47803 .67979 .47344 .6733 .45506 Metetra
.647 .559 .741 r
.6733 .45506 .67979 .47344 .6923 .46889 .68578 .45004 Metetra
.643 .554 .738 r
.68578 .45004 .6923 .46889 .70486 .46442 .69832 .44517 Metetra
.638 .548 .736 r
.69832 .44517 .70486 .46442 .71748 .46012 .71092 .44058 Metetra
.632 .543 .735 r
.71092 .44058 .71748 .46012 .73017 .45605 .72359 .43635 Metetra
.625 .538 .736 r
.72359 .43635 .73017 .45605 .74294 .45228 .73636 .4326 Metetra
.617 .534 .738 r
.73636 .4326 .74294 .45228 .7558 .44886 .74922 .42943 Metetra
.608 .531 .742 r
.74922 .42943 .7558 .44886 .76874 .44584 .76219 .42689 Metetra
.598 .529 .748 r
.76219 .42689 .76874 .44584 .78179 .44325 .77529 .42502 Metetra
.587 .529 .757 r
.77529 .42502 .78179 .44325 .79495 .4411 .78852 .42385 Metetra
.575 .532 .769 r
.78852 .42385 .79495 .4411 .80821 .43935 .80189 .42332 Metetra
.563 .538 .785 r
.80189 .42332 .80821 .43935 .82159 .43796 .8154 .42335 Metetra
.551 .55 .806 r
.8154 .42335 .82159 .43796 .83508 .43681 .82905 .42376 Metetra
.542 .568 .831 r
.82905 .42376 .83508 .43681 .84866 .43576 .84281 .42432 Metetra
.538 .595 .859 r
.84281 .42432 .84866 .43576 .86232 .43461 .85665 .42469 Metetra
.546 .633 .889 r
.85665 .42469 .86232 .43461 .87602 .43307 .87052 .42442 Metetra
.576 .682 .913 r
.87052 .42442 .87602 .43307 .88973 .4308 .88436 .42294 Metetra
.633 .733 .92 r
.88436 .42294 .88973 .4308 .90339 .42737 .89807 .41956 Metetra
.659 .746 .915 r
.89807 .41956 .90339 .42737 .91701 .42305 .91175 .41533 Metetra
.657 .749 .918 r
.30141 .59377 .3085 .60004 .31958 .59665 .31251 .59035 Metetra
.668 .752 .913 r
.31251 .59035 .31958 .59665 .33071 .59291 .32368 .5866 Metetra
.732 .765 .879 r
.32368 .5866 .33071 .59291 .342 .5873 .33502 .58053 Metetra
.765 .757 .845 r
.33502 .58053 .342 .5873 .35338 .58039 .34649 .57257 Metetra
.772 .734 .818 r
.34649 .57257 .35338 .58039 .36482 .57273 .35803 .56353 Metetra
.765 .706 .797 r
.35803 .56353 .36482 .57273 .37629 .56478 .3696 .55403 Metetra
.752 .679 .78 r
.3696 .55403 .37629 .56478 .38777 .55688 .38117 .54459 Metetra
.735 .652 .768 r
.38117 .54459 .38777 .55688 .39927 .54929 .39274 .53555 Metetra
.717 .628 .758 r
.39274 .53555 .39927 .54929 .41077 .5422 .4043 .52717 Metetra
.698 .607 .751 r
.4043 .52717 .41077 .5422 .42227 .5357 .41584 .5196 Metetra
.681 .589 .746 r
.41584 .5196 .42227 .5357 .43378 .52985 .42738 .51293 Metetra
.665 .574 .743 r
.42738 .51293 .43378 .52985 .44531 .52466 .43893 .50716 Metetra
.65 .562 .741 r
.43893 .50716 .44531 .52466 .45687 .5201 .45049 .50226 Metetra
.638 .552 .742 r
.45049 .50226 .45687 .5201 .46846 .51612 .46207 .49815 Metetra
.627 .545 .743 r
.46207 .49815 .46846 .51612 .48009 .51262 .47369 .49471 Metetra
.618 .541 .746 r
.47369 .49471 .48009 .51262 .49176 .50953 .48535 .49183 Metetra
.612 .54 .749 r
.48535 .49183 .49176 .50953 .50349 .50672 .49707 .48935 Metetra
.607 .541 .754 r
.49707 .48935 .50349 .50672 .51527 .5041 .50884 .48712 Metetra
.606 .544 .758 r
.50884 .48712 .51527 .5041 .52711 .50156 .52068 .485 Metetra
.607 .549 .763 r
.52068 .485 .52711 .50156 .53901 .49899 .53258 .48285 Metetra
.61 .555 .768 r
.53258 .48285 .53901 .49899 .55097 .49631 .54454 .48055 Metetra
.616 .562 .772 r
.54454 .48055 .55097 .49631 .56299 .49344 .55656 .47798 Metetra
.623 .57 .774 r
.55656 .47798 .56299 .49344 .57506 .49031 .56864 .47506 Metetra
.63 .577 .776 r
.56864 .47506 .57506 .49031 .58719 .48688 .58077 .47173 Metetra
.638 .582 .775 r
.58077 .47173 .58719 .48688 .59936 .48313 .59295 .46796 Metetra
.646 .587 .774 r
.59295 .46796 .59936 .48313 .61158 .47905 .60517 .46374 Metetra
.652 .589 .771 r
.60517 .46374 .61158 .47905 .62384 .47467 .61743 .45909 Metetra
.657 .589 .767 r
.61743 .45909 .62384 .47467 .63614 .47001 .62973 .45407 Metetra
.66 .587 .762 r
.62973 .45407 .63614 .47001 .64849 .46514 .64206 .44875 Metetra
.661 .583 .757 r
.64206 .44875 .64849 .46514 .66087 .46013 .65443 .44324 Metetra
.66 .579 .753 r
.65443 .44324 .66087 .46013 .6733 .45506 .66684 .43766 Metetra
.657 .573 .749 r
.66684 .43766 .6733 .45506 .68578 .45004 .6793 .43214 Metetra
.652 .566 .745 r
.6793 .43214 .68578 .45004 .69832 .44517 .69182 .42684 Metetra
.645 .559 .743 r
.69182 .42684 .69832 .44517 .71092 .44058 .7044 .42191 Metetra
.637 .552 .742 r
.7044 .42191 .71092 .44058 .72359 .43635 .71706 .4175 Metetra
.626 .545 .743 r
.71706 .4175 .72359 .43635 .73636 .4326 .72982 .41375 Metetra
.615 .539 .746 r
.72982 .41375 .73636 .4326 .74922 .42943 .74269 .41078 Metetra
.601 .533 .75 r
.74269 .41078 .74922 .42943 .76219 .42689 .75569 .40869 Metetra
.586 .529 .757 r
.75569 .40869 .76219 .42689 .77529 .42502 .76884 .40753 Metetra
.569 .526 .767 r
.76884 .40753 .77529 .42502 .78852 .42385 .78214 .40731 Metetra
.55 .525 .781 r
.78214 .40731 .78852 .42385 .80189 .42332 .79561 .40797 Metetra
.53 .528 .798 r
.79561 .40797 .80189 .42332 .8154 .42335 .80925 .40938 Metetra
.509 .536 .819 r
.80925 .40938 .8154 .42335 .82905 .42376 .82305 .41131 Metetra
.492 .552 .845 r
.82305 .41131 .82905 .42376 .84281 .42432 .83698 .41342 Metetra
.485 .579 .874 r
.83698 .41342 .84281 .42432 .85665 .42469 .85099 .41522 Metetra
.499 .622 .903 r
.85099 .41522 .85665 .42469 .87052 .42442 .86502 .41608 Metetra
.549 .68 .925 r
.86502 .41608 .87052 .42442 .88436 .42294 .87897 .41521 Metetra
.633 .738 .924 r
.87897 .41521 .88436 .42294 .89807 .41956 .89272 .41177 Metetra
.657 .748 .917 r
.89272 .41177 .89807 .41956 .91175 .41533 .90645 .40755 Metetra
.657 .749 .918 r
.29426 .58745 .30141 .59377 .31251 .59035 .30539 .584 Metetra
.662 .751 .916 r
.30539 .584 .31251 .59035 .32368 .5866 .31657 .58042 Metetra
.738 .77 .879 r
.31657 .58042 .32368 .5866 .33502 .58053 .32796 .57412 Metetra
.782 .768 .84 r
.32796 .57412 .33502 .58053 .34649 .57257 .33952 .56529 Metetra
.793 .749 .812 r
.33952 .56529 .34649 .57257 .35803 .56353 .35116 .55498 Metetra
.788 .724 .792 r
.35116 .55498 .35803 .56353 .3696 .55403 .36283 .54403 Metetra
.775 .697 .777 r
.36283 .54403 .3696 .55403 .38117 .54459 .37451 .5331 Metetra
.757 .671 .767 r
.37451 .5331 .38117 .54459 .39274 .53555 .38616 .52266 Metetra
.737 .647 .759 r
.38616 .52266 .39274 .53555 .4043 .52717 .39778 .51304 Metetra
.717 .625 .754 r
.39778 .51304 .4043 .52717 .41584 .5196 .40937 .50445 Metetra
.696 .606 .751 r
.40937 .50445 .41584 .5196 .42738 .51293 .42094 .49699 Metetra
.677 .589 .75 r
.42094 .49699 .42738 .51293 .43893 .50716 .4325 .49068 Metetra
.658 .575 .75 r
.4325 .49068 .43893 .50716 .45049 .50226 .44407 .48547 Metetra
.642 .563 .751 r
.44407 .48547 .45049 .50226 .46207 .49815 .45565 .48128 Metetra
.627 .555 .754 r
.45565 .48128 .46207 .49815 .47369 .49471 .46727 .47794 Metetra
.615 .55 .758 r
.46727 .47794 .47369 .49471 .48535 .49183 .47892 .47531 Metetra
.606 .548 .763 r
.47892 .47531 .48535 .49183 .49707 .48935 .49063 .47319 Metetra
.6 .549 .768 r
.49063 .47319 .49707 .48935 .50884 .48712 .5024 .4714 Metetra
.598 .552 .775 r
.5024 .4714 .50884 .48712 .52068 .485 .51423 .46975 Metetra
.599 .558 .781 r
.51423 .46975 .52068 .485 .53258 .48285 .52613 .46806 Metetra
.603 .567 .786 r
.52613 .46806 .53258 .48285 .54454 .48055 .53809 .46616 Metetra
.611 .576 .791 r
.53809 .46616 .54454 .48055 .55656 .47798 .55012 .46393 Metetra
.62 .586 .793 r
.55012 .46393 .55656 .47798 .56864 .47506 .56221 .46124 Metetra
.631 .595 .795 r
.56221 .46124 .56864 .47506 .58077 .47173 .57435 .45802 Metetra
.643 .603 .794 r
.57435 .45802 .58077 .47173 .59295 .46796 .58654 .45422 Metetra
.653 .608 .791 r
.58654 .45422 .59295 .46796 .60517 .46374 .59877 .44984 Metetra
.662 .611 .787 r
.59877 .44984 .60517 .46374 .61743 .45909 .61104 .44492 Metetra
.669 .611 .781 r
.61104 .44492 .61743 .45909 .62973 .45407 .62334 .43951 Metetra
.673 .609 .775 r
.62334 .43951 .62973 .45407 .64206 .44875 .63567 .43372 Metetra
.675 .605 .769 r
.63567 .43372 .64206 .44875 .65443 .44324 .64803 .42767 Metetra
.674 .599 .764 r
.64803 .42767 .65443 .44324 .66684 .43766 .66043 .42154 Metetra
.67 .592 .759 r
.66043 .42154 .66684 .43766 .6793 .43214 .67287 .41549 Metetra
.663 .584 .756 r
.67287 .41549 .6793 .43214 .69182 .42684 .68537 .40972 Metetra
.654 .575 .753 r
.68537 .40972 .69182 .42684 .7044 .42191 .69793 .40442 Metetra
.643 .566 .753 r
.69793 .40442 .7044 .42191 .71706 .4175 .71058 .39978 Metetra
.629 .556 .754 r
.71058 .39978 .71706 .4175 .72982 .41375 .72334 .39598 Metetra
.613 .547 .757 r
.72334 .39598 .72982 .41375 .74269 .41078 .73622 .39319 Metetra
.594 .539 .762 r
.73622 .39319 .74269 .41078 .75569 .40869 .74925 .3915 Metetra
.573 .531 .77 r
.74925 .3915 .75569 .40869 .76884 .40753 .76244 .39101 Metetra
.548 .524 .781 r
.76244 .39101 .76884 .40753 .78214 .40731 .77582 .3917 Metetra
.52 .519 .795 r
.77582 .3917 .78214 .40731 .79561 .40797 .78939 .39352 Metetra
.489 .517 .813 r
.78939 .39352 .79561 .40797 .80925 .40938 .80315 .39627 Metetra
.458 .521 .835 r
.80315 .39627 .80925 .40938 .82305 .41131 .8171 .39965 Metetra
.432 .534 .86 r
.8171 .39965 .82305 .41131 .83698 .41342 .83118 .40321 Metetra
.423 .561 .889 r
.83118 .40321 .83698 .41342 .85099 .41522 .84536 .40633 Metetra
.448 .611 .918 r
.84536 .40633 .85099 .41522 .86502 .41608 .85952 .40816 Metetra
.527 .683 .937 r
.85952 .40816 .86502 .41608 .87897 .41521 .87356 .40765 Metetra
.64 .749 .928 r
.87356 .40765 .87897 .41521 .89272 .41177 .88733 .40395 Metetra
.657 .749 .918 r
.88733 .40395 .89272 .41177 .90645 .40755 .90111 .39969 Metetra
.657 .749 .918 r
.28706 .58108 .29426 .58745 .30539 .584 .29821 .57761 Metetra
.657 .749 .918 r
.29821 .57761 .30539 .584 .31657 .58042 .30942 .57412 Metetra
.73 .767 .882 r
.30942 .57412 .31657 .58042 .32796 .57412 .32082 .56811 Metetra
.795 .78 .839 r
.32082 .56811 .32796 .57412 .33952 .56529 .33246 .55861 Metetra
.812 .764 .808 r
.33246 .55861 .33952 .56529 .35116 .55498 .3442 .54719 Metetra
.81 .741 .788 r
.3442 .54719 .35116 .55498 .36283 .54403 .35598 .53491 Metetra
.797 .716 .775 r
.35598 .53491 .36283 .54403 .37451 .5331 .36776 .52257 Metetra
.779 .692 .767 r
.36776 .52257 .37451 .5331 .38616 .52266 .3795 .5108 Metetra
.758 .668 .762 r
.3795 .5108 .38616 .52266 .39778 .51304 .39119 .5 Metetra
.736 .646 .759 r
.39119 .5 .39778 .51304 .40937 .50445 .40284 .49043 Metetra
.712 .625 .758 r
.40284 .49043 .40937 .50445 .42094 .49699 .41445 .48223 Metetra
.689 .607 .759 r
.41445 .48223 .42094 .49699 .4325 .49068 .42603 .47543 Metetra
.667 .591 .761 r
.42603 .47543 .4325 .49068 .44407 .48547 .43761 .46997 Metetra
.646 .578 .764 r
.43761 .46997 .44407 .48547 .45565 .48128 .44919 .46573 Metetra
.627 .569 .769 r
.44919 .46573 .45565 .48128 .46727 .47794 .4608 .46255 Metetra
.611 .562 .775 r
.4608 .46255 .46727 .47794 .47892 .47531 .47245 .46022 Metetra
.599 .559 .782 r
.47245 .46022 .47892 .47531 .49063 .47319 .48416 .45852 Metetra
.59 .56 .789 r
.48416 .45852 .49063 .47319 .5024 .4714 .49592 .45721 Metetra
.586 .565 .797 r
.49592 .45721 .5024 .4714 .51423 .46975 .50775 .45607 Metetra
.587 .573 .805 r
.50775 .45607 .51423 .46975 .52613 .46806 .51966 .45488 Metetra
.593 .584 .812 r
.51966 .45488 .52613 .46806 .53809 .46616 .53163 .45343 Metetra
.603 .596 .817 r
.53163 .45343 .53809 .46616 .55012 .46393 .54367 .45155 Metetra
.617 .609 .821 r
.54367 .45155 .55012 .46393 .56221 .46124 .55578 .44911 Metetra
.632 .621 .821 r
.55578 .44911 .56221 .46124 .57435 .45802 .56794 .44601 Metetra
.648 .631 .819 r
.56794 .44601 .57435 .45802 .58654 .45422 .58014 .4422 Metetra
.663 .638 .815 r
.58014 .4422 .58654 .45422 .59877 .44984 .59239 .43766 Metetra
.675 .642 .809 r
.59239 .43766 .59877 .44984 .61104 .44492 .60467 .43244 Metetra
.685 .642 .801 r
.60467 .43244 .61104 .44492 .62334 .43951 .61698 .42662 Metetra
.69 .639 .793 r
.61698 .42662 .62334 .43951 .63567 .43372 .62931 .42032 Metetra
.692 .634 .786 r
.62931 .42032 .63567 .43372 .64803 .42767 .64167 .41371 Metetra
.691 .626 .779 r
.64167 .41371 .64803 .42767 .66043 .42154 .65406 .40698 Metetra
.686 .617 .773 r
.65406 .40698 .66043 .42154 .67287 .41549 .66649 .40035 Metetra
.678 .607 .769 r
.66649 .40035 .67287 .41549 .68537 .40972 .67898 .39406 Metetra
.666 .596 .767 r
.67898 .39406 .68537 .40972 .69793 .40442 .69153 .38834 Metetra
.652 .584 .766 r
.69153 .38834 .69793 .40442 .71058 .39978 .70417 .38342 Metetra
.634 .572 .768 r
.70417 .38342 .71058 .39978 .72334 .39598 .71692 .37953 Metetra
.613 .56 .771 r
.71692 .37953 .72334 .39598 .73622 .39319 .72982 .37686 Metetra
.587 .548 .778 r
.72982 .37686 .73622 .39319 .74925 .3915 .74287 .37554 Metetra
.557 .536 .787 r
.74287 .37554 .74925 .3915 .76244 .39101 .75612 .37566 Metetra
.523 .524 .798 r
.75612 .37566 .76244 .39101 .77582 .3917 .76957 .37722 Metetra
.482 .513 .813 r
.76957 .37722 .77582 .3917 .78939 .39352 .78323 .38013 Metetra
.438 .505 .83 r
.78323 .38013 .78939 .39352 .80315 .39627 .79712 .38415 Metetra
.393 .502 .851 r
.79712 .38415 .80315 .39627 .8171 .39965 .8112 .38891 Metetra
.357 .511 .874 r
.8112 .38891 .8171 .39965 .83118 .40321 .82543 .39382 Metetra
.348 .54 .901 r
.82543 .39382 .83118 .40321 .84536 .40633 .83975 .39811 Metetra
.393 .602 .931 r
.83975 .39811 .84536 .40633 .85952 .40816 .85403 .40071 Metetra
.514 .693 .95 r
.85403 .40071 .85952 .40816 .87356 .40765 .86812 .40028 Metetra
.654 .763 .929 r
.86812 .40028 .87356 .40765 .88733 .40395 .88189 .39607 Metetra
.657 .749 .918 r
.88189 .39607 .88733 .40395 .90111 .39969 .89571 .39177 Metetra
.657 .749 .918 r
.2798 .57466 .28706 .58108 .29821 .57761 .29098 .57116 Metetra
.657 .749 .918 r
.29098 .57116 .29821 .57761 .30942 .57412 .30222 .56765 Metetra
.707 .76 .893 r
.30222 .56765 .30942 .57412 .32082 .56811 .3136 .5625 Metetra
.805 .791 .84 r
.3136 .5625 .32082 .56811 .33246 .55861 .3253 .55259 Metetra
.828 .779 .805 r
.3253 .55259 .33246 .55861 .3442 .54719 .33714 .54024 Metetra
.829 .759 .785 r
.33714 .54024 .3442 .54719 .35598 .53491 .34903 .52675 Metetra
.819 .736 .774 r
.34903 .52675 .35598 .53491 .36776 .52257 .36091 .51313 Metetra
.801 .713 .768 r
.36091 .51313 .36776 .52257 .3795 .5108 .37275 .5001 Metetra
.78 .691 .765 r
.37275 .5001 .3795 .5108 .39119 .5 .38452 .48819 Metetra
.756 .669 .765 r
.38452 .48819 .39119 .5 .40284 .49043 .39623 .47771 Metetra
.73 .648 .767 r
.39623 .47771 .40284 .49043 .41445 .48223 .40788 .46883 Metetra
.703 .629 .771 r
.40788 .46883 .41445 .48223 .42603 .47543 .41949 .46159 Metetra
.677 .612 .776 r
.41949 .46159 .42603 .47543 .43761 .46997 .43108 .45593 Metetra
.651 .598 .782 r
.43108 .45593 .43761 .46997 .44919 .46573 .44268 .45171 Metetra
.627 .586 .789 r
.44268 .45171 .44919 .46573 .4608 .46255 .45429 .44873 Metetra
.605 .579 .798 r
.45429 .44873 .4608 .46255 .47245 .46022 .46593 .44676 Metetra
.587 .575 .807 r
.46593 .44676 .47245 .46022 .48416 .45852 .47764 .44553 Metetra
.575 .576 .817 r
.47764 .44553 .48416 .45852 .49592 .45721 .4894 .44477 Metetra
.568 .582 .828 r
.4894 .44477 .49592 .45721 .50775 .45607 .50124 .44419 Metetra
.569 .593 .838 r
.50124 .44419 .50775 .45607 .51966 .45488 .51315 .44354 Metetra
.576 .608 .847 r
.51315 .44354 .51966 .45488 .53163 .45343 .52514 .44257 Metetra
.59 .624 .854 r
.52514 .44257 .53163 .45343 .54367 .45155 .5372 .44109 Metetra
.609 .642 .858 r
.5372 .44109 .54367 .45155 .55578 .44911 .54932 .43892 Metetra
.631 .658 .858 r
.54932 .43892 .55578 .44911 .56794 .44601 .56151 .43596 Metetra
.654 .671 .854 r
.56151 .43596 .56794 .44601 .58014 .4422 .57374 .43213 Metetra
.674 .679 .847 r
.57374 .43213 .58014 .4422 .59239 .43766 .58601 .42742 Metetra
.691 .683 .838 r
.58601 .42742 .59239 .43766 .60467 .43244 .59831 .42189 Metetra
.704 .683 .827 r
.59831 .42189 .60467 .43244 .61698 .42662 .61064 .41563 Metetra
.711 .678 .816 r
.61064 .41563 .61698 .42662 .62931 .42032 .62298 .40879 Metetra
.714 .671 .807 r
.62298 .40879 .62931 .42032 .64167 .41371 .63535 .40157 Metetra
.712 .661 .798 r
.63535 .40157 .64167 .41371 .65406 .40698 .64774 .3942 Metetra
.706 .65 .791 r
.64774 .3942 .65406 .40698 .66649 .40035 .66017 .38694 Metetra
.696 .637 .786 r
.66017 .38694 .66649 .40035 .67898 .39406 .67264 .38007 Metetra
.682 .623 .784 r
.67264 .38007 .67898 .39406 .69153 .38834 .68519 .37388 Metetra
.663 .609 .784 r
.68519 .37388 .69153 .38834 .70417 .38342 .69783 .36863 Metetra
.641 .594 .786 r
.69783 .36863 .70417 .38342 .71692 .37953 .71059 .3646 Metetra
.613 .578 .791 r
.71059 .3646 .71692 .37953 .72982 .37686 .72349 .36199 Metetra
.58 .561 .798 r
.72349 .36199 .72982 .37686 .74287 .37554 .73658 .36098 Metetra
.539 .544 .808 r
.73658 .36098 .74287 .37554 .75612 .37566 .74987 .36166 Metetra
.491 .526 .82 r
.74987 .36166 .75612 .37566 .76957 .37722 .76339 .36403 Metetra
.435 .507 .834 r
.76339 .36403 .76957 .37722 .78323 .38013 .77715 .36796 Metetra
.373 .49 .848 r
.77715 .36796 .78323 .38013 .79712 .38415 .79114 .37317 Metetra
.311 .478 .864 r
.79114 .37317 .79712 .38415 .8112 .38891 .80535 .37919 Metetra
.264 .481 .881 r
.80535 .37919 .8112 .38891 .82543 .39382 .81973 .38533 Metetra
.26 .514 .905 r
.81973 .38533 .82543 .39382 .83975 .39811 .83417 .3906 Metetra
.337 .594 .94 r
.83417 .3906 .83975 .39811 .85403 .40071 .84855 .39373 Metetra
.54 .725 .959 r
.84855 .39373 .85403 .40071 .86812 .40028 .86259 .39243 Metetra
.657 .751 .919 r
.86259 .39243 .86812 .40028 .88189 .39607 .8764 .38811 Metetra
.657 .749 .918 r
.8764 .38811 .88189 .39607 .89571 .39177 .89027 .38378 Metetra
.657 .749 .918 r
.27248 .56819 .2798 .57466 .29098 .57116 .28369 .56467 Metetra
.657 .749 .918 r
.28369 .56467 .29098 .57116 .30222 .56765 .29495 .56113 Metetra
.668 .752 .913 r
.29495 .56113 .30222 .56765 .3136 .5625 .30629 .55726 Metetra
.81 .802 .844 r
.30629 .55726 .3136 .5625 .3253 .55259 .31804 .54722 Metetra
.842 .794 .805 r
.31804 .54722 .3253 .55259 .33714 .54024 .32998 .53416 Metetra
.847 .776 .783 r
.32998 .53416 .33714 .54024 .34903 .52675 .34198 .51963 Metetra
.838 .757 .773 r
.34198 .51963 .34903 .52675 .36091 .51313 .35397 .50484 Metetra
.822 .736 .769 r
.35397 .50484 .36091 .51313 .37275 .5001 .3659 .49066 Metetra
.801 .715 .769 r
.3659 .49066 .37275 .5001 .38452 .48819 .37776 .47772 Metetra
.776 .694 .773 r
.37776 .47772 .38452 .48819 .39623 .47771 .38953 .4664 Metetra
.749 .674 .778 r
.38953 .4664 .39623 .47771 .40788 .46883 .40123 .45691 Metetra
.719 .655 .786 r
.40123 .45691 .40788 .46883 .41949 .46159 .41288 .4493 Metetra
.687 .638 .795 r
.41288 .4493 .41949 .46159 .43108 .45593 .42449 .4435 Metetra
.655 .622 .805 r
.42449 .4435 .43108 .45593 .44268 .45171 .43609 .43936 Metetra
.624 .609 .816 r
.43609 .43936 .44268 .45171 .45429 .44873 .4477 .43665 Metetra
.594 .6 .828 r
.4477 .43665 .45429 .44873 .46593 .44676 .45935 .4351 Metetra
.569 .596 .841 r
.45935 .4351 .46593 .44676 .47764 .44553 .47106 .4344 Metetra
.549 .598 .855 r
.47106 .4344 .47764 .44553 .4894 .44477 .48282 .43422 Metetra
.538 .605 .868 r
.48282 .43422 .4894 .44477 .50124 .44419 .49467 .43426 Metetra
.537 .619 .882 r
.49467 .43426 .50124 .44419 .51315 .44354 .50659 .4342 Metetra
.546 .639 .893 r
.50659 .4342 .51315 .44354 .52514 .44257 .5186 .43376 Metetra
.566 .662 .902 r
.5186 .43376 .52514 .44257 .5372 .44109 .53069 .4327 Metetra
.593 .686 .906 r
.53069 .4327 .5372 .44109 .54932 .43892 .54284 .43084 Metetra
.625 .708 .905 r
.54284 .43084 .54932 .43892 .56151 .43596 .55506 .42802 Metetra
.657 .724 .899 r
.55506 .42802 .56151 .43596 .57374 .43213 .56732 .42417 Metetra
.686 .735 .888 r
.56732 .42417 .57374 .43213 .58601 .42742 .57963 .41929 Metetra
.71 .738 .874 r
.57963 .41929 .58601 .42742 .59831 .42189 .59196 .41343 Metetra
.727 .736 .859 r
.59196 .41343 .59831 .42189 .61064 .41563 .60431 .4067 Metetra
.737 .729 .844 r
.60431 .4067 .61064 .41563 .62298 .40879 .61668 .39929 Metetra
.74 .719 .832 r
.61668 .39929 .62298 .40879 .63535 .40157 .62906 .39141 Metetra
.738 .706 .821 r
.62906 .39141 .63535 .40157 .64774 .3942 .64146 .38335 Metetra
.731 .692 .813 r
.64146 .38335 .64774 .3942 .66017 .38694 .65389 .37541 Metetra
.718 .676 .807 r
.65389 .37541 .66017 .38694 .67264 .38007 .66637 .36791 Metetra
.701 .659 .805 r
.66637 .36791 .67264 .38007 .68519 .37388 .67892 .36119 Metetra
.678 .641 .806 r
.67892 .36119 .68519 .37388 .69783 .36863 .69156 .35555 Metetra
.65 .622 .809 r
.69156 .35555 .69783 .36863 .71059 .3646 .70432 .35131 Metetra
.614 .602 .815 r
.70432 .35131 .71059 .3646 .72349 .36199 .71725 .34871 Metetra
.571 .58 .824 r
.71725 .34871 .72349 .36199 .73658 .36098 .73036 .34795 Metetra
.517 .556 .834 r
.73036 .34795 .73658 .36098 .74987 .36166 .7437 .34912 Metetra
.451 .528 .846 r
.7437 .34912 .74987 .36166 .76339 .36403 .75728 .35222 Metetra
.374 .498 .856 r
.75728 .35222 .76339 .36403 .77715 .36796 .77113 .3571 Metetra
.288 .468 .863 r
.77113 .3571 .77715 .36796 .79114 .37317 .78523 .3634 Metetra
.206 .444 .867 r
.78523 .3634 .79114 .37317 .80535 .37919 .79957 .37057 Metetra
.152 .441 .875 r
.79957 .37057 .80535 .37919 .81973 .38533 .81406 .37777 Metetra
.163 .483 .899 r
.81406 .37777 .81973 .38533 .83417 .3906 .82862 .38383 Metetra
.286 .59 .946 r
.82862 .38383 .83417 .3906 .84855 .39373 .84306 .3872 Metetra
.593 .767 .962 r
.84306 .3872 .84855 .39373 .86259 .39243 .85701 .38444 Metetra
.657 .749 .918 r
.85701 .38444 .86259 .39243 .8764 .38811 .87086 .38009 Metetra
.657 .749 .918 r
.87086 .38009 .8764 .38811 .89027 .38378 .88479 .37571 Metetra
.657 .749 .918 r
.2651 .56167 .27248 .56819 .28369 .56467 .27635 .55812 Metetra
.657 .749 .918 r
.27635 .55812 .28369 .56467 .29495 .56113 .28764 .55455 Metetra
.657 .749 .918 r
.28764 .55455 .29495 .56113 .30629 .55726 .29898 .55097 Metetra
.777 .776 .852 r
.29898 .55097 .30629 .55726 .31804 .54722 .31068 .54246 Metetra
.852 .807 .806 r
.31068 .54246 .31804 .54722 .32998 .53416 .3227 .52893 Metetra
.862 .793 .782 r
.3227 .52893 .32998 .53416 .34198 .51963 .3348 .51356 Metetra
.856 .776 .772 r
.3348 .51356 .34198 .51963 .35397 .50484 .3469 .49774 Metetra
.843 .759 .77 r
.3469 .49774 .35397 .50484 .3659 .49066 .35894 .48254 Metetra
.823 .741 .774 r
.35894 .48254 .3659 .49066 .37776 .47772 .37088 .46867 Metetra
.798 .722 .781 r
.37088 .46867 .37776 .47772 .38953 .4664 .38273 .45659 Metetra
.768 .704 .791 r
.38273 .45659 .38953 .4664 .40123 .45691 .39448 .44656 Metetra
.735 .686 .804 r
.39448 .44656 .40123 .45691 .41288 .4493 .40617 .43864 Metetra
.698 .669 .818 r
.40617 .43864 .41288 .4493 .42449 .4435 .4178 .43277 Metetra
.658 .653 .833 r
.4178 .43277 .42449 .4435 .43609 .43936 .42942 .42877 Metetra
.617 .639 .85 r
.42942 .42877 .43609 .43936 .4477 .43665 .44104 .42639 Metetra
.575 .628 .867 r
.44104 .42639 .4477 .43665 .45935 .4351 .45269 .42532 Metetra
.537 .622 .884 r
.45269 .42532 .45935 .4351 .47106 .4344 .4644 .4252 Metetra
.505 .623 .901 r
.4644 .4252 .47106 .4344 .48282 .43422 .47618 .42568 Metetra
.483 .631 .918 r
.47618 .42568 .48282 .43422 .49467 .43426 .48804 .42639 Metetra
.477 .649 .934 r
.48804 .42639 .49467 .43426 .50659 .4342 .49998 .42696 Metetra
.487 .675 .948 r
.49998 .42696 .50659 .4342 .5186 .43376 .51201 .42709 Metetra
.514 .707 .958 r
.51201 .42709 .5186 .43376 .53069 .4327 .52413 .4265 Metetra
.555 .74 .963 r
.52413 .4265 .53069 .4327 .54284 .43084 .53632 .42495 Metetra
.603 .771 .96 r
.53632 .42495 .54284 .43084 .55506 .42802 .54857 .4223 Metetra
.651 .793 .95 r
.54857 .4223 .55506 .42802 .56732 .42417 .56088 .41844 Metetra
.694 .806 .934 r
.56088 .41844 .56732 .42417 .57963 .41929 .57323 .41338 Metetra
.728 .808 .915 r
.57323 .41338 .57963 .41929 .59196 .41343 .5856 .40717 Metetra
.751 .803 .894 r
.5856 .40717 .59196 .41343 .60431 .4067 .59799 .39994 Metetra
.765 .793 .875 r
.59799 .39994 .60431 .4067 .61668 .39929 .61038 .39191 Metetra
.771 .778 .859 r
.61038 .39191 .61668 .39929 .62906 .39141 .62279 .38334 Metetra
.769 .761 .846 r
.62279 .38334 .62906 .39141 .64146 .38335 .63521 .37454 Metetra
.76 .743 .837 r
.63521 .37454 .64146 .38335 .65389 .37541 .64766 .36587 Metetra
.745 .723 .831 r
.64766 .36587 .65389 .37541 .66637 .36791 .66014 .35768 Metetra
.724 .703 .83 r
.66014 .35768 .66637 .36791 .67892 .36119 .6727 .35037 Metetra
.697 .682 .832 r
.6727 .35037 .67892 .36119 .69156 .35555 .68535 .34429 Metetra
.661 .659 .837 r
.68535 .34429 .69156 .35555 .70432 .35131 .69813 .33978 Metetra
.616 .634 .845 r
.69813 .33978 .70432 .35131 .71725 .34871 .71107 .33713 Metetra
.559 .605 .855 r
.71107 .33713 .71725 .34871 .73036 .34795 .72422 .33654 Metetra
.487 .571 .866 r
.72422 .33654 .73036 .34795 .7437 .34912 .7376 .33814 Metetra
.398 .531 .874 r
.7376 .33814 .7437 .34912 .75728 .35222 .75126 .34189 Metetra
.293 .484 .875 r
.75126 .34189 .75728 .35222 .77113 .3571 .76519 .34761 Metetra
.179 .435 .867 r
.76519 .34761 .77113 .3571 .78523 .3634 .77939 .35489 Metetra
.079 .396 .853 r
.77939 .35489 .78523 .3634 .79957 .37057 .79383 .36307 Metetra
.026 .39 .849 r
.79383 .36307 .79957 .37057 .81406 .37777 .80844 .37114 Metetra
.064 .448 .879 r
.80844 .37114 .81406 .37777 .82862 .38383 .82308 .37774 Metetra
.268 .606 .954 r
.82308 .37774 .82862 .38383 .84306 .3872 .83754 .38076 Metetra
.652 .797 .952 r
.83754 .38076 .84306 .3872 .85701 .38444 .85138 .37639 Metetra
.657 .749 .918 r
.85138 .37639 .85701 .38444 .87086 .38009 .86528 .37199 Metetra
.657 .749 .918 r
.86528 .37199 .87086 .38009 .88479 .37571 .87925 .36758 Metetra
.657 .749 .918 r
.25767 .5551 .2651 .56167 .27635 .55812 .26894 .55152 Metetra
.657 .749 .918 r
.26894 .55152 .27635 .55812 .28764 .55455 .28026 .54792 Metetra
.657 .749 .918 r
.28026 .54792 .28764 .55455 .29898 .55097 .29163 .54431 Metetra
.728 .764 .881 r
.29163 .54431 .29898 .55097 .31068 .54246 .30321 .53822 Metetra
.859 .82 .809 r
.30321 .53822 .31068 .54246 .3227 .52893 .3153 .52451 Metetra
.874 .809 .782 r
.3153 .52451 .3227 .52893 .3348 .51356 .32751 .5085 Metetra
.872 .796 .772 r
.32751 .5085 .3348 .51356 .3469 .49774 .33972 .49184 Metetra
.861 .781 .771 r
.33972 .49184 .3469 .49774 .35894 .48254 .35186 .47573 Metetra
.843 .767 .778 r
.35186 .47573 .35894 .48254 .37088 .46867 .36389 .46104 Metetra
.819 .752 .79 r
.36389 .46104 .37088 .46867 .38273 .45659 .37581 .44831 Metetra
.788 .737 .805 r
.37581 .44831 .38273 .45659 .39448 .44656 .38763 .43782 Metetra
.752 .722 .824 r
.38763 .43782 .39448 .44656 .40617 .43864 .39935 .42967 Metetra
.708 .706 .846 r
.39935 .42967 .40617 .43864 .4178 .43277 .41102 .42379 Metetra
.658 .69 .869 r
.41102 .42379 .4178 .43277 .42942 .42877 .42265 .41999 Metetra
.601 .675 .892 r
.42265 .41999 .42942 .42877 .44104 .42639 .43428 .418 Metetra
.539 .66 .915 r
.43428 .418 .44104 .42639 .45269 .42532 .44594 .41747 Metetra
.477 .649 .934 r
.44594 .41747 .45269 .42532 .4644 .4252 .45766 .418 Metetra
.421 .644 .95 r
.45766 .418 .4644 .4252 .47618 .42568 .46945 .41918 Metetra
.378 .648 .962 r
.46945 .41918 .47618 .42568 .48804 .42639 .48132 .4206 Metetra
.358 .664 .972 r
.48132 .4206 .48804 .42639 .49998 .42696 .49329 .42187 Metetra
.365 .694 .982 r
.49329 .42187 .49998 .42696 .51201 .42709 .50535 .42261 Metetra
.402 .737 .992 r
.50535 .42261 .51201 .42709 .52413 .4265 .5175 .42251 Metetra
.463 .785 .999 r
.5175 .42251 .52413 .4265 .53632 .42495 .52974 .42131 Metetra
.539 .83 .999 r
.52974 .42131 .53632 .42495 .54857 .4223 .54204 .41883 Metetra
.616 .865 .99 r
.54204 .41883 .54857 .4223 .56088 .41844 .5544 .41497 Metetra
.683 .884 .972 r
.5544 .41497 .56088 .41844 .57323 .41338 .5668 .40971 Metetra
.735 .888 .95 r
.5668 .40971 .57323 .41338 .5856 .40717 .57922 .40313 Metetra
.771 .88 .925 r
.57922 .40313 .5856 .40717 .59799 .39994 .59165 .39539 Metetra
.793 .866 .903 r
.59165 .39539 .59799 .39994 .61038 .39191 .60409 .38671 Metetra
.802 .847 .884 r
.60409 .38671 .61038 .39191 .62279 .38334 .61654 .3774 Metetra
.801 .825 .87 r
.61654 .3774 .62279 .38334 .63521 .37454 .62899 .36781 Metetra
.793 .803 .861 r
.62899 .36781 .63521 .37454 .64766 .36587 .64146 .35834 Metetra
.776 .78 .856 r
.64146 .35834 .64766 .36587 .66014 .35768 .65396 .34942 Metetra
.752 .757 .857 r
.65396 .34942 .66014 .35768 .6727 .35037 .66653 .34145 Metetra
.719 .732 .861 r
.66653 .34145 .6727 .35037 .68535 .34429 .67919 .33487 Metetra
.675 .705 .87 r
.67919 .33487 .68535 .34429 .69813 .33978 .69199 .33003 Metetra
.618 .674 .881 r
.69199 .33003 .69813 .33978 .71107 .33713 .70496 .32726 Metetra
.544 .636 .893 r
.70496 .32726 .71107 .33713 .72422 .33654 .71814 .32679 Metetra
.447 .589 .901 r
.71814 .32679 .72422 .33654 .7376 .33814 .73158 .32873 Metetra
.326 .53 .9 r
.73158 .32873 .7376 .33814 .75126 .34189 .74529 .33304 Metetra
.186 .459 .882 r
.74529 .33304 .75126 .34189 .76519 .34761 .7593 .33951 Metetra
.046 .387 .848 r
.7593 .33951 .76519 .34761 .77939 .35489 .7736 .34764 Metetra
0 .334 .811 r
.7736 .34764 .77939 .35489 .79383 .36307 .78814 .35666 Metetra
0 .331 .801 r
.78814 .35666 .79383 .36307 .80844 .37114 .80284 .3654 Metetra
0 .415 .849 r
.80284 .3654 .80844 .37114 .82308 .37774 .81755 .37226 Metetra
.399 .71 .985 r
.81755 .37226 .82308 .37774 .83754 .38076 .83181 .37267 Metetra
.657 .749 .918 r
.83181 .37267 .83754 .38076 .85138 .37639 .8457 .36826 Metetra
.657 .749 .918 r
.8457 .36826 .85138 .37639 .86528 .37199 .85965 .36383 Metetra
.657 .749 .918 r
.85965 .36383 .86528 .37199 .87925 .36758 .87366 .35937 Metetra
.657 .749 .918 r
.25017 .54848 .25767 .5551 .26894 .55152 .26147 .54487 Metetra
.657 .749 .918 r
.26147 .54487 .26894 .55152 .28026 .54792 .27282 .54124 Metetra
.657 .749 .918 r
.27282 .54124 .28026 .54792 .29163 .54431 .28422 .5376 Metetra
.657 .749 .918 r
.28422 .5376 .29163 .54431 .30321 .53822 .29567 .53394 Metetra
.854 .823 .817 r
.29567 .53394 .30321 .53822 .3153 .52451 .30778 .52079 Metetra
.884 .824 .784 r
.30778 .52079 .3153 .52451 .32751 .5085 .32008 .50439 Metetra
.886 .813 .772 r
.32008 .50439 .32751 .5085 .33972 .49184 .3324 .48707 Metetra
.877 .803 .773 r
.3324 .48707 .33972 .49184 .35186 .47573 .34465 .47022 Metetra
.862 .793 .782 r
.34465 .47022 .35186 .47573 .36389 .46104 .35678 .45483 Metetra
.839 .783 .798 r
.35678 .45483 .36389 .46104 .37581 .44831 .36878 .44153 Metetra
.808 .773 .82 r
.36878 .44153 .37581 .44831 .38763 .43782 .38065 .43066 Metetra
.768 .762 .847 r
.38065 .43066 .38763 .43782 .39935 .42967 .39242 .42235 Metetra
.717 .75 .878 r
.39242 .42235 .39935 .42967 .41102 .42379 .40412 .41654 Metetra
.651 .735 .911 r
.40412 .41654 .41102 .42379 .42265 .41999 .41577 .41301 Metetra
.569 .716 .941 r
.41577 .41301 .42265 .41999 .43428 .418 .42742 .41147 Metetra
.471 .691 .963 r
.42742 .41147 .43428 .418 .44594 .41747 .43909 .41153 Metetra
.364 .662 .971 r
.43909 .41153 .44594 .41747 .45766 .418 .45082 .41276 Metetra
.262 .633 .962 r
.45082 .41276 .45766 .418 .46945 .41918 .46262 .4147 Metetra
.182 .613 .942 r
.46262 .4147 .46945 .41918 .48132 .4206 .47451 .41689 Metetra
.138 .612 .922 r
.47451 .41689 .48132 .4206 .49329 .42187 .48651 .41889 Metetra
.14 .636 .911 r
.48651 .41889 .49329 .42187 .50535 .42261 .49861 .42027 Metetra
.187 .685 .915 r
.49861 .42027 .50535 .42261 .5175 .42251 .5108 .4207 Metetra
.275 .754 .931 r
.5108 .4207 .5175 .42251 .52974 .42131 .52309 .41987 Metetra
.391 .829 .95 r
.52309 .41987 .52974 .42131 .54204 .41883 .53545 .41758 Metetra
.514 .893 .963 r
.53545 .41758 .54204 .41883 .5544 .41497 .54787 .41371 Metetra
.625 .936 .963 r
.54787 .41371 .5544 .41497 .5668 .40971 .56033 .40826 Metetra
.712 .953 .951 r
.56033 .40826 .5668 .40971 .57922 .40313 .57281 .4013 Metetra
.772 .952 .933 r
.57281 .4013 .57922 .40313 .59165 .39539 .5853 .393 Metetra
.809 .937 .914 r
.5853 .393 .59165 .39539 .60409 .38671 .59779 .38364 Metetra
.827 .917 .897 r
.59779 .38364 .60409 .38671 .61654 .3774 .61028 .37355 Metetra
.831 .893 .885 r
.61028 .37355 .61654 .3774 .62899 .36781 .62277 .36312 Metetra
.824 .868 .879 r
.62277 .36312 .62899 .36781 .64146 .35834 .63527 .35282 Metetra
.807 .843 .877 r
.63527 .35282 .64146 .35834 .65396 .34942 .64781 .3431 Metetra
.781 .818 .882 r
.64781 .3431 .65396 .34942 .66653 .34145 .6604 .33444 Metetra
.743 .791 .891 r
.6604 .33444 .66653 .34145 .67919 .33487 .67309 .32729 Metetra
.691 .76 .905 r
.67309 .32729 .67919 .33487 .69199 .33003 .68591 .32206 Metetra
.619 .723 .92 r
.68591 .32206 .69199 .33003 .70496 .32726 .69891 .31911 Metetra
.521 .674 .933 r
.69891 .31911 .70496 .32726 .71814 .32679 .71213 .31867 Metetra
.392 .607 .935 r
.71213 .31867 .71814 .32679 .73158 .32873 .72561 .32088 Metetra
.231 .52 .914 r
.72561 .32088 .73158 .32873 .74529 .33304 .73939 .32566 Metetra
.055 .418 .865 r
.73939 .32566 .74529 .33304 .7593 .33951 .75347 .33275 Metetra
0 .322 .798 r
.75347 .33275 .7593 .33951 .7736 .34764 .76786 .34159 Metetra
0 .263 .742 r
.76786 .34159 .7736 .34764 .78814 .35666 .78249 .35127 Metetra
0 .273 .736 r
.78249 .35127 .78814 .35666 .80284 .3654 .79726 .36044 Metetra
0 .393 .817 r
.79726 .36044 .80284 .3654 .81755 .37226 .81202 .36726 Metetra
.557 .811 .993 r
.81202 .36726 .81755 .37226 .83181 .37267 .82603 .36451 Metetra
.657 .749 .918 r
.82603 .36451 .83181 .37267 .8457 .36826 .83996 .36006 Metetra
.657 .749 .918 r
.83996 .36006 .8457 .36826 .85965 .36383 .85396 .35559 Metetra
.657 .749 .918 r
.85396 .35559 .85965 .36383 .87366 .35937 .86803 .35109 Metetra
.657 .749 .918 r
.24262 .5418 .25017 .54848 .26147 .54487 .25395 .53816 Metetra
.657 .749 .918 r
.25395 .53816 .26147 .54487 .27282 .54124 .26533 .53451 Metetra
.657 .749 .918 r
.26533 .53451 .27282 .54124 .28422 .5376 .27676 .53084 Metetra
.657 .749 .918 r
.27676 .53084 .28422 .5376 .29567 .53394 .28823 .52715 Metetra
.788 .769 .836 r
.28823 .52715 .29567 .53394 .30778 .52079 .30015 .51764 Metetra
.89 .836 .787 r
.30015 .51764 .30778 .52079 .32008 .50439 .31253 .50112 Metetra
.896 .829 .773 r
.31253 .50112 .32008 .50439 .3324 .48707 .32495 .48335 Metetra
.891 .823 .774 r
.32495 .48335 .3324 .48707 .34465 .47022 .3373 .46591 Metetra
.878 .818 .785 r
.3373 .46591 .34465 .47022 .35678 .45483 .34952 .44995 Metetra
.857 .814 .806 r
.34952 .44995 .35678 .45483 .36878 .44153 .3616 .43619 Metetra
.827 .81 .835 r
.3616 .43619 .36878 .44153 .38065 .43066 .37354 .42504 Metetra
.783 .806 .871 r
.37354 .42504 .38065 .43066 .39242 .42235 .38536 .41665 Metetra
.72 .799 .914 r
.38536 .41665 .39242 .42235 .40412 .41654 .39709 .41095 Metetra
.63 .784 .955 r
.39709 .41095 .40412 .41654 .41577 .41301 .40877 .40775 Metetra
.504 .752 .985 r
.40877 .40775 .41577 .41301 .42742 .41147 .42044 .40671 Metetra
.343 .696 .982 r
.42044 .40671 .42742 .41147 .43909 .41153 .43212 .40742 Metetra
.166 .617 .936 r
.43212 .40742 .43909 .41153 .45082 .41276 .44386 .4094 Metetra
.01 .534 .856 r
.44386 .4094 .45082 .41276 .46262 .4147 .45568 .41215 Metetra
0 .471 .77 r
.45568 .41215 .46262 .4147 .47451 .41689 .4676 .41516 Metetra
0 .443 .705 r
.4676 .41516 .47451 .41689 .48651 .41889 .47963 .41793 Metetra
.139 0 0 r
.47963 .41793 .48651 .41889 .49861 .42027 .49176 .42 Metetra
.082 0 0 r
.49176 .42 .49861 .42027 .5108 .4207 .50401 .42098 Metetra
.50401 .42098 .5108 .4207 .52309 .41987 .51635 .42054 Metetra
.165 .703 .753 r
.51635 .42054 .52309 .41987 .53545 .41758 .52878 .41845 Metetra
.331 .815 .81 r
.52878 .41845 .53545 .41758 .54787 .41371 .54126 .41458 Metetra
.496 .906 .856 r
.54126 .41458 .54787 .41371 .56033 .40826 .55379 .40893 Metetra
.634 .963 .883 r
.55379 .40893 .56033 .40826 .57281 .4013 .56635 .40156 Metetra
.734 .987 .892 r
.56635 .40156 .57281 .4013 .5853 .393 .57891 .39269 Metetra
.798 .987 .89 r
.57891 .39269 .5853 .393 .59779 .38364 .59146 .38261 Metetra
.833 .973 .885 r
.59146 .38261 .59779 .38364 .61028 .37355 .60401 .3717 Metetra
.848 .952 .882 r
.60401 .3717 .61028 .37355 .62277 .36312 .61655 .36041 Metetra
.848 .93 .882 r
.61655 .36041 .62277 .36312 .63527 .35282 .62909 .34922 Metetra
.834 .906 .888 r
.62909 .34922 .63527 .35282 .64781 .3431 .64167 .33866 Metetra
.807 .881 .899 r
.64167 .33866 .64781 .3431 .6604 .33444 .65429 .32924 Metetra
.766 .854 .916 r
.65429 .32924 .6604 .33444 .67309 .32729 .66701 .32148 Metetra
.704 .822 .938 r
.66701 .32148 .67309 .32729 .68591 .32206 .67986 .31581 Metetra
.615 .778 .959 r
.67986 .31581 .68591 .32206 .69891 .31911 .69289 .31261 Metetra
.488 .714 .971 r
.69289 .31261 .69891 .31911 .71213 .31867 .70615 .31214 Metetra
.316 .62 .957 r
.70615 .31214 .71213 .31867 .72561 .32088 .71969 .31453 Metetra
.111 .495 .903 r
.71969 .31453 .72561 .32088 .73939 .32566 .73353 .31968 Metetra
0 .36 .813 r
.73353 .31968 .73939 .32566 .75347 .33275 .74768 .32727 Metetra
0 .249 .717 r
.74768 .32727 .75347 .33275 .76786 .34159 .76214 .33666 Metetra
0 .194 .657 r
.76214 .33666 .76786 .34159 .78249 .35127 .77685 .34679 Metetra
0 .225 .671 r
.77685 .34679 .78249 .35127 .79726 .36044 .79168 .35613 Metetra
.012 .498 .871 r
.79168 .35613 .79726 .36044 .81202 .36726 .80629 .36075 Metetra
.652 .799 .953 r
.80629 .36075 .81202 .36726 .82603 .36451 .8202 .35628 Metetra
.657 .749 .918 r
.8202 .35628 .82603 .36451 .83996 .36006 .83418 .35179 Metetra
.657 .749 .918 r
.83418 .35179 .83996 .36006 .85396 .35559 .84823 .34727 Metetra
.657 .749 .918 r
.84823 .34727 .85396 .35559 .86803 .35109 .86234 .34274 Metetra
.657 .749 .918 r
.23501 .53507 .24262 .5418 .25395 .53816 .24637 .5314 Metetra
.657 .749 .918 r
.24637 .5314 .25395 .53816 .26533 .53451 .25777 .52772 Metetra
.657 .749 .918 r
.25777 .52772 .26533 .53451 .27676 .53084 .26923 .52402 Metetra
.657 .749 .918 r
.26923 .52402 .27676 .53084 .28823 .52715 .28074 .5203 Metetra
.708 .761 .893 r
.28074 .5203 .28823 .52715 .30015 .51764 .29242 .51487 Metetra
.893 .847 .792 r
.29242 .51487 .30015 .51764 .31253 .50112 .30485 .49853 Metetra
.904 .843 .774 r
.30485 .49853 .31253 .50112 .32495 .48335 .31736 .48053 Metetra
.902 .841 .775 r
.31736 .48053 .32495 .48335 .3373 .46591 .32981 .4627 Metetra
.892 .841 .788 r
.32981 .4627 .3373 .46591 .34952 .44995 .34213 .4463 Metetra
.873 .843 .813 r
.34213 .4463 .34952 .44995 .3616 .43619 .35429 .43219 Metetra
.842 .847 .848 r
.35429 .43219 .3616 .43619 .37354 .42504 .3663 .42084 Metetra
.793 .851 .895 r
.3663 .42084 .37354 .42504 .38536 .41665 .37817 .41244 Metetra
.713 .849 .947 r
.37817 .41244 .38536 .41665 .39709 .41095 .38994 .40693 Metetra
.583 .827 .991 r
.38994 .40693 .39709 .41095 .40877 .40775 .40164 .40411 Metetra
.385 .759 .991 r
.40164 .40411 .40877 .40775 .42044 .40671 .41333 .40363 Metetra
.137 .632 .911 r
.41333 .40363 .42044 .40671 .43212 .40742 .42503 .40503 Metetra
0 .477 .765 r
.42503 .40503 .43212 .40742 .44386 .4094 .43678 .4078 Metetra
.253 0 0 r
.43678 .4078 .44386 .4094 .45568 .41215 .44862 .4114 Metetra
.338 0 0 r
.44862 .4114 .45568 .41215 .4676 .41516 .46057 .41526 Metetra
.364 0 0 r
.46057 .41526 .4676 .41516 .47963 .41793 .47263 .41884 Metetra
.344 0 0 r
.47263 .41884 .47963 .41793 .49176 .42 .48481 .42162 Metetra
.284 0 0 r
.48481 .42162 .49176 .42 .50401 .42098 .49711 .42318 Metetra
.184 0 0 r
.49711 .42318 .50401 .42098 .51635 .42054 .50952 .42315 Metetra
.043 0 0 r
.50952 .42315 .51635 .42054 .52878 .41845 .52201 .42128 Metetra
.52201 .42128 .52878 .41845 .54126 .41458 .53458 .41741 Metetra
.327 .791 .673 r
.53458 .41741 .54126 .41458 .55379 .40893 .54719 .41154 Metetra
.508 .898 .746 r
.54719 .41154 .55379 .40893 .56635 .40156 .55982 .40377 Metetra
.653 .965 .795 r
.55982 .40377 .56635 .40156 .57891 .39269 .57246 .3943 Metetra
.753 .994 .824 r
.57246 .3943 .57891 .39269 .59146 .38261 .58509 .38348 Metetra
.814 .999 .84 r
.58509 .38348 .59146 .38261 .60401 .3717 .5977 .37172 Metetra
.846 .99 .852 r
.5977 .37172 .60401 .3717 .61655 .36041 .61031 .35951 Metetra
.856 .975 .864 r
.61031 .35951 .61655 .36041 .62909 .34922 .6229 .3474 Metetra
.849 .957 .88 r
.6229 .3474 .62909 .34922 .64167 .33866 .63552 .33596 Metetra
.825 .937 .902 r
.63552 .33596 .64167 .33866 .65429 .32924 .64819 .32575 Metetra
.782 .914 .929 r
.64819 .32575 .65429 .32924 .66701 .32148 .66094 .31732 Metetra
.712 .882 .96 r
.66094 .31732 .66701 .32148 .67986 .31581 .67383 .31116 Metetra
.602 .832 .987 r
.67383 .31116 .67986 .31581 .69289 .31261 .68691 .30765 Metetra
.439 .748 .993 r
.68691 .30765 .69289 .31261 .70615 .31214 .70021 .30708 Metetra
.22 .618 .953 r
.70021 .30708 .70615 .31214 .71969 .31453 .7138 .30956 Metetra
0 .451 .855 r
.7138 .30956 .71969 .31453 .73353 .31968 .72769 .31498 Metetra
0 .291 .729 r
.72769 .31498 .73353 .31968 .74768 .32727 .74192 .32294 Metetra
0 .179 .623 r
.74192 .32294 .74768 .32727 .76214 .33666 .75644 .3327 Metetra
.41 0 0 r
.75644 .3327 .76214 .33666 .77685 .34679 .77121 .34307 Metetra
0 .197 .619 r
.77121 .34307 .77685 .34679 .79168 .35613 .78608 .35229 Metetra
.314 .726 .977 r
.78608 .35229 .79168 .35613 .80629 .36075 .80036 .35248 Metetra
.657 .749 .918 r
.80036 .35248 .80629 .36075 .8202 .35628 .81432 .34797 Metetra
.657 .749 .918 r
.81432 .34797 .8202 .35628 .83418 .35179 .82835 .34344 Metetra
.657 .749 .918 r
.82835 .34344 .83418 .35179 .84823 .34727 .84244 .33889 Metetra
.657 .749 .918 r
.84244 .33889 .84823 .34727 .86234 .34274 .85661 .33431 Metetra
.657 .749 .918 r
.22733 .52828 .23501 .53507 .24637 .5314 .23872 .52459 Metetra
.657 .749 .918 r
.23872 .52459 .24637 .5314 .25777 .52772 .25016 .52087 Metetra
.657 .749 .918 r
.25016 .52087 .25777 .52772 .26923 .52402 .26164 .51714 Metetra
.657 .749 .918 r
.26164 .51714 .26923 .52402 .28074 .5203 .27318 .51339 Metetra
.657 .749 .918 r
.27318 .51339 .28074 .5203 .29242 .51487 .28477 .50963 Metetra
.845 .805 .812 r
.28477 .50963 .29242 .51487 .30485 .49853 .29706 .49644 Metetra
.908 .854 .778 r
.29706 .49644 .30485 .49853 .31736 .48053 .30964 .47846 Metetra
.91 .856 .776 r
.30964 .47846 .31736 .48053 .32981 .4627 .32218 .46041 Metetra
.902 .861 .79 r
.32218 .46041 .32981 .4627 .34213 .4463 .3346 .44373 Metetra
.884 .87 .818 r
.3346 .44373 .34213 .4463 .35429 .43219 .34684 .42939 Metetra
.853 .882 .86 r
.34684 .42939 .35429 .43219 .3663 .42084 .35892 .41793 Metetra
.795 .894 .914 r
.35892 .41793 .3663 .42084 .37817 .41244 .37084 .40958 Metetra
.689 .893 .972 r
.37084 .40958 .37817 .41244 .38994 .40693 .38265 .40432 Metetra
.496 .844 .995 r
.38265 .40432 .38994 .40693 .40164 .40411 .39438 .40193 Metetra
.203 .7 .916 r
.39438 .40193 .40164 .40411 .41333 .40363 .40608 .40204 Metetra
0 .484 .726 r
.40608 .40204 .41333 .40363 .42503 .40503 .4178 .40417 Metetra
.315 0 0 r
.4178 .40417 .42503 .40503 .43678 .4078 .42957 .40778 Metetra
.431 0 0 r
.42957 .40778 .43678 .4078 .44862 .4114 .44143 .41225 Metetra
.481 0 0 r
.44143 .41225 .44862 .4114 .46057 .41526 .45341 .417 Metetra
.486 0 0 r
.45341 .417 .46057 .41526 .47263 .41884 .4655 .42141 Metetra
.458 0 0 r
.4655 .42141 .47263 .41884 .48481 .42162 .47773 .42493 Metetra
.4 0 0 r
.47773 .42493 .48481 .42162 .49711 .42318 .49009 .42709 Metetra
.309 0 0 r
.49009 .42709 .49711 .42318 .50952 .42315 .50257 .42749 Metetra
.181 0 0 r
.50257 .42749 .50952 .42315 .52201 .42128 .51514 .42583 Metetra
.015 0 0 r
.51514 .42583 .52201 .42128 .53458 .41741 .52779 .42198 Metetra
.52779 .42198 .53458 .41741 .54719 .41154 .54049 .41589 Metetra
.54049 .41589 .54719 .41154 .55982 .40377 .55321 .40769 Metetra
.555 .9 .673 r
.55321 .40769 .55982 .40377 .57246 .3943 .56594 .39761 Metetra
.687 .962 .731 r
.56594 .39761 .57246 .3943 .58509 .38348 .57866 .38603 Metetra
.774 .991 .77 r
.57866 .38603 .58509 .38348 .5977 .37172 .59135 .37339 Metetra
.824 1 .799 r
.59135 .37339 .5977 .37172 .61031 .35951 .60402 .36025 Metetra
.848 .997 .825 r
.60402 .36025 .61031 .35951 .6229 .3474 .61668 .34718 Metetra
.849 .989 .852 r
.61668 .34718 .6229 .3474 .63552 .33596 .62936 .33482 Metetra
.83 .977 .884 r
.62936 .33482 .63552 .33596 .64819 .32575 .64207 .32379 Metetra
.787 .961 .922 r
.64207 .32379 .64819 .32575 .66094 .31732 .65488 .31465 Metetra
.709 .932 .963 r
.65488 .31465 .66094 .31732 .67383 .31116 .66781 .30794 Metetra
.577 .875 .994 r
.66781 .30794 .67383 .31116 .68691 .30765 .68093 .30408 Metetra
.375 .767 .988 r
.68093 .30408 .68691 .30765 .70021 .30708 .69428 .30335 Metetra
.114 .595 .912 r
.69428 .30335 .70021 .30708 .7138 .30956 .70792 .30584 Metetra
0 .394 .775 r
.70792 .30584 .7138 .30956 .72769 .31498 .72187 .31141 Metetra
0 .225 .633 r
.72187 .31141 .72769 .31498 .74192 .32294 .73615 .3196 Metetra
.44 0 0 r
.73615 .3196 .74192 .32294 .75644 .3327 .75074 .32955 Metetra
.462 0 0 r
.75074 .32955 .75644 .3327 .77121 .34307 .76555 .33991 Metetra
.371 0 0 r
.76555 .33991 .77121 .34307 .78608 .35229 .78043 .34867 Metetra
.602 .883 .991 r
.78043 .34867 .78608 .35229 .80036 .35248 .79437 .34414 Metetra
.657 .749 .918 r
.79437 .34414 .80036 .35248 .81432 .34797 .80838 .33959 Metetra
.657 .749 .918 r
.80838 .33959 .81432 .34797 .82835 .34344 .82246 .33502 Metetra
.657 .749 .918 r
.82246 .33502 .82835 .34344 .84244 .33889 .8366 .33042 Metetra
.657 .749 .918 r
.8366 .33042 .84244 .33889 .85661 .33431 .85082 .32581 Metetra
.657 .749 .918 r
.21959 .52144 .22733 .52828 .23872 .52459 .23101 .51772 Metetra
.657 .749 .918 r
.23101 .51772 .23872 .52459 .25016 .52087 .24248 .51397 Metetra
.657 .749 .918 r
.24248 .51397 .25016 .52087 .26164 .51714 .25399 .51021 Metetra
.657 .749 .918 r
.25399 .51021 .26164 .51714 .27318 .51339 .26556 .50643 Metetra
.657 .749 .918 r
.26556 .50643 .27318 .51339 .28477 .50963 .27718 .50264 Metetra
.762 .768 .858 r
.27718 .50264 .28477 .50963 .29706 .49644 .28915 .49461 Metetra
.909 .863 .783 r
.28915 .49461 .29706 .49644 .30964 .47846 .3018 .47692 Metetra
.914 .868 .779 r
.3018 .47692 .30964 .47846 .32218 .46041 .31442 .45886 Metetra
.909 .878 .793 r
.31442 .45886 .32218 .46041 .3346 .44373 .32692 .44205 Metetra
.892 .892 .822 r
.32692 .44205 .3346 .44373 .34684 .42939 .33925 .42759 Metetra
.858 .912 .868 r
.33925 .42759 .34684 .42939 .35892 .41793 .35139 .41611 Metetra
.788 .93 .927 r
.35139 .41611 .35892 .41793 .37084 .40958 .36337 .40789 Metetra
.642 .92 .978 r
.36337 .40789 .37084 .40958 .38265 .40432 .37522 .40293 Metetra
.366 .814 .946 r
.37522 .40293 .38265 .40432 .39438 .40193 .38698 .40101 Metetra
0 .574 .759 r
.38698 .40101 .39438 .40193 .40608 .40204 .3987 .40174 Metetra
.29 0 0 r
.3987 .40174 .40608 .40204 .4178 .40417 .41044 .40463 Metetra
.453 0 0 r
.41044 .40463 .4178 .40417 .42957 .40778 .42223 .40909 Metetra
.53 0 0 r
.42223 .40909 .42957 .40778 .44143 .41225 .43411 .41446 Metetra
.557 .009 0 r
.43411 .41446 .44143 .41225 .45341 .417 .44611 .42011 Metetra
.552 .016 0 r
.44611 .42011 .45341 .417 .4655 .42141 .45825 .42537 Metetra
.521 0 0 r
.45825 .42537 .4655 .42141 .47773 .42493 .47053 .42966 Metetra
.465 0 0 r
.47053 .42966 .47773 .42493 .49009 .42709 .48295 .43243 Metetra
.381 0 0 r
.48295 .43243 .49009 .42709 .50257 .42749 .4955 .43326 Metetra
.263 0 0 r
.4955 .43326 .50257 .42749 .51514 .42583 .50815 .43183 Metetra
.107 0 0 r
.50815 .43183 .51514 .42583 .52779 .42198 .52089 .42798 Metetra
.52089 .42798 .52779 .42198 .54049 .41589 .53369 .42168 Metetra
.53369 .42168 .54049 .41589 .55321 .40769 .54651 .41304 Metetra
.474 .83 .564 r
.54651 .41304 .55321 .40769 .56594 .39761 .55933 .40235 Metetra
.624 .916 .64 r
.55933 .40235 .56594 .39761 .57866 .38603 .57214 .38998 Metetra
.729 .965 .695 r
.57214 .38998 .57866 .38603 .59135 .37339 .58492 .37646 Metetra
.795 .988 .737 r
.58492 .37646 .59135 .37339 .60402 .36025 .59768 .36235 Metetra
.829 .997 .774 r
.59768 .36235 .60402 .36025 .61668 .34718 .61042 .34832 Metetra
.838 .999 .81 r
.61042 .34832 .61668 .34718 .62936 .33482 .62316 .33502 Metetra
.824 .996 .85 r
.62316 .33502 .62936 .33482 .64207 .32379 .63593 .32313 Metetra
.781 .987 .896 r
.63593 .32313 .64207 .32379 .65488 .31465 .64879 .31327 Metetra
.695 .962 .943 r
.64879 .31327 .65488 .31465 .66781 .30794 .66177 .30598 Metetra
.543 .898 .974 r
.66177 .30598 .66781 .30794 .68093 .30408 .67494 .30171 Metetra
.307 .765 .951 r
.67494 .30171 .68093 .30408 .69428 .30335 .68834 .30074 Metetra
.018 .558 .843 r
.68834 .30074 .69428 .30335 .70792 .30584 .70203 .30316 Metetra
0 .339 .686 r
.70203 .30316 .70792 .30584 .72187 .31141 .71604 .30877 Metetra
.405 0 0 r
.71604 .30877 .72187 .31141 .73615 .3196 .73038 .31705 Metetra
.486 0 0 r
.73038 .31705 .73615 .3196 .75074 .32955 .74501 .327 Metetra
.484 0 0 r
.74501 .327 .75074 .32955 .76555 .33991 .75985 .33709 Metetra
0 .525 .831 r
.75985 .33709 .76555 .33991 .78043 .34867 .77435 .34029 Metetra
.657 .749 .918 r
.77435 .34029 .78043 .34867 .79437 .34414 .78834 .33572 Metetra
.657 .749 .918 r
.78834 .33572 .79437 .34414 .80838 .33959 .80239 .33113 Metetra
.657 .749 .918 r
.80239 .33113 .80838 .33959 .82246 .33502 .81652 .32652 Metetra
.657 .749 .918 r
.81652 .32652 .82246 .33502 .8366 .33042 .83071 .32188 Metetra
.657 .749 .918 r
.83071 .32188 .8366 .33042 .85082 .32581 .84498 .31723 Metetra
.657 .749 .918 r
.21179 .51455 .21959 .52144 .23101 .51772 .22324 .51079 Metetra
.657 .749 .918 r
.22324 .51079 .23101 .51772 .24248 .51397 .23474 .50702 Metetra
.657 .749 .918 r
.23474 .50702 .24248 .51397 .25399 .51021 .24628 .50322 Metetra
.657 .749 .918 r
.24628 .50322 .25399 .51021 .26556 .50643 .25788 .49942 Metetra
.657 .749 .918 r
.25788 .49942 .26556 .50643 .27718 .50264 .26953 .49559 Metetra
.657 .749 .918 r
.26953 .49559 .27718 .50264 .28915 .49461 .28123 .49175 Metetra
.89 .851 .798 r
.28123 .49175 .28915 .49461 .3018 .47692 .29384 .47568 Metetra
.915 .877 .783 r
.29384 .47568 .3018 .47692 .31442 .45886 .30654 .45782 Metetra
.912 .89 .796 r
.30654 .45782 .31442 .45886 .32692 .44205 .31912 .44105 Metetra
.896 .91 .826 r
.31912 .44105 .32692 .44205 .33925 .42759 .33152 .42659 Metetra
.858 .936 .874 r
.33152 .42659 .33925 .42759 .35139 .41611 .34373 .41517 Metetra
.771 .955 .932 r
.34373 .41517 .35139 .41611 .36337 .40789 .35576 .40714 Metetra
.574 .921 .96 r
.35576 .40714 .36337 .40789 .37522 .40293 .36765 .40252 Metetra
.217 .737 .849 r
.36765 .40252 .37522 .40293 .38698 .40101 .37944 .40109 Metetra
.168 0 0 r
.37944 .40109 .38698 .40101 .3987 .40174 .39119 .40248 Metetra
.411 0 0 r
.39119 .40248 .3987 .40174 .41044 .40463 .40294 .40614 Metetra
.533 0 0 r
.40294 .40614 .41044 .40463 .42223 .40909 .41475 .41145 Metetra
.586 .048 0 r
.41475 .41145 .42223 .40909 .43411 .41446 .42665 .41774 Metetra
.601 .08 0 r
.42665 .41774 .43411 .41446 .44611 .42011 .43868 .4243 Metetra
.59 .08 .008 r
.43868 .4243 .44611 .42011 .45825 .42537 .45086 .43042 Metetra
.558 .054 .013 r
.45086 .43042 .45825 .42537 .47053 .42966 .46319 .43546 Metetra
.504 .003 0 r
.46319 .43546 .47053 .42966 .48295 .43243 .47567 .43886 Metetra
.424 0 0 r
.47567 .43886 .48295 .43243 .4955 .43326 .48829 .44012 Metetra
.311 0 0 r
.48829 .44012 .4955 .43326 .50815 .43183 .50104 .43893 Metetra
.161 0 0 r
.50104 .43893 .50815 .43183 .52089 .42798 .51387 .43509 Metetra
.51387 .43509 .52089 .42798 .53369 .42168 .52677 .42856 Metetra
.52677 .42856 .53369 .42168 .54651 .41304 .5397 .4195 Metetra
.5397 .4195 .54651 .41304 .55933 .40235 .55263 .40818 Metetra
.584 .878 .573 r
.55263 .40818 .55933 .40235 .57214 .38998 .56554 .39503 Metetra
.699 .938 .636 r
.56554 .39503 .57214 .38998 .58492 .37646 .57842 .3806 Metetra
.772 .971 .685 r
.57842 .3806 .58492 .37646 .59768 .36235 .59126 .36554 Metetra
.812 .988 .726 r
.59126 .36554 .59768 .36235 .61042 .34832 .60408 .35052 Metetra
.826 .996 .766 r
.60408 .35052 .61042 .34832 .62316 .33502 .6169 .33628 Metetra
.814 1 .81 r
.6169 .33628 .62316 .33502 .63593 .32313 .62974 .32353 Metetra
.77 .996 .859 r
.62974 .32353 .63593 .32313 .64879 .31327 .64266 .31291 Metetra
.678 .973 .908 r
.64266 .31291 .64879 .31327 .66177 .30598 .6557 .30502 Metetra
.51 .903 .935 r
.6557 .30502 .66177 .30598 .67494 .30171 .66892 .3003 Metetra
.249 .749 .897 r
.66892 .3003 .67494 .30171 .68834 .30074 .68238 .29905 Metetra
0 .521 .77 r
.68238 .29905 .68834 .30074 .70203 .30316 .69612 .30131 Metetra
.296 0 0 r
.69612 .30131 .70203 .30316 .71604 .30877 .71018 .30686 Metetra
.444 0 0 r
.71018 .30686 .71604 .30877 .73038 .31705 .72456 .31506 Metetra
.505 0 0 r
.72456 .31506 .73038 .31705 .74501 .327 .73923 .3248 Metetra
.478 0 0 r
.73923 .3248 .74501 .327 .75985 .33709 .75409 .33436 Metetra
.434 .833 .98 r
.75409 .33436 .75985 .33709 .77435 .34029 .76821 .33184 Metetra
.657 .749 .918 r
.76821 .33184 .77435 .34029 .78834 .33572 .78224 .32723 Metetra
.657 .749 .918 r
.78224 .32723 .78834 .33572 .80239 .33113 .79635 .3226 Metetra
.657 .749 .918 r
.79635 .3226 .80239 .33113 .81652 .32652 .81052 .31794 Metetra
.657 .749 .918 r
.81052 .31794 .81652 .32652 .83071 .32188 .82477 .31327 Metetra
.657 .749 .918 r
.82477 .31327 .83071 .32188 .84498 .31723 .83908 .30857 Metetra
.657 .749 .918 r
.20393 .5076 .21179 .51455 .22324 .51079 .2154 .50381 Metetra
.657 .749 .918 r
.2154 .50381 .22324 .51079 .23474 .50702 .22693 .5 Metetra
.657 .749 .918 r
.22693 .5 .23474 .50702 .24628 .50322 .23851 .49618 Metetra
.657 .749 .918 r
.23851 .49618 .24628 .50322 .25788 .49942 .25014 .49234 Metetra
.657 .749 .918 r
.25014 .49234 .25788 .49942 .26953 .49559 .26182 .48848 Metetra
.657 .749 .918 r
.26182 .48848 .26953 .49559 .28123 .49175 .27355 .48461 Metetra
.793 .77 .832 r
.27355 .48461 .28123 .49175 .29384 .47568 .28579 .47448 Metetra
.913 .881 .789 r
.28579 .47448 .29384 .47568 .30654 .45782 .29854 .45705 Metetra
.912 .898 .8 r
.29854 .45705 .30654 .45782 .31912 .44105 .31119 .44048 Metetra
.896 .923 .83 r
.31119 .44048 .31912 .44105 .33152 .42659 .32367 .42614 Metetra
.853 .952 .878 r
.32367 .42614 .33152 .42659 .34373 .41517 .33594 .41487 Metetra
.746 .968 .932 r
.33594 .41487 .34373 .41517 .35576 .40714 .34802 .40708 Metetra
.496 .899 .925 r
.34802 .40708 .35576 .40714 .36765 .40252 .35995 .40283 Metetra
.081 .641 .738 r
.35995 .40283 .36765 .40252 .37944 .40109 .37177 .40192 Metetra
.284 0 0 r
.37177 .40192 .37944 .40109 .39119 .40248 .38354 .40396 Metetra
.486 0 0 r
.38354 .40396 .39119 .40248 .40294 .40614 .39531 .40839 Metetra
.581 .04 0 r
.39531 .40839 .40294 .40614 .41475 .41145 .40713 .41457 Metetra
.621 .103 0 r
.40713 .41457 .41475 .41145 .42665 .41774 .41906 .42176 Metetra
.629 .127 .039 r
.41906 .42176 .42665 .41774 .43868 .4243 .43111 .42921 Metetra
.616 .123 .059 r
.43111 .42921 .43868 .4243 .45086 .43042 .44333 .43619 Metetra
.583 .094 .059 r
.44333 .43619 .45086 .43042 .46319 .43546 .45571 .44199 Metetra
.53 .042 .042 r
.45571 .44199 .46319 .43546 .47567 .43886 .46826 .446 Metetra
.45 0 .005 r
.46826 .446 .47567 .43886 .48829 .44012 .48096 .4477 Metetra
.339 0 0 r
.48096 .4477 .48829 .44012 .50104 .43893 .49379 .44674 Metetra
.188 0 0 r
.49379 .44674 .50104 .43893 .51387 .43509 .50672 .4429 Metetra
.001 0 0 r
.50672 .4429 .51387 .43509 .52677 .42856 .51973 .43616 Metetra
.51973 .43616 .52677 .42856 .5397 .4195 .53277 .42667 Metetra
.53277 .42667 .5397 .4195 .55263 .40818 .54581 .41472 Metetra
.574 .861 .538 r
.54581 .41472 .55263 .40818 .56554 .39503 .55883 .4008 Metetra
.691 .924 .602 r
.55883 .4008 .56554 .39503 .57842 .3806 .57182 .38549 Metetra
.765 .959 .651 r
.57182 .38549 .57842 .3806 .59126 .36554 .58476 .36946 Metetra
.807 .978 .692 r
.58476 .36946 .59126 .36554 .60408 .35052 .59767 .35348 Metetra
.821 .99 .732 r
.59767 .35348 .60408 .35052 .6169 .33628 .61057 .3383 Metetra
.81 .997 .776 r
.61057 .3383 .6169 .33628 .62974 .32353 .62349 .32468 Metetra
.765 .996 .825 r
.62349 .32468 .62974 .32353 .64266 .31291 .63647 .31331 Metetra
.668 .975 .873 r
.63647 .31331 .64266 .31291 .6557 .30502 .64958 .30479 Metetra
.489 .901 .896 r
.64958 .30479 .6557 .30502 .66892 .3003 .66286 .2996 Metetra
.214 .735 .848 r
.66286 .2996 .66892 .3003 .68238 .29905 .67637 .29801 Metetra
0 .497 .716 r
.67637 .29801 .68238 .29905 .69612 .30131 .69016 .30004 Metetra
.323 0 0 r
.69016 .30004 .69612 .30131 .71018 .30686 .70427 .3054 Metetra
.456 0 0 r
.70427 .3054 .71018 .30686 .72456 .31506 .7187 .31337 Metetra
.499 0 0 r
.7187 .31337 .72456 .31506 .73923 .3248 .73339 .32268 Metetra
0 .348 .666 r
.73339 .32268 .73923 .3248 .75409 .33436 .74799 .32794 Metetra
.65 .809 .96 r
.74799 .32794 .75409 .33436 .76821 .33184 .76201 .32331 Metetra
.657 .749 .918 r
.76201 .32331 .76821 .33184 .78224 .32723 .7761 .31866 Metetra
.657 .749 .918 r
.7761 .31866 .78224 .32723 .79635 .3226 .79025 .31399 Metetra
.657 .749 .918 r
.79025 .31399 .79635 .3226 .81052 .31794 .80447 .30929 Metetra
.657 .749 .918 r
.80447 .30929 .81052 .31794 .82477 .31327 .81877 .30457 Metetra
.657 .749 .918 r
.81877 .30457 .82477 .31327 .83908 .30857 .83313 .29983 Metetra
.657 .749 .918 r
.196 .50059 .20393 .5076 .2154 .50381 .2075 .49677 Metetra
.657 .749 .918 r
.2075 .49677 .2154 .50381 .22693 .5 .21906 .49293 Metetra
.657 .749 .918 r
.21906 .49293 .22693 .5 .23851 .49618 .23067 .48908 Metetra
.657 .749 .918 r
.23067 .48908 .23851 .49618 .25014 .49234 .24233 .4852 Metetra
.657 .749 .918 r
.24233 .4852 .25014 .49234 .26182 .48848 .25404 .48132 Metetra
.657 .749 .918 r
.25404 .48132 .26182 .48848 .27355 .48461 .2658 .47741 Metetra
.672 .753 .911 r
.2658 .47741 .27355 .48461 .28579 .47448 .27766 .47303 Metetra
.907 .882 .798 r
.27766 .47303 .28579 .47448 .29854 .45705 .29044 .45627 Metetra
.909 .902 .806 r
.29044 .45627 .29854 .45705 .31119 .44048 .30315 .44007 Metetra
.893 .929 .835 r
.30315 .44007 .31119 .44048 .32367 .42614 .31569 .42597 Metetra
.845 .961 .883 r
.31569 .42597 .32367 .42614 .33594 .41487 .32803 .41494 Metetra
.719 .972 .93 r
.32803 .41494 .33594 .41487 .34802 .40708 .34016 .40744 Metetra
.422 .866 .888 r
.34016 .40744 .34802 .40708 .35995 .40283 .35213 .40359 Metetra
.023 0 0 r
.35213 .40359 .35995 .40283 .37177 .40192 .36397 .4032 Metetra
.361 0 0 r
.36397 .4032 .37177 .40192 .38354 .40396 .37576 .40589 Metetra
.533 0 0 r
.37576 .40589 .38354 .40396 .39531 .40839 .38755 .41107 Metetra
.612 .087 0 r
.38755 .41107 .39531 .40839 .40713 .41457 .39939 .41808 Metetra
.645 .141 .035 r
.39939 .41808 .40713 .41457 .41906 .42176 .41133 .42615 Metetra
.65 .159 .072 r
.41133 .42615 .41906 .42176 .43111 .42921 .42341 .43448 Metetra
.636 .152 .086 r
.42341 .43448 .43111 .42921 .44333 .43619 .43566 .44229 Metetra
.602 .121 .083 r
.43566 .44229 .44333 .43619 .45571 .44199 .44809 .44883 Metetra
.548 .066 .063 r
.44809 .44883 .45571 .44199 .46826 .446 .4607 .45344 Metetra
.467 0 .023 r
.4607 .45344 .46826 .446 .48096 .4477 .47348 .45557 Metetra
.352 0 0 r
.47348 .45557 .48096 .4477 .49379 .44674 .48641 .45483 Metetra
.195 0 0 r
.48641 .45483 .49379 .44674 .50672 .4429 .49944 .451 Metetra
.49944 .451 .50672 .4429 .51973 .43616 .51256 .44405 Metetra
.51256 .44405 .51973 .43616 .53277 .42667 .52571 .43413 Metetra
.52571 .43413 .53277 .42667 .54581 .41472 .53887 .42158 Metetra
.593 .867 .535 r
.53887 .42158 .54581 .41472 .55883 .4008 .55201 .4069 Metetra
.707 .925 .595 r
.55201 .4069 .55883 .4008 .57182 .38549 .5651 .39072 Metetra
.778 .957 .639 r
.5651 .39072 .57182 .38549 .58476 .36946 .57815 .37376 Metetra
.816 .975 .676 r
.57815 .37376 .58476 .36946 .59767 .35348 .59116 .35683 Metetra
.829 .986 .714 r
.59116 .35683 .59767 .35348 .61057 .3383 .60415 .34074 Metetra
.816 .994 .755 r
.60415 .34074 .61057 .3383 .62349 .32468 .61715 .32627 Metetra
.771 .995 .802 r
.61715 .32627 .62349 .32468 .63647 .31331 .63021 .31415 Metetra
.673 .976 .849 r
.63021 .31415 .63647 .31331 .64958 .30479 .64338 .30502 Metetra
.489 .903 .871 r
.64338 .30502 .64958 .30479 .66286 .2996 .65673 .29933 Metetra
.209 .734 .821 r
.65673 .29933 .66286 .2996 .67637 .29801 .6703 .29735 Metetra
.096 0 0 r
.6703 .29735 .67637 .29801 .69016 .30004 .68414 .29908 Metetra
.323 0 0 r
.68414 .29908 .69016 .30004 .70427 .3054 .6983 .30415 Metetra
.444 0 0 r
.6983 .30415 .70427 .3054 .7187 .31337 .71276 .31172 Metetra
.47 0 0 r
.71276 .31172 .7187 .31337 .73339 .32268 .72746 .32037 Metetra
.283 .756 .937 r
.72746 .32037 .73339 .32268 .74799 .32794 .74169 .31938 Metetra
.657 .749 .918 r
.74169 .31938 .74799 .32794 .76201 .32331 .75576 .31471 Metetra
.657 .749 .918 r
.75576 .31471 .76201 .32331 .7761 .31866 .76989 .31001 Metetra
.657 .749 .918 r
.76989 .31001 .7761 .31866 .79025 .31399 .7841 .3053 Metetra
.657 .749 .918 r
.7841 .3053 .79025 .31399 .80447 .30929 .79837 .30056 Metetra
.657 .749 .918 r
.79837 .30056 .80447 .30929 .81877 .30457 .81271 .29579 Metetra
.657 .749 .918 r
.81271 .29579 .81877 .30457 .83313 .29983 .82713 .29101 Metetra
.657 .749 .918 r
.18801 .49352 .196 .50059 .2075 .49677 .19954 .48967 Metetra
.657 .749 .918 r
.19954 .48967 .2075 .49677 .21906 .49293 .21113 .4858 Metetra
.657 .749 .918 r
.21113 .4858 .21906 .49293 .23067 .48908 .22276 .48191 Metetra
.657 .749 .918 r
.22276 .48191 .23067 .48908 .24233 .4852 .23445 .47801 Metetra
.657 .749 .918 r
.23445 .47801 .24233 .4852 .25404 .48132 .2462 .47409 Metetra
.657 .749 .918 r
.2462 .47409 .25404 .48132 .2658 .47741 .25799 .47015 Metetra
.657 .749 .918 r
.25799 .47015 .2658 .47741 .27766 .47303 .26984 .46619 Metetra
.807 .781 .829 r
.26984 .46619 .27766 .47303 .29044 .45627 .28227 .4552 Metetra
.903 .901 .814 r
.28227 .4552 .29044 .45627 .30315 .44007 .29502 .43955 Metetra
.888 .931 .842 r
.29502 .43955 .30315 .44007 .31569 .42597 .30761 .42582 Metetra
.836 .964 .889 r
.30761 .42582 .31569 .42597 .32803 .41494 .32 .41509 Metetra
.696 .969 .931 r
.32 .41509 .32803 .41494 .34016 .40744 .33218 .40793 Metetra
.365 .835 .863 r
.33218 .40793 .34016 .40744 .35213 .40359 .34419 .40449 Metetra
.093 0 0 r
.34419 .40449 .35213 .40359 .36397 .4032 .35606 .40462 Metetra
.41 0 0 r
.35606 .40462 .36397 .4032 .37576 .40589 .36787 .40792 Metetra
.565 .016 0 r
.36787 .40792 .37576 .40589 .38755 .41107 .37967 .41383 Metetra
.635 .117 0 r
.37967 .41383 .38755 .41107 .39939 .41808 .39152 .42163 Metetra
.664 .166 .054 r
.39152 .42163 .39939 .41808 .41133 .42615 .40348 .43054 Metetra
.667 .181 .086 r
.40348 .43054 .41133 .42615 .42341 .43448 .41559 .4397 Metetra
.652 .17 .097 r
.41559 .4397 .42341 .43448 .43566 .44229 .42787 .4483 Metetra
.617 .137 .09 r
.42787 .4483 .43566 .44229 .44809 .44883 .44035 .45555 Metetra
.562 .078 .065 r
.44035 .45555 .44809 .44883 .4607 .45344 .45302 .46073 Metetra
.477 0 .02 r
.45302 .46073 .4607 .45344 .47348 .45557 .46588 .46326 Metetra
.354 0 0 r
.46588 .46326 .47348 .45557 .48641 .45483 .47889 .46274 Metetra
.183 0 0 r
.47889 .46274 .48641 .45483 .49944 .451 .49203 .45892 Metetra
.49203 .45892 .49944 .451 .51256 .44405 .50525 .45176 Metetra
.50525 .45176 .51256 .44405 .52571 .43413 .51852 .44144 Metetra
.51852 .44144 .52571 .43413 .53887 .42158 .5318 .4283 Metetra
.641 .893 .561 r
.5318 .4283 .53887 .42158 .55201 .4069 .54506 .4129 Metetra
.745 .941 .611 r
.54506 .4129 .55201 .4069 .5651 .39072 .55827 .39588 Metetra
.807 .965 .647 r
.55827 .39588 .5651 .39072 .57815 .37376 .57144 .37804 Metetra
.84 .978 .679 r
.57144 .37804 .57815 .37376 .59116 .35683 .58455 .36021 Metetra
.848 .987 .711 r
.58455 .36021 .59116 .35683 .60415 .34074 .59764 .34324 Metetra
.834 .994 .749 r
.59764 .34324 .60415 .34074 .61715 .32627 .61073 .32796 Metetra
.79 .997 .795 r
.61073 .32796 .61715 .32627 .63021 .31415 .62387 .31512 Metetra
.694 .982 .842 r
.62387 .31512 .63021 .31415 .64338 .30502 .63711 .30538 Metetra
.513 .915 .867 r
.63711 .30538 .64338 .30502 .65673 .29933 .65052 .29919 Metetra
.234 .752 .823 r
.65052 .29919 .65673 .29933 .6703 .29735 .66414 .29679 Metetra
.072 0 0 r
.66414 .29679 .6703 .29735 .68414 .29908 .67804 .29815 Metetra
.296 0 0 r
.67804 .29815 .68414 .29908 .6983 .30415 .69224 .3028 Metetra
.409 0 0 r
.69224 .3028 .6983 .30415 .71276 .31172 .70672 .3098 Metetra
.285 0 0 r
.70672 .3098 .71276 .31172 .72746 .32037 .72129 .31543 Metetra
.633 .855 .984 r
.72129 .31543 .72746 .32037 .74169 .31938 .73534 .31074 Metetra
.657 .749 .918 r
.73534 .31074 .74169 .31938 .75576 .31471 .74945 .30603 Metetra
.657 .749 .918 r
.74945 .30603 .75576 .31471 .76989 .31001 .76363 .30129 Metetra
.657 .749 .918 r
.76363 .30129 .76989 .31001 .7841 .3053 .77788 .29653 Metetra
.657 .749 .918 r
.77788 .29653 .7841 .3053 .79837 .30056 .79221 .29175 Metetra
.657 .749 .918 r
.79221 .29175 .79837 .30056 .81271 .29579 .8066 .28694 Metetra
.657 .749 .918 r
.8066 .28694 .81271 .29579 .82713 .29101 .82107 .28211 Metetra
.657 .749 .918 r
.17995 .4864 .18801 .49352 .19954 .48967 .19151 .48251 Metetra
.657 .749 .918 r
.19151 .48251 .19954 .48967 .21113 .4858 .20313 .47861 Metetra
.657 .749 .918 r
.20313 .47861 .21113 .4858 .22276 .48191 .21479 .47469 Metetra
.657 .749 .918 r
.21479 .47469 .22276 .48191 .23445 .47801 .22652 .47076 Metetra
.657 .749 .918 r
.22652 .47076 .23445 .47801 .2462 .47409 .23829 .4668 Metetra
.657 .749 .918 r
.23829 .4668 .2462 .47409 .25799 .47015 .25012 .46283 Metetra
.657 .749 .918 r
.25012 .46283 .25799 .47015 .26984 .46619 .262 .45884 Metetra
.696 .759 .9 r
.262 .45884 .26984 .46619 .28227 .4552 .27403 .45357 Metetra
.893 .894 .823 r
.27403 .45357 .28227 .4552 .29502 .43955 .28681 .43865 Metetra
.88 .926 .85 r
.28681 .43865 .29502 .43955 .30761 .42582 .29945 .4254 Metetra
.828 .96 .897 r
.29945 .4254 .30761 .42582 .32 .41509 .31189 .41506 Metetra
.68 .963 .938 r
.31189 .41506 .32 .41509 .33218 .40793 .32411 .40826 Metetra
.332 .815 .86 r
.32411 .40826 .33218 .40793 .34419 .40449 .33615 .40523 Metetra
.133 0 0 r
.33615 .40523 .34419 .40449 .35606 .40462 .34805 .40585 Metetra
.439 0 0 r
.34805 .40585 .35606 .40462 .36787 .40792 .35987 .40974 Metetra
.586 .04 0 r
.35987 .40974 .36787 .40792 .37967 .41383 .37169 .41631 Metetra
.653 .136 0 r
.37169 .41631 .37967 .41383 .39152 .42163 .38355 .42485 Metetra
.68 .182 .056 r
.38355 .42485 .39152 .42163 .40348 .43054 .39552 .43452 Metetra
.682 .194 .084 r
.39552 .43452 .40348 .43054 .41559 .4397 .40765 .44446 Metetra
.666 .181 .091 r
.40765 .44446 .41559 .4397 .42787 .4483 .41997 .4538 Metetra
.63 .144 .08 r
.41997 .4538 .42787 .4483 .44035 .45555 .43249 .46169 Metetra
.572 .08 .049 r
.43249 .46169 .44035 .45555 .45302 .46073 .44522 .46741 Metetra
.481 0 0 r
.44522 .46741 .45302 .46073 .46588 .46326 .45815 .47032 Metetra
.344 0 0 r
.45815 .47032 .46588 .46326 .47889 .46274 .47125 .46999 Metetra
.151 0 0 r
.47125 .46999 .47889 .46274 .49203 .45892 .48448 .46618 Metetra
.48448 .46618 .49203 .45892 .50525 .45176 .49782 .45883 Metetra
.49782 .45883 .50525 .45176 .51852 .44144 .51121 .44812 Metetra
.563 .862 .552 r
.51121 .44812 .51852 .44144 .5318 .4283 .52461 .43444 Metetra
.709 .932 .61 r
.52461 .43444 .5318 .4283 .54506 .4129 .53799 .41836 Metetra
.798 .963 .645 r
.53799 .41836 .54506 .4129 .55827 .39588 .55132 .40057 Metetra
.847 .975 .67 r
.55132 .40057 .55827 .39588 .57144 .37804 .5646 .3819 Metetra
.871 .982 .694 r
.5646 .3819 .57144 .37804 .58455 .36021 .57782 .36322 Metetra
.876 .988 .721 r
.57782 .36322 .58455 .36021 .59764 .34324 .59101 .34544 Metetra
.86 .994 .756 r
.59101 .34544 .59764 .34324 .61073 .32796 .60419 .3294 Metetra
.818 1 .8 r
.60419 .3294 .61073 .32796 .62387 .31512 .61742 .31589 Metetra
.728 .99 .849 r
.61742 .31589 .62387 .31512 .63711 .30538 .63074 .30556 Metetra
.558 .934 .882 r
.63074 .30556 .63711 .30538 .65052 .29919 .64421 .29887 Metetra
.287 .786 .851 r
.64421 .29887 .65052 .29919 .66414 .29679 .6579 .29603 Metetra
0 .561 .742 r
.6579 .29603 .66414 .29679 .67804 .29815 .67184 .29695 Metetra
.241 0 0 r
.67184 .29695 .67804 .29815 .69224 .3028 .68608 .30108 Metetra
.344 0 0 r
.68608 .30108 .69224 .3028 .70672 .3098 .70058 .30735 Metetra
.256 .736 .932 r
.70058 .30735 .70672 .3098 .72129 .31543 .71483 .30675 Metetra
.657 .749 .918 r
.71483 .30675 .72129 .31543 .73534 .31074 .72892 .30202 Metetra
.657 .749 .918 r
.72892 .30202 .73534 .31074 .74945 .30603 .74308 .29726 Metetra
.657 .749 .918 r
.74308 .29726 .74945 .30603 .76363 .30129 .75731 .29248 Metetra
.657 .749 .918 r
.75731 .29248 .76363 .30129 .77788 .29653 .77162 .28768 Metetra
.657 .749 .918 r
.77162 .28768 .77788 .29653 .79221 .29175 .78599 .28285 Metetra
.657 .749 .918 r
.78599 .28285 .79221 .29175 .8066 .28694 .80044 .278 Metetra
.657 .749 .918 r
.80044 .278 .8066 .28694 .82107 .28211 .81496 .27312 Metetra
.657 .749 .918 r
.17182 .47921 .17995 .4864 .19151 .48251 .18341 .4753 Metetra
.657 .749 .918 r
.18341 .4753 .19151 .48251 .20313 .47861 .19506 .47136 Metetra
.657 .749 .918 r
.19506 .47136 .20313 .47861 .21479 .47469 .20676 .46741 Metetra
.657 .749 .918 r
.20676 .46741 .21479 .47469 .22652 .47076 .21851 .46344 Metetra
.657 .749 .918 r
.21851 .46344 .22652 .47076 .23829 .4668 .23031 .45945 Metetra
.657 .749 .918 r
.23031 .45945 .23829 .4668 .25012 .46283 .24217 .45545 Metetra
.657 .749 .918 r
.24217 .45545 .25012 .46283 .262 .45884 .25409 .45142 Metetra
.657 .749 .918 r
.25409 .45142 .262 .45884 .27403 .45357 .26605 .44738 Metetra
.804 .802 .85 r
.26605 .44738 .27403 .45357 .28681 .43865 .27855 .43708 Metetra
.869 .915 .858 r
.27855 .43708 .28681 .43865 .29945 .4254 .29122 .42444 Metetra
.819 .95 .906 r
.29122 .42444 .29945 .4254 .31189 .41506 .3037 .41454 Metetra
.673 .954 .951 r
.3037 .41454 .31189 .41506 .32411 .40826 .31596 .40813 Metetra
.324 .807 .879 r
.31596 .40813 .32411 .40826 .33615 .40523 .32803 .4055 Metetra
.145 0 0 r
.32803 .4055 .33615 .40523 .34805 .40585 .33995 .40658 Metetra
.454 0 0 r
.33995 .40658 .34805 .40585 .35987 .40974 .35179 .41099 Metetra
.6 .051 0 r
.35179 .41099 .35987 .40974 .37169 .41631 .36362 .41817 Metetra
.667 .146 0 r
.36362 .41817 .37169 .41631 .38355 .42485 .37549 .42736 Metetra
.693 .19 .042 r
.37549 .42736 .38355 .42485 .39552 .43452 .38748 .43772 Metetra
.695 .201 .067 r
.38748 .43772 .39552 .43452 .40765 .44446 .39962 .44835 Metetra
.678 .186 .071 r
.39962 .44835 .40765 .44446 .41997 .4538 .41196 .45834 Metetra
.641 .144 .053 r
.41196 .45834 .41997 .4538 .43249 .46169 .42452 .46682 Metetra
.578 .072 .014 r
.42452 .46682 .43249 .46169 .44522 .46741 .43731 .47301 Metetra
.477 0 0 r
.43731 .47301 .44522 .46741 .45815 .47032 .4503 .47627 Metetra
.319 0 0 r
.4503 .47627 .45815 .47032 .47125 .46999 .46349 .47612 Metetra
.089 0 0 r
.46349 .47612 .47125 .46999 .48448 .46618 .47682 .4723 Metetra
.47682 .4723 .48448 .46618 .49782 .45883 .49026 .46477 Metetra
.467 .828 .567 r
.49026 .46477 .49782 .45883 .51121 .44812 .50376 .45372 Metetra
.666 .929 .638 r
.50376 .45372 .51121 .44812 .52461 .43444 .51729 .43954 Metetra
.787 .969 .671 r
.51729 .43954 .52461 .43444 .53799 .41836 .53079 .42284 Metetra
.854 .981 .688 r
.53079 .42284 .53799 .41836 .55132 .40057 .54425 .40434 Metetra
.889 .982 .7 r
.54425 .40434 .55132 .40057 .5646 .3819 .55764 .38492 Metetra
.904 .982 .715 r
.55764 .38492 .5646 .3819 .57782 .36322 .57098 .36549 Metetra
.904 .984 .737 r
.57098 .36549 .57782 .36322 .59101 .34544 .58427 .34697 Metetra
.888 .991 .768 r
.58427 .34697 .59101 .34544 .60419 .3294 .59754 .33025 Metetra
.849 .998 .812 r
.59754 .33025 .60419 .3294 .61742 .31589 .61086 .31613 Metetra
.769 .995 .864 r
.61086 .31613 .61742 .31589 .63074 .30556 .62425 .30525 Metetra
.616 .954 .907 r
.62425 .30525 .63074 .30556 .64421 .29887 .6378 .29808 Metetra
.363 .83 .898 r
.6378 .29808 .64421 .29887 .6579 .29603 .65154 .29478 Metetra
.068 .624 .81 r
.65154 .29478 .6579 .29603 .67184 .29695 .66554 .2952 Metetra
0 .435 .706 r
.66554 .2952 .67184 .29695 .68608 .30108 .6798 .29869 Metetra
0 .432 .736 r
.6798 .29869 .68608 .30108 .70058 .30735 .69424 .30275 Metetra
.626 .866 .988 r
.69424 .30275 .70058 .30735 .71483 .30675 .70831 .298 Metetra
.657 .749 .918 r
.70831 .298 .71483 .30675 .72892 .30202 .72245 .29322 Metetra
.657 .749 .918 r
.72245 .29322 .72892 .30202 .74308 .29726 .73666 .28842 Metetra
.657 .749 .918 r
.73666 .28842 .74308 .29726 .75731 .29248 .75094 .2836 Metetra
.657 .749 .918 r
.75094 .2836 .75731 .29248 .77162 .28768 .76529 .27875 Metetra
.657 .749 .918 r
.76529 .27875 .77162 .28768 .78599 .28285 .77972 .27387 Metetra
.657 .749 .918 r
.77972 .27387 .78599 .28285 .80044 .278 .79421 .26898 Metetra
.657 .749 .918 r
.79421 .26898 .80044 .278 .81496 .27312 .80879 .26406 Metetra
.657 .749 .918 r
.16362 .47197 .17182 .47921 .18341 .4753 .17525 .46802 Metetra
.657 .749 .918 r
.17525 .46802 .18341 .4753 .19506 .47136 .18692 .46405 Metetra
.657 .749 .918 r
.18692 .46405 .19506 .47136 .20676 .46741 .19865 .46007 Metetra
.657 .749 .918 r
.19865 .46007 .20676 .46741 .21851 .46344 .21044 .45607 Metetra
.657 .749 .918 r
.21044 .45607 .21851 .46344 .23031 .45945 .22227 .45205 Metetra
.657 .749 .918 r
.22227 .45205 .23031 .45945 .24217 .45545 .23416 .44801 Metetra
.657 .749 .918 r
.23416 .44801 .24217 .45545 .25409 .45142 .24611 .44395 Metetra
.657 .749 .918 r
.24611 .44395 .25409 .45142 .26605 .44738 .25811 .43987 Metetra
.693 .758 .902 r
.25811 .43987 .26605 .44738 .27855 .43708 .27026 .4346 Metetra
.854 .897 .866 r
.27026 .4346 .27855 .43708 .29122 .42444 .28295 .42268 Metetra
.809 .932 .914 r
.28295 .42268 .29122 .42444 .3037 .41454 .29545 .41328 Metetra
.672 .939 .965 r
.29545 .41328 .3037 .41454 .31596 .40813 .30775 .40727 Metetra
.339 .809 .915 r
.30775 .40727 .31596 .40813 .32803 .4055 .31985 .40503 Metetra
.13 0 0 r
.31985 .40503 .32803 .4055 .33995 .40658 .33179 .40651 Metetra
.452 0 0 r
.33179 .40651 .33995 .40658 .35179 .41099 .34365 .41137 Metetra
.606 .048 0 r
.34365 .41137 .35179 .41099 .36362 .41817 .35548 .41905 Metetra
.675 .146 0 r
.35548 .41905 .36362 .41817 .37549 .42736 .36736 .4288 Metetra
.703 .191 .01 r
.36736 .4288 .37549 .42736 .38748 .43772 .37936 .43974 Metetra
.706 .201 .034 r
.37936 .43974 .38748 .43772 .39962 .44835 .39152 .45096 Metetra
.689 .183 .032 r
.39152 .45096 .39962 .44835 .41196 .45834 .40388 .46152 Metetra
.649 .135 .006 r
.40388 .46152 .41196 .45834 .42452 .46682 .41648 .4705 Metetra
.579 .051 0 r
.41648 .4705 .42452 .46682 .43731 .47301 .42931 .4771 Metetra
.461 0 0 r
.42931 .4771 .43731 .47301 .4503 .47627 .44236 .48065 Metetra
.269 0 0 r
.44236 .48065 .4503 .47627 .46349 .47612 .45562 .48064 Metetra
.45562 .48064 .46349 .47612 .47682 .4723 .46905 .47682 Metetra
.46905 .47682 .47682 .4723 .49026 .46477 .48259 .46913 Metetra
.606 .927 .697 r
.48259 .46913 .49026 .46477 .50376 .45372 .49621 .45777 Metetra
.769 .982 .728 r
.49621 .45777 .50376 .45372 .51729 .43954 .50985 .44315 Metetra
.856 .991 .731 r
.50985 .44315 .51729 .43954 .53079 .42284 .52347 .42591 Metetra
.901 .984 .728 r
.52347 .42591 .53079 .42284 .54425 .40434 .53705 .40681 Metetra
.922 .976 .729 r
.53705 .40681 .54425 .40434 .55764 .38492 .55056 .38674 Metetra
.929 .972 .736 r
.55056 .38674 .55764 .38492 .57098 .36549 .56401 .36665 Metetra
.926 .972 .753 r
.56401 .36665 .57098 .36549 .58427 .34697 .5774 .34749 Metetra
.91 .978 .782 r
.5774 .34749 .58427 .34697 .59754 .33025 .59078 .33018 Metetra
.876 .987 .824 r
.59078 .33018 .59754 .33025 .61086 .31613 .60418 .31552 Metetra
.807 .99 .879 r
.60418 .31552 .61086 .31613 .62425 .30525 .61765 .30416 Metetra
.675 .965 .933 r
.61765 .30416 .62425 .30525 .6378 .29808 .63127 .29653 Metetra
.452 .868 .947 r
.63127 .29653 .6378 .29808 .65154 .29478 .64507 .29276 Metetra
.179 .694 .89 r
.64507 .29276 .65154 .29478 .66554 .2952 .65911 .29263 Metetra
0 .526 .81 r
.65911 .29263 .66554 .2952 .6798 .29869 .6734 .29539 Metetra
.374 .788 .979 r
.6734 .29539 .6798 .29869 .69424 .30275 .6876 .29396 Metetra
.657 .749 .918 r
.6876 .29396 .69424 .30275 .70831 .298 .70172 .28916 Metetra
.657 .749 .918 r
.70172 .28916 .70831 .298 .72245 .29322 .71591 .28434 Metetra
.657 .749 .918 r
.71591 .28434 .72245 .29322 .73666 .28842 .73017 .27949 Metetra
.657 .749 .918 r
.73017 .27949 .73666 .28842 .75094 .2836 .7445 .27463 Metetra
.657 .749 .918 r
.7445 .27463 .75094 .2836 .76529 .27875 .75891 .26973 Metetra
.657 .749 .918 r
.75891 .26973 .76529 .27875 .77972 .27387 .77338 .26481 Metetra
.657 .749 .918 r
.77338 .26481 .77972 .27387 .79421 .26898 .78793 .25987 Metetra
.657 .749 .918 r
.78793 .25987 .79421 .26898 .80879 .26406 .80256 .2549 Metetra
.657 .749 .918 r
.15536 .46467 .16362 .47197 .17525 .46802 .16701 .46068 Metetra
.657 .749 .918 r
.16701 .46068 .17525 .46802 .18692 .46405 .17872 .45668 Metetra
.657 .749 .918 r
.17872 .45668 .18692 .46405 .19865 .46007 .19048 .45267 Metetra
.657 .749 .918 r
.19048 .45267 .19865 .46007 .21044 .45607 .2023 .44863 Metetra
.657 .749 .918 r
.2023 .44863 .21044 .45607 .22227 .45205 .21416 .44457 Metetra
.657 .749 .918 r
.21416 .44457 .22227 .45205 .23416 .44801 .22609 .4405 Metetra
.657 .749 .918 r
.22609 .4405 .23416 .44801 .24611 .44395 .23806 .43641 Metetra
.657 .749 .918 r
.23806 .43641 .24611 .44395 .25811 .43987 .2501 .43229 Metetra
.657 .749 .918 r
.2501 .43229 .25811 .43987 .27026 .4346 .26218 .42816 Metetra
.768 .8 .879 r
.26218 .42816 .27026 .4346 .28295 .42268 .27465 .41987 Metetra
.795 .905 .918 r
.27465 .41987 .28295 .42268 .29545 .41328 .28718 .41103 Metetra
.673 .916 .975 r
.28718 .41103 .29545 .41328 .30775 .40727 .2995 .40544 Metetra
.372 .812 .957 r
.2995 .40544 .30775 .40727 .31985 .40503 .31163 .40354 Metetra
0 .499 .723 r
.31163 .40354 .31985 .40503 .33179 .40651 .32359 .40536 Metetra
.43 0 0 r
.32359 .40536 .33179 .40651 .34365 .41137 .33546 .41058 Metetra
.6 .031 0 r
.33546 .41058 .34365 .41137 .35548 .41905 .3473 .41866 Metetra
.676 .135 0 r
.3473 .41866 .35548 .41905 .36736 .4288 .35919 .42884 Metetra
.708 .183 0 r
.35919 .42884 .36736 .4288 .37936 .43974 .37119 .44025 Metetra
.712 .192 0 r
.37119 .44025 .37936 .43974 .39152 .45096 .38336 .45194 Metetra
.694 .17 0 r
.38336 .45194 .39152 .45096 .40388 .46152 .39574 .46294 Metetra
.65 .113 0 r
.39574 .46294 .40388 .46152 .41648 .4705 .40837 .47233 Metetra
.568 .011 0 r
.40837 .47233 .41648 .4705 .42931 .4771 .42124 .47925 Metetra
.422 0 0 r
.42124 .47925 .42931 .4771 .44236 .48065 .43435 .48303 Metetra
.176 0 0 r
.43435 .48303 .44236 .48065 .45562 .48064 .44768 .48314 Metetra
.44768 .48314 .45562 .48064 .46905 .47682 .46119 .47931 Metetra
.514 .908 .784 r
.46119 .47931 .46905 .47682 .48259 .46913 .47483 .47148 Metetra
.735 .99 .813 r
.47483 .47148 .48259 .46913 .49621 .45777 .48855 .45985 Metetra
.848 .998 .797 r
.48855 .45985 .49621 .45777 .50985 .44315 .5023 .44488 Metetra
.903 .984 .774 r
.5023 .44488 .50985 .44315 .52347 .42591 .51604 .42718 Metetra
.929 .968 .757 r
.51604 .42718 .52347 .42591 .53705 .40681 .52973 .40757 Metetra
.94 .956 .75 r
.52973 .40757 .53705 .40681 .55056 .38674 .54336 .38697 Metetra
.942 .95 .752 r
.54336 .38697 .55056 .38674 .56401 .36665 .55691 .36635 Metetra
.937 .95 .765 r
.55691 .36635 .56401 .36665 .5774 .34749 .57042 .34668 Metetra
.922 .955 .791 r
.57042 .34668 .5774 .34749 .59078 .33018 .58389 .32888 Metetra
.892 .965 .831 r
.58389 .32888 .59078 .33018 .60418 .31552 .59738 .31378 Metetra
.834 .971 .886 r
.59738 .31378 .60418 .31552 .61765 .30416 .61093 .302 Metetra
.724 .957 .947 r
.61093 .302 .61765 .30416 .63127 .29653 .62462 .29395 Metetra
.538 .888 .982 r
.62462 .29395 .63127 .29653 .64507 .29276 .63848 .28972 Metetra
.303 .753 .959 r
.63848 .28972 .64507 .29276 .65911 .29263 .65255 .28899 Metetra
.207 .675 .94 r
.65255 .28899 .65911 .29263 .6734 .29539 .66681 .2899 Metetra
.64 .844 .978 r
.66681 .2899 .6734 .29539 .6876 .29396 .68091 .28508 Metetra
.657 .749 .918 r
.68091 .28508 .6876 .29396 .70172 .28916 .69508 .28024 Metetra
.657 .749 .918 r
.69508 .28024 .70172 .28916 .71591 .28434 .70932 .27538 Metetra
.657 .749 .918 r
.70932 .27538 .71591 .28434 .73017 .27949 .72363 .27049 Metetra
.657 .749 .918 r
.72363 .27049 .73017 .27949 .7445 .27463 .73801 .26557 Metetra
.657 .749 .918 r
.73801 .26557 .7445 .27463 .75891 .26973 .75246 .26063 Metetra
.657 .749 .918 r
.75246 .26063 .75891 .26973 .77338 .26481 .76699 .25567 Metetra
.657 .749 .918 r
.76699 .25567 .77338 .26481 .78793 .25987 .78159 .25068 Metetra
.657 .749 .918 r
.78159 .25068 .78793 .25987 .80256 .2549 .79627 .24566 Metetra
.657 .749 .918 r
.14703 .4573 .15536 .46467 .16701 .46068 .15871 .45328 Metetra
.657 .749 .918 r
.15871 .45328 .16701 .46068 .17872 .45668 .17045 .44925 Metetra
.657 .749 .918 r
.17045 .44925 .17872 .45668 .19048 .45267 .18224 .4452 Metetra
.657 .749 .918 r
.18224 .4452 .19048 .45267 .2023 .44863 .19409 .44113 Metetra
.657 .749 .918 r
.19409 .44113 .2023 .44863 .21416 .44457 .20598 .43704 Metetra
.657 .749 .918 r
.20598 .43704 .21416 .44457 .22609 .4405 .21794 .43293 Metetra
.657 .749 .918 r
.21794 .43293 .22609 .4405 .23806 .43641 .22995 .4288 Metetra
.657 .749 .918 r
.22995 .4288 .23806 .43641 .2501 .43229 .24201 .42465 Metetra
.657 .749 .918 r
.24201 .42465 .2501 .43229 .26218 .42816 .25414 .42049 Metetra
.673 .754 .911 r
.25414 .42049 .26218 .42816 .27465 .41987 .26635 .41581 Metetra
.778 .871 .916 r
.26635 .41581 .27465 .41987 .28718 .41103 .27889 .40758 Metetra
.672 .882 .976 r
.27889 .40758 .28718 .41103 .2995 .40544 .29124 .40239 Metetra
.413 .804 .988 r
.29124 .40239 .2995 .40544 .31163 .40354 .30338 .4008 Metetra
0 .54 .815 r
.30338 .4008 .31163 .40354 .32359 .40536 .31537 .40288 Metetra
.381 0 0 r
.31537 .40288 .32359 .40536 .33546 .41058 .32725 .40837 Metetra
.575 0 0 r
.32725 .40837 .33546 .41058 .3473 .41866 .3391 .41672 Metetra
.664 .111 0 r
.3391 .41672 .3473 .41866 .35919 .42884 .35099 .4272 Metetra
.701 .163 0 r
.35099 .4272 .35919 .42884 .37119 .44025 .363 .43893 Metetra
.707 .172 0 r
.363 .43893 .37119 .44025 .38336 .45194 .37518 .45095 Metetra
.686 .144 0 r
.37518 .45095 .38336 .45194 .39574 .46294 .38757 .46227 Metetra
.634 .075 0 r
.38757 .46227 .39574 .46294 .40837 .47233 .40022 .47194 Metetra
.531 0 0 r
.40022 .47194 .40837 .47233 .42124 .47925 .41312 .4791 Metetra
.34 0 0 r
.41312 .4791 .42124 .47925 .43435 .48303 .42628 .48304 Metetra
.02 0 0 r
.42628 .48304 .43435 .48303 .44768 .48314 .43967 .48323 Metetra
.37 .837 .872 r
.43967 .48323 .44768 .48314 .46119 .47931 .45325 .47938 Metetra
.662 .968 .914 r
.45325 .47938 .46119 .47931 .47483 .47148 .46698 .47143 Metetra
.815 .988 .879 r
.46698 .47143 .47483 .47148 .48855 .45985 .4808 .4596 Metetra
.887 .972 .833 r
.4808 .4596 .48855 .45985 .5023 .44488 .49465 .44434 Metetra
.92 .951 .796 r
.49465 .44434 .5023 .44488 .51604 .42718 .5085 .4263 Metetra
.936 .934 .772 r
.5085 .4263 .51604 .42718 .52973 .40757 .52231 .40632 Metetra
.943 .922 .76 r
.52231 .40632 .52973 .40757 .54336 .38697 .53604 .38532 Metetra
.943 .917 .76 r
.53604 .38532 .54336 .38697 .55691 .36635 .54971 .36429 Metetra
.936 .917 .77 r
.54971 .36429 .55691 .36635 .57042 .34668 .56331 .34425 Metetra
.923 .923 .794 r
.56331 .34425 .57042 .34668 .58389 .32888 .57688 .3261 Metetra
.896 .932 .832 r
.57688 .3261 .58389 .32888 .59738 .31378 .59046 .31066 Metetra
.847 .939 .884 r
.59046 .31066 .59738 .31378 .61093 .302 .60409 .29854 Metetra
.756 .93 .945 r
.60409 .29854 .61093 .302 .62462 .29395 .61784 .29013 Metetra
.606 .882 .991 r
.61784 .29013 .62462 .29395 .63848 .28972 .63176 .28544 Metetra
.417 .783 .995 r
.63176 .28544 .63848 .28972 .65255 .28899 .64587 .28407 Metetra
.545 .825 .998 r
.64587 .28407 .65255 .28899 .66681 .2899 .66001 .28099 Metetra
.657 .749 .918 r
.66001 .28099 .66681 .2899 .68091 .28508 .67416 .27613 Metetra
.657 .749 .918 r
.67416 .27613 .68091 .28508 .69508 .28024 .68837 .27124 Metetra
.657 .749 .918 r
.68837 .27124 .69508 .28024 .70932 .27538 .70266 .26633 Metetra
.657 .749 .918 r
.70266 .26633 .70932 .27538 .72363 .27049 .71702 .26139 Metetra
.657 .749 .918 r
.71702 .26139 .72363 .27049 .73801 .26557 .73145 .25643 Metetra
.657 .749 .918 r
.73145 .25643 .73801 .26557 .75246 .26063 .74596 .25145 Metetra
.657 .749 .918 r
.74596 .25145 .75246 .26063 .76699 .25567 .76054 .24644 Metetra
.657 .749 .918 r
.76054 .24644 .76699 .25567 .78159 .25068 .77519 .2414 Metetra
.657 .749 .918 r
.77519 .2414 .78159 .25068 .79627 .24566 .78992 .23634 Metetra
.657 .749 .918 r
.13863 .44987 .14703 .4573 .15871 .45328 .15034 .44582 Metetra
.657 .749 .918 r
.15034 .44582 .15871 .45328 .17045 .44925 .16211 .44175 Metetra
.657 .749 .918 r
.16211 .44175 .17045 .44925 .18224 .4452 .17393 .43767 Metetra
.657 .749 .918 r
.17393 .43767 .18224 .4452 .19409 .44113 .1858 .43356 Metetra
.657 .749 .918 r
.1858 .43356 .19409 .44113 .20598 .43704 .19774 .42944 Metetra
.657 .749 .918 r
.19774 .42944 .20598 .43704 .21794 .43293 .20972 .42529 Metetra
.657 .749 .918 r
.20972 .42529 .21794 .43293 .22995 .4288 .22176 .42113 Metetra
.657 .749 .918 r
.22176 .42113 .22995 .4288 .24201 .42465 .23386 .41695 Metetra
.657 .749 .918 r
.23386 .41695 .24201 .42465 .25414 .42049 .24602 .41274 Metetra
.657 .749 .918 r
.24602 .41274 .25414 .42049 .26635 .41581 .25823 .40852 Metetra
.704 .774 .906 r
.25823 .40852 .26635 .41581 .27889 .40758 .27062 .40276 Metetra
.667 .841 .966 r
.27062 .40276 .27889 .40758 .29124 .40239 .28298 .39797 Metetra
.453 .783 .998 r
.28298 .39797 .29124 .40239 .30338 .4008 .29515 .39664 Metetra
.079 .576 .894 r
.29515 .39664 .30338 .4008 .31537 .40288 .30715 .39889 Metetra
0 .279 .647 r
.30715 .39889 .31537 .40288 .32725 .40837 .31904 .40452 Metetra
.52 0 0 r
.31904 .40452 .32725 .40837 .3391 .41672 .3309 .41302 Metetra
.629 .07 0 r
.3309 .41302 .3391 .41672 .35099 .4272 .3428 .42365 Metetra
.674 .127 0 r
.3428 .42365 .35099 .4272 .363 .43893 .35481 .43554 Metetra
.681 .135 0 r
.35481 .43554 .363 .43893 .37518 .45095 .36699 .44773 Metetra
.654 .099 0 r
.36699 .44773 .37518 .45095 .38757 .46227 .37939 .45922 Metetra
.584 .012 0 r
.37939 .45922 .38757 .46227 .40022 .47194 .39206 .46906 Metetra
.443 0 0 r
.39206 .46906 .40022 .47194 .41312 .4791 .40499 .47635 Metetra
0 .397 .7 r
.40499 .47635 .41312 .4791 .42628 .48304 .41819 .48037 Metetra
.185 .688 .909 r
.41819 .48037 .42628 .48304 .43967 .48323 .43163 .4806 Metetra
.53 .878 .987 r
.43163 .4806 .43967 .48323 .45325 .47938 .44528 .47671 Metetra
.738 .936 .952 r
.44528 .47671 .45325 .47938 .46698 .47143 .45908 .46868 Metetra
.84 .934 .89 r
.45908 .46868 .46698 .47143 .4808 .4596 .47298 .45671 Metetra
.889 .917 .836 r
.47298 .45671 .4808 .4596 .49465 .44434 .48693 .44126 Metetra
.914 .901 .798 r
.48693 .44126 .49465 .44434 .5085 .4263 .50088 .423 Metetra
.927 .888 .774 r
.50088 .423 .5085 .4263 .52231 .40632 .51479 .40276 Metetra
.932 .881 .762 r
.51479 .40276 .52231 .40632 .53604 .38532 .52863 .38151 Metetra
.931 .878 .76 r
.52863 .38151 .53604 .38532 .54971 .36429 .5424 .36025 Metetra
.926 .879 .77 r
.5424 .36025 .54971 .36429 .56331 .34425 .5561 .33997 Metetra
.913 .884 .791 r
.5561 .33997 .56331 .34425 .57688 .3261 .56976 .3216 Metetra
.889 .892 .825 r
.56976 .3216 .57688 .3261 .59046 .31066 .58342 .30595 Metetra
.846 .897 .874 r
.58342 .30595 .59046 .31066 .60409 .29854 .59713 .29359 Metetra
.77 .89 .93 r
.59713 .29359 .60409 .29854 .61784 .29013 .61094 .28487 Metetra
.651 .854 .978 r
.61094 .28487 .61784 .29013 .63176 .28544 .62491 .27973 Metetra
.551 .803 .992 r
.62491 .27973 .63176 .28544 .64587 .28407 .63902 .27688 Metetra
.654 .798 .952 r
.63902 .27688 .64587 .28407 .66001 .28099 .65315 .27199 Metetra
.657 .749 .918 r
.65315 .27199 .66001 .28099 .67416 .27613 .66734 .26709 Metetra
.657 .749 .918 r
.66734 .26709 .67416 .27613 .68837 .27124 .6816 .26216 Metetra
.657 .749 .918 r
.6816 .26216 .68837 .27124 .70266 .26633 .69594 .2572 Metetra
.657 .749 .918 r
.69594 .2572 .70266 .26633 .71702 .26139 .71035 .25222 Metetra
.657 .749 .918 r
.71035 .25222 .71702 .26139 .73145 .25643 .72483 .24721 Metetra
.657 .749 .918 r
.72483 .24721 .73145 .25643 .74596 .25145 .73939 .24218 Metetra
.657 .749 .918 r
.73939 .24218 .74596 .25145 .76054 .24644 .75402 .23712 Metetra
.657 .749 .918 r
.75402 .23712 .76054 .24644 .77519 .2414 .76873 .23203 Metetra
.657 .749 .918 r
.76873 .23203 .77519 .2414 .78992 .23634 .78351 .22692 Metetra
.657 .749 .918 r
.13015 .44238 .13863 .44987 .15034 .44582 .1419 .4383 Metetra
.657 .749 .918 r
.1419 .4383 .15034 .44582 .16211 .44175 .15369 .43419 Metetra
.657 .749 .918 r
.15369 .43419 .16211 .44175 .17393 .43767 .16555 .43007 Metetra
.657 .749 .918 r
.16555 .43007 .17393 .43767 .1858 .43356 .17745 .42593 Metetra
.657 .749 .918 r
.17745 .42593 .1858 .43356 .19774 .42944 .18942 .42177 Metetra
.657 .749 .918 r
.18942 .42177 .19774 .42944 .20972 .42529 .20144 .41759 Metetra
.657 .749 .918 r
.20144 .41759 .20972 .42529 .22176 .42113 .21351 .41339 Metetra
.657 .749 .918 r
.21351 .41339 .22176 .42113 .23386 .41695 .22564 .40917 Metetra
.657 .749 .918 r
.22564 .40917 .23386 .41695 .24602 .41274 .23783 .40494 Metetra
.657 .749 .918 r
.23783 .40494 .24602 .41274 .25823 .40852 .25008 .40068 Metetra
.657 .749 .918 r
.25008 .40068 .25823 .40852 .27062 .40276 .26238 .3964 Metetra
.657 .793 .947 r
.26238 .3964 .27062 .40276 .28298 .39797 .27474 .39205 Metetra
.485 .749 .988 r
.27474 .39205 .28298 .39797 .29515 .39664 .28693 .3909 Metetra
.177 .595 .94 r
.28693 .3909 .29515 .39664 .30715 .39889 .29895 .39324 Metetra
0 .345 .762 r
.29895 .39324 .30715 .39889 .31904 .40452 .31086 .39889 Metetra
.425 0 0 r
.31086 .39889 .31904 .40452 .3309 .41302 .32273 .40738 Metetra
.556 .008 0 r
.32273 .40738 .3309 .41302 .3428 .42365 .33463 .418 Metetra
.611 .07 0 r
.33463 .418 .3428 .42365 .35481 .43554 .34664 .4299 Metetra
.616 .076 0 r
.34664 .4299 .35481 .43554 .36699 .44773 .35882 .4421 Metetra
.575 .03 0 r
.35882 .4421 .36699 .44773 .37939 .45922 .37124 .45361 Metetra
.474 0 0 r
.37124 .45361 .37939 .45922 .39206 .46906 .38391 .46346 Metetra
0 .257 .683 r
.38391 .46346 .39206 .46906 .40499 .47635 .39686 .47077 Metetra
.018 .498 .874 r
.39686 .47077 .40499 .47635 .41819 .48037 .41009 .4748 Metetra
.355 .712 .986 r
.41009 .4748 .41819 .48037 .43163 .4806 .42357 .47501 Metetra
.608 .824 .983 r
.42357 .47501 .43163 .4806 .44528 .47671 .43727 .47109 Metetra
.752 .858 .927 r
.43727 .47109 .44528 .47671 .45908 .46868 .45114 .463 Metetra
.829 .86 .869 r
.45114 .463 .45908 .46868 .47298 .45671 .46512 .45095 Metetra
.871 .853 .822 r
.46512 .45095 .47298 .45671 .48693 .44126 .47915 .43541 Metetra
.894 .845 .789 r
.47915 .43541 .48693 .44126 .50088 .423 .49319 .41705 Metetra
.906 .839 .768 r
.49319 .41705 .50088 .423 .51479 .40276 .50719 .39672 Metetra
.912 .836 .757 r
.50719 .39672 .51479 .40276 .52863 .38151 .52113 .37538 Metetra
.913 .836 .756 r
.52113 .37538 .52863 .38151 .5424 .36025 .53499 .35404 Metetra
.908 .839 .764 r
.53499 .35404 .5424 .36025 .5561 .33997 .54878 .33369 Metetra
.897 .844 .784 r
.54878 .33369 .5561 .33997 .56976 .3216 .56253 .31525 Metetra
.875 .85 .815 r
.56253 .31525 .56976 .3216 .58342 .30595 .57627 .2995 Metetra
.836 .853 .857 r
.57627 .2995 .58342 .30595 .59713 .29359 .59006 .28701 Metetra
.772 .845 .907 r
.59006 .28701 .59713 .29359 .61094 .28487 .60393 .27804 Metetra
.676 .816 .95 r
.60393 .27804 .61094 .28487 .62491 .27973 .61794 .27249 Metetra
.645 .794 .954 r
.61794 .27249 .62491 .27973 .63902 .27688 .63205 .26784 Metetra
.657 .749 .918 r
.63205 .26784 .63902 .27688 .65315 .27199 .64622 .26292 Metetra
.657 .749 .918 r
.64622 .26292 .65315 .27199 .66734 .26709 .66046 .25796 Metetra
.657 .749 .918 r
.66046 .25796 .66734 .26709 .6816 .26216 .67477 .25299 Metetra
.657 .749 .918 r
.67477 .25299 .6816 .26216 .69594 .2572 .68916 .24798 Metetra
.657 .749 .918 r
.68916 .24798 .69594 .2572 .71035 .25222 .70362 .24295 Metetra
.657 .749 .918 r
.70362 .24295 .71035 .25222 .72483 .24721 .71815 .2379 Metetra
.657 .749 .918 r
.71815 .2379 .72483 .24721 .73939 .24218 .73276 .23282 Metetra
.657 .749 .918 r
.73276 .23282 .73939 .24218 .75402 .23712 .74745 .22771 Metetra
.657 .749 .918 r
.74745 .22771 .75402 .23712 .76873 .23203 .76221 .22258 Metetra
.657 .749 .918 r
.76221 .22258 .76873 .23203 .78351 .22692 .77704 .21742 Metetra
.657 .749 .918 r
.1216 .43483 .13015 .44238 .1419 .4383 .13338 .43071 Metetra
.657 .749 .918 r
.13338 .43071 .1419 .4383 .15369 .43419 .14521 .42657 Metetra
.657 .749 .918 r
.14521 .42657 .15369 .43419 .16555 .43007 .15709 .42241 Metetra
.657 .749 .918 r
.15709 .42241 .16555 .43007 .17745 .42593 .16903 .41824 Metetra
.657 .749 .918 r
.16903 .41824 .17745 .42593 .18942 .42177 .18103 .41404 Metetra
.657 .749 .918 r
.18103 .41404 .18942 .42177 .20144 .41759 .19308 .40982 Metetra
.657 .749 .918 r
.19308 .40982 .20144 .41759 .21351 .41339 .20518 .40559 Metetra
.657 .749 .918 r
.20518 .40559 .21351 .41339 .22564 .40917 .21735 .40133 Metetra
.657 .749 .918 r
.21735 .40133 .22564 .40917 .23783 .40494 .22957 .39706 Metetra
.657 .749 .918 r
.22957 .39706 .23783 .40494 .25008 .40068 .24185 .39276 Metetra
.657 .749 .918 r
.24185 .39276 .25008 .40068 .26238 .3964 .25419 .38845 Metetra
.643 .745 .923 r
.25419 .38845 .26238 .3964 .27474 .39205 .26655 .38455 Metetra
.508 .711 .963 r
.26655 .38455 .27474 .39205 .28693 .3909 .27875 .38353 Metetra
.264 .595 .95 r
.27875 .38353 .28693 .3909 .29895 .39324 .29079 .38585 Metetra
0 .399 .84 r
.29079 .38585 .29895 .39324 .31086 .39889 .30271 .3914 Metetra
0 .203 .683 r
.30271 .3914 .31086 .39889 .32273 .40738 .31459 .39973 Metetra
0 .07 .561 r
.31459 .39973 .32273 .40738 .33463 .418 .3265 .41018 Metetra
.499 0 0 r
.3265 .41018 .33463 .418 .34664 .4299 .33852 .4219 Metetra
.498 0 0 r
.33852 .4219 .34664 .4299 .35882 .4421 .35071 .43394 Metetra
0 .058 .56 r
.35071 .43394 .35882 .4421 .37124 .45361 .36312 .44531 Metetra
0 .173 .671 r
.36312 .44531 .37124 .45361 .38391 .46346 .3758 .45504 Metetra
0 .343 .811 r
.3758 .45504 .38391 .46346 .39686 .47077 .38877 .46225 Metetra
.195 .529 .922 r
.38877 .46225 .39686 .47077 .41009 .4748 .40202 .4662 Metetra
.45 .669 .956 r
.40202 .4662 .41009 .4748 .42357 .47501 .41553 .46634 Metetra
.63 .744 .93 r
.41553 .46634 .42357 .47501 .43727 .47109 .42927 .46238 Metetra
.74 .776 .882 r
.42927 .46238 .43727 .47109 .45114 .463 .44319 .45426 Metetra
.805 .788 .837 r
.44319 .45426 .45114 .463 .46512 .45095 .45723 .44221 Metetra
.844 .791 .8 r
.45723 .44221 .46512 .45095 .47915 .43541 .47133 .42668 Metetra
.867 .791 .774 r
.47133 .42668 .47915 .43541 .49319 .41705 .48544 .40835 Metetra
.881 .791 .757 r
.48544 .40835 .49319 .41705 .50719 .39672 .49953 .38807 Metetra
.889 .793 .748 r
.49953 .38807 .50719 .39672 .52113 .37538 .51355 .36681 Metetra
.89 .795 .748 r
.51355 .36681 .52113 .37538 .53499 .35404 .5275 .34556 Metetra
.887 .799 .757 r
.5275 .34556 .53499 .35404 .54878 .33369 .54138 .32531 Metetra
.876 .804 .774 r
.54138 .32531 .54878 .33369 .56253 .31525 .55521 .30695 Metetra
.856 .808 .802 r
.55521 .30695 .56253 .31525 .57627 .2995 .56902 .29125 Metetra
.821 .809 .839 r
.56902 .29125 .57627 .2995 .59006 .28701 .58287 .27872 Metetra
.765 .8 .881 r
.58287 .27872 .59006 .28701 .60393 .27804 .5968 .26957 Metetra
.686 .775 .918 r
.5968 .26957 .60393 .27804 .61794 .27249 .61085 .26368 Metetra
.657 .756 .923 r
.61085 .26368 .61794 .27249 .63205 .26784 .625 .25873 Metetra
.657 .749 .918 r
.625 .25873 .63205 .26784 .64622 .26292 .63922 .25375 Metetra
.657 .749 .918 r
.63922 .25375 .64622 .26292 .66046 .25796 .65351 .24875 Metetra
.657 .749 .918 r
.65351 .24875 .66046 .25796 .67477 .25299 .66787 .24373 Metetra
.657 .749 .918 r
.66787 .24373 .67477 .25299 .68916 .24798 .68231 .23868 Metetra
.657 .749 .918 r
.68231 .23868 .68916 .24798 .70362 .24295 .69682 .2336 Metetra
.657 .749 .918 r
.69682 .2336 .70362 .24295 .71815 .2379 .71141 .2285 Metetra
.657 .749 .918 r
.71141 .2285 .71815 .2379 .73276 .23282 .72607 .22337 Metetra
.657 .749 .918 r
.72607 .22337 .73276 .23282 .74745 .22771 .74081 .21821 Metetra
.657 .749 .918 r
.74081 .21821 .74745 .22771 .76221 .22258 .75562 .21303 Metetra
.657 .749 .918 r
.75562 .21303 .76221 .22258 .77704 .21742 .77051 .20782 Metetra
.657 .749 .918 r
.11299 .42721 .1216 .43483 .13338 .43071 .12479 .42305 Metetra
.657 .749 .918 r
.12479 .42305 .13338 .43071 .14521 .42657 .13665 .41888 Metetra
.657 .749 .918 r
.13665 .41888 .14521 .42657 .15709 .42241 .14857 .41469 Metetra
.657 .749 .918 r
.14857 .41469 .15709 .42241 .16903 .41824 .16054 .41047 Metetra
.657 .749 .918 r
.16054 .41047 .16903 .41824 .18103 .41404 .17256 .40624 Metetra
.657 .749 .918 r
.17256 .40624 .18103 .41404 .19308 .40982 .18465 .40199 Metetra
.657 .749 .918 r
.18465 .40199 .19308 .40982 .20518 .40559 .19679 .39772 Metetra
.657 .749 .918 r
.19679 .39772 .20518 .40559 .21735 .40133 .20898 .39342 Metetra
.657 .749 .918 r
.20898 .39342 .21735 .40133 .22957 .39706 .22124 .38911 Metetra
.657 .749 .918 r
.22124 .38911 .22957 .39706 .24185 .39276 .23355 .38478 Metetra
.657 .749 .918 r
.23355 .38478 .24185 .39276 .25419 .38845 .24592 .38042 Metetra
.657 .749 .918 r
.24592 .38042 .25419 .38845 .26655 .38455 .25835 .37605 Metetra
.546 .699 .94 r
.25835 .37605 .26655 .38455 .27875 .38353 .27062 .37451 Metetra
.333 .584 .935 r
.27062 .37451 .27875 .38353 .29079 .38585 .28268 .37672 Metetra
.088 .435 .875 r
.28268 .37672 .29079 .38585 .30271 .3914 .29462 .38202 Metetra
0 .273 .769 r
.29462 .38202 .30271 .3914 .31459 .39973 .30652 .39005 Metetra
0 .153 .675 r
.30652 .39005 .31459 .39973 .3265 .41018 .31844 .40016 Metetra
0 .093 .625 r
.31844 .40016 .3265 .41018 .33852 .4219 .33046 .41153 Metetra
0 .093 .629 r
.33046 .41153 .33852 .4219 .35071 .43394 .34265 .42323 Metetra
0 .147 .68 r
.34265 .42323 .35071 .43394 .36312 .44531 .35507 .4343 Metetra
0 .251 .762 r
.35507 .4343 .36312 .44531 .3758 .45504 .36775 .44376 Metetra
.09 .386 .846 r
.36775 .44376 .3758 .45504 .38877 .46225 .38073 .45075 Metetra
.309 .517 .895 r
.38073 .45075 .38877 .46225 .40202 .4662 .39399 .45453 Metetra
.496 .615 .899 r
.39399 .45453 .40202 .4662 .41553 .46634 .40752 .45457 Metetra
.63 .675 .874 r
.40752 .45457 .41553 .46634 .42927 .46238 .42129 .45055 Metetra
.72 .708 .839 r
.42129 .45055 .42927 .46238 .44319 .45426 .43525 .44244 Metetra
.777 .726 .805 r
.43525 .44244 .44319 .45426 .45723 .44221 .44933 .43045 Metetra
.815 .737 .778 r
.44933 .43045 .45723 .44221 .47133 .42668 .46349 .41503 Metetra
.839 .743 .758 r
.46349 .41503 .47133 .42668 .48544 .40835 .47767 .39687 Metetra
.855 .748 .745 r
.47767 .39687 .48544 .40835 .49953 .38807 .49182 .37681 Metetra
.864 .753 .739 r
.49182 .37681 .49953 .38807 .51355 .36681 .50591 .35579 Metetra
.867 .757 .739 r
.50591 .35579 .51355 .36681 .5275 .34556 .51994 .3348 Metetra
.864 .762 .748 r
.51994 .3348 .5275 .34556 .54138 .32531 .53389 .31481 Metetra
.855 .766 .764 r
.53389 .31481 .54138 .32531 .55521 .30695 .54779 .29669 Metetra
.836 .77 .789 r
.54779 .29669 .55521 .30695 .56902 .29125 .56168 .28117 Metetra
.803 .769 .821 r
.56168 .28117 .56902 .29125 .58287 .27872 .57559 .2687 Metetra
.754 .759 .857 r
.57559 .2687 .58287 .27872 .5968 .26957 .58957 .25949 Metetra
.656 .725 .899 r
.58957 .25949 .5968 .26957 .61085 .26368 .6037 .25452 Metetra
.657 .749 .918 r
.6037 .25452 .61085 .26368 .625 .25873 .61789 .24952 Metetra
.657 .749 .918 r
.61789 .24952 .625 .25873 .63922 .25375 .63216 .2445 Metetra
.657 .749 .918 r
.63216 .2445 .63922 .25375 .65351 .24875 .6465 .23946 Metetra
.657 .749 .918 r
.6465 .23946 .65351 .24875 .66787 .24373 .66091 .23438 Metetra
.657 .749 .918 r
.66091 .23438 .66787 .24373 .68231 .23868 .6754 .22929 Metetra
.657 .749 .918 r
.6754 .22929 .68231 .23868 .69682 .2336 .68996 .22416 Metetra
.657 .749 .918 r
.68996 .22416 .69682 .2336 .71141 .2285 .7046 .21901 Metetra
.657 .749 .918 r
.7046 .21901 .71141 .2285 .72607 .22337 .71931 .21383 Metetra
.657 .749 .918 r
.71931 .21383 .72607 .22337 .74081 .21821 .73411 .20863 Metetra
.657 .749 .918 r
.73411 .20863 .74081 .21821 .75562 .21303 .74897 .20339 Metetra
.657 .749 .918 r
.74897 .20339 .75562 .21303 .77051 .20782 .76392 .19814 Metetra
.657 .749 .918 r
.10429 .41952 .11299 .42721 .12479 .42305 .11613 .41533 Metetra
.657 .749 .918 r
.11613 .41533 .12479 .42305 .13665 .41888 .12802 .41112 Metetra
.657 .749 .918 r
.12802 .41112 .13665 .41888 .14857 .41469 .13996 .40689 Metetra
.657 .749 .918 r
.13996 .40689 .14857 .41469 .16054 .41047 .15197 .40264 Metetra
.657 .749 .918 r
.15197 .40264 .16054 .41047 .17256 .40624 .16403 .39838 Metetra
.657 .749 .918 r
.16403 .39838 .17256 .40624 .18465 .40199 .17614 .39409 Metetra
.657 .749 .918 r
.17614 .39409 .18465 .40199 .19679 .39772 .18831 .38978 Metetra
.657 .749 .918 r
.18831 .38978 .19679 .39772 .20898 .39342 .20055 .38545 Metetra
.657 .749 .918 r
.20055 .38545 .20898 .39342 .22124 .38911 .21283 .3811 Metetra
.657 .749 .918 r
.21283 .3811 .22124 .38911 .23355 .38478 .22518 .37672 Metetra
.657 .749 .918 r
.22518 .37672 .23355 .38478 .24592 .38042 .23759 .37233 Metetra
.657 .749 .918 r
.23759 .37233 .24592 .38042 .25835 .37605 .25005 .36792 Metetra
.644 .745 .923 r
.25005 .36792 .25835 .37605 .27062 .37451 .26254 .36389 Metetra
.385 .57 .91 r
.26254 .36389 .27062 .37451 .28268 .37672 .27463 .36588 Metetra
.193 .455 .878 r
.27463 .36588 .28268 .37672 .29462 .38202 .2866 .37082 Metetra
.007 .327 .812 r
.2866 .37082 .29462 .38202 .30652 .39005 .29851 .37839 Metetra
0 .225 .746 r
.29851 .37839 .30652 .39005 .31844 .40016 .31045 .388 Metetra
0 .173 .708 r
.31045 .388 .31844 .40016 .33046 .41153 .32248 .39885 Metetra
0 .172 .709 r
.32248 .39885 .33046 .41153 .34265 .42323 .33468 .41006 Metetra
0 .219 .742 r
.33468 .41006 .34265 .42323 .35507 .4343 .3471 .42066 Metetra
.046 .302 .791 r
.3471 .42066 .35507 .4343 .36775 .44376 .35978 .42971 Metetra
.211 .402 .833 r
.35978 .42971 .36775 .44376 .38073 .45075 .37276 .43637 Metetra
.377 .496 .852 r
.37276 .43637 .38073 .45075 .39399 .45453 .38602 .4399 Metetra
.518 .57 .847 r
.38602 .4399 .39399 .45453 .40752 .45457 .39957 .43977 Metetra
.624 .621 .827 r
.39957 .43977 .40752 .45457 .42129 .45055 .41335 .43569 Metetra
.7 .655 .802 r
.41335 .43569 .42129 .45055 .43525 .44244 .42733 .42762 Metetra
.752 .677 .778 r
.42733 .42762 .43525 .44244 .44933 .43045 .44145 .41575 Metetra
.788 .691 .757 r
.44145 .41575 .44933 .43045 .46349 .41503 .45565 .40056 Metetra
.813 .702 .742 r
.45565 .40056 .46349 .41503 .47767 .39687 .46988 .3827 Metetra
.83 .71 .733 r
.46988 .3827 .47767 .39687 .49182 .37681 .48408 .36299 Metetra
.839 .717 .729 r
.48408 .36299 .49182 .37681 .50591 .35579 .49824 .34238 Metetra
.844 .723 .731 r
.49824 .34238 .50591 .35579 .51994 .3348 .51233 .32182 Metetra
.842 .729 .739 r
.51233 .32182 .51994 .3348 .53389 .31481 .52634 .30226 Metetra
.833 .733 .754 r
.52634 .30226 .53389 .31481 .54779 .29669 .54031 .28453 Metetra
.815 .735 .777 r
.54031 .28453 .54779 .29669 .56168 .28117 .55426 .26931 Metetra
.785 .733 .805 r
.55426 .26931 .56168 .28117 .57559 .2687 .56823 .25702 Metetra
.693 .706 .857 r
.56823 .25702 .57559 .2687 .58957 .25949 .5823 .25029 Metetra
.657 .749 .918 r
.5823 .25029 .58957 .25949 .6037 .25452 .59647 .24528 Metetra
.657 .749 .918 r
.59647 .24528 .6037 .25452 .61789 .24952 .61071 .24023 Metetra
.657 .749 .918 r
.61071 .24023 .61789 .24952 .63216 .2445 .62503 .23517 Metetra
.657 .749 .918 r
.62503 .23517 .63216 .2445 .6465 .23946 .63942 .23007 Metetra
.657 .749 .918 r
.63942 .23007 .6465 .23946 .66091 .23438 .65388 .22495 Metetra
.657 .749 .918 r
.65388 .22495 .66091 .23438 .6754 .22929 .66842 .2198 Metetra
.657 .749 .918 r
.66842 .2198 .6754 .22929 .68996 .22416 .68304 .21463 Metetra
.657 .749 .918 r
.68304 .21463 .68996 .22416 .7046 .21901 .69773 .20943 Metetra
.657 .749 .918 r
.69773 .20943 .7046 .21901 .71931 .21383 .71249 .2042 Metetra
.657 .749 .918 r
.71249 .2042 .71931 .21383 .73411 .20863 .72734 .19895 Metetra
.657 .749 .918 r
.72734 .19895 .73411 .20863 .74897 .20339 .74226 .19366 Metetra
.657 .749 .918 r
.74226 .19366 .74897 .20339 .76392 .19814 .75726 .18835 Metetra
.657 .749 .918 r
.09552 .41177 .10429 .41952 .11613 .41533 .10739 .40755 Metetra
.657 .749 .918 r
.10739 .40755 .11613 .41533 .12802 .41112 .11931 .4033 Metetra
.657 .749 .918 r
.11931 .4033 .12802 .41112 .13996 .40689 .13129 .39903 Metetra
.657 .749 .918 r
.13129 .39903 .13996 .40689 .15197 .40264 .14332 .39475 Metetra
.657 .749 .918 r
.14332 .39475 .15197 .40264 .16403 .39838 .15541 .39044 Metetra
.657 .749 .918 r
.15541 .39044 .16403 .39838 .17614 .39409 .16756 .38611 Metetra
.657 .749 .918 r
.16756 .38611 .17614 .39409 .18831 .38978 .17977 .38177 Metetra
.657 .749 .918 r
.17977 .38177 .18831 .38978 .20055 .38545 .19203 .3774 Metetra
.657 .749 .918 r
.19203 .3774 .20055 .38545 .21283 .3811 .20436 .37301 Metetra
.657 .749 .918 r
.20436 .37301 .21283 .3811 .22518 .37672 .21674 .3686 Metetra
.657 .749 .918 r
.21674 .3686 .22518 .37672 .23759 .37233 .22918 .36417 Metetra
.657 .749 .918 r
.22918 .36417 .23759 .37233 .25005 .36792 .24168 .35972 Metetra
.657 .749 .918 r
.24168 .35972 .25005 .36792 .26254 .36389 .25424 .35524 Metetra
.553 .703 .939 r
.25424 .35524 .26254 .36389 .27463 .36588 .26664 .35346 Metetra
.274 .466 .867 r
.26664 .35346 .27463 .36588 .2866 .37082 .27864 .35793 Metetra
.126 .365 .825 r
.27864 .35793 .2866 .37082 .29851 .37839 .29058 .3649 Metetra
.017 .281 .779 r
.29058 .3649 .29851 .37839 .31045 .388 .30254 .37385 Metetra
0 .236 .75 r
.30254 .37385 .31045 .388 .32248 .39885 .31458 .38403 Metetra
0 .233 .746 r
.31458 .38403 .32248 .39885 .33468 .41006 .32679 .39457 Metetra
.052 .269 .763 r
.32679 .39457 .33468 .41006 .3471 .42066 .33921 .40456 Metetra
.161 .332 .788 r
.33921 .40456 .3471 .42066 .35978 .42971 .3519 .41307 Metetra
.292 .406 .807 r
.3519 .41307 .35978 .42971 .37276 .43637 .36487 .41928 Metetra
.42 .477 .814 r
.36487 .41928 .37276 .43637 .38602 .4399 .37814 .42247 Metetra
.53 .536 .806 r
.37814 .42247 .38602 .4399 .39957 .43977 .39168 .42214 Metetra
.617 .581 .791 r
.39168 .42214 .39957 .43977 .41335 .43569 .40547 .41799 Metetra
.682 .614 .773 r
.40547 .41799 .41335 .43569 .42733 .42762 .41946 .40998 Metetra
.73 .637 .755 r
.41946 .40998 .42733 .42762 .44145 .41575 .4336 .39832 Metetra
.765 .655 .74 r
.4336 .39832 .44145 .41575 .45565 .40056 .44783 .38344 Metetra
.79 .668 .729 r
.44783 .38344 .45565 .40056 .46988 .3827 .46209 .366 Metetra
.806 .678 .722 r
.46209 .366 .46988 .3827 .48408 .36299 .47633 .3468 Metetra
.817 .687 .72 r
.47633 .3468 .48408 .36299 .49824 .34238 .49054 .32675 Metetra
.822 .694 .723 r
.49054 .32675 .49824 .34238 .51233 .32182 .50467 .30678 Metetra
.82 .7 .732 r
.50467 .30678 .51233 .32182 .52634 .30226 .51875 .2878 Metetra
.812 .704 .746 r
.51875 .2878 .52634 .30226 .54031 .28453 .53277 .2706 Metetra
.795 .706 .766 r
.53277 .2706 .54031 .28453 .55426 .26931 .54677 .25581 Metetra
.736 .691 .808 r
.54677 .25581 .55426 .26931 .56823 .25702 .56081 .24605 Metetra
.655 .707 .886 r
.56081 .24605 .56823 .25702 .5823 .25029 .57496 .24101 Metetra
.657 .749 .918 r
.57496 .24101 .5823 .25029 .59647 .24528 .58918 .23595 Metetra
.657 .749 .918 r
.58918 .23595 .59647 .24528 .61071 .24023 .60347 .23086 Metetra
.657 .749 .918 r
.60347 .23086 .61071 .24023 .62503 .23517 .61783 .22574 Metetra
.657 .749 .918 r
.61783 .22574 .62503 .23517 .63942 .23007 .63227 .2206 Metetra
.657 .749 .918 r
.63227 .2206 .63942 .23007 .65388 .22495 .64679 .21543 Metetra
.657 .749 .918 r
.64679 .21543 .65388 .22495 .66842 .2198 .66138 .21023 Metetra
.657 .749 .918 r
.66138 .21023 .66842 .2198 .68304 .21463 .67605 .20501 Metetra
.657 .749 .918 r
.67605 .20501 .68304 .21463 .69773 .20943 .69079 .19976 Metetra
.657 .749 .918 r
.69079 .19976 .69773 .20943 .71249 .2042 .70561 .19448 Metetra
.657 .749 .918 r
.70561 .19448 .71249 .2042 .72734 .19895 .72051 .18917 Metetra
.657 .749 .918 r
.72051 .18917 .72734 .19895 .74226 .19366 .73548 .18384 Metetra
.657 .749 .918 r
.73548 .18384 .74226 .19366 .75726 .18835 .75054 .17848 Metetra
.657 .749 .918 r
.08668 .40395 .09552 .41177 .10739 .40755 .09858 .39969 Metetra
.657 .749 .918 r
.09858 .39969 .10739 .40755 .11931 .4033 .11053 .39541 Metetra
.657 .749 .918 r
.11053 .39541 .11931 .4033 .13129 .39903 .12254 .3911 Metetra
.657 .749 .918 r
.12254 .3911 .13129 .39903 .14332 .39475 .1346 .38678 Metetra
.657 .749 .918 r
.1346 .38678 .14332 .39475 .15541 .39044 .14673 .38244 Metetra
.657 .749 .918 r
.14673 .38244 .15541 .39044 .16756 .38611 .15891 .37807 Metetra
.657 .749 .918 r
.15891 .37807 .16756 .38611 .17977 .38177 .17115 .37369 Metetra
.657 .749 .918 r
.17115 .37369 .17977 .38177 .19203 .3774 .18345 .36928 Metetra
.657 .749 .918 r
.18345 .36928 .19203 .3774 .20436 .37301 .1958 .36485 Metetra
.657 .749 .918 r
.1958 .36485 .20436 .37301 .21674 .3686 .20822 .3604 Metetra
.657 .749 .918 r
.20822 .3604 .21674 .3686 .22918 .36417 .22069 .35593 Metetra
.657 .749 .918 r
.22069 .35593 .22918 .36417 .24168 .35972 .23323 .35144 Metetra
.657 .749 .918 r
.23323 .35144 .24168 .35972 .25424 .35524 .24583 .34693 Metetra
.657 .749 .918 r
.24583 .34693 .25424 .35524 .26664 .35346 .25848 .34239 Metetra
.434 .588 .906 r
.25848 .34239 .26664 .35346 .27864 .35793 .27075 .34351 Metetra
.218 .392 .823 r
.27075 .34351 .27864 .35793 .29058 .3649 .28272 .34977 Metetra
.129 .323 .79 r
.28272 .34977 .29058 .3649 .30254 .37385 .29471 .35793 Metetra
.088 .283 .766 r
.29471 .35793 .30254 .37385 .31458 .38403 .30677 .36729 Metetra
.1 .278 .758 r
.30677 .36729 .31458 .38403 .32679 .39457 .31899 .37702 Metetra
.156 .304 .764 r
.31899 .37702 .32679 .39457 .33921 .40456 .33142 .38625 Metetra
.244 .351 .775 r
.33142 .38625 .33921 .40456 .3519 .41307 .34411 .3941 Metetra
.346 .407 .782 r
.34411 .3941 .3519 .41307 .36487 .41928 .35708 .39976 Metetra
.447 .463 .783 r
.35708 .39976 .36487 .41928 .37814 .42247 .37034 .40255 Metetra
.537 .512 .776 r
.37034 .40255 .37814 .42247 .39168 .42214 .38387 .40197 Metetra
.61 .552 .764 r
.38387 .40197 .39168 .42214 .40547 .41799 .39766 .39774 Metetra
.668 .583 .75 r
.39766 .39774 .40547 .41799 .41946 .40998 .41165 .38982 Metetra
.712 .606 .737 r
.41165 .38982 .41946 .40998 .4336 .39832 .42579 .37841 Metetra
.745 .625 .726 r
.42579 .37841 .4336 .39832 .44783 .38344 .44003 .36394 Metetra
.769 .639 .718 r
.44003 .36394 .44783 .38344 .46209 .366 .45431 .34704 Metetra
.786 .651 .714 r
.45431 .34704 .46209 .366 .47633 .3468 .46858 .32848 Metetra
.797 .661 .713 r
.46858 .32848 .47633 .3468 .49054 .32675 .48282 .30913 Metetra
.801 .669 .717 r
.48282 .30913 .49054 .32675 .50467 .30678 .497 .28989 Metetra
.8 .675 .726 r
.497 .28989 .50467 .30678 .51875 .2878 .51111 .27163 Metetra
.792 .679 .739 r
.51111 .27163 .51875 .2878 .53277 .2706 .52518 .25509 Metetra
.766 .677 .764 r
.52518 .25509 .53277 .2706 .54677 .25581 .53923 .24179 Metetra
.645 .646 .837 r
.53923 .24179 .54677 .25581 .56081 .24605 .55335 .23673 Metetra
.657 .749 .918 r
.55335 .23673 .56081 .24605 .57496 .24101 .56755 .23164 Metetra
.657 .749 .918 r
.56755 .23164 .57496 .24101 .58918 .23595 .58181 .22653 Metetra
.657 .749 .918 r
.58181 .22653 .58918 .23595 .60347 .23086 .59615 .22139 Metetra
.657 .749 .918 r
.59615 .22139 .60347 .23086 .61783 .22574 .61057 .21622 Metetra
.657 .749 .918 r
.61057 .21622 .61783 .22574 .63227 .2206 .62506 .21103 Metetra
.657 .749 .918 r
.62506 .21103 .63227 .2206 .64679 .21543 .63963 .20581 Metetra
.657 .749 .918 r
.63963 .20581 .64679 .21543 .66138 .21023 .65427 .20057 Metetra
.657 .749 .918 r
.65427 .20057 .66138 .21023 .67605 .20501 .66899 .19529 Metetra
.657 .749 .918 r
.66899 .19529 .67605 .20501 .69079 .19976 .68378 .18999 Metetra
.657 .749 .918 r
.68378 .18999 .69079 .19976 .70561 .19448 .69865 .18466 Metetra
.657 .749 .918 r
.69865 .18466 .70561 .19448 .72051 .18917 .71361 .1793 Metetra
.657 .749 .918 r
.71361 .1793 .72051 .18917 .73548 .18384 .72864 .17392 Metetra
.657 .749 .918 r
.72864 .17392 .73548 .18384 .75054 .17848 .74375 .1685 Metetra
.657 .749 .918 r
.07776 .39607 .08668 .40395 .09858 .39969 .08969 .39177 Metetra
.657 .749 .918 r
.08969 .39177 .09858 .39969 .11053 .39541 .10167 .38745 Metetra
.657 .749 .918 r
.10167 .38745 .11053 .39541 .12254 .3911 .11371 .38311 Metetra
.657 .749 .918 r
.11371 .38311 .12254 .3911 .1346 .38678 .12581 .37874 Metetra
.657 .749 .918 r
.12581 .37874 .1346 .38678 .14673 .38244 .13796 .37436 Metetra
.657 .749 .918 r
.13796 .37436 .14673 .38244 .15891 .37807 .15018 .36996 Metetra
.657 .749 .918 r
.15018 .36996 .15891 .37807 .17115 .37369 .16245 .36553 Metetra
.657 .749 .918 r
.16245 .36553 .17115 .37369 .18345 .36928 .17478 .36109 Metetra
.657 .749 .918 r
.17478 .36109 .18345 .36928 .1958 .36485 .18717 .35662 Metetra
.657 .749 .918 r
.18717 .35662 .1958 .36485 .20822 .3604 .19962 .35213 Metetra
.657 .749 .918 r
.19962 .35213 .20822 .3604 .22069 .35593 .21213 .34762 Metetra
.657 .749 .918 r
.21213 .34762 .22069 .35593 .23323 .35144 .2247 .34309 Metetra
.657 .749 .918 r
.2247 .34309 .23323 .35144 .24583 .34693 .23734 .33854 Metetra
.657 .749 .918 r
.23734 .33854 .24583 .34693 .25848 .34239 .25003 .33396 Metetra
.657 .749 .918 r
.25003 .33396 .25848 .34239 .27075 .34351 .26279 .32936 Metetra
.338 .471 .847 r
.26279 .32936 .27075 .34351 .28272 .34977 .27493 .33326 Metetra
.216 .355 .79 r
.27493 .33326 .28272 .34977 .29471 .35793 .28695 .3405 Metetra
.181 .32 .77 r
.28695 .3405 .29471 .35793 .30677 .36729 .29905 .34891 Metetra
.189 .312 .76 r
.29905 .34891 .30677 .36729 .31899 .37702 .31128 .35771 Metetra
.233 .33 .758 r
.31128 .35771 .31899 .37702 .33142 .38625 .32372 .36607 Metetra
.303 .365 .761 r
.32372 .36607 .33142 .38625 .34411 .3941 .33641 .37314 Metetra
.385 .409 .762 r
.33641 .37314 .34411 .3941 .35708 .39976 .34937 .37816 Metetra
.467 .454 .76 r
.34937 .37816 .35708 .39976 .37034 .40255 .36262 .38048 Metetra
.542 .495 .753 r
.36262 .38048 .37034 .40255 .38387 .40197 .37615 .37962 Metetra
.605 .53 .744 r
.37615 .37962 .38387 .40197 .39766 .39774 .38992 .37531 Metetra
.656 .559 .734 r
.38992 .37531 .39766 .39774 .41165 .38982 .4039 .36751 Metetra
.696 .582 .724 r
.4039 .36751 .41165 .38982 .42579 .37841 .41803 .35641 Metetra
.727 .601 .716 r
.41803 .35641 .42579 .37841 .44003 .36394 .43227 .34242 Metetra
.751 .616 .71 r
.43227 .34242 .44003 .36394 .45431 .34704 .44655 .32616 Metetra
.767 .629 .707 r
.44655 .32616 .45431 .34704 .46858 .32848 .46084 .30835 Metetra
.778 .639 .708 r
.46084 .30835 .46858 .32848 .48282 .30913 .4751 .28982 Metetra
.783 .648 .712 r
.4751 .28982 .48282 .30913 .497 .28989 .4893 .27144 Metetra
.782 .654 .721 r
.4893 .27144 .497 .28989 .51111 .27163 .50345 .25402 Metetra
.775 .658 .734 r
.50345 .25402 .51111 .27163 .52518 .25509 .51755 .23824 Metetra
.648 .608 .795 r
.51755 .23824 .52518 .25509 .53923 .24179 .53165 .23243 Metetra
.657 .749 .918 r
.53165 .23243 .53923 .24179 .55335 .23673 .54582 .22732 Metetra
.657 .749 .918 r
.54582 .22732 .55335 .23673 .56755 .23164 .56006 .22218 Metetra
.657 .749 .918 r
.56006 .22218 .56755 .23164 .58181 .22653 .57438 .21702 Metetra
.657 .749 .918 r
.57438 .21702 .58181 .22653 .59615 .22139 .58877 .21183 Metetra
.657 .749 .918 r
.58877 .21183 .59615 .22139 .61057 .21622 .60324 .20662 Metetra
.657 .749 .918 r
.60324 .20662 .61057 .21622 .62506 .21103 .61778 .20138 Metetra
.657 .749 .918 r
.61778 .20138 .62506 .21103 .63963 .20581 .63239 .19611 Metetra
.657 .749 .918 r
.63239 .19611 .63963 .20581 .65427 .20057 .64709 .19081 Metetra
.657 .749 .918 r
.64709 .19081 .65427 .20057 .66899 .19529 .66186 .18548 Metetra
.657 .749 .918 r
.66186 .18548 .66899 .19529 .68378 .18999 .67671 .18013 Metetra
.657 .749 .918 r
.67671 .18013 .68378 .18999 .69865 .18466 .69163 .17475 Metetra
.657 .749 .918 r
.69163 .17475 .69865 .18466 .71361 .1793 .70664 .16934 Metetra
.657 .749 .918 r
.70664 .16934 .71361 .1793 .72864 .17392 .72173 .1639 Metetra
.657 .749 .918 r
.72173 .1639 .72864 .17392 .74375 .1685 .73689 .15843 Metetra
.657 .749 .918 r
.06876 .38811 .07776 .39607 .08969 .39177 .08072 .38378 Metetra
.657 .749 .918 r
.08072 .38378 .08969 .39177 .10167 .38745 .09273 .37942 Metetra
.657 .749 .918 r
.09273 .37942 .10167 .38745 .11371 .38311 .10481 .37504 Metetra
.657 .749 .918 r
.10481 .37504 .11371 .38311 .12581 .37874 .11694 .37064 Metetra
.657 .749 .918 r
.11694 .37064 .12581 .37874 .13796 .37436 .12912 .36622 Metetra
.657 .749 .918 r
.12912 .36622 .13796 .37436 .15018 .36996 .14137 .36177 Metetra
.657 .749 .918 r
.14137 .36177 .15018 .36996 .16245 .36553 .15368 .35731 Metetra
.657 .749 .918 r
.15368 .35731 .16245 .36553 .17478 .36109 .16604 .35282 Metetra
.657 .749 .918 r
.16604 .35282 .17478 .36109 .18717 .35662 .17847 .34832 Metetra
.657 .749 .918 r
.17847 .34832 .18717 .35662 .19962 .35213 .19095 .34379 Metetra
.657 .749 .918 r
.19095 .34379 .19962 .35213 .21213 .34762 .2035 .33924 Metetra
.657 .749 .918 r
.2035 .33924 .21213 .34762 .2247 .34309 .2161 .33466 Metetra
.657 .749 .918 r
.2161 .33466 .2247 .34309 .23734 .33854 .22877 .33007 Metetra
.657 .749 .918 r
.22877 .33007 .23734 .33854 .25003 .33396 .2415 .32545 Metetra
.657 .749 .918 r
.2415 .32545 .25003 .33396 .26279 .32936 .25429 .32081 Metetra
.657 .749 .918 r
.25429 .32081 .26279 .32936 .27493 .33326 .26715 .31615 Metetra
.299 .398 .797 r
.26715 .31615 .27493 .33326 .28695 .3405 .27925 .32188 Metetra
.254 .35 .769 r
.27925 .32188 .28695 .3405 .29905 .34891 .29138 .32924 Metetra
.258 .34 .757 r
.29138 .32924 .29905 .34891 .31128 .35771 .30365 .33701 Metetra
.292 .351 .752 r
.30365 .33701 .31128 .35771 .32372 .36607 .3161 .34439 Metetra
.348 .377 .75 r
.3161 .34439 .32372 .36607 .33641 .37314 .32879 .35061 Metetra
.415 .412 .748 r
.32879 .35061 .33641 .37314 .34937 .37816 .34175 .35492 Metetra
.483 .449 .744 r
.34175 .35492 .34937 .37816 .36262 .38048 .35499 .35671 Metetra
.546 .484 .737 r
.35499 .35671 .36262 .38048 .37615 .37962 .3685 .35554 Metetra
.601 .515 .73 r
.3685 .35554 .37615 .37962 .38992 .37531 .38225 .35114 Metetra
.647 .542 .722 r
.38225 .35114 .38992 .37531 .4039 .36751 .39621 .34347 Metetra
.684 .564 .714 r
.39621 .34347 .4039 .36751 .41803 .35641 .41033 .33273 Metetra
.713 .583 .708 r
.41033 .33273 .41803 .35641 .43227 .34242 .42455 .31929 Metetra
.735 .598 .704 r
.42455 .31929 .43227 .34242 .44655 .32616 .43882 .30374 Metetra
.752 .611 .702 r
.43882 .30374 .44655 .32616 .46084 .30835 .45311 .28678 Metetra
.762 .622 .704 r
.45311 .28678 .46084 .30835 .4751 .28982 .46738 .26918 Metetra
.767 .63 .709 r
.46738 .26918 .4751 .28982 .4893 .27144 .48159 .25176 Metetra
.766 .637 .719 r
.48159 .25176 .4893 .27144 .50345 .25402 .49576 .23527 Metetra
.662 .594 .769 r
.49576 .23527 .50345 .25402 .51755 .23824 .50986 .22811 Metetra
.656 .731 .904 r
.50986 .22811 .51755 .23824 .53165 .23243 .524 .22297 Metetra
.657 .749 .918 r
.524 .22297 .53165 .23243 .54582 .22732 .53822 .21782 Metetra
.657 .749 .918 r
.53822 .21782 .54582 .22732 .56006 .22218 .55251 .21263 Metetra
.657 .749 .918 r
.55251 .21263 .56006 .22218 .57438 .21702 .56687 .20742 Metetra
.657 .749 .918 r
.56687 .20742 .57438 .21702 .58877 .21183 .58132 .20218 Metetra
.657 .749 .918 r
.58132 .20218 .58877 .21183 .60324 .20662 .59583 .19692 Metetra
.657 .749 .918 r
.59583 .19692 .60324 .20662 .61778 .20138 .61042 .19162 Metetra
.657 .749 .918 r
.61042 .19162 .61778 .20138 .63239 .19611 .62509 .1863 Metetra
.657 .749 .918 r
.62509 .1863 .63239 .19611 .64709 .19081 .63984 .18095 Metetra
.657 .749 .918 r
.63984 .18095 .64709 .19081 .66186 .18548 .65466 .17558 Metetra
.657 .749 .918 r
.65466 .17558 .66186 .18548 .67671 .18013 .66956 .17017 Metetra
.657 .749 .918 r
.66956 .17017 .67671 .18013 .69163 .17475 .68454 .16474 Metetra
.657 .749 .918 r
.68454 .16474 .69163 .17475 .70664 .16934 .69961 .15927 Metetra
.657 .749 .918 r
.69961 .15927 .70664 .16934 .72173 .1639 .71475 .15378 Metetra
.657 .749 .918 r
.71475 .15378 .72173 .1639 .73689 .15843 .72997 .14826 Metetra
.657 .749 .918 r
.05968 .38009 .06876 .38811 .08072 .38378 .07167 .37571 Metetra
.657 .749 .918 r
.07167 .37571 .08072 .38378 .09273 .37942 .08372 .37132 Metetra
.657 .749 .918 r
.08372 .37132 .09273 .37942 .10481 .37504 .09582 .3669 Metetra
.657 .749 .918 r
.09582 .3669 .10481 .37504 .11694 .37064 .10798 .36246 Metetra
.657 .749 .918 r
.10798 .36246 .11694 .37064 .12912 .36622 .1202 .358 Metetra
.657 .749 .918 r
.1202 .358 .12912 .36622 .14137 .36177 .13248 .35352 Metetra
.657 .749 .918 r
.13248 .35352 .14137 .36177 .15368 .35731 .14482 .34901 Metetra
.657 .749 .918 r
.14482 .34901 .15368 .35731 .16604 .35282 .15722 .34449 Metetra
.657 .749 .918 r
.15722 .34449 .16604 .35282 .17847 .34832 .16968 .33994 Metetra
.657 .749 .918 r
.16968 .33994 .17847 .34832 .19095 .34379 .1822 .33537 Metetra
.657 .749 .918 r
.1822 .33537 .19095 .34379 .2035 .33924 .19478 .33078 Metetra
.657 .749 .918 r
.19478 .33078 .2035 .33924 .2161 .33466 .20742 .32616 Metetra
.657 .749 .918 r
.20742 .32616 .2161 .33466 .22877 .33007 .22013 .32153 Metetra
.657 .749 .918 r
.22013 .32153 .22877 .33007 .2415 .32545 .23289 .31687 Metetra
.657 .749 .918 r
.23289 .31687 .2415 .32545 .25429 .32081 .24572 .31218 Metetra
.657 .749 .918 r
.24572 .31218 .25429 .32081 .26715 .31615 .25862 .30748 Metetra
.657 .749 .918 r
.25862 .30748 .26715 .31615 .27925 .32188 .27157 .30275 Metetra
.32 .385 .773 r
.27157 .30275 .27925 .32188 .29138 .32924 .28377 .30865 Metetra
.312 .363 .755 r
.28377 .30865 .29138 .32924 .30365 .33701 .29607 .3153 Metetra
.338 .369 .747 r
.29607 .3153 .30365 .33701 .3161 .34439 .30855 .32164 Metetra
.383 .389 .742 r
.30855 .32164 .3161 .34439 .32879 .35061 .32125 .32693 Metetra
.438 .416 .738 r
.32125 .32693 .32879 .35061 .34175 .35492 .3342 .33048 Metetra
.495 .447 .733 r
.3342 .33048 .34175 .35492 .35499 .35671 .34743 .33171 Metetra
.55 .477 .727 r
.34743 .33171 .35499 .35671 .3685 .35554 .36091 .3302 Metetra
.598 .505 .72 r
.36091 .3302 .3685 .35554 .38225 .35114 .37464 .3257 Metetra
.639 .53 .713 r
.37464 .3257 .38225 .35114 .39621 .34347 .38857 .31819 Metetra
.674 .551 .707 r
.38857 .31819 .39621 .34347 .41033 .33273 .40266 .30783 Metetra
.701 .569 .703 r
.40266 .30783 .41033 .33273 .42455 .31929 .41686 .295 Metetra
.722 .584 .7 r
.41686 .295 .42455 .31929 .43882 .30374 .43112 .28023 Metetra
.738 .597 .7 r
.43112 .28023 .43882 .30374 .45311 .28678 .4454 .26417 Metetra
.748 .608 .703 r
.4454 .26417 .45311 .28678 .46738 .26918 .45966 .24758 Metetra
.753 .617 .708 r
.45966 .24758 .46738 .26918 .48159 .25176 .47388 .23119 Metetra
.657 .575 .751 r
.47388 .23119 .48159 .25176 .49576 .23527 .48797 .22377 Metetra
.653 .701 .881 r
.48797 .22377 .49576 .23527 .50986 .22811 .50208 .21861 Metetra
.657 .749 .918 r
.50208 .21861 .50986 .22811 .524 .22297 .51628 .21343 Metetra
.657 .749 .918 r
.51628 .21343 .524 .22297 .53822 .21782 .53054 .20823 Metetra
.657 .749 .918 r
.53054 .20823 .53822 .21782 .55251 .21263 .54488 .20299 Metetra
.657 .749 .918 r
.54488 .20299 .55251 .21263 .56687 .20742 .5593 .19773 Metetra
.657 .749 .918 r
.5593 .19773 .56687 .20742 .58132 .20218 .57379 .19244 Metetra
.657 .749 .918 r
.57379 .19244 .58132 .20218 .59583 .19692 .58835 .18712 Metetra
.657 .749 .918 r
.58835 .18712 .59583 .19692 .61042 .19162 .603 .18178 Metetra
.657 .749 .918 r
.603 .18178 .61042 .19162 .62509 .1863 .61772 .17641 Metetra
.657 .749 .918 r
.61772 .17641 .62509 .1863 .63984 .18095 .63252 .17101 Metetra
.657 .749 .918 r
.63252 .17101 .63984 .18095 .65466 .17558 .64739 .16558 Metetra
.657 .749 .918 r
.64739 .16558 .65466 .17558 .66956 .17017 .66235 .16012 Metetra
.657 .749 .918 r
.66235 .16012 .66956 .17017 .68454 .16474 .67738 .15463 Metetra
.657 .749 .918 r
.67738 .15463 .68454 .16474 .69961 .15927 .6925 .14911 Metetra
.657 .749 .918 r
.6925 .14911 .69961 .15927 .71475 .15378 .7077 .14356 Metetra
.657 .749 .918 r
.7077 .14356 .71475 .15378 .72997 .14826 .72298 .13799 Metetra
.657 .749 .918 r
.05052 .37199 .05968 .38009 .07167 .37571 .06254 .36758 Metetra
.657 .749 .918 r
.06254 .36758 .07167 .37571 .08372 .37132 .07462 .36314 Metetra
.657 .749 .918 r
.07462 .36314 .08372 .37132 .09582 .3669 .08676 .35869 Metetra
.657 .749 .918 r
.08676 .35869 .09582 .3669 .10798 .36246 .09895 .35421 Metetra
.657 .749 .918 r
.09895 .35421 .10798 .36246 .1202 .358 .11121 .34971 Metetra
.657 .749 .918 r
.11121 .34971 .1202 .358 .13248 .35352 .12352 .34518 Metetra
.657 .749 .918 r
.12352 .34518 .13248 .35352 .14482 .34901 .13589 .34064 Metetra
.657 .749 .918 r
.13589 .34064 .14482 .34901 .15722 .34449 .14832 .33607 Metetra
.657 .749 .918 r
.14832 .33607 .15722 .34449 .16968 .33994 .16082 .33149 Metetra
.657 .749 .918 r
.16082 .33149 .16968 .33994 .1822 .33537 .17337 .32687 Metetra
.657 .749 .918 r
.17337 .32687 .1822 .33537 .19478 .33078 .18599 .32224 Metetra
.657 .749 .918 r
.18599 .32224 .19478 .33078 .20742 .32616 .19867 .31758 Metetra
.657 .749 .918 r
.19867 .31758 .20742 .32616 .22013 .32153 .21141 .31291 Metetra
.657 .749 .918 r
.21141 .31291 .22013 .32153 .23289 .31687 .22421 .3082 Metetra
.657 .749 .918 r
.22421 .3082 .23289 .31687 .24572 .31218 .23708 .30348 Metetra
.657 .749 .918 r
.23708 .30348 .24572 .31218 .25862 .30748 .25001 .29873 Metetra
.657 .749 .918 r
.25001 .29873 .25862 .30748 .27157 .30275 .263 .29396 Metetra
.657 .749 .918 r
.263 .29396 .27157 .30275 .28377 .30865 .27606 .28916 Metetra
.399 .431 .778 r
.27606 .28916 .28377 .30865 .29607 .3153 .28853 .29299 Metetra
.376 .387 .744 r
.28853 .29299 .29607 .3153 .30855 .32164 .30103 .29824 Metetra
.412 .401 .738 r
.30103 .29824 .30855 .32164 .32125 .32693 .31375 .30255 Metetra
.458 .423 .732 r
.31375 .30255 .32125 .32693 .3342 .33048 .3267 .3053 Metetra
.506 .448 .726 r
.3267 .3053 .3342 .33048 .34743 .33171 .33992 .30594 Metetra
.554 .475 .72 r
.33992 .30594 .34743 .33171 .36091 .3302 .35338 .30408 Metetra
.597 .499 .714 r
.35338 .30408 .36091 .3302 .37464 .3257 .36708 .29949 Metetra
.634 .522 .709 r
.36708 .29949 .37464 .3257 .38857 .31819 .38098 .29214 Metetra
.665 .542 .704 r
.38098 .29214 .38857 .31819 .40266 .30783 .39504 .28219 Metetra
.691 .559 .7 r
.39504 .28219 .40266 .30783 .41686 .295 .4092 .26999 Metetra
.711 .574 .699 r
.4092 .26999 .41686 .295 .43112 .28023 .42344 .25604 Metetra
.726 .587 .7 r
.42344 .25604 .43112 .28023 .4454 .26417 .43769 .24095 Metetra
.735 .598 .703 r
.43769 .24095 .4454 .26417 .45966 .24758 .45194 .2254 Metetra
.628 .546 .742 r
.45194 .2254 .45966 .24758 .47388 .23119 .46598 .21941 Metetra
.652 .695 .877 r
.46598 .21941 .47388 .23119 .48797 .22377 .48007 .21423 Metetra
.657 .749 .918 r
.48007 .21423 .48797 .22377 .50208 .21861 .49424 .20903 Metetra
.657 .749 .918 r
.49424 .20903 .50208 .21861 .51628 .21343 .50848 .2038 Metetra
.657 .749 .918 r
.50848 .2038 .51628 .21343 .53054 .20823 .52279 .19854 Metetra
.657 .749 .918 r
.52279 .19854 .53054 .20823 .54488 .20299 .53718 .19326 Metetra
.657 .749 .918 r
.53718 .19326 .54488 .20299 .5593 .19773 .55165 .18794 Metetra
.657 .749 .918 r
.55165 .18794 .5593 .19773 .57379 .19244 .56619 .1826 Metetra
.657 .749 .918 r
.56619 .1826 .57379 .19244 .58835 .18712 .5808 .17723 Metetra
.657 .749 .918 r
.5808 .17723 .58835 .18712 .603 .18178 .5955 .17184 Metetra
.657 .749 .918 r
.5955 .17184 .603 .18178 .61772 .17641 .61027 .16641 Metetra
.657 .749 .918 r
.61027 .16641 .61772 .17641 .63252 .17101 .62512 .16096 Metetra
.657 .749 .918 r
.62512 .16096 .63252 .17101 .64739 .16558 .64005 .15547 Metetra
.657 .749 .918 r
.64005 .15547 .64739 .16558 .66235 .16012 .65506 .14996 Metetra
.657 .749 .918 r
.65506 .14996 .66235 .16012 .67738 .15463 .67015 .14442 Metetra
.657 .749 .918 r
.67015 .14442 .67738 .15463 .6925 .14911 .68533 .13885 Metetra
.657 .749 .918 r
.68533 .13885 .6925 .14911 .7077 .14356 .70058 .13324 Metetra
.657 .749 .918 r
.70058 .13324 .7077 .14356 .72298 .13799 .71592 .12761 Metetra
.657 .749 .918 r
.04128 .36383 .05052 .37199 .06254 .36758 .05334 .35937 Metetra
.657 .749 .918 r
.05334 .35937 .06254 .36758 .07462 .36314 .06545 .3549 Metetra
.657 .749 .918 r
.06545 .3549 .07462 .36314 .08676 .35869 .07761 .3504 Metetra
.657 .749 .918 r
.07761 .3504 .08676 .35869 .09895 .35421 .08984 .34588 Metetra
.657 .749 .918 r
.08984 .34588 .09895 .35421 .11121 .34971 .10213 .34134 Metetra
.657 .749 .918 r
.10213 .34134 .11121 .34971 .12352 .34518 .11447 .33678 Metetra
.657 .749 .918 r
.11447 .33678 .12352 .34518 .13589 .34064 .12688 .33219 Metetra
.657 .749 .918 r
.12688 .33219 .13589 .34064 .14832 .33607 .13935 .32759 Metetra
.657 .749 .918 r
.13935 .32759 .14832 .33607 .16082 .33149 .15187 .32296 Metetra
.657 .749 .918 r
.15187 .32296 .16082 .33149 .17337 .32687 .16446 .3183 Metetra
.657 .749 .918 r
.16446 .3183 .17337 .32687 .18599 .32224 .17711 .31363 Metetra
.657 .749 .918 r
.17711 .31363 .18599 .32224 .19867 .31758 .18983 .30893 Metetra
.657 .749 .918 r
.18983 .30893 .19867 .31758 .21141 .31291 .2026 .30421 Metetra
.657 .749 .918 r
.2026 .30421 .21141 .31291 .22421 .3082 .21544 .29946 Metetra
.657 .749 .918 r
.21544 .29946 .22421 .3082 .23708 .30348 .22835 .29469 Metetra
.657 .749 .918 r
.22835 .29469 .23708 .30348 .25001 .29873 .24132 .2899 Metetra
.657 .749 .918 r
.24132 .2899 .25001 .29873 .263 .29396 .25435 .28508 Metetra
.657 .749 .918 r
.25435 .28508 .263 .29396 .27606 .28916 .26745 .28024 Metetra
.657 .749 .918 r
.26745 .28024 .27606 .28916 .28853 .29299 .28061 .27538 Metetra
.532 .534 .802 r
.28061 .27538 .28853 .29299 .30103 .29824 .29354 .27459 Metetra
.437 .415 .736 r
.29354 .27459 .30103 .29824 .31375 .30255 .30627 .27792 Metetra
.475 .432 .73 r
.30627 .27792 .31375 .30255 .3267 .3053 .31923 .27985 Metetra
.517 .453 .723 r
.31923 .27985 .3267 .3053 .33992 .30594 .33243 .27989 Metetra
.558 .475 .717 r
.33243 .27989 .33992 .30594 .35338 .30408 .34588 .27767 Metetra
.596 .497 .712 r
.34588 .27767 .35338 .30408 .36708 .29949 .35955 .27298 Metetra
.63 .517 .707 r
.35955 .27298 .36708 .29949 .38098 .29214 .37341 .2658 Metetra
.659 .536 .703 r
.37341 .2658 .38098 .29214 .39504 .28219 .38743 .25627 Metetra
.683 .552 .7 r
.38743 .25627 .39504 .28219 .4092 .26999 .40156 .24472 Metetra
.702 .567 .7 r
.40156 .24472 .4092 .26999 .42344 .25604 .41576 .2316 Metetra
.688 .564 .71 r
.41576 .2316 .42344 .25604 .43769 .24095 .42991 .2202 Metetra
.619 .554 .759 r
.42991 .2202 .43769 .24095 .45194 .2254 .4439 .21503 Metetra
.656 .729 .903 r
.4439 .21503 .45194 .2254 .46598 .21941 .45797 .20983 Metetra
.657 .749 .918 r
.45797 .20983 .46598 .21941 .48007 .21423 .4721 .2046 Metetra
.657 .749 .918 r
.4721 .2046 .48007 .21423 .49424 .20903 .48632 .19935 Metetra
.657 .749 .918 r
.48632 .19935 .49424 .20903 .50848 .2038 .50061 .19407 Metetra
.657 .749 .918 r
.50061 .19407 .50848 .2038 .52279 .19854 .51497 .18876 Metetra
.657 .749 .918 r
.51497 .18876 .52279 .19854 .53718 .19326 .52941 .18343 Metetra
.657 .749 .918 r
.52941 .18343 .53718 .19326 .55165 .18794 .54392 .17806 Metetra
.657 .749 .918 r
.54392 .17806 .55165 .18794 .56619 .1826 .55851 .17267 Metetra
.657 .749 .918 r
.55851 .17267 .56619 .1826 .5808 .17723 .57318 .16725 Metetra
.657 .749 .918 r
.57318 .16725 .5808 .17723 .5955 .17184 .58793 .1618 Metetra
.657 .749 .918 r
.58793 .1618 .5955 .17184 .61027 .16641 .60275 .15632 Metetra
.657 .749 .918 r
.60275 .15632 .61027 .16641 .62512 .16096 .61766 .15081 Metetra
.657 .749 .918 r
.61766 .15081 .62512 .16096 .64005 .15547 .63264 .14527 Metetra
.657 .749 .918 r
.63264 .14527 .64005 .15547 .65506 .14996 .64771 .13971 Metetra
.657 .749 .918 r
.64771 .13971 .65506 .14996 .67015 .14442 .66285 .13411 Metetra
.657 .749 .918 r
.66285 .13411 .67015 .14442 .68533 .13885 .67808 .12848 Metetra
.657 .749 .918 r
.67808 .12848 .68533 .13885 .70058 .13324 .69339 .12282 Metetra
.657 .749 .918 r
.69339 .12282 .70058 .13324 .71592 .12761 .70878 .11713 Metetra
.657 .749 .918 r
.03196 .35559 .04128 .36383 .05334 .35937 .04405 .35109 Metetra
.657 .749 .918 r
.04405 .35109 .05334 .35937 .06545 .3549 .05619 .34658 Metetra
.657 .749 .918 r
.05619 .34658 .06545 .3549 .07761 .3504 .06839 .34204 Metetra
.657 .749 .918 r
.06839 .34204 .07761 .3504 .08984 .34588 .08065 .33748 Metetra
.657 .749 .918 r
.08065 .33748 .08984 .34588 .10213 .34134 .09297 .3329 Metetra
.657 .749 .918 r
.09297 .3329 .10213 .34134 .11447 .33678 .10534 .3283 Metetra
.657 .749 .918 r
.10534 .3283 .11447 .33678 .12688 .33219 .11778 .32367 Metetra
.657 .749 .918 r
.11778 .32367 .12688 .33219 .13935 .32759 .13029 .31902 Metetra
.657 .749 .918 r
.13029 .31902 .13935 .32759 .15187 .32296 .14285 .31435 Metetra
.657 .749 .918 r
.14285 .31435 .15187 .32296 .16446 .3183 .15547 .30965 Metetra
.657 .749 .918 r
.15547 .30965 .16446 .3183 .17711 .31363 .16816 .30493 Metetra
.657 .749 .918 r
.16816 .30493 .17711 .31363 .18983 .30893 .18091 .30019 Metetra
.657 .749 .918 r
.18091 .30019 .18983 .30893 .2026 .30421 .19372 .29543 Metetra
.657 .749 .918 r
.19372 .29543 .2026 .30421 .21544 .29946 .2066 .29064 Metetra
.657 .749 .918 r
.2066 .29064 .21544 .29946 .22835 .29469 .21954 .28582 Metetra
.657 .749 .918 r
.21954 .28582 .22835 .29469 .24132 .2899 .23255 .28099 Metetra
.657 .749 .918 r
.23255 .28099 .24132 .2899 .25435 .28508 .24562 .27613 Metetra
.657 .749 .918 r
.24562 .27613 .25435 .28508 .26745 .28024 .25876 .27124 Metetra
.657 .749 .918 r
.25876 .27124 .26745 .28024 .28061 .27538 .27196 .26633 Metetra
.657 .749 .918 r
.27196 .26633 .28061 .27538 .29354 .27459 .28523 .26139 Metetra
.646 .658 .848 r
.28523 .26139 .29354 .27459 .30627 .27792 .29857 .25643 Metetra
.556 .508 .756 r
.29857 .25643 .30627 .27792 .31923 .27985 .31176 .25452 Metetra
.526 .459 .724 r
.31176 .25452 .31923 .27985 .33243 .27989 .32496 .25396 Metetra
.563 .479 .718 r
.32496 .25396 .33243 .27989 .34588 .27767 .33838 .25138 Metetra
.597 .498 .712 r
.33838 .25138 .34588 .27767 .35955 .27298 .35202 .2466 Metetra
.628 .516 .708 r
.35202 .2466 .35955 .27298 .37341 .2658 .36585 .23959 Metetra
.654 .534 .704 r
.36585 .23959 .37341 .2658 .38743 .25627 .37983 .23048 Metetra
.66 .54 .706 r
.37983 .23048 .38743 .25627 .40156 .24472 .39386 .22099 Metetra
.609 .523 .732 r
.39386 .22099 .40156 .24472 .41576 .2316 .40775 .21583 Metetra
.638 .621 .817 r
.40775 .21583 .41576 .2316 .42991 .2202 .42172 .21063 Metetra
.657 .749 .918 r
.42172 .21063 .42991 .2202 .4439 .21503 .43576 .20541 Metetra
.657 .749 .918 r
.43576 .20541 .4439 .21503 .45797 .20983 .44987 .20016 Metetra
.657 .749 .918 r
.44987 .20016 .45797 .20983 .4721 .2046 .46406 .19489 Metetra
.657 .749 .918 r
.46406 .19489 .4721 .2046 .48632 .19935 .47832 .18958 Metetra
.657 .749 .918 r
.47832 .18958 .48632 .19935 .50061 .19407 .49266 .18425 Metetra
.657 .749 .918 r
.49266 .18425 .50061 .19407 .51497 .18876 .50707 .17889 Metetra
.657 .749 .918 r
.50707 .17889 .51497 .18876 .52941 .18343 .52156 .1735 Metetra
.657 .749 .918 r
.52156 .1735 .52941 .18343 .54392 .17806 .53612 .16808 Metetra
.657 .749 .918 r
.53612 .16808 .54392 .17806 .55851 .17267 .55076 .16264 Metetra
.657 .749 .918 r
.55076 .16264 .55851 .17267 .57318 .16725 .56548 .15716 Metetra
.657 .749 .918 r
.56548 .15716 .57318 .16725 .58793 .1618 .58028 .15166 Metetra
.657 .749 .918 r
.58028 .15166 .58793 .1618 .60275 .15632 .59516 .14613 Metetra
.657 .749 .918 r
.59516 .14613 .60275 .15632 .61766 .15081 .61012 .14056 Metetra
.657 .749 .918 r
.61012 .14056 .61766 .15081 .63264 .14527 .62516 .13497 Metetra
.657 .749 .918 r
.62516 .13497 .63264 .14527 .64771 .13971 .64027 .12935 Metetra
.657 .749 .918 r
.64027 .12935 .64771 .13971 .66285 .13411 .65548 .12369 Metetra
.657 .749 .918 r
.65548 .12369 .66285 .13411 .67808 .12848 .67076 .11801 Metetra
.657 .749 .918 r
.67076 .11801 .67808 .12848 .69339 .12282 .68613 .1123 Metetra
.657 .749 .918 r
.68613 .1123 .69339 .12282 .70878 .11713 .70158 .10655 Metetra
.657 .749 .918 r
.02256 .34727 .03196 .35559 .04405 .35109 .03467 .34274 Metetra
.657 .749 .918 r
.03467 .34274 .04405 .35109 .05619 .34658 .04685 .33818 Metetra
.657 .749 .918 r
.04685 .33818 .05619 .34658 .06839 .34204 .05908 .33361 Metetra
.657 .749 .918 r
.05908 .33361 .06839 .34204 .08065 .33748 .07137 .32901 Metetra
.657 .749 .918 r
.07137 .32901 .08065 .33748 .09297 .3329 .08372 .32438 Metetra
.657 .749 .918 r
.08372 .32438 .09297 .3329 .10534 .3283 .09613 .31974 Metetra
.657 .749 .918 r
.09613 .31974 .10534 .3283 .11778 .32367 .10861 .31507 Metetra
.657 .749 .918 r
.10861 .31507 .11778 .32367 .13029 .31902 .12114 .31038 Metetra
.657 .749 .918 r
.12114 .31038 .13029 .31902 .14285 .31435 .13374 .30566 Metetra
.657 .749 .918 r
.13374 .30566 .14285 .31435 .15547 .30965 .1464 .30092 Metetra
.657 .749 .918 r
.1464 .30092 .15547 .30965 .16816 .30493 .15912 .29616 Metetra
.657 .749 .918 r
.15912 .29616 .16816 .30493 .18091 .30019 .17191 .29138 Metetra
.657 .749 .918 r
.17191 .29138 .18091 .30019 .19372 .29543 .18476 .28657 Metetra
.657 .749 .918 r
.18476 .28657 .19372 .29543 .2066 .29064 .19767 .28173 Metetra
.657 .749 .918 r
.19767 .28173 .2066 .29064 .21954 .28582 .21065 .27688 Metetra
.657 .749 .918 r
.21065 .27688 .21954 .28582 .23255 .28099 .2237 .27199 Metetra
.657 .749 .918 r
.2237 .27199 .23255 .28099 .24562 .27613 .23681 .26709 Metetra
.657 .749 .918 r
.23681 .26709 .24562 .27613 .25876 .27124 .24998 .26216 Metetra
.657 .749 .918 r
.24998 .26216 .25876 .27124 .27196 .26633 .26322 .2572 Metetra
.657 .749 .918 r
.26322 .2572 .27196 .26633 .28523 .26139 .27654 .25222 Metetra
.657 .749 .918 r
.27654 .25222 .28523 .26139 .29857 .25643 .28991 .24721 Metetra
.657 .749 .918 r
.28991 .24721 .29857 .25643 .31176 .25452 .30336 .24218 Metetra
.649 .679 .865 r
.30336 .24218 .31176 .25452 .32496 .25396 .31688 .23712 Metetra
.632 .601 .801 r
.31688 .23712 .32496 .25396 .33838 .25138 .33046 .23203 Metetra
.623 .568 .772 r
.33046 .23203 .33838 .25138 .35202 .2466 .34411 .22692 Metetra
.622 .565 .769 r
.34411 .22692 .35202 .2466 .36585 .23959 .35784 .22179 Metetra
.629 .59 .791 r
.35784 .22179 .36585 .23959 .37983 .23048 .37164 .21662 Metetra
.645 .655 .845 r
.37164 .21662 .37983 .23048 .39386 .22099 .3855 .21143 Metetra
.657 .749 .918 r
.3855 .21143 .39386 .22099 .40775 .21583 .39944 .20622 Metetra
.657 .749 .918 r
.39944 .20622 .40775 .21583 .42172 .21063 .41346 .20097 Metetra
.657 .749 .918 r
.41346 .20097 .42172 .21063 .43576 .20541 .42754 .1957 Metetra
.657 .749 .918 r
.42754 .1957 .43576 .20541 .44987 .20016 .4417 .1904 Metetra
.657 .749 .918 r
.4417 .1904 .44987 .20016 .46406 .19489 .45594 .18507 Metetra
.657 .749 .918 r
.45594 .18507 .46406 .19489 .47832 .18958 .47024 .17972 Metetra
.657 .749 .918 r
.47024 .17972 .47832 .18958 .49266 .18425 .48463 .17433 Metetra
.657 .749 .918 r
.48463 .17433 .49266 .18425 .50707 .17889 .49909 .16892 Metetra
.657 .749 .918 r
.49909 .16892 .50707 .17889 .52156 .1735 .51363 .16348 Metetra
.657 .749 .918 r
.51363 .16348 .52156 .1735 .53612 .16808 .52824 .15801 Metetra
.657 .749 .918 r
.52824 .15801 .53612 .16808 .55076 .16264 .54294 .15251 Metetra
.657 .749 .918 r
.54294 .15251 .55076 .16264 .56548 .15716 .55771 .14698 Metetra
.657 .749 .918 r
.55771 .14698 .56548 .15716 .58028 .15166 .57256 .14142 Metetra
.657 .749 .918 r
.57256 .14142 .58028 .15166 .59516 .14613 .58749 .13583 Metetra
.657 .749 .918 r
.58749 .13583 .59516 .14613 .61012 .14056 .6025 .13022 Metetra
.657 .749 .918 r
.6025 .13022 .61012 .14056 .62516 .13497 .61759 .12457 Metetra
.657 .749 .918 r
.61759 .12457 .62516 .13497 .64027 .12935 .63277 .11889 Metetra
.657 .749 .918 r
.63277 .11889 .64027 .12935 .65548 .12369 .64803 .11318 Metetra
.657 .749 .918 r
.64803 .11318 .65548 .12369 .67076 .11801 .66337 .10743 Metetra
.657 .749 .918 r
.66337 .10743 .67076 .11801 .68613 .1123 .67879 .10166 Metetra
.657 .749 .918 r
.67879 .10166 .68613 .1123 .70158 .10655 .6943 .09586 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooo
oooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oo
oooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo000000[ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003oooooo`[ooooo00Go
0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?ooooooooooooooool00000
F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@401Jooooo`00oooo
ool3o`000003ooooool0003ooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Jooooo`00oOoo
ool2o`0000?ooooo0ol00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_ooool00?[ooooo0ol0
0006ooooo`03o`000?oooooo000006;ooooo003hooooo`;o00002Oooool00ol0003oooooo`00001R
ooooo`00mOooool3o`0000_ooooo00Co0000oooooooooooo0000HOooool00?;ooooo0ol00003oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001Pooooo`00l?ooool2o`00
017ooooo00Go0000ooooooooooooooooo`00001Pooooo`00kOooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Mooooo`00joooool2o`0001Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Looooo`00/oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd07oooool3o`000003ooooool0003ooooo
01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`00/oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0000Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool00;?ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo01Sooooo0ol0000Nooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01Oooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0F_ooool00;?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05Oooool3o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`00/oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3
o`0000?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`;o0000Foooool0
0;?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01;ooooo0_l0000Y
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0F?ooool007cooooo0_l00002oooo
o`;o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`?o0000:oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001looooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgMD_ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Gooooo`00OOooool01?oMgMgo0000oa0@4?o<c<a@ooooo`?o00000_ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool007gooooo00Cok^k^
ob4Q8Ol@413ok^k^C_ooool2o`0003?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Eooooo`00OOooool01?lQ8B7oMgMgogMgMolb<S9;ooooo`?o0000=Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05Gooooo001looooo`;o00000_ooool2o`0004Sooooo0_l0000h
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00<Oooooo1?l0000ioooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool00<Gooooo0_l00004ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Cooooo`00
`_ooool3o`0003oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`00_ooo
ool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`00_Oooool3
o`0004Cooooo00?o0000ooooooooool03?ooool2o`0005?ooooo002jooooo`?o00000oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00;So
oooo0_l0001:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool00;Gooooo
0ol0001<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool008_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0Sooooo`;o0000Coooool2o`00017ooooo00?o0000ooooooooool0
C_ooool008_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Pooooo`?o00000_ooool00ol0003ooooo
ooooo`19ooooo`?o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`1=ooooo`00Rooo
ool01Ol@413ooooooooooooooooo410@01kooooo0_l0001?ooooo`;o00001?nX_n/2o`00017ooooo
00?o0000ooooooooool0COooool008_ooooo00Go0000ooooooooooooooooo`00000Kooooo`?o0000
C_ooool3o`000003ojRojol0003oZ;o[00?oZ;o[0ol0000Aooooo`03o`000?oooooooooo04cooooo
002;ooooo`05o`000?ooooooooooooooool000006Oooool2o`0004oooooo0_l00005ojRoj`03o`00
0?nX_n_o000000;o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`1;ooooo`00Rooo
ool01Ol@413ooooooooooooooooo410@01Kooooo0ol000000ooooooo0000ooooo`1;ooooo`?o0000
00?oZ;o[o`000?nX_n/01?nX_n/2o`0000;oZ;o[00Co0000ojRojonX_n_o00004Oooool00ol0003o
ooooooooo`1;ooooo`00Roooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0ol0001>ooooo`?o
00001OnX_n/00ol0003oZ;o[o`000002o`000005ojRojol0003oZ;o[ojRojol000000_nX_n/00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04[ooooo002;ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04Oooool2o`0004gooooo1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRo
j`03o`000?nX_n_o000000;oZ;o[0_l0000Aooooo`03o`000?oooooooooo04[ooooo002Nooooo`?o
0000C?ooool3o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o
0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool2o`0004_o
oooo002Looooo`;o00000_ooool00ol0003oooooooooo`18ooooo`;o00001OnX_n/00ol0003oZ;o[
ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/4o`0000CoZ;o[00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`18ooooo`00VOooool3o`0004cooooo0ol000000onX_n_o0000
ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000?oZ;o[
00?o0000ojRojonX_n/00_nX_n/2o`00017ooooo00?o0000ooooooooool0B?ooool009Oooooo0_l0
001=ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0_l000001OnX_n_o0000o`000?nX_n_o000001;ooooo
00?o0000ooooooooool0Aoooool009Cooooo0ol0001<ooooo`?o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`03o`000?nX_n_o000000;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX
_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo04Kooooo002Booooo`;o000000?oooooo`000?ooool0B_ooool2o`0000KoZ;o[00?o0000
ojRojonX_n/00ol00006ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001_nX_n/00ol0003oZ;o[
o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`16ooooo`00Soooool3o`0000Cooooo00?o0000ooooooooool0A_ooool2o`0000;oZ;o[00?o
0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00?o
0000ojRojonX_n/00onX_n/2o`0000;oZ;o[00Co0000ojRojonX_n_o00000onX_n/3o`00017ooooo
00?o0000ooooooooool0AOooool008cooooo0ol0001=ooooo`?o00001OnX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRo
j`04ojRoj`03o`000?nX_n_o000000;o000000GoZ;o[o`000?nX_n_oZ;o[o`000002ojRoj`Co0000
0_nX_n/00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Cooooo002:ooooo`;o0000C?oo
ool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX
_n/2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000;o0000
00?oZ;o[o`000?nX_n/01?nX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
0027ooooo`Go0000BOooool3o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l0
00000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00_nX
_n/2o`00017ooooo00?o0000ooooooooool0@oooool008Gooooo0_l0001<ooooo`;o00001OnX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o
0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?o
Z;o[o`000?l000001?nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003ooooo017ooooo00?o
0000ooooooooool0@_ooool008;ooooo0ol0001;ooooo`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`03o`000?nX_n_o000000;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/0
0ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001OnX_n/2
o`0000;oZ;o[0ol00005ojRoj`03o`000?oooooooooo00kooooo0_l00014ooooo`00BOooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Ooo
ool2o`0004cooooo0_l00006ojRoj`03o`000?nX_n_oZ;o[00?o00001_nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000GoZ;o[00?o0000ojRojol000000_l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003o
Z;o[ojRoj`03ojRoj`;o00004Oooool00ol0003oooooooooo`11ooooo`00BOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01gooooo0ol000000ooooooo
0000ooooo`19ooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0003o
Z;o[ojRoj`03ojRoj`;o00001?nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001_nX_n/00ol0003o
Z;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04Oooool00ol0003oooooooooo`10ooooo`00
@Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01[o
oooo0_l0001<ooooo`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00Co
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00
00CoZ;o[0_l00004ojRoj`;o00001OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
043ooooo0019ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Hoooo
o`?o0000B_ooool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000GoZ;o[00?o0000ojRo
jonX_n/00_nX_n/2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o
000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`08o`000?nX
_n_oZ;o[ojRojol0003oZ;o[o`000?nX_n/2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00
017ooooo00?o0000ooooooooool0?oooool004Wooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05oooool2o`0004[ooooo0ol000000onX_n_o0000ojRoj`04
ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[o`000002
o`000003ojRojol0003oZ;o[00CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005
ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`03o`000?nX_n_oZ;o[00Co00001OnX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd08oooool004Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Ko
oooo0ol000000ooooooo0000ooooo`17ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o
00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol000000_l000000onX
_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0
003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[
00?oZ;o[0_l00005ojRoj`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02;ooooo0019oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`?o0000Boooool2
o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[
o`000002o`000004ojRojol0003oZ;o[o`0000?oZ;o[00?o0000ojRojol000000_l000000onX_n_o
0000ojRoj`04ojRoj`;o00004?ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Qooooo`00BOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000@ooooo`;o0000C?ooool2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`Co
00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/2o`0000;oZ;o[0ol00005ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Rooooo`00Joooool3o`0004_o
oooo0ol000000onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o
00001?nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/00ol0003oZ;o[ojRoj`03o`0000Go
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o
000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000Go
Z;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo001Yooooo`;o00000_ooool00ol0
003oooooooooo`16ooooo`?o00001OnX_n/00ol0003oZ;o[o`000002o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRo
jol000000_l000000onX_n_o0000ojRoj`04ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRo
j`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo02Gooooo001Vooooo`?o0000B_ooool3o`0000?oZ;o[00?o0000
ojRojonX_n/00_nX_n/2o`0000KoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_o
Z;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co
0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[
ojRoj`03ojRoj`;o00001?nX_n/2o`0000CoZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o
00003oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00cooooo0ol000000ol@413oooooooooo`0Cooooo`00I?ooool2o`0004[ooooo0ol000000onX_n_o
0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`00
00GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o0000
1OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[0_l000001_nX_n_o0000
o`000?l0003oZ;o[o`0000GoZ;o[1?l00002ojRoj`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooo00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03oa0@4?nj
^[[ooooo01Cooooo001Qooooo`?o0000B_ooool2o`0000GoZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`00
0?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000
ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001?nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojol0
00000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08_ooool00onHV9So<S8booooo`0Dooooo`00Goooool2o`0000;ooooo00?o0000ooooooooool0
A_ooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/0
0onX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/0
0ol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[
o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`Go000000?oZ;o[o`000?nX_n/01?nX_n/2o`0000GoZ;o[00Co0000ojRojonX
_n_oZ;o[0ol0000@ooooo`03o`000?oooooooooo02;ooooo00?ogMgMo`000?nj^[X05?ooool005co
oooo0ol00005ooooo`03o`000?oooooooooo04;ooooo0ol00005ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001OnX_n/00ol0003oZ;o[o`000002o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01?l0003oZ;o[ojRo
jonX_n/3o`0000GoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[o`000002ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4o`0000;oZ;o[00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03oeEEEOmgMgOoA4A401Cooooo001Jooooo`;o0000
BOooool4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00?o0000ojRojonX_n/0
0_nX_n/2o`0000KoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_o000000;o0000
00?oZ;o[o`000?nX_n/01?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
Z;o[0_l00005ojRoj`;o000000CoZ;o[o`000?l0003o00001OnX_n/00ol0003oZ;o[o`000002o`00
0003ojRojol0003oZ;o[00CoZ;o[00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ooooo
o`05omgMgOl@413oooooob4Q8OoMgMd04oooool005Oooooo0ol00019ooooo`;o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03
o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00_nX_n/2o`0000GoZ;o[00?o0000ojRojonX_n/00_nX_n/2o`00013ooooo00?o0000oooooooo
ool07oooool01OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo001Dooooo`?o00000oooool00ol0003o
ooooooooo`14ooooo`;o00001OnX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Co0000ojRojonX
_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00?oZ;o[0_l00004ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00005ojRoj`04o`000?nX_n_o
Z;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?oo
ool04?ooool00ol0003oooooooooo`0Mooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool04Oooool005;ooooo0_l0001:ooooo`?o000000?oYJOHo`000?nX_n/01?nX_n/3o`0000?oXikA
00?o0000ojRojonX_n/00_nX_n/4o`0000?oYk[W00?o0000ojRojonX_n/00_nX_n/2o`0000GoZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`;o00001?nX_n/2o`0000?oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX
_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0@ooooo`00:_ooool4o`000003oa0@4?oooooooooo01kooooo0ol0
0019ooooo`?o00001OnUYmP00ol0003oZ;o[o`000002o`000003oi^5^ol0003oXikA00CoXikA00Co
0000ojRojol0003o00000_nNSL800ol0003oYk[WojNji`03ojNji`04o`000?nX_n_o0000o`0000;o
Y[7P00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000Go
Z;o[00?o0000ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`04ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/0
0ol0003oZ;o[ojRoj`03ojRoj`;o00004?ooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0
003oooooooooo`0Nooooo`?o0000B?ooool3o`0000;oXIO:00?o0000ojFWf?nUYmP00onUYmP2o`00
00GoVhFk00?o0000oj>NdOnSW]400_nSW]42o`0000GoWXg200Co0000ojNjionW^^OoYk[W0ol00005
ojJah004o`000?nX_n_o0000o`0000;oYk?Q00?o0000ojRojonX_n/00_nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l0
0002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX
_n/00ol0003oZ;o[o`000004o`0000GoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?ooool04?ooool00ol0003ooooo
ooooo`0dooooo`008Oooool6o`0000Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o
0000ooooooooool0@oooool2o`000003oin@a?l0003oXIO:00?oXIO:00Oo0000ojFWf?nUYmSoYJOH
o`000?nXR[Co000000GoVhFk00?o0000oj>NdOnSW]400_l000000on`T;Go0000oij=`P05oij=`P?o
00000_nPRkd00ol0003oY[7PojJah003ojJah0;o00001OnW/n400ol0003oZ;o[ojRoj`03o`0000Go
Z;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00?o0000ojRojonX_n/00_nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[
00CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0_l00003ojRoj`03o`000?nX_n_o0000
00?oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oooooooooo`0=oooo
o`?o0000=Oooool002cooooo00?o0000ooooooooool06Oooool2o`0004[ooooo0_l00004oin@a003
o`000?nQUl[oXIO:00;oXIO:00?o0000ojFWf?l000000onXR[@00ol0003oVhFkoi^5^`02oi^5^`03
o`000?nSW]7o000000Co/92e00?o0000oij=`_nNSL800_nNSL82o`0000GoX8^m00?o0000ojJah?l0
00000_l000000onXTl3o0000ojNch@04ojNch@?o00000onW^nL00ol0003oZ;o[ojRoj`02ojRoj`;o
00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003o
Z;o[o`0000?oZ;o[00?o0000ojRojol000000ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol0
0002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo03?ooooo000/
ooooo`03o`000?oooooooooo01Kooooo0ol00019ooooo`?o000000?oWi75o`000?nOT<@00onOT<@0
0ol0003oXIO:oj6GbP02oj6GbP;o00001?nXR[@00ol0003oVhFkoi^5^`03oi^5^`03o`000?n`T;Go
/92e00?o/92e00Go0000oij=`_nNSL;oWXg2o`000002okbI/`03o`000?nPRkgoX8^m00?oX8^m00?o
0000ojRC`?nXTl000onXTl000ol0003oYk?QojNch@02o`000003ojVHa?l0003oYk_W00CoYk_W00Ko
0000ojRojol0003o0000ojRojol00005ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o
00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3o`00
00CoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`04ojRoj`03o`000?nX_n_o0000
00;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003ooooo
013ooooo00?o0000ooooooooool0<_ooool002cooooo00?o0000ooooooooool05?ooool2o`0000;o
oooo00?o0000ooooooooool0A?ooool3o`0000GoWi7500Go0000oin@a?nOT<CoWi34o`000002oj6G
bP;o000000?oYhRdo`000?nXR[@00onXR[@00ol0003oVhFkoi^5^`03oi^5^`03o`000?n`T;Go/92e
00?o/92e00Co0000oij=`_nNSL;o00000onlVK<00ol0003oX8^moj2;_@03oj2;_@03o`000?nXTl3o
Z9?000?oZ9?000?o0000ojNchOl000001?nYV<@00ol0003oYk_WojNki`02ojNki`;o00001?nX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00?o0000ojRojol000000_l00000
0onX_n_o0000ojRoj`03ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/01?nX_n/4
o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2o`000003ojRojol0003oZ;o[00;oZ;o[00Co0000
ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo017ooooo0ol00018
ooooo`?o00000_nQVLd00ol0003oWi75oinAa@03oinAa@03o`000?nOT<CoWi3400;oWi340_l00003
ojN8]003o`000?nXR[CoZ8Zd00?oZ8Zd00Oo0000oi^5^onKQK_oVhFko`000?ncTK?o000000Go/92e
0_l00004okbI/`03o`000?nPRkgoX8^m00;oX8^m00?o0000ol2M]Ol000001OnXTl000ol0003oZIS4
ojVHa003ojVHa003o`000?nW^nOo000000;o000000?oYI_;o`000?nX_n/00onX_n/2o`0000GoZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003o
Z;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Co0000ojRojol0003o00000_nX_n/2o`00
00?oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[
00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo037ooooo000Zooooo`03oeEEEOmVIVKo0000013o
oooo0ol00019ooooo`;o000000?oYZgMo`000?nQVLd00onQVLd00ol0003oWi75oinAa@02oinAa@04
o`000?nOT<CoWi34oin@a0;o00001OnWR;@00ol0003oZ8ZdojR:]002ojR:]004o`000?nKQK_oVhFk
o`0000;o/i6c00?o0000ok2@]On`T;D00on`T;D00ol0003o_9VcokbI/`04okbI/`04o`000?nPRkgo
X8^mo`0000;o`9fe00?o0000ojRC`?nXTl000onXTl000ol0003oZIS4ojVHa004ojVHa003o`000?nU
Vl_oYI_;00?oYI_;00Co0000ojRojol0003o00000_nUYMH00ol0003oZ;o[ojRoj`02ojRoj`Co0000
0_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o0000
1OnX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00005
ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003oZ;o[o`000002
o`000003ojRojol0003ooooo013ooooo00?o0000ooooooooool0<?ooool003_ooooo0ol00018oooo
o`?o00001?nV[Md01Ol0003oXIW=oj6IcOnQVLgo000000GoWi750ol000000onPQ;Go0000ojN8]004
ojN8]003o`000?nXR[CoZ8Zd00;oZ8Zd00?o0000oi^5^ol000000oncTK<00ol0003o/92eok2@]@03
ok2@]@03o`000?nlVK?o_9Vc00Co_9Vc00Co0000oj2;_OnPRkgo00000oo0WKD01ol0003oZ9?0ojRC
`?nXTl3o0000olBS^?l000001OnYV<@00ol0003oYI_;ojFKb`03ojFKb`;o00001OnUYMH01?l0003o
Z;o[o`000?l00002ojNdhP03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000_l000000onX
_n_o0000ojRoj`04ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4
o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02oooooo000hooooo`?o00000_ooool00ol0003oooooooooo`12ooooo`Co00000_nX_n/0
0ol0003oYZgMojJ]g@02ojJ]g@03o`000?nQVLgoXIW=00;oXIW=00Co0000oinAaOnOTLGoWi750_l0
0004oj24]@03o`000?nWR;CoYhRd00;oYhRd00?o0000ojR:]?nXR[@00_nXR[@2o`0000Go/i6c00Oo
0000ok2@]On`T;Go/92eo`000?niU[?o000000Go_9Vc00?o0000oj2;_Ol000001?o0WKD01?l0003o
Z9?0ojRC`?l00002olBS^003o`000?nYV<CoZIS400;oZIS400?o0000olJX^ol000000onUVl/00ol0
003oa:g3o`000005ojFUeP;o00001OnW]>800ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Co0000ojRo
jonX_n_oZ;o[0ol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001OnX_n/00ol0003oZ;o[
o`000004o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00002ojRoj`03o`00
0?nX_n_oZ;o[00?oZ;o[0_l0000@ooooo`03o`000?oooooooooo02oooooo000fooooo`;o0000B?oo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01Ol0003oYZgMojJ]gOnV[Mgo000000CoXIW=
00Ko0000oinAaOl0003o0000oiQo]_l00004oj24]@03o`000?nWR;CoYhRd00;oYhRd00?o0000ojR:
]?nXR[@00_l000000on^SK?o0000ok>A/`04ok>A/`04o`000?n`T;Go/92eo`0000;o^IJc00?o0000
okbI/onlVK<01?nlVK<00ol0003o`9feol2M]@03ol2M]@03o`000?nXTl3o000000Coa:>h00Co0000
ojVHa?nYV<Co00000_o6Z;/01?l0003oYI_;ojFKbol00003olB]``03o`000?nUYMKoYJGF00;o0000
00?o_;3>o`000?nW]>801?nW]>83o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[
00?o0000ojRojonX_n/00onX_n/2o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[1Ol000001OnX_n_o
0000ojRojol0003oZ;o[00;o000000?oZ;o[o`000?nX_n/01?nX_n/00ol0003oZ;o[o`000002o`00
0003ojRojol0003oZ;o[00?oZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ooooo`0@oooo
o`03o`000?oooooooooo02kooooo000cooooo`?o0000B?ooool2o`0000GoZ;o[00Go0000ojRojonX
_n_oZ;o[o`000004ojJ]g@03o`000?nQVLgoXIW=00?o00000onHOkH00ol0003oX8Beoj24]@02oj24
]@03o`000?nWR;CoYhRd00?oYhRd0_l00003ojj=/`03o`000?ncTK?o/i6c00?o/i6c00?o0000ok2@
]Ol000000oniU[<00ol0003o_9VcokbI/`03okbI/`;o00001_o0WKD00ol0003oa:>holBS^003olBS
^003o`000?nYV<Co000000?oaZRk00?o0000ojFKbol000001?o4[L<00ol0003oYJGFo`000004okb`
cP03o`000?nW]>;oYkCR00;o000000?o/KCKo`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003o
Z;o[o`0000GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`03ojRoj`Oo00001?nX
_n/3o`0000CoZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o0000
1OnX_n/00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo000booooo`?o0000Aooo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/<o`0000;oT7Zg00?o0000oiQo]_nHOkH00_nH
OkH00ol0003oX8Beoj24]@02oj24]@04o`000?nWR;CoYhRdojN8]0;o00001On^SK<00ol0003o/i6c
ok>A/`03ok>A/`03o`000?niU[?o^IJc00?o^IJc00Go0000okbI/onlVK?o_9Vco`000002oknK/`03
o`000?o0WKGo`9fe00;o`9fe0_l00006olBS^003o`000?o6Z;_oaZRk00?oaZRk00?o0000olB]`oo4
[L<01?o4[L<00ol0003o_;3>okb`cP03okb`cP03o`000?nW]>;o000000Co/KCK00Co0000ojRojonX
_n_oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[o`000004
o`0000CoZ;o[00?o0000ojRojol000001?l00004ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00003oooool2o`0002oooooo000boooo
o`Co0000@oooool3o`0000GoZ;o[00Ko0000ojRojol0003o0000ojFXfOl00003ohj2`@05o`000?n6
MKWoQWFiohIe^Ol000001?n@N[L00ol0003oV7nfoiQo]P02oiQo]P03o`000?nPQ;GoX8Be00;oX8Be
00Ko0000ojN8]?nWR;Co0000ojR9/ol00005ojj=/`03o`000?ncTK?o/i6c00;o/i6c0_l00005okVF
/`04o`000?nlVK?o_9Vco`0000?o_i^c00Go0000ol2M]Oo0WKGo`9feo`000002olBQ]@03o`000?o4
XkSoa:>h00;oa:>h0_l00005olJX^`03o`000?o4[L?oa:g300Coa:g300?o0000okb`c_nl/<h01?nl
/<h00ol0003o/KCKok6df`03ok6df`Co00000_nW^NH00ol0003oZ;o[ojRoj`02ojRoj`Co00000onX
_n/01?l0003oZ;o[ojRojonX_n/5o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`;o
000000?oZ;o[o`000?l000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o
000000?oZ;o[o`000?nX_n/01?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`00017ooooo00?o0000
ooooooooool0;?ooool003;ooooo00Co0000oooooooooooo0000?oooool4o`0000;oZ;o[00?o0000
ojRojonX_n/00onX_n/2o`0000?oYJSI00?o0000ohj2`On>P/400_n>P/401Ol0003oQWFiohIe^On6
MKWo000000CoT7Zg00Go0000oiQo]_nHOkKoV7nfo`000004oj24]@03o`000?nWR;Co000000?oZ8Vc
00?o0000ojj=/on^SK<00_n^SK<01ol0003o/i6cok>A/oncTK?o0000okJB/_l000001OniU[<00ol0
003o_9Vco`000004oknK/`04o`000?o0WKGo`9feo`0000?oa:6e00Go0000olBS^?o4XkSoa:>ho`00
0002olRW^007o`000?o6Z;_oaZRkolJX^ol0003obZfmo`000004olB]``03o`000?o;]<Co000000Co
_;3>00?o0000olRkc_l000000ona]=/00ol0003o`L;Ko`000005ojNiiP04o`000?nX_n_o0000o`00
00;oZ<7/00?o0000ojRojonX_n/00_nX_n/7o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/01?l0003oZ;o[ojRojonX_n/3
o`0000CoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`00<_ooool01Ol0
003ooooooooooooooooo000003cooooo0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000
ojRojol000000_l000000onX_n_o0000ojFXf@03ojFXf@05o`000?n>P/7oSX;1ohj2`Ol000000on6
MKT00ol0003oT7Zgoi1j]`02oi1j]`05o`000?nHOkKoV7nfoiQo]_l000001?nPQ;D2o`0000CoZ8Vc
00?o0000ojj=/on^SK<00_n^SK<01?l0003o/i6cok>A/ol00003okJB/P03o`000?niU[?o^IJc00?o
^IJc00?o0000oknK/onoVk<01?noVk<2o`0000Coa:6e00Co0000olBS^?o4XkSo00000oo8YkP01?l0
003oaZRkolJX^ol00003olZ]_@04o`000?o4[L?oa:g3o`0000?obkC400Co0000okb`c_nl/<ko0000
0oo8^lh00ol0003o/KCKo`000003ol72f`03o`000?nW^NKoYkWV00;oYkWV0_l00005ojS1k003o`00
0?nX_n_o000000Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00?o0000ojRojol000001?l00005ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`00013ooooo00?o0000ooooooooool0:oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Kooooo0ol00005ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/0
1Ol0003oYJSIojFXfOnUZ=Wo000000?oSX;100Go0000ohIe^On6MKWoQWFio`000004oi1j]`05o`00
0?nHOkKoV7nfoiQo]_l000000_nPQ;D2o`000003oj64]?l0003oZ8Vc00?oZ8Vc00?o0000ojj=/on^
SK<00on^SK<2o`0000Co]Y:b00?o0000okVF/oniU[<00_niU[<2o`0000Ko_i^c00?o0000olBQ]Oo4
XKD01?o4XKD2o`0000Cob:Nh00?o0000olJX^ol000001?o:[Kd00ol0003oa:g3o`000004ol^da003
o`000?nl/<ko000000Cob;_>0_l00004ol72f`03o`000?nW^NKo000000;o000000?o[lK[o`000?nX
`N`01?nX`N`4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/2o`000006ojRojol0003o0000o`000?nX_n_o00001?nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00CoZ;o[0ol00002ojRoj`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0:_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03;ooooo0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`05o`000?nX_n_oZ;o[
ojRojol000000onUZ=T00ol0003oSX;1ohj2`@02ohj2`@05o`000?n6MKWoQWFiohIe^Ol000000on@
N[L00ol0003oV7nfoiQo]P02oiQo]P;o00000onQQ;@00ol0003oZ8VcojR9/`03ojR9/`03o`000?n^
SK?o[Xfc00;o[Xfc00?o0000okJB/_nfT[800onfT[801ol0003o^IJcokVF/oniU[?o0000okbH/ol0
00001_noVk<00ol0003oa:6eolBQ]@04olBQ]@03o`000?o8YkSob:Nh00Cob:Nh00?o0000olZ]_Oo:
[Kd01?o:[Kd00ol0003obkC4ol^da003ol^da0;o00001?o8^lh00ol0003ocLCBo`000004ol72f`?o
00001?n_a^/00ol0003oZ<7/o`000004o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
Z;o[0ol00003ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/00ol0003oZ;o[ojRoj`03o`00
00GoZ;o[00?o0000ojRojol000000_l000000onX_n_o0000ojRoj`03ojRoj`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0:_ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;ooo
ool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[2?l000000onUZ=Wo0000ohj2`@02ohj2`@05o`000?n6MKWoQWFiohIe^Ol0
00001?n@N[L00ol0003oV7nfo`000002o`0000GoXHBd00?o0000ojR9/onXRK<00_nXRK<01?l0003o
[Xfcojj=/on^SK<2o`0000Go]Y:b00Co0000okVF/oniU[?o00000onlV;<00ol0003o_i^coknK/`02
oknK/`;o00001_o4XKD00ol0003ob:NholRW^004olRW^003o`000?o:[KgobZfm00?obZfm0_l00004
ol^da003o`000?o@_<Ko000000?ob;_>00Go0000olg4d_o=a=;ocLCBo`000002ol72f`05o`000?o3
c>7o`lcQol?<hOl000000_n_a^/4o`0000CoYL_d00Co0000ojRojol0003o00000_nWc?<00ol0003o
Z;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/4o`000003
ojRojol0003o000000GoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_l00005ojRoj`03
o`000?nX_n_oZ;o[00?o00004?ooool00ol0003oooooooooo`0Yooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0;?ooool2o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00000on8R<d00ol0003oKfZlofmZ_006o`0000?oQWFi00?o0000oi1j]on@N[L0
1?l00002oiQo]P03o`000?nQQ;CoXHBd00?oXHBd00?o0000ojR9/onXRK<00_nXRK<01?l0003o[Xfc
ojj=/ol00002ok2?/`03o`000?nfT[;o]Y:b00?o]Y:b0_l00004okbH/`05o`000?noVk?o_i^coknK
/ol000000_o3Wk@00ol0003oa:6eolBQ]@02olBQ]@03o`000?o8YKKo000000Cob:Nh00?o0000olb/
^Ol000000oo:[Kd01?l0003ockBnolnd__l00002ol^da007o`000?o@_<Kod;c6om2la_l0003ob;_>
o`000004olg4dP03o`000?o1`]_o000000Co`lcQ1Ol000000on]d??o0000ojG;m002ojG;m0?o0000
1OnWc?<00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRo
j`;o000000KoZ;o[o`000?l0003o0000ojRojol00004ojRoj`03o`000?nX_n_o000000;o000000?o
Z;o[o`000?nX_n/01?nX_n/3o`0000;oZ;o[00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`04ooooo`;o
00002?ooool00ol0003oooooooooo`0Yooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o
00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00001?nX_n/01Ol0003oR8S=ohR8cOn8R<go0000
00;oKfZl00Co0000ogU^^_miK[[oNFjj1ol00002ohii]`03o`000?nHOkKoV7nf00;oV7nf00?o0000
oj64]?nQQ;@00_nQQ;@00ol0003oZ8VcojR9/`03ojR9/`;o00000on`Sk<00ol0003o]Y:bokJB/P03
okJB/P03o`000?nlV;?o_9Rc00?o_9Rc00Co0000oknK/onoVk?o00000oo3Wk@01Ol0003oa:6eolBQ
]Oo4XKGo000000;ob:Ff00Go0000olRW^?o8YkSob:Nho`000002olb/^@04o`000?o:[KgobZfmo`00
00?ockBn00?o0000ol^da?l000001Oo@_<H00ol0003ocLCBolg4dP03olg4dP;o00000oo3c>44o`00
00Co[M3c1?l00003ohg=o@04o`000?nWc??oYlccojO<l`Co00000_nX_n/00ol0003oZ;o[ojRoj`03
ojRoj`;o00001?nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol0
0005ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`Co
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRo
jol0003o00000_nX_n/01Ol0003oZ;o[ojRojonX_n_o000000?oR8S=00Go0000ofmZ_?m_J[coKfZl
o`000003ogU^^P05o`000?n4LkWoQ7>iohAc^Ol000001?n>NKL01Ol0003oV7nfoiQo]_nHOkKo0000
00CoXHBd00?o0000ojR9/onXRK<00_nXRK<2o`0000Co/8nc00?o0000okJB/_nfT[800onfT[800ol0
003o_9RcokbH/`04okbH/`;o00001?o3Wk@01?l0003oa:6eolBQ]Ol00003olRU]P04o`000?o8YkSo
b:Nho`0000?oc:bi00?o0000olZ]_Ol000001Oo?];h00ol0003od;c6om2laP04om2laP03o`000?o=
a=;ocLCB00;ocLCB00?o0000om;?e_oBcmH01?l00003olGHj004o`000?n]d??o0000o`0000?oY][j
00?o0000ohg=oOn=cOd01Ol00002oh_Co`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol00000
0_l000000onX_n_o0000ojRoj`03ojRoj`Co000000?oZ;o[o`000?l000001OnX_n/3o`0000?oZ;o[
00Co0000ojRojonX_n_oZ;o[0ol00005ojRoj`03o`000?nX_n_oZ;o[00?o00004?ooool00ol0003o
ooooooooo`0Wooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`?o00001?nX
_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`05o`000?nX
_n_oZ;o[ojRojol000000_n8R<d01Ol0003oKfZlofmZ_?m_J[co000000?oNFjj00Go0000ohAc^On4
LkWoQ7>io`000004ohii]`05o`000?nHOkKoV7nfoiQo]_l000001?nQQ;@00ol0003oZ8VcojR9/`02
o`000003ojZ:]?l0003o/8nc00Co/8nc00Oo0000okJB/_nfT[;o]Y:bo`000?nhUK?o000000Go_9Rc
00?o0000ol>O]?o3Wk@01?o3Wk@2o`0000Gob:Ff0_l00005olb/^@03o`000?o?];kockBn00CockBn
00?o0000om2la_o@_<H00oo@_<H00ol0003oe/G9o`000002olg4dP03o`000?oBcmKo000000?o0000
1Oo5f>P3o`0000?oY][j1?l00003of[8oP03o`000?n;doooRm?o00;oRm?o00?o0000ojRojonX_n/0
0ol00005ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0_l000001_nX
_n_o0000o`000?l0003oZ;o[o`0000CoZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1?l0
0003ojRoj`03o`000?oooooooooo00gooooo0_l0000Xooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Mooooo`?o000000?oZ;o[o`000?nX_n/01?nX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/01_l00003ohR8c@04o`000?m_J[coKfZl
o`0000CoNFjj00Go0000ohAc^On4LkWoQ7>io`000003ohii]`03o`000?nHOkKoV7nf00;oV7nf00?o
0000oj64]?nQQ;@00_nQQ;@2o`0000?oZXZd00?o0000ok2?/on`Sk<00on`Sk<01?l0003o]Y:bokJB
/_l00002okRE/`03o`000?nlV;?o_9Rc00?o_9Rc00?o0000ol>O]?o3Wk@01?o3Wk@00ol0003ob:Ff
olRU]P04olRU]P03o`000?o<[;Woc:bi00Coc:bi00?o0000olnd__o?];h00oo?];h00ol0003oeK_1
o`000003om2laP05o`000?oFaLWoe/G9o`000?o=a=800ol00002om;?eP04o`000?oFf]_o0000olGH
j0?o00000_o5hnh4o`0000;oVn7m3Ol00003oj?HnP04o`000?nX_n_oZ;o[ojRoj`?o00001OnX_n/0
0ol0003oZ;o[ojRoj`03o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`06o`00
0?nX_n_o0000o`000?nX_n_o00001OnX_n/2o`0000oooooo00?o0000ooooooooool09_ooool0033o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`Co00001?nX_n/00ol0003o
Z;o[o`000002o`000003ojRojol0003oZ;o[00CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005
ojRoj`?o00000_nX_n/00ol0003oIVk7ofI^a`03o`000003ohR8cOl0003oKfZl00;oKfZl00Go0000
ogU^^_miK[[oNFjjo`000003ohAc^@03o`000?n>NKOoSWVg00;oSWVg00Go0000oiQo]_nHOkKoV7nf
o`000003oj64]0;o00001OnZR[@00ol0003o/8ncok2?/`02ok2?/`03o`000?nfT[;o000000?o^9Fc
00?o0000okbH/onlV;<00_nlV;<00ol0003o`9bco`000005ol>O]003o`000?o8YKKob:Ff00Cob:Ff
00?o0000olb/^Oo<[;T00oo<[;T00ol0003odK>ko`000003olnd_P07o`000?oE^l7oeK_1omFk`Ol0
003od;c6o`000002omK5b@Co00000ooBcmH01?l0003oe][KomKJfooFf]/2o`0000?oaN?^00?o0000
ol7^lOo1k_401?l00002ohWSn`_o00000_nSf?X5o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/3
o`0000;oZ;o[0_l00003ojRoj`?o00001?nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o
0000ojRojol000000_l000000onX_n_o0000ooooo`0?ooooo`03o`000?oooooooooo02Gooooo000`
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool3o`0000CoZ;o[00?o0000
ojRojonX_n/00ol00005ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/00ol0003oZ;o[o`00
0002o`000003ojRojol0003oZ;o[00?oZ;o[00Go0000ofI^aomVK/Oo0000of1S_P02o`0000?oKfZl
00Go0000ogU^^_miK[[oNFjjo`000003ohAc^@03o`000?n>NKOoSWVg00;oSWVg00Ko0000oiQo]_nH
OkKoV7nfo`000?nQQ;@2o`000003oj:5]Ol0003oZXZd00CoZXZd00?o0000ok2?/on`Sk<00_n`Sk<2
o`0000Go^9Fc00Co0000okbH/onlV;?o00000_o0W;<00ol0003o`indol>O]002ol>O]003o`000?o7
XkGo000000Cob:Ff00?o0000olf[]ol000001?o<[;T01?l0003odK>kom6c^ol00002olnd_P03o`00
0?oE^l7oeK_100;oeK_11?l00002omK5b@05o`000?oKc/go0000om;?e_l000000ooFf]/01_l0003o
f>GOomSUgol0003oaN?^o`0000;o`Nka00?o0000okWdl_nim?801?l00002og?NlP_o00000omObOX0
0ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00_nX_n/5
o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/2
o`0000GoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Tooooo`00<?ooool00ol0
003oooooooooo`0>ooooo`;o00004oooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/00_nX_n/4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`05o`000?nX_n_oZ;o[ojRojol000000_mVK/L01?l0003oH6>nof1S__mPHkh4o`0000?oNFjj00Go
0000ohAc^On4LkWoQ7>io`000004ohii]`04o`000?nHOkKoV7nfoiQo]P;o00001?nRQKD00ol0003o
ZXZdojZ:]002ojZ:]007o`000?n`Sk?o/8ncok2?/ol0003o/i6co`000005okRE/`04o`000?nlV;?o
_9Rco`0000?o`9bc00Co0000ol>O]?o3WkCo00000_o7XkD01Ol0003ob:FfolRU]_o8YKKo000000;o
cJ^g00Go0000olb/^Oo<[;Woc:bio`000003om6c^`03o`000?o?];ko000000CoeK_10_l00004omK5
b@05o`000?oKc/goflk=om_>cOl000000ooFf]/01?l0003of>GOomSUgooHiMl3o`000005ol7^lOl0
003o^OCbokWdl_l000000_n/mnhDo`0000;oZ;o[0ol00005ojRoj`03o`000?nX_n_o000000?o0000
1OnX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000GoZ;o[00Ko0000ojRojol0003o0000ojRojol0
0005ojRoj`;o00003oooool00ol0003oooooooooo`0Tooooo`00<?ooool2o`00017ooooo00?o0000
ooooooooool03Oooool4o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?oZ;o[
00?o0000ojRojonX_n/00_nX_n/3o`000003ojRojol0003oIVk700;oIVk700Co0000of1S__mPHkko
00000_mYI[`4o`000003ogU^^_l0003oQ7>i00;oQ7>i00?o0000ohii]on>NKL00_n>NKL3o`000003
oiQo]_l0003oXXFe00?oXXFe00?o0000ojZ:]?nZR[@00_nZR[@01?l0003o/8ncok2?/ol00002ok>A
/`03o`000?nhUK?o^9Fc00?o^9Fc00?o0000okbH/ol000001?o0W;<01?l0003o`indol>O]?l00003
olNS]@04o`000?o8YKKob:Ffo`0000?ocJ^g00?o0000olb/^Ol000001OoA/k/00ol0003oeK_1omFk
`@04o`000005om[4`ol0003oe/G9omK5bOl000000ooKc/d01Ol0003ogmW@o`000?oFf]_o000000?o
f>GO00Co0000omS`h_oHl>;of?3R0_l000000onim?;o0000ojcgkP0<o`000003oh;Wkol0003o0000
00Wo00000_nPgO`00ol0003oZ;o[ojRoj`03ojRoj`;o00000onX_n/2o`0000?oZ;o[0ol00004ojRo
j`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/00ol0003oZ;o[o`000002o`000003ojRojol0003o
oooo00oooooo00?o0000ooooooooool08oooool0033ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`09ooooo`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
1ol0003oZ;o[o`000?l0003oZ;o[o`000?mAH/D00ol00002ofI^a`04o`000?mPHkkoH6>no`0000?o
JFJl00?o0000ogE/^omeK;/02ol00003oiQo]P03o`000?nRQKGoXXFe00;oXXFe00?o0000ojZ:]?nZ
R[@00onZR[@2o`0000Co/i6c00?o0000okRE/onhUK<00onhUK<00ol0003o`9bcol2L/`03ol2L/`03
o`000?o3WkCo000000Coaj>e00?o0000olRU]_l000001?o=ZkL00ol0003oc:bio`000005om6c^`?o
00000_oE^l401_l0003of/C3om[4`ol0003oe/G9o`0000?oflk=00Go0000omoId?oOfM3ogmW@o`00
0003omSUg`06o`000?oHl>;of?3RomS`h_l0003oeOSR4Ol00002oh_Un@Go000000CoGlClo`000?l0
003o00000onPgO`00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[1?l00002ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo000_ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool2o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?o
Z;o[00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03
o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oDF;5oe5Ra@02o`000003ofI^aol0003oH6>n00;o
H6>n00Co0000ofUV_?mYI[co00000omeK;/01Ol0003oPG:ioh5b^On1L[Wo000000CoSGVh00?o0000
oiQo]_nHOkH00_nHOkH00ol0003oXXFeoj:5]@02oj:5]@04o`000?nZR[CoZXZdojZ:]0;o00001Onc
TK<00ol0003o^9FcokRE/`02okRE/`;o00001_o0W;<00ol0003oaj>eolNS]@04olNS]@03o`000?o=
ZkOocJ^g00CocJ^g00Co0000om6c^ooA/k_odK>k0ol000001OoG^[go0000omFk`OoE^l7o000000Co
f/C300Go0000om_>cOoKc/goflk=o`000004omoId0;o000000?of>GOo`000?oHl>800_oHl>800ol0
003oeOSRo`000002olkmh@;o000000Go^_gIo`000?nanmOo0000ojcif@03o`000004ojgij?l0003o
/OKaok7fl@?o00000_nCgoh<o`0000GoZ;o[00?o0000ojRojol000000ol00005ojRoj`06o`000?nX
_n_o0000o`000?nX_n_o00001OnX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/00onX_n/2o`0000oo
oooo00?o0000ooooooooool08_ooool002oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`02ooooo`Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00000onX_n/01Ol0003oZ;o[ojRojonX_n_o000000;oDF;500?o0000
odmL`Ol000000_l00002of1S_P05o`000?mYI[coJFJlofUV_?l000000_meK;/00ol0003oPG:ioh5b
^@02oh5b^@05o`000?n=NKSoSGVhohei^?l000001?nHOkH00ol0003oXXFeoj:5]@02oj:5]@06o`00
0?nZR[CoZXZdo`000?n/SKCo00001OncTK<01ol0003o^9FcokRE/onhUK?o0000okbI]?l000001_o0
W;<00ol0003oaj>eolNS]@04olNS]@03o`000?o=ZkOocJ^g00CocJ^g1?l000001ooA/k_o0000omNj
_OoG^[go0000omFk`Ol000001OoJa<<2o`000003om_>cOl0003ogmW@00?ogmW@00?o0000on?TdooS
i=<00ol000001?oHl>;o0000omGhh_l00002olkmh@;o000000Go^_gIo`000?nanmOo0000ojcif@03
o`000003ojgij?l0003o/OKa00;o00000_nek_H3o`0000;oV]Cl2ol00003ojRoj`?o00000onX_n/2
o`0000?oZ;o[0ol00004ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`000?nX_n/00onX_n/0
0ol0003oZ;o[o`000002o`000003ojRojol0003ooooo00oooooo00?o0000ooooooooool08Oooool0
02oooooo00?o0000ooooooooool05Oooool4o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRo
j`03o`000?nX_n_oZ;o[00Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_o
Z;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`05o`000?nX
_n_oZ;o[ojRojol000000_mAH/D00ol0003oCec1odmL`@02o`000003of1S__l0003oJFJl00;oJFJl
00Go0000ogE/^omeK;_oMFbko`000003oh5b^@03o`000?n=NKSoSGVh00;oSGVh00Go0000oiQo]_nH
OkKoV7nfo`000004oj:5]@03o`000?nZR[Co000000?o[8fd00?o0000ok>A/oncTK<00_ncTK<01?l0
003o^9FcokRE/ol00003okbI]003o`000?o0W;?o`9bc00;o`9bc00?o0000olBQ]?l000001?o7XkD0
0ol0003oc:Vfo`000003olf[]`Co00000_oA/k/00ol0003oekZmomNj_@02omNj_@03o`000?oJa<?o
f/C300?of/C300?o0000on3=a_oPcLH00_l00003omoId005o`000?oSi=?ohnCCon?Tdol000000_oU
k]@4o`000003olkmhOl0003o000000Oo000000?oaOkKo`000?l000000ol000000onek_Ko0000o`00
0002okKQm@?o00000onMaoD01Ol0003oO;Khogbfn?ml]_So000000;oD9kd1?l00002oj;Jn`03o`00
0?nX_n_oZ;o[00;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003oZ;o[
ojRoj`03o`0000GoZ;o[00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`00;ooo
ool00ol0003oooooooooo`0Dooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX
_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o
0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Ko00000_mAH/D01Ol0003oCec1odmL
`Ol0003oEUjo00?o00000_mYI[`01Ol0003oMFbkogE/^omeK;_o000000?oPG:i00?o0000ohei^?n=
NKP00_n=NKP01Ol0003oV7nfoiQo]_nHOkKo000000CoXXFe0_l00004ojb=]003o`000?ncTK?o/i6c
00?o/i6c0_l00004okbI]005o`000?o0W;?o`9bcol2L/ol000000_o4XK@01Ol0003oaj>eolNS]Oo7
XkGo000000;oc:Vf1Ol00002om:a^@03o`000?oA/k_o000000GoekZm0_l00003om[4``09o`000?oP
cLKoh<g6on3=a_l0003oiMS8o`000?oOfM3o000000?ohnCC00Ko0000onG^e?oUk]Co0000onCge?l0
0002on3ldP05o`000?oIoloo0000o`000?o:ol/00_l000001_o3o]?o0000olGnfol0003oaocUo`00
00;obOK/0ol000000onfhOGo0000o`000002okCBl003o`000?nMaoGoWLOe00_o00001?nRf_/00ol0
003oZ;o[o`000003o`0000GoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0ol00003ojRo
j`04o`000?nX_n_oZ;o[ojRoj`?o00003_ooool2o`0002;ooooo000_ooooo`03o`000?oooooooooo
017ooooo1?l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oC6G<odaU
c003o`000005oe5RaOl0003oCec1odmL`Ol000000_mFG[l2o`000003ofUV_?l0003oMFbk00;oMFbk
00?o0000oh5b^On1L[T00_n1L[T01Ol0003oSGVhohei^?n=NKSo000000?oV7nf00?o0000oj:5]OnR
QKD00_l000000onSQkKo0000ojb=]003ojb=]003o`000?ncTK?o/i6c00?o/i6c00?o0000okbI]?nl
VK@00onlVK@01?l0003o`9bcol2L/ol00003olBQ]005o`000?o7XkGoaj>eo`000?o<ZKH00ol00002
olf[]`03o`000?oB/KWod[6i00;od[6i00?o0000omNj_OoG^[d00ooG^[d01_l0003ogL>oomg3_ol0
003of/C3o`0000?oh<g600Go0000onGHb?oUf<SoiMS8o`000003on?Td`06o`000?oUk]CoiNkDo`00
0?oTmmCo00000_oPo=801Ol0003ofOo?o`000?l0003ob_o;00;o000000Ko`okCo`000?o5o]_o0000
olOliOl00002olWfk003o`000?o8jNgob>W]00;o00001?ndd_03o`0000;oW[W[00Go0000ohF/k_n5
[>koQJc^o`000003ofBKk`Oo00000onX_n/2o`000006ojRojol0003o0000o`000?nX_n_o00001?nX
_n/00ol0003oZ;o[o`000002o`000003ojRojol0003oZ;o[00?oZ;o[1?l00002ojRoj`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool07oooool002oooooo0_l0000?ooooo`?o00001?nX_n/0
0ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04o`000?nX_n_o
0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`05o`000?nX_n_oZ;o[ojRojol000000_m<IL`01?l0003o
@EW4o`000?l00002odmL`@05o`000?mFG[ooEUjoo`000?mRHkd00ol00002ogE/^`03o`000?n1L[Wo
PG:i00;oPG:i00Go0000ohei^?n=NKSoSGVho`000004oiQo]P;o00000onSQkH00ol0003o[8fdojb=
]003ojb=]004o`000?ncTK?o/i6cok>A/`;o00001_nlVK@2o`0000Goa:6d1?l00003olbY]P;o0000
1OoB/KT00ol0003oekZmomNj_@02omNj_@03o`000?oM`koogL>o00;ogL>o00Go0000on3=a_oPcLKo
h<g6o`000004onGHb0;o000000OohnCCo`000?oUk]CoiNkDo`000?oTmmCo000000;oh?cB00Go0000
omWocol0003o0000ol[ob`09o`000005olWfk?l0003ob>W]olSYkOl000000_o4f^X01_l0003o]=;`
o`000?l0003o/<;Wo`0000CoW[W[00Go0000ohF/k_n5[>koQJc^o`000003ofBKk`03o`000?lkQNWo
000000Co00000_nX_n/3o`0000GoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00001OnX_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo
000^ooooo`03o`000?oooooooooo00gooooo0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol0
0003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX
_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`04
o`000?nX_n_oZ;o[o`0000?oC6G<00?o0000od5Ia?l000000om?G<401?l0003oEUjooeIN_ol00002
of9S_@?o000000?oMFbko`000?n1L[T00_n1L[T00ol0003oSGVhohei^002ohei^003o`000?nHOkKo
000000;o00001OnSQkH00ol0003o[8fdojb=]002ojb=]004o`000?ncTK?o/i6co`0000;o]YFe00?o
0000okbI]?nlVK@00onlVK@00ol0003oa:6dolBQ]003olBQ]0;o00001_o<ZKH00ol0003od[6iom:a
^@03om:a^@03o`000?oH^K_o000000?oekZm00?o0000omg3_ooM`kl00_oM`kl01Ol0003oh<g6on3=
a_oPcLKo000000?oiMS800?o0000onWRb_oYh/X00_l000001?oUk]Co0000onCge?l00002on3ldP03
o`000?oIoloo000000?o000000Cod?k1o`000?l0003od?o?0_l00002omCjhP?o000000?ob>W]o`00
0?o4f^X00_o4f^X2o`0000Co/<;W00?o0000oijijonN^N/02Ol000001?mTVnoo0000oc^5jOlkQNT5
o`0000;oY/oe00?o0000ojRojonX_n/00onX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol0
0004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00003oooool00ol0003oooooooooo`07ooooo`Co0000
00?o410@ooooooooool04?ooool002kooooo00?o0000ooooooooool02_ooool4o`0000CoZ;o[00Co
0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`04o`000?nX_n_o0000o`0000;o
Z;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000Co
Z;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`Go00000om<IL`00ol0
003o@EW4od5Ia002o`000005odmL`Ol0003oEUjooeIN_ol000000_mRHkd00ol0003oL6Zlog1Z_00<
o`0000;oVH6h00?o0000oj>7]_nSQkH00onSQkH00ol0003o[8fdojb=]002ojb=]003o`000?ncTK?o
000000?o]YFe00?o0000okbI]?nlVK@00onlVK@00ol0003oa:6dolBQ]003o`000003olBQ]?l0003o
c:Vf00Goc:Vf00?o0000om:a^OoB/KT00ooB/KT01_l0003of;VkomRi^ol0003oekZmo`0000CogL>o
00Go0000on?<`Ol0003oh<g6o`000003onGHb006o`000?oYh/[ojN;:onWRb_l0003ok>c;2?l00000
1?oLo/7o0000o`000?o@o/42o`000003om3ocol0003o000000;oe?[R00?o0000om?_i_oCknH00ol0
00000oo4f^[o0000o`000002okk:i003o`000?n``^Oo/<;W00Co00000_nN[>401Ol0003oRj;Toh^R
i?n;X^Co000000;oLYKV2Ol00002ojK?m@;o000000KoZ;o[o`000?l0003o0000ojRojol00004ojRo
j`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000_nX_n/00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool002kooooo00?o0000oooooooo
ool01oooool3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_oZ;o[00Co
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`Co00000_nX_n/00ol0003oEWSHoeIhf002o`000006odaUc?l0003o@EW4od5Ia?l0003o@UO1
0_l00002oeIN_`05o`000?mRHkgoHV>mof9S_Ol000000_m`J[`00ol0003oOW:kogib^`02ogib^`05
o`000?n<N[[oS7Zjohaj^_l000001?nIPKP00ol0003oXhNfoj>7]P02oj>7]P03o`000?n/SKCo[8fd
00;o[8fd0_l00005okJE]@04o`000?nlVKCo_9VdokbI]0Co00000oo4XK@00ol0003obJJfo`000004
olbY]P03o`000?oA[kSo000000?od[6i00?o0000omRi^ooH^K/00_oH^K/00ol0003ogL>oomg3_`02
omg3_`05o`000?oSc<7ohlc1on?<`Ol000000ooUf<P01Ol0003ojN;:onWRb_oYh/[o000000;ok>c;
00Go0000oncdb_l0003oj?[8o`000002on?ma0?o000000Cod?k1o`000?l0003od?o?0ol000001OoD
n^;o0000om?_i_oCknKo000000;oc^7V0_l00004okk:i0?o00000_n/]=h00ol0003oWZcQoij/h@02
oij/h@05o`000?n;X^CoRj;Toh^Ri?l000000_mbU^H01?l0003oDhOVoe>7i_mCQnH9o`0000GoZ;o[
00Ko0000ojRojol0003o0000ojRojol00005ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX
_n/2o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`00;_ooool0
0ol0003oooooooooo`05ooooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000GoZ;o[00?o0000
ojRojonX_n/01?l00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[
o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000oeIhf?l0003o=e[:0ol00002od5I
a003o`000?m2El7o@UO100;o000000GoEUjoo`000?mRHkgoHV>mo`000003og1Z_005o`000?mnL[_o
OW:kogib^ol000000on<N[X00ol0003oVH6hoiV1^002oiV1^003o`000?nSQkKoXhNf00;oXhNf00?o
0000ojb=]?n/SK@00_l000000on_T;Ko0000okJE]@04okJE]@03o`000?nlVKCo000000;o000000?o
`9feo`000?o4XK@00_o4XK@01?l0003obJJfolVV]_l00003olbY]P07o`000?oA[kSodJnhom6_^?l0
003od[6io`000005omRi^`05o`000?oM`koogL>oomg3_ol000001?oSc<42o`000003onGHb?l0003o
jN;:00;ojN;:00So0000onc/boo/k<_o0000oncdb_l0003oj?[8o`0000;ohog40ol000000oo@o/7o
0000o`000003o`0000;ofOgJ0_l000001ooCknKo0000olkQi_o>hNKo0000olOAhOl000000onnb^@0
0ol0003o^;_Lo`000004ojbdgP03o`000?nN[>7oWZcQ00[o00000omCQnH00ol0003o;gGQo`000006
o`0000?oZ;o[0ol00004ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00001?nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`00013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`00
;_ooool00ol0003oooooooooo`03ooooo`?o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRo
j`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`00
00CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`05o`000?nX_n_oZ;o[ojRojol000000_mFN=P0
0ol0003o=e[:ocMJbP02o`000006od5Ia?l0003o@UO1od9G`Ol0003oBUW00_l00002of9S_@05o`00
0?m`J[coL6Zlog1Z_?l000001?mnL[/01Ol0003oS7Zjohaj^_n<N[[o000000?oVH6h00?o0000oj>7
]_nSQkH00onSQkH2o`0000?o[i2f00?o0000okJE]OnfUKD00_nfUKD4o`0000Co`9fe00Co0000olBQ
]?o4XKCo00000oo9Y[H01?l0003oc:VfolbY]_l00003om6_^003o`000?oB/KWo000000Cof;Vk00?o
0000omg1_Ol000000_oM`kl01Ol0003ohlc1on?<`OoSc<7o000000;oj=K30_l00003onWRbP07o`00
0?o/k<_o0000oncdb_l0003oj?[8o`000002on?ma0Go000000Cod_fko`000?l0003o00000_oIoMX0
0ol0003ofOCQo`000002o`000003olkQi_l0003oam7Q00;oam7Q00?o0000okk:i?l000000onh^m`0
1?l0003o[;CNojbdg_n/]=h3o`0000;oWJ;H00Go0000ohnJf_n?V][oSi[Jo`000002ogbBg@Ko0000
0_l_MN48o`0000?oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o
00001?nX_n/00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool002kooooo00?o0000ooooool000000ol00003ojRoj`03o`000?nX_n_oZ;o[00Co0000
1?nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`00
00;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/02?l000001OmF
N=So0000ocMJb_l0003o;U7500;o00000_m2El401?l0003oBUW0odYI`?l00003of9S_@04o`000?m`
J[coL6Zlo`0000CoOW:k00Go0000ohaj^_n<N[[oS7Zjo`000004oiV1^004o`000?nSQkKoXhNfoj>7
]P;o00001On_T;H4o`000003okJE]Ol0003o000000Go`9fe00?o0000olBQ]?l000001?o9Y[H00ol0
003oc:Vfo`000005om6_^003o`000?oH^K_of;Vk00;of;Vk00Ko0000omg1_OoM`Kgo0000omg3_ol0
0004on?<`@0:o`000?oXe/?oj=K3o`000?o]hLGo0000onWRb_l0003ok>c;o`0000;ok?C:0_l00002
on?ma0;o000000CofObfo`000?l0003od_fk0ol00002omWmfP03o`000?oIm>7o000000;oeNOS0_l0
0004olOAh@;o00001?nh^m`01_l0003o[;CNo`000?l0003oZJSFo`0000CoWJ;H00Go0000ohnJf_n?
V][oSi[Jo`000002ogbBg@04o`000?mUQmooIHOOofF7g`Co000000?o2f?Io`000?l000000_l00005
ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00;Oooool3o`00
00?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/0
0ol0003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`06o`000?nX_n_o
0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[0ol00003ojRoj`05o`000?m_U^OoKiKWo`000?lgI=800_l00002ocMJbP04o`000?l^DLGo0000
o`0000;o@UO100?o0000odYI`?m:FL000_l000000omRHkgo0000og1Z_002og1Z_005o`000?mnL[_o
OW:kogib^ol000000on<N[X00ol0003oVH6hoiV1^002oiV1^006o`000?nSQkKoXhNfo`000?nUR[So
00000on_T;H3o`0000?o]YFe00?o0000okZI]ol000001_o0WKD00ol0003obJJfolVV]P04olVV]P03
o`000?oA[kSodJnh00CodJnh00Go0000omRi^ooH^K_of;Vko`000004omg1_@03o`000?oSc<7ohlc1
00;ohlc100Co0000onSF`ooXe/?o00000oo]hLD4o`000003oncdb_l0003o000000?o000000Goh?bh
o`000?l0003o0000om;m^`04o`000004omWmf_l0003ofOCQo`0000;oeNOS00Go0000olkGh?o>en3o
0000olOAh@02o`0000;o`<7K00?o0000okRkg?nh^m`00ol00004ojVXeP05o`000?nMX]SoWJ;HoifR
f?l000000on?V]X01Ol0003oO9;MogbBgOmlT]go000000?oIHOO00Co0000od]kgol0003o00000_l;
HmT3o`000006ojRojol0003o0000o`000?nJh_go00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000GoZ;o[0ol00002ojRoj`03o`000?oooooooooo00gooooo0_l00007ooooo`03o`000?oooooo
oooo01;ooooo000]ooooo`03o`000?oooooo000000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[
00Co00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000
ofnFiom_U^Oo00000_lgI=83o`0000;o;U750_l000001_m2El7o0000odYI`?m:FL3o0000oeUP_`;o
00000om`J[`01Ol0003oOW:kogib^omnL[_o000000?oS7Zj00?o0000oiV1^?nIPKP00_nIPKP00ol0
003oXhNfo`000003ojF:^0?o00000_n_T;H01?l0003o]YFeokJE]Ol00002okZI]`03o`000?o0WKGo
`9fe00Co`9fe00?o0000olVV]_o9Y[H01?o9Y[H00ol0003odJnhom6_^003om6_^003o`000?oF]k[o
000000;of;Vk00?o0000omg1_OoM`Kd00_oM`Kd2o`0000;ohlc100Go0000onSF`ooXe/?oj=K3o`00
0003ongQa@07o`000?o_j/Go0000onoc`ol0003okOS0o`000002onOk_0Co000000Cod_fko`000?l0
003oe?o61_l000000ooEin?o0000olkGh002olkGh0;o00001?o0`M/3o`0000;o/ZkD00?o0000ojVX
e_nYZ=H00_nYZ=H00ol0003oWJ;HoifRf00?o`0000;oBg_O0_l000000ol;HmWo0000o`000002o`00
00CoV^;m00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o000000;o000000?oZ;o[o`00
0?nX_n/00onX_n/00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Cooooo00?oEEEE
ofIVI_l000005?ooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`04o`000?oooooo
ooooo`0000;oZ;o[1?l00003ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/0
0_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003o
Z;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l000001Om_U^Oo0000ocMTd_l0003o8E;:
00;o000000?o;U75o`000?l`Cl800_l00003odYI`003o`000?mIH;ooFF2o00Co00001?mnL[/01Ol0
003oS7Zjohaj^_n<N[[o000000;oVH6h0ol000000onUR[So0000o`000002o`0000Go[i2f0_l00004
okZI]`03o`000?o0WKGo`9fe00;o`9fe00?o0000olBS]ol000001?o9Y[H00ol0003ocZfho`000003
om6_^006o`000?oF]k[oe[Njo`000?oH^K_o00001?oM`Kd01_l0003ohl^oon?;_ol0003ohlc1o`00
00;oj=K300Oo0000ongQaOo]hLGokN75o`000?o_j/Go000000;oko?30_l00002onOk_0;o000000?o
fObfo`000?l000000_l000000ooDolKo0000o`000002om_ig@04o`000?oIk^7ofNkQo`0000?oc]OP
00?o0000olK7fol000000oo0`M/00ol0003o^K?Do`000004ok:^e003o`000?nYZ=KoZJSF00Co0000
0_nMV]001Ol0003oTYCBoi:Dd_nBU=;o000000?oQ8kE00Co0000og>7f?mcQmSoLhOH1?l000000ol]
Kmgo0000o`00000:o`0000?oZ;o[00?o0000ojRojonX_n/00ol00005ojRoj`03o`000?nX_n_oZ;o[
00?o00003oooool00ol0003oooooooooo`0Iooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00Co0000oooooooooooooooo0_l00004ojRoj`03o`000?nX_n_oZ;o[00;o00001OnX_n/0
0ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`02ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/01?l00002ohfcl004o`000?m6Mmgo0000o`00
00;o=fCB00?o0000ob5Bb_l000000_l^DLD01?l0003o<4o2o`000?l00002odYI`004o`000?mIH;oo
FF2oo`0000;oJVVo3?l00002oiV3^P;o00000onUR[P00ol0003o[i2fojn@]P03ojn@]P03o`000?nj
VKOo^YVg00?o^YVg00Go0000ol2M]Oo0WKGo`9feo`000002olBS]`05o`000?o9Y[KobJJfolVV]_l0
00000_o>[KP01?l0003odJnhom6_^?l00004omJg^P03o`000?oM`KgogL6m00?ogL6m00Go0000on?;
_ooSbkoohl^oo`000002onSF``05o`000?o]hLGokN75ongQaOl000000_o_j/D01?l0003oko?3o`00
0?l00002onOk_0;o000000?ofObfo`000?l000000_l000000ooDolKo0000o`000002om_ig@08o`00
0?oIk^7ofNkQo`000?oBg^7o0000olkGh?l00003olK7f`03o`000?o0`M_o000000?o^K?D00Co0000
ok:^e?nb[]Co/ZkD0ol00002ojJOc`03o`000?nMV]3oWI[@00;oWI[@00Go0000oi:Dd_nBU=;oTYCB
o`000003ohB>e@06o`000?mcQmSoLhOHog>7f?l0003oGgoK0_l00003obe_g@;o000000?o05G?o`00
0?l000000_l00005ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`?o00000onX_n/00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo000Sooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`02ooooo`03o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000;oZ;o[00?o
0000ohfcl?n=/o000_n=/o000ol0003oAWOModIgg@03o`0000;o8E;:0ol00002oc1?`P;o000000Go
BUW0o`000?mIH;ooFF2oo`000003ofYY_`05o`000?mkL[koNg:nog]b__l000000on;Nk`00ol0003o
VH>jo`000003o`0000GoYHZh00Co0000ojn@]_n_T;Ko[i2f0_l00005okZI]`04o`000?o0WKGo`9fe
o`0000?oa:>g00Co0000olVV]_o9Y[Ko00000oo>[KP00ol0003odJnho`000005omJg^P03o`000?oM
`KgogL6m00;ogL6m00?o0000on?;_ooSbkl00_oSbkl2o`000005onSF`ol0003okN75ongQaOl00000
0_o_j/D01_l0003oko?3o`000?o]n<3o0000onOk_0Oo000000Koe?o6o`000?l0003o0000om_igOl0
0002omW^h@03o`000?oBg^7od]kQ00;o00001?o6am/2o`0000Co^K?D00Ko0000ok:^e?l0003o0000
ojfTc_l00004ojJOc`05o`000?nMV]3oWI[@oifJd?l000000onBU=801Ol0003oQ8kEohB>eOn4S]Go
000000CoLhOH00?o0000oemofomOOm/00_l000000ol]Kmgo0000o`000003o`000004o`=og_l0003o
0000ojRoj`?o000000?oY/cco`000?nX_n/00onX_n/00ol0003oZ;o[o`000002o`000003ojRojol0
003oZ;o[00?oZ;o[0_l0000?ooooo`03o`000?oooooooooo01Oooooo000Sooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`03ooooo`06o`000?nX_n_o0000o`000?nX_n_o
00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`05o`000?n=
/o3oSK?`ohfcl?l000000_m6Mmd00ol0003o85gCo`000002ob5BbP07o`000?lFB<Co0000o`000?l`
Cl;o0000oc]D`P03o`0000;oFF2o00Co0000ofYY_omZJKoo00000omkL[h00ol0003oRg^loh]k_003
o`0000CoVH>j00?o0000ojF:^?nUR[P00_nUR[P01?l0003o[i2fojn@]_l00002ok:D^@03o`000?nj
VKOo^YVg00?o^YVg0_l00005olBS]`;o00001Oo>[KP00ol0003oe[NjomJg^P03omJg^P03o`000?oM
`;go000000;ogL6m00?o0000on?;_ooSbkl00_oSbkl00ol0003ojMK1onWF`@02o`000005ongQaOl0
003okn[5onoZaOl000000_o_ll<2o`000003onOk_?l0003o000000So000000Kof?gJo`000?l0003o
0000omW^hOl00002om;Nh@05o`000?o;cMcoblgLo`000?o6am/00_l000000onn^MCo0000okVce003
okVce0;o00001?n]Y<h01Ol0003oYYo?ojJOconVWloo000000;oWI[@3ol00002oemof`03o`000?m9
Mmco000000Oo000000?o0goNo`000?nVc?<01?nVc?<00ol0003oZ;o[ojRoj`03o`0000GoZ;o[1?l0
00000onX_n_o0000ooooo`0>ooooo`03o`000?oooooooooo01Oooooo000Sooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`05ooooo`;o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`04o`00
0?nX_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`08o`00
0003odIggOl0003o85gC00;o000000Co8E;:o`000?lFB<Co00000_l`Cl800ol0003o>eC2oc]D`P02
o`000003oeUP_ol0003oJVVo00;oJVVo00?o0000og]b__mkL[h00ol00002oh]k_003o`000?nIPk[o
VH>j00;oVH>j00?o0000ojF:^?nUR[P00_nUR[P00ol0003o[i2fo`000003ok:D^@03o`000?njVKOo
^YVg00?o^YVg00?o0000olBS]oo4XkL01?o4XkL00ol0003ocZfholj]^004olj]^003o`000?oF]k[o
e[Nj00?oe[Nj00Ko0000omg0_OoM`;go0000omg1_Ol00003on?;_`06o`000?oYe/7ojMK1onWF`Ol0
003ok^320ol000000oo_j/Go0000onoc``04o`000006omkk/Ol0003o0000om3i[Ol0003oaOR_0ol0
00001?oHoM[o0000omWchOoIln43o`000003om;NhOl0003oblgL00;oblgL0_l00004okjie006o`00
0?ni/mCo0000o`000?ncZ<ko00001?n]Y<h00ol0003oYYo?ojJOc`04o`0000;oW9?:00Go0000oiB?
c?nDSlcoU8o<o`000003ohV;cP04o`000?mmQ]7oOHKAogf6d@Go00000om9Mm`4o`000004o`1DcOl0
003o0000o`0000?oY/cc1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001OnX_n/00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Kooooo000Sooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooo`000007ooooo`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[
ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_o000000;oZ;o[
00?o0000ojRojonX_n/00_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;o
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onT_^`01Ol0003oHY7Xof:Aj?l0003o<GCP
00;o000000?o85gCo`000?l4AlL00_l00002oaI8a0?o00000_lkE<801?l0003oCEg2o`000?l00003
ofYY_`?o000000?oNg:no`000?n;Nk`00_n;Nk`00ol0003oVH>joiV3^P02oiV3^P03o`000?nUR[So
YHZh00;oYHZh0_l00005ok:D^@04o`000?njVKOo^YVgokZI]`;o00001_o4XkL00ol0003ocZfholj]
^003olj]^003o`000?oD]K_o000000?oe[Nj00?o0000omg0_OoM`;d00_oM`;d01Ol0003ohl^oon?;
_ooSbkoo000000?ojMK100Co0000onkP`_o^h<;o00000_oaj/83o`000003ongh_?l0003oio^g00?o
000000?od?V]o`000?o5n:l00ol000001OoHoM[o0000omWchOoIln7o000000;oe>CR0_l00003ol_=
g003o`000?o2_]Ko000000Co_[WD0_l00004ok>XcP04o`000?n]Y<ko[JC>ojfTcP?o00000_nTV<T0
0ol0003oW9?:oibCbP02oibCbP05o`000?nDSlcoU8o<oiB?c?l000000on9Rlh01Ol0003oOHKAogf6
dOmmQ]7o000000;oKh7E0ol000000om9Mmco0000o`000009o`0000;oS/on00?o0000ojRojonX_n/0
0_nX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol0000?ooooo`03o`000?oooooooooo01Go
oooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool2o`0000Wooooo0_l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003o
Z;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04o`000?nX_n_o0000o`00
00;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nT_^coY;k/00;oY;k/00Co0000
of:Aj?mRTNSo00000_laM>03o`000006o`A7aol0003o5TS4oaI8a?l0003o6DO20_l000001?lkE<;o
0000odeM`_m=GL85o`0000?oNg:n00?o0000oh]k_?n;Nk`00_n;Nk`00ol0003oVH>joiV3^P02oiV3
^PCo000000?oYhnko`000?nbU;T01?nbU;T01?l0003o^YVgokZI]ol00002okjO^@03o`000?o4XkOo
a:>g00;oa:>g00?o0000olZ[^_l000001?o>[KP01_l0003oe;FkomBe^ol0003oe[Njo`0000GogL2m
0_l000000ooSbkoo0000onWF`@02onWF`@04o`000?o^h<;ok^32o`0000?olN[200Go0000oo7c`?l0
003o0000onOk]`05o`000003olGh[ol0003o000000Co000000GofO?Qo`000?oDi>;oe>CRo`000002
olgCgP03o`000?o;cMco000000?o`[kF00Ko0000okjie?l0003o0000okN]c_l00004ok>XcP06o`00
0?n]Y<ko0000o`000?nYVlSo00001?nTV<T01Ol0003oW9?:oibCb_nLTl[o000000?oU8o<00Go0000
ohV;c_n9RlkoRH_>o`000004ogf6d@05o`000?m_PMGoKh7Eo`000?mOOMT01?l000001?ldLMgo0000
o`000?l6HmT2o`000003o`1ZfOl0003o000000?o000000GoZ;o[o`000?l0003oZ;o[o`000004ojRo
j`Co00000_nX_n/00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo000Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`09ooooo`06o`000?nX_n_oZ;o[
ojRojol0003oZ;o[0_l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRo
j`04o`0000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nT
_^coY;k/00Ko000000?o<GCPo`000?l1Dll00_l000001ol4AlOo0000o`000?lFB<Co0000oaU7`_l0
00000_lkE<86o`000005ofYY_ol0003oNg:nog]b__l000001?n;Nk`01?l0003oVH>joiV3^_nIPkX2
o`0000CoYhnk00?o0000ok:D^OnbU;T00onbU;T00ol0003o^YVgo`000003okjO^@05o`000?o4XkOo
a:>golBS]ol000000_o:ZkX01Ol0003ocZfholj]^?o>[KSo000000?oe;Fk00?o0000omJg^_l00000
1?oM`;d00ol0003ohl^oon?;_`02o`0000?ojMK100Co0000onkP`_o^h<;o00000_oaj/801?l0003o
lO?0o`000?o]n;`6o`000007olGh[ol0003o0000o`000?o@omOo0000omGihP03o`000003omCTh_l0
003ocM?N00;ocM?N0_l00004ol:neP;o00001?ng[Lh01?l0003o/jS>ok>Xc_ncZ<h2o`0000CoZI_8
00Go0000ojBHbOnTV<WoY9S9o`000003oibCbP05o`000?nDSlcoU8o<oiB?c?l000000on9Rlh00ol0
003oOHKAogf6d@02ogf6d@05o`000?m_PMGoKh7Eofn1eOl000000omOOMT3o`000003obI`gol0003o
000000Co00000_mV]O`2o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00005ojRoj`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05?ooool002cooooo00?o0000ooooooooool02_oo
ool00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[
ojRoj`02ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[
00Co00000on;/_000ol0003oEIG_o`000003o`0000;o0E??0_l000001?l0?;oo0000o`000?lIAl84
o`0000;oCEg200?o0000of9X`omRJ<<01?l000000omkL[ko0000oh]k_002oh]k_006o`000?nIPk[o
0000o`000?nJQkko00001OnWSk/00ol0003o/YBiok:D^@02ok:D^@;o00001OnnWkT01?l0003oa:>g
olBS]ol00003olZ[^P03o`000?o>[KSo000000Goe;Fk00?o0000omg0_OoM`;d00_oM`;d02Ol0003o
hl^oon?;_ooSbkoo0000onWF`Ol0003ojMK1o`000002onkP`P0;o`000?oaj/;olN[2o`000?oall3o
0000ongh_?l0003oio^go`000?o>mjD01_l000001?o@omOo0000omGih_l00002om?Zi@;o00000oo=
dmh00ol0003oa<;Ho`000003ol:neP03o`000?nk/M3o000000Co]jg>00Ko0000ok>Xc_l0003o0000
ojjOb?l00004ojVKb005o`000?nTV<WoY9S9ojBHbOl000000_nLTlXCo`0000?oGggI1?l00003obI`
g`;o000000?o47;Qo`000?l000000_l00003ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`00
00kooooo00?o0000ooooool000005Oooool002cooooo00?o0000ooooooooool02oooool2o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003o
Z;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00Co0000ojRojol0003o00000_nX_n/0
0ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00So0000
oh^bl?n;/_3oRk;`o`000?mEUNoo0000oaI_g`;o000000Go0E??o`000?l0>Kko0000o`0l_`02o`00
0004oaU7`_l0003o0000o`0000?oCEg200Co0000of9X`omRJ<?o00000_mgM<87o`0000CoVXNn00?o
0000ojN?^onWSk/00_nWSk/01ol0003o/YBiok:D^OnbU;Wo0000okJK_?l000001OnnWkT00ol0003o
a:>go`000004olZ[^P03o`000?o>[KSo000000Goe;Fk00Go0000omg0_OoM`;gogL2mo`000003on?;
_`05o`000?oYe/7ojMK1onWF`Ol000000_o^h<801?l0003olN[2oo7Z`_l00002oo7c`0;o000000?o
io^go`000?l000000ol000001onjmk7o0000o`000?o@omOo0000omGih_l000000_oCj^D01_l0003o
cMSRolgHh_l0003ocM?No`0000?oa<;H00?o0000ol:ne_l000000onk/M001?l0003o]jg>okN]c_ng
[Lh2o`0000Co[Yo800Go0000ojVKb?nYVlSoZI_8o`000002ojBHb@Co00000_nLSlD01Ol0003oUXc7
oiJ<aonFS<Oo000000?oSXW900?o0000ohF6c?n5Q/`00_n5Q/`00ol0003oNh?@og^3d004o`000004
oemmfOl0003o0000odmjg@;o000000?o9W3Oo`000?lYNnH00ol000000om4VoCo0000o`000002o`00
00?oY/cc00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04oooool002cooooo00?o0000ooooooooool02oooool00ol0003oZ;o[ojRoj`02ojRoj`?o
00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03
o`000?nX_n_oZ;o[00Co00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003
ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[2?l00002oaI_g`Go000000Co03boo`000?lIAl;o6DO20ol0
0002odeM`P05o`000?mRJ<?oHVS3of9X`ol000000_mgM<800ol0003oRWk0ohYn`002ohYn`003o`00
0?nJQkkoVXNn00;oVXNn00?o0000ojN?^onWSk/00_nWSk/01?l0003o/YBiok:D^Ol00002okJK_003
o`000?nnWkWo_Yni00Co_Yni00?o0000olZ[^_o:ZkX01?o:ZkX00ol0003oe;FkomBe^`03omBe^`03
o`000?oJ_kko000000;ogL2m00Go0000on?;_ooSbkoohl^oo`000003onWF`@;o000000Cok^32o`00
0?oaj/;o00000_oall000ol0003okORlo`000005o`000003ok[g/Ol0003o000000Go000000?odn[U
o`000?o=f>800_o=f>82o`0000Coa<;H0_l00004ok^ad006o`000?ng[Lko0000o`000?nbXlWo0000
1?n^WlP01?l0003oZI_8ojVKb?nYVlP3o`0000;oXY;400?o0000oib?aOnLSlD00_nLSlD01Ol0003o
UXc7oiJ<aonFS<Oo000000?oSXW900?o0000ohF6c?n5Q/`00_n5Q/`01?l0003oNh?@og^3d?l00002
og21e0Go000000Co@g_Qo`000?l0003o00000olYNnH4o`0000?oY/cc1?l00002ojRoj`03o`000?nX
_n_oZ;o[00;oZ;o[0_l0000?ooooo`03o`000?oooooooooo01;ooooo000[ooooo`03o`000?oooooo
oooo00gooooo00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00001?nX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[
00Ko0000ojRojol0003o0000ojBnk?l00004oh:fmP03o`000?m3V??o000000Go000000Oo03Vno`00
0?l0003o0000oaU7`_l0003o9dg300;o00000_m=GL801?l0003oHVS3of9X`ol00003ogMd`P05o`00
0?n:O/3oRWk0ohYn`?l000001?nJQkh00ol0003oYhnkojN?^`03ojN?^`;o00001?nfVk`00ol0003o
_YniokjO^@02okjO^@;o00001_o:ZkX00ol0003oe;FkomBe^`02omBe^`06o`000?oJ_kkof[nno`00
0?oM`;go00000ooSbkl01Ol0003ojMK1onWF`OoYe/7o000000;ok^732?l000000ooSnk?o0000o`00
0006o`000004olclhol0003ocnoYolo_j@;o00000oo=f>800ol0003oaLOKo`000003olC2f003o`00
0?nl]=;o000000Co^k7@0_l00004ok:Sb@06o`000?n^WlSo[Yo8ojjOb?l0003oZI_80_l000000onV
ULCo0000oj:Ba003oj:Ba005o`000?nLSlGoW8o5oib?aOl000000onFS<L01Ol0003oSXW9ohj9bOn>
RLWo000000CoQHK<00Go0000og^3d?mkPm3oNh?@o`000002og21e003o`000?mTP=Wo000000;o0000
0om3Nn44o`0000;oBIOb1?l00002oiO4mP03o`000?nX_n_oZ;o[00;oZ;o[00Ko0000ojRojol0003o
0000ojRojol0000@ooooo`03o`000?oooooooooo017ooooo000[ooooo`?o00003_ooool2o`0000Co
Z;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nT_^`00ol0003oP[Kfoh:fmP07o`00
00;o04G41_l000000olWCL?o0000ociIaP03o`0000?oHVS300Co0000ogMd`_mgM<;o00001?n:O/00
0ol0003oVXNnoiZ7_P02oiZ7_P04o`000?nWSk_oYhnkojN?^`;o00001OnfVk`01Ol0003o_YniokjO
^OnnWkWo000000;o`jNm00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003od;>mo`000002omBe^`03o`00
0?oJ_kkof[nn00;of[nn0_l00002on?;_`05o`000?oYe/7ojMK1onWF`Ol000000oo^hL<00ol0003o
lNc2o`000002oo3d_`03o`000?o/nK[o000000;o000000?o]>bHo`000?l000000ol000001Oo<o>?o
0000olo_jOo?knWo000000;obmgW00?o0000olgHh_l000000oo5am/00ol0003oa<;Ho`000003okbd
dP06o`000?nk/M3o0000o`000?ndY/[o00001?nbXlT00ol0003o[Yo8ojjOb003o`0000CoYYG400Go
0000oj:Ba?nRT/CoXY;4o`000003oib?a@05o`000?nFS<OoUXc7oiJ<aol000000_n>RLT7o`0000?o
Nh?@00So0000og21e?m`PMCoL87Do`000?mTP=Wo0000ofB0f@Go000000?o@X?Wo`000?l000001?l0
0004oiO4mP03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo017ooooo000[ooooo`03o`000?oooooooooo013ooooo00?o0000ojRojonX_n/01?l00004
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03
o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00004ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oY;k/ojBnk005o`0000?oO;ol3?l000000olWCL?o
0000ociIaP02ociIaP;o000000?oHVS3o`000?mgM<800_mgM<801Ol0003oRWk0ohYn`?n:O/3o0000
00CoVXNn00Ko0000ojN?^onWSk_o0000oj^E_ol00005okJK_004o`000?nnWkWo_Ynio`0000?o`jNm
00Go0000olZ[^_o:Zk[obZ^jo`000002om2c_@03o`000?oD]K_o000000Gof[nn00Go0000on7:`Ol0
003ohl^oo`000002onWF`@07o`000?o^hL?ok^73onkQ`ol0003olNc2o`000002oo3d_`03o`000?o/
nK[o000000Co000000?oWnZSo`000?l000001?l000000oo?knWo0000ol_Mi`02ol_Mi`;o00001?o5
am/2o`0000Co_;CB0_l00004okBVbP04o`000?nbXlWo/Z?9ok:Sb@?o00000_nZV<@00ol0003oYYG4
ojJEa002ojJEa005o`000?nRT/CoXY;4oj:Ba?l000000_nLSlD8o`0000;oTXO500Co0000ohb6aon<
Q/OoS8K72Ol00002ofB0f@;o00000omKP]l4o`0000?oEYS`2?l00003ojS0j`03o`000?nX_n_oZ;o[
00?o00003oooool00ol0003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`0Aooooo`;o
00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`04
o`000?nX_n_o0000o`0000;oZ;o[00Ko0000ojRojonX_n_oZ;o[o`000?nX_n/2o`0000;oZ;o[00?o
0000ojRojonX_n/00_nX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/5o`0000;oZ<_b00?o
0000ogboo?ml_o`02Ol000000ol0;;Go0000o`0k_P03o`0000?o?UW600Co0000oeQXb?l0003o0000
0omgM<801Ol0003oRWk0ohYn`?n:O/3o000000CoVXNn00?o0000ojN?^ol000000on[UKl00ol0003o
]Y^lokJK_003okJK_0;o00001?o3Ykd01?l0003obZ^jolZ[^_l00004om2c_@03o`000?oJ_kkof[nn
00?of[nn00Go0000on7:`OoQb/7ohL[1o`000003onWF`@04o`000?o^hL?ok^73o`0000;olNc200Ko
0000oo3d_ol0003ok?Vjo`000?oSnk<3o`000005oioZXol0003o0000ok_li?l000000_o5lnh3o`00
0003ol_Miol0003o000000;o`l_O00Ko0000olG7fol0003o0000okfhe?l00003okbddP03o`000?nf
ZLco000000Co]:K:00Ko0000ok:SbOl0003o0000ojfKa?l00004ojZHa005o`000?nVULCoYYG4ojJE
a?l000000_nRT/@4o`0000;oW8c100Go0000oiR9`onHRL?oV8W3o`000004oi:7a@05o`000?n<Q/Oo
S8K7ohb6aol000000on5Q</00ol0003oOHC@ogf4d006o`0000?oFh;O00Co0000oeV:i_l0003o0000
0omFV?000ol0003oR[WeohZim@02ohZim@04o`000?nX`>_oZ<3[ojS0j`Co00000onX_n/00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo01;ooooo
00?o0000ojRojonX_n/00_nX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`00
0?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o
00000_nX_n/01_l0003oZ;o[ojRojonX_n_o0000ojRoj`Co000000CoZ;o[o`000?nXbo;oZ<_b1Ol0
0003og?8o`Ko000000Co02beo`000?l0003o3DC30_l00002ociIaP04o`000?mHJ<SoF6S8oeQXb0Co
00001?n:O/000ol0003oVXNnoiZ7_P03o`0000CoZiFo00?o0000okJK_?nfVk`00onfVk`00ol0003o
`jNmol>W_@04ol>W_@;o00001Oo@/kd00ol0003of[nnomZo_P02omZo_P03o`000?oQb/7ohL[100;o
hL[10_l000000ooYe/7o0000onkQ``02onkQ``05o`000?oak<;o0000oo3d_ol000000_o/nKX7o`00
0003ok_li?l0003oaO?^00;o00000_o5hN`2o`0000Co`l_O0_l00004okfhe003o`000?nl]=;o0000
00?o]ZW<00Co0000okBVb_ndY/[o]:K:0_l00004ojfKa005o`000?nZV<CoZYS4ojZHa?l000000onV
UL@3o`0000;oXHk100?o0000oib<`OnLS<400_nLS<401Ol0003oV8W3oiR9`onHRL?o000000?oTXO5
00?o0000ohb6aon<Q/L00_n<Q/L01Ol0003oQHC;ohF4bon5Q<_o000000;oOHC@00?o0000ogF5eOme
QMD01Ol000001?mKP]oo0000oeV:i_mIR^H5o`0000;oR[We1Ol00002ojO3k@03o`000?nX_n_oZ;o[
00;oZ;o[0_l0000>ooooo`03o`000?oooooooooo00oooooo000[ooooo`03o`000?oooooooooo01?o
oooo00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0
003oZ;o[ojRoj`02ojRoj`?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`0000CoZ]Og3_l000000ol=
A<?o0000ociIaP02ociIaP04o`000?mHJ<SoF6S8o`0000;oLWK82?l00002oib=``03o`000?n[UKoo
ZiFo00?oZiFo00Co0000okJK_?nfVkco]Y^l0_l00006ol>W_@03o`000?o@/kgod;>m00?od;>m00?o
0000omJn`_l000000ooJ_kh01Ol0003ohL[1on7:`OoQb/7o000000;oimK40ol000001?o^hL?o0000
oo7/`_l00002oo3d_`03o`000?o/nK[o000000[o00000oo5hN`01Ol0003o`<gTol3=i?l0003o`l_O
00;o000000?o_;[Ho`000?nm^=@00onm^=@2o`0000Co]ZW<00Ko0000okBVb_ndY/[o0000ojnMaOl0
0004ojfKa006o`000?nZV<CoZYS4ojZHa?l0003oYYG40_l000000onTT<3o0000oj6>`@03oj6>`@05
o`000?nLS<7oW8c1oib<`Ol000000onHRL<01Ol0003oTXO5oi:7aOnBQlGo000000CoS8K700Go0000
ohF4bon5Q<_oQHC;o`000003ogf4d003o`000?meQMGoMHGE00;o00000_m^R=`6o`0000;oI9[^0ol0
0002oh>al`03o`000?nW`ngoYl?]00?oYl?]1?l000000onX_n_o0000ooooo`0=ooooo`;o00004?oo
ool002[ooooo00?o0000ooooooooool05Oooool2o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRo
jol00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/3o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003o
Z;o[o`000?l00003okC6i`04o`000?nZeoOo0000o`0000;o[>7i1?l00002oeo?m0Oo000000Go3DC3
o`000?l0003o?UW6o`000003oeQXb004o`000?mbM/SoLWK8o`0000?oRH?600?o0000oib=`onLSL<0
0onLSL<00ol0003oZiFooj^E_`02oj^E_`04o`000?nfVkco]Y^lo`0000;o^Z?100?o0000ol>W_Oo3
Ykd00_o3Ykd2o`0000Cod;>m00Oo0000omJn`_oF_/;oe[k2o`000?oJ_kko000000?ohL[100Go0000
onOFa?oWe/CoimK4o`000002ongSaP;o000000?olNc2o`000?o`m;l00ol000000ooJnk3o0000o`00
0006o`0000;o_>?c00?o0000olGQk?l000000oo0cN@2o`0000Co_;[H00Ko0000okfhe?l0003o0000
okJ[c_l00004okJYc003o`000?ndY/[o000000?o[ig500Go0000ojfKa?n]VlCo[I_4o`000002ojZH
a0?o00001?nTT<001Ol0003oXHk1oj6>`OnQS/7o000000?oW8c100Go0000oiR9`onHRL?oV8W3o`00
0004oi:7a@05o`000?n<Q/OoS8K7ohb6aol000000on5Q</01Ol0003oOHC@ogf4d?mmQ=3o000000?o
MHGE0_l00002ofj8g004o`000?m/Sn?oK8oSofb?h`Go00001?n3/O<00ol0003oYl?]ojO3k@03o`00
00GoZ;o[00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`00:_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000Co
Z;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`02
ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000Co]<KW0ol000000on/hOWo0000o`000003
ojcZn@So000000Go02beo`000?l=A<?o0000obUDb@02o`0000?oF6S800Co0000og9fb?mbM/So0000
1?n9PlH00ol0003oW8g3oib=``02oib=``03o`000?n[UKooZiFo00;oZiFo00?o0000okJK_?l00000
1?njXl401?l0003o`jNmol>W_Ol00002olV``@05o`000?o@/kgod;>mom2c_Ol000001?oF_/801Ol0
003ohL[1on7:`OoQb/7o000000?oimK400Ko0000ongSa_o]hlKokN?6o`000?o_klD4o`000003onKk
^_l0003o000000Ko00001?nlho<2o`0000?o`<gT00?o0000okZlfol000001?nl^]P2o`0000Co]Z_>
00Co0000okJYc?nfZLco]ZW<0_l00004ojnMa@04o`000?n]VlCo[I_4ojfKa0?o00000_nWTl000ol0
003oY930ojB@`002ojB@`005o`000?nQS/7oXHk1oj6>`Ol000001?nLS<400ol0003oV8W3o`00000G
o`0000?oKXSL00Go0000ofb?hom/Sn?oK8oSo`000002og:Lj`So00000onS_nd00ol0003oZ;o[ojRo
j`03o`0000oooooo00?o0000ooooooooool03Oooool002[ooooo00?o0000ooooooooool06?ooool2
o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
1?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[00?o0000ojRojol000000ol0
0004ojRoj`?o00001?nX_n/01?l0003o]<KWo`000?l00002olONjPCo000000Co[>[io`000?l0003o
[?3g1?l000001On^m_3o0000o`000?l0003o02be00?o000000?o:EC9o`000?l000000_mHJ<P01Ol0
003oLWK8og9fb?mbM/So000000?oRH?600?o0000oib=`onLSL<00_nLSL<00ol0003oZiFooj^E_`02
oj^E_`;o00001OnjXl400ol0003o`jNmo`000004olV``@03o`000?o@/kgo000000Goe[k200Go0000
on7:`OoQb/7ohL[1o`000003onOFa004o`000?o]hlKokN?6o`0000;okno500Co0000ongg`Ol0003o
i_^j1ol00002ojkRn004o`000?nlho?o0000o`0000;o^/kZ00?o0000ol3=i?l000000onj_=/01_l0
003o_;[Ho`000?l0003o]Zg@o`0000Co]Z_>00Ko0000okJYc?l0003o0000ok2Paol00004ojnMa@06
o`000?n]VlCo0000o`000?nYUL7o00001?nWTl001Ol0003oY930ojB@`?nTT<3o000000CoXHk100?o
0000oib<`Ol000000ol00002oiV8_`05o`000?nFQl7oUXO1oiJ7`Ol000001?nAQ/@01Ol0003oS8K7
ohb6aon<Q/Oo000000?oQhO<00Co0000oh:9dOn2RM7oPXWA1Ol00004ofb?h`05o`000?mbW>_oLYc[
og:Ljol000001?n6[^l00ol0003oXko]oj>ok@04o`0000?oZ;oZ00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`00:_ooool2o`0001[ooooo00?o0000ojRojonX_n/00_nX_n/3o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00004ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0
003oZ;o[ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`;o00000oo7g^X01?l0003obnO[ol_Wjoo;in/?o`000004o`0h_Ol0003o0000obUDb@?o0000
00GoF6S8o`000?mbM/SoLWK8o`000004ohV3aP03o`000?nLSL?oW8g300;oW8g31?l000000on^WLGo
0000okZS`@04okZS`@;o00001_o9/<400ol0003oe[k2omJn`P03omJn`P05o`000?oMb/Ko0000on7:
`Ol000000ooWe/@01?l0003okN?6ongSa_l00002ono_a@04o`000?o]ml7o0000onKk^POo00000_n^
h_P3o`0000Co^/kZ0_l00004okZlf`;o00001?nf[M001?l0003o]Z_>okJ[c_nfZlh2o`0000Co/:37
00Co0000ojnMaOn_WLGo[ig50_l00004ojVE`@05o`000?nWTl3oYi?0ojNC`?l000001?nTT<000ol0
003oXHk1o`000003o`0000;oWHVn00?o0000oiV8_onIR;l00_nIR;l01Ol0003oUXO1oiJ7`OnFQl7o
000000CoTHK400Go0000ohb6aon<Q/OoS8K7o`000003ohN7c005o`000?n2RM7oPXWAoh:9dOl00000
0_mmSMPAo`0000;oX[c/00?o0000ojRoj_nX_nX00_nX_nX2o`0000kooooo00?o0000ooooooooool0
3?ooool002[ooooo00?o0000ooooooooool06_ooool01_l0003oZ;o[o`000?l0003oZ;o[o`0000Co
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Go
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000CoZ;o[00Co0000ojRojol0003o00000_n/`NT00ol0
003oamkZo`000003ol_Wj`06o`000?o?k^WocnkYo`000?oAlnOo00000ooCmND00ol0003oe_KSo`00
0002omSfhP?o000000Co03Rmo`000?lYE<Wo00000_m:Ilh3o`000003og9fb?l0003oRH?600?oRH?6
00?o0000oib=`onLSL<00ol00005ojjMa@07o`000?njXl7o^Z?1okZS`Ol0003o`:g7o`000005olV`
`@;o00001?oF_/801?l0003ogL[6omg:a_oMb/H2o`0000;oimK400Co0000ongSa_o]hlKo00000_o_
klD01?l0003okOO1o`000?oVnkX4o`0000;oWMgm1?l00003ok7>k`04o`000?njc^[o0000o`0000;o
]KcO00Ko0000okZlfol0003o0000okB^dol00004okJ]d006o`000?nfZlko0000o`000?naX/Wo0000
1?n`X<L01_l0003o[ig5o`000?l0003oZiO2o`0000CoZIG100Go0000ojNC`?nWTl3oYi?0o`000002
ojB@`0Co00000_nPRkh00ol0003oWHVnoif9_P02oif9_P05o`000?nIR;ooVHRooiV8_ol000000onF
Ql400ol0003oTHK4oi66a002oi66a005o`000?n<Q/OoS8K7ohb6aol000000on7Ql`00ol0003oPXWA
oh:9d@02oh:9d@04o`000?mmSMSoOHgHo`0000CoO9CO00Go0000ognOiomoWnOoOioWo`000004ohb^
k003o`000?nR_>coX[c/00;oX[c/00Ko0000ojRoj_l0003o0000ojRnj_l0000?ooooo`03o`000?oo
oooooooo00_ooooo000Zooooo`03o`000?oooooooooo01_ooooo0_l00003ojRoj`04o`000?nX_n_o
0000o`0000;oZ;o[00?o0000ojRojonX_n/00_nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000Co
Z;o[1Ol00002ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000Co
[<7Y1?l000001oo;in_o0000olo^jOo?k^Wo0000om7ciol000000ooCmND00ol0003oe_KSo`000002
omSfhP04o`000?oJln3o0000o`0000;o03Rm0ol00002odYWcP03o`000?m[N]3o000000;o00000_n9
PlH4o`0000;oWIC:00?o0000ojjMaOn^WLD00on^WLD01?l0003o^Z?1okZS`Ol00003ol2]a`05o`00
0?o9/<7obK31olV``Ol000000_o@_<L01?l0003oe[k2omJn`_l00004omg:aP05o`000?oTf<Wo0000
onOFa?l000000_o]hlH01Ol0003okno5ono_aOl0003okOO100So00000onVbo<00ol0003o/Lk_ok7>
k`03o`0000Co]KcO0_l00004okB^d`04o`000?nf[M3o]Zg@okJ]d0;o00001?naX/T01?l0003o/:37
ok2Paon`X<L2o`0000CoZiO200Go0000ojVE`OnYUL7oZIG1o`000003ojNC`0?o00000_nSSKd00ol0
003oX8^noj2;_P02oj2;_P05o`000?nMRKkoWHVnoif9__l000000onIR;l01Ol0003oUXO1oiJ7`OnF
Ql7o000000CoTHK400Go0000ohb6aon<Q/OoS8K7o`000003ohN7c003o`000?n2RM7oPXWA00;oPXWA
0_l00002ogf=f003o`000?mlU=ooO9CO00;oO9CO00Go0000ognOiomoWnOoOioWo`000004ohb^k003
o`000?nR_>coX[c/00?o00001?nX_^X00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000ojRojonX_n/00ol00004ojRoj`03o`00
0?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[o`000004o`0000CoZ;o[0ol00002ojRoj`03o`00
0?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`04o`000?n/`NWo0000o`0000?oa<cQ2Ol000001?oCmNGo
0000omKfhol00002omSfhP03o`000?oJln3of_?P00Go000000?o2dg:o`000?l000000_m:Ilh00ol0
003oJg[@of]jd003o`0000;oQhW>00?o0000oifDb_nMU<X00_nMU<X00ol0003o[Yg5ojjMa@02ojjM
a@03o`000?njXl7o000000Co`:g700Co0000olV``Oo9/<7o00000oo@_<L00ol0003oe[k2o`000004
omg:aP04o`000?oTf<Woi=S9onCHb@;o000000KokN?6o`000?o_klGokno5o`000?o]ml45o`0000?o
V/Ge00?o0000ojK;lonVbo<01?l00003ojnlh`06o`000?ne_=oo0000o`000?n`[]Ko00001?nd[]<0
1_l0003o]Zg@o`000?l0003o/:?;o`0000Co/J;900Ko0000ok2Paol0003o0000ojbI`ol00004oj^G
`P03o`000?nYUL7oZIG100;oZIG10ol000000onUSkko0000oj>=_@03oj>=_@05o`000?nPRkkoX8^n
oj2;__l000000onMRKh00ol0003oVHRooiV8_`02oiV8_`03o`000?nFQl7o000002Oo00000_nR^n/0
1?l0003oZ;kZojRnj_nX_^X3o`0000kooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000
ooooooooool07oooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[00Ko0000ojRojol0003o
0000ojRojol00004ojRoj`?o00000oo4c>401Ol0003of^GMom[UgOoJiMgo000000;og^[K00?o0000
on7]fOoQkMT03ol000001Ol;CL[o0000odYWc_m:Ilko000000;oJg[@00?o0000ohN9c_n7RLh00on7
RLh01Ol0003oWIC:oifDb_nMU<[o000000Co[Yg50_l00005ol2]a`03o`000?o9/<7o000000God;c7
00?o0000omg:a_oMb/H00_oMb/H00ol0003oi=S9onCHb@02onCHb@03o`000?oYi/co000000Go0000
00Gofofko`000?l0003oS[gfo`000002oi[5m@Co00000_nX^NH00ol0003o[kcSojnlh`02ojnlh`;o
00001?n`[]H01?l0003o]:kCokB^dond[]<2o`0000Co/:?;00Co0000ok6RbOnaX/Wo/J;90_l00004
ojbI``05o`000?n[Ul;oZiO2oj^G`_l000000onYUL42o`0000CoYHnn00Go0000oj>=_OnSSKgoXhfm
o`000003oj2;_P03o`000?nMRKkoWHVn00;oWHVn00?o0000oiV8_ol000000ol00002oiV7_`03o`00
0?nFQl7oUXO100;oUXO100Go0000oi>8a?nCR<CoThS4o`000003oi29b003o`000?n=S<koSHc>00;o
SHc>0_l00002ohZAe005o`000?n9V=_oRISKohVHfol000001?n;X^<00ol0003oTjkYoi>^j@02oi>^
j@03o`000?nR^n_oX[_[00Go00000_nY`>X00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Wooooo000Yooooo`03o`000?oooooooooo023ooooo00?o0000ojRojonX_n/01?l00004ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX
_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000?oZ;o[00?o0000olC<hOl000000ooJiMd01?l0
003og^[KomkZfol00002on7]f@03o`000?oSk]Oo000000;oi>gE00Co0000onG/e?oUk=Co00000_oU
j=<00ol0003oi>CBo`000002o`0000;o2dg:0_l000001Om:Ilko0000of]jd?m[N]3o000000CoQhW>
00?o0000oifDb_nMU<X00_nMU<X01_l0003o[Yg5ojjMaOl0003o/jO=o`0000Ko`:g700?o0000om2l
aoo@_<L01?o@_<L2o`0000?ogL[600Go0000onCHbOoTf<Woi=S9o`000002onWVc005o`000?o[ll_o
jo?;o`000?oWnlH00ol000000on>_OKo0000o`000002o`0000;oWkGW00?o0000ojRii_nX^NH00_nX
^NH01_l0003o[kcSo`000?l0003o[:gHo`0000Co/:kF00Ko0000okB^dol0003o0000ojnTcOl00004
ok2Sb`06o`000?naX/Wo0000o`000?n/V/Co00001?n/VL<00ol0003oZiO2oj^G`P02oj^G`P?o0000
00?oYY2no`000?nUSkh00onUSkh01Ol0003oXhfmoj>=_OnSSKgo000000CoX8^n00?o0000oif9__l0
00000ol00002oi^7_@03o`000?nIQkooVHNo00;oVHNo00?o0000oiJ7`OnFQl400_nFQl401Ol0003o
ThS4oi>8a?nCR<Co000000?oT8W800?o0000ohf<c_n=S<h00_n=S<h2o`0000;oRY7D00Go0000ohVH
fon9V=_oRISKo`000004oh^Rh`03o`000?nC[^WoTjkY00Co00000_nR^nX00ol0003oZL3ZojW0jP02
ojW0jP;o00003Oooool3o`0000[ooooo000Yooooo`03o`000?oooooooooo027ooooo0_l00003ojRo
j`03o`000?nX_n_oZ;o[00;oZ;o[1?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`Co000000Gof^GMo`00
0?oNj]_og^[Ko`000002on7]f@03o`000?oSk]Oo000000;oi>gE00Co0000onG/e?oUk=Co00000_oU
j=<00ol0003oi>CBonCTdP06o`000003ocIVeOl0003o000000?oJg[@00Go0000ohN9c_n7RLkoQhW>
o`000004oifDbP03o`000?n^WLGo000000?o/jO=00?o0000ol2]aoo0[LL00_o0[LL2o`0000God;c7
00Ko0000omS:c?oHb/co0000omg:a_l00003onCHb@04o`000?oYi/cojNK<o`0000;ojo?;00?o0000
onOka_l000001?l00002oiN_i`03o`000?nO]NOoWkGW00;oWkGW00?o0000ojRii_nX^NH00ol00004
ojb]f003o`000?n`[]Ko/:kF00?o00001?n_Y<d01?l0003o/:?;ok2Sbon`Xl/2o`0000Co[9[400Go
0000ojbI`on/VL?o[9W3o`000002oj^G`P?o00001?nVT;h01Ol0003oYHnnojF?__nUSkko000000Co
Xhfm00?o0000oj2;__l000000ol00002oif8_003o`000?nKQkgoVhNm00;oVhNm00Go0000oiV7_onI
QkooVHNoo`000004oiJ7`@05o`000?nCR<CoThS4oi>8a?l000000on@RLP00ol0003oSHc>ohf<cP02
ohf<cP;o00000_n:TM@00ol0003oRISKohVHf`09o`0000;oV[3V00?o0000oj:kj_nR^nX00_nR^nX0
1_l0003oZL3Zo`000?l0003oZL7[o`0000[ooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo
000Yooooo`?o00008_ooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX_n_o000000?o00001?nX
_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/01?l0003oZ;o[o`000?l00003ok72iP?o000000Oog^[Ko`000?oQkMWohNgIo`000?oSk]Oo0000
00;oi>gE00Co0000onG/e?oUk=Co00000_oUj=<01?l0003oi>CBonCTd_l00002on;Nd@;o000000?o
0433o`000?l000000_lfI]D4o`0000CoQhW>00?o0000oifDb_nMU<X00ol00005ok>Wc@04o`000?o0
[LOo`:g7o`0000;oa[W>00Go0000om2laoo@_<Ood;c7o`000004omS:c005o`000?oTf<Woi=S9onCH
bOl000000_oYi/`01Ol0003ojo?;on_cbol0003oio_600?o00000_n@ZNH01Ol0003oUjoWoiN_ionG
[nOo000000;oWkGW1?l00002ojN[fP03o`000?n/[MSo[:gH00;o[:gH0ol00002ojbTc`03o`000?n_
Y<go[jC=00;o[jC=00Ko0000ok2Sbol0003o0000ojbKa_l00004ojbJa004o`000?n/VL?o[9W3ojbI
``?o00000_nXT[l00ol0003oYY2nojJ@_P02ojJ@_P03o`000?nUSkkoYHnn00;oYHnn00?o0000oj>=
_Ol000000ol00002oin9_003o`000?nMR;coWHRl00;oWHRl00Go0000oi^7_OnKQkgoVhNmo`000004
oiV7_`05o`000?nFQl7oUXO1oiJ7`Ol000000onCR<@00ol0003oT8W8oi29b00=o`0000;oUIcH00?o
0000oiJUh?nFYN000_nFYN000ol0003oV[3VoiZ`iP02oiZ`iP03o`000?nR^n[oX[_Z00?o00001?nY
`N/00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`00:Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003oZ;o[o`000?l0
0002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000ona`^H01?l0003ocLgIolg=fOo=cMT=o`000005onGX
dol0003oi>CBonCTd_l000000_oRg]401_l0003ogmO@o`000?l0003o0433o`0000;o=VKE00?o0000
of1nf_mPO]X02?l00002oinNd`03o`000?ncYlgo/jO=00?o/jO=00?o0000ol2]aol000001?o6^Lh0
0ol0003od;c7o`000004omS:c005o`000?oNf];o0000onCHbOl000000ooYi/`01?l0003ojo?;o`00
0?oWnlH3o`0000;oT:WV2?l00002oj6Xf`03o`000?nWZm[oYj_J00;oYj_J00Ko0000ojb]f?l0003o
0000ojVSd?l00004ojbTc`04o`000?n_Y<go[jC=ojnTc@;o00001?n/VlH01_l0003o[9[4ojbJa?n/
V/Co0000ojbI``;o000000?oZ9C0o`000?nXT[l00onXT[l01Ol0003oYY2nojJ@__nVT;ko000000?o
YHnn0ol00002oj6;_003o`000?nORKcoWhVl00;oWhVl00Go0000oif8_?nMR;coWHRlo`000003oi^7
_@03o`000?nIQkooVHNo00;oVHNo00?o0000oiJ7`OnFQl402?l00002oiN<aP03o`000?nFT<_oUY3;
00;oUY3;00Go0000oiFEdOl0003oUIGAo`000004oiFLf003o`000?nFYN3oUZGP00;oUZGP00?o0000
oiZ`i_nJ/>H01?l00003ojFljP03o`000?nY`N_oZL7[00?o000000?oooooo`000?l000000_l00008
ooooo`03o`000?oooooooooo00Sooooo00000ol0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001Ooo
ool00ol0003oooooooooo`0Uooooo`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3
o`0000CoZ;o[00?o0000ok72i_l000000oo=cMT01ol0003oi>CBonCTd_oTi=;o0000onOVd?l00000
0_oXi/h01Ol0003ojNG<onWUc?l0003ojN?;00Go000000Coh]kAo`000?oOem3ogmO@0ol000001Ol0
@<?o0000o`000?lfI]Go000000;oH7kJ00Go0000ohBAf?n4TMSoQ97Ho`000005oinNd`03o`000?nc
Ylgo/jO=00;o/jO=0_l00005olJicP;o00001?oHb/`01?l0003og][BomkJd_oNf]83o`000003onWV
c?l0003ojo?;00?o000000?oa?^jo`000?l000000_l00002oiNOfP05o`000?nKY=_oVjCKoi^Tfol0
00001?nQZ=/00ol0003oYj_JojN[fP03o`0000CoZJ?@00Ko0000ojbTcon/Y<oo[:C?o`000?n_Y<d2
o`000003oj^Laol0003o[9_600?o[9_600Co0000ojbJa?n/V/Co[9[40_l00004ojRD`005o`000?nX
T[ooZ9:oojRB_ol000001?nVT;h3o`000003oj><_?l0003oXH^l00?oXH^l00Go0000oin9_?nORKco
WhVlo`000003oif8_003o`000?nKQkgoVhNm00;oVhNm00?o0000oiV7_onIQkl01?l00002oiZ8_`05
o`000?nIR/;oVH[2oiV:`_l000001?nGS<H00ol0003oUY3;oiJ@b`02oiJ@b`05o`000?nEUM7o0000
oiFEdOl000000onEW=P00ol0003oUZGPoiJUh005o`0000;oX[GV00Co0000ojFlj_nU_>[oYKcZ1?l0
0003ojRoj`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00003oooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo02;o
oooo0ol00002ooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Co
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/00_nX_n/2o`0000?ocLgI00Oo0000onCTd_oTi=;oi>CBo`000?oWi]3o000000;oj>K>00Co
0000onWUc?oYiLco00000_oYhl/01Ol0003oj>3;onSPbol0003oi]c:00;o000000?ogmO@o`000?oK
d<h00_oKd<h2o`000003oaMRf?l0003o000000?oH7kJ00Go0000ohBAf?n4TMSoQ97Ho`000004oinN
d`03o`000?ncYlgo/jO=00;o000000?o^;GFo`000?o6^Lh00oo6^Lh00ol0003oc/WFo`000003omS:
c005o`000?oNf];og][BomkJd_l000000_oSj]H6o`000003olCk^_l0003oTi_H00;oTi_H00Go0000
oiNOf_nGWm[oUioJo`000003oi^Tf`03o`000?nQZ=_oXJSK00Co00000_nUXM400ol0003oZJ?@ojVS
d002ojVSd003o`000?n/Y<oo[:C?00?o00001?n[W<L01_l0003o[9_6ojbKa_n/VlKo0000ojbJa0;o
000000?oZIG1o`000?nXU<000onXU<001Ol0003oZ9:oojRB_onXT[oo000000;oYY2n0ol00003oj><
_003o`000?nQRkcoXH^l00;oXH^l00Go0000oin9_?nORKcoWhVlo`000004oif8_003o`000?nKQkgo
000000Co00000_nKQkd00ol0003oVXRooiZ8_`02oiZ8_`05o`000?nIR/;oVH[2oiV:`_l000000onG
S<H00ol0003oUY3;oiJ@b`02oiJ@b`05o`000?nEUM7o0000oiFEdOl000000_nEW=P4o`0000?oX:gP
00?o0000oj:ei_nR]NH01Ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00003?ooool00ol0003o
ooooooooo`07ooooo`000_ooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0
003oooooooooo`0Oooooo`?o00001_ooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00Co00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRo
jol0003o00000_nX_n/00ol0003ocLgIo`000003onCTdP03o`000?oWi]3o000000;oj>K>00Co0000
onWUc?oYiLco00000_oYhl/01?l0003oj>3;onSPbol00002onKLbP04o`000?oTelWo0000o`0000?o
fm3>0ol000000olGH]So0000of1nfP03of1nfP05o`000?n4TMSoQ97HohBAf?l000000onOW]<00ol0
003o/jO=o`000004okReeP04o`000?o6^Lkoa[W>o`0000?oc/WF00?o0000omS:c?l000000ooNf]80
1?l0003ohn[Fon?Ze_l00002on?he@07o`000?oIolco0000olCk^_l0003oTIOFo`000003oi>Kf004
o`000?nGWm[oUioJo`0000;oVjCK1?l00002oj6NdP03o`000?nUXM7oYJ7A00;oYJ7A00Co0000ojVS
d?nYXm3oZJ?@0ol00002ojVLb@03o`000?n[W<OoZic700;oZic700Co0000ojbKa_n/VlKo[9_60_l0
0004ojVE`@05o`000?nXU<3oZ9C0ojRD`?l000000onXT[l3o`0000;oY8fl00?o0000oj><_?nSS;`0
0_nSS;`01Ol0003oXH^loj6;_?nQRkco000000CoWhVl00?o0000oif8_?l000000ol00002oif7_003
o`000?nKQkgoVhNm00?oVhNm00Go0000oiZ8_onJR;ooVXRoo`000003oiV:`P05o`000?nGS<KoUhc6
oiN<a_l000000onFT</8o`0000;oWjGJ00?o0000oj2]h?nP[N000_nP[N03o`0000;oZ;o[00?o0000
ojRojonX_n/00_nX_n/4o`0000;oZ;o[00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`000_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003ooooooooo
o`0Looooo`?o00002_ooool01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[
1?l000001?oTi=;o0000onOVd?l00003onSVcP06o`000?oYiLcojNG<o`000?oYhl_o00000_oXh</0
1?l0003oi]c:onKLb_l00002onCGb@05o`000?oPdLSo0000om_@c_l000000_oFb<`2o`000003oaMR
f?l0003o000000?o00000on4TMP00ol0003oWikCoinNd`03o`0000Go^;GF00?o0000olJic_l00000
1?o>bMH4o`000005omkJd_l0003ohn[Fon?Ze_l000000_oSn=D01Ol0003ofOo<o`000?o4nk[o0000
00;oTIOF00?o0000oi>Kf?nCVmP01ol00002oifKdP03o`000?nQW];oXIkB00;oXIkB00Ko0000ojFQ
dOnUXM7oYJ7Ao`000?nYXm02o`000003ojNKb_l0003oZIc900?oZIc900Ko0000oj^Laon[W<OoZic7
o`000?n/VlH2o`000003ojRF`ol0003oZIG100?oZIG100?o0000ojRD`?nXU<000_nXU<03o`000003
ojF?_Ol0003oY8fl00?oY8fl00Go0000oj><_?nSS;coXhblo`000004oj6;_003o`000?nORKco0000
00?o00000_nNR;/00ol0003oWHNloif7_002oif7_003o`000?nKQkgoVhNm00;oVhNm00Go0000oiZ8
_onJR;ooVXRoo`000003oiV:`P03o`000?nGS<KoUhc600Go00000_nNVLl00ol0003oWYkDoijNe002
o`0000CoWjGJ00Ko0000oj2]h?l0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00001?nX_n/2o`0000_ooooo00?o0000ooooooooool01oooool000;ooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool06Oooool3o`0000kooooo00?o0000
ojRojol000000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00001?nb
`^H5o`000007onSVc_l0003ojNG<onWUc?l0003ojN?;o`000003onSPb`03o`000?oVg<[o000000;o
i=O900Go0000on3Ab?oPdLSoh=78o`000003omK8c0Go00000_m?Q>D7o`0000?oXJcO00?o0000okRe
e_nh]MH00_nh]MH3o`0000?oc/WF00Co0000omCLg_oDg=koe=cN0ol000001_oSj]Ko0000on?heOoS
n=Go0000omWoc0Wo00000_nGULl01?l0003oVYSAoiZHdOl00004oifKdP05o`000?nQW];oXIkBoj6N
d_l000000_nUXM43o`0000CoYi_:00Go0000ojVLbOnYW<WoZIc9o`000002oj^La`?o00001?nXU/<0
1Ol0003oZIG1ojVE`OnYUL7o000000?oZ9C00_l00004ojF?_@05o`000?nTSKcoY8flojB=_?l00000
0onSS;`01?l0003oXH^loj6;_?nQRk`3o`0000;oWhRk00?o0000oij8^onNR;/00_nNR;/01Ol0003o
WHNloif7_?nMQkco000000CoVhNm00?o0000oiZ8_onJR;l00_nJR;l00ol0003oVH[2o`000003o`00
00;oWYK;00?o0000oijIconNVLl00_nNVLl01?l0003oWYkDoijNe?nNW]@2o`0000;oWjGJ0ol00004
ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000_ooooo
00?o0000ooooooooool01oooool000;ooooo00?o410@ooooooooool02Oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00?o
oooo0_l0000Gooooo`?o00004_ooool00ol0003oZ;o[ojRoj`02ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`00
0?nX_n_oZ;o[00?o00001Onb`^H01?l0003oc/ODolk7e?l00002onSQc0So000000Coj>3;o`000?oV
g<[o00000_oTelT00ol0003oh=78on3Ab002on3Ab0;o000000Koe/S<o`000?oA`<[odL3:o`000?l0
Ell2o`0000;oChCU00Go0000ogjMi_mnWNKoOYgVo`000005oj6/g`04o`000?nh]MKo0000o`0000?o
_LKQ00?o0000olk9e_l000000ooDg=h01?l0003oenoSomO_hooGkn<7o`0000;oUY3<00Go0000oiJB
c_nFT/koUY;>o`000004oiNEc`04o`000?nJV=7oVYSAo`0000?oWI_B00?o0000oj6Nd_nQW]801?l0
0002ojBJb`03o`000?nWVl[oYi_:00;oYi_:00Co0000ojVLbOnYW<WoZIc90ol00002ojRFa003o`00
0?nXU/?oZ9K300;oZ9K300?o0000ojVE`OnYUL400_nYUL43o`000003ojJ@__l0003oYHnm00?oYHnm
00Go0000ojB=_?nTSKcoY8flo`000004oj><_0?o000000?oXHVko`000?nOR;/00_nOR;/00ol0003o
WXRkoij8^`02oij8^`05o`000?nMQkcoWHNloif7_?l000001OnKQkd00ol0003oVXRoo`000003o`00
00;oWi?700?o0000oijFbonNU//00_nNU//00ol0003oWYW?oijIc`02oijIc`03o`000?nNW]CoWYkD
00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRo
j`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00003oooooonHV9SoMgMg00_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool05?ooool2o`0001Kooooo00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01?l0003oZ;o[o`00
0?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`?o00000onX_n/01Ol0003o//;Vok;2i_nb`^Ko0000
00;oc/OD00Go0000onSQc?oXhLcoj>7<o`000002onWQb@03o`000?oZh<So000000;ojMk71?l00000
0ooTelWo0000on3Ab003on3Ab004o`000?oLblSog<_8o`0000?odL3:0_l00002o`1Gc`;o000000?o
ChCUo`000?mnWNH00_mnWNH00ol0003oXJcOoj6/g`02oj6/g`;o00001Onma^42o`0000?oe=cN00So
0000omO_hooGkn?oenoSo`000?o@o>7o0000okcmd0?o00001?nFT<`01Ol0003oUY;>oiJBc_nFT/ko
000000?oUiG?00Co0000oiZHdOnJV=7o00000_nMVm84o`0000;oXIS;00?o0000ojBJbonTV//00_nT
V//01_l0003oYi_:ojNKb_nWVl[o0000ojVLb@;o000000?oYYK5o`000?nXU/@00onXU/@01Ol0003o
Z9K3ojRF`onXU/?o000000;oZIG10ol00004ojJ@_P05o`000?nUSkgoYHnmojF?_Ol000001?nTSK`0
0ol0003oXhblo`000002o`0000?oXHVk00?o0000oin8^onOR;/00_nOR;/01Ol0003oWXRkoij8^onN
R;_o000000CoWHNl00?o0000oi^7_OnKQkd01?l00002oinAa@03o`000?nOTlOoWi?700;oWi?700Go
0000oijFbonNU/_oWYK;o`000003oijIc`Co000000?oZ;o[o`000?l000000onX_n/4o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00002Oooool00ol0003ooooo
ooooo`07ooooo`0000?o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0Booooo`?o00006Oooool2o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[
00;oZ;o[00?o0000ok;2i_l000000_o>am@01Ol0003oj>7<onSQc?oXhLco000000;ojN7900?o0000
on[Pb?l000000ooYg/L01?l0003oj=_6o`000?oVelH2o`0000?oh=7800Co0000omc;b?oLblSog<_8
0_l000001?oA`<[o0000olbhaoo<^<L3o`000003oc67k?l0003o000000?oOYgV00?o0000oj6/gol0
00000_l000000onQ_^ko0000okg6h@02okg6h@;o00000_o0fnd00ol0003oe=cNo`000003omO_h`04
o`000?o@o>7o0000okcmd0;o00000_nGSlT01Ol0003oUY3<oiJ@c?nFT<co000000?oUY;>00?o0000
oiNEconGULl01ol00002oijFb`03o`000?nQV<_oXIS;00;oXIS;00Go0000ojBJbonTV/_oY9[;o`00
0002ojNKbP?o00001?nVU/D01Ol0003oZ9K4ojRFa?nXU/Co000000?oZ9K30ol00002ojJA_`03o`00
0?nVT;koYY2n00;oYY2n00?o0000ojF?_OnUSkd00_nUSkd00ol0003oY8flo`000003o`0000;oXXZk
00?o0000oj69^onQRK/00_nQRK/01Ol0003oWhRkoin8^onOR;_o000000CoWXRk00?o0000oif7_?l0
00001?l00002oj2?``03o`000?nOTLGoWi7500;oWi7500Go0000oinCaonOTlOoWi?7o`000003oijF
b`06o`000?nNVLoo0000o`000?nX_n_o00001?nX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[
1?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co00000onX_n/00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo00oooooo0ol0000Nooooo`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00000oo>am@01?l0003oj>7<onSQc?l00002onWQb@03
o`000?oZh<So000000?ojMk700?o0000onSKa_l000000_oVelH01Ol0003oi=;6o`000?oPdLSo0000
00?og<_800Co0000omO4aooGa<Oo00001?o<^<L3o`0000;o<HO/1_l00004oj6nkP03o`000?nma^7o
000000Co`=_]1?l000000ooGkn?o0000om3lh@04o`0000?oUho900Go0000oiJ@c?nFT<coUY3<o`00
0002oiJBcPCo00000_nJTLT01?l0003oW9?:oibCb_l00004oijFb`05o`000?nQV<_oXIS;oj6Hbol0
00000_nTV//4o`0000;oYIK600?o0000ojJFaOnVU/D00_nVU/D01_l0003oZ9K4ojRFa?nXU/Co0000
ojRF``;o000000?oYY;0o`000?nVTKl00onVTKl01Ol0003oYY2nojJ@__nVT;ko000000?oYHnm0ol0
0002oj>;^`03o`000?nRR[_oXXZk00;oXXZk00Go0000oj69^onQRK_oXHVko`000003oin8^`04o`00
0?nNR;_oWXRkoij8^`?o00000_nPSl800ol0003oX8o3oj2?``03oj2?``05o`000?nOTLGoWi75oinA
aOl000000onOTlL00ol0003oWYK;oijFb`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol0
0004ojRoj`Co00000_nX_n/01?l0003oZ;o[ojRojonX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_o
Z;o[0ol00007ooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo00cooooo
0ol0000Rooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oc/ODo`000002onSQc004o`00
0?oYhLWojN79o`0000;oj^3800Ko0000onWNaooYg/Oo0000onSKa_l00002onKGaP05o`000?oTd/Ko
i=;6onCBa_l000000ooLblP01Ol0003oelC7omO4aooGa<Oo000000?oc;S700Co0000olJaaOl0003o
_jc71Ol00003og>[m003o`000?nQ_^koXKk^00Co00000oo0fnd01?l0003o_>ocokc_lonlko<5o`00
00;oVHo800?o0000oiN?bOnGSlT02?l00002oiV>a`03o`000?nJTLWoVY7900;oVY7900Co0000oibC
b_nLTl[o00000onNU//00ol0003oXIS;oj6Hb`04o`0000;oXiC600?o0000ojFFa_nUU/H00_nUU/H0
1Ol0003oYYK5ojJFaOnVU/Go000000;oZ9K40ol00004ojJB`005o`000?nVTKooYY6oojJA_ol00000
1?nVT;h3o`000003oj><_?l0003oXh^k00?oXh^k00Go0000oj::^onRR[_oXXZko`000003oj69^`03
o`000?nOR;_oWhRk00;oWhRk0ol000000onQS/7o0000oj2?`P03oj2?`P03o`000?nPSl?oX8o300;o
X8o300Go0000oinAaOnOTLGoWi75o`000002oinCa`Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[0_l000001OnX_n_o0000o`000?nX_n_o000000GoZ;o[0ol000000onX_n_o0000ojRoj`03
ojRoj`Co00000_nX_n/00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo000Woooo
o`03o`000?oooooooooo00Wooooo0ol0000Uooooo`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/01ol000001OoYhLWo0000on[Pb?oZh<So000000;ojMk700Ko0000onSKa_oXflKo0000onKG
a_l00004onCBaP;o000000?og<_8o`000?oGa<L00_oGa<L01Ol0003od[g6o`000?o<^<Oo000000?o
a[7500Go0000okn/aol0003o0000o`Aog`07o`0000CoVm;k00?o0000ol3KkOl000000_nlko<2o`00
0003ojWgjOl0003oPnS800Oo00000_nIS<@01Ol0003oVHg6oiV=a_nISLKo000000CoVHk700Go0000
oiZAbOnJTLWoVY79o`000003oibCbP03o`000?nNU/_oWYK;00?o00000_nQTlH00ol0003oXiC6oj>D
aP02oj>DaP05o`000?nUU/KoYIK6ojFFa_l000000onVU/D3o`0000;oYI;100?o0000ojJB`?nVT/00
0_nVT/001Ol0003oYY6oojJA_onVTKoo000000;oYY2n0ol00003oj><_003o`000?nSRk_oXh^k00;o
Xh^k00Go0000oj::^onRR[_oXXZko`000004oj69^`03o`000?nOR;_o000000;o00001?nQS/401Ol0
003oX8o2oj2?`_nPSl;o000000CoX8o300?o0000oinAaOnOTLD01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004
ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/2o`0000Oooooo00?o0000ooooooooool0
1_ooool002Oooooo00?o0000ooooooooool01_ooool3o`0002Wooooo00Co0000ojRojol0003o0000
0_nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000?oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRo
j`03o`000?nX_n_oZ;o[00?o00000on/`>T01?l0003oblGDol_5e?o;aM@8o`000005onSKa_l0003o
i]O6onKGa_l000000ooTd/H01?l0003oh<g5on3=aOl00003omO4a`05o`000?oB_LKod[g6om:ma_l0
00001Oo6/LD00ol0003o^ZG4okZUa004o`0000CoF[Kl00?o0000oi_BnonKd_/01?l000001?nlko?o
0000ojWgjOnYmnT3o`0000;oWHc200Co0000oi^<`onKS<?o00001?nIS<@01Ol0003oVHg6oiV=a_nI
SLKo000000?oVHk700Go0000oiZAbOnJTLWoVY79o`000002oibCbPCo000000?oWi76o`000?nQTlH0
0onQTlH01Ol0003oXiC6oj>Da_nSU<Ko000000?oYIK600Ko0000ojJFaOl0003o0000ojFB`_l00004
ojFB`@05o`000?nVT/3oYY;0ojJB`?l000000onVTKl3o`0000;oY8fm00?o0000oj><_?nSS;`00_nS
S;`01Ol0003oXh^koj>;^onSRk_o000000CoXXZk00?o0000oj69^ol000000ol00002oj6?`@03o`00
0?nQS/7oXHk100;oXHk100?o0000oj2?`_nPSl800_nPSl801?l0003oX8o3oj2?`onPSl<3o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/2o`0000;o
Z;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000Oooooo00?o0000ooooooooool01_ooool002Oooooo00?o0000ooooooooool00oooool3o`00
02gooooo0_l00004ojRoj`03o`000?nX_n_o000000;oZ;o[00?o0000ojRojonX_n/00_nX_n/00ol0
003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[0ol00003ojRoj`03o`000?n/`>Wo0000
00CoblGD00Co0000on?Ic?oSfLco00000_oXg<P01_l0003oj=[7o`000?l0003oi]O6o`0000?oi=;6
00Co0000on3=aOoPcLGoh<g50_l000000ooGa<Oo0000om:maP03om:maP03o`000?o6/LGoa[7500;o
a[750_l00004okZUa0Wo00000_n7h?`8o`0000CoWHc200Co0000oi^<`onKS<?o00000onIS<@01Ol0
003oVHg6oiV=a_nISLKo000000?oVHk700?o0000oiZAbOnJTLT01?l00002oif?a@05o`000?nOTLKo
Wi76oinAa_l000000onQTlH01Ol0003oXiC6oj>Da_nSU<Ko000000;oYIK60ol00004ojFB`P05o`00
0?nUT/7oYI;1ojFB`Ol000001?nVT/03o`000003ojB>__l0003oY8fm00?oY8fm00Go0000oj><_?nS
S;coXhblo`000004oj>;^`03o`000?nRR[_o000000?o00000_nRSl400ol0003oXHo1oj6?`@02oj6?
`@05o`000?nQS/7oXHk1oj6>`Ol000001?nPSl801_l0003oX8o3o`000?l0003oZ;o[o`0000CoZ;o[
0ol00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo000Vooooo`?o000000Coooooo`000?l0003o
0000<_ooool00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06
o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/2o`0000CoblGD00Co0000on?Ic?oSfLco00000_oX
g<P01Ol0003oj=[7onSJaol0003oimO600?o000000?oi=;6o`000?oPcLD00_oPcLD00ol0003og<O5
omc7a@02o`0000?od[g600?o0000olfga?l000000_o6/LD01?l0003o`J_3ol6[`ol00003okZUa0;o
00000_n`Vl8;o`0000CoX8k100Go0000oif<`_nMS<;oWHc2o`000002oi^<``05o`000?nIS<CoVHc4
oiV<a?l000000onISLH00ol0003oVHk7oiV>a`04o`0000;oW8k400?o0000oif?aOnMSlD00_nMSlD0
1?l0003oWi76oinAa_l00003oj6CaP03o`000?nSU<KoXiC600Co00000_nTT/<00ol0003oYI;2ojFB
`P02ojFB`P05o`000?nUT/7oYI;1ojFB`Ol000000_nVT/03o`0000CoY8jn00Go0000ojB=_OnTSKgo
Y8fmo`000003oj><_004o`000?nSRk_oXh^koj>;^`?o00000_nST<400ol0003oXXo1oj:?`@02oj:?
`@05o`000?nQSl7oXHo1oj6?`Ol000001?nQS/400ol0003oX8o2oj2?`P03o`0000CoZ;o[1?l00000
0onX_n_o0000ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`?o000000?oZ;o[
o`000?l000000onX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`04o`000?nX
_n_oZ;o[ojRoj`?o00001Oooool00ol0003oooooooooo`06ooooo`009_ooool4o`0003Kooooo0_l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko
0000ojRojol0003o0000ojRojol00003ol_5e004o`000?oSfLcohmW<o`0000;oj=c800Co0000onSJ
aooXf/Oo00000_oWelH01?l0003oiMC5onGDaOl00003on3=a@09o`000?oLalGog<O5omc7aOl0003o
el;5o`000?oB_LKo000000;ocKO400?o0000olJaaOl000000oo1Zl<01_l0003o^ZG4o`000?l0003o
]Yo2o`0000Co/9_200?o0000ojZG`_nZUl800ol00003ojB@`005o`000?nPS/7oX8k1oj2>`Ol00000
0onMS<801?l0003oVhc3oi^<`ol00002oiV<a0So00000_nKS<<00ol0003oW8k4oib>a002oib>a005
o`000?nMSlGoWHo5oif?aOl000000_nOTLH00ol0003oXI?6oj6CaP04o`0000;oXY7300?o0000ojBB
`onTT/<00_nTT/<01Ol0003oYI;2ojFB`_nUT/;o000000?oYI;10ol00002ojB?_`03o`000?nTS[ko
Y8jn00;oY8jn00Go0000ojB=_OnTSKgoY8fmo`000004oj><_0?o000000?oXi71o`000?nST<400onS
T<401Ol0003oXXo1oj:?`OnRSl7o000000?oXHo100?o0000oj6>`OnQS/401Ol00002ojRoj`03o`00
0?nX_n_oZ;o[00?o00001OnX_n/3o`000003ojRojol0003oZ;o[00CoZ;o[1?l000000onX_n_o0000
ojRoj`02ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`05o`0000;oZ;o[00?o0000ojRojonX_n/0
1Ol00002ojRoj`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool002Kooooo0_l0
000jooooo`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?o;aMCo000000?ohmW<00?o0000onSLb?l000000_oX
f/L01?l0003oimO6onOGa_l00003onGDa@;o000000?oh<g5o`000?oLalD00_oLalD01Ol0003oel;5
omO2aOoG`/Go000000CocKO400?o0000ol6[`oo1Zl<00oo1Zl<00ol0003o]Yo2okJO`P02okJO`P04
o`000?n`Vl;o/9_2ok2K`P?o00000_nXTkl01Ol0003oY930ojB@`?nTT<3o000000?oX8k100?o0000
oif<`_nMS<800_nMS<800ol0003oVhc3o`000002o`0000;oVh[100Go0000oi^;`_nKRl;oVh_2o`00
0004oi^<``05o`000?nLS/CoW8k4oib>a?l000000onMSlD00ol0003oWi76oinAaP03o`0000;oXI33
00?o0000oj:A`onRTL<00_nRTL<01Ol0003oY9;3ojBB`onTT/?o000000CoYI;20ol000000onTSl3o
0000ojB?_`03ojB?_`05o`000?nTS[koY8jnojB>__l000001?nTSKd00ol0003oXhblo`000002o`00
00CoXi7100Go0000oj>@`OnST<7oXi31o`000003oj:?`@03o`000?nQSl7oXHo100Co00000onX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o
Z;o[00?o00001OnX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Cooooo00?o0000ooooooooool01_ooool0
02Sooooo00?o0000ooooooooool0>?ooool2o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/00ol0003oZ;o[ojRoj`04o`000004on?Ic?l0003oj=c8
o`0000?oj=[700?o0000onOGa_l000000ooUe<D01?l0003oh]35on;@aOl00003omc7a@03o`000?oG
`/Goel;500;oel;500Oo0000olfga?o=]lCocKO4o`000?o7/<?o000000?o`J_30_l00004okJO`P06
o`000?n`Vl;o0000o`000?n]U[oo00001?nXTkl01?l0003oY930ojB@`?l00004oj2>`@03o`000?nM
S<;o000000?o000000?oW8Zoo`000?nKR/400onKR/401Ol0003oVh_2oi^;`_nKRl;o000000?oVhc3
00Go0000oib>a?nLS/CoW8k4o`000002oif?a@Co000000?oWho2o`000?nQT<<00onQT<<01Ol0003o
XY73oj:A`onRTL?o000000?oY9;300?o0000ojFB`_nUT/800ol00004ojB?`005o`000?nTSkooY8no
ojB?_ol000001?nTS[h00ol0003oY8fmo`000003o`0000;oXi7200?o0000oj>A`OnSTL400_nSTL40
1Ol0003oXi31oj>@`OnST<7o000000?oXXo10ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX
_n_oZ;o[00?o00000onX_n/2o`000005ojRojol0003o0000ojRojol000001?nX_n/3o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`05o`000?ooooooooooooooool000002?ooool002Wooooo
00?o0000ooooooooool0=oooool00ol0003oZ;o[ojRoj`02ojRoj`?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`Ko000000Goj=[7o`000?oWelKo
imO6o`000002onGDa@04o`000?oRd<Goh]35on;@a@;o000000?og<O5o`000?oG`/D00ooG`/D01Ol0
003od[c4o`000?o=]lCo000000?oak3300?o0000ol6[`ol000000_nlYL801?l0003o]Yo2okJO`_nf
Wl82o`0000Co[IJo00Go0000ojRC_onXTkooZ9>oo`000003ojB@`003o`000?nPS/7o000000?o0000
0_nNR[h01Ol0003oW8Zooib:_onLR[oo000000?oVh[100Go0000oi^;`_nKRl;oVh_2o`000003oi^<
``03o`000?nLS/CoW8k400Co00000_nNSL801Ol0003oWho2oin?`_nOSl;o000000?oXI3300Go0000
oj:A`onRTL?oXY73o`000002ojBB``Co00000_nST<000ol0003oY8o0ojB?`002ojB?`005o`000?nT
SkooY8noojB?_ol000000onTS[h3o`0000;oY9;300?o0000oj>A`_nSTL800_nSTL801Ol0003oXi71
oj>A`OnSTL7o000000CoXi310ol000000onX_n_o0000ojRoj`03ojRoj`?o00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004
ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`02ojRoj`;o00000oooool00ol0003oooooooooo`05
ooooo`00:_ooool00ol0003oooooooooo`0gooooo`06o`000?nX_n_o0000o`000?nX_n_o00001?nX
_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`04o`000?nX_n_o0000o`0000?o`lCK
00?o0000omS>cooHc/l00_l000000ooWelKo0000onGDa@02onGDa@04o`000?oRd<Goh]35o`0000;o
gl_50_l00003omO2a@05o`000?oB_<Cod[c4om:la?l000001Oo7/<<01Ol0003o_:G2okbU`_nlYL;o
000000;o]Yo200?o0000ok:K`?l000001?n]U[l01Ol0003oZ9>oojRC_onXTkoo000000;oY9300ol0
0002oj2;_P03o`000?nNR[koWXZn00;oWXZn00Go0000oib:_onLR[ooW8Zoo`000002oi^:`@05o`00
0?nKRl;oVh_2oi^;`_l000000_nKS<<4o`0000;oWHc100?o0000oij=`_nNSL800_nNSL801?l0003o
Who2oin?`_l00003oj6@``03o`000?nRTL?oXY7300Co00000_nST<400ol0003oXi30oj>@`002oj>@
`005o`000?nTSl3oY8o0ojB?`?l000001?nTSkl3o`000003ojBCa?l0003oY9;300?oY9;300Go0000
oj>A`_nSTL;oXi72o`000004oj>A`@03o`000?nST<7o000000;o00001?nX_n/01_l0003oZ;o[o`00
0?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`;o00000_nX_n/3o`0000Co
Z;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o0000
0oooool00ol0003oooooooooo`05ooooo`00:oooool2o`0003Sooooo0_l00003ojRoj`04o`000?nX
_n_o0000o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000oo3a=/01_l0003of<k?omS>cooHc/oo0000onCHbP?o000000GoiMC5o`000?oRd<Goh]35o`00
0003omo;a@05o`000?oKa/Go0000omO2aOl000001?oB_<@00ol0003oak33olN```02olN```;o0000
0onlYL800ol0003o]Yo2o`000003ok:K`005o`000?n]U[oo[IJoojfF_ol000000onXTkl3o`000003
oj>=_Ol0003oX8^n00?oX8^n00Go0000oij:__nNR[koWXZno`000003oib:_`06o`000?nKR/7oVh[1
oi^:`Ol0003oVh_21?l00002oif;`003o`000?nMS<7oWHc100;oWHc100Go0000oij=`_nNSL;oWXg2
o`000002oin?`P03o`000?nQT<?oXI3300Co00000_nRSl400ol0003oXi31oj>@`@02oj>@`@05o`00
0?nST<3oXi30oj>@`?l000001?nTSl000ol0003oY8noo`000002o`0000CoY9?400Go0000ojBB`onT
T/?oY9;3o`000003oj>A`P03o`000?nSTL7oXi7100Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`00
0?ooooooooooo`0000Oooooo000]ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRojonX_n/0
0ol00004ojRoj`03o`000?nX_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00004ojRoj`03
o`000?o3a=_o000000?of<k?00Co0000onCHb_oTf<[o00000_oSe/T2o`000003on;@aOl0003ogl_5
00;ogl_500Go0000om_6aOoKa/GoflK5o`000004om:la003o`000?o=]/Co000000;oak3300Co0000
ol:[`oo2Zl?o00000_nlYL82o`0000Co/Y_000?o0000ojfF_on]U[l00_n]U[l3o`000003ojJ?_Ol0
003oXhfm00;oXhfm00Go0000oj2;__nPRkkoX8^no`000003oij:_P03o`000?nLR[ooW8Zo00Oo0000
0_nLRKl00ol0003oWH_0oif;`002oif;`005o`000?nMS<7oWHc1oif<`Ol000000onNSL800ol0003o
Who2oin?`P03o`0000;oXHk100?o0000oj:?`OnRSl400_nRSl401Ol0003oXi31oj>@`OnST<7o0000
00?oXi3000?o0000ojB?`?nTSl001?l00002ojBDa@03o`000?nTTlCoY9?400;oY9?400Go0000ojBB
`onTT/?oY9;3o`000002oj>A`PCo00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000
ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000;oZ;o[
00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`04o`000?nX_n_oZ;o[ojRoj`Co000000?oZ;o[o`00
0?l000000_nX_n/5o`0000;oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`03o`000?nX_n_oZ;o[
00?o00000_ooool00ol0003oooooooooo`05ooooo`00;_ooool00ol0003oooooooooo`0gooooo`;o
00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00?o0000ojRojol000000_nX_n/00ol0003o
Z;o[ojRoj`02ojRoj`;o00000ooHc/l01?l0003oi=S:onCHb_l00003on?Fb@04o`000?oRd/So0000
o`0000;ogl_500?o0000om_6aOoKa/D00_oKa/D01Ol0003od[c4om:la?oB_<Co000000;ocKK400?o
0000olN``ol000000oo2Zl<01Ol0003o_:G2o`000?ngWl7o000000Co/Y_000?o0000ojfF_on]U[l0
0ol00004ojJ?_@04o`000?nSSKgoXhfmo`0000?oX8^n00?o0000oij:__nNR[h01?l00002oif8_@04
o`000?nLRKkoW8Vno`0000CoW8Vo00Go0000oif;`?nMRl3oWH_0o`000003oif<`@03o`000?nNSL;o
WXg200;oWXg20_l000000onPSL3o0000oj6>`@03oj6>`@05o`000?nRSl7oXXo1oj:?`Ol000000onS
T<400ol0003oXi30oj>@`004o`0000;oY9G500?o0000ojBDaOnTU<D00_nTU<D01Ol0003oY9?4ojBC
a?nTTlCo000000;oY9;31?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00000onX_n/4o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?oooooo000000Oooooo000_ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01?l0003oZ;o[o`000?l00002
ojRoj`03o`000?oHc/oo000000;oi=S:00Go0000on?FbOoSe/WohmK9o`000002on;Bb005o`000?oO
clSo0000omo;aOl000000ooKa/D01Ol0003oe/75o`000?oB_<Co000000CocKK400?o0000ol:[`oo2
Zl<00oo2Zl<01Ol0003o]io1okNO`OngWl7o000000?o/Y_00ol00002ojZB_P03o`000?nVSkgoYXnm
00;oYXnm00Co0000oj>=_OnSSKgo00000_nPRkh4o`0000;oWXVl00?o0000oif8_OnMR;d00_nMR;d0
1?l0003oW8Vnoib9__l00003oib9_`05o`000?nMRl3oWH_0oif;`?l000001?nMS<400ol0003oWXg2
o`000002o`0000?oX8g000Go0000oj6>`OnQS/7oXHk1o`000003oj:?`@04o`000?nST<7oXi31oj>@
`@?o00000_nTULH00ol0003oY9G5ojBEa@02ojBEa@05o`000?nTU<GoY9C5ojBDaOl000000onTTl@3
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`?o000000?oZ;o[
o`000?nX_n/01?nX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00002ojRoj`;o00000_nX_n/4
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00001oooool0
033ooooo0_l0000hooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`?o000000?oi=S:o`000?oSe/T00_oSe/T01?l0003oh];8on;Bb?l00003
omo?b005o`000?oKa/GoflK5om_6aOl000000ooF`LD00ol0003ocKK4olffa002olffa0;o00001?o2
Zl<2o`0000?o]io100Ko0000ok:K`?nbVl3o0000ojjF__l00004ojZB_P05o`000?nVSkgoYXnmojJ?
_Ol000000_nSSKd3o`0000;oX8Vl00?o0000oij9_?nNRK`00_nNRK`01Ol0003oWHRmoif8_OnMR;go
000000;oW8Vn00Go0000oib9_onLRKooW8Voo`000002oif;`0So00000_nOS<001Ol0003oX8g0oj2=
`?nPSL3o000000?oXHk100?o0000oj:?`OnRSl400_nRSl43o`000003ojBEa_l0003oY9G600?oY9G6
00Go0000ojBEaOnTULGoY9G5o`000003ojBDa@06o`000?nTTlCo0000o`000?nX_n_o00001?nX_n/3
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
1?l0003oZ;o[ojRojonX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[1?l00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0_l00007ooooo`00
<_ooool00ol0003oooooooooo`0gooooo`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00Co0000ojRojol0003o00000one`^@3o`000005on?FbOl0003oh];8on;B
b?l000001?oOclP2o`000003om_6aOl0003oe/7500;oe/750_l00003olffa004o`000?o7/LCoak74
o`0000;o`Z_300Co0000okbU`_nlYL;o00000_ngWl400ol0003o/Y_0o`000003ojjF_P05o`000?nZ
T[koZY:nojZB__l000001?nVSkd2o`000003oj:;_?l0003oX8Vl00?oX8Vl00Go0000oij9_?nNRKco
WXVlo`000003oif8_@04o`000?nLRKkoW8Vno`0000;oW8Vo1?l00002oij:_P05o`000?nNRkooWX^o
oij;_ol000001?nOS<001Ol0003oX8g0oj2=`?nPSL3o000000?oXHk100?o0000oj:?`Ol000000_l0
0004ojBEaP05o`000?nTULKoY9G6ojBEa_l000000onTULD00ol0003oY9C5ojBDa@03o`0000CoZ;o[
00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01Ol00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`03o`000?nX_n_o0000
00?o00001?nX_n/3o`0000;oZ;o[00Co0000ojRojonX_n_oZ;o[1?l00002ojRoj`03o`000?nX_n_o
Z;o[00?o00001oooool003?ooooo00?o0000ooooooooool0=oooool2o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`03o`000?nX_n_oZ;o[00?o00000one`^@01?l0003obLCFolW4e_o9a=H2
o`000003on;Bb?l0003oglo800?oglo800Co0000omc;b?oLblSo00000ooF`LD01_l0003odKc6om6l
a_l0003ocKK4o`0000?oak7400?o0000ol:[`ol000000onlYL800ol0003o]io1okNO`@02o`0000Co
[YJn00Go0000ojZB__nZT[koZY:no`000002ojJ?_@?o00000onRRk`01Ol0003oX8Vloj29_?nPRKco
000000?oWXVl00?o0000oif8_OnMR;d00_nMR;d00ol0003oW8Vno`000002o`0000;oWXVm00?o0000
oij:__nNR[h00_nNR[h01Ol0003oWX^ooij;_onNRkoo000000?oWhc000Go0000oj2=`?nPSL3oX8g0
o`000002oj6>`@?o00000_nSULH00ol0003oY9G6ojBEaP02ojBEaP05o`000?nTULKoY9G6ojBEa_l0
00000_nTULD4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00001?nX_n/3o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/2o`000005ojRojol0003o0000ojRojol000000onX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ooooo`03o`000?oooooooooo00Cooooo000d
ooooo`03o`000?oooooooooo03Oooooo00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003o]L;To`000003olW4eP03o`000?oJd]7of];A00;o00000ooOclP0
2?l0003og<_8omc;b?l0003of<K8o`000?oF`LGo00000ooA_<H2o`0000Coak740_l00004okbU`P05
o`000?ngWl7o0000ok:K`?l000001?n^U[h01?l0003oZY:nojZB__nZT[h3o`0000;oY8fl00Go0000
oj:;_?nRRkcoXX^lo`000003oj29_003o`000?nNRKcoWXVl00;oWXVl00?o0000oif8_Ol000000ol0
00000onNR;co0000oij9_@03oij9_@05o`000?nNR[koWXZnoij:__l000000onNRkl01Ol0003oWhc0
oin<`?nOS<3o000000;oX8g01?l000000onSU<Ko0000oj>EaP03oj>EaP05o`000?nTULKoY9G6ojBE
a_l000000_nTULH4o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03o`000?nX
_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003oZ;o[ojRojonX_n/3o`0000CoZ;o[
0ol000000onX_n_o0000ojRoj`03ojRoj`?o00001oooool00ol0003oooooooooo`04ooooo`00=Ooo
ool2o`0003Sooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRo
j`03o`0000?obLCF00Wo0000om[BdOoJd]7of];Ao`000?oKdLoo0000omo?b?l000000_oLblP01Ol0
003of<K8omS6b?oHa/So000000?odKc600?o0000olbga_l000000oo7/L@00ol0003o`J_4o`000004
okbU`P;o00000onbVl000ol0003o[YJnojjF_P02ojjF_P?o000000?oYhnmo`000?nTSK`00onTSK`0
1?l0003oXX^loj:;_?l00004oj29_003o`000?nNRKco000000?o00000_nNR;/01Ol0003oWXRloij8
_?nNR;co000000?oWXVm00Go0000oij:__nNR[koWXZno`000003oij;_`03o`000?nOS<3oWhc000Co
00000_nRU<D01Ol0003oXiC6oj>Da_nSU<Ko000000?oXiG600?o0000ojBEa_nTULH01?l00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00004ojRoj`?o000000?oZ;o[o`000?nX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01Ol000000onX_n_o0000o`000002ojRoj`?o00001?nX_n/01?l0
003oZ;o[o`000?l0000:ooooo`03o`000?oooooooooo00Cooooo000gooooo`03o`000?oooooooooo
03Kooooo00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003obLCFo`000003om[Bd@04o`000?oKdLoofm7?om_Ac`;o000000?og<_8o`000?oHa/P00_oH
a/P01Ol0003oe<;8o`000?oA_<Ko000000?oc;O600?o0000olNaa?l000000oo1Zl@01_l0003o_:G2
okbU`_l0003o]j32o`0000Co/Y_000?o0000ojjF__n^U[h00_l00004ojN?_@05o`000?nTSKcoY8fl
ojB=_?l000000onRRk`00ol0003oX8Vlo`000003o`0000;oWhRk00?o0000oij8^onNR;/00_nNR;/0
1?l0003oWXRloij8_?l00003oij9_@03o`000?nNR[koWXZn00;oWXZn00?o0000oij;_ol000000ol0
0002oj:Ca@03o`000?nRU<GoXYC500;oXYC500Co0000oj>Da_nSU<Ko00000onSULH3o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`000?nX
_n_o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_oZ;o[
ojRoj`Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00003?ooool00ol0003oooooooooo`04ooooo`00>?ooool00ol0
003oooooooooo`0fooooo`03o`000?nX_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000ooJd]401Ol0003ofm7?om_AcooKdLoo000000;of/k>00Go
0000omS6b?oHa/Sof<K8o`000003omC2b003o`000?o<]lKoc;O600?oc;O600?o0000ol6[a?o1Zl@0
0_o1Zl@00ol0003o_:G2o`000003okNP`P09o`000?nbVl3o/Y_0ok:K`?l0003o[YJno`000?nZTkko
000000CoYhnm00Go0000ojB=_?nTSKcoY8flo`000002oj:;_0?o00000_nPR;/00ol0003oWhRkoin8
^`02oin8^`05o`000?nNR;_oWXRkoij8^ol000000_nNR;`00ol0003oWXVmoij9_@02oij9_@03o`00
0?nNR[ko000000?o00000_nQT/@00ol0003oXY?5oj:Ca@02oj:Ca@05o`000?nRU<GoXYC5oj:DaOl0
00000_nSU<H01_l0003oXiG6o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[
0ol00002ojRoj`03o`000?nX_n_oZ;o[00Go00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00002ojRoj`;o00000_nX_n/4o`0000oooooo00?o0000ooooooooool0
1?ooool003Wooooo00?o0000ooooooooool0=_ooool00ol0003oZ;o[ojRoj`02ojRoj`03o`000?nX
_n_o000000;oZ;o[00Co0000ojRojonX_n_oZ;o[0ol00003ojRoj`03o`000?oJd]7o000000?ofm7?
00So0000om[>c_oJc/ko0000omO;c_l0003of<K8o`0000Coe<;80_l00003olbgaP;o00001?o1Zl@2
o`0000Co]j3200Co0000ok:K`?nbVl3o/Y_00_l00003ojZC_P05o`000?nWSkgoYhnmojN?_Ol00000
1?nTSK`2o`000003oj69^ol0003oX8Rk00;oX8Rk00?o0000oin8^onOR;/00_nOR;/01Ol0003oWXRk
oij8^onNR;_o000000?oWXRl00?o0000oij9_Ol000000ol00002oj6A``03o`000?nQT/CoXI;400;o
XI;400Go0000oj:CaOnRTlGoXY?5o`000003oj:Da@03o`000?nSU<KoXiC600;o00001?nX_n/01_l0
003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX
_n_oZ;o[00?o00001?nX_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/01?l0000Cooooo`03o`000?oooooooooo00Cooooo000jooooo`;o0000=oooool00ol0003oZ;o[
ojRoj`03o`0000CoZ;o[00?o0000ojRojol000000onX_n/00ol0003oZ;o[ojRoj`04o`000005om_A
col0003of/k>om[>c_l000000ooGblh2o`0000?oe<;800Ko0000olnmbOo?_LWo0000olbga_l00002
olJbaP06o`000?o1ZlCo`J_4o`000?nlY/Co00001?ngX<801_l0003o/Y_0o`000?l0003o[YNoo`00
00?oZY>n00?o0000ojN?_OnWSkd00_nWSkd00ol0003oY8flo`000002o`0000;oXHVk00?o0000oj28
^onPR;/00_nPR;/01Ol0003oWhRkoin8^onOR;_o000000CoWXRk00?o0000oij8_?l000000_l00002
oj6@``03o`000?nQTL?oXI7300;oXI7300Go0000oj6Ba?nQT/CoXI;4o`000003oj:Ca@03o`000?nR
U<GoXYC500Co00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Co0000ojRojol0003o0000
0_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00004ojRoj`?o000000?oZ;o[o`000?nX_n/00onX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co000000?oooooo`000?ooool05?ooool00ol0003ooooo
ooooo`04ooooo`00??ooool00ol0003oooooooooo`0eooooo`;o00000onX_n/00ol0003oZ;o[ojRo
j`03o`0000CoZ;o[0ol00003ok[3h@?o000000?of/k>o`000?oGblh00ooGblh01Ol0003odlO>o`00
0?oD`/So000000Cockg900Oo0000olJba_o6//Koa[;6o`000?o1ZlCo000000?o_:K400Co0000okNP
`_ngX<;o]j320_l00004ojjG_`04o`000?nZTkkoZY>no`0000?oYhnm0ol00002oj>;^`05o`000?nQ
RK_oXHVkoj69^ol000000onPR;/00ol0003oWhRkoin8^`02oin8^`03o`000?nNR;_o000000?o0000
00?oXHo2o`000?nQT<<00onQT<<01Ol0003oXI73oj6A`onQTL?o000000?oXI;400?o0000oj:CaOnR
TlD01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000Co
Z;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`03o`0000CoZ;o[00Ko0000ojRojol0003o0000ojRojol00004ojRoj`?o00000_nX_n/0
1?l0003oZ;o[ojRojonX_n/4o`0000Kooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`00?Oooool00ol0003oooooooooo`0eooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/0
1_l0003oZ;o[o`000?l0003oZ;o[o`0000?o^/?Q00Co0000olK6f_o6a][oa/KJ0_l00003omO;cP05
o`000?oCalkodlO>om?7c_l000001?o?_LT2o`0000Coa[;600?o0000okbVa?nlY/@00_nlY/@01_l0
003o]j32o`000?l0003o/Yc2o`0000Co[YNo00Co0000ojZC__nZTkkoZY>n0ol000000onUSKco0000
oj>;^`03oj>;^`04o`000?nQRK_oXHVko`0000?oX8Rk00Co0000oin8^onOR;_oWhRk0ol00002oj6?
`@05o`000?nQSl;oXHo2oj6?`_l000000onQT<<01Ol0003oXI73oj6A`onQTL?o000000;oXI;41?l0
0003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00Ko
0000ojRojol0003o0000ojRojol00004ojRoj`?o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`06o`000?nX_n_o0000o`00
0?nX_n_o00000onX_n/4o`0000_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`00?_ooool00ol0003oooooooooo`0eooooo`;o00001?nX_n/00ol0003oZ;o[ojRoj`02o`00
00CoZ;o[00?o0000ok[3hOl000000oo6a]X01_l0003oclgHolo=f?l0003oel_>o`0000?odlO>0_l0
0003olnmb@04o`000?o9^L[obKW:o`0000;oa[;60_l00005okbVa003o`000?nbW<;o/Yc200;o/Yc2
00Go0000ojjG_on^Ukoo[YNoo`000002ojZC_P;o00001?nUSK`01Ol0003oXh^koj>;^onSRk_o0000
00;oXHVk00?o0000oj28^onPR;/00_nPR;/3o`000003oj6?`Ol0003oXHo100?oXHo100Co0000oj6?
`_nQSl;o00000onQT<<00ol0003oXI73oj6A``04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002
ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[00Ko0000
ojRojol0003o0000ojRojol00003ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[
00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`?o00004?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000oooooo`03o`000?oooooooooo03Kooooo00?o
0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o00000oo6a]X01?l0003oclgHolo=
f?o?cMP2o`0000?odlO>00Ko0000olo3c_o?`lko0000olnmbOl00003olVibP03o`000?o6//Ko0000
00;o`:g700Co0000okbVa?nlY/Co_:K40_l00004ok:L`P04o`000?n^Ukoo[YNoojjG_`?o000000?o
Yi2mo`000?nUSK`00onUSK`01Ol0003oXh^koj>;^onSRk_o000000?oXHVk00?o0000oj28^ol00000
0_l00004oj6?`@05o`000?nQSl7oXHo1oj6?`Ol000000_nQSl800ol0003oXI33oj6@``04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004ojRoj`05o`000?nX_n_o0000ojRo
jol000001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRo
j`03o`000?nX_n_oZ;o[00?o00004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00?ooooo0010ooooo`;o0000=oooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03
o`000?o6a][o000000?oclgH00Ko0000olk:eoo>b]Oo0000om?7c_l00003olo3cP;o00001?o9^LX2
o`0000Co`:g700?o0000okbVa?l000000_nfX/D01_l0003o/Yc2ok:L`_nbW<;o0000ojjG_`;o0000
00?oZIBoo`000?nWT;d00_nWT;d01Ol0003oYHflojF=_?nUSKco000000CoXh^k00?o0000oj69^ol0
00000_l00002oj:?`@03o`000?nQSl7oXHo100;oXHo100Go0000oj6?`OnQSl7oXHo1o`000002oj6?
`P?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000?oZ;o[00?o
0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0000Fooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00oooool004;ooooo00?o0000ooooooooool0=Oooool00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/01?l000000oo?cMSo0000olk:e`02olk:e`;o00000oo?`lh0
0ol0003obko?o`000003olVibP03o`000?o3]<co000000Co`:g70_l00003okJRa@04o`000?nbW<;o
/Yc2ok:L`P;o00001?nYU;l01?l0003oYi2mojN@_Ol00004ojF=_003o`000?nSRk_o000000?o0000
00?oXXo1o`000?nRSl400onRSl401Ol0003oXHo1oj6?`OnQSl7o000000CoXHo10_l000000onX_n_o
0000ojRoj`03ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;o
Z;o[00?o0000ojRojonX_n/00ol00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/01?l0000Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool004?ooooo00?o0000ooooooooool0=Oooool2o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00003oj_0j@;o00000oo>b]L01_l0003oblOFol_7e_l0003ocl?>o`0000?obko?00?o0000
olVib_l000000oo3]<`01_l0003o`:g7o`000?l0003o^ZW8o`0000?o]Z;500Ko0000ok:L`_l0003o
0000ojbH`_l00004ojVD_`04o`000?nWT;goYi2mo`0000;oYHfl1?l00002oj>@`@05o`000?nRSl7o
XXo1oj:?`Ol000000onRSl400ol0003oXHo1oj6?`@02oj6?`@03o`000?nQSl7o000000;o00000onX
_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[0ol00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX
_n/01?l0000Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool004Cooooo
00?o0000ooooooooool0=_ooool00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00Co0000oj_0jOl0003o
00000_nd`^@00ol0003oc/[Go`000003ol_7eP;o00001?o;_ll2o`0000Co`kC<0_l00004okZYb003
o`000?nfX/Go]Z;500;o00001?n/V<801Ol0003oZIBoojVD_onYU;oo000000;oYi2m0ol00002ojBB
`P03o`000?nST<7oXi3100;oXi3100Co0000oj:?`OnRSl7o00000onRSl400ol0003oXHo1oj6?`@04
o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o
0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/01_l0003oZ;o[o`000?l0003oZ;o[o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co
00000onX_n/00ol0003oZ;o[ojRoj`03o`0002Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`00AOooool2o`0003Oooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00;o0000
1?nd`^@2o`0000?oblOF00?o0000olS4eol000000oo;_ll00ol0003oaK_Ao`000003ol>dc003o`00
0?nm/<go000000Co^ZW800Go0000okJRaOl0003o/9k6o`000004ojbH`P03o`000?nYU;ooZIBo00;o
ZIBo0_l000000onVU<Co0000ojBB`P03ojBB`P05o`000?nST<7oXi31oj>@`Ol000000_nRSl400ol0
003oXXo1oj:?`@04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[
00?o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[
00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`000003ojRojol0003oZ;o[00?oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co0000:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo0017ooooo`03o`000?oooooooooo03Gooooo00?o0000ojRojonX_n/01?l00002ojRoj`04
o`000?nd`^Co0000o`0000;o^/CQ00?o0000ol_7e_l000000oo8a=L00ol0003obko?o`000003olFk
d@03o`000?o3]<co000000?o_K3=00Co0000okZYb?njZLSo^ZW80_l00003ok2NaP05o`000?n/V<;o
[9S2ojbH`_l000000_nYU;l3o`0000?oYYC400Go0000ojBB`_nTT/;oY9;2o`000003oj>@`@03o`00
0?nRSl7oXXo100?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol00003ojRoj`06o`000?nX_n_o0000o`000?nX_n_o00001?nX_n/3o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00;o00001?nX_n/01?l0
003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000;Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo0018ooooo`03o`000?oooooooooo03Gooooo0_l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000onja>43o`0000?ob<CG0ol00003olFkd@;o00001?nm/<d01_l0
003o^ZW8o`000?l0003o/jG:o`0000?o/9k600?o0000ojbH`_n/V<801?l00002ojNHaP05o`000?nV
U<CoYYC4ojJDa?l000000onTT/800ol0003oXi31oj>@`@04o`0000;oZ;o[00?o0000ojRojonX_n/0
1?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[
00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o00001?nX_n/3o`00037o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00BOooool00ol0003ooooo
ooooo`0eooooo`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o^/CQo`000003okc5h@03o`00
0?o8a=Oo000000?o`l7H00Go0000olFkdOl0003o_kSCo`000004okf`c@;o00001?ncYLX00ol0003o
/9k6ok2NaP03o`0000;oZIc800?o0000ojNHa_nWV<H00_nWV<H01?l0003oYYC4ojJDa?l00002ojBB
`PCo00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000CoZ;o[0ol00002ojRo
j`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`00
00?oZ;o[00Co0000ojRojol0003o0000=Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo001:ooooo`;o0000=_ooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00004okc5
h@;o00001?o3`MP2o`0000?o_kSC00Ko0000okf`cOl0003o0000okJ/col00004ok>UbP05o`000?n`
W/Ko0000oj^Qc?l000001?nYW<P01Ol0003oYiS6ojNHa_nWV<Ko000000;oYYC40ol00003ojRoj`03
o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX
_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/01_l0003oZ;o[o`000?l0003oZ;o[
o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`03o`0003Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02
ooooo`00C?ooool00ol0003oooooooooo`0eooooo`03o`000?nX_n_oZ;o[00?o00000onY`>X01?l0
003o_<GQo`000?l00002ok_3h@06o`000?o3`MSo0000o`000?nn_][o00000ono^=<2o`0000Co]Zc?
00?o0000ok>Ub_ncYLX00ol00003oj^Qc005o`000?nYW<SoZIc8ojVLb?l000000onWV<H3o`0000;o
Z;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o
00001?nX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003o
Z;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o
00000onX_n/00ol0003oZ;o[ojRoj`04o`0003cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`00COooool00ol0003oooooooooo`0eooooo`;o00000_nX_n/00ol0003oZL3Z
ojW0jP03o`0000Co^l?Q0_l00004okjnfP05o`000?no^=?o0000okRde_l000001?nf[<l3o`0000;o
[JKA00Go0000oj^Qc?n[XLcoZj7<o`000003ojVLb004o`000?nWV<Ko0000o`0000;oZ;o[00?o0000
ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`03o`0000?oZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_o
Z;o[00Co0000@?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo001>oooo
o`03o`000?oooooooooo03Gooooo00?o0000ojRojonX_n/00ol00003oj_0j@04o`000?nk`n7o0000
o`0000;o^<;R00?o0000okjnf_nn_]X00ol00003okRdeP06o`000?nf[<oo0000o`000?n_[MKo0000
1?n]Y]401?l0003oZj7<oj^Qc?l00002ojVLb0?o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?o
Z;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003o
Z;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000AOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo001?ooooo`;o0000=_ooool2o`0000?o
Z;o[00?o0000oj_0jOn[`>T00_l00004okS2hP?o00000onh_=d00ol0003o^;CFokRdeP02o`0000Co
[jgF00Go0000ojfVdOn]Y]7o[JKAo`000002oj^Qc0?o00000onX_n/01?l0003oZ;o[o`000?l00002
ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000
ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04
o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`04
o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o0000B_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo001Aooooo`03o`000?oooooooooo
03Cooooo00?o0000ojRojonX_n/01?l00002oj^oj006o`000?nh`^;o0000o`000?nd`NCo00001?nh
_=d3o`0000;o/;CL00Go0000ojn]e_n_[MKo[jgFo`000002ojfVd@Co00000onX_n/00ol0003oZ;o[
ojRoj`02o`0000CoZ;o[0ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[
ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003o
Z;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00Co
0000COooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo001Booooo`03o`00
0?oooooooooo03Cooooo0_l00003ojRoj`03o`000?n[_nSoZkoX00?o00000ond`N@01_l0003o^;cM
o`000?l0003o/;_Ro`0000Co/;CL00?o0000ojn]e_n_[MH00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00_l00004
ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/01?l0001B
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool005?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oZ;o[ojRoj`04o`0000?oZl3Y00?o0000okC1i?nd`N@00_l00004ok2k
hP03o`000?n`]=co/;CL00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00_l00004ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000
ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000Eoooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo007ooooo001Dooooo`;o0000=Oooool2o`0000?oYko[00?o0000oj_0
jOn[`>T01?l00002ojk0i`03o`000?n`^n;o/;_R00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`00
00?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`04o`000?nX_n_o0000o`0000;oZ;o[00?o0000
ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03
o`0000?oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/0
0ol0003oZ;o[ojRoj`02o`0000CoZ;o[0ol00002ojRoj`03o`000?nX_n_oZ;o[00Co0000G?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo001Fooooo`03o`000?oooooooooo
03Cooooo00?o0000ojNojonW_n/00ol00003oj[1j`03o`000?n^`>Oo[/3W00?o00000onX_n/00ol0
003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[
00;o00001?nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_o
Z;o[00?o0000H?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo007ooooo001Goooo
o`03o`000?oooooooooo03Cooooo0_l00002ojJoj`03o`000?nZ`N_oZ/7[00Co00000onX_n/00ol0
003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/01?l0003oZ;o[o`000?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/00ol00004
ojRoj`?o0000I?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo007ooooo001Hoooo
o`03o`000?oooooooooo03Cooooo00?o0000ojJojonV_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[
00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00?o00000_nX_n/4o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/01?l0003oZ;o[o`000?l0001X
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00Oooool005Wooooo0_l0000eoooo
o`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0ol00003ojRo
j`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`00
00;oZ;o[00?o0000ojRojonX_n/00ol0001[ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`7ooooo001Kooooo`03o`000?oooooooooo03?ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03
o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX
_n/00ol00003ojRoj`03o`000?nX_n_o000000;oZ;o[00?o0000ojRojonX_n/01?l00003ojRoj`03
o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX
_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0006ko
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005cooooo00?o0000ooooooooool0
<oooool2o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`?o0000
0onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`00
0?nX_n_oZ;o[00Co00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/0
1?l0001booooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001Mooooo`03o`000?oo
oooooooo03?ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX
_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0
001gooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`7ooooo001Nooooo`;o0000=?ooool2
o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000;oZ;o[00Co0000ojRojol0003o00000_nX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol0001looooo`05o`000?oo
ooooooooooooool000000_ooool0063ooooo00?o0000ooooooooool0<_ooool00ol0003oZ;o[ojRo
j`04o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000;oZ;o[1?l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX
_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX
_n_oZ;o[00Co0000Ooooool01Ol0003ooooooooooooooooo000000;ooooo001Qooooo`03o`000?oo
oooooooo03;ooooo0_l00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`?o00000onX_n/00ol0003oZ;o[ojRo
j`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0008Cooooo00Co0000oooooooooooo00000_ooool006;ooooo00?o
0000ooooooooool0<oooool00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/00ol0
0003ojRoj`03o`000?nX_n_oZ;o[00?o00000_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l0
0003ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o
0000ojRojonX_n/00ol00029ooooo`03o`000?oooooo000000;ooooo001Sooooo`;o0000=?ooool2
o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/3
o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX_n/0
0ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l0002<ooooo`04o`000?oooooo
ooooo`00007ooooo001Uooooo`03o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/00ol00003
ojRoj`03o`000?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[o`000002ojRoj`03o`000?nX_n_o
Z;o[00Co00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRojonX_n/01?l00003
ojRoj`03o`000?nX_n_oZ;o[00?o0000TOooool00ol0003oooooo`000001ooooo`00I_ooool00ol0
003oooooooooo`0booooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRo
jonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00Co0000UOooool2o`00007ooooo001Wooooo`03
o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_oZ;o[00?o
00000_nX_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co
00000_nX_n/00ol0003oZ;o[ojRoj`04o`0009Sooooo0ol00001ooooo`00J?ooool00ol0003ooooo
ooooo`0booooo`;o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0000;oZ;o[0ol00003ojRoj`03o`00
0?nX_n_oZ;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000?oZ;o[00?o0000ojRojonX_n/0
0ol0002Hooooo`Co00001?ooool006Wooooo0_l0000cooooo`03o`000?nX_n_oZ;o[00?o00000_nX
_n/4o`0000;oZ;o[00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`04o`0009Sooooo0ol00008ooooo`00Joooool00ol0003oooooooooo`0a
ooooo`;o00000_nX_n/3o`0000?oZ;o[00?o0000ojRojonX_n/00ol00003ojRoj`03o`000?nX_n_o
Z;o[00?o00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Sooooo1?l0000;ooooo`00K?ooool00ol0
003oooooooooo`0booooo`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0000;oZ;o[00?o0000ojRo
jonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00Co0000Uoooool4o`0000oooooo001]ooooo`03
o`000?oooooooooo03;ooooo00?o0000ojRojonX_n/01?l00002ojRoj`03o`000?nX_n_oZ;o[00?o
00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Oooooo1?l0000Cooooo`00K_ooool2o`0003?ooooo
0_l00003ojRoj`03o`000?nX_n_oZ;o[00?o00000_nX_n/00ol0003oZ;o[ojRoj`04o`0009Oooooo
0ol0000Gooooo`00L?ooool00ol0003oooooooooo`0aooooo`03o`000?nX_n_oZ;o[00Co00000_nX
_n/00ol0003oZ;o[ojRoj`03o`0009Oooooo1?l0000Jooooo`00LOooool00ol0003oooooooooo`0a
ooooo`;o00000onX_n/00ol0003oZ;o[ojRoj`03o`0009Kooooo1?l0000Nooooo`00L_ooool00ol0
003oooooooooo`0aooooo`03o`000?nX_n_oZ;o[00Co0000UOooool4o`0002;ooooo001cooooo`;o
0000<_ooool2o`0009Gooooo1?l0000Vooooo`00MOooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo097ooooo0ol0000Zooooo`00M_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo08gooooo1?l0000]ooooo`00Moooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo08Wooooo1?l0000aooooo`00N?ooool2o`0002gooooo00?o0000ooooooooool0QOooool4o`00
03Gooooo001jooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0P_ooool3o`0003Wo
oooo001kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0O_ooool4o`0003cooooo
001looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0N_ooool4o`00043ooooo001m
ooooo`;o0000:?ooool00ol0003oooooooooo`1fooooo`Co0000A?ooool007oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1cooooo`?o0000B?ooool0083ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`1_ooooo`Co0000Boooool0087ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1[ooooo`Co0000Coooool008;ooooo0_l0000Sooooo`03o`000?oo
oooooooo06Oooooo1?l0001Cooooo`00Q?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06Cooooo0ol0001Gooooo`00QOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
063ooooo1?l0001Jooooo`00Q_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05co
oooo1?l0001Nooooo`00Qoooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0006;ooooo
0029ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0006Kooooo002:
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`0006[ooooo002;oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool4o`0006gooooo002<ooooo`;o
00006Oooool00ol0003oooooooooo`19ooooo`Co0000LOooool008kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`Co0000MOooool008oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`12ooooo`?o0000NOooool0093ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0nooooo`Co0000O?ooool0097ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0jooooo`Co0000P?ooool009;ooooo0_l0000Booooo`03o`000?oooooooooo03Oo
oooo1?l00024ooooo`00U?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo
0ol00028ooooo`00UOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo1?l0
002;ooooo`00U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l0002?
ooooo`00Uoooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0009?ooooo002Iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool3o`0009Oooooo002Jooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`0009[ooooo002Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0009kooooo002Looooo`;o00002?ooool0
0ol0003oooooooooo`0Iooooo`Co0000X_ooool009kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Eooooo`Co0000Y_ooool009oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`?o0000Z_ooool00:3ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`Co0000[Oooool00:7ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0
002aooooo`00Xoooool01?l0003oooooooooool00008ooooo`Co0000]Oooool00:Cooooo00?o0000
ooooool000001Oooool3o`000;Wooooo002Uooooo`;o000000?oooooo`000?l000000_l0002loooo
o`00Y_ooool2o`000<3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002nooooo`?o000000?o410@ooooooooool0Y?ooool009cooooo00?o^[Zjoc8b<_ooool0
3Oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Fooooo`00WOooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Gooooo`00Voooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo1Ol0001gooooo`00Voooool01ol0003oZJVYoeEEEOnHV9So
EEEEokZj^_l000000_ooool00ol0003oooooooooo`05ooooo`0:o`000?ooooooooooooooooo^k^ko
8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool00omEEEGoMgMgodA4A006
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A7Oooooo002Kooooo`06oc8b
<_o^k^koV9RHoeEEEOoMgMgo410@0ol00008ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2_ooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000000[ooooo00?oV9RHob4Q8Oo^k^h0N?ooool009_ooooo00Oo
^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h:ooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0Mooo
ool009_ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S89ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool00oooool00ol0003oooooooooo`0Booooo`05o`000?n7QhOoooooojVYZOl000003?ooool00omg
MgOoIVIVooooo`1fooooo`00Voooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo
00Sooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol@413o0000ogMg
M`02o`000003oiRHV?oooooooooo00_ooooo00?o0000ooooooooool0MOooool009kooooo00?oIVIV
ohN7Qoooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00Go0000
okZj^_ooooooV9RHoa0@401gooooo`00W_ooool00onYZJWoA4A4ooooo`0;ooooo`;o00006_ooool2
o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01gooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.11607, 0.0207698, \
0.00372262, 0.00372262}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -37.6875 0 ]
[.5 .82364 37.6875 10.125 ]
[.03045 .24505 -12 -8.71092 ]
[.03045 .24505 0 .28908 ]
[.17875 .18668 -23.5791 -9 ]
[.17875 .18668 .42091 0 ]
[.33612 .12478 -5.58359 -9 ]
[.33612 .12478 .41641 0 ]
[.5034 .05901 -15.8172 -9 ]
[.5034 .05901 2.18278 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70361 -0.00072 0 -6.25801 ]
[.70361 -0.00072 6 2.74199 ]
[.82501 .18517 0 -6.07699 ]
[.82501 .18517 18 2.92301 ]
[.92763 .34231 0 -5.92977 ]
[.92763 .34231 6 3.07023 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.01698 .30981 -36 -2.7801 ]
[.01698 .30981 0 6.2199 ]
[.00392 .3917 -6 -2.8496 ]
[.00392 .3917 0 6.1504 ]
[-0.00985 .478 -30 -2.92324 ]
[-0.00985 .478 0 6.07676 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -98.6875 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.312 11.250 moveto
(@) show
80.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
86.312 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
92.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
98.375 11.250 moveto
(D) show
104.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
116.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
122.375 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
128.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
134.375 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.69139 .00406 m
.68528 .00644 L
s
[(0)] .70361 -0.00072 -1 .39067 Mshowa
.81263 .18951 m
.80643 .19168 L
s
[(0.5)] .82501 .18517 -1 .35044 Mshowa
.91512 .34629 m
.90887 .34827 L
s
[(1)] .92763 .34231 -1 .31773 Mshowa
.125 Mabswid
.71738 .04381 m
.7137 .04521 L
s
.74245 .08216 m
.73876 .08354 L
s
.76665 .11918 m
.76296 .12054 L
s
.79003 .15495 m
.78632 .15627 L
s
.83448 .22293 m
.83075 .22421 L
s
.85562 .25527 m
.85189 .25653 L
s
.87608 .28658 m
.87235 .28781 L
s
.89591 .3169 m
.89216 .31811 L
s
.93375 .37478 m
.92999 .37595 L
s
.95181 .40242 m
.94805 .40357 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02924 .30512 m
.03537 .30278 L
s
[(-0.001)] .01698 .30981 1 -0.3822 Mshowa
.01623 .38718 m
.02239 .38492 L
s
[(0)] .00392 .3917 1 -0.36675 Mshowa
.00253 .47366 m
.00872 .47149 L
s
[(0.001)] -0.00985 .478 1 -0.35039 Mshowa
.125 Mabswid
.02669 .3212 m
.03037 .3198 L
s
.02412 .33744 m
.0278 .33605 L
s
.02152 .35385 m
.02521 .35247 L
s
.01889 .37043 m
.02258 .36906 L
s
.01355 .40411 m
.01725 .40277 L
s
.01084 .42122 m
.01454 .41989 L
s
.0081 .43852 m
.01181 .43719 L
s
.00533 .45599 m
.00904 .45468 L
s
.03176 .28921 m
.03543 .2878 L
s
.03426 .27346 m
.03793 .27204 L
s
.03673 .25787 m
.04039 .25644 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.654 .753 .922 r
.39463 .71356 .40109 .71913 .41189 .71612 .40546 .71053 Metetra
.654 .753 .922 r
.40546 .71053 .41189 .71612 .42273 .71309 .41633 .70748 Metetra
.654 .753 .922 r
.41633 .70748 .42273 .71309 .43361 .71006 .42724 .70442 Metetra
.654 .753 .922 r
.42724 .70442 .43361 .71006 .44454 .70701 .4382 .70135 Metetra
.654 .753 .922 r
.4382 .70135 .44454 .70701 .45552 .70395 .4492 .69827 Metetra
.654 .753 .922 r
.4492 .69827 .45552 .70395 .46653 .70088 .46025 .69518 Metetra
.654 .753 .922 r
.46025 .69518 .46653 .70088 .4776 .6978 .47134 .69207 Metetra
.654 .753 .922 r
.47134 .69207 .4776 .6978 .48871 .6947 .48248 .68895 Metetra
.654 .753 .922 r
.48248 .68895 .48871 .6947 .49986 .69159 .49366 .68582 Metetra
.654 .753 .922 r
.49366 .68582 .49986 .69159 .51106 .68847 .50489 .68267 Metetra
.654 .753 .922 r
.50489 .68267 .51106 .68847 .5223 .68534 .51616 .67951 Metetra
.654 .753 .922 r
.51616 .67951 .5223 .68534 .53359 .68219 .52749 .67634 Metetra
.654 .753 .922 r
.52749 .67634 .53359 .68219 .54493 .67903 .53885 .67316 Metetra
.654 .753 .922 r
.53885 .67316 .54493 .67903 .55632 .67585 .55027 .66996 Metetra
.654 .753 .922 r
.55027 .66996 .55632 .67585 .56775 .67267 .56173 .66675 Metetra
.654 .753 .922 r
.56173 .66675 .56775 .67267 .57923 .66947 .57324 .66353 Metetra
.654 .753 .922 r
.57324 .66353 .57923 .66947 .59075 .66625 .5848 .66029 Metetra
.654 .753 .922 r
.5848 .66029 .59075 .66625 .60233 .66303 .59641 .65704 Metetra
.654 .753 .922 r
.59641 .65704 .60233 .66303 .61395 .65979 .60806 .65377 Metetra
.654 .753 .922 r
.60806 .65377 .61395 .65979 .62562 .65654 .61977 .65049 Metetra
.654 .753 .922 r
.61977 .65049 .62562 .65654 .63734 .65327 .63152 .6472 Metetra
.654 .753 .922 r
.63152 .6472 .63734 .65327 .64911 .64999 .64332 .64389 Metetra
.654 .753 .922 r
.64332 .64389 .64911 .64999 .66093 .64669 .65518 .64057 Metetra
.654 .753 .922 r
.65518 .64057 .66093 .64669 .6728 .64338 .66708 .63724 Metetra
.654 .753 .922 r
.66708 .63724 .6728 .64338 .68472 .64006 .67903 .63389 Metetra
.654 .753 .922 r
.67903 .63389 .68472 .64006 .69669 .63673 .69103 .63053 Metetra
.654 .753 .922 r
.69103 .63053 .69669 .63673 .70871 .63338 .70309 .62715 Metetra
.654 .753 .922 r
.70309 .62715 .70871 .63338 .72078 .63001 .7152 .62376 Metetra
.654 .753 .922 r
.7152 .62376 .72078 .63001 .7329 .62663 .72735 .62035 Metetra
.654 .753 .922 r
.72735 .62035 .7329 .62663 .74507 .62324 .73956 .61693 Metetra
.654 .753 .922 r
.73956 .61693 .74507 .62324 .7573 .61983 .75183 .6135 Metetra
.654 .753 .922 r
.75183 .6135 .7573 .61983 .76958 .61641 .76414 .61005 Metetra
.654 .753 .922 r
.76414 .61005 .76958 .61641 .78191 .61297 .77651 .60658 Metetra
.654 .753 .922 r
.77651 .60658 .78191 .61297 .79429 .60952 .78893 .60311 Metetra
.654 .753 .922 r
.78893 .60311 .79429 .60952 .80673 .60605 .80141 .59961 Metetra
.654 .753 .922 r
.80141 .59961 .80673 .60605 .81922 .60257 .81394 .5961 Metetra
.654 .753 .922 r
.81394 .5961 .81922 .60257 .83177 .59907 .82652 .59258 Metetra
.654 .753 .922 r
.82652 .59258 .83177 .59907 .84437 .59556 .83916 .58903 Metetra
.654 .753 .922 r
.83916 .58903 .84437 .59556 .85702 .59203 .85185 .58548 Metetra
.654 .753 .922 r
.85185 .58548 .85702 .59203 .86973 .58849 .8646 .58191 Metetra
.654 .753 .922 r
.8646 .58191 .86973 .58849 .88249 .58493 .87741 .57832 Metetra
.654 .753 .922 r
.87741 .57832 .88249 .58493 .89532 .58136 .89027 .57472 Metetra
.654 .753 .922 r
.89027 .57472 .89532 .58136 .90819 .57777 .90319 .5711 Metetra
.654 .753 .922 r
.90319 .5711 .90819 .57777 .92113 .57416 .91617 .56746 Metetra
.654 .753 .922 r
.91617 .56746 .92113 .57416 .93412 .57054 .9292 .56381 Metetra
.654 .753 .922 r
.9292 .56381 .93412 .57054 .94717 .5669 .94229 .56015 Metetra
.654 .753 .922 r
.94229 .56015 .94717 .5669 .96027 .56325 .95544 .55646 Metetra
.654 .753 .922 r
.95544 .55646 .96027 .56325 .97344 .55958 .96865 .55276 Metetra
.654 .753 .922 r
.96865 .55276 .97344 .55958 .98666 .55589 .98191 .54905 Metetra
.654 .753 .922 r
.38813 .70795 .39463 .71356 .40546 .71053 .39898 .7049 Metetra
.654 .753 .922 r
.39898 .7049 .40546 .71053 .41633 .70748 .40988 .70183 Metetra
.654 .753 .922 r
.40988 .70183 .41633 .70748 .42724 .70442 .42082 .69875 Metetra
.654 .753 .922 r
.42082 .69875 .42724 .70442 .4382 .70135 .43181 .69566 Metetra
.654 .753 .922 r
.43181 .69566 .4382 .70135 .4492 .69827 .44284 .69255 Metetra
.654 .753 .922 r
.44284 .69255 .4492 .69827 .46025 .69518 .45391 .68943 Metetra
.654 .753 .922 r
.45391 .68943 .46025 .69518 .47134 .69207 .46503 .6863 Metetra
.654 .753 .922 r
.46503 .6863 .47134 .69207 .48248 .68895 .4762 .68316 Metetra
.654 .753 .922 r
.4762 .68316 .48248 .68895 .49366 .68582 .48741 .68 Metetra
.654 .753 .922 r
.48741 .68 .49366 .68582 .50489 .68267 .49867 .67683 Metetra
.654 .753 .922 r
.49867 .67683 .50489 .68267 .51616 .67951 .50998 .67365 Metetra
.654 .753 .922 r
.50998 .67365 .51616 .67951 .52749 .67634 .52133 .67045 Metetra
.654 .753 .922 r
.52133 .67045 .52749 .67634 .53885 .67316 .53273 .66724 Metetra
.654 .753 .922 r
.53273 .66724 .53885 .67316 .55027 .66996 .54418 .66402 Metetra
.654 .753 .922 r
.54418 .66402 .55027 .66996 .56173 .66675 .55567 .66079 Metetra
.654 .753 .922 r
.55567 .66079 .56173 .66675 .57324 .66353 .56721 .65754 Metetra
.654 .753 .922 r
.56721 .65754 .57324 .66353 .5848 .66029 .5788 .65427 Metetra
.654 .753 .922 r
.5788 .65427 .5848 .66029 .59641 .65704 .59044 .651 Metetra
.654 .753 .922 r
.59044 .651 .59641 .65704 .60806 .65377 .60213 .64771 Metetra
.654 .753 .922 r
.60213 .64771 .60806 .65377 .61977 .65049 .61387 .6444 Metetra
.654 .753 .922 r
.61387 .6444 .61977 .65049 .63152 .6472 .62565 .64109 Metetra
.654 .753 .922 r
.62565 .64109 .63152 .6472 .64332 .64389 .63749 .63775 Metetra
.654 .753 .922 r
.63749 .63775 .64332 .64389 .65518 .64057 .64938 .63441 Metetra
.654 .753 .922 r
.64938 .63441 .65518 .64057 .66708 .63724 .66131 .63105 Metetra
.654 .753 .922 r
.66131 .63105 .66708 .63724 .67903 .63389 .6733 .62767 Metetra
.654 .753 .922 r
.6733 .62767 .67903 .63389 .69103 .63053 .68534 .62428 Metetra
.654 .753 .922 r
.68534 .62428 .69103 .63053 .70309 .62715 .69743 .62088 Metetra
.654 .753 .922 r
.69743 .62088 .70309 .62715 .7152 .62376 .70957 .61746 Metetra
.654 .753 .922 r
.70957 .61746 .7152 .62376 .72735 .62035 .72177 .61403 Metetra
.654 .753 .922 r
.72177 .61403 .72735 .62035 .73956 .61693 .73401 .61058 Metetra
.654 .753 .922 r
.73401 .61058 .73956 .61693 .75183 .6135 .74631 .60712 Metetra
.654 .753 .922 r
.74631 .60712 .75183 .6135 .76414 .61005 .75866 .60364 Metetra
.654 .753 .922 r
.75866 .60364 .76414 .61005 .77651 .60658 .77107 .60015 Metetra
.654 .753 .922 r
.77107 .60015 .77651 .60658 .78893 .60311 .78353 .59664 Metetra
.654 .753 .922 r
.78353 .59664 .78893 .60311 .80141 .59961 .79604 .59312 Metetra
.654 .753 .922 r
.79604 .59312 .80141 .59961 .81394 .5961 .80861 .58958 Metetra
.654 .753 .922 r
.80861 .58958 .81394 .5961 .82652 .59258 .82123 .58603 Metetra
.654 .753 .922 r
.82123 .58603 .82652 .59258 .83916 .58903 .83391 .58246 Metetra
.654 .753 .922 r
.83391 .58246 .83916 .58903 .85185 .58548 .84665 .57887 Metetra
.654 .753 .922 r
.84665 .57887 .85185 .58548 .8646 .58191 .85944 .57527 Metetra
.654 .753 .922 r
.85944 .57527 .8646 .58191 .87741 .57832 .87228 .57166 Metetra
.654 .753 .922 r
.87228 .57166 .87741 .57832 .89027 .57472 .88519 .56802 Metetra
.654 .753 .922 r
.88519 .56802 .89027 .57472 .90319 .5711 .89815 .56438 Metetra
.654 .753 .922 r
.89815 .56438 .90319 .5711 .91617 .56746 .91116 .56071 Metetra
.654 .753 .922 r
.91116 .56071 .91617 .56746 .9292 .56381 .92424 .55703 Metetra
.654 .753 .922 r
.92424 .55703 .9292 .56381 .94229 .56015 .93737 .55333 Metetra
.654 .753 .922 r
.93737 .55333 .94229 .56015 .95544 .55646 .95056 .54962 Metetra
.654 .753 .922 r
.95056 .54962 .95544 .55646 .96865 .55276 .96382 .54589 Metetra
.654 .753 .922 r
.96382 .54589 .96865 .55276 .98191 .54905 .97713 .54214 Metetra
.654 .753 .922 r
.38158 .7023 .38813 .70795 .39898 .7049 .39246 .69922 Metetra
.654 .753 .922 r
.39246 .69922 .39898 .7049 .40988 .70183 .40339 .69613 Metetra
.654 .753 .922 r
.40339 .69613 .40988 .70183 .42082 .69875 .41435 .69303 Metetra
.654 .753 .922 r
.41435 .69303 .42082 .69875 .43181 .69566 .42537 .68991 Metetra
.654 .753 .922 r
.42537 .68991 .43181 .69566 .44284 .69255 .43643 .68678 Metetra
.654 .753 .922 r
.43643 .68678 .44284 .69255 .45391 .68943 .44753 .68364 Metetra
.654 .753 .922 r
.44753 .68364 .45391 .68943 .46503 .6863 .45868 .68049 Metetra
.654 .753 .922 r
.45868 .68049 .46503 .6863 .4762 .68316 .46988 .67732 Metetra
.654 .753 .922 r
.46988 .67732 .4762 .68316 .48741 .68 .48112 .67414 Metetra
.654 .753 .922 r
.48112 .67414 .48741 .68 .49867 .67683 .49241 .67095 Metetra
.654 .753 .922 r
.49241 .67095 .49867 .67683 .50998 .67365 .50374 .66774 Metetra
.654 .753 .922 r
.50374 .66774 .50998 .67365 .52133 .67045 .51513 .66452 Metetra
.654 .753 .922 r
.51513 .66452 .52133 .67045 .53273 .66724 .52656 .66129 Metetra
.654 .753 .922 r
.52656 .66129 .53273 .66724 .54418 .66402 .53803 .65804 Metetra
.654 .753 .922 r
.53803 .65804 .54418 .66402 .55567 .66079 .54956 .65478 Metetra
.654 .753 .922 r
.54956 .65478 .55567 .66079 .56721 .65754 .56113 .6515 Metetra
.654 .753 .922 r
.56113 .6515 .56721 .65754 .5788 .65427 .57276 .64822 Metetra
.654 .753 .922 r
.57276 .64822 .5788 .65427 .59044 .651 .58443 .64491 Metetra
.654 .753 .922 r
.58443 .64491 .59044 .651 .60213 .64771 .59615 .6416 Metetra
.654 .753 .922 r
.59615 .6416 .60213 .64771 .61387 .6444 .60792 .63827 Metetra
.654 .753 .922 r
.60792 .63827 .61387 .6444 .62565 .64109 .61974 .63492 Metetra
.654 .753 .922 r
.61974 .63492 .62565 .64109 .63749 .63775 .63161 .63157 Metetra
.654 .753 .922 r
.63161 .63157 .63749 .63775 .64938 .63441 .64353 .62819 Metetra
.654 .753 .922 r
.64353 .62819 .64938 .63441 .66131 .63105 .6555 .62481 Metetra
.654 .753 .922 r
.6555 .62481 .66131 .63105 .6733 .62767 .66752 .6214 Metetra
.654 .753 .922 r
.66752 .6214 .6733 .62767 .68534 .62428 .6796 .61799 Metetra
.654 .753 .922 r
.6796 .61799 .68534 .62428 .69743 .62088 .69172 .61456 Metetra
.654 .753 .922 r
.69172 .61456 .69743 .62088 .70957 .61746 .7039 .61111 Metetra
.654 .753 .922 r
.7039 .61111 .70957 .61746 .72177 .61403 .71613 .60765 Metetra
.654 .753 .922 r
.71613 .60765 .72177 .61403 .73401 .61058 .72842 .60418 Metetra
.654 .753 .922 r
.72842 .60418 .73401 .61058 .74631 .60712 .74075 .60069 Metetra
.654 .753 .922 r
.74075 .60069 .74631 .60712 .75866 .60364 .75314 .59718 Metetra
.654 .753 .922 r
.75314 .59718 .75866 .60364 .77107 .60015 .76558 .59366 Metetra
.654 .753 .922 r
.76558 .59366 .77107 .60015 .78353 .59664 .77808 .59013 Metetra
.654 .753 .922 r
.77808 .59013 .78353 .59664 .79604 .59312 .79064 .58657 Metetra
.654 .753 .922 r
.79064 .58657 .79604 .59312 .80861 .58958 .80324 .58301 Metetra
.654 .753 .922 r
.80324 .58301 .80861 .58958 .82123 .58603 .8159 .57943 Metetra
.654 .753 .922 r
.8159 .57943 .82123 .58603 .83391 .58246 .82862 .57583 Metetra
.654 .753 .922 r
.82862 .57583 .83391 .58246 .84665 .57887 .8414 .57221 Metetra
.654 .753 .922 r
.8414 .57221 .84665 .57887 .85944 .57527 .85423 .56858 Metetra
.654 .753 .922 r
.85423 .56858 .85944 .57527 .87228 .57166 .86711 .56494 Metetra
.654 .753 .922 r
.86711 .56494 .87228 .57166 .88519 .56802 .88006 .56128 Metetra
.654 .753 .922 r
.88006 .56128 .88519 .56802 .89815 .56438 .89306 .5576 Metetra
.654 .753 .922 r
.89306 .5576 .89815 .56438 .91116 .56071 .90612 .5539 Metetra
.654 .753 .922 r
.90612 .5539 .91116 .56071 .92424 .55703 .91924 .55019 Metetra
.654 .753 .922 r
.91924 .55019 .92424 .55703 .93737 .55333 .93242 .54646 Metetra
.654 .753 .922 r
.93242 .54646 .93737 .55333 .95056 .54962 .94565 .54272 Metetra
.654 .753 .922 r
.94565 .54272 .95056 .54962 .96382 .54589 .95895 .53896 Metetra
.654 .753 .922 r
.95895 .53896 .96382 .54589 .97713 .54214 .9723 .53518 Metetra
.654 .753 .922 r
.37498 .69661 .38158 .7023 .39246 .69922 .38589 .69351 Metetra
.654 .753 .922 r
.38589 .69351 .39246 .69922 .40339 .69613 .39684 .69039 Metetra
.654 .753 .922 r
.39684 .69039 .40339 .69613 .41435 .69303 .40784 .68727 Metetra
.654 .753 .922 r
.40784 .68727 .41435 .69303 .42537 .68991 .41888 .68413 Metetra
.654 .753 .922 r
.41888 .68413 .42537 .68991 .43643 .68678 .42997 .68097 Metetra
.654 .753 .922 r
.42997 .68097 .43643 .68678 .44753 .68364 .4411 .67781 Metetra
.654 .753 .922 r
.4411 .67781 .44753 .68364 .45868 .68049 .45228 .67463 Metetra
.654 .753 .922 r
.45228 .67463 .45868 .68049 .46988 .67732 .46351 .67144 Metetra
.654 .753 .922 r
.46351 .67144 .46988 .67732 .48112 .67414 .47478 .66823 Metetra
.654 .753 .922 r
.47478 .66823 .48112 .67414 .49241 .67095 .4861 .66502 Metetra
.654 .753 .922 r
.4861 .66502 .49241 .67095 .50374 .66774 .49746 .66178 Metetra
.654 .753 .922 r
.49746 .66178 .50374 .66774 .51513 .66452 .50888 .65854 Metetra
.654 .753 .922 r
.50888 .65854 .51513 .66452 .52656 .66129 .52034 .65528 Metetra
.654 .753 .922 r
.52034 .65528 .52656 .66129 .53803 .65804 .53185 .65201 Metetra
.654 .753 .922 r
.53185 .65201 .53803 .65804 .54956 .65478 .5434 .64872 Metetra
.654 .753 .922 r
.5434 .64872 .54956 .65478 .56113 .6515 .55501 .64542 Metetra
.654 .753 .922 r
.55501 .64542 .56113 .6515 .57276 .64822 .56666 .64211 Metetra
.654 .753 .922 r
.56666 .64211 .57276 .64822 .58443 .64491 .57837 .63878 Metetra
.654 .753 .922 r
.57837 .63878 .58443 .64491 .59615 .6416 .59012 .63544 Metetra
.654 .753 .922 r
.59012 .63544 .59615 .6416 .60792 .63827 .60193 .63208 Metetra
.654 .753 .922 r
.60193 .63208 .60792 .63827 .61974 .63492 .61378 .62871 Metetra
.654 .753 .922 r
.61378 .62871 .61974 .63492 .63161 .63157 .62568 .62533 Metetra
.654 .753 .922 r
.62568 .62533 .63161 .63157 .64353 .62819 .63764 .62193 Metetra
.654 .753 .922 r
.63764 .62193 .64353 .62819 .6555 .62481 .64964 .61851 Metetra
.654 .753 .922 r
.64964 .61851 .6555 .62481 .66752 .6214 .6617 .61509 Metetra
.654 .753 .922 r
.6617 .61509 .66752 .6214 .6796 .61799 .67381 .61164 Metetra
.654 .753 .922 r
.67381 .61164 .6796 .61799 .69172 .61456 .68597 .60819 Metetra
.654 .753 .922 r
.68597 .60819 .69172 .61456 .7039 .61111 .69819 .60471 Metetra
.654 .753 .922 r
.69819 .60471 .7039 .61111 .71613 .60765 .71045 .60123 Metetra
.654 .753 .922 r
.71045 .60123 .71613 .60765 .72842 .60418 .72277 .59772 Metetra
.654 .753 .922 r
.72277 .59772 .72842 .60418 .74075 .60069 .73515 .5942 Metetra
.654 .753 .922 r
.73515 .5942 .74075 .60069 .75314 .59718 .74757 .59067 Metetra
.654 .753 .922 r
.74757 .59067 .75314 .59718 .76558 .59366 .76006 .58712 Metetra
.654 .753 .922 r
.76006 .58712 .76558 .59366 .77808 .59013 .77259 .58356 Metetra
.654 .753 .922 r
.77259 .58356 .77808 .59013 .79064 .58657 .78518 .57998 Metetra
.654 .753 .922 r
.78518 .57998 .79064 .58657 .80324 .58301 .79783 .57638 Metetra
.654 .753 .922 r
.79783 .57638 .80324 .58301 .8159 .57943 .81053 .57277 Metetra
.654 .753 .922 r
.81053 .57277 .8159 .57943 .82862 .57583 .82329 .56914 Metetra
.654 .753 .922 r
.82329 .56914 .82862 .57583 .8414 .57221 .8361 .5655 Metetra
.654 .753 .922 r
.8361 .5655 .8414 .57221 .85423 .56858 .84898 .56184 Metetra
.654 .753 .922 r
.84898 .56184 .85423 .56858 .86711 .56494 .8619 .55816 Metetra
.654 .753 .922 r
.8619 .55816 .86711 .56494 .88006 .56128 .87489 .55447 Metetra
.654 .753 .922 r
.87489 .55447 .88006 .56128 .89306 .5576 .88793 .55076 Metetra
.654 .753 .922 r
.88793 .55076 .89306 .5576 .90612 .5539 .90104 .54704 Metetra
.654 .753 .922 r
.90104 .54704 .90612 .5539 .91924 .55019 .9142 .5433 Metetra
.654 .753 .922 r
.9142 .5433 .91924 .55019 .93242 .54646 .92742 .53954 Metetra
.654 .753 .922 r
.92742 .53954 .93242 .54646 .94565 .54272 .9407 .53576 Metetra
.654 .753 .922 r
.9407 .53576 .94565 .54272 .95895 .53896 .95404 .53197 Metetra
.654 .753 .922 r
.95404 .53197 .95895 .53896 .9723 .53518 .96743 .52816 Metetra
.654 .753 .922 r
.36833 .69087 .37498 .69661 .38589 .69351 .37927 .68775 Metetra
.654 .753 .922 r
.37927 .68775 .38589 .69351 .39684 .69039 .39025 .68461 Metetra
.654 .753 .922 r
.39025 .68461 .39684 .69039 .40784 .68727 .40127 .68146 Metetra
.654 .753 .922 r
.40127 .68146 .40784 .68727 .41888 .68413 .41234 .6783 Metetra
.654 .753 .922 r
.41234 .6783 .41888 .68413 .42997 .68097 .42346 .67512 Metetra
.654 .753 .922 r
.42346 .67512 .42997 .68097 .4411 .67781 .43462 .67193 Metetra
.654 .753 .922 r
.43462 .67193 .4411 .67781 .45228 .67463 .44583 .66873 Metetra
.654 .753 .922 r
.44583 .66873 .45228 .67463 .46351 .67144 .45709 .66551 Metetra
.654 .753 .922 r
.45709 .66551 .46351 .67144 .47478 .66823 .46839 .66228 Metetra
.654 .753 .922 r
.46839 .66228 .47478 .66823 .4861 .66502 .47974 .65904 Metetra
.654 .753 .922 r
.47974 .65904 .4861 .66502 .49746 .66178 .49113 .65578 Metetra
.654 .753 .922 r
.49113 .65578 .49746 .66178 .50888 .65854 .50258 .65251 Metetra
.654 .753 .922 r
.50258 .65251 .50888 .65854 .52034 .65528 .51407 .64923 Metetra
.654 .753 .922 r
.51407 .64923 .52034 .65528 .53185 .65201 .52561 .64593 Metetra
.654 .753 .922 r
.52561 .64593 .53185 .65201 .5434 .64872 .5372 .64262 Metetra
.654 .753 .922 r
.5372 .64262 .5434 .64872 .55501 .64542 .54884 .63929 Metetra
.654 .753 .922 r
.54884 .63929 .55501 .64542 .56666 .64211 .56052 .63595 Metetra
.654 .753 .922 r
.56052 .63595 .56666 .64211 .57837 .63878 .57226 .6326 Metetra
.654 .753 .922 r
.57226 .6326 .57837 .63878 .59012 .63544 .58405 .62923 Metetra
.654 .753 .922 r
.58405 .62923 .59012 .63544 .60193 .63208 .59588 .62585 Metetra
.654 .753 .922 r
.59588 .62585 .60193 .63208 .61378 .62871 .60777 .62245 Metetra
.654 .753 .922 r
.60777 .62245 .61378 .62871 .62568 .62533 .61971 .61904 Metetra
.654 .753 .922 r
.61971 .61904 .62568 .62533 .63764 .62193 .6317 .61562 Metetra
.654 .753 .922 r
.6317 .61562 .63764 .62193 .64964 .61851 .64374 .61217 Metetra
.654 .753 .922 r
.64374 .61217 .64964 .61851 .6617 .61509 .65583 .60872 Metetra
.654 .753 .922 r
.65583 .60872 .6617 .61509 .67381 .61164 .66798 .60525 Metetra
.654 .753 .922 r
.66798 .60525 .67381 .61164 .68597 .60819 .68018 .60176 Metetra
.654 .753 .922 r
.68018 .60176 .68597 .60819 .69819 .60471 .69243 .59826 Metetra
.654 .753 .922 r
.69243 .59826 .69819 .60471 .71045 .60123 .70473 .59475 Metetra
.654 .753 .922 r
.70473 .59475 .71045 .60123 .72277 .59772 .71709 .59122 Metetra
.654 .753 .922 r
.71709 .59122 .72277 .59772 .73515 .5942 .7295 .58767 Metetra
.654 .753 .922 r
.7295 .58767 .73515 .5942 .74757 .59067 .74196 .58411 Metetra
.654 .753 .922 r
.74196 .58411 .74757 .59067 .76006 .58712 .75448 .58053 Metetra
.654 .753 .922 r
.75448 .58053 .76006 .58712 .77259 .58356 .76706 .57694 Metetra
.654 .753 .922 r
.76706 .57694 .77259 .58356 .78518 .57998 .77969 .57333 Metetra
.654 .753 .922 r
.77969 .57333 .78518 .57998 .79783 .57638 .79237 .5697 Metetra
.654 .753 .922 r
.79237 .5697 .79783 .57638 .81053 .57277 .80512 .56606 Metetra
.654 .753 .922 r
.80512 .56606 .81053 .57277 .82329 .56914 .81791 .5624 Metetra
.654 .753 .922 r
.81791 .5624 .82329 .56914 .8361 .5655 .83077 .55873 Metetra
.654 .753 .922 r
.83077 .55873 .8361 .5655 .84898 .56184 .84368 .55504 Metetra
.654 .753 .922 r
.84368 .55504 .84898 .56184 .8619 .55816 .85665 .55134 Metetra
.654 .753 .922 r
.85665 .55134 .8619 .55816 .87489 .55447 .86968 .54761 Metetra
.654 .753 .922 r
.86968 .54761 .87489 .55447 .88793 .55076 .88276 .54387 Metetra
.654 .753 .922 r
.88276 .54387 .88793 .55076 .90104 .54704 .89591 .54012 Metetra
.654 .753 .922 r
.89591 .54012 .90104 .54704 .9142 .5433 .90911 .53634 Metetra
.654 .753 .922 r
.90911 .53634 .9142 .5433 .92742 .53954 .92238 .53255 Metetra
.654 .753 .922 r
.92238 .53255 .92742 .53954 .9407 .53576 .9357 .52875 Metetra
.654 .753 .922 r
.9357 .52875 .9407 .53576 .95404 .53197 .94908 .52492 Metetra
.654 .753 .922 r
.94908 .52492 .95404 .53197 .96743 .52816 .96253 .52108 Metetra
.654 .753 .922 r
.36163 .68509 .36833 .69087 .37927 .68775 .3726 .68195 Metetra
.654 .753 .922 r
.3726 .68195 .37927 .68775 .39025 .68461 .3836 .67878 Metetra
.654 .753 .922 r
.3836 .67878 .39025 .68461 .40127 .68146 .39466 .67561 Metetra
.654 .753 .922 r
.39466 .67561 .40127 .68146 .41234 .6783 .40576 .67242 Metetra
.654 .753 .922 r
.40576 .67242 .41234 .6783 .42346 .67512 .4169 .66922 Metetra
.654 .753 .922 r
.4169 .66922 .42346 .67512 .43462 .67193 .42809 .66601 Metetra
.654 .753 .922 r
.42809 .66601 .43462 .67193 .44583 .66873 .43933 .66278 Metetra
.654 .753 .922 r
.43933 .66278 .44583 .66873 .45709 .66551 .45062 .65954 Metetra
.654 .753 .922 r
.45062 .65954 .45709 .66551 .46839 .66228 .46195 .65628 Metetra
.654 .753 .922 r
.46195 .65628 .46839 .66228 .47974 .65904 .47333 .65302 Metetra
.654 .753 .922 r
.47333 .65302 .47974 .65904 .49113 .65578 .48475 .64973 Metetra
.654 .753 .922 r
.48475 .64973 .49113 .65578 .50258 .65251 .49623 .64644 Metetra
.654 .753 .922 r
.49623 .64644 .50258 .65251 .51407 .64923 .50775 .64313 Metetra
.654 .753 .922 r
.50775 .64313 .51407 .64923 .52561 .64593 .51932 .63981 Metetra
.654 .753 .922 r
.51932 .63981 .52561 .64593 .5372 .64262 .53095 .63647 Metetra
.654 .753 .922 r
.53095 .63647 .5372 .64262 .54884 .63929 .54262 .63312 Metetra
.654 .753 .922 r
.54262 .63312 .54884 .63929 .56052 .63595 .55434 .62975 Metetra
.654 .753 .922 r
.55434 .62975 .56052 .63595 .57226 .6326 .56611 .62637 Metetra
.654 .753 .922 r
.56611 .62637 .57226 .6326 .58405 .62923 .57793 .62298 Metetra
.654 .753 .922 r
.57793 .62298 .58405 .62923 .59588 .62585 .5898 .61957 Metetra
.654 .753 .922 r
.5898 .61957 .59588 .62585 .60777 .62245 .60172 .61614 Metetra
.654 .753 .922 r
.60172 .61614 .60777 .62245 .61971 .61904 .61369 .6127 Metetra
.654 .753 .922 r
.61369 .6127 .61971 .61904 .6317 .61562 .62571 .60925 Metetra
.654 .753 .922 r
.62571 .60925 .6317 .61562 .64374 .61217 .63779 .60578 Metetra
.654 .753 .922 r
.63779 .60578 .64374 .61217 .65583 .60872 .64992 .6023 Metetra
.654 .753 .922 r
.64992 .6023 .65583 .60872 .66798 .60525 .6621 .5988 Metetra
.654 .753 .922 r
.6621 .5988 .66798 .60525 .68018 .60176 .67433 .59529 Metetra
.654 .753 .922 r
.67433 .59529 .68018 .60176 .69243 .59826 .68662 .59176 Metetra
.654 .753 .922 r
.68662 .59176 .69243 .59826 .70473 .59475 .69896 .58822 Metetra
.654 .753 .922 r
.69896 .58822 .70473 .59475 .71709 .59122 .71135 .58466 Metetra
.654 .753 .922 r
.71135 .58466 .71709 .59122 .7295 .58767 .7238 .58108 Metetra
.654 .753 .922 r
.7238 .58108 .7295 .58767 .74196 .58411 .73631 .57749 Metetra
.654 .753 .922 r
.73631 .57749 .74196 .58411 .75448 .58053 .74886 .57388 Metetra
.654 .753 .922 r
.74886 .57388 .75448 .58053 .76706 .57694 .76148 .57026 Metetra
.654 .753 .922 r
.76148 .57026 .76706 .57694 .77969 .57333 .77415 .56662 Metetra
.654 .753 .922 r
.77415 .56662 .77969 .57333 .79237 .5697 .78687 .56297 Metetra
.654 .753 .922 r
.78687 .56297 .79237 .5697 .80512 .56606 .79965 .5593 Metetra
.654 .753 .922 r
.79965 .5593 .80512 .56606 .81791 .5624 .81249 .55561 Metetra
.654 .753 .922 r
.81249 .55561 .81791 .5624 .83077 .55873 .82539 .55191 Metetra
.654 .753 .922 r
.82539 .55191 .83077 .55873 .84368 .55504 .83834 .54819 Metetra
.654 .753 .922 r
.83834 .54819 .84368 .55504 .85665 .55134 .85135 .54445 Metetra
.654 .753 .922 r
.85135 .54445 .85665 .55134 .86968 .54761 .86442 .5407 Metetra
.654 .753 .922 r
.86442 .5407 .86968 .54761 .88276 .54387 .87755 .53693 Metetra
.654 .753 .922 r
.87755 .53693 .88276 .54387 .89591 .54012 .89074 .53314 Metetra
.654 .753 .922 r
.89074 .53314 .89591 .54012 .90911 .53634 .90399 .52933 Metetra
.654 .753 .922 r
.90399 .52933 .90911 .53634 .92238 .53255 .91729 .52551 Metetra
.654 .753 .922 r
.91729 .52551 .92238 .53255 .9357 .52875 .93066 .52167 Metetra
.654 .753 .922 r
.93066 .52167 .9357 .52875 .94908 .52492 .94409 .51782 Metetra
.654 .753 .922 r
.94409 .51782 .94908 .52492 .96253 .52108 .95758 .51394 Metetra
.654 .753 .922 r
.35488 .67927 .36163 .68509 .3726 .68195 .36587 .6761 Metetra
.654 .753 .922 r
.36587 .6761 .3726 .68195 .3836 .67878 .37691 .67291 Metetra
.654 .753 .922 r
.37691 .67291 .3836 .67878 .39466 .67561 .38799 .66971 Metetra
.654 .753 .922 r
.38799 .66971 .39466 .67561 .40576 .67242 .39912 .6665 Metetra
.654 .753 .922 r
.39912 .6665 .40576 .67242 .4169 .66922 .41029 .66328 Metetra
.654 .753 .922 r
.41029 .66328 .4169 .66922 .42809 .66601 .42151 .66004 Metetra
.654 .753 .922 r
.42151 .66004 .42809 .66601 .43933 .66278 .43278 .65679 Metetra
.654 .753 .922 r
.43278 .65679 .43933 .66278 .45062 .65954 .4441 .65352 Metetra
.654 .753 .922 r
.4441 .65352 .45062 .65954 .46195 .65628 .45546 .65024 Metetra
.654 .753 .922 r
.45546 .65024 .46195 .65628 .47333 .65302 .46687 .64695 Metetra
.654 .753 .922 r
.46687 .64695 .47333 .65302 .48475 .64973 .47833 .64364 Metetra
.654 .753 .922 r
.47833 .64364 .48475 .64973 .49623 .64644 .48983 .64032 Metetra
.654 .753 .922 r
.48983 .64032 .49623 .64644 .50775 .64313 .50139 .63698 Metetra
.654 .753 .922 r
.50139 .63698 .50775 .64313 .51932 .63981 .51299 .63363 Metetra
.654 .753 .922 r
.51299 .63363 .51932 .63981 .53095 .63647 .52464 .63027 Metetra
.654 .753 .922 r
.52464 .63027 .53095 .63647 .54262 .63312 .53635 .62689 Metetra
.654 .753 .922 r
.53635 .62689 .54262 .63312 .55434 .62975 .5481 .6235 Metetra
.654 .753 .922 r
.5481 .6235 .55434 .62975 .56611 .62637 .5599 .62009 Metetra
.654 .753 .922 r
.5599 .62009 .56611 .62637 .57793 .62298 .57176 .61667 Metetra
.654 .753 .922 r
.57176 .61667 .57793 .62298 .5898 .61957 .58366 .61323 Metetra
.654 .753 .922 r
.58366 .61323 .5898 .61957 .60172 .61614 .59562 .60978 Metetra
.654 .753 .922 r
.59562 .60978 .60172 .61614 .61369 .6127 .60762 .60632 Metetra
.654 .753 .922 r
.60762 .60632 .61369 .6127 .62571 .60925 .61968 .60284 Metetra
.654 .753 .922 r
.61968 .60284 .62571 .60925 .63779 .60578 .63179 .59934 Metetra
.654 .753 .922 r
.63179 .59934 .63779 .60578 .64992 .6023 .64396 .59583 Metetra
.654 .753 .922 r
.64396 .59583 .64992 .6023 .6621 .5988 .65617 .5923 Metetra
.654 .753 .922 r
.65617 .5923 .6621 .5988 .67433 .59529 .66844 .58876 Metetra
.654 .753 .922 r
.66844 .58876 .67433 .59529 .68662 .59176 .68077 .5852 Metetra
.654 .753 .922 r
.68077 .5852 .68662 .59176 .69896 .58822 .69314 .58163 Metetra
.654 .753 .922 r
.69314 .58163 .69896 .58822 .71135 .58466 .70558 .57804 Metetra
.654 .753 .922 r
.70558 .57804 .71135 .58466 .7238 .58108 .71806 .57444 Metetra
.654 .753 .922 r
.71806 .57444 .7238 .58108 .73631 .57749 .7306 .57082 Metetra
.654 .753 .922 r
.7306 .57082 .73631 .57749 .74886 .57388 .7432 .56718 Metetra
.654 .753 .922 r
.7432 .56718 .74886 .57388 .76148 .57026 .75585 .56353 Metetra
.654 .753 .922 r
.75585 .56353 .76148 .57026 .77415 .56662 .76856 .55986 Metetra
.654 .753 .922 r
.76856 .55986 .77415 .56662 .78687 .56297 .78133 .55618 Metetra
.654 .753 .922 r
.78133 .55618 .78687 .56297 .79965 .5593 .79415 .55248 Metetra
.654 .753 .922 r
.79415 .55248 .79965 .5593 .81249 .55561 .80703 .54876 Metetra
.654 .753 .922 r
.80703 .54876 .81249 .55561 .82539 .55191 .81996 .54503 Metetra
.654 .753 .922 r
.81996 .54503 .82539 .55191 .83834 .54819 .83296 .54127 Metetra
.654 .753 .922 r
.83296 .54127 .83834 .54819 .85135 .54445 .84601 .53751 Metetra
.654 .753 .922 r
.84601 .53751 .85135 .54445 .86442 .5407 .85912 .53372 Metetra
.654 .753 .922 r
.85912 .53372 .86442 .5407 .87755 .53693 .8723 .52992 Metetra
.654 .753 .922 r
.8723 .52992 .87755 .53693 .89074 .53314 .88553 .5261 Metetra
.654 .753 .922 r
.88553 .5261 .89074 .53314 .90399 .52933 .89882 .52226 Metetra
.654 .753 .922 r
.89882 .52226 .90399 .52933 .91729 .52551 .91217 .51841 Metetra
.654 .753 .922 r
.91217 .51841 .91729 .52551 .93066 .52167 .92558 .51454 Metetra
.654 .753 .922 r
.92558 .51454 .93066 .52167 .94409 .51782 .93905 .51065 Metetra
.654 .753 .922 r
.93905 .51065 .94409 .51782 .95758 .51394 .95259 .50674 Metetra
.654 .753 .922 r
.34808 .6734 .35488 .67927 .36587 .6761 .3591 .67021 Metetra
.654 .753 .922 r
.3591 .67021 .36587 .6761 .37691 .67291 .37016 .667 Metetra
.654 .753 .922 r
.37016 .667 .37691 .67291 .38799 .66971 .38127 .66377 Metetra
.654 .753 .922 r
.38127 .66377 .38799 .66971 .39912 .6665 .39243 .66054 Metetra
.654 .753 .922 r
.39243 .66054 .39912 .6665 .41029 .66328 .40363 .65729 Metetra
.654 .753 .922 r
.40363 .65729 .41029 .66328 .42151 .66004 .41488 .65402 Metetra
.654 .753 .922 r
.41488 .65402 .42151 .66004 .43278 .65679 .42618 .65075 Metetra
.654 .753 .922 r
.42618 .65075 .43278 .65679 .4441 .65352 .43752 .64745 Metetra
.654 .753 .922 r
.43752 .64745 .4441 .65352 .45546 .65024 .44892 .64415 Metetra
.654 .753 .922 r
.44892 .64415 .45546 .65024 .46687 .64695 .46036 .64083 Metetra
.654 .753 .922 r
.46036 .64083 .46687 .64695 .47833 .64364 .47185 .6375 Metetra
.654 .753 .922 r
.47185 .6375 .47833 .64364 .48983 .64032 .48338 .63415 Metetra
.654 .753 .922 r
.48338 .63415 .48983 .64032 .50139 .63698 .49497 .63079 Metetra
.654 .753 .922 r
.49497 .63079 .50139 .63698 .51299 .63363 .50661 .62741 Metetra
.654 .753 .922 r
.50661 .62741 .51299 .63363 .52464 .63027 .51829 .62402 Metetra
.654 .753 .922 r
.51829 .62402 .52464 .63027 .53635 .62689 .53003 .62062 Metetra
.654 .753 .922 r
.53003 .62062 .53635 .62689 .5481 .6235 .54181 .6172 Metetra
.654 .753 .922 r
.54181 .6172 .5481 .6235 .5599 .62009 .55365 .61376 Metetra
.654 .753 .922 r
.55365 .61376 .5599 .62009 .57176 .61667 .56554 .61032 Metetra
.654 .753 .922 r
.56554 .61032 .57176 .61667 .58366 .61323 .57747 .60685 Metetra
.654 .753 .922 r
.57747 .60685 .58366 .61323 .59562 .60978 .58946 .60337 Metetra
.654 .753 .922 r
.58946 .60337 .59562 .60978 .60762 .60632 .60151 .59988 Metetra
.654 .753 .922 r
.60151 .59988 .60762 .60632 .61968 .60284 .6136 .59637 Metetra
.654 .753 .922 r
.6136 .59637 .61968 .60284 .63179 .59934 .62575 .59285 Metetra
.654 .753 .922 r
.62575 .59285 .63179 .59934 .64396 .59583 .63795 .58931 Metetra
.654 .753 .922 r
.63795 .58931 .64396 .59583 .65617 .5923 .6502 .58575 Metetra
.654 .753 .922 r
.6502 .58575 .65617 .5923 .66844 .58876 .66251 .58218 Metetra
.654 .753 .922 r
.66251 .58218 .66844 .58876 .68077 .5852 .67487 .5786 Metetra
.654 .753 .922 r
.67487 .5786 .68077 .5852 .69314 .58163 .68728 .57499 Metetra
.654 .753 .922 r
.68728 .57499 .69314 .58163 .70558 .57804 .69975 .57138 Metetra
.654 .753 .922 r
.69975 .57138 .70558 .57804 .71806 .57444 .71227 .56774 Metetra
.654 .753 .922 r
.71227 .56774 .71806 .57444 .7306 .57082 .72485 .56409 Metetra
.654 .753 .922 r
.72485 .56409 .7306 .57082 .7432 .56718 .73749 .56043 Metetra
.654 .753 .922 r
.73749 .56043 .7432 .56718 .75585 .56353 .75018 .55675 Metetra
.654 .753 .922 r
.75018 .55675 .75585 .56353 .76856 .55986 .76293 .55305 Metetra
.654 .753 .922 r
.76293 .55305 .76856 .55986 .78133 .55618 .77573 .54933 Metetra
.654 .753 .922 r
.77573 .54933 .78133 .55618 .79415 .55248 .7886 .5456 Metetra
.654 .753 .922 r
.7886 .5456 .79415 .55248 .80703 .54876 .80152 .54185 Metetra
.654 .753 .922 r
.80152 .54185 .80703 .54876 .81996 .54503 .8145 .53809 Metetra
.654 .753 .922 r
.8145 .53809 .81996 .54503 .83296 .54127 .82753 .53431 Metetra
.654 .753 .922 r
.82753 .53431 .83296 .54127 .84601 .53751 .84063 .53051 Metetra
.654 .753 .922 r
.84063 .53051 .84601 .53751 .85912 .53372 .85378 .52669 Metetra
.654 .753 .922 r
.85378 .52669 .85912 .53372 .8723 .52992 .867 .52286 Metetra
.654 .753 .922 r
.867 .52286 .8723 .52992 .88553 .5261 .88027 .519 Metetra
.654 .753 .922 r
.88027 .519 .88553 .5261 .89882 .52226 .89361 .51514 Metetra
.654 .753 .922 r
.89361 .51514 .89882 .52226 .91217 .51841 .907 .51125 Metetra
.654 .753 .922 r
.907 .51125 .91217 .51841 .92558 .51454 .92046 .50735 Metetra
.654 .753 .922 r
.92046 .50735 .92558 .51454 .93905 .51065 .93398 .50342 Metetra
.654 .753 .922 r
.93398 .50342 .93905 .51065 .95259 .50674 .94756 .49948 Metetra
.654 .753 .922 r
.34122 .66749 .34808 .6734 .3591 .67021 .35227 .66427 Metetra
.654 .753 .922 r
.35227 .66427 .3591 .67021 .37016 .667 .36336 .66104 Metetra
.654 .753 .922 r
.36336 .66104 .37016 .667 .38127 .66377 .3745 .65779 Metetra
.654 .753 .922 r
.3745 .65779 .38127 .66377 .39243 .66054 .38569 .65453 Metetra
.654 .753 .922 r
.38569 .65453 .39243 .66054 .40363 .65729 .39692 .65125 Metetra
.654 .753 .922 r
.39692 .65125 .40363 .65729 .41488 .65402 .4082 .64796 Metetra
.654 .753 .922 r
.4082 .64796 .41488 .65402 .42618 .65075 .41953 .64466 Metetra
.654 .753 .922 r
.41953 .64466 .42618 .65075 .43752 .64745 .4309 .64134 Metetra
.654 .753 .922 r
.4309 .64134 .43752 .64745 .44892 .64415 .44233 .63801 Metetra
.654 .753 .922 r
.44233 .63801 .44892 .64415 .46036 .64083 .4538 .63467 Metetra
.654 .753 .922 r
.4538 .63467 .46036 .64083 .47185 .6375 .46532 .63131 Metetra
.654 .753 .922 r
.46532 .63131 .47185 .6375 .48338 .63415 .47689 .62793 Metetra
.654 .753 .922 r
.47689 .62793 .48338 .63415 .49497 .63079 .4885 .62454 Metetra
.654 .753 .922 r
.4885 .62454 .49497 .63079 .50661 .62741 .50017 .62114 Metetra
.654 .753 .922 r
.50017 .62114 .50661 .62741 .51829 .62402 .51189 .61773 Metetra
.654 .753 .922 r
.51189 .61773 .51829 .62402 .53003 .62062 .52366 .61429 Metetra
.654 .753 .922 r
.52366 .61429 .53003 .62062 .54181 .6172 .53548 .61085 Metetra
.654 .753 .922 r
.53548 .61085 .54181 .6172 .55365 .61376 .54735 .60739 Metetra
.654 .753 .922 r
.54735 .60739 .55365 .61376 .56554 .61032 .55927 .60391 Metetra
.654 .753 .922 r
.55927 .60391 .56554 .61032 .57747 .60685 .57124 .60042 Metetra
.654 .753 .922 r
.57124 .60042 .57747 .60685 .58946 .60337 .58326 .59691 Metetra
.654 .753 .922 r
.58326 .59691 .58946 .60337 .60151 .59988 .59534 .59339 Metetra
.654 .753 .922 r
.59534 .59339 .60151 .59988 .6136 .59637 .60747 .58985 Metetra
.654 .753 .922 r
.60747 .58985 .6136 .59637 .62575 .59285 .61965 .5863 Metetra
.654 .753 .922 r
.61965 .5863 .62575 .59285 .63795 .58931 .63189 .58273 Metetra
.654 .753 .922 r
.63189 .58273 .63795 .58931 .6502 .58575 .64418 .57915 Metetra
.654 .753 .922 r
.64418 .57915 .6502 .58575 .66251 .58218 .65652 .57555 Metetra
.654 .753 .922 r
.65652 .57555 .66251 .58218 .67487 .5786 .66892 .57193 Metetra
.654 .753 .922 r
.66892 .57193 .67487 .5786 .68728 .57499 .68137 .5683 Metetra
.654 .753 .922 r
.68137 .5683 .68728 .57499 .69975 .57138 .69388 .56466 Metetra
.654 .753 .922 r
.69388 .56466 .69975 .57138 .71227 .56774 .70644 .56099 Metetra
.654 .753 .922 r
.70644 .56099 .71227 .56774 .72485 .56409 .71906 .55731 Metetra
.654 .753 .922 r
.71906 .55731 .72485 .56409 .73749 .56043 .73173 .55362 Metetra
.654 .753 .922 r
.73173 .55362 .73749 .56043 .75018 .55675 .74446 .54991 Metetra
.654 .753 .922 r
.74446 .54991 .75018 .55675 .76293 .55305 .75725 .54618 Metetra
.654 .753 .922 r
.75725 .54618 .76293 .55305 .77573 .54933 .7701 .54243 Metetra
.654 .753 .922 r
.7701 .54243 .77573 .54933 .7886 .5456 .783 .53867 Metetra
.654 .753 .922 r
.783 .53867 .7886 .5456 .80152 .54185 .79596 .53489 Metetra
.654 .753 .922 r
.79596 .53489 .80152 .54185 .8145 .53809 .80898 .53109 Metetra
.654 .753 .922 r
.80898 .53109 .8145 .53809 .82753 .53431 .82206 .52728 Metetra
.654 .753 .922 r
.82206 .52728 .82753 .53431 .84063 .53051 .8352 .52345 Metetra
.654 .753 .922 r
.8352 .52345 .84063 .53051 .85378 .52669 .84839 .5196 Metetra
.654 .753 .922 r
.84839 .5196 .85378 .52669 .867 .52286 .86165 .51573 Metetra
.654 .753 .922 r
.86165 .51573 .867 .52286 .88027 .519 .87497 .51185 Metetra
.654 .753 .922 r
.87497 .51185 .88027 .519 .89361 .51514 .88835 .50795 Metetra
.654 .753 .922 r
.88835 .50795 .89361 .51514 .907 .51125 .90179 .50403 Metetra
.654 .753 .922 r
.90179 .50403 .907 .51125 .92046 .50735 .91529 .50009 Metetra
.654 .753 .922 r
.91529 .50009 .92046 .50735 .93398 .50342 .92886 .49614 Metetra
.654 .753 .922 r
.92886 .49614 .93398 .50342 .94756 .49948 .94248 .49216 Metetra
.654 .753 .922 r
.33432 .66153 .34122 .66749 .35227 .66427 .34539 .65829 Metetra
.654 .753 .922 r
.34539 .65829 .35227 .66427 .36336 .66104 .35651 .65503 Metetra
.654 .753 .922 r
.35651 .65503 .36336 .66104 .3745 .65779 .36768 .65176 Metetra
.654 .753 .922 r
.36768 .65176 .3745 .65779 .38569 .65453 .3789 .64847 Metetra
.654 .753 .922 r
.3789 .64847 .38569 .65453 .39692 .65125 .39016 .64517 Metetra
.654 .753 .922 r
.39016 .64517 .39692 .65125 .4082 .64796 .40147 .64185 Metetra
.654 .753 .922 r
.40147 .64185 .4082 .64796 .41953 .64466 .41282 .63852 Metetra
.654 .753 .922 r
.41282 .63852 .41953 .64466 .4309 .64134 .42423 .63518 Metetra
.654 .753 .922 r
.42423 .63518 .4309 .64134 .44233 .63801 .43568 .63182 Metetra
.654 .753 .922 r
.43568 .63182 .44233 .63801 .4538 .63467 .44718 .62845 Metetra
.654 .753 .922 r
.44718 .62845 .4538 .63467 .46532 .63131 .45874 .62507 Metetra
.654 .753 .922 r
.45874 .62507 .46532 .63131 .47689 .62793 .47034 .62167 Metetra
.654 .753 .922 r
.47034 .62167 .47689 .62793 .4885 .62454 .48199 .61825 Metetra
.654 .753 .922 r
.48199 .61825 .4885 .62454 .50017 .62114 .49369 .61482 Metetra
.654 .753 .922 r
.49369 .61482 .50017 .62114 .51189 .61773 .50544 .61138 Metetra
.654 .753 .922 r
.50544 .61138 .51189 .61773 .52366 .61429 .51724 .60792 Metetra
.654 .753 .922 r
.51724 .60792 .52366 .61429 .53548 .61085 .52909 .60445 Metetra
.654 .753 .922 r
.52909 .60445 .53548 .61085 .54735 .60739 .54099 .60096 Metetra
.654 .753 .922 r
.54099 .60096 .54735 .60739 .55927 .60391 .55295 .59745 Metetra
.654 .753 .922 r
.55295 .59745 .55927 .60391 .57124 .60042 .56496 .59393 Metetra
.654 .753 .922 r
.56496 .59393 .57124 .60042 .58326 .59691 .57701 .5904 Metetra
.654 .753 .922 r
.57701 .5904 .58326 .59691 .59534 .59339 .58913 .58685 Metetra
.654 .753 .922 r
.58913 .58685 .59534 .59339 .60747 .58985 .60129 .58328 Metetra
.654 .753 .922 r
.60129 .58328 .60747 .58985 .61965 .5863 .61351 .5797 Metetra
.654 .753 .922 r
.61351 .5797 .61965 .5863 .63189 .58273 .62578 .5761 Metetra
.654 .753 .922 r
.62578 .5761 .63189 .58273 .64418 .57915 .63811 .57249 Metetra
.654 .753 .922 r
.63811 .57249 .64418 .57915 .65652 .57555 .65049 .56886 Metetra
.654 .753 .922 r
.65049 .56886 .65652 .57555 .66892 .57193 .66292 .56522 Metetra
.654 .753 .922 r
.66292 .56522 .66892 .57193 .68137 .5683 .67541 .56156 Metetra
.654 .753 .922 r
.67541 .56156 .68137 .5683 .69388 .56466 .68795 .55788 Metetra
.654 .753 .922 r
.68795 .55788 .69388 .56466 .70644 .56099 .70056 .55419 Metetra
.654 .753 .922 r
.70056 .55419 .70644 .56099 .71906 .55731 .71321 .55048 Metetra
.654 .753 .922 r
.71321 .55048 .71906 .55731 .73173 .55362 .72593 .54675 Metetra
.654 .753 .922 r
.72593 .54675 .73173 .55362 .74446 .54991 .7387 .54301 Metetra
.654 .753 .922 r
.7387 .54301 .74446 .54991 .75725 .54618 .75153 .53925 Metetra
.654 .753 .922 r
.75153 .53925 .75725 .54618 .7701 .54243 .76441 .53547 Metetra
.654 .753 .922 r
.76441 .53547 .7701 .54243 .783 .53867 .77736 .53168 Metetra
.654 .753 .922 r
.77736 .53168 .783 .53867 .79596 .53489 .79036 .52787 Metetra
.654 .753 .922 r
.79036 .52787 .79596 .53489 .80898 .53109 .80342 .52404 Metetra
.654 .753 .922 r
.80342 .52404 .80898 .53109 .82206 .52728 .81654 .52019 Metetra
.654 .753 .922 r
.81654 .52019 .82206 .52728 .8352 .52345 .82972 .51633 Metetra
.654 .753 .922 r
.82972 .51633 .8352 .52345 .84839 .5196 .84296 .51245 Metetra
.654 .753 .922 r
.84296 .51245 .84839 .5196 .86165 .51573 .85626 .50855 Metetra
.654 .753 .922 r
.85626 .50855 .86165 .51573 .87497 .51185 .86962 .50463 Metetra
.654 .753 .922 r
.86962 .50463 .87497 .51185 .88835 .50795 .88305 .5007 Metetra
.654 .753 .922 r
.88305 .5007 .88835 .50795 .90179 .50403 .89653 .49674 Metetra
.654 .753 .922 r
.89653 .49674 .90179 .50403 .91529 .50009 .91008 .49277 Metetra
.654 .753 .922 r
.91008 .49277 .91529 .50009 .92886 .49614 .92369 .48878 Metetra
.654 .753 .922 r
.92369 .48878 .92886 .49614 .94248 .49216 .93736 .48478 Metetra
.654 .753 .922 r
.32736 .65553 .33432 .66153 .34539 .65829 .33846 .65226 Metetra
.654 .753 .922 r
.33846 .65226 .34539 .65829 .35651 .65503 .34961 .64898 Metetra
.654 .753 .922 r
.34961 .64898 .35651 .65503 .36768 .65176 .36081 .64568 Metetra
.654 .753 .922 r
.36081 .64568 .36768 .65176 .3789 .64847 .37205 .64236 Metetra
.654 .753 .922 r
.37205 .64236 .3789 .64847 .39016 .64517 .38334 .63904 Metetra
.654 .753 .922 r
.38334 .63904 .39016 .64517 .40147 .64185 .39468 .6357 Metetra
.654 .753 .922 r
.39468 .6357 .40147 .64185 .41282 .63852 .40607 .63234 Metetra
.654 .753 .922 r
.40607 .63234 .41282 .63852 .42423 .63518 .4175 .62897 Metetra
.654 .753 .922 r
.4175 .62897 .42423 .63518 .43568 .63182 .42899 .62559 Metetra
.654 .753 .922 r
.42899 .62559 .43568 .63182 .44718 .62845 .44052 .62219 Metetra
.654 .753 .922 r
.44052 .62219 .44718 .62845 .45874 .62507 .4521 .61878 Metetra
.654 .753 .922 r
.4521 .61878 .45874 .62507 .47034 .62167 .46374 .61535 Metetra
.654 .753 .922 r
.46374 .61535 .47034 .62167 .48199 .61825 .47542 .61191 Metetra
.654 .753 .922 r
.47542 .61191 .48199 .61825 .49369 .61482 .48715 .60845 Metetra
.654 .753 .922 r
.48715 .60845 .49369 .61482 .50544 .61138 .49893 .60498 Metetra
.654 .753 .922 r
.49893 .60498 .50544 .61138 .51724 .60792 .51077 .60149 Metetra
.654 .753 .922 r
.51077 .60149 .51724 .60792 .52909 .60445 .52265 .59799 Metetra
.654 .753 .922 r
.52265 .59799 .52909 .60445 .54099 .60096 .53459 .59448 Metetra
.654 .753 .922 r
.53459 .59448 .54099 .60096 .55295 .59745 .54658 .59094 Metetra
.654 .753 .922 r
.54658 .59094 .55295 .59745 .56496 .59393 .55862 .5874 Metetra
.654 .753 .922 r
.55862 .5874 .56496 .59393 .57701 .5904 .57071 .58383 Metetra
.654 .753 .922 r
.57071 .58383 .57701 .5904 .58913 .58685 .58286 .58025 Metetra
.654 .753 .922 r
.58286 .58025 .58913 .58685 .60129 .58328 .59506 .57666 Metetra
.654 .753 .922 r
.59506 .57666 .60129 .58328 .61351 .5797 .60731 .57305 Metetra
.654 .753 .922 r
.60731 .57305 .61351 .5797 .62578 .5761 .61962 .56942 Metetra
.654 .753 .922 r
.61962 .56942 .62578 .5761 .63811 .57249 .63198 .56578 Metetra
.654 .753 .922 r
.63198 .56578 .63811 .57249 .65049 .56886 .6444 .56212 Metetra
.654 .753 .922 r
.6444 .56212 .65049 .56886 .66292 .56522 .65687 .55845 Metetra
.654 .753 .922 r
.65687 .55845 .66292 .56522 .67541 .56156 .6694 .55476 Metetra
.654 .753 .922 r
.6694 .55476 .67541 .56156 .68795 .55788 .68198 .55105 Metetra
.654 .753 .922 r
.68198 .55105 .68795 .55788 .70056 .55419 .69462 .54733 Metetra
.654 .753 .922 r
.69462 .54733 .70056 .55419 .71321 .55048 .70732 .54358 Metetra
.654 .753 .922 r
.70732 .54358 .71321 .55048 .72593 .54675 .72007 .53983 Metetra
.654 .753 .922 r
.72007 .53983 .72593 .54675 .7387 .54301 .73288 .53605 Metetra
.654 .753 .922 r
.73288 .53605 .7387 .54301 .75153 .53925 .74575 .53226 Metetra
.654 .753 .922 r
.74575 .53226 .75153 .53925 .76441 .53547 .75868 .52845 Metetra
.654 .753 .922 r
.75868 .52845 .76441 .53547 .77736 .53168 .77166 .52463 Metetra
.654 .753 .922 r
.77166 .52463 .77736 .53168 .79036 .52787 .78471 .52078 Metetra
.654 .753 .922 r
.78471 .52078 .79036 .52787 .80342 .52404 .79781 .51692 Metetra
.654 .753 .922 r
.79781 .51692 .80342 .52404 .81654 .52019 .81098 .51305 Metetra
.654 .753 .922 r
.81098 .51305 .81654 .52019 .82972 .51633 .8242 .50915 Metetra
.654 .753 .922 r
.8242 .50915 .82972 .51633 .84296 .51245 .83748 .50524 Metetra
.654 .753 .922 r
.83748 .50524 .84296 .51245 .85626 .50855 .85083 .5013 Metetra
.654 .753 .922 r
.85083 .5013 .85626 .50855 .86962 .50463 .86423 .49735 Metetra
.654 .753 .922 r
.86423 .49735 .86962 .50463 .88305 .5007 .8777 .49339 Metetra
.654 .753 .922 r
.8777 .49339 .88305 .5007 .89653 .49674 .89123 .4894 Metetra
.654 .753 .922 r
.89123 .4894 .89653 .49674 .91008 .49277 .90483 .48539 Metetra
.654 .753 .922 r
.90483 .48539 .91008 .49277 .92369 .48878 .91848 .48137 Metetra
.654 .753 .922 r
.91848 .48137 .92369 .48878 .93736 .48478 .9322 .47733 Metetra
.672 .757 .915 r
.32034 .64948 .32736 .65553 .33846 .65226 .3315 .64568 Metetra
.652 .737 .912 r
.3315 .64568 .33846 .65226 .34961 .64898 .34267 .64246 Metetra
.613 .729 .928 r
.34267 .64246 .34961 .64898 .36081 .64568 .35384 .64023 Metetra
.574 .753 .963 r
.35384 .64023 .36081 .64568 .37205 .64236 .36504 .63856 Metetra
.516 .796 .996 r
.36504 .63856 .37205 .64236 .38334 .63904 .37629 .63707 Metetra
.416 .819 .981 r
.37629 .63707 .38334 .63904 .39468 .6357 .3876 .63549 Metetra
.278 .777 .87 r
.3876 .63549 .39468 .6357 .40607 .63234 .39898 .63362 Metetra
.158 .695 .714 r
.39898 .63362 .40607 .63234 .4175 .62897 .41044 .63131 Metetra
.41044 .63131 .4175 .62897 .42899 .62559 .42197 .62847 Metetra
.42197 .62847 .42899 .62559 .44052 .62219 .43356 .62506 Metetra
.43356 .62506 .44052 .62219 .4521 .61878 .44522 .62108 Metetra
.298 .782 .708 r
.44522 .62108 .4521 .61878 .46374 .61535 .45693 .61655 Metetra
.468 .892 .849 r
.45693 .61655 .46374 .61535 .47542 .61191 .4687 .61155 Metetra
.623 .944 .95 r
.4687 .61155 .47542 .61191 .48715 .60845 .48051 .60614 Metetra
.708 .909 .966 r
.48051 .60614 .48715 .60845 .49893 .60498 .49236 .60043 Metetra
.73 .833 .928 r
.49236 .60043 .49893 .60498 .51077 .60149 .50425 .59451 Metetra
.724 .756 .878 r
.50425 .59451 .51077 .60149 .52265 .59799 .51617 .5885 Metetra
.708 .693 .834 r
.51617 .5885 .52265 .59799 .53459 .59448 .52813 .58249 Metetra
.691 .645 .799 r
.52813 .58249 .53459 .59448 .54658 .59094 .54012 .57659 Metetra
.675 .608 .772 r
.54012 .57659 .54658 .59094 .55862 .5874 .55215 .57089 Metetra
.661 .58 .753 r
.55215 .57089 .55862 .5874 .57071 .58383 .56423 .56547 Metetra
.65 .558 .738 r
.56423 .56547 .57071 .58383 .58286 .58025 .57634 .56041 Metetra
.64 .543 .729 r
.57634 .56041 .58286 .58025 .59506 .57666 .58851 .55576 Metetra
.631 .531 .723 r
.58851 .55576 .59506 .57666 .60731 .57305 .60074 .55156 Metetra
.624 .523 .72 r
.60074 .55156 .60731 .57305 .61962 .56942 .61303 .54783 Metetra
.617 .519 .721 r
.61303 .54783 .61962 .56942 .63198 .56578 .62538 .54457 Metetra
.611 .519 .725 r
.62538 .54457 .63198 .56578 .6444 .56212 .63781 .54177 Metetra
.607 .521 .732 r
.63781 .54177 .6444 .56212 .65687 .55845 .65032 .5394 Metetra
.602 .529 .744 r
.65032 .5394 .65687 .55845 .6694 .55476 .66291 .5374 Metetra
.599 .541 .761 r
.66291 .5374 .6694 .55476 .68198 .55105 .67559 .53572 Metetra
.595 .561 .785 r
.67559 .53572 .68198 .55105 .69462 .54733 .68834 .53428 Metetra
.592 .589 .818 r
.68834 .53428 .69462 .54733 .70732 .54358 .70119 .53298 Metetra
.586 .63 .862 r
.70119 .53298 .70732 .54358 .72007 .53983 .71411 .53172 Metetra
.574 .687 .917 r
.71411 .53172 .72007 .53983 .73288 .53605 .7271 .53039 Metetra
.544 .755 .975 r
.7271 .53039 .73288 .53605 .74575 .53226 .74017 .5289 Metetra
.475 .814 .999 r
.74017 .5289 .74575 .53226 .75868 .52845 .75329 .52712 Metetra
.353 .812 .932 r
.75329 .52712 .75868 .52845 .77166 .52463 .76646 .52496 Metetra
.218 .741 .783 r
.76646 .52496 .77166 .52463 .78471 .52078 .77967 .52232 Metetra
.77967 .52232 .78471 .52078 .79781 .51692 .79291 .51915 Metetra
.79291 .51915 .79781 .51692 .81098 .51305 .80617 .51539 Metetra
.80617 .51539 .81098 .51305 .8242 .50915 .81944 .51103 Metetra
.81944 .51103 .8242 .50915 .83748 .50524 .83271 .5061 Metetra
.387 .844 .783 r
.83271 .5061 .83748 .50524 .85083 .5013 .84599 .50067 Metetra
.552 .928 .913 r
.84599 .50067 .85083 .5013 .86423 .49735 .85929 .49489 Metetra
.662 .93 .971 r
.85929 .49489 .86423 .49735 .8777 .49339 .87262 .48894 Metetra
.699 .872 .963 r
.87262 .48894 .8777 .49339 .89123 .4894 .88601 .4831 Metetra
.693 .804 .934 r
.88601 .4831 .89123 .4894 .90483 .48539 .8995 .47772 Metetra
.667 .751 .914 r
.8995 .47772 .90483 .48539 .91848 .48137 .91315 .47326 Metetra
.637 .727 .913 r
.91315 .47326 .91848 .48137 .9322 .47733 .92699 .46982 Metetra
.668 .756 .917 r
.31327 .64338 .32034 .64948 .3315 .64568 .32446 .63968 Metetra
.665 .759 .921 r
.32446 .63968 .3315 .64568 .34267 .64246 .33568 .63604 Metetra
.561 .716 .945 r
.33568 .63604 .34267 .64246 .35384 .64023 .34682 .63488 Metetra
.443 .708 .979 r
.34682 .63488 .35384 .64023 .36504 .63856 .35795 .63511 Metetra
.268 .694 .966 r
.35795 .63511 .36504 .63856 .37629 .63707 .36913 .63591 Metetra
.04 .602 .8 r
.36913 .63591 .37629 .63707 .3876 .63549 .38039 .6366 Metetra
.129 0 0 r
.38039 .6366 .3876 .63549 .39898 .63362 .39175 .63668 Metetra
.192 0 0 r
.39175 .63668 .39898 .63362 .41044 .63131 .40321 .63581 Metetra
.183 0 0 r
.40321 .63581 .41044 .63131 .42197 .62847 .41478 .63376 Metetra
.122 0 0 r
.41478 .63376 .42197 .62847 .43356 .62506 .42644 .63042 Metetra
.008 0 0 r
.42644 .63042 .43356 .62506 .44522 .62108 .43818 .62579 Metetra
.43818 .62579 .44522 .62108 .45693 .61655 .45 .61992 Metetra
.436 .852 .693 r
.45 .61992 .45693 .61655 .4687 .61155 .46187 .61297 Metetra
.679 .978 .873 r
.46187 .61297 .4687 .61155 .48051 .60614 .47378 .6051 Metetra
.794 .952 .921 r
.47378 .6051 .48051 .60614 .49236 .60043 .48572 .59654 Metetra
.807 .859 .888 r
.48572 .59654 .49236 .60043 .50425 .59451 .49768 .58753 Metetra
.783 .768 .839 r
.49768 .58753 .50425 .59451 .51617 .5885 .50965 .57831 Metetra
.753 .697 .797 r
.50965 .57831 .51617 .5885 .52813 .58249 .52164 .56914 Metetra
.725 .642 .765 r
.52164 .56914 .52813 .58249 .54012 .57659 .53364 .56023 Metetra
.701 .601 .742 r
.53364 .56023 .54012 .57659 .55215 .57089 .54566 .5518 Metetra
.68 .57 .724 r
.54566 .5518 .55215 .57089 .56423 .56547 .5577 .54404 Metetra
.662 .545 .712 r
.5577 .54404 .56423 .56547 .57634 .56041 .56978 .53711 Metetra
.645 .526 .704 r
.56978 .53711 .57634 .56041 .58851 .55576 .5819 .53113 Metetra
.631 .511 .699 r
.5819 .53113 .58851 .55576 .60074 .55156 .59408 .52619 Metetra
.617 .5 .697 r
.59408 .52619 .60074 .55156 .61303 .54783 .60634 .52233 Metetra
.604 .491 .698 r
.60634 .52233 .61303 .54783 .62538 .54457 .61868 .51957 Metetra
.592 .486 .702 r
.61868 .51957 .62538 .54457 .63781 .54177 .63111 .51786 Metetra
.58 .484 .711 r
.63111 .51786 .63781 .54177 .65032 .5394 .64365 .51715 Metetra
.567 .486 .723 r
.64365 .51715 .65032 .5394 .66291 .5374 .6563 .51731 Metetra
.553 .493 .742 r
.6563 .51731 .66291 .5374 .67559 .53572 .66908 .51822 Metetra
.538 .506 .768 r
.66908 .51822 .67559 .53572 .68834 .53428 .68197 .51968 Metetra
.518 .528 .806 r
.68197 .51968 .68834 .53428 .70119 .53298 .69497 .5215 Metetra
.489 .564 .859 r
.69497 .5215 .70119 .53298 .71411 .53172 .70809 .52343 Metetra
.439 .617 .926 r
.70809 .52343 .71411 .53172 .7271 .53039 .7213 .52525 Metetra
.339 .674 .977 r
.7213 .52525 .7271 .53039 .74017 .5289 .7346 .52668 Metetra
.16 .667 .904 r
.7346 .52668 .74017 .5289 .75329 .52712 .74795 .52749 Metetra
.033 0 0 r
.74795 .52749 .75329 .52712 .76646 .52496 .76134 .52743 Metetra
.138 0 0 r
.76134 .52743 .76646 .52496 .77967 .52232 .77475 .5263 Metetra
.162 0 0 r
.77475 .5263 .77967 .52232 .79291 .51915 .78814 .52394 Metetra
.129 0 0 r
.78814 .52394 .79291 .51915 .80617 .51539 .8015 .52026 Metetra
.046 0 0 r
.8015 .52026 .80617 .51539 .81944 .51103 .8148 .51522 Metetra
.8148 .51522 .81944 .51103 .83271 .5061 .82805 .50891 Metetra
.82805 .50891 .83271 .5061 .84599 .50067 .84123 .50152 Metetra
.578 .939 .809 r
.84123 .50152 .84599 .50067 .85929 .49489 .85438 .49338 Metetra
.735 .975 .925 r
.85438 .49338 .85929 .49489 .87262 .48894 .86753 .48496 Metetra
.766 .907 .937 r
.86753 .48496 .87262 .48894 .88601 .4831 .88075 .47692 Metetra
.734 .823 .92 r
.88075 .47692 .88601 .4831 .8995 .47772 .89414 .47009 Metetra
.668 .755 .916 r
.89414 .47009 .8995 .47772 .91315 .47326 .90784 .46556 Metetra
.63 .738 .925 r
.90784 .46556 .91315 .47326 .92699 .46982 .92174 .46224 Metetra
.654 .753 .922 r
.30615 .63724 .31327 .64338 .32446 .63968 .31734 .63389 Metetra
.679 .771 .92 r
.31734 .63389 .32446 .63968 .33568 .63604 .32862 .62981 Metetra
.521 .709 .957 r
.32862 .62981 .33568 .63604 .34682 .63488 .33975 .62927 Metetra
.307 .635 .964 r
.33975 .62927 .34682 .63488 .35795 .63511 .35082 .63115 Metetra
.046 .537 .884 r
.35082 .63115 .35795 .63511 .36913 .63591 .36192 .63409 Metetra
.185 0 0 r
.36192 .63409 .36913 .63591 .38039 .6366 .37312 .63701 Metetra
.29 0 0 r
.37312 .63701 .38039 .6366 .39175 .63668 .38444 .63909 Metetra
.289 0 0 r
.38444 .63909 .39175 .63668 .40321 .63581 .3959 .63974 Metetra
.223 0 0 r
.3959 .63974 .40321 .63581 .41478 .63376 .4075 .63859 Metetra
.103 0 0 r
.4075 .63859 .41478 .63376 .42644 .63042 .41922 .63545 Metetra
.41922 .63545 .42644 .63042 .43818 .62579 .43105 .63029 Metetra
.43105 .63029 .43818 .62579 .45 .61992 .44297 .6232 Metetra
.608 .943 .76 r
.44297 .6232 .45 .61992 .46187 .61297 .45495 .6144 Metetra
.795 .996 .864 r
.45495 .6144 .46187 .61297 .47378 .6051 .46697 .60417 Metetra
.858 .942 .873 r
.46697 .60417 .47378 .6051 .48572 .59654 .47901 .59285 Metetra
.854 .857 .843 r
.47901 .59285 .48572 .59654 .49768 .58753 .49105 .58083 Metetra
.826 .778 .808 r
.49105 .58083 .49768 .58753 .50965 .57831 .50309 .5685 Metetra
.793 .714 .777 r
.50309 .5685 .50965 .57831 .52164 .56914 .51512 .55623 Metetra
.762 .663 .753 r
.51512 .55623 .52164 .56914 .53364 .56023 .52714 .54439 Metetra
.733 .622 .735 r
.52714 .54439 .53364 .56023 .54566 .5518 .53916 .5333 Metetra
.707 .589 .721 r
.53916 .5333 .54566 .5518 .5577 .54404 .55118 .52327 Metetra
.683 .561 .711 r
.55118 .52327 .5577 .54404 .56978 .53711 .56323 .51452 Metetra
.661 .539 .705 r
.56323 .51452 .56978 .53711 .5819 .53113 .57532 .50726 Metetra
.64 .52 .701 r
.57532 .50726 .5819 .53113 .59408 .52619 .58746 .50159 Metetra
.619 .504 .701 r
.58746 .50159 .59408 .52619 .60634 .52233 .59969 .49761 Metetra
.599 .491 .703 r
.59969 .49761 .60634 .52233 .61868 .51957 .61201 .49532 Metetra
.578 .481 .708 r
.61201 .49532 .61868 .51957 .63111 .51786 .62444 .49468 Metetra
.555 .473 .717 r
.62444 .49468 .63111 .51786 .64365 .51715 .63701 .49558 Metetra
.531 .468 .731 r
.63701 .49558 .64365 .51715 .6563 .51731 .64972 .49784 Metetra
.502 .467 .75 r
.64972 .49784 .6563 .51731 .66908 .51822 .66258 .50126 Metetra
.467 .47 .778 r
.66258 .50126 .66908 .51822 .68197 .51968 .67559 .50555 Metetra
.421 .48 .815 r
.67559 .50555 .68197 .51968 .69497 .5215 .68875 .5104 Metetra
.355 .498 .864 r
.68875 .5104 .69497 .5215 .70809 .52343 .70205 .51545 Metetra
.252 .521 .912 r
.70205 .51545 .70809 .52343 .7213 .52525 .71546 .52032 Metetra
.092 .527 .907 r
.71546 .52032 .7213 .52525 .7346 .52668 .72897 .52459 Metetra
0 .476 .768 r
.72897 .52459 .7346 .52668 .74795 .52749 .74255 .52789 Metetra
.21 0 0 r
.74255 .52789 .74795 .52749 .76134 .52743 .75614 .52983 Metetra
.234 0 0 r
.75614 .52983 .76134 .52743 .77475 .5263 .76973 .53009 Metetra
.193 0 0 r
.76973 .53009 .77475 .5263 .78814 .52394 .78326 .52842 Metetra
.1 0 0 r
.78326 .52842 .78814 .52394 .8015 .52026 .79671 .52468 Metetra
.79671 .52468 .8015 .52026 .8148 .51522 .81004 .51884 Metetra
.81004 .51884 .8148 .51522 .82805 .50891 .82325 .51105 Metetra
.54 .903 .705 r
.82325 .51105 .82805 .50891 .84123 .50152 .83634 .50164 Metetra
.746 .994 .845 r
.83634 .50164 .84123 .50152 .85438 .49338 .84935 .49115 Metetra
.825 .967 .895 r
.84935 .49115 .85438 .49338 .86753 .48496 .86234 .48038 Metetra
.815 .894 .899 r
.86234 .48038 .86753 .48496 .88075 .47692 .87542 .47037 Metetra
.758 .82 .902 r
.87542 .47037 .88075 .47692 .89414 .47009 .88875 .46251 Metetra
.65 .751 .923 r
.88875 .46251 .89414 .47009 .90784 .46556 .90256 .45851 Metetra
.645 .767 .937 r
.90256 .45851 .90784 .46556 .92174 .46224 .91644 .4546 Metetra
.654 .753 .922 r
.29897 .63105 .30615 .63724 .31734 .63389 .31019 .62767 Metetra
.674 .758 .914 r
.31019 .62767 .31734 .63389 .32862 .62981 .32149 .62371 Metetra
.508 .711 .963 r
.32149 .62371 .32862 .62981 .33975 .62927 .33263 .62329 Metetra
.192 .559 .934 r
.33263 .62329 .33975 .62927 .35082 .63115 .34365 .6265 Metetra
0 .383 .787 r
.34365 .6265 .35082 .63115 .36192 .63409 .35468 .6314 Metetra
.35 0 0 r
.35468 .6314 .36192 .63409 .37312 .63701 .36581 .63647 Metetra
.413 0 0 r
.36581 .63647 .37312 .63701 .38444 .63909 .37708 .64057 Metetra
.372 0 0 r
.37708 .64057 .38444 .63909 .3959 .63974 .38852 .64283 Metetra
.259 0 0 r
.38852 .64283 .3959 .63974 .4075 .63859 .40014 .64272 Metetra
.077 0 0 r
.40014 .64272 .4075 .63859 .41922 .63545 .41192 .63993 Metetra
.41192 .63993 .41922 .63545 .43105 .63029 .42383 .6344 Metetra
.48 .868 .672 r
.42383 .6344 .43105 .63029 .44297 .6232 .43585 .62625 Metetra
.732 .987 .798 r
.43585 .62625 .44297 .6232 .45495 .6144 .44795 .61577 Metetra
.861 .988 .842 r
.44795 .61577 .45495 .6144 .46697 .60417 .46008 .60333 Metetra
.895 .926 .833 r
.46008 .60333 .46697 .60417 .47901 .59285 .47223 .58941 Metetra
.884 .853 .807 r
.47223 .58941 .47901 .59285 .49105 .58083 .48437 .57454 Metetra
.856 .786 .781 r
.48437 .57454 .49105 .58083 .50309 .5685 .49648 .55922 Metetra
.825 .729 .759 r
.49648 .55922 .50309 .5685 .51512 .55623 .50857 .544 Metetra
.793 .682 .742 r
.50857 .544 .51512 .55623 .52714 .54439 .52062 .52935 Metetra
.762 .643 .729 r
.52062 .52935 .52714 .54439 .53916 .5333 .53266 .51573 Metetra
.733 .609 .719 r
.53266 .51573 .53916 .5333 .55118 .52327 .54468 .50352 Metetra
.705 .58 .712 r
.54468 .50352 .55118 .52327 .56323 .51452 .55671 .49304 Metetra
.677 .554 .708 r
.55671 .49304 .56323 .51452 .57532 .50726 .56876 .48454 Metetra
.65 .532 .706 r
.56876 .48454 .57532 .50726 .58746 .50159 .58088 .4782 Metetra
.622 .512 .707 r
.58088 .4782 .58746 .50159 .59969 .49761 .59307 .4741 Metetra
.593 .493 .71 r
.59307 .4741 .59969 .49761 .61201 .49532 .60538 .47226 Metetra
.562 .477 .717 r
.60538 .47226 .61201 .49532 .62444 .49468 .61781 .47263 Metetra
.527 .462 .726 r
.61781 .47263 .62444 .49468 .63701 .49558 .6304 .47506 Metetra
.487 .449 .74 r
.6304 .47506 .63701 .49558 .64972 .49784 .64316 .47933 Metetra
.439 .437 .76 r
.64316 .47933 .64972 .49784 .66258 .50126 .6561 .48514 Metetra
.377 .426 .785 r
.6561 .48514 .66258 .50126 .67559 .50555 .66922 .49214 Metetra
.294 .416 .815 r
.66922 .49214 .67559 .50555 .68875 .5104 .68252 .49989 Metetra
.179 .405 .844 r
.68252 .49989 .68875 .5104 .70205 .51545 .69598 .50791 Metetra
.02 .385 .846 r
.69598 .50791 .70205 .51545 .71546 .52032 .70958 .51567 Metetra
0 .344 .772 r
.70958 .51567 .71546 .52032 .72897 .52459 .72329 .52264 Metetra
.3 0 0 r
.72329 .52264 .72897 .52459 .74255 .52789 .73707 .52826 Metetra
.34 0 0 r
.73707 .52826 .74255 .52789 .75614 .52983 .75085 .53203 Metetra
.301 0 0 r
.75085 .53203 .75614 .52983 .76973 .53009 .7646 .53351 Metetra
.2 0 0 r
.7646 .53351 .76973 .53009 .78326 .52842 .77826 .53236 Metetra
.038 0 0 r
.77826 .53236 .78326 .52842 .79671 .52468 .79179 .5284 Metetra
.79179 .5284 .79671 .52468 .81004 .51884 .80514 .52161 Metetra
.482 .862 .65 r
.80514 .52161 .81004 .51884 .82325 .51105 .8183 .51224 Metetra
.726 .984 .784 r
.8183 .51224 .82325 .51105 .83634 .50164 .8313 .50076 Metetra
.85 .991 .845 r
.8313 .50076 .83634 .50164 .84935 .49115 .84417 .48797 Metetra
.873 .937 .859 r
.84417 .48797 .84935 .49115 .86234 .48038 .85701 .475 Metetra
.84 .871 .866 r
.85701 .475 .86234 .48038 .87542 .47037 .86998 .46334 Metetra
.767 .81 .887 r
.86998 .46334 .87542 .47037 .88875 .46251 .88331 .45492 Metetra
.644 .75 .926 r
.88331 .45492 .88875 .46251 .90256 .45851 .89719 .45107 Metetra
.654 .76 .928 r
.89719 .45107 .90256 .45851 .91644 .4546 .9111 .44689 Metetra
.654 .753 .922 r
.29173 .62481 .29897 .63105 .31019 .62767 .30298 .6214 Metetra
.662 .755 .919 r
.30298 .6214 .31019 .62767 .32149 .62371 .31429 .61777 Metetra
.529 .726 .964 r
.31429 .61777 .32149 .62371 .33263 .62329 .32548 .61691 Metetra
.118 .5 .906 r
.32548 .61691 .33263 .62329 .34365 .6265 .33646 .62104 Metetra
0 .26 .706 r
.33646 .62104 .34365 .6265 .35468 .6314 .34742 .62765 Metetra
.459 0 0 r
.34742 .62765 .35468 .6314 .36581 .63647 .35846 .63477 Metetra
.504 0 0 r
.35846 .63477 .36581 .63647 .37708 .64057 .36968 .64087 Metetra
.442 0 0 r
.36968 .64087 .37708 .64057 .38852 .64283 .38109 .64482 Metetra
.292 0 0 r
.38109 .64482 .38852 .64283 .40014 .64272 .39272 .64587 Metetra
.046 0 0 r
.39272 .64587 .40014 .64272 .41192 .63993 .40454 .64361 Metetra
.40454 .64361 .41192 .63993 .42383 .6344 .41653 .63792 Metetra
.606 .941 .755 r
.41653 .63792 .42383 .6344 .43585 .62625 .42865 .62893 Metetra
.812 1 .816 r
.42865 .62893 .43585 .62625 .44795 .61577 .44086 .61698 Metetra
.898 .97 .819 r
.44086 .61698 .44795 .61577 .46008 .60333 .45311 .60256 Metetra
.916 .91 .8 r
.45311 .60256 .46008 .60333 .47223 .58941 .46537 .58626 Metetra
.904 .848 .779 r
.46537 .58626 .47223 .58941 .48437 .57454 .47762 .56873 Metetra
.88 .792 .76 r
.47762 .56873 .48437 .57454 .49648 .55922 .48982 .55064 Metetra
.851 .744 .744 r
.48982 .55064 .49648 .55922 .50857 .544 .50198 .53265 Metetra
.821 .701 .733 r
.50198 .53265 .50857 .544 .52062 .52935 .51408 .51538 Metetra
.79 .664 .724 r
.51408 .51538 .52062 .52935 .53266 .51573 .52614 .49938 Metetra
.759 .631 .718 r
.52614 .49938 .53266 .51573 .54468 .50352 .53817 .48513 Metetra
.728 .6 .715 r
.53817 .48513 .54468 .50352 .55671 .49304 .55019 .47303 Metetra
.695 .573 .713 r
.55019 .47303 .55671 .49304 .56876 .48454 .56224 .46338 Metetra
.662 .547 .714 r
.56224 .46338 .56876 .48454 .58088 .4782 .57433 .45638 Metetra
.627 .523 .716 r
.57433 .45638 .58088 .4782 .59307 .4741 .5865 .45217 Metetra
.588 .499 .721 r
.5865 .45217 .59307 .4741 .60538 .47226 .59879 .45076 Metetra
.544 .475 .729 r
.59879 .45076 .60538 .47226 .61781 .47263 .61123 .45207 Metetra
.493 .452 .739 r
.61123 .45207 .61781 .47263 .6304 .47506 .62384 .45594 Metetra
.433 .427 .753 r
.62384 .45594 .6304 .47506 .64316 .47933 .63664 .46208 Metetra
.356 .399 .768 r
.63664 .46208 .64316 .47933 .6561 .48514 .64964 .47014 Metetra
.258 .368 .785 r
.64964 .47014 .6561 .48514 .66922 .49214 .66286 .47967 Metetra
.129 .329 .795 r
.66286 .47967 .66922 .49214 .68252 .49989 .67628 .49013 Metetra
0 .28 .783 r
.67628 .49013 .68252 .49989 .69598 .50791 .68989 .50091 Metetra
0 .222 .724 r
.68989 .50091 .69598 .50791 .70958 .51567 .70367 .51136 Metetra
0 .169 .611 r
.70367 .51136 .70958 .51567 .72329 .52264 .71755 .52079 Metetra
.444 0 0 r
.71755 .52079 .72329 .52264 .73707 .52826 .73151 .52852 Metetra
.429 0 0 r
.73151 .52852 .73707 .52826 .75085 .53203 .74546 .53389 Metetra
.341 0 0 r
.74546 .53389 .75085 .53203 .7646 .53351 .75936 .53637 Metetra
.18 0 0 r
.75936 .53637 .7646 .53351 .77826 .53236 .77312 .53552 Metetra
.77312 .53552 .77826 .53236 .79179 .5284 .78671 .53114 Metetra
.385 .812 .636 r
.78671 .53114 .79179 .5284 .80514 .52161 .80006 .52326 Metetra
.679 .967 .762 r
.80006 .52326 .80514 .52161 .8183 .51224 .81318 .5122 Metetra
.847 .998 .815 r
.81318 .5122 .8183 .51224 .8313 .50076 .82607 .49864 Metetra
.901 .957 .824 r
.82607 .49864 .8313 .50076 .84417 .48797 .83882 .48363 Metetra
.893 .899 .825 r
.83882 .48363 .84417 .48797 .85701 .475 .85154 .46868 Metetra
.85 .845 .838 r
.85154 .46868 .85701 .475 .86998 .46334 .86445 .45574 Metetra
.762 .794 .879 r
.86445 .45574 .86998 .46334 .88331 .45492 .87784 .44731 Metetra
.647 .753 .926 r
.87784 .44731 .88331 .45492 .89719 .45107 .89175 .44333 Metetra
.654 .753 .922 r
.89175 .44333 .89719 .45107 .9111 .44689 .90571 .43911 Metetra
.654 .753 .922 r
.28444 .61851 .29173 .62481 .30298 .6214 .29572 .61509 Metetra
.654 .753 .922 r
.29572 .61509 .30298 .6214 .31429 .61777 .30704 .61164 Metetra
.569 .735 .954 r
.30704 .61164 .31429 .61777 .32548 .61691 .3183 .6101 Metetra
.096 .473 .893 r
.3183 .6101 .32548 .61691 .33646 .62104 .32926 .61469 Metetra
0 .176 .654 r
.32926 .61469 .33646 .62104 .34742 .62765 .34015 .62272 Metetra
.526 0 0 r
.34015 .62272 .34742 .62765 .35846 .63477 .35111 .63173 Metetra
.567 0 0 r
.35111 .63173 .35846 .63477 .36968 .64087 .36225 .63978 Metetra
.5 0 0 r
.36225 .63978 .36968 .64087 .38109 .64482 .37362 .64547 Metetra
.322 0 0 r
.37362 .64547 .38109 .64482 .39272 .64587 .38524 .64782 Metetra
.011 0 0 r
.38524 .64782 .39272 .64587 .40454 .64361 .3971 .64628 Metetra
.387 .837 .736 r
.3971 .64628 .40454 .64361 .41653 .63792 .40915 .64065 Metetra
.703 .983 .819 r
.40915 .64065 .41653 .63792 .42865 .62893 .42137 .63108 Metetra
.861 .994 .823 r
.42137 .63108 .42865 .62893 .44086 .61698 .43368 .61793 Metetra
.918 .95 .8 r
.43368 .61793 .44086 .61698 .45311 .60256 .44606 .6018 Metetra
.928 .896 .776 r
.44606 .6018 .45311 .60256 .46537 .58626 .45845 .58339 Metetra
.918 .845 .756 r
.45845 .58339 .46537 .58626 .47762 .56873 .4708 .56348 Metetra
.898 .798 .742 r
.4708 .56348 .47762 .56873 .48982 .55064 .48311 .54288 Metetra
.873 .757 .732 r
.48311 .54288 .48982 .55064 .50198 .53265 .49534 .52237 Metetra
.845 .72 .725 r
.49534 .52237 .50198 .53265 .51408 .51538 .50751 .5027 Metetra
.816 .686 .721 r
.50751 .5027 .51408 .51538 .52614 .49938 .51961 .48451 Metetra
.785 .654 .719 r
.51961 .48451 .52614 .49938 .53817 .48513 .53166 .46839 Metetra
.751 .624 .719 r
.53166 .46839 .53817 .48513 .55019 .47303 .54369 .45479 Metetra
.715 .595 .721 r
.54369 .45479 .55019 .47303 .56224 .46338 .55573 .44408 Metetra
.676 .567 .724 r
.55573 .44408 .56224 .46338 .57433 .45638 .56781 .43649 Metetra
.632 .538 .73 r
.56781 .43649 .57433 .45638 .5865 .45217 .57997 .43218 Metetra
.582 .508 .737 r
.57997 .43218 .5865 .45217 .59879 .45076 .59225 .43115 Metetra
.522 .476 .746 r
.59225 .43115 .59879 .45076 .61123 .45207 .60469 .43333 Metetra
.45 .441 .756 r
.60469 .43333 .61123 .45207 .62384 .45594 .61731 .43851 Metetra
.361 .399 .766 r
.61731 .43851 .62384 .45594 .63664 .46208 .63015 .44637 Metetra
.246 .35 .772 r
.63015 .44637 .63664 .46208 .64964 .47014 .64321 .45649 Metetra
.101 .288 .767 r
.64321 .45649 .64964 .47014 .66286 .47967 .65652 .46833 Metetra
0 .215 .738 r
.65652 .46833 .66286 .47967 .67628 .49013 .67005 .48125 Metetra
0 .134 .672 r
.67005 .48125 .67628 .49013 .68989 .50091 .68379 .49454 Metetra
0 .065 .571 r
.68379 .49454 .68989 .50091 .70367 .51136 .69771 .50741 Metetra
.52 0 0 r
.69771 .50741 .70367 .51136 .71755 .52079 .71175 .51903 Metetra
.539 0 0 r
.71175 .51903 .71755 .52079 .73151 .52852 .72586 .52857 Metetra
.486 0 0 r
.72586 .52857 .73151 .52852 .74546 .53389 .73996 .53527 Metetra
.356 0 0 r
.73996 .53527 .74546 .53389 .75936 .53637 .75398 .53847 Metetra
.125 0 0 r
.75398 .53847 .75936 .53637 .77312 .53552 .76783 .53768 Metetra
.76783 .53768 .77312 .53552 .78671 .53114 .78145 .53267 Metetra
.589 .938 .776 r
.78145 .53267 .78671 .53114 .80006 .52326 .7948 .52353 Metetra
.818 1 .82 r
.7948 .52353 .80006 .52326 .81318 .5122 .80786 .5107 Metetra
.905 .967 .811 r
.80786 .5107 .81318 .5122 .82607 .49864 .82066 .49507 Metetra
.919 .912 .796 r
.82066 .49507 .82607 .49864 .83882 .48363 .8333 .478 Metetra
.898 .861 .796 r
.8333 .478 .83882 .48363 .85154 .46868 .84593 .46134 Metetra
.85 .819 .818 r
.84593 .46134 .85154 .46868 .86445 .45574 .85882 .44755 Metetra
.745 .775 .877 r
.85882 .44755 .86445 .45574 .87784 .44731 .87232 .43973 Metetra
.653 .758 .927 r
.87232 .43973 .87784 .44731 .89175 .44333 .88626 .43552 Metetra
.654 .753 .922 r
.88626 .43552 .89175 .44333 .90571 .43911 .90027 .43126 Metetra
.654 .753 .922 r
.27709 .61217 .28444 .61851 .29572 .61509 .28839 .60872 Metetra
.654 .753 .922 r
.28839 .60872 .29572 .61509 .30704 .61164 .29975 .60525 Metetra
.608 .74 .939 r
.29975 .60525 .30704 .61164 .3183 .6101 .31107 .60293 Metetra
.125 .48 .898 r
.31107 .60293 .3183 .6101 .32926 .61469 .32205 .60746 Metetra
0 .13 .631 r
.32205 .60746 .32926 .61469 .34015 .62272 .33288 .61655 Metetra
.561 .035 0 r
.33288 .61655 .34015 .62272 .35111 .63173 .34376 .62721 Metetra
.606 .054 0 r
.34376 .62721 .35111 .63173 .36225 .63978 .35482 .63713 Metetra
.541 0 0 r
.35482 .63713 .36225 .63978 .37362 .64547 .36613 .64458 Metetra
.348 0 0 r
.36613 .64458 .37362 .64547 .38524 .64782 .37773 .64835 Metetra
.37773 .64835 .38524 .64782 .3971 .64628 .3896 .64772 Metetra
.474 .895 .846 r
.3896 .64772 .3971 .64628 .40915 .64065 .40171 .64241 Metetra
.766 .995 .865 r
.40171 .64241 .40915 .64065 .42137 .63108 .41401 .63254 Metetra
.888 .977 .825 r
.41401 .63254 .42137 .63108 .43368 .61793 .42643 .61851 Metetra
.928 .931 .786 r
.42643 .61851 .43368 .61793 .44606 .6018 .43893 .601 Metetra
.936 .884 .758 r
.43893 .601 .44606 .6018 .45845 .58339 .45144 .5808 Metetra
.928 .842 .739 r
.45144 .5808 .45845 .58339 .4708 .56348 .46391 .55883 Metetra
.912 .804 .727 r
.46391 .55883 .4708 .56348 .48311 .54288 .47633 .53602 Metetra
.891 .77 .721 r
.47633 .53602 .48311 .54288 .49534 .52237 .48866 .51328 Metetra
.867 .738 .718 r
.48866 .51328 .49534 .52237 .50751 .5027 .50089 .49146 Metetra
.84 .708 .718 r
.50089 .49146 .50751 .5027 .51961 .48451 .51305 .47133 Metetra
.81 .68 .72 r
.51305 .47133 .51961 .48451 .53166 .46839 .52514 .45352 Metetra
.776 .651 .724 r
.52514 .45352 .53166 .46839 .54369 .45479 .53719 .43858 Metetra
.737 .622 .731 r
.53719 .43858 .54369 .45479 .55573 .44408 .54923 .42692 Metetra
.693 .592 .739 r
.54923 .42692 .55573 .44408 .56781 .43649 .56131 .4188 Metetra
.639 .559 .748 r
.56131 .4188 .56781 .43649 .57997 .43218 .57347 .41439 Metetra
.575 .522 .759 r
.57347 .41439 .57997 .43218 .59225 .43115 .58575 .41371 Metetra
.495 .48 .769 r
.58575 .41371 .59225 .43115 .60469 .43333 .59819 .41666 Metetra
.393 .427 .778 r
.59819 .41666 .60469 .43333 .61731 .43851 .61083 .42301 Metetra
.262 .362 .778 r
.61083 .42301 .61731 .43851 .63015 .44637 .6237 .43241 Metetra
.098 .281 .761 r
.6237 .43241 .63015 .44637 .64321 .45649 .63681 .44436 Metetra
0 .183 .715 r
.63681 .44436 .64321 .45649 .65652 .46833 .65019 .45826 Metetra
0 .08 .634 r
.65019 .45826 .65652 .46833 .67005 .48125 .66381 .47337 Metetra
0 0 .528 r
.66381 .47337 .67005 .48125 .68379 .49454 .67766 .48886 Metetra
.57 .061 0 r
.67766 .48886 .68379 .49454 .69771 .50741 .69171 .50382 Metetra
.614 .07 0 r
.69171 .50382 .69771 .50741 .71175 .51903 .70588 .51729 Metetra
.598 .029 0 r
.70588 .51729 .71175 .51903 .72586 .52857 .72013 .52832 Metetra
.517 0 0 r
.72013 .52832 .72586 .52857 .73996 .53527 .73435 .53601 Metetra
.343 0 0 r
.73435 .53601 .73996 .53527 .75398 .53847 .74846 .53962 Metetra
.022 0 0 r
.74846 .53962 .75398 .53847 .76783 .53768 .76237 .53862 Metetra
.418 .863 .799 r
.76237 .53862 .76783 .53768 .78145 .53267 .77602 .53277 Metetra
.751 .994 .858 r
.77602 .53277 .78145 .53267 .7948 .52353 .78934 .52222 Metetra
.889 .975 .827 r
.78934 .52222 .7948 .52353 .80786 .5107 .80234 .50757 Metetra
.925 .919 .79 r
.80234 .50757 .80786 .5107 .82066 .49507 .81505 .48993 Metetra
.92 .868 .77 r
.81505 .48993 .82066 .49507 .8333 .478 .8276 .47097 Metetra
.894 .827 .773 r
.8276 .47097 .8333 .478 .84593 .46134 .84017 .45295 Metetra
.842 .795 .805 r
.84017 .45295 .84593 .46134 .85882 .44755 .85308 .43881 Metetra
.721 .754 .878 r
.85308 .43881 .85882 .44755 .87232 .43973 .86674 .43192 Metetra
.654 .754 .923 r
.86674 .43192 .87232 .43973 .88626 .43552 .88073 .42764 Metetra
.654 .753 .922 r
.88073 .42764 .88626 .43552 .90027 .43126 .89478 .42335 Metetra
.654 .753 .922 r
.26968 .60578 .27709 .61217 .28839 .60872 .28101 .6023 Metetra
.654 .753 .922 r
.28101 .6023 .28839 .60872 .29975 .60525 .29239 .5988 Metetra
.647 .751 .925 r
.29239 .5988 .29975 .60525 .31107 .60293 .30381 .59549 Metetra
.202 .519 .917 r
.30381 .59549 .31107 .60293 .32205 .60746 .31484 .59939 Metetra
0 .116 .635 r
.31484 .59939 .32205 .60746 .33288 .61655 .32562 .60911 Metetra
.571 .073 0 r
.32562 .60911 .33288 .61655 .34376 .62721 .33642 .62115 Metetra
.624 .098 0 r
.33642 .62115 .34376 .62721 .35482 .63713 .34739 .63281 Metetra
.565 .004 0 r
.34739 .63281 .35482 .63713 .36613 .64458 .35864 .64201 Metetra
.365 0 0 r
.35864 .64201 .36613 .64458 .37773 .64835 .3702 .64729 Metetra
.052 .613 .797 r
.3702 .64729 .37773 .64835 .3896 .64772 .38207 .64776 Metetra
.534 .916 .93 r
.38207 .64776 .3896 .64772 .40171 .64241 .39421 .64303 Metetra
.799 .985 .894 r
.39421 .64303 .40171 .64241 .41401 .63254 .40658 .63316 Metetra
.899 .956 .826 r
.40658 .63316 .41401 .63254 .42643 .61851 .4191 .61861 Metetra
.932 .913 .777 r
.4191 .61861 .42643 .61851 .43893 .601 .43171 .60006 Metetra
.939 .874 .745 r
.43171 .60006 .43893 .601 .45144 .5808 .44435 .57845 Metetra
.934 .839 .726 r
.44435 .57845 .45144 .5808 .46391 .55883 .45695 .55479 Metetra
.923 .809 .716 r
.45695 .55479 .46391 .55883 .47633 .53602 .46947 .53012 Metetra
.907 .782 .712 r
.46947 .53012 .47633 .53602 .48866 .51328 .4819 .50547 Metetra
.887 .756 .712 r
.4819 .50547 .48866 .51328 .50089 .49146 .49423 .48181 Metetra
.864 .732 .715 r
.49423 .48181 .50089 .49146 .51305 .47133 .50645 .45998 Metetra
.836 .707 .722 r
.50645 .45998 .51305 .47133 .52514 .45352 .51859 .44071 Metetra
.802 .682 .731 r
.51859 .44071 .52514 .45352 .53719 .43858 .53067 .4246 Metetra
.762 .654 .743 r
.53067 .4246 .53719 .43858 .54923 .42692 .54274 .41209 Metetra
.712 .624 .757 r
.54274 .41209 .54923 .42692 .56131 .4188 .55483 .40351 Metetra
.649 .588 .773 r
.55483 .40351 .56131 .4188 .57347 .41439 .56699 .39901 Metetra
.566 .543 .789 r
.56699 .39901 .57347 .41439 .58575 .41371 .57928 .39863 Metetra
.456 .486 .801 r
.57928 .39863 .58575 .41371 .59819 .41666 .59173 .40225 Metetra
.311 .409 .801 r
.59173 .40225 .59819 .41666 .61083 .42301 .60438 .40963 Metetra
.123 .308 .778 r
.60438 .40963 .61083 .42301 .6237 .43241 .61728 .42036 Metetra
0 .185 .717 r
.61728 .42036 .6237 .43241 .63681 .44436 .63043 .4339 Metetra
0 .056 .615 r
.63043 .4339 .63681 .44436 .65019 .45826 .64387 .44956 Metetra
0 0 .495 r
.64387 .44956 .65019 .45826 .66381 .47337 .65757 .46653 Metetra
.607 .123 0 r
.65757 .46653 .66381 .47337 .67766 .48886 .67151 .48388 Metetra
.665 .151 0 r
.67151 .48388 .67766 .48886 .69171 .50382 .68566 .50056 Metetra
.673 .136 0 r
.68566 .50056 .69171 .50382 .70588 .51729 .69994 .51551 Metetra
.632 .072 0 r
.69994 .51551 .70588 .51729 .72013 .52832 .71429 .52764 Metetra
.525 0 0 r
.71429 .52764 .72013 .52832 .73435 .53601 .7286 .53597 Metetra
.295 0 0 r
.7286 .53597 .73435 .53601 .74846 .53962 .74279 .53966 Metetra
.133 .681 .77 r
.74279 .53966 .74846 .53962 .76237 .53862 .75674 .53816 Metetra
.605 .95 .91 r
.75674 .53816 .76237 .53862 .77602 .53277 .77039 .53124 Metetra
.841 .979 .874 r
.77039 .53124 .77602 .53277 .78934 .52222 .78368 .51915 Metetra
.913 .925 .809 r
.78368 .51915 .78934 .52222 .80234 .50757 .79661 .50266 Metetra
.925 .871 .766 r
.79661 .50266 .80234 .50757 .81505 .48993 .80925 .48312 Metetra
.913 .829 .749 r
.80925 .48312 .81505 .48993 .8276 .47097 .82172 .46252 Metetra
.886 .797 .757 r
.82172 .46252 .8276 .47097 .84017 .45295 .83427 .44354 Metetra
.828 .772 .798 r
.83427 .44354 .84017 .45295 .85308 .43881 .84727 .42962 Metetra
.689 .732 .883 r
.84727 .42962 .85308 .43881 .86674 .43192 .86111 .42401 Metetra
.654 .753 .922 r
.86111 .42401 .86674 .43192 .88073 .42764 .87514 .41969 Metetra
.654 .753 .922 r
.87514 .41969 .88073 .42764 .89478 .42335 .88925 .41536 Metetra
.654 .753 .922 r
.26221 .59934 .26968 .60578 .28101 .6023 .27357 .59583 Metetra
.654 .753 .922 r
.27357 .59583 .28101 .6023 .29239 .5988 .28498 .5923 Metetra
.654 .753 .922 r
.28498 .5923 .29239 .5988 .30381 .59549 .29645 .58876 Metetra
.348 .625 .956 r
.29645 .58876 .30381 .59549 .31484 .59939 .30761 .59059 Metetra
0 .133 .661 r
.30761 .59059 .31484 .59939 .32562 .60911 .31838 .60046 Metetra
.56 .089 0 r
.31838 .60046 .32562 .60911 .33642 .62115 .32911 .61356 Metetra
.624 .128 0 r
.32911 .61356 .33642 .62115 .34739 .63281 .33999 .62676 Metetra
.572 .041 0 r
.33999 .62676 .34739 .63281 .35864 .64201 .35115 .63765 Metetra
.371 0 0 r
.35115 .63765 .35864 .64201 .3702 .64729 .36266 .64451 Metetra
.066 .593 .87 r
.36266 .64451 .3702 .64729 .38207 .64776 .37451 .64624 Metetra
.559 .898 .981 r
.37451 .64624 .38207 .64776 .39421 .64303 .38667 .64234 Metetra
.809 .958 .911 r
.38667 .64234 .39421 .64303 .40658 .63316 .3991 .63282 Metetra
.899 .933 .828 r
.3991 .63282 .40658 .63316 .4191 .61861 .41171 .61809 Metetra
.931 .897 .772 r
.41171 .61809 .4191 .61861 .43171 .60006 .42442 .59892 Metetra
.94 .865 .737 r
.42442 .59892 .43171 .60006 .44435 .57845 .43717 .5763 Metetra
.939 .838 .717 r
.43717 .5763 .44435 .57845 .45695 .55479 .44989 .55133 Metetra
.932 .815 .707 r
.44989 .55133 .45695 .55479 .46947 .53012 .46254 .52519 Metetra
.92 .794 .704 r
.46254 .52519 .46947 .53012 .4819 .50547 .47508 .499 Metetra
.905 .774 .707 r
.47508 .499 .4819 .50547 .49423 .48181 .4875 .47381 Metetra
.886 .756 .713 r
.4875 .47381 .49423 .48181 .50645 .45998 .4998 .45057 Metetra
.861 .737 .724 r
.4998 .45057 .50645 .45998 .51859 .44071 .512 .43007 Metetra
.83 .716 .739 r
.512 .43007 .51859 .44071 .53067 .4246 .52413 .41296 Metetra
.789 .693 .758 r
.52413 .41296 .53067 .4246 .54274 .41209 .53623 .39974 Metetra
.735 .664 .781 r
.53623 .39974 .54274 .41209 .55483 .40351 .54834 .39075 Metetra
.66 .627 .806 r
.54834 .39075 .55483 .40351 .56699 .39901 .56052 .38618 Metetra
.553 .573 .829 r
.56052 .38618 .56699 .39901 .57928 .39863 .57282 .38605 Metetra
.4 .494 .84 r
.57282 .38605 .57928 .39863 .59173 .40225 .58528 .39024 Metetra
.189 .378 .82 r
.58528 .39024 .59173 .40225 .60438 .40963 .59795 .39847 Metetra
0 .226 .746 r
.59795 .39847 .60438 .40963 .61728 .42036 .61087 .41031 Metetra
0 .064 .619 r
.61087 .41031 .61728 .42036 .63043 .4339 .62407 .42517 Metetra
0 0 .475 r
.62407 .42517 .63043 .4339 .64387 .44956 .63755 .44229 Metetra
.636 .161 0 r
.63755 .44229 .64387 .44956 .65757 .46653 .65131 .46077 Metetra
.701 .206 0 r
.65131 .46077 .65757 .46653 .67151 .48388 .66533 .47959 Metetra
.722 .211 0 r
.66533 .47959 .67151 .48388 .68566 .50056 .67956 .49759 Metetra
.707 .178 0 r
.67956 .49759 .68566 .50056 .69994 .51551 .69393 .5136 Metetra
.648 .093 0 r
.69393 .5136 .69994 .51551 .71429 .52764 .70835 .52643 Metetra
.511 0 0 r
.70835 .52643 .71429 .52764 .7286 .53597 .72273 .535 Metetra
.204 0 0 r
.72273 .535 .7286 .53597 .74279 .53966 .73696 .53843 Metetra
.325 .8 .912 r
.73696 .53843 .74279 .53966 .75674 .53816 .75093 .53613 Metetra
.732 .96 .942 r
.75093 .53613 .75674 .53816 .77039 .53124 .76456 .52795 Metetra
.877 .93 .853 r
.76456 .52795 .77039 .53124 .78368 .51915 .77781 .51422 Metetra
.915 .874 .783 r
.77781 .51422 .78368 .51915 .79661 .50266 .79068 .49592 Metetra
.917 .829 .744 r
.79068 .49592 .79661 .50266 .80925 .48312 .80325 .47463 Metetra
.903 .796 .732 r
.80325 .47463 .80925 .48312 .82172 .46252 .81568 .4527 Metetra
.874 .772 .746 r
.81568 .4527 .82172 .46252 .83427 .44354 .82825 .43322 Metetra
.806 .75 .8 r
.82825 .43322 .83427 .44354 .84727 .42962 .84141 .42036 Metetra
.655 .718 .895 r
.84141 .42036 .84727 .42962 .86111 .42401 .85542 .41603 Metetra
.654 .753 .922 r
.85542 .41603 .86111 .42401 .87514 .41969 .86951 .41167 Metetra
.654 .753 .922 r
.86951 .41167 .87514 .41969 .88925 .41536 .88366 .4073 Metetra
.654 .753 .922 r
.25468 .59285 .26221 .59934 .27357 .59583 .26607 .58931 Metetra
.654 .753 .922 r
.26607 .58931 .27357 .59583 .28498 .5923 .27751 .58575 Metetra
.654 .753 .922 r
.27751 .58575 .28498 .5923 .29645 .58876 .28901 .58218 Metetra
.536 .716 .955 r
.28901 .58218 .29645 .58876 .30761 .59059 .30037 .58123 Metetra
0 .179 .706 r
.30037 .58123 .30761 .59059 .31838 .60046 .31115 .59071 Metetra
0 0 .457 r
.31115 .59071 .31838 .60046 .32911 .61356 .32182 .60449 Metetra
.61 .144 0 r
.32182 .60449 .32911 .61356 .33999 .62676 .33261 .61898 Metetra
.564 .07 0 r
.33261 .61898 .33999 .62676 .35115 .63765 .34369 .63146 Metetra
0 .153 .621 r
.34369 .63146 .35115 .63765 .36266 .64451 .35512 .63992 Metetra
.065 .541 .895 r
.35512 .63992 .36266 .64451 .37451 .64624 .36694 .64307 Metetra
.551 .847 .998 r
.36694 .64307 .37451 .64624 .38667 .64234 .3791 .64024 Metetra
.799 .921 .919 r
.3791 .64024 .38667 .64234 .3991 .63282 .39157 .63136 Metetra
.892 .908 .83 r
.39157 .63136 .3991 .63282 .41171 .61809 .40424 .61684 Metetra
.926 .881 .77 r
.40424 .61684 .41171 .61809 .42442 .59892 .41705 .59746 Metetra
.939 .857 .733 r
.41705 .59746 .42442 .59892 .43717 .5763 .42991 .57425 Metetra
.942 .837 .712 r
.42991 .57425 .43717 .5763 .44989 .55133 .44275 .54841 Metetra
.938 .82 .701 r
.44275 .54841 .44989 .55133 .46254 .52519 .45552 .5212 Metetra
.931 .805 .699 r
.45552 .5212 .46254 .52519 .47508 .499 .46817 .49384 Metetra
.92 .792 .702 r
.46817 .49384 .47508 .499 .4875 .47381 .48069 .46748 Metetra
.905 .78 .712 r
.48069 .46748 .4875 .47381 .4998 .45057 .49308 .44312 Metetra
.885 .767 .727 r
.49308 .44312 .4998 .45057 .512 .43007 .50536 .42164 Metetra
.858 .754 .748 r
.50536 .42164 .512 .43007 .52413 .41296 .51755 .40373 Metetra
.819 .738 .775 r
.51755 .40373 .52413 .41296 .53623 .39974 .52969 .38994 Metetra
.761 .715 .809 r
.52969 .38994 .53623 .39974 .54834 .39075 .54184 .38062 Metetra
.672 .679 .848 r
.54184 .38062 .54834 .39075 .56052 .38618 .55405 .37597 Metetra
.53 .615 .882 r
.55405 .37597 .56052 .38618 .57282 .38605 .56636 .37604 Metetra
.309 .5 .883 r
.56636 .37604 .57282 .38605 .58528 .39024 .57884 .38068 Metetra
.009 .322 .809 r
.57884 .38068 .58528 .39024 .59795 .39847 .59153 .38959 Metetra
0 .113 .652 r
.59153 .38959 .59795 .39847 .61087 .41031 .60448 .40232 Metetra
0 0 .471 r
.60448 .40232 .61087 .41031 .62407 .42517 .61771 .41821 Metetra
.657 .176 0 r
.61771 .41821 .62407 .42517 .63755 .44229 .63123 .43645 Metetra
.727 .238 0 r
.63123 .43645 .63755 .44229 .65131 .46077 .64504 .45607 Metetra
.756 .26 0 r
.64504 .45607 .65131 .46077 .66533 .47959 .65911 .47594 Metetra
.755 .248 0 r
.65911 .47594 .66533 .47959 .67956 .49759 .6734 .49483 Metetra
.725 .2 0 r
.6734 .49483 .67956 .49759 .69393 .5136 .68782 .51146 Metetra
.648 .094 0 r
.68782 .51146 .69393 .5136 .70835 .52643 .7023 .52457 Metetra
.469 0 0 r
.7023 .52457 .70835 .52643 .72273 .535 .71672 .53298 Metetra
0 .508 .779 r
.71672 .53298 .72273 .535 .73696 .53843 .73097 .53579 Metetra
.503 .865 .987 r
.73097 .53579 .73696 .53843 .75093 .53613 .74494 .53243 Metetra
.798 .922 .92 r
.74494 .53243 .75093 .53613 .76456 .52795 .75855 .5228 Metetra
.886 .875 .821 r
.75855 .5228 .76456 .52795 .77781 .51422 .77175 .50737 Metetra
.907 .828 .757 r
.77175 .50737 .77781 .51422 .79068 .49592 .78456 .48732 Metetra
.906 .793 .726 r
.78456 .48732 .79068 .49592 .80325 .47463 .79707 .46451 Metetra
.892 .768 .719 r
.79707 .46451 .80325 .47463 .81568 .4527 .80949 .44161 Metetra
.861 .75 .74 r
.80949 .44161 .81568 .4527 .82825 .43322 .82212 .42213 Metetra
.756 .72 .819 r
.82212 .42213 .82825 .43322 .84141 .42036 .83562 .41235 Metetra
.654 .753 .922 r
.83562 .41235 .84141 .42036 .85542 .41603 .84969 .40797 Metetra
.654 .753 .922 r
.84969 .40797 .85542 .41603 .86951 .41167 .86382 .40358 Metetra
.654 .753 .922 r
.86382 .40358 .86951 .41167 .88366 .4073 .87803 .39917 Metetra
.654 .753 .922 r
.24709 .5863 .25468 .59285 .26607 .58931 .25851 .58273 Metetra
.654 .753 .922 r
.25851 .58273 .26607 .58931 .27751 .58575 .26998 .57915 Metetra
.654 .753 .922 r
.26998 .57915 .27751 .58575 .28901 .58218 .2815 .57555 Metetra
.654 .753 .922 r
.2815 .57555 .28901 .58218 .30037 .58123 .29308 .57193 Metetra
0 .272 .775 r
.29308 .57193 .30037 .58123 .31115 .59071 .30394 .58004 Metetra
0 0 .491 r
.30394 .58004 .31115 .59071 .32182 .60449 .31456 .59405 Metetra
.585 .149 0 r
.31456 .59405 .32182 .60449 .33261 .61898 .32528 .60955 Metetra
0 0 .447 r
.32528 .60955 .33261 .61898 .34369 .63146 .33626 .62346 Metetra
0 .112 .625 r
.33626 .62346 .34369 .63146 .35512 .63992 .34761 .6335 Metetra
.05 .471 .884 r
.34761 .6335 .35512 .63992 .36694 .64307 .35937 .63816 Metetra
.519 .778 .991 r
.35937 .63816 .36694 .64307 .3791 .64024 .37152 .63662 Metetra
.775 .876 .921 r
.37152 .63662 .3791 .64024 .39157 .63136 .384 .6287 Metetra
.877 .881 .834 r
.384 .6287 .39157 .63136 .40424 .61684 .39672 .61476 Metetra
.918 .866 .772 r
.39672 .61476 .40424 .61684 .41705 .59746 .40961 .59557 Metetra
.936 .85 .733 r
.40961 .59557 .41705 .59746 .42991 .57425 .42257 .57221 Metetra
.942 .836 .71 r
.42257 .57221 .42991 .57425 .44275 .54841 .43552 .54595 Metetra
.943 .825 .698 r
.43552 .54595 .44275 .54841 .45552 .5212 .44841 .5181 Metetra
.94 .816 .695 r
.44841 .5181 .45552 .5212 .46817 .49384 .46117 .48997 Metetra
.933 .809 .699 r
.46117 .48997 .46817 .49384 .48069 .46748 .4738 .46278 Metetra
.923 .804 .71 r
.4738 .46278 .48069 .46748 .49308 .44312 .48629 .43762 Metetra
.908 .799 .728 r
.48629 .43762 .49308 .44312 .50536 .42164 .49865 .41541 Metetra
.885 .795 .756 r
.49865 .41541 .50536 .42164 .51755 .40373 .51091 .39691 Metetra
.849 .789 .793 r
.51091 .39691 .51755 .40373 .52969 .38994 .52311 .38267 Metetra
.789 .778 .843 r
.52311 .38267 .52969 .38994 .54184 .38062 .5353 .3731 Metetra
.682 .747 .901 r
.5353 .3731 .54184 .38062 .55405 .37597 .54755 .3684 Metetra
.485 .667 .944 r
.54755 .3684 .55405 .37597 .56636 .37604 .55989 .3686 Metetra
.158 .489 .903 r
.55989 .3686 .56636 .37604 .57884 .38068 .5724 .37357 Metetra
0 .224 .723 r
.5724 .37357 .57884 .38068 .59153 .38959 .58511 .38299 Metetra
.508 .013 0 r
.58511 .38299 .59153 .38959 .60448 .40232 .59808 .39636 Metetra
.665 .164 0 r
.59808 .39636 .60448 .40232 .61771 .41821 .61134 .41298 Metetra
.742 .247 0 r
.61134 .41298 .61771 .41821 .63123 .43645 .62489 .43199 Metetra
.777 .285 0 r
.62489 .43199 .63123 .43645 .64504 .45607 .63873 .45235 Metetra
.786 .292 0 r
.63873 .45235 .64504 .45607 .65911 .47594 .65284 .47285 Metetra
.772 .268 0 r
.65284 .47285 .65911 .47594 .6734 .49483 .66717 .49219 Metetra
.73 .206 0 r
.66717 .49219 .6734 .49483 .68782 .51146 .68164 .50899 Metetra
.631 .075 0 r
.68164 .50899 .68782 .51146 .7023 .52457 .69614 .52193 Metetra
.391 0 0 r
.69614 .52193 .7023 .52457 .71672 .53298 .71058 .52979 Metetra
.126 .624 .907 r
.71058 .52979 .71672 .53298 .73097 .53579 .72482 .53165 Metetra
.63 .87 .987 r
.72482 .53165 .73097 .53579 .74494 .53243 .73877 .52697 Metetra
.825 .87 .879 r
.73877 .52697 .74494 .53243 .75855 .5228 .75234 .51574 Metetra
.882 .827 .789 r
.75234 .51574 .75855 .5228 .77175 .50737 .76549 .49861 Metetra
.897 .791 .736 r
.76549 .49861 .77175 .50737 .78456 .48732 .77825 .47693 Metetra
.894 .765 .711 r
.77825 .47693 .78456 .48732 .79707 .46451 .79073 .45286 Metetra
.88 .746 .71 r
.79073 .45286 .79707 .46451 .80949 .44161 .80317 .42941 Metetra
.845 .732 .738 r
.80317 .42941 .80949 .44161 .82212 .42213 .81591 .4105 Metetra
.69 .684 .84 r
.81591 .4105 .82212 .42213 .83562 .41235 .82979 .40426 Metetra
.654 .753 .922 r
.82979 .40426 .83562 .41235 .84969 .40797 .8439 .39985 Metetra
.654 .753 .922 r
.8439 .39985 .84969 .40797 .86382 .40358 .85809 .39542 Metetra
.654 .753 .922 r
.85809 .39542 .86382 .40358 .87803 .39917 .87234 .39097 Metetra
.654 .753 .922 r
.23944 .5797 .24709 .5863 .25851 .58273 .25089 .5761 Metetra
.654 .753 .922 r
.25089 .5761 .25851 .58273 .26998 .57915 .26239 .57249 Metetra
.654 .753 .922 r
.26239 .57249 .26998 .57915 .2815 .57555 .27394 .56886 Metetra
.654 .753 .922 r
.27394 .56886 .2815 .57555 .29308 .57193 .28555 .56522 Metetra
.183 .541 .927 r
.28555 .56522 .29308 .57193 .30394 .58004 .29672 .56865 Metetra
0 0 .536 r
.29672 .56865 .30394 .58004 .31456 .59405 .30734 .58242 Metetra
0 0 .422 r
.30734 .58242 .31456 .59405 .32528 .60955 .31798 .59858 Metetra
0 0 .457 r
.31798 .59858 .32528 .60955 .33626 .62346 .32887 .61371 Metetra
0 .076 .617 r
.32887 .61371 .33626 .62346 .34761 .6335 .34013 .62526 Metetra
.027 .397 .853 r
.34013 .62526 .34761 .6335 .35937 .63816 .35182 .63149 Metetra
.471 .7 .968 r
.35182 .63149 .35937 .63816 .37152 .63662 .36393 .63142 Metetra
.739 .827 .919 r
.36393 .63142 .37152 .63662 .384 .6287 .3764 .62473 Metetra
.856 .853 .838 r
.3764 .62473 .384 .6287 .39672 .61476 .38916 .61172 Metetra
.907 .851 .777 r
.38916 .61172 .39672 .61476 .40961 .59557 .40211 .59314 Metetra
.93 .843 .736 r
.40211 .59314 .40961 .59557 .42257 .57221 .41515 .57008 Metetra
.941 .836 .711 r
.41515 .57008 .42257 .57221 .43552 .54595 .4282 .54382 Metetra
.946 .83 .698 r
.4282 .54382 .43552 .54595 .44841 .5181 .4412 .51577 Metetra
.947 .827 .693 r
.4412 .51577 .44841 .5181 .46117 .48997 .45407 .48728 Metetra
.944 .826 .697 r
.45407 .48728 .46117 .48997 .4738 .46278 .46681 .45964 Metetra
.938 .827 .709 r
.46681 .45964 .4738 .46278 .48629 .43762 .4794 .43399 Metetra
.928 .831 .73 r
.4794 .43399 .48629 .43762 .49865 .41541 .49185 .41132 Metetra
.909 .838 .762 r
.49185 .41132 .49865 .41541 .51091 .39691 .50419 .39242 Metetra
.877 .846 .81 r
.50419 .39242 .51091 .39691 .52311 .38267 .51646 .37789 Metetra
.814 .851 .877 r
.51646 .37789 .52311 .38267 .5353 .3731 .52872 .36814 Metetra
.679 .83 .956 r
.52872 .36814 .5353 .3731 .54755 .3684 .54101 .36339 Metetra
.39 .714 .987 r
.54101 .36339 .54755 .3684 .55989 .3686 .55339 .36368 Metetra
0 .425 .832 r
.55339 .36368 .55989 .3686 .5724 .37357 .56593 .36886 Metetra
.446 0 0 r
.56593 .36886 .5724 .37357 .58511 .38299 .57867 .37859 Metetra
.648 .115 0 r
.57867 .37859 .58511 .38299 .59808 .39636 .59167 .39235 Metetra
.742 .231 0 r
.59167 .39235 .59808 .39636 .61134 .41298 .60494 .40939 Metetra
.785 .289 0 r
.60494 .40939 .61134 .41298 .62489 .43199 .61852 .42882 Metetra
.802 .312 0 r
.61852 .42882 .62489 .43199 .63873 .45235 .63239 .44952 Metetra
.8 .308 0 r
.63239 .44952 .63873 .45235 .65284 .47285 .64653 .47022 Metetra
.778 .274 0 r
.64653 .47022 .65284 .47285 .66717 .49219 .66087 .48955 Metetra
.723 .197 0 r
.66087 .48955 .66717 .49219 .68164 .50899 .67535 .50607 Metetra
.593 .034 0 r
.67535 .50607 .68164 .50899 .69614 .52193 .68986 .51841 Metetra
0 .297 .682 r
.68986 .51841 .69614 .52193 .71058 .52979 .70429 .52533 Metetra
.319 .71 .98 r
.70429 .52533 .71058 .52979 .72482 .53165 .71852 .52592 Metetra
.705 .842 .948 r
.71852 .52592 .72482 .53165 .73877 .52697 .73243 .51971 Metetra
.835 .823 .837 r
.73243 .51971 .73877 .52697 .75234 .51574 .74595 .50679 Metetra
.875 .788 .761 r
.74595 .50679 .75234 .51574 .76549 .49861 .75905 .48798 Metetra
.886 .761 .719 r
.75905 .48798 .76549 .49861 .77825 .47693 .77177 .46486 Metetra
.883 .741 .701 r
.77177 .46486 .77825 .47693 .79073 .45286 .78425 .43986 Metetra
.868 .728 .705 r
.78425 .43986 .79073 .45286 .80317 .42941 .79673 .41632 Metetra
.81 .71 .755 r
.79673 .41632 .80317 .42941 .81591 .4105 .8098 .40053 Metetra
.654 .705 .884 r
.8098 .40053 .81591 .4105 .82979 .40426 .8239 .3961 Metetra
.654 .753 .922 r
.8239 .3961 .82979 .40426 .8439 .39985 .83806 .39165 Metetra
.654 .753 .922 r
.83806 .39165 .8439 .39985 .85809 .39542 .8523 .38718 Metetra
.654 .753 .922 r
.8523 .38718 .85809 .39542 .87234 .39097 .8666 .38269 Metetra
.654 .753 .922 r
.23173 .57305 .23944 .5797 .25089 .5761 .24321 .56942 Metetra
.654 .753 .922 r
.24321 .56942 .25089 .5761 .26239 .57249 .25474 .56578 Metetra
.654 .753 .922 r
.25474 .56578 .26239 .57249 .27394 .56886 .26632 .56212 Metetra
.654 .753 .922 r
.26632 .56212 .27394 .56886 .28555 .56522 .27795 .55845 Metetra
.568 .727 .949 r
.27795 .55845 .28555 .56522 .29672 .56865 .2895 .5568 Metetra
0 .028 .593 r
.2895 .5568 .29672 .56865 .30734 .58242 .30013 .56982 Metetra
0 0 .449 r
.30013 .56982 .30734 .58242 .31798 .59858 .31072 .58625 Metetra
0 0 .466 r
.31072 .58625 .31798 .59858 .32887 .61371 .32152 .60234 Metetra
0 .045 .604 r
.32152 .60234 .32887 .61371 .34013 .62526 .33268 .61527 Metetra
0 .328 .813 r
.33268 .61527 .34013 .62526 .35182 .63149 .34429 .62309 Metetra
.415 .621 .937 r
.34429 .62309 .35182 .63149 .36393 .63142 .35634 .62461 Metetra
.695 .774 .912 r
.35634 .62461 .36393 .63142 .3764 .62473 .36878 .6194 Metetra
.829 .823 .843 r
.36878 .6194 .3764 .62473 .38916 .61172 .38155 .60765 Metetra
.892 .835 .784 r
.38155 .60765 .38916 .61172 .40211 .59314 .39454 .59006 Metetra
.922 .836 .742 r
.39454 .59006 .40211 .59314 .41515 .57008 .40765 .56771 Metetra
.939 .835 .715 r
.40765 .56771 .41515 .57008 .4282 .54382 .42079 .54191 Metetra
.947 .835 .7 r
.42079 .54191 .4282 .54382 .4412 .51577 .43389 .51408 Metetra
.951 .837 .694 r
.43389 .51408 .4412 .51577 .45407 .48728 .44687 .48563 Metetra
.952 .841 .696 r
.44687 .48563 .45407 .48728 .46681 .45964 .45972 .45791 Metetra
.95 .849 .708 r
.45972 .45791 .46681 .45964 .4794 .43399 .47241 .43211 Metetra
.943 .862 .73 r
.47241 .43211 .4794 .43399 .49185 .41132 .48496 .40924 Metetra
.929 .88 .766 r
.48496 .40924 .49185 .41132 .50419 .39242 .49739 .39015 Metetra
.897 .904 .822 r
.49739 .39015 .50419 .39242 .51646 .37789 .50974 .37546 Metetra
.824 .926 .901 r
.50974 .37546 .51646 .37789 .52872 .36814 .52206 .36561 Metetra
.637 .904 .984 r
.52206 .36561 .52872 .36814 .54101 .36339 .53441 .36082 Metetra
.215 .698 .931 r
.53441 .36082 .54101 .36339 .55339 .36368 .54684 .36114 Metetra
.29 0 0 r
.54684 .36114 .55339 .36368 .56593 .36886 .55942 .36641 Metetra
.583 .013 0 r
.55942 .36641 .56593 .36886 .57867 .37859 .57219 .37627 Metetra
.714 .181 0 r
.57219 .37627 .57867 .37859 .59167 .39235 .58522 .39016 Metetra
.775 .268 0 r
.58522 .39016 .59167 .39235 .60494 .40939 .59852 .40733 Metetra
.802 .31 0 r
.59852 .40733 .60494 .40939 .61852 .42882 .61211 .4268 Metetra
.811 .324 0 r
.61211 .4268 .61852 .42882 .63239 .44952 .626 .44743 Metetra
.803 .312 0 r
.626 .44743 .63239 .44952 .64653 .47022 .64014 .4679 Metetra
.774 .268 0 r
.64014 .4679 .64653 .47022 .66087 .48955 .65449 .48677 Metetra
.704 .171 0 r
.65449 .48677 .66087 .48955 .67535 .50607 .66897 .50257 Metetra
.527 0 0 r
.66897 .50257 .67535 .50607 .68986 .51841 .68347 .5139 Metetra
0 .424 .815 r
.68347 .5139 .68986 .51841 .70429 .52533 .69787 .51952 Metetra
.477 .75 .989 r
.69787 .51952 .70429 .52533 .71852 .52592 .71206 .51857 Metetra
.747 .805 .899 r
.71206 .51857 .71852 .52592 .73243 .51971 .72592 .51066 Metetra
.837 .783 .801 r
.72592 .51066 .73243 .51971 .74595 .50679 .73939 .49601 Metetra
.867 .757 .739 r
.73939 .49601 .74595 .50679 .75905 .48798 .75245 .47561 Metetra
.876 .737 .705 r
.75245 .47561 .75905 .48798 .77177 .46486 .76514 .45128 Metetra
.872 .723 .693 r
.76514 .45128 .77177 .46486 .78425 .43986 .77764 .42572 Metetra
.855 .712 .704 r
.77764 .42572 .78425 .43986 .79673 .41632 .79022 .40259 Metetra
.741 .676 .787 r
.79022 .40259 .79673 .41632 .8098 .40053 .80382 .39234 Metetra
.654 .753 .922 r
.80382 .39234 .8098 .40053 .8239 .3961 .81796 .38787 Metetra
.654 .753 .922 r
.81796 .38787 .8239 .3961 .83806 .39165 .83217 .38338 Metetra
.654 .753 .922 r
.83217 .38338 .83806 .39165 .8523 .38718 .84646 .37887 Metetra
.654 .753 .922 r
.84646 .37887 .8523 .38718 .8666 .38269 .86081 .37434 Metetra
.654 .753 .922 r
.22395 .56634 .23173 .57305 .24321 .56942 .23546 .56269 Metetra
.654 .753 .922 r
.23546 .56269 .24321 .56942 .25474 .56578 .24702 .55901 Metetra
.654 .753 .922 r
.24702 .55901 .25474 .56578 .26632 .56212 .25863 .55533 Metetra
.654 .753 .922 r
.25863 .55533 .26632 .56212 .27795 .55845 .2703 .55162 Metetra
.654 .753 .922 r
.2703 .55162 .27795 .55845 .2895 .5568 .28201 .5479 Metetra
0 .218 .73 r
.28201 .5479 .2895 .5568 .30013 .56982 .29293 .5565 Metetra
0 0 .483 r
.29293 .5565 .30013 .56982 .31072 .58625 .30349 .57277 Metetra
0 0 .477 r
.30349 .57277 .31072 .58625 .32152 .60234 .31421 .58952 Metetra
0 .021 .59 r
.31421 .58952 .32152 .60234 .33268 .61527 .32528 .60366 Metetra
0 .267 .773 r
.32528 .60366 .33268 .61527 .34429 .62309 .33679 .61301 Metetra
.354 .544 .902 r
.33679 .61301 .34429 .62309 .35634 .62461 .34876 .6162 Metetra
.642 .718 .903 r
.34876 .6162 .35634 .62461 .36878 .6194 .36116 .61266 Metetra
.796 .791 .847 r
.36116 .61266 .36878 .6194 .38155 .60765 .37391 .60245 Metetra
.872 .818 .792 r
.37391 .60245 .38155 .60765 .39454 .59006 .38692 .58621 Metetra
.912 .828 .751 r
.38692 .58621 .39454 .59006 .40765 .56771 .40008 .56498 Metetra
.934 .834 .722 r
.40008 .56498 .40765 .56771 .42079 .54191 .41329 .54005 Metetra
.947 .839 .705 r
.41329 .54005 .42079 .54191 .43389 .51408 .42647 .51287 Metetra
.954 .846 .697 r
.42647 .51287 .43389 .51408 .44687 .48563 .43956 .48487 Metetra
.958 .856 .698 r
.43956 .48487 .44687 .48563 .45972 .45791 .45251 .45743 Metetra
.958 .871 .708 r
.45251 .45743 .45972 .45791 .47241 .43211 .46531 .43178 Metetra
.954 .891 .729 r
.46531 .43178 .47241 .43211 .48496 .40924 .47797 .40899 Metetra
.939 .919 .766 r
.47797 .40899 .48496 .40924 .49739 .39015 .49049 .38992 Metetra
.902 .955 .822 r
.49049 .38992 .49739 .39015 .50974 .37546 .50293 .37521 Metetra
.801 .983 .896 r
.50293 .37521 .50974 .37546 .52206 .36561 .51532 .36533 Metetra
.522 .912 .924 r
.51532 .36533 .52206 .36561 .53441 .36082 .52774 .36052 Metetra
0 .575 .724 r
.52774 .36052 .53441 .36082 .54684 .36114 .54022 .36081 Metetra
.433 0 0 r
.54022 .36081 .54684 .36114 .55942 .36641 .55285 .36604 Metetra
.642 .083 0 r
.55285 .36604 .55942 .36641 .57219 .37627 .56566 .37583 Metetra
.737 .215 0 r
.56566 .37583 .57219 .37627 .58522 .39016 .57872 .38962 Metetra
.783 .284 .002 r
.57872 .38962 .58522 .39016 .59852 .40733 .59204 .40659 Metetra
.805 .317 .026 r
.59204 .40659 .59852 .40733 .61211 .4268 .60565 .42576 Metetra
.81 .324 .021 r
.60565 .42576 .61211 .4268 .626 .44743 .61954 .44593 Metetra
.799 .305 0 r
.61954 .44593 .626 .44743 .64014 .4679 .63369 .46574 Metetra
.762 .249 0 r
.63369 .46574 .64014 .4679 .65449 .48677 .64803 .48372 Metetra
.668 .126 0 r
.64803 .48372 .65449 .48677 .66897 .50257 .66249 .49838 Metetra
.418 0 0 r
.66249 .49838 .66897 .50257 .68347 .5139 .67696 .50831 Metetra
.12 .546 .918 r
.67696 .50831 .68347 .5139 .69787 .51952 .69132 .51233 Metetra
.588 .756 .958 r
.69132 .51233 .69787 .51952 .71206 .51857 .70546 .50961 Metetra
.771 .772 .854 r
.70546 .50961 .71206 .51857 .72592 .51066 .71927 .49987 Metetra
.836 .752 .771 r
.71927 .49987 .72592 .51066 .73939 .49601 .73269 .4835 Metetra
.86 .733 .721 r
.73269 .4835 .73939 .49601 .75245 .47561 .74571 .46167 Metetra
.867 .718 .695 r
.74571 .46167 .75245 .47561 .76514 .45128 .7584 .43641 Metetra
.862 .708 .689 r
.7584 .43641 .76514 .45128 .77764 .42572 .77094 .41071 Metetra
.842 .7 .706 r
.77094 .41071 .77764 .42572 .79022 .40259 .78365 .38856 Metetra
.643 .627 .818 r
.78365 .38856 .79022 .40259 .80382 .39234 .79777 .38407 Metetra
.654 .753 .922 r
.79777 .38407 .80382 .39234 .81796 .38787 .81197 .37956 Metetra
.654 .753 .922 r
.81197 .37956 .81796 .38787 .83217 .38338 .82623 .37503 Metetra
.654 .753 .922 r
.82623 .37503 .83217 .38338 .84646 .37887 .84056 .37048 Metetra
.654 .753 .922 r
.84056 .37048 .84646 .37887 .86081 .37434 .85497 .36591 Metetra
.654 .753 .922 r
.21611 .55958 .22395 .56634 .23546 .56269 .22765 .55589 Metetra
.654 .753 .922 r
.22765 .55589 .23546 .56269 .24702 .55901 .23924 .55219 Metetra
.654 .753 .922 r
.23924 .55219 .24702 .55901 .25863 .55533 .25088 .54847 Metetra
.654 .753 .922 r
.25088 .54847 .25863 .55533 .2703 .55162 .26258 .54474 Metetra
.654 .753 .922 r
.26258 .54474 .2703 .55162 .28201 .5479 .27433 .54099 Metetra
.339 .627 .958 r
.27433 .54099 .28201 .5479 .29293 .5565 .28573 .54274 Metetra
0 0 .525 r
.28573 .54274 .29293 .5565 .30349 .57277 .29629 .55841 Metetra
0 0 .49 r
.29629 .55841 .30349 .57277 .31421 .58952 .30695 .57546 Metetra
0 .003 .579 r
.30695 .57546 .31421 .58952 .32528 .60366 .31792 .59058 Metetra
0 .215 .737 r
.31792 .59058 .32528 .60366 .33679 .61301 .32933 .60136 Metetra
.293 .473 .866 r
.32933 .60136 .33679 .61301 .34876 .6162 .34121 .60625 Metetra
.584 .66 .89 r
.34121 .60625 .34876 .6162 .36116 .61266 .35354 .6045 Metetra
.756 .755 .851 r
.35354 .6045 .36116 .61266 .37391 .60245 .36626 .59607 Metetra
.848 .798 .802 r
.36626 .59607 .37391 .60245 .38692 .58621 .37926 .58149 Metetra
.898 .819 .761 r
.37926 .58149 .38692 .58621 .40008 .56498 .39244 .56174 Metetra
.926 .832 .732 r
.39244 .56174 .40008 .56498 .41329 .54005 .40571 .53808 Metetra
.944 .843 .713 r
.40571 .53808 .41329 .54005 .42647 .51287 .41896 .51194 Metetra
.955 .855 .703 r
.41896 .51194 .42647 .51287 .43956 .48487 .43214 .48477 Metetra
.961 .87 .702 r
.43214 .48477 .43956 .48487 .45251 .45743 .44519 .45797 Metetra
.963 .89 .71 r
.44519 .45797 .45251 .45743 .46531 .43178 .4581 .43279 Metetra
.958 .917 .728 r
.4581 .43279 .46531 .43178 .47797 .40899 .47085 .41033 Metetra
.939 .951 .76 r
.47085 .41033 .47797 .40899 .49049 .38992 .48348 .39148 Metetra
.884 .989 .805 r
.48348 .39148 .49049 .38992 .50293 .37521 .49601 .37691 Metetra
.727 .99 .841 r
.49601 .37691 .50293 .37521 .51532 .36533 .50849 .36708 Metetra
.345 .818 .759 r
.50849 .36708 .51532 .36533 .52774 .36052 .52097 .36224 Metetra
.167 0 0 r
.52097 .36224 .52774 .36052 .54022 .36081 .53353 .36245 Metetra
.497 0 0 r
.53353 .36245 .54022 .36081 .55285 .36604 .54621 .36752 Metetra
.658 .121 0 r
.54621 .36752 .55285 .36604 .56566 .37583 .55906 .37706 Metetra
.737 .229 .011 r
.55906 .37706 .56566 .37583 .57872 .38962 .57215 .39049 Metetra
.778 .287 .048 r
.57215 .39049 .57872 .38962 .59204 .40659 .5855 .40697 Metetra
.798 .313 .054 r
.5855 .40697 .59204 .40659 .60565 .42576 .59912 .42549 Metetra
.802 .314 .033 r
.59912 .42549 .60565 .42576 .61954 .44593 .61302 .44481 Metetra
.787 .287 0 r
.61302 .44481 .61954 .44593 .63369 .46574 .62716 .46355 Metetra
.739 .216 0 r
.62716 .46355 .63369 .46574 .64803 .48372 .64148 .48024 Metetra
.607 .055 0 r
.64148 .48024 .64803 .48372 .66249 .49838 .6559 .49337 Metetra
0 .273 .708 r
.6559 .49337 .66249 .49838 .67696 .50831 .67033 .50157 Metetra
.318 .635 .964 r
.67033 .50157 .67696 .50831 .69132 .51233 .68464 .50371 Metetra
.659 .745 .914 r
.68464 .50371 .69132 .51233 .70546 .50961 .69872 .49905 Metetra
.785 .745 .816 r
.69872 .49905 .70546 .50961 .71927 .49987 .71247 .48744 Metetra
.834 .728 .748 r
.71247 .48744 .71927 .49987 .73269 .4835 .72585 .46942 Metetra
.853 .714 .708 r
.72585 .46942 .73269 .4835 .74571 .46167 .73884 .44636 Metetra
.859 .703 .688 r
.73884 .44636 .74571 .46167 .7584 .43641 .75155 .42051 Metetra
.853 .696 .687 r
.75155 .42051 .7584 .43641 .77094 .41071 .76416 .3951 Metetra
.779 .671 .744 r
.76416 .3951 .77094 .41071 .78365 .38856 .7775 .38026 Metetra
.654 .753 .922 r
.7775 .38026 .78365 .38856 .79777 .38407 .79167 .37573 Metetra
.654 .753 .922 r
.79167 .37573 .79777 .38407 .81197 .37956 .80592 .37118 Metetra
.654 .753 .922 r
.80592 .37118 .81197 .37956 .82623 .37503 .82023 .36661 Metetra
.654 .753 .922 r
.82023 .36661 .82623 .37503 .84056 .37048 .83462 .36202 Metetra
.654 .753 .922 r
.83462 .36202 .84056 .37048 .85497 .36591 .84907 .3574 Metetra
.654 .753 .922 r
.20821 .55276 .21611 .55958 .22765 .55589 .21978 .54905 Metetra
.654 .753 .922 r
.21978 .54905 .22765 .55589 .23924 .55219 .2314 .54531 Metetra
.654 .753 .922 r
.2314 .54531 .23924 .55219 .25088 .54847 .24307 .54156 Metetra
.654 .753 .922 r
.24307 .54156 .25088 .54847 .26258 .54474 .2548 .5378 Metetra
.654 .753 .922 r
.2548 .5378 .26258 .54474 .27433 .54099 .26657 .53401 Metetra
.654 .753 .922 r
.26657 .53401 .27433 .54099 .28573 .54274 .27841 .53021 Metetra
0 .033 .6 r
.27841 .53021 .28573 .54274 .29629 .55841 .2891 .54343 Metetra
0 0 .509 r
.2891 .54343 .29629 .55841 .30695 .57546 .29971 .56041 Metetra
0 0 .571 r
.29971 .56041 .30695 .57546 .31792 .59058 .3106 .57624 Metetra
0 .172 .706 r
.3106 .57624 .31792 .59058 .32933 .60136 .3219 .58828 Metetra
.234 .408 .831 r
.3219 .58828 .32933 .60136 .34121 .60625 .33368 .59483 Metetra
.522 .602 .875 r
.33368 .59483 .34121 .60625 .35354 .6045 .34593 .59496 Metetra
.711 .716 .853 r
.34593 .59496 .35354 .6045 .36626 .59607 .35858 .58848 Metetra
.818 .775 .812 r
.35858 .58848 .36626 .59607 .37926 .58149 .37156 .57581 Metetra
.879 .807 .774 r
.37156 .57581 .37926 .58149 .39244 .56174 .38475 .55785 Metetra
.916 .828 .745 r
.38475 .55785 .39244 .56174 .40571 .53808 .39804 .53581 Metetra
.938 .845 .725 r
.39804 .53581 .40571 .53808 .41896 .51194 .41136 .51108 Metetra
.953 .863 .713 r
.41136 .51108 .41896 .51194 .43214 .48477 .42461 .4851 Metetra
.961 .883 .709 r
.42461 .4851 .43214 .48477 .44519 .45797 .43775 .45928 Metetra
.963 .908 .713 r
.43775 .45928 .44519 .45797 .4581 .43279 .45075 .43487 Metetra
.955 .938 .727 r
.45075 .43487 .4581 .43279 .47085 .41033 .46361 .413 Metetra
.925 .973 .749 r
.46361 .413 .47085 .41033 .48348 .39148 .47634 .39456 Metetra
.839 .997 .769 r
.47634 .39456 .48348 .39148 .49601 .37691 .48897 .38025 Metetra
.612 .94 .741 r
.48897 .38025 .49601 .37691 .50849 .36708 .50154 .37055 Metetra
.50154 .37055 .50849 .36708 .52097 .36224 .51411 .36571 Metetra
.258 0 0 r
.51411 .36571 .52097 .36224 .53353 .36245 .52673 .36577 Metetra
.519 0 0 r
.52673 .36577 .53353 .36245 .54621 .36752 .53947 .37056 Metetra
.654 .137 0 r
.53947 .37056 .54621 .36752 .55906 .37706 .55238 .37968 Metetra
.726 .229 .053 r
.55238 .37968 .55906 .37706 .57215 .39049 .56551 .3925 Metetra
.766 .279 .073 r
.56551 .3925 .57215 .39049 .5855 .40697 .57888 .40821 Metetra
.786 .3 .066 r
.57888 .40821 .5855 .40697 .59912 .42549 .59252 .42573 Metetra
.788 .295 .03 r
.59252 .42573 .59912 .42549 .61302 .44481 .60641 .44385 Metetra
.767 .257 0 r
.60641 .44385 .61302 .44481 .62716 .46355 .62054 .46115 Metetra
.7 .162 0 r
.62054 .46115 .62716 .46355 .64148 .48024 .63483 .47617 Metetra
.506 0 0 r
.63483 .47617 .64148 .48024 .6559 .49337 .64921 .48744 Metetra
0 .425 .846 r
.64921 .48744 .6559 .49337 .67033 .50157 .66359 .49363 Metetra
.472 .682 .957 r
.66359 .49363 .67033 .50157 .68464 .50371 .67784 .49368 Metetra
.705 .73 .87 r
.67784 .49368 .68464 .50371 .69872 .49905 .69186 .48697 Metetra
.794 .723 .785 r
.69186 .48697 .69872 .49905 .71247 .48744 .70556 .4735 Metetra
.831 .71 .73 r
.70556 .4735 .71247 .48744 .72585 .46942 .71889 .45397 Metetra
.848 .699 .698 r
.71889 .45397 .72585 .46942 .73884 .44636 .73188 .42993 Metetra
.851 .692 .684 r
.73188 .42993 .73884 .44636 .75155 .42051 .74462 .40386 Metetra
.843 .687 .689 r
.74462 .40386 .75155 .42051 .76416 .3951 .75734 .3792 Metetra
.684 .624 .783 r
.75734 .3792 .76416 .3951 .7775 .38026 .7713 .37188 Metetra
.654 .753 .922 r
.7713 .37188 .7775 .38026 .79167 .37573 .78552 .36732 Metetra
.654 .753 .922 r
.78552 .36732 .79167 .37573 .80592 .37118 .79981 .36272 Metetra
.654 .753 .922 r
.79981 .36272 .80592 .37118 .82023 .36661 .81418 .35811 Metetra
.654 .753 .922 r
.81418 .35811 .82023 .36661 .83462 .36202 .82861 .35347 Metetra
.654 .753 .922 r
.82861 .35347 .83462 .36202 .84907 .3574 .84312 .34881 Metetra
.654 .753 .922 r
.20024 .54589 .20821 .55276 .21978 .54905 .21184 .54214 Metetra
.654 .753 .922 r
.21184 .54214 .21978 .54905 .2314 .54531 .22349 .53838 Metetra
.654 .753 .922 r
.22349 .53838 .2314 .54531 .24307 .54156 .23519 .5346 Metetra
.654 .753 .922 r
.23519 .5346 .24307 .54156 .2548 .5378 .24695 .5308 Metetra
.654 .753 .922 r
.24695 .5308 .2548 .5378 .26657 .53401 .25876 .52698 Metetra
.654 .753 .922 r
.25876 .52698 .26657 .53401 .27841 .53021 .27062 .52315 Metetra
.02 .435 .867 r
.27062 .52315 .27841 .53021 .2891 .54343 .2819 .52813 Metetra
0 0 .534 r
.2819 .52813 .2891 .54343 .29971 .56041 .2925 .54464 Metetra
0 0 .568 r
.2925 .54464 .29971 .56041 .3106 .57624 .30331 .56085 Metetra
0 .138 .68 r
.30331 .56085 .3106 .57624 .3219 .58828 .31451 .57395 Metetra
.178 .349 .798 r
.31451 .57395 .3219 .58828 .33368 .59483 .32618 .58205 Metetra
.457 .544 .857 r
.32618 .58205 .33368 .59483 .34593 .59496 .33833 .58406 Metetra
.658 .673 .853 r
.33833 .58406 .34593 .59496 .35858 .58848 .35091 .57964 Metetra
.782 .748 .822 r
.35091 .57964 .35858 .58848 .37156 .57581 .36383 .56909 Metetra
.856 .792 .788 r
.36383 .56909 .37156 .57581 .38475 .55785 .377 .55319 Metetra
.901 .822 .76 r
.377 .55319 .38475 .55785 .39804 .53581 .39031 .53308 Metetra
.93 .846 .739 r
.39031 .53308 .39804 .53581 .41136 .51108 .40366 .51008 Metetra
.948 .869 .726 r
.40366 .51008 .41136 .51108 .42461 .4851 .41697 .48562 Metetra
.959 .894 .72 r
.41697 .48562 .42461 .4851 .43775 .45928 .43019 .46108 Metetra
.96 .923 .721 r
.43019 .46108 .43775 .45928 .45075 .43487 .44329 .43773 Metetra
.947 .956 .727 r
.44329 .43773 .45075 .43487 .46361 .413 .45624 .41668 Metetra
.9 .985 .735 r
.45624 .41668 .46361 .413 .47634 .39456 .46907 .39885 Metetra
.774 .981 .722 r
.46907 .39885 .47634 .39456 .48897 .38025 .4818 .38493 Metetra
.487 .858 .63 r
.4818 .38493 .48897 .38025 .50154 .37055 .49447 .37542 Metetra
.49447 .37542 .50154 .37055 .51411 .36571 .50713 .37058 Metetra
.303 0 0 r
.50713 .37058 .51411 .36571 .52673 .36577 .51983 .37045 Metetra
.52 0 0 r
.51983 .37045 .52673 .36577 .53947 .37056 .53264 .37484 Metetra
.641 .136 .034 r
.53264 .37484 .53947 .37056 .55238 .37968 .54561 .38335 Metetra
.709 .218 .073 r
.54561 .38335 .55238 .37968 .56551 .3925 .55877 .39536 Metetra
.749 .262 .081 r
.55877 .39536 .56551 .3925 .57888 .40821 .57217 .41001 Metetra
.768 .278 .062 r
.57217 .41001 .57888 .40821 .59252 .42573 .58582 .42624 Metetra
.768 .265 .009 r
.58582 .42624 .59252 .42573 .60641 .44385 .59972 .44281 Metetra
.737 .212 0 r
.59972 .44281 .60641 .44385 .62054 .46115 .61382 .45834 Metetra
.635 .081 0 r
.61382 .45834 .62054 .46115 .63483 .47617 .62808 .47138 Metetra
0 .199 .634 r
.62808 .47138 .63483 .47617 .64921 .48744 .64242 .4805 Metetra
.194 .555 .933 r
.64242 .4805 .64921 .48744 .66359 .49363 .65674 .48445 Metetra
.579 .7 .924 r
.65674 .48445 .66359 .49363 .67784 .49368 .67093 .48227 Metetra
.736 .715 .832 r
.67093 .48227 .67784 .49368 .69186 .48697 .68489 .47348 Metetra
.8 .705 .761 r
.68489 .47348 .69186 .48697 .70556 .4735 .69854 .45822 Metetra
.829 .695 .716 r
.69854 .45822 .70556 .4735 .71889 .45397 .71184 .43736 Metetra
.842 .688 .691 r
.71184 .43736 .71889 .45397 .73188 .42993 .72483 .41265 Metetra
.844 .683 .682 r
.72483 .41265 .73188 .42993 .74462 .40386 .73764 .38675 Metetra
.801 .667 .716 r
.73764 .38675 .74462 .40386 .75734 .3792 .75083 .36802 Metetra
.652 .685 .869 r
.75083 .36802 .75734 .3792 .7713 .37188 .76503 .36343 Metetra
.654 .753 .922 r
.76503 .36343 .7713 .37188 .78552 .36732 .77931 .35882 Metetra
.654 .753 .922 r
.77931 .35882 .78552 .36732 .79981 .36272 .79365 .35419 Metetra
.654 .753 .922 r
.79365 .35419 .79981 .36272 .81418 .35811 .80807 .34953 Metetra
.654 .753 .922 r
.80807 .34953 .81418 .35811 .82861 .35347 .82255 .34485 Metetra
.654 .753 .922 r
.82255 .34485 .82861 .35347 .84312 .34881 .83711 .34015 Metetra
.654 .753 .922 r
.1922 .53896 .20024 .54589 .21184 .54214 .20383 .53518 Metetra
.654 .753 .922 r
.20383 .53518 .21184 .54214 .22349 .53838 .21551 .53138 Metetra
.654 .753 .922 r
.21551 .53138 .22349 .53838 .23519 .5346 .22725 .52757 Metetra
.654 .753 .922 r
.22725 .52757 .23519 .5346 .24695 .5308 .23904 .52374 Metetra
.654 .753 .922 r
.23904 .52374 .24695 .5308 .25876 .52698 .25088 .51989 Metetra
.654 .753 .922 r
.25088 .51989 .25876 .52698 .27062 .52315 .26277 .51603 Metetra
.63 .747 .931 r
.26277 .51603 .27062 .52315 .2819 .52813 .27467 .5128 Metetra
0 0 .568 r
.27467 .5128 .2819 .52813 .2925 .54464 .28528 .52842 Metetra
0 0 .572 r
.28528 .52842 .2925 .54464 .30331 .56085 .29604 .54467 Metetra
0 .112 .66 r
.29604 .54467 .30331 .56085 .31451 .57395 .30715 .55857 Metetra
.126 .298 .768 r
.30715 .55857 .31451 .57395 .32618 .58205 .31871 .56806 Metetra
.392 .487 .837 r
.31871 .56806 .32618 .58205 .33833 .58406 .33075 .5719 Metetra
.601 .627 .85 r
.33075 .5719 .33833 .58406 .35091 .57964 .34324 .56958 Metetra
.739 .717 .831 r
.34324 .56958 .35091 .57964 .36383 .56909 .35609 .56127 Metetra
.826 .774 .803 r
.35609 .56127 .36383 .56909 .377 .55319 .36921 .54763 Metetra
.882 .813 .777 r
.36921 .54763 .377 .55319 .39031 .53308 .38251 .52969 Metetra
.917 .845 .757 r
.38251 .52969 .39031 .53308 .40366 .51008 .39588 .50871 Metetra
.941 .874 .743 r
.39588 .50871 .40366 .51008 .41697 .48562 .40923 .48606 Metetra
.953 .904 .735 r
.40923 .48606 .41697 .48562 .43019 .46108 .42252 .46308 Metetra
.954 .936 .732 r
.42252 .46308 .43019 .46108 .44329 .43773 .4357 .44104 Metetra
.933 .969 .732 r
.4357 .44104 .44329 .43773 .45624 .41668 .44875 .42103 Metetra
.867 .989 .723 r
.44875 .42103 .45624 .41668 .46907 .39885 .46167 .40397 Metetra
.703 .952 .676 r
.46167 .40397 .46907 .39885 .4818 .38493 .4745 .39057 Metetra
.4745 .39057 .4818 .38493 .49447 .37542 .48727 .38133 Metetra
.013 0 0 r
.48727 .38133 .49447 .37542 .50713 .37058 .50002 .37649 Metetra
.321 0 0 r
.50002 .37649 .50713 .37058 .51983 .37045 .51281 .37611 Metetra
.51 .002 0 r
.51281 .37611 .51983 .37045 .53264 .37484 .5257 .38 Metetra
.621 .124 .049 r
.5257 .38 .53264 .37484 .54561 .38335 .53872 .38775 Metetra
.688 .197 .076 r
.53872 .38775 .54561 .38335 .55877 .39536 .55194 .39873 Metetra
.727 .236 .073 r
.55194 .39873 .55877 .39536 .57217 .41001 .56537 .41207 Metetra
.744 .245 .041 r
.56537 .41207 .57217 .41001 .58582 .42624 .57904 .42673 Metetra
.738 .221 0 r
.57904 .42673 .58582 .42624 .59972 .44281 .59293 .44147 Metetra
.688 .143 0 r
.59293 .44147 .59972 .44281 .61382 .45834 .60701 .45493 Metetra
.527 0 0 r
.60701 .45493 .61382 .45834 .62808 .47138 .62124 .46571 Metetra
0 .375 .803 r
.62124 .46571 .62808 .47138 .64242 .4805 .63553 .47246 Metetra
.389 .639 .955 r
.63553 .47246 .64242 .4805 .65674 .48445 .64979 .47402 Metetra
.65 .702 .884 r
.64979 .47402 .65674 .48445 .67093 .48227 .66391 .46955 Metetra
.756 .701 .8 r
.66391 .46955 .67093 .48227 .68489 .47348 .67782 .4587 Metetra
.804 .692 .742 r
.67782 .4587 .68489 .47348 .69854 .45822 .69142 .44179 Metetra
.827 .685 .705 r
.69142 .44179 .69854 .45822 .71184 .43736 .70471 .41985 Metetra
.838 .679 .686 r
.70471 .41985 .71184 .43736 .72483 .41265 .71774 .3948 Metetra
.837 .676 .683 r
.71774 .3948 .72483 .41265 .73764 .38675 .73063 .36949 Metetra
.712 .625 .759 r
.73063 .36949 .73764 .38675 .75083 .36802 .74446 .35953 Metetra
.654 .753 .922 r
.74446 .35953 .75083 .36802 .76503 .36343 .75872 .3549 Metetra
.654 .753 .922 r
.75872 .3549 .76503 .36343 .77931 .35882 .77304 .35025 Metetra
.654 .753 .922 r
.77304 .35025 .77931 .35882 .79365 .35419 .78743 .34557 Metetra
.654 .753 .922 r
.78743 .34557 .79365 .35419 .80807 .34953 .8019 .34087 Metetra
.654 .753 .922 r
.8019 .34087 .80807 .34953 .82255 .34485 .81644 .33615 Metetra
.654 .753 .922 r
.81644 .33615 .82255 .34485 .83711 .34015 .83105 .3314 Metetra
.654 .753 .922 r
.1841 .53197 .1922 .53896 .20383 .53518 .19576 .52816 Metetra
.654 .753 .922 r
.19576 .52816 .20383 .53518 .21551 .53138 .20747 .52433 Metetra
.654 .753 .922 r
.20747 .52433 .21551 .53138 .22725 .52757 .21924 .52049 Metetra
.654 .753 .922 r
.21924 .52049 .22725 .52757 .23904 .52374 .23106 .51663 Metetra
.654 .753 .922 r
.23106 .51663 .23904 .52374 .25088 .51989 .24293 .51275 Metetra
.654 .753 .922 r
.24293 .51275 .25088 .51989 .26277 .51603 .25486 .50885 Metetra
.654 .753 .922 r
.25486 .50885 .26277 .51603 .27467 .5128 .26684 .50493 Metetra
0 .293 .773 r
.26684 .50493 .27467 .5128 .28528 .52842 .27806 .51203 Metetra
0 .007 .583 r
.27806 .51203 .28528 .52842 .29604 .54467 .28879 .52795 Metetra
0 .095 .647 r
.28879 .52795 .29604 .54467 .30715 .55857 .29982 .54236 Metetra
.08 .255 .743 r
.29982 .54236 .30715 .55857 .31871 .56806 .31127 .55303 Metetra
.328 .432 .816 r
.31127 .55303 .31871 .56806 .33075 .5719 .3232 .55857 Metetra
.539 .579 .843 r
.3232 .55857 .33075 .5719 .34324 .56958 .33557 .55833 Metetra
.69 .682 .837 r
.33557 .55833 .34324 .56958 .35609 .56127 .34833 .55232 Metetra
.79 .751 .817 r
.34833 .55232 .35609 .56127 .36921 .54763 .3614 .54106 Metetra
.856 .8 .795 r
.3614 .54106 .36921 .54763 .38251 .52969 .37466 .52548 Metetra
.9 .84 .777 r
.37466 .52548 .38251 .52969 .39588 .50871 .38802 .50674 Metetra
.929 .875 .763 r
.38802 .50674 .39588 .50871 .40923 .48606 .40141 .48614 Metetra
.944 .911 .755 r
.40141 .48614 .40923 .48606 .42252 .46308 .41474 .46497 Metetra
.944 .947 .749 r
.41474 .46497 .42252 .46308 .4357 .44104 .42799 .44445 Metetra
.917 .979 .742 r
.42799 .44445 .4357 .44104 .44875 .42103 .44112 .42568 Metetra
.833 .988 .718 r
.44112 .42568 .44875 .42103 .46167 .40397 .45414 .40955 Metetra
.639 .922 .643 r
.45414 .40955 .46167 .40397 .4745 .39057 .46707 .39679 Metetra
.46707 .39679 .4745 .39057 .48727 .38133 .47994 .38786 Metetra
.049 0 0 r
.47994 .38786 .48727 .38133 .50002 .37649 .49279 .38304 Metetra
.32 0 0 r
.49279 .38304 .50002 .37649 .51281 .37611 .50567 .38237 Metetra
.491 0 0 r
.50567 .38237 .51281 .37611 .5257 .38 .51863 .38566 Metetra
.597 .1 .044 r
.51863 .38566 .5257 .38 .53872 .38775 .53173 .39249 Metetra
.661 .166 .061 r
.53173 .39249 .53872 .38775 .55194 .39873 .54499 .40225 Metetra
.699 .198 .048 r
.54499 .40225 .55194 .39873 .56537 .41207 .55846 .41407 Metetra
.712 .198 0 r
.55846 .41407 .56537 .41207 .57904 .42673 .57215 .42691 Metetra
.694 .155 0 r
.57215 .42691 .57904 .42673 .59293 .44147 .58604 .43957 Metetra
.607 .039 0 r
.58604 .43957 .59293 .44147 .60701 .45493 .60011 .45073 Metetra
0 .212 .621 r
.60011 .45073 .60701 .45493 .62124 .46571 .6143 .45905 Metetra
.145 .536 .922 r
.6143 .45905 .62124 .46571 .63553 .47246 .62854 .46328 Metetra
.528 .679 .934 r
.62854 .46328 .63553 .47246 .64979 .47402 .64274 .46236 Metetra
.697 .697 .847 r
.64274 .46236 .64979 .47402 .66391 .46955 .65681 .4556 Metetra
.77 .69 .775 r
.65681 .4556 .66391 .46955 .67782 .4587 .67066 .4428 Metetra
.807 .682 .727 r
.67066 .4428 .67782 .4587 .69142 .44179 .68424 .42443 Metetra
.825 .676 .698 r
.68424 .42443 .69142 .44179 .70471 .41985 .69753 .4017 Metetra
.833 .673 .684 r
.69753 .4017 .70471 .41985 .71774 .3948 .7106 .37668 Metetra
.81 .664 .701 r
.7106 .37668 .71774 .3948 .73063 .36949 .72381 .35562 Metetra
.644 .636 .827 r
.72381 .35562 .73063 .36949 .74446 .35953 .73804 .35097 Metetra
.654 .753 .922 r
.73804 .35097 .74446 .35953 .75872 .3549 .75234 .34629 Metetra
.654 .753 .922 r
.75234 .34629 .75872 .3549 .77304 .35025 .76671 .3416 Metetra
.654 .753 .922 r
.76671 .3416 .77304 .35025 .78743 .34557 .78116 .33688 Metetra
.654 .753 .922 r
.78116 .33688 .78743 .34557 .8019 .34087 .79568 .33213 Metetra
.654 .753 .922 r
.79568 .33213 .8019 .34087 .81644 .33615 .81027 .32736 Metetra
.654 .753 .922 r
.81027 .32736 .81644 .33615 .83105 .3314 .82493 .32257 Metetra
.654 .753 .922 r
.17593 .52492 .1841 .53197 .19576 .52816 .18762 .52108 Metetra
.654 .753 .922 r
.18762 .52108 .19576 .52816 .20747 .52433 .19936 .51722 Metetra
.654 .753 .922 r
.19936 .51722 .20747 .52433 .21924 .52049 .21116 .51334 Metetra
.654 .753 .922 r
.21116 .51334 .21924 .52049 .23106 .51663 .22301 .50945 Metetra
.654 .753 .922 r
.22301 .50945 .23106 .51663 .24293 .51275 .23491 .50554 Metetra
.654 .753 .922 r
.23491 .50554 .24293 .51275 .25486 .50885 .24687 .50161 Metetra
.654 .753 .922 r
.24687 .50161 .25486 .50885 .26684 .50493 .25889 .49766 Metetra
.57 .727 .948 r
.25889 .49766 .26684 .50493 .27806 .51203 .2708 .49576 Metetra
0 .032 .602 r
.2708 .49576 .27806 .51203 .28879 .52795 .28153 .51097 Metetra
0 .087 .64 r
.28153 .51097 .28879 .52795 .29982 .54236 .2925 .52555 Metetra
.041 .22 .722 r
.2925 .52555 .29982 .54236 .31127 .55303 .30386 .53714 Metetra
.268 .383 .795 r
.30386 .53714 .31127 .55303 .3232 .55857 .31566 .5442 Metetra
.475 .53 .833 r
.31566 .5442 .3232 .55857 .33557 .55833 .32792 .54594 Metetra
.635 .641 .839 r
.32792 .54594 .33557 .55833 .34833 .55232 .34058 .54221 Metetra
.747 .722 .829 r
.34058 .54221 .34833 .55232 .3614 .54106 .35356 .5334 Metetra
.824 .781 .813 r
.35356 .5334 .3614 .54106 .37466 .52548 .36677 .5203 Metetra
.876 .83 .798 r
.36677 .5203 .37466 .52548 .38802 .50674 .38011 .50396 Metetra
.911 .873 .787 r
.38011 .50396 .38802 .50674 .40141 .48614 .3935 .48559 Metetra
.931 .914 .779 r
.3935 .48559 .40141 .48614 .41474 .46497 .40686 .46642 Metetra
.932 .955 .773 r
.40686 .46642 .41474 .46497 .42799 .44445 .42017 .44762 Metetra
.899 .987 .761 r
.42017 .44762 .42799 .44445 .44112 .42568 .43337 .43025 Metetra
.802 .986 .725 r
.43337 .43025 .44112 .42568 .45414 .40955 .44648 .4152 Metetra
.593 .902 .631 r
.44648 .4152 .45414 .40955 .46707 .39679 .45951 .40316 Metetra
.45951 .40316 .46707 .39679 .47994 .38786 .47247 .3946 Metetra
.058 0 0 r
.47247 .3946 .47994 .38786 .49279 .38304 .48542 .3898 Metetra
.304 0 0 r
.48542 .3898 .49279 .38304 .50567 .38237 .4984 .3888 Metetra
.464 0 0 r
.4984 .3888 .50567 .38237 .51863 .38566 .51144 .3914 Metetra
.565 .062 .018 r
.51144 .3914 .51863 .38566 .53173 .39249 .52461 .3972 Metetra
.628 .121 .027 r
.52461 .3972 .53173 .39249 .54499 .40225 .53794 .40557 Metetra
.661 .145 0 r
.53794 .40557 .54499 .40225 .55846 .41407 .55145 .41568 Metetra
.666 .13 0 r
.55145 .41568 .55846 .41407 .57215 .42691 .56515 .4265 Metetra
.622 .058 0 r
.56515 .4265 .57215 .42691 .58604 .43957 .57905 .43688 Metetra
.468 0 0 r
.57905 .43688 .58604 .43957 .60011 .45073 .5931 .44557 Metetra
0 .415 .817 r
.5931 .44557 .60011 .45073 .6143 .45905 .60726 .4513 Metetra
.369 .64 .96 r
.60726 .4513 .6143 .45905 .62854 .46328 .62146 .45293 Metetra
.619 .693 .897 r
.62146 .45293 .62854 .46328 .64274 .46236 .63561 .44952 Metetra
.728 .691 .814 r
.63561 .44952 .64274 .46236 .65681 .4556 .64963 .44054 Metetra
.78 .682 .755 r
.64963 .44054 .65681 .4556 .67066 .4428 .66344 .42595 Metetra
.808 .675 .716 r
.66344 .42595 .67066 .4428 .68424 .42443 .677 .40637 Metetra
.823 .671 .693 r
.677 .40637 .68424 .42443 .69753 .4017 .69031 .38317 Metetra
.829 .669 .685 r
.69031 .38317 .69753 .4017 .7106 .37668 .70345 .35856 Metetra
.726 .626 .746 r
.70345 .35856 .7106 .37668 .72381 .35562 .71727 .34701 Metetra
.654 .753 .922 r
.71727 .34701 .72381 .35562 .73804 .35097 .73155 .34232 Metetra
.654 .753 .922 r
.73155 .34232 .73804 .35097 .75234 .34629 .7459 .3376 Metetra
.654 .753 .922 r
.7459 .3376 .75234 .34629 .76671 .3416 .76033 .33286 Metetra
.654 .753 .922 r
.76033 .33286 .76671 .3416 .78116 .33688 .77482 .3281 Metetra
.654 .753 .922 r
.77482 .3281 .78116 .33688 .79568 .33213 .78939 .32331 Metetra
.654 .753 .922 r
.78939 .32331 .79568 .33213 .81027 .32736 .80404 .3185 Metetra
.654 .753 .922 r
.80404 .3185 .81027 .32736 .82493 .32257 .81876 .31366 Metetra
.654 .753 .922 r
.16769 .51782 .17593 .52492 .18762 .52108 .17941 .51394 Metetra
.654 .753 .922 r
.17941 .51394 .18762 .52108 .19936 .51722 .19119 .51005 Metetra
.654 .753 .922 r
.19119 .51005 .19936 .51722 .21116 .51334 .20301 .50614 Metetra
.654 .753 .922 r
.20301 .50614 .21116 .51334 .22301 .50945 .21489 .50221 Metetra
.654 .753 .922 r
.21489 .50221 .22301 .50945 .23491 .50554 .22683 .49827 Metetra
.654 .753 .922 r
.22683 .49827 .23491 .50554 .24687 .50161 .23882 .4943 Metetra
.654 .753 .922 r
.23882 .4943 .24687 .50161 .25889 .49766 .25087 .49032 Metetra
.654 .753 .922 r
.25087 .49032 .25889 .49766 .2708 .49576 .26297 .48632 Metetra
0 .292 .787 r
.26297 .48632 .2708 .49576 .28153 .51097 .27425 .49398 Metetra
0 .089 .642 r
.27425 .49398 .28153 .51097 .2925 .52555 .28518 .50838 Metetra
.011 .194 .706 r
.28518 .50838 .2925 .52555 .30386 .53714 .29645 .5206 Metetra
.213 .339 .776 r
.29645 .5206 .30386 .53714 .31566 .5442 .30815 .52895 Metetra
.412 .481 .821 r
.30815 .52895 .31566 .5442 .32792 .54594 .32028 .53251 Metetra
.575 .598 .838 r
.32028 .53251 .32792 .54594 .34058 .54221 .33283 .53098 Metetra
.697 .688 .837 r
.33283 .53098 .34058 .54221 .35356 .5334 .34571 .52461 Metetra
.783 .757 .829 r
.34571 .52461 .35356 .5334 .36677 .5203 .35885 .51403 Metetra
.845 .814 .819 r
.35885 .51403 .36677 .5203 .38011 .50396 .37214 .50019 Metetra
.887 .864 .812 r
.37214 .50019 .38011 .50396 .3935 .48559 .38552 .48418 Metetra
.912 .913 .806 r
.38552 .48418 .3935 .48559 .40686 .46642 .3989 .46715 Metetra
.915 .958 .801 r
.3989 .46715 .40686 .46642 .42017 .44762 .41224 .45021 Metetra
.882 .992 .788 r
.41224 .45021 .42017 .44762 .43337 .43025 .42551 .43438 Metetra
.779 .988 .747 r
.42551 .43438 .43337 .43025 .44648 .4152 .4387 .42051 Metetra
.568 .897 .646 r
.4387 .42051 .44648 .4152 .45951 .40316 .45182 .40927 Metetra
.45182 .40927 .45951 .40316 .47247 .3946 .46488 .40113 Metetra
.043 0 0 r
.46488 .40113 .47247 .3946 .48542 .3898 .47793 .39636 Metetra
.272 0 0 r
.47793 .39636 .48542 .3898 .4984 .3888 .491 .39498 Metetra
.425 0 0 r
.491 .39498 .4984 .3888 .51144 .3914 .50413 .39682 Metetra
.522 .006 0 r
.50413 .39682 .51144 .3914 .52461 .3972 .51738 .40148 Metetra
.581 .057 0 r
.51738 .40148 .52461 .3972 .53794 .40557 .53076 .40833 Metetra
.608 .068 0 r
.53076 .40833 .53794 .40557 .55145 .41568 .54432 .41658 Metetra
.593 .028 0 r
.54432 .41658 .55145 .41568 .56515 .4265 .55805 .42524 Metetra
.501 0 0 r
.55805 .42524 .56515 .4265 .57905 .43688 .57195 .43321 Metetra
0 .327 .696 r
.57195 .43321 .57905 .43688 .5931 .44557 .586 .4393 Metetra
.198 .587 .943 r
.586 .4393 .5931 .44557 .60726 .4513 .60013 .44238 Metetra
.524 .687 .941 r
.60013 .44238 .60726 .4513 .62146 .45293 .61429 .44139 Metetra
.677 .694 .858 r
.61429 .44139 .62146 .45293 .63561 .44952 .62839 .43557 Metetra
.749 .684 .788 r
.62839 .43557 .63561 .44952 .64963 .44054 .64237 .42452 Metetra
.788 .675 .739 r
.64237 .42452 .64963 .44054 .66344 .42595 .65616 .40836 Metetra
.81 .669 .708 r
.65616 .40836 .66344 .42595 .677 .40637 .66972 .38786 Metetra
.821 .667 .691 r
.66972 .38786 .677 .40637 .69031 .38317 .68307 .36453 Metetra
.81 .661 .698 r
.68307 .36453 .69031 .38317 .70345 .35856 .69642 .34304 Metetra
.638 .611 .807 r
.69642 .34304 .70345 .35856 .71727 .34701 .71068 .33833 Metetra
.654 .753 .922 r
.71068 .33833 .71727 .34701 .73155 .34232 .72501 .33359 Metetra
.654 .753 .922 r
.72501 .33359 .73155 .34232 .7459 .3376 .73941 .32883 Metetra
.654 .753 .922 r
.73941 .32883 .7459 .3376 .76033 .33286 .75388 .32405 Metetra
.654 .753 .922 r
.75388 .32405 .76033 .33286 .77482 .3281 .76843 .31924 Metetra
.654 .753 .922 r
.76843 .31924 .77482 .3281 .78939 .32331 .78305 .31441 Metetra
.654 .753 .922 r
.78305 .31441 .78939 .32331 .80404 .3185 .79775 .30955 Metetra
.654 .753 .922 r
.79775 .30955 .80404 .3185 .81876 .31366 .81252 .30467 Metetra
.654 .753 .922 r
.15938 .51065 .16769 .51782 .17941 .51394 .17113 .50674 Metetra
.654 .753 .922 r
.17113 .50674 .17941 .51394 .19119 .51005 .18294 .50282 Metetra
.654 .753 .922 r
.18294 .50282 .19119 .51005 .20301 .50614 .1948 .49888 Metetra
.654 .753 .922 r
.1948 .49888 .20301 .50614 .21489 .50221 .20671 .49491 Metetra
.654 .753 .922 r
.20671 .49491 .21489 .50221 .22683 .49827 .21868 .49093 Metetra
.654 .753 .922 r
.21868 .49093 .22683 .49827 .23882 .4943 .2307 .48694 Metetra
.654 .753 .922 r
.2307 .48694 .23882 .4943 .25087 .49032 .24278 .48292 Metetra
.654 .753 .922 r
.24278 .48292 .25087 .49032 .26297 .48632 .25492 .47889 Metetra
.555 .721 .951 r
.25492 .47889 .26297 .48632 .27425 .49398 .26692 .47722 Metetra
0 .102 .652 r
.26692 .47722 .27425 .49398 .28518 .50838 .27785 .49109 Metetra
0 .179 .697 r
.27785 .49109 .28518 .50838 .29645 .5206 .28905 .50361 Metetra
.165 .302 .759 r
.28905 .50361 .29645 .5206 .30815 .52895 .30064 .51298 Metetra
.351 .435 .808 r
.30064 .51298 .30815 .52895 .32028 .53251 .31266 .51814 Metetra
.513 .553 .834 r
.31266 .51814 .32028 .53251 .33283 .53098 .32509 .51867 Metetra
.64 .648 .842 r
.32509 .51867 .33283 .53098 .34571 .52461 .33786 .51464 Metetra
.736 .725 .842 r
.33786 .51464 .34571 .52461 .35885 .51403 .35091 .50656 Metetra
.805 .79 .838 r
.35091 .50656 .35885 .51403 .37214 .50019 .36414 .49525 Metetra
.855 .848 .836 r
.36414 .49525 .37214 .50019 .38552 .48418 .37749 .48166 Metetra
.886 .903 .835 r
.37749 .48166 .38552 .48418 .3989 .46715 .39087 .46686 Metetra
.894 .954 .834 r
.39087 .46686 .3989 .46715 .41224 .45021 .40424 .45189 Metetra
.864 .993 .824 r
.40424 .45189 .41224 .45021 .42551 .43438 .41756 .43769 Metetra
.766 .992 .785 r
.41756 .43769 .42551 .43438 .4387 .42051 .43081 .42508 Metetra
.566 .909 .688 r
.43081 .42508 .4387 .42051 .45182 .40927 .44401 .4147 Metetra
.44401 .4147 .45182 .40927 .46488 .40113 .45717 .40702 Metetra
.001 0 0 r
.45717 .40702 .46488 .40113 .47793 .39636 .47031 .40227 Metetra
.219 0 0 r
.47031 .40227 .47793 .39636 .491 .39498 .48347 .4005 Metetra
.367 0 0 r
.48347 .4005 .491 .39498 .50413 .39682 .4967 .40152 Metetra
.461 0 0 r
.4967 .40152 .50413 .39682 .51738 .40148 .51002 .40495 Metetra
.513 0 0 r
.51002 .40495 .51738 .40148 .53076 .40833 .52348 .41019 Metetra
.523 0 0 r
.52348 .41019 .53076 .40833 .54432 .41658 .53708 .41648 Metetra
.469 0 0 r
.53708 .41648 .54432 .41658 .55805 .42524 .55085 .42287 Metetra
.291 0 0 r
.55085 .42287 .55805 .42524 .57195 .43321 .56476 .42835 Metetra
.066 .545 .895 r
.56476 .42835 .57195 .43321 .586 .4393 .5788 .43182 Metetra
.424 .681 .97 r
.5788 .43182 .586 .4393 .60013 .44238 .59291 .43224 Metetra
.62 .701 .903 r
.59291 .43224 .60013 .44238 .61429 .44139 .60704 .42871 Metetra
.715 .69 .825 r
.60704 .42871 .61429 .44139 .62839 .43557 .62111 .42061 Metetra
.764 .678 .767 r
.62111 .42061 .62839 .43557 .64237 .42452 .63506 .40769 Metetra
.793 .67 .728 r
.63506 .40769 .64237 .42452 .65616 .40836 .64883 .39023 Metetra
.81 .665 .703 r
.64883 .39023 .65616 .40836 .66972 .38786 .66241 .36913 Metetra
.819 .665 .691 r
.66241 .36913 .66972 .38786 .68307 .36453 .67581 .34605 Metetra
.726 .623 .744 r
.67581 .34605 .68307 .36453 .69642 .34304 .68971 .33433 Metetra
.654 .753 .922 r
.68971 .33433 .69642 .34304 .71068 .33833 .70402 .32957 Metetra
.654 .753 .922 r
.70402 .32957 .71068 .33833 .72501 .33359 .7184 .32479 Metetra
.654 .753 .922 r
.7184 .32479 .72501 .33359 .73941 .32883 .73285 .31998 Metetra
.654 .753 .922 r
.73285 .31998 .73941 .32883 .75388 .32405 .74738 .31515 Metetra
.654 .753 .922 r
.74738 .31515 .75388 .32405 .76843 .31924 .76198 .3103 Metetra
.654 .753 .922 r
.76198 .3103 .76843 .31924 .78305 .31441 .77665 .30542 Metetra
.654 .753 .922 r
.77665 .30542 .78305 .31441 .79775 .30955 .7914 .30052 Metetra
.654 .753 .922 r
.7914 .30052 .79775 .30955 .81252 .30467 .80623 .29559 Metetra
.654 .753 .922 r
.151 .50342 .15938 .51065 .17113 .50674 .16279 .49948 Metetra
.654 .753 .922 r
.16279 .49948 .17113 .50674 .18294 .50282 .17462 .49552 Metetra
.654 .753 .922 r
.17462 .49552 .18294 .50282 .1948 .49888 .18651 .49155 Metetra
.654 .753 .922 r
.18651 .49155 .1948 .49888 .20671 .49491 .19846 .48755 Metetra
.654 .753 .922 r
.19846 .48755 .20671 .49491 .21868 .49093 .21046 .48354 Metetra
.654 .753 .922 r
.21046 .48354 .21868 .49093 .2307 .48694 .22251 .47951 Metetra
.654 .753 .922 r
.22251 .47951 .2307 .48694 .24278 .48292 .23463 .47546 Metetra
.654 .753 .922 r
.23463 .47546 .24278 .48292 .25492 .47889 .2468 .47139 Metetra
.654 .753 .922 r
.2468 .47139 .25492 .47889 .26692 .47722 .25902 .4673 Metetra
.03 .365 .836 r
.25902 .4673 .26692 .47722 .27785 .49109 .27048 .47392 Metetra
0 .173 .695 r
.27048 .47392 .27785 .49109 .28905 .50361 .28164 .48639 Metetra
.127 .274 .746 r
.28164 .48639 .28905 .50361 .30064 .51298 .29315 .49647 Metetra
.295 .394 .794 r
.29315 .49647 .30064 .51298 .31266 .51814 .30505 .50297 Metetra
.451 .508 .826 r
.30505 .50297 .31266 .51814 .32509 .51867 .31736 .50534 Metetra
.581 .606 .842 r
.31736 .50534 .32509 .51867 .33786 .51464 .33002 .50351 Metetra
.681 .688 .85 r
.33002 .50351 .33786 .51464 .35091 .50656 .34296 .49785 Metetra
.758 .759 .853 r
.34296 .49785 .35091 .50656 .36414 .49525 .35612 .48901 Metetra
.814 .823 .857 r
.35612 .48901 .36414 .49525 .37749 .48166 .36942 .47785 Metetra
.851 .883 .862 r
.36942 .47785 .37749 .48166 .39087 .46686 .38278 .46531 Metetra
.865 .94 .867 r
.38278 .46531 .39087 .46686 .40424 .45189 .39616 .45235 Metetra
.843 .985 .864 r
.39616 .45235 .40424 .45189 .41756 .43769 .40951 .43984 Metetra
.759 .996 .835 r
.40951 .43984 .41756 .43769 .43081 .42508 .42283 .42854 Metetra
.585 .933 .754 r
.42283 .42854 .43081 .42508 .44401 .4147 .4361 .41908 Metetra
.4361 .41908 .44401 .4147 .45717 .40702 .44934 .41187 Metetra
.44934 .41187 .45717 .40702 .47031 .40227 .46258 .40715 Metetra
.137 0 0 r
.46258 .40715 .47031 .40227 .48347 .4005 .47584 .40496 Metetra
.281 0 0 r
.47584 .40496 .48347 .4005 .4967 .40152 .48915 .40512 Metetra
.368 0 0 r
.48915 .40512 .4967 .40152 .51002 .40495 .50256 .40727 Metetra
.405 0 0 r
.50256 .40727 .51002 .40495 .52348 .41019 .51608 .41084 Metetra
.38 0 0 r
.51608 .41084 .52348 .41019 .53708 .41648 .52974 .4151 Metetra
.256 0 0 r
.52974 .4151 .53708 .41648 .55085 .42287 .54354 .4192 Metetra
.016 .541 .856 r
.54354 .4192 .55085 .42287 .56476 .42835 .55748 .42217 Metetra
.346 .683 .979 r
.55748 .42217 .56476 .42835 .5788 .43182 .57151 .42303 Metetra
.566 .713 .941 r
.57151 .42303 .5788 .43182 .59291 .43224 .58561 .42088 Metetra
.679 .7 .863 r
.58561 .42088 .59291 .43224 .60704 .42871 .59972 .41495 Metetra
.739 .684 .798 r
.59972 .41495 .60704 .42871 .62111 .42061 .61376 .40476 Metetra
.774 .672 .751 r
.61376 .40476 .62111 .42061 .63506 .40769 .6277 .39022 Metetra
.796 .666 .72 r
.6277 .39022 .63506 .40769 .64883 .39023 .64147 .37176 Metetra
.81 .663 .701 r
.64147 .37176 .64883 .39023 .66241 .36913 .65508 .35042 Metetra
.8 .657 .705 r
.65508 .35042 .66241 .36913 .67581 .34605 .66866 .3303 Metetra
.637 .61 .806 r
.66866 .3303 .67581 .34605 .68971 .33433 .68294 .32552 Metetra
.654 .753 .922 r
.68294 .32552 .68971 .33433 .70402 .32957 .6973 .32072 Metetra
.654 .753 .922 r
.6973 .32072 .70402 .32957 .7184 .32479 .71173 .3159 Metetra
.654 .753 .922 r
.71173 .3159 .7184 .32479 .73285 .31998 .72623 .31105 Metetra
.654 .753 .922 r
.72623 .31105 .73285 .31998 .74738 .31515 .74081 .30617 Metetra
.654 .753 .922 r
.74081 .30617 .74738 .31515 .76198 .3103 .75546 .30127 Metetra
.654 .753 .922 r
.75546 .30127 .76198 .3103 .77665 .30542 .77019 .29635 Metetra
.654 .753 .922 r
.77019 .29635 .77665 .30542 .7914 .30052 .78499 .2914 Metetra
.654 .753 .922 r
.78499 .2914 .7914 .30052 .80623 .29559 .79987 .28642 Metetra
.654 .753 .922 r
.14255 .49614 .151 .50342 .16279 .49948 .15437 .49216 Metetra
.654 .753 .922 r
.15437 .49216 .16279 .49948 .17462 .49552 .16623 .48817 Metetra
.654 .753 .922 r
.16623 .48817 .17462 .49552 .18651 .49155 .17815 .48416 Metetra
.654 .753 .922 r
.17815 .48416 .18651 .49155 .19846 .48755 .19013 .48013 Metetra
.654 .753 .922 r
.19013 .48013 .19846 .48755 .21046 .48354 .20216 .47608 Metetra
.654 .753 .922 r
.20216 .47608 .21046 .48354 .22251 .47951 .21425 .47201 Metetra
.654 .753 .922 r
.21425 .47201 .22251 .47951 .23463 .47546 .2264 .46793 Metetra
.654 .753 .922 r
.2264 .46793 .23463 .47546 .2468 .47139 .2386 .46382 Metetra
.654 .753 .922 r
.2386 .46382 .2468 .47139 .25902 .4673 .25086 .4597 Metetra
.597 .736 .941 r
.25086 .4597 .25902 .4673 .27048 .47392 .26306 .45706 Metetra
0 .18 .701 r
.26306 .45706 .27048 .47392 .28164 .48639 .2742 .46915 Metetra
.098 .256 .738 r
.2742 .46915 .28164 .48639 .29315 .49647 .28564 .4796 Metetra
.247 .36 .782 r
.28564 .4796 .29315 .49647 .30505 .50297 .29745 .48715 Metetra
.393 .465 .816 r
.29745 .48715 .30505 .50297 .31736 .50534 .30964 .4911 Metetra
.52 .562 .838 r
.30964 .4911 .31736 .50534 .33002 .50351 .32218 .49126 Metetra
.623 .646 .852 r
.32218 .49126 .33002 .50351 .34296 .49785 .33502 .48785 Metetra
.703 .72 .862 r
.33502 .48785 .34296 .49785 .35612 .48901 .34809 .48139 Metetra
.765 .788 .872 r
.34809 .48139 .35612 .48901 .36942 .47785 .36133 .47259 Metetra
.807 .852 .883 r
.36133 .47259 .36942 .47785 .38278 .46531 .37466 .46229 Metetra
.829 .913 .895 r
.37466 .46229 .38278 .46531 .39616 .45235 .38803 .45134 Metetra
.818 .965 .901 r
.38803 .45134 .39616 .45235 .40951 .43984 .40141 .44053 Metetra
.755 .99 .889 r
.40141 .44053 .40951 .43984 .42283 .42854 .41477 .43057 Metetra
.618 .957 .836 r
.41477 .43057 .42283 .42854 .4361 .41908 .4281 .42202 Metetra
.41 .848 .731 r
.4281 .42202 .4361 .41908 .44934 .41187 .44142 .4153 Metetra
.44142 .4153 .44934 .41187 .46258 .40715 .45475 .41061 Metetra
.012 0 0 r
.45475 .41061 .46258 .40715 .47584 .40496 .4681 .40799 Metetra
.146 0 0 r
.4681 .40799 .47584 .40496 .48915 .40512 .4815 .40727 Metetra
.218 0 0 r
.4815 .40727 .48915 .40512 .50256 .40727 .49499 .40811 Metetra
.224 0 0 r
.49499 .40811 .50256 .40727 .51608 .41084 .50858 .40999 Metetra
.141 0 0 r
.50858 .40999 .51608 .41084 .52974 .4151 .5223 .41223 Metetra
.056 .591 .858 r
.5223 .41223 .52974 .4151 .54354 .4192 .53614 .41404 Metetra
.32 .703 .98 r
.53614 .41404 .54354 .4192 .55748 .42217 .5501 .41455 Metetra
.529 .732 .967 r
.5501 .41455 .55748 .42217 .57151 .42303 .56415 .41291 Metetra
.649 .716 .897 r
.56415 .41291 .57151 .42303 .58561 .42088 .57824 .40832 Metetra
.716 .694 .828 r
.57824 .40832 .58561 .42088 .59972 .41495 .59233 .40018 Metetra
.755 .678 .776 r
.59233 .40018 .59972 .41495 .61376 .40476 .60637 .38816 Metetra
.781 .668 .739 r
.60637 .38816 .61376 .40476 .6277 .39022 .6203 .37231 Metetra
.798 .663 .714 r
.6203 .37231 .6277 .39022 .64147 .37176 .63409 .35319 Metetra
.809 .662 .701 r
.63409 .35319 .64147 .37176 .65508 .35042 .64773 .33196 Metetra
.711 .618 .751 r
.64773 .33196 .65508 .35042 .66866 .3303 .66177 .32146 Metetra
.654 .753 .922 r
.66177 .32146 .66866 .3303 .68294 .32552 .67611 .31664 Metetra
.654 .753 .922 r
.67611 .31664 .68294 .32552 .6973 .32072 .69051 .31179 Metetra
.654 .753 .922 r
.69051 .31179 .6973 .32072 .71173 .3159 .705 .30692 Metetra
.654 .753 .922 r
.705 .30692 .71173 .3159 .72623 .31105 .71955 .30203 Metetra
.654 .753 .922 r
.71955 .30203 .72623 .31105 .74081 .30617 .73418 .29711 Metetra
.654 .753 .922 r
.73418 .29711 .74081 .30617 .75546 .30127 .74888 .29216 Metetra
.654 .753 .922 r
.74888 .29216 .75546 .30127 .77019 .29635 .76367 .28719 Metetra
.654 .753 .922 r
.76367 .28719 .77019 .29635 .78499 .2914 .77852 .28219 Metetra
.654 .753 .922 r
.77852 .28219 .78499 .2914 .79987 .28642 .79346 .27716 Metetra
.654 .753 .922 r
.13403 .48878 .14255 .49614 .15437 .49216 .14588 .48478 Metetra
.654 .753 .922 r
.14588 .48478 .15437 .49216 .16623 .48817 .15777 .48075 Metetra
.654 .753 .922 r
.15777 .48075 .16623 .48817 .17815 .48416 .16973 .47671 Metetra
.654 .753 .922 r
.16973 .47671 .17815 .48416 .19013 .48013 .18174 .47264 Metetra
.654 .753 .922 r
.18174 .47264 .19013 .48013 .20216 .47608 .1938 .46856 Metetra
.654 .753 .922 r
.1938 .46856 .20216 .47608 .21425 .47201 .20592 .46446 Metetra
.654 .753 .922 r
.20592 .46446 .21425 .47201 .2264 .46793 .2181 .46033 Metetra
.654 .753 .922 r
.2181 .46033 .2264 .46793 .2386 .46382 .23034 .45619 Metetra
.654 .753 .922 r
.23034 .45619 .2386 .46382 .25086 .4597 .24263 .45203 Metetra
.654 .753 .922 r
.24263 .45203 .25086 .4597 .26306 .45706 .25498 .44785 Metetra
.191 .493 .903 r
.25498 .44785 .26306 .45706 .2742 .46915 .26673 .45209 Metetra
.082 .249 .737 r
.26673 .45209 .2742 .46915 .28564 .4796 .27813 .46258 Metetra
.209 .334 .772 r
.27813 .46258 .28564 .4796 .29745 .48715 .28985 .47084 Metetra
.342 .428 .806 r
.28985 .47084 .29745 .48715 .30964 .4911 .30193 .47608 Metetra
.462 .519 .831 r
.30193 .47608 .30964 .4911 .32218 .49126 .31436 .47797 Metetra
.564 .602 .849 r
.31436 .47797 .32218 .49126 .33502 .48785 .32709 .4766 Metetra
.646 .676 .865 r
.32709 .4766 .33502 .48785 .34809 .48139 .34007 .47234 Metetra
.71 .745 .879 r
.34007 .47234 .34809 .48139 .36133 .47259 .35323 .46579 Metetra
.756 .811 .896 r
.35323 .46579 .36133 .47259 .37466 .46229 .36651 .45764 Metetra
.784 .873 .913 r
.36651 .45764 .37466 .46229 .38803 .45134 .37986 .44864 Metetra
.785 .929 .929 r
.37986 .44864 .38803 .45134 .40141 .44053 .39325 .4395 Metetra
.746 .966 .934 r
.39325 .4395 .40141 .44053 .41477 .43057 .40664 .43086 Metetra
.652 .965 .912 r
.40664 .43086 .41477 .43057 .4281 .42202 .42003 .42324 Metetra
.501 .908 .853 r
.42003 .42324 .4281 .42202 .44142 .4153 .43342 .41699 Metetra
.323 .806 .77 r
.43342 .41699 .44142 .4153 .45475 .41061 .44683 .41233 Metetra
.163 .696 .697 r
.44683 .41233 .45475 .41061 .4681 .40799 .46026 .40928 Metetra
.46026 .40928 .4681 .40799 .4815 .40727 .47376 .40769 Metetra
.47376 .40769 .4815 .40727 .49499 .40811 .48733 .40723 Metetra
.05 .614 .78 r
.48733 .40723 .49499 .40811 .50858 .40999 .50099 .40743 Metetra
.175 .683 .903 r
.50099 .40743 .50858 .40999 .5223 .41223 .51477 .40769 Metetra
.357 .744 .987 r
.51477 .40769 .5223 .41223 .53614 .41404 .52866 .40728 Metetra
.522 .756 .982 r
.52866 .40728 .53614 .41404 .5501 .41455 .54264 .40544 Metetra
.631 .734 .922 r
.54264 .40544 .5501 .41455 .56415 .41291 .5567 .40145 Metetra
.697 .707 .856 r
.5567 .40145 .56415 .41291 .57824 .40832 .5708 .39464 Metetra
.738 .686 .801 r
.5708 .39464 .57824 .40832 .59233 .40018 .58489 .38454 Metetra
.766 .673 .76 r
.58489 .38454 .59233 .40018 .60637 .38816 .59893 .37098 Metetra
.786 .665 .73 r
.59893 .37098 .60637 .38816 .6203 .37231 .61286 .35414 Metetra
.799 .662 .712 r
.61286 .35414 .6203 .37231 .63409 .35319 .62668 .33471 Metetra
.781 .652 .72 r
.62668 .33471 .63409 .35319 .64773 .33196 .64052 .31738 Metetra
.641 .631 .825 r
.64052 .31738 .64773 .33196 .66177 .32146 .65483 .31254 Metetra
.654 .753 .922 r
.65483 .31254 .66177 .32146 .67611 .31664 .66921 .30767 Metetra
.654 .753 .922 r
.66921 .30767 .67611 .31664 .69051 .31179 .68367 .30278 Metetra
.654 .753 .922 r
.68367 .30278 .69051 .31179 .705 .30692 .6982 .29786 Metetra
.654 .753 .922 r
.6982 .29786 .705 .30692 .71955 .30203 .71281 .29292 Metetra
.654 .753 .922 r
.71281 .29292 .71955 .30203 .73418 .29711 .72749 .28795 Metetra
.654 .753 .922 r
.72749 .28795 .73418 .29711 .74888 .29216 .74224 .28296 Metetra
.654 .753 .922 r
.74224 .28296 .74888 .29216 .76367 .28719 .75708 .27794 Metetra
.654 .753 .922 r
.75708 .27794 .76367 .28719 .77852 .28219 .77199 .27289 Metetra
.654 .753 .922 r
.77199 .27289 .77852 .28219 .79346 .27716 .78698 .26782 Metetra
.654 .753 .922 r
.12544 .48137 .13403 .48878 .14588 .48478 .13731 .47733 Metetra
.654 .753 .922 r
.13731 .47733 .14588 .48478 .15777 .48075 .14924 .47327 Metetra
.654 .753 .922 r
.14924 .47327 .15777 .48075 .16973 .47671 .16122 .46919 Metetra
.654 .753 .922 r
.16122 .46919 .16973 .47671 .18174 .47264 .17327 .46509 Metetra
.654 .753 .922 r
.17327 .46509 .18174 .47264 .1938 .46856 .18536 .46097 Metetra
.654 .753 .922 r
.18536 .46097 .1938 .46856 .20592 .46446 .19752 .45683 Metetra
.654 .753 .922 r
.19752 .45683 .20592 .46446 .2181 .46033 .20973 .45267 Metetra
.654 .753 .922 r
.20973 .45267 .2181 .46033 .23034 .45619 .222 .4485 Metetra
.654 .753 .922 r
.222 .4485 .23034 .45619 .24263 .45203 .23433 .4443 Metetra
.654 .753 .922 r
.23433 .4443 .24263 .45203 .25498 .44785 .24672 .44008 Metetra
.654 .753 .922 r
.24672 .44008 .25498 .44785 .26673 .45209 .25916 .43585 Metetra
.089 .268 .752 r
.25916 .43585 .26673 .45209 .27813 .46258 .27058 .44558 Metetra
.182 .318 .767 r
.27058 .44558 .27813 .46258 .28985 .47084 .28224 .45422 Metetra
.299 .398 .797 r
.28224 .45422 .28985 .47084 .30193 .47608 .29423 .46042 Metetra
.41 .481 .822 r
.29423 .46042 .30193 .47608 .31436 .47797 .30655 .46374 Metetra
.507 .558 .843 r
.30655 .46374 .31436 .47797 .32709 .4766 .31917 .46415 Metetra
.588 .63 .861 r
.31917 .46415 .32709 .4766 .34007 .47234 .33205 .46188 Metetra
.652 .697 .879 r
.33205 .46188 .34007 .47234 .35323 .46579 .34513 .45739 Metetra
.701 .761 .898 r
.34513 .45739 .35323 .46579 .36651 .45764 .35836 .45126 Metetra
.733 .822 .92 r
.35836 .45126 .36651 .45764 .37986 .44864 .37168 .44411 Metetra
.744 .878 .941 r
.37168 .44411 .37986 .44864 .39325 .4395 .38506 .43658 Metetra
.727 .922 .958 r
.38506 .43658 .39325 .4395 .40664 .43086 .39848 .42921 Metetra
.673 .943 .962 r
.39848 .42921 .40664 .43086 .42003 .42324 .41191 .42248 Metetra
.581 .931 .946 r
.41191 .42248 .42003 .42324 .43342 .41699 .42537 .4167 Metetra
.467 .887 .914 r
.42537 .4167 .43342 .41699 .44683 .41233 .43884 .41206 Metetra
.361 .831 .885 r
.43884 .41206 .44683 .41233 .46026 .40928 .45236 .40858 Metetra
.295 .787 .881 r
.45236 .40858 .46026 .40928 .47376 .40769 .46593 .40613 Metetra
.287 .773 .912 r
.46593 .40613 .47376 .40769 .48733 .40723 .47958 .40441 Metetra
.341 .782 .963 r
.47958 .40441 .48733 .40723 .50099 .40743 .49332 .403 Metetra
.441 .792 .997 r
.49332 .403 .50099 .40743 .51477 .40769 .50716 .40136 Metetra
.546 .781 .985 r
.50716 .40136 .51477 .40769 .52866 .40728 .5211 .39886 Metetra
.629 .753 .936 r
.5211 .39886 .52866 .40728 .54264 .40544 .53512 .39484 Metetra
.686 .722 .877 r
.53512 .39484 .54264 .40544 .5567 .40145 .5492 .3887 Metetra
.725 .696 .823 r
.5492 .3887 .5567 .40145 .5708 .39464 .56331 .37992 Metetra
.753 .679 .78 r
.56331 .37992 .5708 .39464 .58489 .38454 .5774 .36816 Metetra
.773 .668 .748 r
.5774 .36816 .58489 .38454 .59893 .37098 .59145 .35338 Metetra
.788 .663 .725 r
.59145 .35338 .59893 .37098 .61286 .35414 .6054 .33591 Metetra
.799 .662 .712 r
.6054 .33591 .61286 .35414 .62668 .33471 .61926 .31652 Metetra
.681 .607 .766 r
.61926 .31652 .62668 .33471 .64052 .31738 .63345 .30842 Metetra
.654 .753 .922 r
.63345 .30842 .64052 .31738 .65483 .31254 .64781 .30354 Metetra
.654 .753 .922 r
.64781 .30354 .65483 .31254 .66921 .30767 .66225 .29862 Metetra
.654 .753 .922 r
.66225 .29862 .66921 .30767 .68367 .30278 .67675 .29368 Metetra
.654 .753 .922 r
.67675 .29368 .68367 .30278 .6982 .29786 .69134 .28872 Metetra
.654 .753 .922 r
.69134 .28872 .6982 .29786 .71281 .29292 .706 .28373 Metetra
.654 .753 .922 r
.706 .28373 .71281 .29292 .72749 .28795 .72073 .27871 Metetra
.654 .753 .922 r
.72073 .27871 .72749 .28795 .74224 .28296 .73554 .27367 Metetra
.654 .753 .922 r
.73554 .27367 .74224 .28296 .75708 .27794 .75043 .2686 Metetra
.654 .753 .922 r
.75043 .2686 .75708 .27794 .77199 .27289 .7654 .26351 Metetra
.654 .753 .922 r
.7654 .26351 .77199 .27289 .78698 .26782 .78044 .25838 Metetra
.654 .753 .922 r
.11677 .47389 .12544 .48137 .13731 .47733 .12867 .46982 Metetra
.654 .753 .922 r
.12867 .46982 .13731 .47733 .14924 .47327 .14063 .46572 Metetra
.654 .753 .922 r
.14063 .46572 .14924 .47327 .16122 .46919 .15265 .4616 Metetra
.654 .753 .922 r
.15265 .4616 .16122 .46919 .17327 .46509 .16472 .45747 Metetra
.654 .753 .922 r
.16472 .45747 .17327 .46509 .18536 .46097 .17685 .45332 Metetra
.654 .753 .922 r
.17685 .45332 .18536 .46097 .19752 .45683 .18904 .44914 Metetra
.654 .753 .922 r
.18904 .44914 .19752 .45683 .20973 .45267 .20129 .44495 Metetra
.654 .753 .922 r
.20129 .44495 .20973 .45267 .222 .4485 .21359 .44073 Metetra
.654 .753 .922 r
.21359 .44073 .222 .4485 .23433 .4443 .22595 .4365 Metetra
.654 .753 .922 r
.22595 .4365 .23433 .4443 .24672 .44008 .23837 .43225 Metetra
.654 .753 .922 r
.23837 .43225 .24672 .44008 .25916 .43585 .25085 .42797 Metetra
.398 .652 .96 r
.25085 .42797 .25916 .43585 .27058 .44558 .26298 .42879 Metetra
.167 .312 .768 r
.26298 .42879 .27058 .44558 .28224 .45422 .27461 .43746 Metetra
.266 .377 .791 r
.27461 .43746 .28224 .45422 .29423 .46042 .28652 .44428 Metetra
.366 .449 .813 r
.28652 .44428 .29423 .46042 .30655 .46374 .29875 .44872 Metetra
.457 .519 .834 r
.29875 .44872 .30655 .46374 .31917 .46415 .31127 .45061 Metetra
.534 .586 .853 r
.31127 .45061 .31917 .46415 .33205 .46188 .32406 .45007 Metetra
.597 .649 .872 r
.32406 .45007 .33205 .46188 .34513 .45739 .33705 .44741 Metetra
.647 .709 .893 r
.33705 .44741 .34513 .45739 .35836 .45126 .35022 .44311 Metetra
.682 .765 .915 r
.35022 .44311 .35836 .45126 .37168 .44411 .3635 .43768 Metetra
.7 .818 .938 r
.3635 .43768 .37168 .44411 .38506 .43658 .37687 .43163 Metetra
.699 .862 .96 r
.37687 .43163 .38506 .43658 .39848 .42921 .39029 .42546 Metetra
.676 .893 .976 r
.39029 .42546 .39848 .42921 .41191 .42248 .40376 .41956 Metetra
.63 .905 .984 r
.40376 .41956 .41191 .42248 .42537 .4167 .41726 .41422 Metetra
.573 .898 .984 r
.41726 .41422 .42537 .4167 .43884 .41206 .43081 .4096 Metetra
.52 .878 .983 r
.43081 .4096 .43884 .41206 .45236 .40858 .4444 .40571 Metetra
.492 .858 .988 r
.4444 .40571 .45236 .40858 .46593 .40613 .45805 .40244 Metetra
.499 .84 .997 r
.45805 .40244 .46593 .40613 .47958 .40441 .47178 .39953 Metetra
.537 .822 .998 r
.47178 .39953 .47958 .40441 .49332 .403 .48559 .39661 Metetra
.59 .797 .979 r
.48559 .39661 .49332 .403 .50716 .40136 .49949 .3932 Metetra
.642 .765 .938 r
.49949 .3932 .50716 .40136 .5211 .39886 .51347 .38877 Metetra
.684 .733 .888 r
.51347 .38877 .5211 .39886 .53512 .39484 .52753 .3828 Metetra
.717 .706 .839 r
.52753 .3828 .53512 .39484 .5492 .3887 .54163 .37477 Metetra
.742 .686 .797 r
.54163 .37477 .5492 .3887 .56331 .37992 .55576 .3643 Metetra
.761 .672 .764 r
.55576 .3643 .56331 .37992 .5774 .36816 .56987 .35121 Metetra
.777 .665 .739 r
.56987 .35121 .5774 .36816 .59145 .35338 .58393 .33556 Metetra
.789 .662 .723 r
.58393 .33556 .59145 .35338 .6054 .33591 .59792 .3178 Metetra
.748 .641 .742 r
.59792 .3178 .6054 .33591 .61926 .31652 .61199 .30429 Metetra
.649 .678 .864 r
.61199 .30429 .61926 .31652 .63345 .30842 .62632 .29938 Metetra
.654 .753 .922 r
.62632 .29938 .63345 .30842 .64781 .30354 .64073 .29444 Metetra
.654 .753 .922 r
.64073 .29444 .64781 .30354 .66225 .29862 .65522 .28948 Metetra
.654 .753 .922 r
.65522 .28948 .66225 .29862 .67675 .29368 .66978 .2845 Metetra
.654 .753 .922 r
.66978 .2845 .67675 .29368 .69134 .28872 .68441 .27949 Metetra
.654 .753 .922 r
.68441 .27949 .69134 .28872 .706 .28373 .69912 .27445 Metetra
.654 .753 .922 r
.69912 .27445 .706 .28373 .72073 .27871 .71391 .26938 Metetra
.654 .753 .922 r
.71391 .26938 .72073 .27871 .73554 .27367 .72877 .26429 Metetra
.654 .753 .922 r
.72877 .26429 .73554 .27367 .75043 .2686 .74372 .25917 Metetra
.654 .753 .922 r
.74372 .25917 .75043 .2686 .7654 .26351 .75874 .25403 Metetra
.654 .753 .922 r
.75874 .25403 .7654 .26351 .78044 .25838 .77384 .24886 Metetra
.654 .753 .922 r
.10802 .46635 .11677 .47389 .12867 .46982 .11996 .46224 Metetra
.654 .753 .922 r
.11996 .46224 .12867 .46982 .14063 .46572 .13195 .45811 Metetra
.654 .753 .922 r
.13195 .45811 .14063 .46572 .15265 .4616 .144 .45396 Metetra
.654 .753 .922 r
.144 .45396 .15265 .4616 .16472 .45747 .15611 .44979 Metetra
.654 .753 .922 r
.15611 .44979 .16472 .45747 .17685 .45332 .16827 .44559 Metetra
.654 .753 .922 r
.16827 .44559 .17685 .45332 .18904 .44914 .18049 .44138 Metetra
.654 .753 .922 r
.18049 .44138 .18904 .44914 .20129 .44495 .19277 .43715 Metetra
.654 .753 .922 r
.19277 .43715 .20129 .44495 .21359 .44073 .20511 .4329 Metetra
.654 .753 .922 r
.20511 .4329 .21359 .44073 .22595 .4365 .2175 .42863 Metetra
.654 .753 .922 r
.2175 .42863 .22595 .4365 .23837 .43225 .22996 .42434 Metetra
.654 .753 .922 r
.22996 .42434 .23837 .43225 .25085 .42797 .24247 .42003 Metetra
.654 .753 .922 r
.24247 .42003 .25085 .42797 .26298 .42879 .25505 .41569 Metetra
.263 .443 .851 r
.25505 .41569 .26298 .42879 .27461 .43746 .26694 .42076 Metetra
.245 .366 .788 r
.26694 .42076 .27461 .43746 .28652 .44428 .2788 .42786 Metetra
.332 .425 .807 r
.2788 .42786 .28652 .44428 .29875 .44872 .29095 .43306 Metetra
.415 .487 .825 r
.29095 .43306 .29875 .44872 .31127 .45061 .30339 .43611 Metetra
.487 .547 .843 r
.30339 .43611 .31127 .45061 .32406 .45007 .31608 .437 Metetra
.548 .604 .862 r
.31608 .437 .32406 .45007 .33705 .44741 .32899 .43592 Metetra
.597 .658 .881 r
.32899 .43592 .33705 .44741 .35022 .44311 .34209 .43323 Metetra
.633 .709 .901 r
.34209 .43323 .35022 .44311 .3635 .43768 .35533 .42932 Metetra
.657 .756 .923 r
.35533 .42932 .3635 .43768 .37687 .43163 .36867 .42462 Metetra
.668 .797 .944 r
.36867 .42462 .37687 .43163 .39029 .42546 .3821 .41954 Metetra
.664 .829 .962 r
.3821 .41954 .39029 .42546 .40376 .41956 .39559 .41441 Metetra
.649 .849 .977 r
.39559 .41441 .40376 .41956 .41726 .41422 .40914 .40947 Metetra
.627 .855 .986 r
.40914 .40947 .41726 .41422 .43081 .4096 .42274 .40485 Metetra
.609 .851 .99 r
.42274 .40485 .43081 .4096 .4444 .40571 .43639 .40058 Metetra
.602 .839 .989 r
.43639 .40058 .4444 .40571 .45805 .40244 .45012 .39655 Metetra
.611 .82 .98 r
.45012 .39655 .45805 .40244 .47178 .39953 .46392 .39254 Metetra
.632 .795 .96 r
.46392 .39254 .47178 .39953 .48559 .39661 .47779 .38823 Metetra
.66 .767 .929 r
.47779 .38823 .48559 .39661 .49949 .3932 .49175 .38323 Metetra
.688 .738 .889 r
.49175 .38323 .49949 .3932 .51347 .38877 .50579 .3771 Metetra
.712 .712 .848 r
.50579 .3771 .51347 .38877 .52753 .3828 .51988 .3694 Metetra
.734 .691 .81 r
.51988 .3694 .52753 .3828 .54163 .37477 .53402 .35977 Metetra
.751 .677 .778 r
.53402 .35977 .54163 .37477 .55576 .3643 .54817 .34795 Metetra
.767 .667 .753 r
.54817 .34795 .55576 .3643 .56987 .35121 .56231 .33386 Metetra
.779 .663 .735 r
.56231 .33386 .56987 .35121 .58393 .33556 .5764 .3177 Metetra
.788 .662 .724 r
.5764 .3177 .58393 .33556 .59792 .3178 .59043 .30014 Metetra
.63 .588 .788 r
.59043 .30014 .59792 .3178 .61199 .30429 .60474 .29521 Metetra
.654 .753 .922 r
.60474 .29521 .61199 .30429 .62632 .29938 .61912 .29025 Metetra
.654 .753 .922 r
.61912 .29025 .62632 .29938 .64073 .29444 .63358 .28527 Metetra
.654 .753 .922 r
.63358 .28527 .64073 .29444 .65522 .28948 .64812 .28026 Metetra
.654 .753 .922 r
.64812 .28026 .65522 .28948 .66978 .2845 .66273 .27522 Metetra
.654 .753 .922 r
.66273 .27522 .66978 .2845 .68441 .27949 .67742 .27016 Metetra
.654 .753 .922 r
.67742 .27016 .68441 .27949 .69912 .27445 .69218 .26508 Metetra
.654 .753 .922 r
.69218 .26508 .69912 .27445 .71391 .26938 .70702 .25996 Metetra
.654 .753 .922 r
.70702 .25996 .71391 .26938 .72877 .26429 .72194 .25482 Metetra
.654 .753 .922 r
.72194 .25482 .72877 .26429 .74372 .25917 .73694 .24966 Metetra
.654 .753 .922 r
.73694 .24966 .74372 .25917 .75874 .25403 .75201 .24446 Metetra
.654 .753 .922 r
.75201 .24446 .75874 .25403 .77384 .24886 .76717 .23924 Metetra
.654 .753 .922 r
.0992 .45874 .10802 .46635 .11996 .46224 .11117 .4546 Metetra
.654 .753 .922 r
.11117 .4546 .11996 .46224 .13195 .45811 .12319 .45043 Metetra
.654 .753 .922 r
.12319 .45043 .13195 .45811 .144 .45396 .13527 .44624 Metetra
.654 .753 .922 r
.13527 .44624 .144 .45396 .15611 .44979 .14741 .44203 Metetra
.654 .753 .922 r
.14741 .44203 .15611 .44979 .16827 .44559 .15961 .4378 Metetra
.654 .753 .922 r
.15961 .4378 .16827 .44559 .18049 .44138 .17186 .43356 Metetra
.654 .753 .922 r
.17186 .43356 .18049 .44138 .19277 .43715 .18417 .42929 Metetra
.654 .753 .922 r
.18417 .42929 .19277 .43715 .20511 .4329 .19655 .425 Metetra
.654 .753 .922 r
.19655 .425 .20511 .4329 .2175 .42863 .20898 .42069 Metetra
.654 .753 .922 r
.20898 .42069 .2175 .42863 .22996 .42434 .22147 .41636 Metetra
.654 .753 .922 r
.22147 .41636 .22996 .42434 .24247 .42003 .23402 .41201 Metetra
.654 .753 .922 r
.23402 .41201 .24247 .42003 .25505 .41569 .24663 .40764 Metetra
.618 .742 .935 r
.24663 .40764 .25505 .41569 .26694 .42076 .25922 .40426 Metetra
.236 .365 .791 r
.25922 .40426 .26694 .42076 .2788 .42786 .27106 .41132 Metetra
.31 .411 .803 r
.27106 .41132 .2788 .42786 .29095 .43306 .28315 .41696 Metetra
.383 .462 .818 r
.28315 .41696 .29095 .43306 .30339 .43611 .29551 .42083 Metetra
.449 .514 .833 r
.29551 .42083 .30339 .43611 .31608 .437 .30812 .42283 Metetra
.506 .565 .849 r
.30812 .42283 .31608 .437 .32899 .43592 .32096 .42305 Metetra
.554 .613 .866 r
.32096 .42305 .32899 .43592 .34209 .43323 .33399 .42171 Metetra
.591 .658 .884 r
.33399 .42171 .34209 .43323 .35533 .42932 .34718 .41911 Metetra
.619 .699 .902 r
.34718 .41911 .35533 .42932 .36867 .42462 .3605 .41559 Metetra
.637 .735 .919 r
.3605 .41559 .36867 .42462 .3821 .41954 .37392 .41147 Metetra
.646 .764 .935 r
.37392 .41147 .3821 .41954 .39559 .41441 .38742 .40701 Metetra
.648 .785 .947 r
.38742 .40701 .39559 .41441 .40914 .40947 .401 .40242 Metetra
.647 .795 .954 r
.401 .40242 .40914 .40947 .42274 .40485 .41465 .39781 Metetra
.646 .796 .955 r
.41465 .39781 .42274 .40485 .43639 .40058 .42837 .39319 Metetra
.65 .789 .948 r
.42837 .39319 .43639 .40058 .45012 .39655 .44215 .38847 Metetra
.66 .774 .934 r
.44215 .38847 .45012 .39655 .46392 .39254 .45602 .38347 Metetra
.675 .755 .911 r
.45602 .38347 .46392 .39254 .47779 .38823 .46996 .37794 Metetra
.693 .733 .882 r
.46996 .37794 .47779 .38823 .49175 .38323 .48397 .37154 Metetra
.71 .712 .849 r
.48397 .37154 .49175 .38323 .50579 .3771 .49806 .36394 Metetra
.727 .693 .817 r
.49806 .36394 .50579 .3771 .51988 .3694 .51219 .35481 Metetra
.743 .679 .789 r
.51219 .35481 .51988 .3694 .53402 .35977 .52636 .3439 Metetra
.757 .669 .765 r
.52636 .3439 .53402 .35977 .54817 .34795 .54054 .33105 Metetra
.769 .663 .746 r
.54054 .33105 .54817 .34795 .56231 .33386 .55471 .31631 Metetra
.78 .662 .733 r
.55471 .31631 .56231 .33386 .5764 .3177 .56883 .29997 Metetra
.695 .621 .77 r
.56883 .29997 .5764 .3177 .59043 .30014 .58306 .29101 Metetra
.654 .753 .922 r
.58306 .29101 .59043 .30014 .60474 .29521 .59742 .28603 Metetra
.654 .753 .922 r
.59742 .28603 .60474 .29521 .61912 .29025 .61186 .28103 Metetra
.654 .753 .922 r
.61186 .28103 .61912 .29025 .63358 .28527 .62637 .276 Metetra
.654 .753 .922 r
.62637 .276 .63358 .28527 .64812 .28026 .64095 .27094 Metetra
.654 .753 .922 r
.64095 .27094 .64812 .28026 .66273 .27522 .65562 .26586 Metetra
.654 .753 .922 r
.65562 .26586 .66273 .27522 .67742 .27016 .67036 .26075 Metetra
.654 .753 .922 r
.67036 .26075 .67742 .27016 .69218 .26508 .68517 .25562 Metetra
.654 .753 .922 r
.68517 .25562 .69218 .26508 .70702 .25996 .70007 .25045 Metetra
.654 .753 .922 r
.70007 .25045 .70702 .25996 .72194 .25482 .71504 .24526 Metetra
.654 .753 .922 r
.71504 .24526 .72194 .25482 .73694 .24966 .73009 .24004 Metetra
.654 .753 .922 r
.73009 .24004 .73694 .24966 .75201 .24446 .74522 .2348 Metetra
.654 .753 .922 r
.74522 .2348 .75201 .24446 .76717 .23924 .76044 .22952 Metetra
.654 .753 .922 r
.09031 .45107 .0992 .45874 .11117 .4546 .10231 .44689 Metetra
.654 .753 .922 r
.10231 .44689 .11117 .4546 .12319 .45043 .11436 .44268 Metetra
.654 .753 .922 r
.11436 .44268 .12319 .45043 .13527 .44624 .12647 .43846 Metetra
.654 .753 .922 r
.12647 .43846 .13527 .44624 .14741 .44203 .13864 .43421 Metetra
.654 .753 .922 r
.13864 .43421 .14741 .44203 .15961 .4378 .15087 .42995 Metetra
.654 .753 .922 r
.15087 .42995 .15961 .4378 .17186 .43356 .16316 .42566 Metetra
.654 .753 .922 r
.16316 .42566 .17186 .43356 .18417 .42929 .17551 .42136 Metetra
.654 .753 .922 r
.17551 .42136 .18417 .42929 .19655 .425 .18791 .41703 Metetra
.654 .753 .922 r
.18791 .41703 .19655 .425 .20898 .42069 .20038 .41268 Metetra
.654 .753 .922 r
.20038 .41268 .20898 .42069 .22147 .41636 .2129 .40831 Metetra
.654 .753 .922 r
.2129 .40831 .22147 .41636 .23402 .41201 .22549 .40392 Metetra
.654 .753 .922 r
.22549 .40392 .23402 .41201 .24663 .40764 .23814 .39951 Metetra
.654 .753 .922 r
.23814 .39951 .24663 .40764 .25922 .40426 .25085 .39508 Metetra
.48 .66 .94 r
.25085 .39508 .25922 .40426 .27106 .41132 .26327 .39485 Metetra
.298 .406 .804 r
.26327 .39485 .27106 .41132 .28315 .41696 .27533 .40059 Metetra
.361 .446 .814 r
.27533 .40059 .28315 .41696 .29551 .42083 .28764 .40496 Metetra
.421 .49 .825 r
.28764 .40496 .29551 .42083 .30812 .42283 .30018 .40775 Metetra
.474 .534 .838 r
.30018 .40775 .30812 .42283 .32096 .42305 .31295 .40896 Metetra
.52 .575 .852 r
.31295 .40896 .32096 .42305 .33399 .42171 .32592 .4087 Metetra
.557 .615 .866 r
.32592 .4087 .33399 .42171 .34718 .41911 .33906 .40719 Metetra
.588 .651 .88 r
.33906 .40719 .34718 .41911 .3605 .41559 .35235 .40466 Metetra
.611 .682 .893 r
.35235 .40466 .3605 .41559 .37392 .41147 .36576 .40134 Metetra
.628 .708 .904 r
.36576 .40134 .37392 .41147 .38742 .40701 .37927 .39746 Metetra
.64 .727 .912 r
.37927 .39746 .38742 .40701 .401 .40242 .39287 .39317 Metetra
.649 .739 .915 r
.39287 .39317 .401 .40242 .41465 .39781 .40656 .38855 Metetra
.658 .743 .913 r
.40656 .38855 .41465 .39781 .42837 .39319 .42032 .38362 Metetra
.668 .74 .904 r
.42032 .38362 .42837 .39319 .44215 .38847 .43417 .3783 Metetra
.68 .731 .889 r
.43417 .3783 .44215 .38847 .45602 .38347 .44809 .37244 Metetra
.693 .718 .868 r
.44809 .37244 .45602 .38347 .46996 .37794 .46209 .36585 Metetra
.707 .704 .845 r
.46209 .36585 .46996 .37794 .48397 .37154 .47616 .35828 Metetra
.721 .69 .819 r
.47616 .35828 .48397 .37154 .49806 .36394 .49029 .34948 Metetra
.735 .678 .795 r
.49029 .34948 .49806 .36394 .51219 .35481 .50446 .33921 Metetra
.748 .669 .774 r
.50446 .33921 .51219 .35481 .52636 .3439 .51867 .32733 Metetra
.76 .663 .756 r
.51867 .32733 .52636 .3439 .54054 .33105 .53288 .3138 Metetra
.77 .661 .742 r
.53288 .3138 .54054 .33105 .55471 .31631 .54707 .29875 Metetra
.735 .642 .757 r
.54707 .29875 .55471 .31631 .56883 .29997 .56129 .2868 Metetra
.646 .663 .852 r
.56129 .2868 .56883 .29997 .58306 .29101 .57562 .2818 Metetra
.654 .753 .922 r
.57562 .2818 .58306 .29101 .59742 .28603 .59003 .27678 Metetra
.654 .753 .922 r
.59003 .27678 .59742 .28603 .61186 .28103 .60452 .27172 Metetra
.654 .753 .922 r
.60452 .27172 .61186 .28103 .62637 .276 .61908 .26665 Metetra
.654 .753 .922 r
.61908 .26665 .62637 .276 .64095 .27094 .63372 .26154 Metetra
.654 .753 .922 r
.63372 .26154 .64095 .27094 .65562 .26586 .64843 .25641 Metetra
.654 .753 .922 r
.64843 .25641 .65562 .26586 .67036 .26075 .66323 .25125 Metetra
.654 .753 .922 r
.66323 .25125 .67036 .26075 .68517 .25562 .6781 .24606 Metetra
.654 .753 .922 r
.6781 .24606 .68517 .25562 .70007 .25045 .69304 .24085 Metetra
.654 .753 .922 r
.69304 .24085 .70007 .25045 .71504 .24526 .70807 .23561 Metetra
.654 .753 .922 r
.70807 .23561 .71504 .24526 .73009 .24004 .72318 .23034 Metetra
.654 .753 .922 r
.72318 .23034 .73009 .24004 .74522 .2348 .73837 .22504 Metetra
.654 .753 .922 r
.73837 .22504 .74522 .2348 .76044 .22952 .75364 .21972 Metetra
.654 .753 .922 r
.08133 .44333 .09031 .45107 .10231 .44689 .09336 .43911 Metetra
.654 .753 .922 r
.09336 .43911 .10231 .44689 .11436 .44268 .10545 .43487 Metetra
.654 .753 .922 r
.10545 .43487 .11436 .44268 .12647 .43846 .11759 .4306 Metetra
.654 .753 .922 r
.11759 .4306 .12647 .43846 .13864 .43421 .1298 .42632 Metetra
.654 .753 .922 r
.1298 .42632 .13864 .43421 .15087 .42995 .14206 .42202 Metetra
.654 .753 .922 r
.14206 .42202 .15087 .42995 .16316 .42566 .15438 .4177 Metetra
.654 .753 .922 r
.15438 .4177 .16316 .42566 .17551 .42136 .16676 .41335 Metetra
.654 .753 .922 r
.16676 .41335 .17551 .42136 .18791 .41703 .1792 .40899 Metetra
.654 .753 .922 r
.1792 .40899 .18791 .41703 .20038 .41268 .1917 .4046 Metetra
.654 .753 .922 r
.1917 .4046 .20038 .41268 .2129 .40831 .20426 .40019 Metetra
.654 .753 .922 r
.20426 .40019 .2129 .40831 .22549 .40392 .21688 .39576 Metetra
.654 .753 .922 r
.21688 .39576 .22549 .40392 .23814 .39951 .22957 .39131 Metetra
.654 .753 .922 r
.22957 .39131 .23814 .39951 .25085 .39508 .24231 .38684 Metetra
.654 .753 .922 r
.24231 .38684 .25085 .39508 .26327 .39485 .25512 .38234 Metetra
.419 .551 .882 r
.25512 .38234 .26327 .39485 .27533 .40059 .26748 .38417 Metetra
.35 .44 .813 r
.26748 .38417 .27533 .40059 .28764 .40496 .27975 .38871 Metetra
.402 .475 .82 r
.27975 .38871 .28764 .40496 .30018 .40775 .29224 .39198 Metetra
.451 .511 .829 r
.29224 .39198 .30018 .40775 .31295 .40896 .30496 .39387 Metetra
.494 .547 .839 r
.30496 .39387 .31295 .40896 .32592 .4087 .31787 .39443 Metetra
.532 .581 .849 r
.31787 .39443 .32592 .4087 .33906 .40719 .33097 .39375 Metetra
.564 .612 .859 r
.33097 .39375 .33906 .40719 .35235 .40466 .34423 .392 Metetra
.59 .64 .868 r
.34423 .392 .35235 .40466 .36576 .40134 .35762 .38934 Metetra
.612 .663 .875 r
.35762 .38934 .36576 .40134 .37927 .39746 .37113 .38593 Metetra
.63 .681 .879 r
.37113 .38593 .37927 .39746 .39287 .39317 .38475 .38187 Metetra
.646 .693 .88 r
.38475 .38187 .39287 .39317 .40656 .38855 .39847 .37724 Metetra
.66 .699 .875 r
.39847 .37724 .40656 .38855 .42032 .38362 .41228 .37203 Metetra
.674 .7 .866 r
.41228 .37203 .42032 .38362 .43417 .3783 .42617 .3662 Metetra
.687 .696 .853 r
.42617 .3662 .43417 .3783 .44809 .37244 .44015 .35963 Metetra
.701 .689 .836 r
.44015 .35963 .44809 .37244 .46209 .36585 .45419 .35218 Metetra
.714 .681 .817 r
.45419 .35218 .46209 .36585 .47616 .35828 .46831 .34367 Metetra
.726 .673 .798 r
.46831 .34367 .47616 .35828 .49029 .34948 .48249 .33393 Metetra
.738 .666 .78 r
.48249 .33393 .49029 .34948 .50446 .33921 .4967 .32283 Metetra
.75 .662 .764 r
.4967 .32283 .50446 .33921 .51867 .32733 .51094 .3103 Metetra
.76 .659 .751 r
.51094 .3103 .51867 .32733 .53288 .3138 .52518 .2964 Metetra
.757 .655 .748 r
.52518 .2964 .53288 .3138 .54707 .29875 .53942 .28257 Metetra
.635 .612 .81 r
.53942 .28257 .54707 .29875 .56129 .2868 .55373 .27755 Metetra
.654 .753 .922 r
.55373 .27755 .56129 .2868 .57562 .2818 .56812 .2725 Metetra
.654 .753 .922 r
.56812 .2725 .57562 .2818 .59003 .27678 .58258 .26743 Metetra
.654 .753 .922 r
.58258 .26743 .59003 .27678 .60452 .27172 .59711 .26233 Metetra
.654 .753 .922 r
.59711 .26233 .60452 .27172 .61908 .26665 .61173 .2572 Metetra
.654 .753 .922 r
.61173 .2572 .61908 .26665 .63372 .26154 .62641 .25204 Metetra
.654 .753 .922 r
.62641 .25204 .63372 .26154 .64843 .25641 .64118 .24686 Metetra
.654 .753 .922 r
.64118 .24686 .64843 .25641 .66323 .25125 .65603 .24165 Metetra
.654 .753 .922 r
.65603 .24165 .66323 .25125 .6781 .24606 .67095 .23642 Metetra
.654 .753 .922 r
.67095 .23642 .6781 .24606 .69304 .24085 .68595 .23115 Metetra
.654 .753 .922 r
.68595 .23115 .69304 .24085 .70807 .23561 .70104 .22586 Metetra
.654 .753 .922 r
.70104 .22586 .70807 .23561 .72318 .23034 .7162 .22054 Metetra
.654 .753 .922 r
.7162 .22054 .72318 .23034 .73837 .22504 .73144 .21519 Metetra
.654 .753 .922 r
.73144 .21519 .73837 .22504 .75364 .21972 .74677 .20981 Metetra
.654 .753 .922 r
.07228 .43552 .08133 .44333 .09336 .43911 .08434 .43126 Metetra
.654 .753 .922 r
.08434 .43126 .09336 .43911 .10545 .43487 .09646 .42698 Metetra
.654 .753 .922 r
.09646 .42698 .10545 .43487 .11759 .4306 .10863 .42268 Metetra
.654 .753 .922 r
.10863 .42268 .11759 .4306 .1298 .42632 .12087 .41836 Metetra
.654 .753 .922 r
.12087 .41836 .1298 .42632 .14206 .42202 .13316 .41402 Metetra
.654 .753 .922 r
.13316 .41402 .14206 .42202 .15438 .4177 .14552 .40966 Metetra
.654 .753 .922 r
.14552 .40966 .15438 .4177 .16676 .41335 .15793 .40527 Metetra
.654 .753 .922 r
.15793 .40527 .16676 .41335 .1792 .40899 .17041 .40087 Metetra
.654 .753 .922 r
.17041 .40087 .1792 .40899 .1917 .4046 .18294 .39644 Metetra
.654 .753 .922 r
.18294 .39644 .1917 .4046 .20426 .40019 .19554 .392 Metetra
.654 .753 .922 r
.19554 .392 .20426 .40019 .21688 .39576 .2082 .38753 Metetra
.654 .753 .922 r
.2082 .38753 .21688 .39576 .22957 .39131 .22092 .38304 Metetra
.654 .753 .922 r
.22092 .38304 .22957 .39131 .24231 .38684 .2337 .37852 Metetra
.654 .753 .922 r
.2337 .37852 .24231 .38684 .25512 .38234 .24654 .37399 Metetra
.654 .753 .922 r
.24654 .37399 .25512 .38234 .26748 .38417 .25945 .36943 Metetra
.397 .497 .844 r
.25945 .36943 .26748 .38417 .27975 .38871 .27184 .3723 Metetra
.393 .468 .818 r
.27184 .3723 .27975 .38871 .29224 .39198 .2843 .37574 Metetra
.437 .497 .823 r
.2843 .37574 .29224 .39198 .30496 .39387 .29697 .37804 Metetra
.477 .527 .829 r
.29697 .37804 .30496 .39387 .31787 .39443 .30984 .37913 Metetra
.514 .556 .836 r
.30984 .37913 .31787 .39443 .33097 .39375 .3229 .37904 Metetra
.546 .583 .843 r
.3229 .37904 .33097 .39375 .34423 .392 .33613 .37787 Metetra
.574 .607 .848 r
.33613 .37787 .34423 .392 .35762 .38934 .34951 .3757 Metetra
.599 .628 .852 r
.34951 .3757 .35762 .38934 .37113 .38593 .36302 .37264 Metetra
.621 .645 .853 r
.36302 .37264 .37113 .38593 .38475 .38187 .37665 .36876 Metetra
.64 .658 .851 r
.37665 .36876 .38475 .38187 .39847 .37724 .39039 .3641 Metetra
.658 .666 .846 r
.39039 .3641 .39847 .37724 .41228 .37203 .40424 .35867 Metetra
.674 .669 .837 r
.40424 .35867 .41228 .37203 .42617 .3662 .41817 .35242 Metetra
.689 .669 .826 r
.41817 .35242 .42617 .3662 .44015 .35963 .43219 .34529 Metetra
.703 .667 .812 r
.43219 .34529 .44015 .35963 .45419 .35218 .44628 .33717 Metetra
.716 .664 .798 r
.44628 .33717 .45419 .35218 .46831 .34367 .46044 .32795 Metetra
.728 .66 .783 r
.46044 .32795 .46831 .34367 .48249 .33393 .47465 .31755 Metetra
.739 .658 .769 r
.47465 .31755 .48249 .33393 .4967 .32283 .4889 .30589 Metetra
.75 .657 .758 r
.4889 .30589 .4967 .32283 .51094 .3103 .50318 .29302 Metetra
.759 .657 .749 r
.50318 .29302 .51094 .3103 .52518 .2964 .51745 .27905 Metetra
.644 .603 .793 r
.51745 .27905 .52518 .2964 .53942 .28257 .53174 .27328 Metetra
.654 .753 .922 r
.53174 .27328 .53942 .28257 .55373 .27755 .5461 .26821 Metetra
.654 .753 .922 r
.5461 .26821 .55373 .27755 .56812 .2725 .56054 .26311 Metetra
.654 .753 .922 r
.56054 .26311 .56812 .2725 .58258 .26743 .57505 .25799 Metetra
.654 .753 .922 r
.57505 .25799 .58258 .26743 .59711 .26233 .58963 .25284 Metetra
.654 .753 .922 r
.58963 .25284 .59711 .26233 .61173 .2572 .6043 .24766 Metetra
.654 .753 .922 r
.6043 .24766 .61173 .2572 .62641 .25204 .61904 .24246 Metetra
.654 .753 .922 r
.61904 .24246 .62641 .25204 .64118 .24686 .63386 .23722 Metetra
.654 .753 .922 r
.63386 .23722 .64118 .24686 .65603 .24165 .64876 .23196 Metetra
.654 .753 .922 r
.64876 .23196 .65603 .24165 .67095 .23642 .66373 .22667 Metetra
.654 .753 .922 r
.66373 .22667 .67095 .23642 .68595 .23115 .67879 .22136 Metetra
.654 .753 .922 r
.67879 .22136 .68595 .23115 .70104 .22586 .69393 .21601 Metetra
.654 .753 .922 r
.69393 .21601 .70104 .22586 .7162 .22054 .70915 .21064 Metetra
.654 .753 .922 r
.70915 .21064 .7162 .22054 .73144 .21519 .72445 .20523 Metetra
.654 .753 .922 r
.72445 .20523 .73144 .21519 .74677 .20981 .73983 .1998 Metetra
.654 .753 .922 r
.06314 .42764 .07228 .43552 .08434 .43126 .07524 .42335 Metetra
.654 .753 .922 r
.07524 .42335 .08434 .43126 .09646 .42698 .08739 .41903 Metetra
.654 .753 .922 r
.08739 .41903 .09646 .42698 .10863 .42268 .0996 .41469 Metetra
.654 .753 .922 r
.0996 .41469 .10863 .42268 .12087 .41836 .11186 .41033 Metetra
.654 .753 .922 r
.11186 .41033 .12087 .41836 .13316 .41402 .12419 .40595 Metetra
.654 .753 .922 r
.12419 .40595 .13316 .41402 .14552 .40966 .13658 .40155 Metetra
.654 .753 .922 r
.13658 .40155 .14552 .40966 .15793 .40527 .14903 .39713 Metetra
.654 .753 .922 r
.14903 .39713 .15793 .40527 .17041 .40087 .16154 .39268 Metetra
.654 .753 .922 r
.16154 .39268 .17041 .40087 .18294 .39644 .17411 .38822 Metetra
.654 .753 .922 r
.17411 .38822 .18294 .39644 .19554 .392 .18674 .38373 Metetra
.654 .753 .922 r
.18674 .38373 .19554 .392 .2082 .38753 .19943 .37922 Metetra
.654 .753 .922 r
.19943 .37922 .2082 .38753 .22092 .38304 .21219 .37468 Metetra
.654 .753 .922 r
.21219 .37468 .22092 .38304 .2337 .37852 .22501 .37013 Metetra
.654 .753 .922 r
.22501 .37013 .2337 .37852 .24654 .37399 .23789 .36555 Metetra
.654 .753 .922 r
.23789 .36555 .24654 .37399 .25945 .36943 .25084 .36095 Metetra
.654 .753 .922 r
.25084 .36095 .25945 .36943 .27184 .3723 .26385 .35633 Metetra
.404 .483 .827 r
.26385 .35633 .27184 .3723 .2843 .37574 .27633 .35928 Metetra
.43 .491 .821 r
.27633 .35928 .2843 .37574 .29697 .37804 .28898 .3617 Metetra
.468 .515 .823 r
.28898 .3617 .29697 .37804 .30984 .37913 .30182 .36307 Metetra
.503 .539 .827 r
.30182 .36307 .30984 .37913 .3229 .37904 .31485 .36335 Metetra
.535 .563 .83 r
.31485 .36335 .3229 .37904 .33613 .37787 .32806 .36255 Metetra
.564 .584 .833 r
.32806 .36255 .33613 .37787 .34951 .3757 .34142 .36072 Metetra
.59 .603 .834 r
.34142 .36072 .34951 .3757 .36302 .37264 .35493 .3579 Metetra
.614 .619 .833 r
.35493 .3579 .36302 .37264 .37665 .36876 .36857 .35413 Metetra
.635 .632 .83 r
.36857 .35413 .37665 .36876 .39039 .3641 .38233 .34944 Metetra
.655 .641 .824 r
.38233 .34944 .39039 .3641 .40424 .35867 .39619 .34382 Metetra
.672 .647 .816 r
.39619 .34382 .40424 .35867 .41817 .35242 .41016 .33726 Metetra
.688 .65 .807 r
.41016 .33726 .41817 .35242 .43219 .34529 .42422 .32971 Metetra
.703 .651 .796 r
.42422 .32971 .43219 .34529 .44628 .33717 .43835 .32111 Metetra
.716 .651 .784 r
.43835 .32111 .44628 .33717 .46044 .32795 .45254 .31141 Metetra
.728 .651 .773 r
.45254 .31141 .46044 .32795 .47465 .31755 .46679 .30059 Metetra
.739 .652 .763 r
.46679 .30059 .47465 .31755 .4889 .30589 .48108 .28866 Metetra
.749 .654 .756 r
.48108 .28866 .4889 .30589 .50318 .29302 .49538 .2757 Metetra
.661 .612 .789 r
.49538 .2757 .50318 .29302 .51745 .27905 .50965 .26899 Metetra
.654 .735 .909 r
.50965 .26899 .51745 .27905 .53174 .27328 .52399 .2639 Metetra
.654 .753 .922 r
.52399 .2639 .53174 .27328 .5461 .26821 .5384 .25878 Metetra
.654 .753 .922 r
.5384 .25878 .5461 .26821 .56054 .26311 .55288 .25363 Metetra
.654 .753 .922 r
.55288 .25363 .56054 .26311 .57505 .25799 .56744 .24846 Metetra
.654 .753 .922 r
.56744 .24846 .57505 .25799 .58963 .25284 .58208 .24326 Metetra
.654 .753 .922 r
.58208 .24326 .58963 .25284 .6043 .24766 .5968 .23803 Metetra
.654 .753 .922 r
.5968 .23803 .6043 .24766 .61904 .24246 .61159 .23277 Metetra
.654 .753 .922 r
.61159 .23277 .61904 .24246 .63386 .23722 .62646 .22749 Metetra
.654 .753 .922 r
.62646 .22749 .63386 .23722 .64876 .23196 .64141 .22218 Metetra
.654 .753 .922 r
.64141 .22218 .64876 .23196 .66373 .22667 .65645 .21684 Metetra
.654 .753 .922 r
.65645 .21684 .66373 .22667 .67879 .22136 .67156 .21147 Metetra
.654 .753 .922 r
.67156 .21147 .67879 .22136 .69393 .21601 .68675 .20607 Metetra
.654 .753 .922 r
.68675 .20607 .69393 .21601 .70915 .21064 .70203 .20064 Metetra
.654 .753 .922 r
.70203 .20064 .70915 .21064 .72445 .20523 .71739 .19518 Metetra
.654 .753 .922 r
.71739 .19518 .72445 .20523 .73983 .1998 .73283 .1897 Metetra
.654 .753 .922 r
.05393 .41969 .06314 .42764 .07524 .42335 .06605 .41536 Metetra
.654 .753 .922 r
.06605 .41536 .07524 .42335 .08739 .41903 .07824 .411 Metetra
.654 .753 .922 r
.07824 .411 .08739 .41903 .0996 .41469 .09048 .40663 Metetra
.654 .753 .922 r
.09048 .40663 .0996 .41469 .11186 .41033 .10278 .40223 Metetra
.654 .753 .922 r
.10278 .40223 .11186 .41033 .12419 .40595 .11514 .39781 Metetra
.654 .753 .922 r
.11514 .39781 .12419 .40595 .13658 .40155 .12756 .39337 Metetra
.654 .753 .922 r
.12756 .39337 .13658 .40155 .14903 .39713 .14004 .3889 Metetra
.654 .753 .922 r
.14004 .3889 .14903 .39713 .16154 .39268 .15259 .38442 Metetra
.654 .753 .922 r
.15259 .38442 .16154 .39268 .17411 .38822 .16519 .37991 Metetra
.654 .753 .922 r
.16519 .37991 .17411 .38822 .18674 .38373 .17786 .37538 Metetra
.654 .753 .922 r
.17786 .37538 .18674 .38373 .19943 .37922 .19059 .37083 Metetra
.654 .753 .922 r
.19059 .37083 .19943 .37922 .21219 .37468 .20338 .36626 Metetra
.654 .753 .922 r
.20338 .36626 .21219 .37468 .22501 .37013 .21624 .36166 Metetra
.654 .753 .922 r
.21624 .36166 .22501 .37013 .23789 .36555 .22916 .35704 Metetra
.654 .753 .922 r
.22916 .35704 .23789 .36555 .25084 .36095 .24214 .3524 Metetra
.654 .753 .922 r
.24214 .3524 .25084 .36095 .26385 .35633 .25519 .34773 Metetra
.654 .753 .922 r
.25519 .34773 .26385 .35633 .27633 .35928 .26831 .34304 Metetra
.438 .5 .825 r
.26831 .34304 .27633 .35928 .28898 .3617 .28097 .34513 Metetra
.465 .511 .821 r
.28097 .34513 .28898 .3617 .30182 .36307 .29379 .34654 Metetra
.497 .53 .821 r
.29379 .34654 .30182 .36307 .31485 .36335 .3068 .34697 Metetra
.528 .55 .822 r
.3068 .34697 .31485 .36335 .32806 .36255 .31999 .34637 Metetra
.557 .569 .822 r
.31999 .34637 .32806 .36255 .34142 .36072 .33334 .34472 Metetra
.584 .587 .821 r
.33334 .34472 .34142 .36072 .35493 .3579 .34685 .34203 Metetra
.609 .602 .819 r
.34685 .34203 .35493 .3579 .36857 .35413 .36049 .33832 Metetra
.631 .614 .815 r
.36049 .33832 .36857 .35413 .38233 .34944 .37427 .33358 Metetra
.651 .624 .809 r
.37427 .33358 .38233 .34944 .39619 .34382 .38815 .32783 Metetra
.67 .631 .802 r
.38815 .32783 .39619 .34382 .41016 .33726 .40215 .32104 Metetra
.686 .636 .794 r
.40215 .32104 .41016 .33726 .42422 .32971 .41623 .31321 Metetra
.701 .64 .785 r
.41623 .31321 .42422 .32971 .43835 .32111 .43039 .3043 Metetra
.715 .643 .776 r
.43039 .3043 .43835 .32111 .45254 .31141 .44462 .29433 Metetra
.727 .646 .768 r
.44462 .29433 .45254 .31141 .46679 .30059 .4589 .28332 Metetra
.737 .649 .761 r
.4589 .28332 .46679 .30059 .48108 .28866 .47321 .27135 Metetra
.66 .613 .79 r
.47321 .27135 .48108 .28866 .49538 .2757 .48747 .26468 Metetra
.652 .714 .893 r
.48747 .26468 .49538 .2757 .50965 .26899 .50178 .25957 Metetra
.654 .753 .922 r
.50178 .25957 .50965 .26899 .52399 .2639 .51616 .25443 Metetra
.654 .753 .922 r
.51616 .25443 .52399 .2639 .5384 .25878 .53062 .24926 Metetra
.654 .753 .922 r
.53062 .24926 .5384 .25878 .55288 .25363 .54515 .24406 Metetra
.654 .753 .922 r
.54515 .24406 .55288 .25363 .56744 .24846 .55977 .23884 Metetra
.654 .753 .922 r
.55977 .23884 .56744 .24846 .58208 .24326 .57446 .23358 Metetra
.654 .753 .922 r
.57446 .23358 .58208 .24326 .5968 .23803 .58922 .2283 Metetra
.654 .753 .922 r
.58922 .2283 .5968 .23803 .61159 .23277 .60407 .223 Metetra
.654 .753 .922 r
.60407 .223 .61159 .23277 .62646 .22749 .61899 .21766 Metetra
.654 .753 .922 r
.61899 .21766 .62646 .22749 .64141 .22218 .634 .21229 Metetra
.654 .753 .922 r
.634 .21229 .64141 .22218 .65645 .21684 .64909 .2069 Metetra
.654 .753 .922 r
.64909 .2069 .65645 .21684 .67156 .21147 .66425 .20148 Metetra
.654 .753 .922 r
.66425 .20148 .67156 .21147 .68675 .20607 .6795 .19602 Metetra
.654 .753 .922 r
.6795 .19602 .68675 .20607 .70203 .20064 .69484 .19054 Metetra
.654 .753 .922 r
.69484 .19054 .70203 .20064 .71739 .19518 .71025 .18503 Metetra
.654 .753 .922 r
.71025 .18503 .71739 .19518 .73283 .1897 .72575 .17949 Metetra
.654 .753 .922 r
.04463 .41167 .05393 .41969 .06605 .41536 .05679 .4073 Metetra
.654 .753 .922 r
.05679 .4073 .06605 .41536 .07824 .411 .069 .40291 Metetra
.654 .753 .922 r
.069 .40291 .07824 .411 .09048 .40663 .08128 .39849 Metetra
.654 .753 .922 r
.08128 .39849 .09048 .40663 .10278 .40223 .09361 .39405 Metetra
.654 .753 .922 r
.09361 .39405 .10278 .40223 .11514 .39781 .106 .38959 Metetra
.654 .753 .922 r
.106 .38959 .11514 .39781 .12756 .39337 .11846 .38511 Metetra
.654 .753 .922 r
.11846 .38511 .12756 .39337 .14004 .3889 .13098 .38061 Metetra
.654 .753 .922 r
.13098 .38061 .14004 .3889 .15259 .38442 .14355 .37608 Metetra
.654 .753 .922 r
.14355 .37608 .15259 .38442 .16519 .37991 .15619 .37153 Metetra
.654 .753 .922 r
.15619 .37153 .16519 .37991 .17786 .37538 .1689 .36696 Metetra
.654 .753 .922 r
.1689 .36696 .17786 .37538 .19059 .37083 .18166 .36237 Metetra
.654 .753 .922 r
.18166 .36237 .19059 .37083 .20338 .36626 .19449 .35775 Metetra
.654 .753 .922 r
.19449 .35775 .20338 .36626 .21624 .36166 .20739 .35312 Metetra
.654 .753 .922 r
.20739 .35312 .21624 .36166 .22916 .35704 .22034 .34845 Metetra
.654 .753 .922 r
.22034 .34845 .22916 .35704 .24214 .3524 .23337 .34377 Metetra
.654 .753 .922 r
.23337 .34377 .24214 .3524 .25519 .34773 .24645 .33906 Metetra
.654 .753 .922 r
.24645 .33906 .25519 .34773 .26831 .34304 .25961 .33433 Metetra
.654 .753 .922 r
.25961 .33433 .26831 .34304 .28097 .34513 .27283 .32957 Metetra
.497 .545 .836 r
.27283 .32957 .28097 .34513 .29379 .34654 .28574 .3298 Metetra
.497 .528 .819 r
.28574 .3298 .29379 .34654 .3068 .34697 .29874 .3302 Metetra
.526 .545 .817 r
.29874 .3302 .3068 .34697 .31999 .34637 .31192 .32962 Metetra
.554 .561 .815 r
.31192 .32962 .31999 .34637 .33334 .34472 .32526 .32802 Metetra
.581 .576 .813 r
.32526 .32802 .33334 .34472 .34685 .34203 .33877 .32537 Metetra
.606 .59 .809 r
.33877 .32537 .34685 .34203 .36049 .33832 .35242 .32166 Metetra
.628 .602 .805 r
.35242 .32166 .36049 .33832 .37427 .33358 .3662 .31688 Metetra
.649 .613 .799 r
.3662 .31688 .37427 .33358 .38815 .32783 .38011 .31103 Metetra
.668 .621 .793 r
.38011 .31103 .38815 .32783 .40215 .32104 .39412 .3041 Metetra
.685 .628 .786 r
.39412 .3041 .40215 .32104 .41623 .31321 .40823 .2961 Metetra
.7 .633 .779 r
.40823 .2961 .41623 .31321 .43039 .3043 .42241 .28705 Metetra
.713 .638 .772 r
.42241 .28705 .43039 .3043 .44462 .29433 .43667 .27699 Metetra
.725 .643 .767 r
.43667 .27699 .44462 .29433 .4589 .28332 .45097 .26599 Metetra
.641 .603 .796 r
.45097 .26599 .4589 .28332 .47321 .27135 .46519 .26036 Metetra
.652 .715 .894 r
.46519 .26036 .47321 .27135 .48747 .26468 .47947 .25522 Metetra
.654 .753 .922 r
.47947 .25522 .48747 .26468 .50178 .25957 .49382 .25005 Metetra
.654 .753 .922 r
.49382 .25005 .50178 .25957 .51616 .25443 .50826 .24486 Metetra
.654 .753 .922 r
.50826 .24486 .51616 .25443 .53062 .24926 .52276 .23964 Metetra
.654 .753 .922 r
.52276 .23964 .53062 .24926 .54515 .24406 .53735 .23439 Metetra
.654 .753 .922 r
.53735 .23439 .54515 .24406 .55977 .23884 .55201 .22912 Metetra
.654 .753 .922 r
.55201 .22912 .55977 .23884 .57446 .23358 .56675 .22381 Metetra
.654 .753 .922 r
.56675 .22381 .57446 .23358 .58922 .2283 .58157 .21848 Metetra
.654 .753 .922 r
.58157 .21848 .58922 .2283 .60407 .223 .59647 .21312 Metetra
.654 .753 .922 r
.59647 .21312 .60407 .223 .61899 .21766 .61145 .20773 Metetra
.654 .753 .922 r
.61145 .20773 .61899 .21766 .634 .21229 .62651 .20231 Metetra
.654 .753 .922 r
.62651 .20231 .634 .21229 .64909 .2069 .64165 .19687 Metetra
.654 .753 .922 r
.64165 .19687 .64909 .2069 .66425 .20148 .65688 .19139 Metetra
.654 .753 .922 r
.65688 .19139 .66425 .20148 .6795 .19602 .67218 .18588 Metetra
.654 .753 .922 r
.67218 .18588 .6795 .19602 .69484 .19054 .68757 .18034 Metetra
.654 .753 .922 r
.68757 .18034 .69484 .19054 .71025 .18503 .70305 .17478 Metetra
.654 .753 .922 r
.70305 .17478 .71025 .18503 .72575 .17949 .71861 .16918 Metetra
.654 .753 .922 r
.03525 .40358 .04463 .41167 .05679 .4073 .04744 .39917 Metetra
.654 .753 .922 r
.04744 .39917 .05679 .4073 .069 .40291 .05969 .39474 Metetra
.654 .753 .922 r
.05969 .39474 .069 .40291 .08128 .39849 .07199 .39028 Metetra
.654 .753 .922 r
.07199 .39028 .08128 .39849 .09361 .39405 .08436 .3858 Metetra
.654 .753 .922 r
.08436 .3858 .09361 .39405 .106 .38959 .09679 .3813 Metetra
.654 .753 .922 r
.09679 .3813 .106 .38959 .11846 .38511 .10928 .37678 Metetra
.654 .753 .922 r
.10928 .37678 .11846 .38511 .13098 .38061 .12183 .37223 Metetra
.654 .753 .922 r
.12183 .37223 .13098 .38061 .14355 .37608 .13444 .36767 Metetra
.654 .753 .922 r
.13444 .36767 .14355 .37608 .15619 .37153 .14712 .36308 Metetra
.654 .753 .922 r
.14712 .36308 .15619 .37153 .1689 .36696 .15985 .35847 Metetra
.654 .753 .922 r
.15985 .35847 .1689 .36696 .18166 .36237 .17266 .35383 Metetra
.654 .753 .922 r
.17266 .35383 .18166 .36237 .19449 .35775 .18552 .34917 Metetra
.654 .753 .922 r
.18552 .34917 .19449 .35775 .20739 .35312 .19845 .34449 Metetra
.654 .753 .922 r
.19845 .34449 .20739 .35312 .22034 .34845 .21145 .33978 Metetra
.654 .753 .922 r
.21145 .33978 .22034 .34845 .23337 .34377 .22451 .33505 Metetra
.654 .753 .922 r
.22451 .33505 .23337 .34377 .24645 .33906 .23764 .3303 Metetra
.654 .753 .922 r
.23764 .3303 .24645 .33906 .25961 .33433 .25083 .32552 Metetra
.654 .753 .922 r
.25083 .32552 .25961 .33433 .27283 .32957 .26409 .32072 Metetra
.654 .753 .922 r
.26409 .32072 .27283 .32957 .28574 .3298 .27742 .3159 Metetra
.583 .618 .853 r
.27742 .3159 .28574 .3298 .29874 .3302 .29065 .31328 Metetra
.527 .544 .816 r
.29065 .31328 .29874 .3302 .31192 .32962 .30382 .31259 Metetra
.554 .558 .812 r
.30382 .31259 .31192 .32962 .32526 .32802 .31717 .31094 Metetra
.58 .572 .809 r
.31717 .31094 .32526 .32802 .33877 .32537 .33067 .30825 Metetra
.604 .584 .804 r
.33067 .30825 .33877 .32537 .35242 .32166 .34433 .3045 Metetra
.627 .596 .799 r
.34433 .3045 .35242 .32166 .3662 .31688 .35812 .29967 Metetra
.647 .606 .794 r
.35812 .29967 .3662 .31688 .38011 .31103 .37204 .29375 Metetra
.666 .615 .788 r
.37204 .29375 .38011 .31103 .39412 .3041 .38607 .28674 Metetra
.683 .623 .782 r
.38607 .28674 .39412 .3041 .40823 .2961 .40019 .27869 Metetra
.698 .63 .777 r
.40019 .27869 .40823 .2961 .42241 .28705 .4144 .26962 Metetra
.689 .626 .78 r
.4144 .26962 .42241 .28705 .43667 .27699 .42863 .26115 Metetra
.636 .622 .819 r
.42863 .26115 .43667 .27699 .45097 .26599 .44281 .25601 Metetra
.654 .74 .913 r
.44281 .25601 .45097 .26599 .46519 .26036 .45706 .25085 Metetra
.654 .753 .922 r
.45706 .25085 .46519 .26036 .47947 .25522 .47139 .24566 Metetra
.654 .753 .922 r
.47139 .24566 .47947 .25522 .49382 .25005 .48579 .24045 Metetra
.654 .753 .922 r
.48579 .24045 .49382 .25005 .50826 .24486 .50027 .2352 Metetra
.654 .753 .922 r
.50027 .2352 .50826 .24486 .52276 .23964 .51483 .22993 Metetra
.654 .753 .922 r
.51483 .22993 .52276 .23964 .53735 .23439 .52947 .22463 Metetra
.654 .753 .922 r
.52947 .22463 .53735 .23439 .55201 .22912 .54418 .2193 Metetra
.654 .753 .922 r
.54418 .2193 .55201 .22912 .56675 .22381 .55898 .21395 Metetra
.654 .753 .922 r
.55898 .21395 .56675 .22381 .58157 .21848 .57385 .20856 Metetra
.654 .753 .922 r
.57385 .20856 .58157 .21848 .59647 .21312 .5888 .20315 Metetra
.654 .753 .922 r
.5888 .20315 .59647 .21312 .61145 .20773 .60383 .19771 Metetra
.654 .753 .922 r
.60383 .19771 .61145 .20773 .62651 .20231 .61895 .19223 Metetra
.654 .753 .922 r
.61895 .19223 .62651 .20231 .64165 .19687 .63415 .18673 Metetra
.654 .753 .922 r
.63415 .18673 .64165 .19687 .65688 .19139 .64943 .1812 Metetra
.654 .753 .922 r
.64943 .1812 .65688 .19139 .67218 .18588 .66479 .17563 Metetra
.654 .753 .922 r
.66479 .17563 .67218 .18588 .68757 .18034 .68024 .17004 Metetra
.654 .753 .922 r
.68024 .17004 .68757 .18034 .70305 .17478 .69577 .16442 Metetra
.654 .753 .922 r
.69577 .16442 .70305 .17478 .71861 .16918 .71139 .15876 Metetra
.654 .753 .922 r
.02579 .39542 .03525 .40358 .04744 .39917 .038 .39097 Metetra
.654 .753 .922 r
.038 .39097 .04744 .39917 .05969 .39474 .05028 .38649 Metetra
.654 .753 .922 r
.05028 .38649 .05969 .39474 .07199 .39028 .06262 .382 Metetra
.654 .753 .922 r
.06262 .382 .07199 .39028 .08436 .3858 .07502 .37748 Metetra
.654 .753 .922 r
.07502 .37748 .08436 .3858 .09679 .3813 .08749 .37294 Metetra
.654 .753 .922 r
.08749 .37294 .09679 .3813 .10928 .37678 .10001 .36837 Metetra
.654 .753 .922 r
.10001 .36837 .10928 .37678 .12183 .37223 .11259 .36379 Metetra
.654 .753 .922 r
.11259 .36379 .12183 .37223 .13444 .36767 .12524 .35918 Metetra
.654 .753 .922 r
.12524 .35918 .13444 .36767 .14712 .36308 .13795 .35454 Metetra
.654 .753 .922 r
.13795 .35454 .14712 .36308 .15985 .35847 .15073 .34989 Metetra
.654 .753 .922 r
.15073 .34989 .15985 .35847 .17266 .35383 .16357 .34521 Metetra
.654 .753 .922 r
.16357 .34521 .17266 .35383 .18552 .34917 .17647 .34051 Metetra
.654 .753 .922 r
.17647 .34051 .18552 .34917 .19845 .34449 .18944 .33578 Metetra
.654 .753 .922 r
.18944 .33578 .19845 .34449 .21145 .33978 .20247 .33103 Metetra
.654 .753 .922 r
.20247 .33103 .21145 .33978 .22451 .33505 .21557 .32626 Metetra
.654 .753 .922 r
.21557 .32626 .22451 .33505 .23764 .3303 .22873 .32146 Metetra
.654 .753 .922 r
.22873 .32146 .23764 .3303 .25083 .32552 .24197 .31664 Metetra
.654 .753 .922 r
.24197 .31664 .25083 .32552 .26409 .32072 .25527 .31179 Metetra
.654 .753 .922 r
.25527 .31179 .26409 .32072 .27742 .3159 .26864 .30692 Metetra
.654 .753 .922 r
.26864 .30692 .27742 .3159 .29065 .31328 .28207 .30203 Metetra
.65 .701 .883 r
.28207 .30203 .29065 .31328 .30382 .31259 .29558 .29711 Metetra
.599 .604 .828 r
.29558 .29711 .30382 .31259 .31717 .31094 .30904 .29372 Metetra
.581 .571 .808 r
.30904 .29372 .31717 .31094 .33067 .30825 .32255 .29093 Metetra
.604 .583 .803 r
.32255 .29093 .33067 .30825 .34433 .3045 .33622 .2871 Metetra
.626 .594 .797 r
.33622 .2871 .34433 .3045 .35812 .29967 .35002 .28221 Metetra
.646 .604 .792 r
.35002 .28221 .35812 .29967 .37204 .29375 .36395 .27625 Metetra
.665 .613 .787 r
.36395 .27625 .37204 .29375 .38607 .28674 .37799 .26923 Metetra
.669 .615 .786 r
.37799 .26923 .38607 .28674 .40019 .27869 .3921 .26193 Metetra
.632 .607 .807 r
.3921 .26193 .40019 .27869 .4144 .26962 .40617 .2568 Metetra
.647 .677 .865 r
.40617 .2568 .4144 .26962 .42863 .26115 .42033 .25165 Metetra
.654 .753 .922 r
.42033 .25165 .42863 .26115 .44281 .25601 .43455 .24646 Metetra
.654 .753 .922 r
.43455 .24646 .44281 .25601 .45706 .25085 .44885 .24125 Metetra
.654 .753 .922 r
.44885 .24125 .45706 .25085 .47139 .24566 .46323 .23601 Metetra
.654 .753 .922 r
.46323 .23601 .47139 .24566 .48579 .24045 .47768 .23074 Metetra
.654 .753 .922 r
.47768 .23074 .48579 .24045 .50027 .2352 .49221 .22545 Metetra
.654 .753 .922 r
.49221 .22545 .50027 .2352 .51483 .22993 .50682 .22013 Metetra
.654 .753 .922 r
.50682 .22013 .51483 .22993 .52947 .22463 .52151 .21477 Metetra
.654 .753 .922 r
.52151 .21477 .52947 .22463 .54418 .2193 .53628 .20939 Metetra
.654 .753 .922 r
.53628 .20939 .54418 .2193 .55898 .21395 .55112 .20398 Metetra
.654 .753 .922 r
.55112 .20398 .55898 .21395 .57385 .20856 .56605 .19854 Metetra
.654 .753 .922 r
.56605 .19854 .57385 .20856 .5888 .20315 .58105 .19308 Metetra
.654 .753 .922 r
.58105 .19308 .5888 .20315 .60383 .19771 .59614 .18758 Metetra
.654 .753 .922 r
.59614 .18758 .60383 .19771 .61895 .19223 .61131 .18205 Metetra
.654 .753 .922 r
.61131 .18205 .61895 .19223 .63415 .18673 .62656 .17649 Metetra
.654 .753 .922 r
.62656 .17649 .63415 .18673 .64943 .1812 .6419 .1709 Metetra
.654 .753 .922 r
.6419 .1709 .64943 .1812 .66479 .17563 .65732 .16528 Metetra
.654 .753 .922 r
.65732 .16528 .66479 .17563 .68024 .17004 .67283 .15963 Metetra
.654 .753 .922 r
.67283 .15963 .68024 .17004 .69577 .16442 .68842 .15395 Metetra
.654 .753 .922 r
.68842 .15395 .69577 .16442 .71139 .15876 .70409 .14824 Metetra
.654 .753 .922 r
.01623 .38718 .02579 .39542 .038 .39097 .02849 .38269 Metetra
.654 .753 .922 r
.02849 .38269 .038 .39097 .05028 .38649 .0408 .37817 Metetra
.654 .753 .922 r
.0408 .37817 .05028 .38649 .06262 .382 .05317 .37364 Metetra
.654 .753 .922 r
.05317 .37364 .06262 .382 .07502 .37748 .0656 .36908 Metetra
.654 .753 .922 r
.0656 .36908 .07502 .37748 .08749 .37294 .0781 .36449 Metetra
.654 .753 .922 r
.0781 .36449 .08749 .37294 .10001 .36837 .09066 .35989 Metetra
.654 .753 .922 r
.09066 .35989 .10001 .36837 .11259 .36379 .10328 .35526 Metetra
.654 .753 .922 r
.10328 .35526 .11259 .36379 .12524 .35918 .11596 .35061 Metetra
.654 .753 .922 r
.11596 .35061 .12524 .35918 .13795 .35454 .12871 .34593 Metetra
.654 .753 .922 r
.12871 .34593 .13795 .35454 .15073 .34989 .14152 .34123 Metetra
.654 .753 .922 r
.14152 .34123 .15073 .34989 .16357 .34521 .15439 .33651 Metetra
.654 .753 .922 r
.15439 .33651 .16357 .34521 .17647 .34051 .16733 .33177 Metetra
.654 .753 .922 r
.16733 .33177 .17647 .34051 .18944 .33578 .18034 .327 Metetra
.654 .753 .922 r
.18034 .327 .18944 .33578 .20247 .33103 .19341 .3222 Metetra
.654 .753 .922 r
.19341 .3222 .20247 .33103 .21557 .32626 .20654 .31738 Metetra
.654 .753 .922 r
.20654 .31738 .21557 .32626 .22873 .32146 .21975 .31254 Metetra
.654 .753 .922 r
.21975 .31254 .22873 .32146 .24197 .31664 .23302 .30767 Metetra
.654 .753 .922 r
.23302 .30767 .24197 .31664 .25527 .31179 .24636 .30278 Metetra
.654 .753 .922 r
.24636 .30278 .25527 .31179 .26864 .30692 .25977 .29786 Metetra
.654 .753 .922 r
.25977 .29786 .26864 .30692 .28207 .30203 .27325 .29292 Metetra
.654 .753 .922 r
.27325 .29292 .28207 .30203 .29558 .29711 .28679 .28795 Metetra
.654 .753 .922 r
.28679 .28795 .29558 .29711 .30904 .29372 .30041 .28296 Metetra
.652 .716 .895 r
.30041 .28296 .30904 .29372 .32255 .29093 .3141 .27794 Metetra
.645 .67 .859 r
.3141 .27794 .32255 .29093 .33622 .2871 .32786 .27289 Metetra
.641 .648 .841 r
.32786 .27289 .33622 .2871 .35002 .28221 .34169 .26782 Metetra
.641 .645 .839 r
.34169 .26782 .35002 .28221 .36395 .27625 .35559 .26272 Metetra
.644 .662 .853 r
.35559 .26272 .36395 .27625 .37799 .26923 .36957 .25759 Metetra
.65 .702 .884 r
.36957 .25759 .37799 .26923 .3921 .26193 .38362 .25244 Metetra
.654 .753 .922 r
.38362 .25244 .3921 .26193 .40617 .2568 .39774 .24726 Metetra
.654 .753 .922 r
.39774 .24726 .40617 .2568 .42033 .25165 .41194 .24205 Metetra
.654 .753 .922 r
.41194 .24205 .42033 .25165 .43455 .24646 .42622 .23682 Metetra
.654 .753 .922 r
.42622 .23682 .43455 .24646 .44885 .24125 .44057 .23156 Metetra
.654 .753 .922 r
.44057 .23156 .44885 .24125 .46323 .23601 .45499 .22627 Metetra
.654 .753 .922 r
.45499 .22627 .46323 .23601 .47768 .23074 .46949 .22095 Metetra
.654 .753 .922 r
.46949 .22095 .47768 .23074 .49221 .22545 .48408 .2156 Metetra
.654 .753 .922 r
.48408 .2156 .49221 .22545 .50682 .22013 .49873 .21022 Metetra
.654 .753 .922 r
.49873 .21022 .50682 .22013 .52151 .21477 .51347 .20482 Metetra
.654 .753 .922 r
.51347 .20482 .52151 .21477 .53628 .20939 .52829 .19938 Metetra
.654 .753 .922 r
.52829 .19938 .53628 .20939 .55112 .20398 .54319 .19392 Metetra
.654 .753 .922 r
.54319 .19392 .55112 .20398 .56605 .19854 .55817 .18843 Metetra
.654 .753 .922 r
.55817 .18843 .56605 .19854 .58105 .19308 .57323 .1829 Metetra
.654 .753 .922 r
.57323 .1829 .58105 .19308 .59614 .18758 .58837 .17735 Metetra
.654 .753 .922 r
.58837 .17735 .59614 .18758 .61131 .18205 .60359 .17176 Metetra
.654 .753 .922 r
.60359 .17176 .61131 .18205 .62656 .17649 .6189 .16615 Metetra
.654 .753 .922 r
.6189 .16615 .62656 .17649 .6419 .1709 .6343 .1605 Metetra
.654 .753 .922 r
.6343 .1605 .6419 .1709 .65732 .16528 .64977 .15483 Metetra
.654 .753 .922 r
.64977 .15483 .65732 .16528 .67283 .15963 .66534 .14912 Metetra
.654 .753 .922 r
.66534 .14912 .67283 .15963 .68842 .15395 .68099 .14338 Metetra
.654 .753 .922 r
.68099 .14338 .68842 .15395 .70409 .14824 .69672 .13761 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.04003 .25401 m
.04482 .2585 L
s
[(-1)] .03045 .24505 1 .93576 Mshowa
.18786 .19613 m
.19242 .20085 L
s
[(-0.5)] .17875 .18668 .96492 1 Mshowa
.34468 .13472 m
.34896 .13969 L
s
[(0)] .33612 .12478 .8612 1 Mshowa
.51132 .06947 m
.51528 .0747 L
s
[(0.5)] .5034 .05901 .75747 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06892 .2427 m
.07176 .24542 L
s
.09814 .23126 m
.10096 .23401 L
s
.1277 .21969 m
.13049 .22246 L
s
.1576 .20797 m
.16037 .21078 L
s
.21848 .18414 m
.22119 .187 L
s
.24947 .172 m
.25214 .1749 L
s
.28082 .15973 m
.28346 .16265 L
s
.31256 .1473 m
.31516 .15025 L
s
.37719 .12199 m
.37973 .125 L
s
.41011 .1091 m
.4126 .11215 L
s
.44343 .09606 m
.44588 .09913 L
s
.47716 .08285 m
.47958 .08595 L
s
.54591 .05593 m
.54824 .0591 L
s
.58094 .04221 m
.58323 .04541 L
s
.61641 .02832 m
.61866 .03155 L
s
.65234 .01425 m
.65454 .01752 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00o?ooool4o`000003oa0@4?oooooooooo06Gooooo
003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003noooo
o`03o`000?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003nooooo`03o`00
0?oooooooooo06Oooooo003nooooo`03o`000?oooooooooo06Oooooo003looooo`03oeEEEOmVIVKo
000000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Jooooo`00ooooool:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0F_ooool00?oooooo2_ooool01Ol@413ooooooooooooooooo410@05[ooooo003o
ooooo`[ooooo00Go0000ooooooooooooooooo`00001Jooooo`00ooooool:ooooo`05o`000?oooooo
ooooooooool00000F_ooool00?oooooo0oooool2o`0000Gooooo00Go410@oooooooooooooooooa0@
401Jooooo`00ooooool3o`000003ooooool0003o000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`1Jooooo`00oOooool2o`0000?ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0F_oo
ool00?[ooooo0ol00006ooooo`03o`000?oooooo000006;ooooo003gooooo`?o00002Oooool00ol0
003oooooo`00001Rooooo`00mOooool2o`000003ooooool0003ooooo00Wooooo00Co0000oooooooo
oooo0000HOooool00?;ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00001Pooooo`00l?ooool2o`00017ooooo00Go0000ooooooooooooooooo`00001Poooo
o`00kOooool3o`0001?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`00
joooool2o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00]?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd07_ooool3o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05cooooo002dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool06oooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Kooooo`00]?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool05oooool3o`0001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00
]?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool05Oooool3o`00027o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00]?ooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`;o00000_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo0ol0001Jooooo`00]?ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool04oooool3o`0002Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Hooooo`00OOooool2o`0000;ooooo0_l0000aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`;o0000:Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001mooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`?o0000:ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo001nooooo`04omgMgOl0003o
410@olc<c5;ooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Eooo
ool007kooooo00Cok^k^ob4Q8Ol@413ok^k^Coooool3o`0000?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo001nooooo`04ob4Q8OmgMgOo
MgMgoc8b<Tgooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOoo
ool007gooooo0_l00002ooooo`;o0000BOooool3o`0003Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Eooooo`00bOooool3o`0003Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Dooooo`00aoooool2o`0000;ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo0034ooooo`?o00001Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00<;ooooo0_l0
0011ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00;oooooo0ol00013
ooooo`03o`000?oooooooooo00cooooo0_l0001Booooo`00_Oooool2o`0000;ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0;ooooo`;o0000Doooool00;[ooooo0ol00018ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00;Sooooo0_l0001;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0Coooool00;Gooooo0ol0001=ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Coooool008gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Pooooo`Co0000Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo002=
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL07_ooool2o`0000Cooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo002=ooooo`05oa0@4?oooooo
ooooooooool@41006oooool3o`0005Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1=ooooo`00SOooool01Ol0003ooooooooooooooooo000001Wooooo0_l0001Hooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool008gooooo00Go0000ooooooooooooooooo`00
000Fooooo`Co0000FOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo002=
ooooo`05oa0@4?ooooooooooooooool@41005?ooool2o`0000?ooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo002=ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04Oooool3o`0005oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1:ooooo`00SOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00oooooo0_l0001Rooooo`03o`000?oo
oooooooo01?ooooo0_l0001;ooooo`00W_ooool3o`0006Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`19ooooo`00Voooool3o`0000?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Sooooo002Iooooo`;o0000Joooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Oooooo002Fooooo`?o0000KOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Oooooo002Dooooo`?o0000Koooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo002Aooooo`?o00000oooool00ol0003oooooooooo`1[
ooooo`;o00006Oooool00ol0003oooooooooo`15ooooo`00Soooool2o`00077ooooo0ol000000onW
`>co0000ooooo`0Hooooo`03o`000?oooooooooo04Gooooo002<ooooo`?o0000L?ooool3o`0000Co
Yl3/0_l0000Iooooo`03o`000?oooooooooo04Cooooo002:ooooo`?o0000K_ooool4o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`3o`0001Wooooo00?o0000ooooooooool0@oooool008Oooooo0ol0
0002ooooo`03o`000?oooooooooo06Wooooo0ol000000onW`>co0000ojO0k004ojO0k003o`000?nW
`>co000000;o000000?oYl3/o`000?ooool06?ooool00ol0003oooooooooo`13ooooo`00Q?ooool3
o`0006oooooo0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00002ojO0k004o`000?nW`>co
Yl3/o`0001Wooooo0_l00013ooooo`00Boooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08Oooool2o`0006oooooo0ol000000onW`>co0000
ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/o`000003ojO0k003o`00
0?oooooooooo01Gooooo00?o0000ooooool00000@oooool004_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Mooooo`Co0000K_ooool2o`0000GoYl3/
00?o0000ojO0k?nW`>`00_nW`>`2o`0000KoYl3/0_l00002ojO0k0?o00006?ooool00ol0003ooooo
ooooo`11ooooo`00@oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo01[ooooo0_l00003ooooo`03o`000?oooooooooo06Wooooo0ol000000onW`>co0000
ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co0000
0_nW`>`00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043ooooo001;ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Hooooo`?o0000Koooool2o`0000GoYl3/
00Co0000ojO0k?nW`>coYl3/0ol00006ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo001;ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Oooooo0_l0001_oooo
o`?o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k003ojO0
k0;o00001?nW`>`2o`0000CoYl3/0_l0000Hooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo001;
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Fooooo`Co0000KOoo
ool3o`0000KoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00006ojO0k003o`000?nW`>co000000;o
000000?oYl3/o`000?nW`>`00onW`>`2o`000006ojO0k?l0003o0000o`000?nW`>co00006Oooool0
0ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool08Oooool004_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo01Cooooo0_l00003ooooo`03o`000?oooooooooo06Oooooo1?l00003ojO0k003o`000?nW
`>coYl3/00?oYl3/0_l00004ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW
`>coYl3/ojO0k0?o00001OnW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo023ooooo001;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00013ooooo0ol0001]ooooo`;o000000?oYl3/o`000?nW
`>`01OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0Co000000?oYl3/o`000?l000001OnW`>`2o`0001So
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool08Oooool006gooooo0ol0001^ooooo`;o00001?nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW
`>co0000ojO0k002ojO0k004o`000?nW`>co0000ojO0k0?o000000?oYl3/o`000?ooool06?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<02;ooooo001[ooooo`;o000000?oooooo`000?ooool0Joooool3o`000003ojO0k?l0
003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW
`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00;o0000
1OnW`>`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo02Cooooo001Xooooo`?o00001?ooool00ol0003ooooo
ooooo`1Wooooo`;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oYl3/o`000002o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0001So
oooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Toooo
o`00I_ooool2o`0006kooooo0ol000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003o
Yl3/ojO0k003ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`000003ojO0k?l0003oYl3/00?oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0
000Gooooo`03o`000?oooooo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
2_ooool3o`000003oa0@4?oooooooooo01?ooooo001Sooooo`?o0000KOooool3o`0000GoYl3/00?o
0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o00000_nW
`>`00ol0003oYl3/ojO0k002ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k0Co00000onW`>`2o`0000CoYl3/0_l00004ojO0k003o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol@413o^[Zjooooo`0Dooooo`00HOooool2o`000003ooooool0003o
oooo06Wooooo1?l00003ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00005ojO0k003o`000?nW`>co
Yl3/00;oYl3/0_l00006ojO0k003o`000?nW`>coYl3/00?o00001_nW`>`01_l0003oYl3/o`000?l0
003oYl3/o`0000KoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00onHV9So<S8booooo`0Dooooo`00G_oo
ool3o`0000Cooooo00?o0000ooooooooool0IOooool2o`000003ojO0k?l0003oYl3/00GoYl3/00Co
0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k004o`000?nW`>co0000o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Co
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0000Hoooo
o`03o`000?oooooooooo027ooooo00?ogMgMo`000?nj^[X05?ooool005cooooo0_l0001]ooooo`;o
00001?nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`00
00GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`000004o`0000GoYl3/1?l00002ojO0
k003o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00omEEEGoMgMgodA4A00Doooo
o`00FOooool3o`0006cooooo0ol000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o
000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Go
Yl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00003ojO0
k004o`000?nW`>co0000ojO0k0?o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01oooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Cooooo`00E_ooool3
o`0000;ooooo00?o0000ooooooooool0J?ooool2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0
0005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`00
0002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0
k004ojO0k0Co00000_nW`>`01_l0003oYl3/ojO0k?nW`>co0000ojO0k0;o00001OnW`>`00ol0003o
Yl3/ojO0k002ojO0k0;o00006?ooool00ol0003oooooooooo`0Nooooo`05ofIVI_n7QhOooooooiRH
V?mEEED04oooool005Cooooo0_l0001]ooooo`?o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000Go
Yl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`00
0?nW`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0
k?l000000_l000000onW`>co0000ooooo`0Gooooo`03o`000?oooooooooo01gooooo00?ok^k^o`00
0?o^k^h00_ooool00ol0003ogMgMooooo`0Aooooo`00;?ooool4o`000003oa0@4?oooooooooo01ko
oooo0ol0001/ooooo`?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00Co
Yl3/00?o0000ojO0k?l000000_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`000003ojO0k?l0003oYl3/00;oYl3/00Co0000ojO0
k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013ooooo000^ooooo`03o`000?oooooo
oooo01kooooo0ol0001[ooooo`?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`0
0ol0003oYl3/ojO0k002ojO0k0;o00001_nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000
ojO0k?l000000_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/o`000003ojO0k0Co00000_nW`>`0
0ol0003oYl3/ojO0k003ojO0k0;o00006?ooool00ol0003oooooooooo`0dooooo`008oooool6o`00
00Gooooo00?o0000ooooooooool06oooool3o`0000?ooooo00?o0000ooooooooool0IOooool3o`00
0003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`00_nW`>`2o`0000KoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW
`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0
003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ooooo`0Gooooo`;o0000=Ooo
ool002kooooo00?o0000ooooooooool06Oooool2o`0006cooooo0_l00005ojO0k004o`000?nW`>co
Yl3/ojO0k0?o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l00000
0_l000000onW`>co0000ojO0k004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW
`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000GoYl3/00?o0000ojO0k?nW
`>`00_nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo
01Kooooo00?o0000ooooooooool0<oooool002kooooo00?o0000ooooooooool05_ooool3o`0006_o
oooo0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0
k0?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o
0000ojO0k?nW`>`00_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0001Sooooo00?o
0000ooooooooool0<_ooool002kooooo00?o0000ooooooooool05?ooool4o`0006Wooooo0ol00006
ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/
1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`2o`000003ojO0k?l0003o000000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Oo
oooo00?o0000ooooooooool0<_ooool002kooooo00?o0000ooooooooool04Oooool3o`0006[ooooo
0ol00003ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00004ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00006ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0
k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`00
0?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`0
0_nW`>`3o`0000GoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?oooooooooo01Kooooo
00?o0000ooooooooool0<Oooool002cooooo00?oEEEEofIVI_l000004?ooool3o`0006[ooooo0ol0
00000onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0ol00003ojO0k003o`00
0?nW`>coYl3/00;oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0
k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`00_nW`>`2o`0001Sooooo00?o0000ooooooooool0<?ooool003gooooo0_l0001[ooooo`;o
00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005
ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l0
0002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00;oYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o0000
0_nW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00?o000000?oYl3/o`000?nW`>`01?nW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0001Sooooo00?o0000ooooooooool0<?ooool003[ooooo0ol00002oooo
o`03o`000?oooooooooo06Kooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00003ojO0
k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0
k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW
`>coYl3/00?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k003o`00
0?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;oooool003Sooooo0_l0001[ooooo`?o00001OnW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0000KoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;oYl3/00?o
0000ojO0k?nW`>`00onW`>`2o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`00
0?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00;oYl3/
0ol000001_nW`>co0000o`000?l0003oYl3/o`0000GoYl3/1?l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/0_l0000Hooooo`03o`000?oooooooooo02kooooo000eooooo`?o0000JOooool4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000CoYl3/00?o0000ojO0k?nW`>`00onW`>`2o`0000Go
Yl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>co000000;o00000_nW`>`00ol0003o
Yl3/ojO0k002ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`0000Go
Yl3/0ol000001_nW`>co0000o`000?l0003oYl3/o`0000?oYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0^ooooo`00=?ooool2o`0006Wooooo0_l00002ojJchP03o`000?nW`>co
Yl3/00;oYl3/00?o0000ojO0k?l000000_l00002ojF]g@03o`000?nW`>coYl3/00;oYl3/00?o0000
ojO0k?l000000_l000000onW_NWo0000ojO0k004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002
ojO0k0;o00001_nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?l000000_l00000
0onW`>co0000ojO0k004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`0
1?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co000000Ko00000_nW`>`01?l0003oYl3/ojO0
k?l00002ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k002ojO0k0;o00001OnW`>`00ol0003ooooo
ooooo`0Eooooo`;o0000;_ooool003Cooooo0ol0001Vooooo`;o00001OnV/n800ol0003oYl3/ojO0
k003o`0000KoYJgM00?o0000ojO0k?nW`>`00ol00005ojNmj@03o`000?nW`>co000000;o000000?o
Y[OTo`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00;oYl3/
0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00000onW`>`3o`000003ojO0k?l0003o000000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00Co
Yl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0;o00005Oooool00ol0003o
ooooo`00000^ooooo`00=?ooool01?l0003oooooooooool0001Rooooo`?o000000?oY:WJo`000?nV
/n801?nV/n83o`0000;oXI_>00?o0000ojF]gOnU[Md01?nU[Md3o`0000?oXYoA00?o0000ojNmjOnW
_NT00_nW_NT2o`0000GoY[OT00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co
Yl3/00;oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`4
o`0000;oYl3/0_l00005ojO0k003o`000?nW`>coYl3/00?o000000?oYl3/o`000?nW`>`00_nW`>`0
1?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000oooo
o`0Fooooo`03o`000?oooooooooo02cooooo000dooooo`05o`000?ooooooooooooooool00000G_oo
ool3o`0000GoY:WJ00?o0000ojJch_nV/n800_l000000on[WLWo0000oj6KcP03oj6KcP04o`000?nU
[MgoYJgMojF]g@;o000000?o/:37o`000?nRWm401?nRWm401?l0003oYkgYo`000?l00002ojBJb`03
o`000?nV]nCoY[OT00;oY[OT1?l00002ojJfi003o`000?nW`>coYl3/00?oYl3/0_l00005ojO0k004
o`000?nW`>coYl3/ojO0k0?o00001OnW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0
k?l000000_l000001?nW`>co0000ojO0k?nW`>`4o`000006ojO0k?l0003o0000o`000?nW`>co0000
1OnW`>`3o`0000;oYl3/00Co0000ojO0k?nW`>co00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW
`>`00onW`>`2o`0000GoYl3/00?o0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`00
<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo0ol00002ojBUeP03o`00
0?nTZM[oY:WJ00?oY:WJ00?o0000ojJch_l000001?n[WLT00ol0003oXI_>oj6KcP02oj6KcP03o`00
0?nU[Mgo000000Co/:3700?o0000oj:OdOnRWm400_nRWm42o`0000GoY9[;00Ko0000ojJgi?l0003o
0000ojRLb_l00005ojJfi003o`000?nW`>co000000;o000000?oYkcXo`000?nW`>`01?nW`>`4o`00
00;oYl3/00?o0000ojO0k?nW`>`00onW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`2o`00
00CoYl3/0ol00002ojO0k0?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/
00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k003o`000?nW`>co0000
00;o000000?oYl3/o`000?nW`>`01?nW`>`2o`0001Oooooo00?o0000ooooooooool0:_ooool003?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Eooooo`;o000000?oY:GGo`000?nT
YMH00onTYMH00ol0003oY:WJojBYfP02ojBYfP;o00001On[WLT00ol0003oXI_>oj6KcP02oj6KcP;o
00001On`X<L00ol0003oXYoAoj:Od@02o`000003okVTa?l0003oY9[;00CoY9[;0_l00004ojRLbP03
o`000?nV]^CoY[KT00;oY[KT0_l00005ojNlj003o`000?nW`>co000000;o000000?oYl3/o`000?nW
`>`01?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0
003o00000_nW`>`01Ol0003oYl3/o`000?l0003oYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003
ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0k003o`000003ojO0k?l0003oYl3/00;oYl3/00Co0000
ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?ooool05_oo
ool00ol0003oooooooooo`0Zooooo`00<oooool2o`0000Kooooo00?o0000ooooooooool0DOooool3
o`0000CoY:GG00?o0000ojBUe_nTYMH00_nTYMH01_l0003oY:WJo`000?l0003oZYc9o`0000KoZig9
00Ko0000oj6Kc_nQVlko0000ok:Qa_l00005ok2Pa`03o`000?nRWm7o000000Co^JC400Oo0000ojBJ
bonTV/_oY9[;o`000?nlY/;o000000GoZ9c:00Co0000ojJfi?l0003o00000_nYW<T00ol0003oYkcX
ojNlj002ojNlj0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00Co0000ojO0k?nW
`>coYl3/0ol00003ojO0k0?o000000GoYl3/o`000?l0003oYl3/o`000005ojO0k003o`000?nW`>co
000000;o000000?oYl3/o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`4
o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Gooooo00?o
0000ooooooooool0:Oooool003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1<
ooooo`Co00000_nUZm/00ol0003oY:GGojBUe`03ojBUe`04o`000?nTYMKoY:GFojBUeP;o00001?nZ
W<T00ol0003oZig9oj^Mb@03oj^Mb@03o`000?nQVlko000000?o/Z7600?o0000ok2Paon`X<L00_n`
X<L2o`0000Go^JC400Co0000ojBJbonTV/_o00000onlY/800ol0003oZ9c:ojRLbP02ojRLbP;o0000
1OnYW<T01?l0003oYkcXo`000?l00002ojBJb`03o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003
o`000?nW`>coYl3/00?oYl3/1?l00003ojO0k0?o000000CoYl3/o`000?l0003o00001?nW`>`01?l0
003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004
ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`0
0onW`>`2o`0001Kooooo00?o0000ooooooooool0:Oooool003?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`19ooooo`;o000000?oY[OUo`000?nUZm/01?nUZm/00ol0003oY:GGojBU
e`02ojBUe`06o`000?nTYMKo0000o`000?nUV/[o00001OnZW<T00ol0003oZig9oj^Mb@02oj^Mb@;o
00001OnbXLH01_l0003o/:37ok2Paol0003o]Z?5o`0000Go^JC400?o0000ojBJbol000001?nlY/80
1ol0003oZ9c:ojRLb_nXW<[o0000oknW`Ol000001OnYW<T2o`0000GoY9[;00Co0000ojO0k?l0003o
00000_nRW<l00ol0003oYl3/ojO0k002ojO0k003o`000?nW`>co000000;o000000CoYl3/o`000?nW
`>coYl3/1ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/
00?oYl3/0_l00005ojO0k004o`000?nW`>coYl3/ojO0k0?o000000KoYl3/o`000?nW`>coYl3/o`00
0?nW`>`3o`000003ojO0k?l0003oYl3/00CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000
ooooo`0Fooooo`03o`000?oooooooooo02Sooooo000cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0A_ooool2o`0000CoY[OU00?o0000ojF[fonUZm/00_nUZm/01?l0003oY:GGojBU
eonTYML3o`0000CoYI[:00?o0000ojZLbOnZW<T00_nZW<T00ol0003oZig9o`000002o`000003ojjO
b?l0003o/Z7600Co/Z7600?o0000ok2Paol000000onfXlD00ol0003o^JC4okVTa003okVTa003o`00
0?nlY/;o_:K200?o_:K200Co0000ojRLb_nXW<[o00000onoYl401ol0003oZIc9ojVLbOnYW<Wo0000
ol:X_ol000001OnTV//2o`0000GoXYc?00?o0000ojO0k?nW`>`00ol00004ojO0k0Ko000000?oYl3/
o`000?nW`>`01?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o
0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0Co00000_nW`>`00ol0003oYl3/o`00
0002ojO0k0;o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000GoYl3/00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Wooooo`00<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04;ooooo0ol000000onW`>co0000ojJgi@04ojJgi@04o`000?nUZm_oYJ_KojF[f`Co0000
0_nPV<`00ol0003oYI[:ojFJbP02ojFJbP03o`000?nZW<WoZYc900;oZYc90_l00005ojjOb003o`00
0?nbXLKo/Z7600;o/Z760_l00004okJSa@03o`000?niY<Co^JC400;o^JC40_l00006okbV`P;o0000
1?noYl401?l0003oZIc9ojVLbOl00003ol:X_`07o`000?nTV/_oY9[;ojBJbol0003o`JNoo`000005
oj:Lc`?o00000onUZMX4o`000003ojO0k?l0003o000000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol0
0005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0
003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co0000
0_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00005_ooool2o`0002Sooooo000booooo`;o00003?oo
ool00ol0003oooooooooo`0nooooo`?o00001OnW`>`00ol0003oY[OUojJgi@02ojJgi@06o`000?nU
Zm_o0000o`000?nJULgo00001OnPV<`00ol0003oYI[:ojFJbP02ojFJbP06o`000?nZW<WoZYc9o`00
0?nZWLWo00001On^WlP00ol0003o/Z76ok:QaP02o`000003ok>Raol0003o]Z?500Co]Z?500Co0000
okVTa?niY<Co00000_njYL@00ol0003o_:K2okbV`P03okbV`P03o`000?noYl7o_jO100?o_jO100?o
0000ojVLbOl000001?o2Z;l01?l0003oY9[;ojBJbol00003ol6W_`07o`000?nRW<ooXYc?oj:Lcol0
003o_:C1o`000002ojFYfPCo000000?oYl3/o`000?l000000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k003o`00
00GoYl3/00Co0000ojO0k?nW`>coYl3/0ol000000onW`>co0000ojO0k002ojO0k006o`000?nW`>co
0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Gooooo
0_l0000Xooooo`00<_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo0ol0
0003ojO0k003o`000?nW`>coYl3/00?oYl3/00?o0000ojJgiOnV]nD00ol00004oiZEc@03o`000?nP
V<coX9S<00;oX9S<00?o0000ojFJb_nUV/X00_nUV/X00ol0003oZYc9o`000003ojZMb@03o`000?n^
WlSo[Yo800;o[Yo800?o0000ok:Qa_l000001?ncX/L00ol0003o]Z?5okJSa@02okJSa@03o`000?ni
Y<Co000000?o^ZG400?o0000okbV`_nlY/800_nlY/82o`0000Ko_jO100?o0000ol:X_oo2Z;l00oo2
Z;l00ol0003oY9[;o`000004ol6W_`04o`000?nRW<ooXYc?o`0000;o_:C10ol00003ojFYfP;o0000
1OnW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_l000000onW`>co0000ojO0k004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co
00000_nW`>`01?l0003oYl3/ojO0k?l00002ojO0k0;o00001?nW`>`01?l0003oYl3/ojO0k?nW`>`3
o`0000GoYl3/00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`00<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo0_l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Co0000ojO0k?nW`>coYl3/1?l00002oiBBcP03o`000?nJULgoVYG=00;oVYG=00?o0000
oj2Hc?nPV<`00_nPV<`01?l0003oYI[:ojFJb_nUV/X3o`0000CoZYg900?o0000ojjOb?n^WlP00_n^
WlP2o`0000Go/j;700?o0000okJSaOnfXlD00_nfXlD2o`0000Go^ZG400Co0000okbV`_nlY/;o0000
0_nmY/<00ol0003o_jO1oknW`@02oknW`@;o00001_o2Z;l00ol0003o`JNool6W_`03ol6W_`04o`00
0?nRW<oo0000okbT`@;o000000?o_:C1o`000?nUZMX00ol000000onaW/Go0000ojO0k004ojO0k0;o
00001OnW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co
0000ojO0k003ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`01?nW`>`00ol0003o
Yl3/o`000002o`000003ojO0k?l0003oYl3/00?oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?o
Yl3/0_l0000Fooooo`03o`000?oooooooooo02Gooooo000booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0<oooool3o`0000GoYl3/00?o0000ojO0k?nW`>`01Ol00002oiVJd`03o`00
0?nDT/koU9;>00;oU9;>00?o0000oiZEcOnJULd00_nJULd01?l0003oX9S<oj2Hc?nPV<`4o`0000;o
YI_;00?o0000ojZMbOnZWLT00onZWLT01_l0003o[Yo8ojjOb?l0003o[j39o`0000Go/j;700?o0000
okJSaOnfXlD00_l000000ongY<Ko0000okZUa004okZUa003o`000?nlY/;o000000Co_JK300Co0000
oknW`OnoYl7o00000_noZ<800ol0003o`ZRool:X_`03ol:X_`03o`000?o1Ykoo`JNo00Co`JNo0ol0
0004okbT`@03o`000?naW/Go/Ik500?o/Ik500?o0000ojO0k?l000000_l000000onQU/Wo0000ojO0
k004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00001OnW`>`00ol0003oYl3/ojO0
k003o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol000000onW`>co0000ojO0k002ojO0k006o`00
0?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo
01Kooooo00?o0000ooooooooool09?ooool003;ooooo0_l0000@ooooo`03o`000?oooooooooo02oo
oooo0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00002ojJchP03o`000?nIV]?oVI[C00?o
VI[C00Go0000oiBBc_nDT/koU9;>o`000004oiZEc@06o`000?nPV<co0000o`000?nPV<co00001OnU
Vl/00ol0003oZYg9ojZMb@02ojZMb@03o`000?n^WlSo000000?o[j3900?o0000ok>RaoncX/L00onc
X/L2o`0000Co]jC600?o0000okZUa?njYL@00_njYL@2o`0000Go_JK300?o0000oknW`Ol000000ono
Z<800ol0003o`ZRool:X_`02ol:X_`03o`000?o2Z<3o000000;o`JNo1?l00006okbT`@03o`000?na
W/Go/Ik500Co/Ik500?o0000oj6FbOnQU/T00onQU/T00ol0003oYl3/o`000002o`000003ojJ]gOl0
003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k004ojO0k0?o00000onW
`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/
00Co0000ojO0k?nW`>coYl3/0ol00005ojO0k003o`000?oooooooooo01Gooooo00?o0000oooooooo
ool08oooool0037ooooo0_l0000Booooo`;o0000;?ooool3o`000003ojO0k?l0003oYl3/00CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00004ojJchP03o`000?nIV]?oVI[C00;oVI[C00Go0000oiBB
c_nDT/koU9;>o`000003oiZEc@?o00001?nPV<`00ol0003oYI_;ojFKb`02ojFKb`03o`000?nZWLWo
ZYg900;oZYg90_l00004ojnPb@03o`000?ncX/Oo/j;700;o/j;70_l00005okNTaP03o`000?njYLCo
^ZG400;o000000?o^ZK5o`000?nmY/<01?nmY/<2o`0000Go_jS200Co0000ol:X_oo2Z;oo00000_o2
Z<03o`0000;o`JNo00?o0000olFY_Ol000001?nlY<400ol0003oajVko`000005ok6Na@03o`000?nQ
U/WoXIK900?oXIK90_l00005ojJ]g@03o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`00
0002o`000003ojO0k?l0003oYl3/00CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00005ojO0k0Co
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o
00005_ooool00ol0003oooooooooo`0Sooooo`00<Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02Kooooo0ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003o
Y[?RojJchP02ojJchP05o`000?nIV]?oVI[CoiVJdol000000_nDT/h5o`0000;oVYG=00?o0000oj2H
c?nPV<`00_nPV<`00ol0003oYI_;ojFKb`02ojFKb`03o`000?nZWLWo000000;o000000?oZik;o`00
0?n_X<T01?n_X<T01_l0003o/j;7ok>Raol0003o/j?8o`0000Go]jC600?o0000okZUa?l000001?nj
Y/D01ol0003o_JK3okfV`onmY/?o0000okfXa?l000001OnoZ<800ol0003o`ZRoo`000003o`000005
ol:X`?l0003o`JNool6W_ol000000_o5ZKd01Ol0003o_:C1okbT`OnlY<7o000000;oajVk00?o0000
ok6NaOnaW/D00_naW/D00ol0003obJVio`000003oj6Fb@03o`000?noY;go000000GoYZgM0ol00004
ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00?o
0000ojO0k?l000000_l000001?nW`>co0000ojO0k?l00003ojO0k006o`000?nW`>co0000o`000?nW
`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Kooooo00?o0000oooo
ooooool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo0ol0
0003ojO0k003o`000?nW`>coYl3/00;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00?oYl3/00Go
0000ojJch_nV/n;oY[?Ro`000002oiVJd`Co00000_nDT/l00ol0003oVYG=oiZEc@03oiZEc@03o`00
0?nPV<coX9S<00;oX9S<00Co0000ojFKbonUVl_oYI_;0_l00005oj^Nb`03o`000?n_X<Wo[j3900;o
[j3900?o0000ok>Raol000000oncXlP00ol0003o]jC6okNTaP02okNTaP;o00001OnjY/D01?l0003o
_JK3okfV`ol00003okfXa003o`000?noZ<;o_jS200;o_jS20ol00004ol:X`003o`000?o1Ykoo0000
00CoaJVm00Co0000okbT`OnlY<7o00000oo7ZK/01?l0003o/Ik5ok6NaOl00002olVY^@04o`000?nQ
U/WoXIK9o`0000?o_jBm00?o0000ojJ]gOnV[Md00_l000000on^VlCo0000ojO0k004ojO0k0?o0000
0_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0;o0000
1OnW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/0ol00005ojO0
k003o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Oooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW
`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/ojO0k?nW`>`8o`0000;o
SHk?00?o0000oiBBconDT/l00_nDT/l00ol0003oVYG=oiZEc@02oiZEc@03o`000?nPV<coX9S<00;o
X9S<00Ko0000ojFKbol0003o0000ojJLc?l00005oj^Nb`03o`000?n_X<Wo[j3900;o[j390_l00005
ok>Sb006o`000?ngY<Ko]jC6o`000?ngY/So00001OnjY/D00ol0003o_JK3o`000004okfXa003o`00
0?noZ<;o000000;o000000?o_jW3o`000?o2Z<001?o2Z<02o`0000GoaJVm00?o0000okbT`Ol00000
1?o7ZK/00ol0003o/Ik5o`000003olVY^@03o`000?nQU/Wo000000Co_jBm00?o0000ojJ]gOl00000
1?n^Vl@00ol0003oYl3/o`000002o`000003ojBQdol0003oYl3/00?oYl3/00?o0000ojO0k?l00000
0_l000000onW`>co0000ojO0k004ojO0k006o`000?nW`>co0000o`000?nW`>co00001OnW`>`4o`00
00;oYl3/00?o0000ojO0k?nW`>`00_nW`>`4o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol0000F
ooooo`03o`000?oooooooooo027ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo
0_l00005ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0k005o`0000;oUIkJ
00Go0000ohJ;d?n6Rm3oQX_@o`000004ohf>c`05o`000?nDT/ooU9;?oiBBcol000001?nJULd01?l0
003oX9S<oj2Hc?nPV<`3o`0000CoYYc<00?o0000oj^Nbon[W//00_n[W//00ol0003o[j39o`000002
o`000003ojnRbol0003o/j?800Co/j?800?o0000okNTa_l000000ongY/P00ol0003o^ZK5okZVa@02
okZVa@;o00001OnmZ<@2o`000003oknX`_l0003o_jW300;o_jW300Oo0000ol:X`?o2Z<3o`ZS0o`00
0?o2ZL7o000000GoaJVm0_l00006olNY^`03o`000?o9ZKWobJVi00?obJVi00?o0000oknT_OnoY;d0
1?noY;d00ol0003o[Y_4ojjKa004ojjKa003o`000?nTXM?oY:7C00?oY:7C00?o0000ojO0k?nW`>`0
0ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003oYl3/o`000002o`000004
ojO0k?l0003oYl3/o`0000?oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00005ojO0k0Co00000_nW
`>`00ol0003oooooooooo`0Dooooo`;o00008_ooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?ooool2o`0001Sooooo00?o0000ooooooooool06Oooool2o`0000;o
Yl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000;o
Yl3/00?o0000oiFNf_nEW]X00onEW]X01Ol0003oQX_@ohJ;d?n6Rm3o000000CoSHk?00Go0000oiBB
conDT/ooU9;?o`000003oiZEc@Co00000_nPV/h00ol0003oYYc<ojJLc003ojJLc004o`000?n[W/_o
Zik;oj^Nb`;o00001On_X//00ol0003o/j?8ok>Sb002ok>Sb0;o00001OngY/P01_l0003o^ZK5okZV
aOl0003o^ZS8o`0000;o_JS40ol000000onmZ<Co0000o`000004oknY``04o`000?o2Z<3o`ZS0o`00
00?o`ZW100Oo0000olFY_Oo5ZKgoaJVmo`000?o4ZKko000000GoajVk0_l00005olVY^@03o`000?no
Y;go_jBm00Co_jBm00?o0000ojjKa?n^Vl@01?n^Vl@00ol0003oY:7CojBQd`03ojBQd`?o00000onW
`>`00ol0003oYl3/ojO0k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00Co
0000ojO0k?l0003oYl3/0ol00004ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`0
1?nW`>`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Eooooo`Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>co
Yl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000CoUIkJ
00Go0000ohJ;d?n6Rm3oQX_@o`000004ohf>c`06o`000?nDT/ooU9;?oiBBcol0003oVYG=0_l00000
0onKUloo0000oj2JcP04oj2JcP03o`000?nVW<coYYc<00;oYYc<00Ko0000oj^Nbol0003o0000oj^Q
cOl00005ojnRb`03o`000?ncXlSo/j?800;o000000?o/jK;o`000?ngY/P01?ngY/P00ol0003o^ZK5
o`000002okZXb0?o00000onmZ<@2o`0000Go_jW300?o0000ol:X`?l000001?o2ZL401?l0003oaJVm
olFY_Ol00003olBY_P05o`000?o7ZK_oajVkolNY^ol000000_o7ZK`01ol0003obJViolVY^Oo9ZKWo
0000olVY^Ol000001?noY;d00ol0003oc:Vfo`000004ojjKa003o`000?o7Y[So000000?oY:7C00?o
0000okJN`?l000001OnW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000GoYl3/0ol00003ojO0k003
o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`01?l0003o
Yl3/ojO0k?nW`>`3o`0001Kooooo00?o0000ooooooooool07oooool000Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo017ooooo0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00Go0000ojO0k?nW`>coYl3/o`000003oiFNfP05o`000?n6Rm3oQX_@ohJ;d?l0
00000on=S/l7o`0000CoViO?00?o0000oj2Jc_nPV/h00_nPV/h00ol0003oYYc<ojJLc002ojJLc0;o
00001?n[XLd00ol0003o[j;;ojnRb`02ojnRb`03o`000?ncXlSo000000Co/jK;00?o0000okNVb?ng
Y/P00_ngY/P5o`0000;o^ZS800Ko0000okfXa?nmZ<Co0000okbZaol00006oknY``03o`000?o2ZL7o
`ZW100?o`ZW100?o0000olFY_Ol000001?o4ZKh01?l0003oajVkolNY^ol00003olNY_004o`000?o9
ZKWobJVio`0000;obJVi00Go0000oknT_OnoY;go_jBmo`000002olbY]P05o`000?n^VlCo[Y_4ojjK
a?l000000_o7Y[P01?l0003oY:7CojBQdol00003okJN`004o`000?nW`>coYl3/ojO0k0?o00001?nW
`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00002ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0Co
00000_nW`>`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413o
ooooooooo`0@ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool3o`000003ojO0k?l0003o
Yl3/00CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>co
Yl3/017o00000_n=Sm001Ol0003oU9?@oiBCd?nDTm3o000000CoViO?00?o0000oj2Jc_nPV/h00_nP
V/h00ol0003oYYc<o`000002o`000003ojJOcol0003oZj7=00CoZj7=00Co0000ojnRbon_X/_o[j;;
0_l00005ok>Vb`03o`000?ngY/So]jK800Co00001OnjZ<P00ol0003o_JS4o`000003okbZa`03o`00
0?noZL?o_jW300;o_jW30_l00006ol:Y`@03o`000?o4ZKkoa:Vn00?oa:Vn00?o0000olNY^ol00000
1?o7ZK`01?l0003obJViolVY^Ol00003olVY^@04o`000?noY;go_jBmo`0000?oc:Vf00Co0000ojjK
a?n^VlCo00000_o7Y[P00ol0003oY:7Co`000005okJN`0?o00000onSW<h00ol0003oYl3/ojO0k003
o`0000GoYl3/00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?nW`>co000000;o000000?o
Yl3/o`000?nW`>`00onW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003oYl3/00CoYl3/00?o
0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo000000Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`09ooooo`Co00001?nW`>`00ol0003oYl3/o`000002o`000003
ojO0k?l0003oYl3/00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0?o00000_nW`>`01Ol0003oOh_Fogn;e_moRmKo000000?oOhOA00Go0000ohJ;dOn6Rm7oQX_Ao`00
0005ohf?d005o`000?nDTm3oU9?@oiBCd?l000001?nKUll01?l0003oX9[>oj2Jc_nPV/h2o`0000Go
YYo?00?o0000oj^QcOn[XLd00_n[XLd01_l0003o[j;;o`000?l0003o/:K>o`0000Go/jK;1?l00003
okNYc003o`000?njZ<So^ZS800;o^ZS80_l00005okbZa`04o`000?noZL?o_jW3o`0000;o_j_600?o
0000ol:Y`Oo2ZL400_o2ZL42o`0000Koa:Vn00?o0000olNY_?o7ZK`01?o7ZK`2o`0000CobJVi00?o
0000oknT_Ol000001?o<ZKH00ol0003o[Y_4o`000004olNV^003o`000?nfW/3o]Yk000Co]Yk000?o
0000oj>Lc_nSW<h00onSW<h3o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`4o`0000?oYl3/00?o
0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k003o`000?nW`>coYl3/00?o00001OnW
`>`01?l0003oYl3/ojO0k?nW`>`3o`0001Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Booooo`00<?ooool2o`0001kooooo00?o0000ooooooooool01Oooool3o`0000CoYl3/00?o
0000ojO0k?nW`>`00ol00005ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01?l0003oYl3/
o`000?l00002ojO0k005o`000?nW`>coYl3/ojO0k?l000000omoRmH01Ol0003oOhOAogn7dOmoQm7o
000000?oQX_A00?o0000ohf?d?n=Sm000_n=Sm000ol0003oU9?@oiBCd002oiBCd006o`000?nKUloo
ViO?oi^Gcol0003oX9[>0_l000000onQWM3o0000ojJOc`04ojJOc`03o`000?n[XLgoZj7=00;oZj7=
0_l00004ok2VcP03o`000?ncY/_o/jK;00Co00001OngZL`00ol0003o^ZS8okZXb002o`000003okV/
c?l0003o_:[700Co_:[700?o0000oknY`ol000001?noZlH01?l0003o`ZW1ol:Y`Ol00002ol6[``03
o`000?o4ZKkoa:Vn00?oa:Vn00?o0000olNY_?o7ZK`01?o7ZK`00ol0003obJViolVY^@04olVY^@03
o`000?o<ZKKoc:Vf00Coc:Vf00?o0000olNV^?o7Y[P00oo7Y[P00ol0003o]Yk0okJN`003okJN`003
o`000?o<Z;Co000000?oXic>00?o0000okVO__l000001?nW`>`00ol0003oYl3/o`000002o`000003
ojO0k?l0003oYl3/00CoYl3/0ol00002ojO0k004o`000?nW`>coYl3/o`0000;oYl3/0ol00002ojO0
k003o`000?nW`>coYl3/00?oYl3/1?l00003ojO0k003o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Booooo`00<?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003
o`000?nW`>coYl3/00;oYl3/1?l00003ojO0k004o`000?nW`>coYl3/ojO0k0?o00001OnW`>`01Ol0
003oYl3/ojO0k?nW`>co000000?oOh_F00Go0000ogn7dOmoQm7oOhOAo`000003ohJ;d@05o`000?n=
Sm3oSHo@ohf?d?l000001?nDTm000ol0003oViO?oi^Gc`03o`0000CoXIg@00?o0000ojJOconVWll0
0_nVWll00ol0003oZj7=o`000002o`000003ojbUd?l0003o/:K>00?o/:K>0ol000001?ncY/_o0000
ok>Zcol00005okNYc003o`000?njZ<So000000Co^Jc<00?o0000okbZaonlZ/L00_nlZ/L2o`0000Go
_j_600?o0000ol:Y`Ol000000oo1Zl<00ol0003oa:VnolBY_P02olBY_P03o`000?o4Z/3o000000Go
ajVl00?o0000olVY^Oo9ZKT01?o9ZKT00ol0003oc:VfolbY]P04olbY]P03o`000?o7Y[SoajJh00;o
ajJh00?o0000olnY/ol000001?nfW/000ol0003oc:Rdo`000002oj>LcP05o`000?niWkko^InnokVO
__l000000_nW`>`3o`0000GoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0
k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`00ol0003oYl3/o`000002o`00
0003ojO0k?l0003oYl3/00CoYl3/0_l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04_ooool0033ooooo00?o0000ooooooooool07oooool5o`0000CoYl3/00Co0000ojO0k?l0
003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000
ojO0k?nW`>`00_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00onW`>`5o`0000?oOh_F00Go0000
ogn7dOmoQm7oOhOAo`000003ohJ;d@03o`000?n=Sm3oSHo@00;oSHo@00?o0000oiBCd?nDTm001?l0
0002oi^Jd@03o`000?nQWM3oXIg@00?oXIg@00Co0000ojJOconVWlooYYo?0_l00005ojbUd008o`00
0?n`Y/ko0000o`000?n`Y/ko0000ok>Vbol00003ok>Zc`03o`000?ngZLco]jW<00;o]jW<0_l00005
okV/c003o`000?nlZ/Oo_:[700;o000000?o_:g;o`000?noZlH01?noZlH2o`0000Go`J_300Co0000
olBY__o4ZKko00000_o4Z/000ol0003oajVlolNY_002olNY_003o`000?o6Z[go000000CobJVi00?o
0000olVY^Ol000001?o<ZKH00ol0003oc:Vfo`000002olNV^004o`000?o?ZK?ocjVco`0000?o]Yk0
00Ko0000olbX]?o<Z;Co0000oj>Lc_l00005okVO_P;o00000onSW<h01?l0003oYl3/ojO0k?nW`>`3
o`0000GoYl3/00?o0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k003o`000?nW`>co
Yl3/00?o00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo01Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`00;oooool00ol0003oooooooooo`0Noooo
o`?o00001?nW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`00ol0003oYl3/o`000002
o`000004ojO0k?l0003oL7oCog1odaCo00000_nEU]800ol0003oVi[Aoi^Jd@02oi^Jd@03o`000?nQ
WM3oXIg@00;oXIg@00Ko0000ojJOcol0003o0000ojNTd_l00004ojbUd0?o00000on`Y/h2o`0000Go
/j[?00Ko0000okNYc?ngZLco0000okJ^dOl00005okV/c003o`000?nlZ/Oo000000Co_:g;00Oo0000
okn[a_noZlKo_j_6o`000?nn[LWo000000Go`J_300?o0000olBY__l000001?o4Z/001?l0003oajVl
olNY_?l00002olJZ_@05o`000?o9ZKWobJViolVY^Ol000000_o9ZKT01Ol0003oc:VfolbY]_o<ZKKo
000000;oc:Vf00Co0000olNV^?o7Y[So00000oo?ZK<00ol0003o]Yk0o`000004olbX]003o`000?ni
Wkko^Inn00Co^Inn00?o0000oj>Lc_nSW<h00onSW<h3o`0000;oYl3/00?o0000ojO0k?nW`>`00onW
`>`3o`0000;oYl3/00Co0000ojO0k?nW`>co00000_nW`>`3o`0000?oYl3/00Co0000ojO0k?nW`>co
Yl3/0ol00005ojO0k003o`000?oooooooooo01?ooooo0_l00007ooooo`03o`000?oooooooooo01;o
oooo000_ooooo`03o`000?oooooooooo01cooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00?o0000
1OnW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Co0000og1odom`Om?o00000omgP]801Ol0003o
OhOBogn7d_moQm;o000000?oQhcB00Go0000ohjAd_n>TM;oSY7Bo`000005oiFFdP05o`000?nKV]7o
Vi[Aoi^JdOl000001?nQWM02o`0000CoYjCB1?l000000on/YM3o0000ok2VcP03o`000003ok2[dol0
003o/j[?00Co/j[?00?o0000okNYc?l000000onf[]400ol0003o^Jc<okV/c002okV/c0;o00001Onl
[L/01?l0003o_j_6okn[a_l00003okj]b@03o`000?o1Zl?o`J_300;o`J_30_l00005olBZ`003o`00
0?o7ZKco000000?oaZZm00Co0000olVY^Oo9ZKWo00000oo9ZKT01?l0003oc:VfolbY]_l00003olbY
]P03o`000?o7Y[So000000CocjVc00?o0000okJN`?l000001?o<Z;@00ol0003o^InnokVO_P03okVO
_P03o`000?o?ZK;o000000?oXic>00?o0000okVP__l000001?nW`>`00ol0003oYl3/o`000002o`00
0003ojO0k?l0003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0
k0Co00000_nW`>`00ol0003oYl3/ojO0k003ojO0k0;o00004oooool01?l0003oooooooooool00004
ooooo`03oeEEEOmVIVKo000001Cooooo000_ooooo`;o00006_ooool4o`0000CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o
0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00Go
0000ojO0k?nW`>coYl3/o`000003og1od`05o`000?mgP];oMh;BogN2d_l000000omoQm801Ol0003o
QhcBohN<d_n7S=;o000000?oSY7B00?o0000oiFFd_nEU]800_nEU]801_l0003oVi[Aoi^JdOnKV]7o
0000oj6Md0?o000000CoXZ7Do`000?nWY=;oYjCB1?l00003ojbUd0;o00001On`Zm<00ol0003o/j[?
ok>Zc`02ok>Zc`;o00001Onf[]401_l0003o^Jc<okV/c?l0003o^;3Ao`0000Go_:g;00?o0000okn[
a_l000001?nn[LT01ol0003o`J_3ol6[`oo1Zl?o0000ol2]aol000001Oo4Z/02o`0000GoaZZm0_l0
0005olVY^@;o00001Oo<ZKH00ol0003ocjVcolnY/`04olnY/`03o`000?o<Z;Coc:Rd00;oc:Rd00?o
0000om6Z/?l000001?niWkh00ol0003ocjVbo`000002oj>LcP05o`000?niX;ko^J2nokVP__l00000
0_nW`>`3o`0000GoYl3/00?o0000ojO0k?nW`>`00ol000000onW`>co0000ojO0k002ojO0k006o`00
0?nW`>co0000o`000?nW`>co00001OnW`>`00ol0003oYl3/o`000002o`000003ojO0k?l0003ooooo
01Gooooo00?o0000ooooooooool06Oooool002oooooo00?o0000ooooooooool05_ooool3o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01?l0003o
Yl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`0
0ol0003oYl3/ojO0k002ojO0k0Go00000om`Om<01Ol0003oMh;BogN2d_mgP];o000000?oOhOB00?o
0000ohN<d_n7S=800_n7S=801Ol0003oSY7BohjAd_n>TM;o000000?oUIKB00?o0000oi^JdOnKV]40
0ol00004oj:Qe0?o00000onWY=801_l0003o[:G@o`000?l0003o[:_Fo`0000Go/:_C00?o0000ok>Z
col000000_l000000onc/=Ko0000okJ^d@04okJ^d@03o`000?ni[<co000000?o^;3A00?o0000okb]
bonl[L/00_nl[L/2o`0000Go_Zg900Co0000ol6[`oo1Zl?o00000oo0[LL01ol0003oa:[0olBZ`?o4
Z/3o0000ol:/`ol000001Oo6Z[d00ol0003obJViolVY^@04olVY^@03o`000?o<ZKKoc:Vf00Coc:Vf
00?o0000olnY/oo?ZK<01?o?ZK<00ol0003oc:RdolbX]002olbX]003o`000?oAZ[3o000000?o^Inn
00Ko0000olnY/_o?ZK;o0000oj>Lc_l00005okVP_P;o00000onTX]<01?l0003oYl3/ojO0k?nW`>`4
o`0000?oYl3/00Co0000ojO0k?l0003oYl3/0ol00004ojO0k004o`000?nW`>coYl3/ojO0k0?o0000
1OnW`>`00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo000_ooooo`03o`000?oo
oooooooo01Cooooo0_l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW
`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00002ofMkd`Go00000omgP]801Ol0003o
OhOBogn7d_moQm;o000000CoQhcB00Go0000ohjAd_n>TM;oSY7Bo`000002oiFFdPCo00000_nMW]D0
0ol0003oXZ7Do`000002o`000003oj:Qe?l0003oYjCB00?oYjCB0_l00004ojb[eP03o`000?n`Zm?o
/:_C00;o/:_C0_l00005ok>`eP03o`000?nf[]7o]ZkA00;o]ZkA0_l00005okR`d@06o`000?nl[L_o
_:g;o`000?nj/M7o00001_nn[LT2o`0000Co`:g700Co0000olBZ`?o4Z/3o00000oo2[<<01?l0003o
aZZmolJZ_Oo6Z[d2o`0000KobJVi00?o0000olbY]_o<ZKH00oo<ZKH00ol0003oc:Vfo`000004olnY
/`03o`000?o?ZK?o000000;oc:Rd00Oo0000om6Z/?oAZ[3odJZ`o`000?niWkko000000CocjVb00?o
0000okVP__niX;h01?niX;h00ol0003oY:;CojBRd`03ojBRd`?o00000_nW`>`00ol0003oYl3/ojO0
k002ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k005o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
000Gooooo`03o`000?oooooooooo01Oooooo000_ooooo`03o`000?oooooooooo017ooooo1?l00004
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`00
0?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00004ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`01?l0003oIg_CofMkdol00002ofimdPCo
000000?oMh;Bo`000?moQm800_moQm800ol0003oQhcBohN<dP08o`0000;oUi[E00?o0000oifNeOnM
W]D00ol00004oj:Qe003o`000?nWY=;o000000;o000000?oZ:[Ho`000?n/ZmH01?n/ZmH01_l0003o
/:_Cok2[dol0003o[k;Jo`0000Go/k3F00?o0000okJ^dOl000000_l000000ond]=So0000okR`d@04
okR`d@03o`000?nl[L_o000000?o^[7A00?o0000okj]bOnn[LT00_nn[LT2o`0000Go`:g700?o0000
olBZ`?l000001?o2[<<01?l0003oaZZmolJZ_Ol00002olF[_`03o`000?o9ZKWobJVi00;obJVi00?o
0000olVZ^_l000001?o<ZKH00ol0003oc:Vfo`000003olnY/`04o`000?o?ZK?ocjVco`0000;oc:Rd
00Oo0000om6Z/?oAZ[3odJZ`o`000?niWkko000000CocjVb00?o0000okVP__niX;h00oniX;h00ol0
003ocjVco`000003ojBRd`;o00001OnW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000;oYl3/00?o
0000ojO0k?nW`>`00ol00002ojO0k003o`000?nW`>coYl3/00?oYl3/0ol00003ojO0k003o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05oooool002kooooo00?o0000ooooooooool03_ooool4
o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`0
1?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o0000
0_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`01Ol0003oYl3/ojO0k?nW`>co000000?o
Ig_C00Co0000ofimd_m^OM;o00000_mgPm88o`0000;oR93D00Go0000oi2EeOn@UMGoT9GEo`000003
oiNJe@?o00000onMW]D00ol0003oXZ7Doj:Qe003o`0000GoZ:[H00?o0000ojb[e_n/ZmH00_n/ZmH0
0ol0003o/:_Co`000003ojnbfP03o`000?nc/=Ko/k3F00;o/k3F0_l00005okBdf003o`000?nh/=7o
^;3A00;o^;3A0_l00005okZad@06o`000?nn[LWo_Zg9o`000?nk/<oo00001Oo0[LL2o`0000Go`Zc3
00?o0000olJZ_Ol000001?o5Zkl01?l0003obJViolVY^Ol00002olVZ^P05o`000?o<ZKKoc:VfolbY
]_l000000_o<ZKH01?l0003ocjVcolnY/ol00003olnY/`03o`000?o<Z;Co000000GodJZ`00?o0000
olnY/_o?ZK800_o?ZK800ol0003oe:^_o`000003okVP_P04o`000?o?ZK?ocjVco`0000;oY:;C00Co
0000okJO`_nfWl;o00000onW`>`3o`0000CoYl3/00?o0000ojO0k?l000000_l000000onW`>co0000
ojO0k003ojO0k003o`000?nW`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`2o`0001Kooooo
00?o0000ooooooooool05_ooool002kooooo0_l0000<ooooo`?o00000onW`>`00ol0003oYl3/ojO0
k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0
k003o`0000GoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k004o`000?nW`>co0000o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000;oIg_C00Go0000ofimd_m^
OM;oKWgBo`000002ogN3dP05o`000?n0RM?oP8WCoh29dol000001On8T=@01?l0003oT9GEoi2EeOn@
UMD3o`0000;oUi[E00Co0000oifNeOnMW]GoWIkE0ol00002oj>Xf@03o`000?nXZ]SoZ:[H00?oZ:[H
00Co0000ojb[e_n/ZmKo[:_F0ol00005ojnbfP06o`000?nc/=Ko/k3Fo`000?na]mko00001Ond]=P0
0ol0003o^;3Ao`000002o`000003okFffOl0003o^[7A00Co^[7A00?o0000okj]bOl000000onk/<l0
1ol0003o`:g7ol2]aoo0[LOo0000okf_c?l000001Oo2[<<2o`0000GoaJ^o00?o0000olVY^Ol00000
1?o9Z[X00ol0003oc:Vfo`000004olbY]P;o00001Oo?ZK<2o`0000GodJZ`00?o0000olnY/_o?ZK80
0_o?ZK800ol0003oe:^_o`000002okVP_P07o`000?o?ZK?ocjVcolnY/ol0003oY:;Co`000004okJO
`P?o00000onV[mh00ol0003oYl3/ojO0k003o`000003ojO0k?l0003oYl3/00;oYl3/00?o0000ojO0
k?nW`>`00ol00005ojO0k006o`000?nW`>co0000o`000?nW`>co00005oooool00ol0003ooooooooo
o`0Eooooo`00;_ooool00ol0003oooooooooo`09ooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`00
0?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/
0ol00004ojO0k003o`000?nW`>coYl3/00?o00001OnW`>`00ol0003oYl3/ojO0k006o`0000?oIg_C
00Go0000ofimd_m^OM;oKWgBo`000002ogN3dP05o`000?n0RM?oP8WCoh29dol000001?n8T=@00ol0
003oT9GEo`000002o`0000CoUi[E00Ko0000oifNeOl0003o0000oijUf_l00004oj>Xf@03o`000?nX
Z]SoZ:[H00;oZ:[H1?l00002ojbcg@03o`000?n_/][o[k;J00?o[k;J00?o0000ok>`e_l000000ona
]mh00ol0003o];CHokBdf002okBdf0;o00001One]]T00ol0003o^[7AokZad@02okZad@;o00001Onk
/<l00ol0003o`:g7o`000003okf_c007o`000?o2[<?o`Zc3ol:/`ol0003o`:g7o`000005olF[_`;o
00001Oo9Z[X00ol0003oc:Vfo`000004olbY]P03o`000?o?ZK?ocjVc00CocjVc00?o0000om6Z/?oA
Z[000ooAZ[000ol0003odZZ`o`000002olnY/P04o`000?oDZjooe:^_o`0000;o^J2n00?o0000olnY
/oo?ZK<00_o?ZK<00ol0003o]Yo2okJO`P03okJO`P03o`000?nV[mkoYZoN00?oYZoN0ol00002ojO0
k004o`000?nW`>coYl3/o`0000;oYl3/0ol00003ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW
`>`00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo000^ooooo`03o`000?oooooo
oooo00Kooooo0ol00005ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004
o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW
`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`0
0_nW`>`3o`0000;oYl3/00?o0000ofEof?mUOmP01Ol00003ofimdP05o`000?mgPm;oMh?BogN3d_l0
00000on0RM<00ol0003oR93DohR@e003o`0000;oT9GE00Co0000oiNJeOnGV]GoUi[E0ol00004oijU
fP03o`000?nSZ=WoXjSI00;oXjSI00Ko0000ojRZf?l0003o0000ojRbgol00005ojbcg@04o`000?n_
/][o[k;JojnbfP?o00001Ona]mh01_l0003o];CHo`000?l0003o/K_Qo`0000Go]KKI00?o0000okZa
dOl000000_l000000onf]]Wo0000ok^`c`04ok^`c`;o00001?nm[l`01?l0003o`Zc3ol:/`ol00003
ol2]a`07o`000?o5ZkooaJ^oolF[_ol0003oa:c2o`000006olVZ^P03o`000?o<ZKKoc:Vf00?oc:Vf
00?o0000olnY/oo?ZK<01?o?ZK<00ol0003odJZ`om6Z/002om6Z/004o`000?oBZ[3odZZ`o`0000;o
cjVb00Co0000omB[[ooDZjooe:^_0_l00005olnY/`03o`000?nfWl;o]Yo200;o]Yo200?o0000olfZ
]ol000000_nV[mh2o`000003ojnOb?l0003oYl3/00?oYl3/00?o0000ojO0k?l000000_l000000onW
`>co0000ojO0k003ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0;o00005_ooool00ol0
003oooooooooo`0Dooooo`00;_ooool00ol0003oooooooooo`03ooooo`?o00000onW`>`00ol0003o
Yl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW
`>`01?l00004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/
o`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k004o`000?mUOmSoIGoHo`0000;o
I7OA2Ol00003oh29d`co00000_nIX=X00ol0003oWZGJoijUfP03oijUfP04o`000?nSZ=WoXjSIoj>X
f@;o00001?nX/]l00ol0003o[;?Mojbcg@02ojbcg@Co00000_n^^n<00ol0003o/KONok6ggP03ok6g
gP;o00001?na^n400ol0003o]KKIokFff@02okFff@;o00001Onf]]T00ol0003o^k3?ok^`c`02o`00
0003okNde_l0003o_Jo<00?o_Jo<00?o0000ol:/`ol000001?o0[LL01?l0003oaJ^oolF[_ol00003
olB/`P03o`000?o9Z[[obJZj00;obJZj0_l00004olbY]P03o`000?o;Z[So000000CocjVc00?o0000
olnZ/ol000000_oAZ[001ol0003odZZ`om:Z/?oBZ[3o0000olnY/_l000001?oDZjl00ol0003ocjVc
olnY/`03olnY/`03o`000?oF[Jko000000;o]Yo200Ko0000olfZ]oo=Z[Oo0000ojJ_g_l00004ojnO
b003o`000?nW`>coYl3/00?o000000?oYl3/o`000?nW`>`00_nW`>`01_l0003oYl3/o`000?l0003o
Yl3/o`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0000Eooooo`03o`000?oooooo000001Go
oooo000^ooooo`04o`000?ooooooooooooooo`;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004
o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00Go0000ojO0k?nW`>coYl3/o`00
0003ofEof004o`000?mTMm7oI7OAo`0000?oKgoB00?o0000ogZ6e?mjQ]@01ol00002oh^Ee`05o`00
0?nBVmWoTY_Ioi:KfOl000001OnIX=X00ol0003oWZGJoijUfP02oijUfP06o`000?nSZ=Wo0000o`00
0?nU/N7o00001OnX/]l01_l0003o[;?Mo`000?l0003oZkgWo`0000Go[[_S00?o0000ok6gg_l00000
0_l000000on/`NWo0000ok6kh@04ok6kh@06o`000?ne]]Wo0000o`000?n`_>?o00001Onf]]T00ol0
003o^k3?o`000004okNdeP04o`000?nm[lco_Jo<okf_c0;o00001Oo0[LL00ol0003oaJ^oo`000004
olB/`P05o`000?o9Z[[obJZjolVZ^_l000000_o7Zkd01?l0003oc:VfolbY]_l00002ol^Z^005o`00
0?o?ZK?ocjVcolnY/ol000000_o?Z[<01?l0003odJZ`om6Z/?l00004om:Z/0;o00001?oDZjl00ol0
003ocjVcolnY/`03olnY/`03o`000?oF[Jko000000;o]Yo200Go0000olfZ]oo=Z[OocJZgo`000006
ojnOb0;o00000onW`>`01?l0003oYl3/o`000?nW`>`3o`0000CoYl3/00Co0000ojO0k?nW`>coYl3/
0ol00004ojO0k003o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool002kooooo1Ol0
0004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o
00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k005o`0000?o
Yl3/00?o0000ojO0k?nW`>`02?l000000omUOmSo0000ofAgd@02ofAgd@04o`000?m_Om;oKgoBofmo
dPCo00000on3S]H00ol0003oRiGGoh^Ee`02oh^Ee`05o`000?nBVmWoTY_Ioi:KfOl000001?nIX=X0
1?l0003oWZGJoijUf_nNYMX3o`0000CoYK7Q00?o0000ojRbgonX/]l00_nX/]l2o`0000CoZkgW00?o
0000ojjkhon^^n<00_n^^n<2o`0000Go[<7Y00?o0000ok6khOna^n400_na^n42o`0000Co/;cS00?o
0000okJffOnf]]T00_nf]]T2o`0000Go]kCF00Ko0000okf_c?nm[lco0000okVbd_l00006ol2]a`03
o`000?o4[<;oa:c200?oa:c200Co0000olVZ^_o9Z[[o00000oo7Zkd01?l0003oc:VfolbY]_l00003
ol^Z^004o`000?o?ZK?ocjVco`0000;ocjZc00?o0000om6Z/?l000001OoBZ[000ol0003oe:^_omB[
[`02omB[[`03o`000?oE[:oo000000?ocjVc00Ko0000omJ][_oF[Jko0000okJO`_l00004olfZ]`03
o`000?n_WlSo[io800?o[io80_l00004ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k005o`0000;o
Yl3/00Co0000ojO0k?nW`>coYl3/0ol0000Fooooo`03o`000?oooooooooo01;ooooo000]ooooo`;o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00Co00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0
k002ojO0k0?o00000_nW`>`01_l0003oJhgQof^=hOm[SN7o0000oeU`d0;o00000omTMm45o`0000?o
NXKD00Go0000oh>>e_n3S]KoPhkFo`000004oh^Ee`05o`000?nBVmWoTY_Ioi:KfOl000000_nIX=X5
o`0000;oXJkQ00?o0000ojFahOnU/N400onU/N401?l0003oZ;;Oo`000?l00002ojRnj@03o`000?n[
_NOoZkgW00;oZkgW00Co0000ojjkhol0003o00000_nXa^l00ol0003o[<7Yojc1j@02ojc1j@03o`00
0?na^n7o000000;o000000?oZ<C]o`000?n`_><01?n`_><01_l0003o][KIo`000?l0003o[k_So`00
00Go]kCF00?o0000okf_c?l000000oni/]800ol0003o`:g7ol2]a`02ol2]a`;o00001_o4[<82o`00
00Coaj^m00?o0000olbY]_l000001?o;Z[P00ol0003ocjVco`000004olnZ/`03o`000?oBZ[3odZZ`
00CodZZ`00?o0000omB[[ooDZjl00_oDZjl00ol0003oeJb_o`000003olnY/`05o`000?oF[JkoeZf^
omJ][_l000001?o=Z[L00ol0003oejn`o`000003ojnOb005o`000?o7Zkkoaj^no`000?nW`>`00_l0
00001OnTX=7o0000ojO0k?nW`>co000000;oYl3/0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/
1?l00003ojO0k003o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool002gooooo0_l0
0004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0
k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o00001?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`01Ol0003oYl3/ojO0k?nW`>co000000?oJhgQ00?o0000oeU`d?mIL=001?l00003ofmo
dP05o`000?mjQ]CoNXKDogZ6e?l000001?n3S]H01Ol0003oRiGGoh^Eeon;UMOo000000;oTY_I1?l0
0002oibYg`03o`000?nQ[^7oXJkQ00?oXJkQ00Co0000ojFahOnU/N7oYK7Q0ol00005ojRnj@03o`00
0?n[_NOoZkgW00?o00001OnXa^l00ol0003o[<7Yojc1j@04o`0000CoZ<C]00Co0000ok2lhon`_>?o
/;cS0ol00004ojnkh`03o`000?ng]=Ko]kCF00;o]kCF0_l00005okVbdP04o`000?o0[LOo`:g7o`00
00;o_:o=00?o0000olB/`_o4[<800_o4[<82o`0000Koaj^m00?o0000ol^Z^?o;Z[P01?o;Z[P00ol0
003ocjZcolnZ/`03olnZ/`03o`000?oBZ[3odZZ`00?odZZ`00?o0000om:[/Ol000000_oDZjl01ol0
003oeJb_omF/[ooE[:oo0000olnY/ol000001?oF[Jh00ol0003ocJZgolfZ]`02olfZ]`03o`000?oG
[k3o000000;o[io800?o0000olN[__o7Zkh00_o7Zkh00ol0003oY:3AojBPd@02ojBPd@03o`000?nW
`>co000000;o000000?oYl3/o`000?nW`>`00onW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000Go
Yl3/0_l0000Eooooo`03o`000?oooooooooo017ooooo000Rooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool01?l0003oooooo`000?nW`>`2o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0
003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>co
Yl3/00;oYl3/0ol00004ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k005o`000?nW`>coYl3/ojO0k?l000000_m[
SN401?l0003oFG3@o`000?l00002ofIid@Wo00000on3S]H8o`0000;oUj?N00?o0000oibYgonLZMl0
0_nLZMl00ol0003oXJkQoj6^h@02oj6^h@Co00000_nV_NX00ol0003oZ;kYojRnj@03ojRnj@?o0000
0onVbO801?l0003oZ<K_ojS6konXa^l4o`0000CoXL_e00?o0000ojS4kOnXa>d01Ol00002ojC3l003
o`000?n_^n?o[k_S00?o[k_S00Ko0000okNde_l0003o0000ojnhh?l00005okVbdP03o`000?o0[LOo
000000Co_:o=00Ko0000olB/`_o4[<;o0000ol6]a_l00006olN[_@03o`000?o;Z[SobjZh00CobjZh
00?o0000olnZ/oo?Z[<00_o?Z[<00ol0003ocj^eo`000004om:Z/003o`000?oBZk7o000000;oe:^_
00Oo0000omF/[ooE[:ooeJb_o`000?o?ZK?o000000?oeZf^00?o0000omR^[_l000000_o=Z[L01_l0
003oejn`omN_/?l0003o[io8o`0000Goaj^n00?o0000ojBPdOnTX=400_nTX=42o`000003ojO0k?l0
003oYl3/00;oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>co000000;o000000?o
Yl3/o`000?ooool05Oooool00ol0003oooooooooo`0@ooooo`008_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00_l00004ojO0k003o`000?nW`>coYl3/00Co00001?nW
`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`02_l00002oeU`d004
o`000?mVNM7oIWWAo`0000?oLh;D00?o0000ogj<e_mnS=H01?l00002ohRDf@05o`000?n@W=_oT9cK
oi2Lfol000001?nGXmh00ol0003oW:WOoibYg`02oibYg`04o`000?nQ[^7o0000o`0000;oXk[Y00?o
0000ojJmj_nV_NX00_nV_NX00ol0003oZ;kYo`000002o`000003ojG;m?l0003oY/Wb00?oY/Wb1?l0
0003oicAnP04o`000?nQboGoXL_eoj7;m@Co00000onGc?X00ol0003oY<?`ojC3l002ojC3l004o`00
0?n_^n?o[k_Sojnkh`?o00001?n_^>000ol0003o^K;BokVbdP02okVbdP;o00001Onl[ld00ol0003o
a:c2o`000003ol6]aP03o`000?o7Zkgoaj^m00;oaj^m00?o0000olJ/`?l000001?o;Z[P00ol0003o
bj^jo`000003olnZ/`03o`000?o?ZkGo000000?odZZ`00Ko0000om:[/OoBZk7o0000omB[[ol00005
omF/[`03o`000?oF[JkoeZf^00;oeZf^00?o0000omR^[_l000000_o=Z[L01Ol0003oejn`omN_/?oG
[k3o000000Goaj^n00?o0000omNc]?l000000_nTX=400ol0003o_Jg9o`000002ojO0k003o`000?nW
`>co000000?o00000onW`>`00ol0003oYl3/ojO0k003o`0000GoYl3/00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0@ooooo`008_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool00_ooool00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW`>`01?l0
0004ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000Co
Yl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0
003oYl3/ojO0k002ojO0k0?o00000onW`>`4o`000003odaWcOl0003o000000?oFG3@00Co0000ofIi
dOmVNM7o00000omcP]@01?l0003oOXcFogj<e_l00005ohRDf@05o`000?n@W=_oT9cKoi2Lfol00000
1?nGXmh00ol0003oW:WOoibYg`03o`0000GoXk[Y00?o0000ojJmj_nV_NX01?l00004ojG;m004o`00
0?nVbO;o0000o`0000?oV]Km00?o0000oicAn_nLdOX01Ol00003ohWBo`03o`000?nGc?[oUlcj00;o
Ulcj00?o0000ojC3l?nT`o001Ol00002oj70k`03o`000?n_^>3o[kSP00;o[kSP00?o0000okVbd_l0
00000_l000000onb]=_o0000okb_c@04okb_c@;o00001Oo1[LH01?l0003oaj^molN[_Ol00002olJ/
`005o`000?o;Z[SobjZhol^Z^?l000000_o;ZkX01?l0003ocjZcolnZ/ol00003oln[]@03o`000?oB
Z[3o000000CodZ^a0_l00005omF/[`05o`000?oF[JkoeZf^omJ][_l000000_oH[Zh00ol0003ocJZg
o`000004omN_/003o`000?o7Zkkoaj^n00?oaj^n00Go0000omNc]?l0003oY:3Ao`000003okf]b@06
o`000?nW`>co0000o`000?nW]>;o00001OnW`>`3o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/0ol0
000Eooooo`03o`000?oooooooooo00oooooo000Rooooo`05o`000?ooooooooooooooool000001_oo
ool2o`0000Cooooo0_l00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k003o`000?nW
`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l0
0004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/
o`000?l00002ojO0k003o`000?nW`>co000000?o00000_mjZ?000ol0003oC6O=odaWc@04o`0000?o
IWWA00Go0000og>2e?mcP]CoLh;Do`000002ogj<eP03o`000?n8U=WoR9CI00;oR9CI00Go0000oi2L
fon@W=_oT9cKo`000003oiNSgPCo00000_nP]NL00ol0003oXk[Yoj>jj@03oj>jj@?o00001?nUbo@0
0ol0003oYL_dojG;m005o`0000;oV]Km1?l00004ogoGo`03o`000?n9d_ooRM;o00Wo00000_n;ao`0
0ol0003oXL3_oj70k`03oj70k`03o`000?n_^>3o[kSP00?o00001Onb]=/00ol0003o_:o=okb_c@02
o`000003okNadol0003o`Jg600Co`Jg600?o0000olN[_Ol000000oo6[<001?l0003objZhol^Z^?l0
0003ol^[^P03o`000?o?Z[?o000000Cocj^e00?o0000om:Z/?l000001?oBZk400ol0003oeJb_omF/
[`03omF/[`03o`000?oF[Joo000000;oeZf^00Co0000omR^[_oH[Zkof:j^0_l00003omN_/003o`00
0?oJ/Zoo000000?oaj^n00Go0000omNc]?oG/kCoek>do`000005okf]b@03o`000?nW]>;o000000;o
YkCR00?o0000ojO0k?l000000_l000000onW`>co0000ojO0k003ojO0k0Co00000_nW`>`00ol0003o
ooooooooo`0Cooooo`;o00004?ooool002;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ojO0k?nW`>`00_nW`>`01?l0003oYl3/o`000?l00002ojO0
k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0
k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0
k?nW`>`01?l00002ojO0k0?o00000_nW`>`5o`0000;oC6O=00?o0000oeabd?mLL]001Ol00003og>2
e005o`000?mnS=KoOXcFogj<e_l000000on8U=T00ol0003oT9cKoi2Lf`05o`0000;oW:kT00?o0000
oj2eionP]NL00_nP]NL00ol0003oXk[Yo`000002o`0000;oYLSb00Co0000ojG;m?nUboCoYL_d1?l0
0003oi_Io@Co00000_mmfo`9o`0000CoElSf00Go0000og3:oom`b_ooL<[oo`000003oh_7o004o`00
0?nQ`>ooXL3_oj70k`Co00000onQ^n`00ol0003o/[CKok:df`02ok:df`03o`000?nl[lgo000000Co
]k7C00?o0000ol6]a_o1[LH00_o1[LH2o`0000GoaZc00_l00005ol^[^P;o00001Oo?ZkD00ol0003o
dZ^aom:[/@03om:[/@03o`000?oE[:ooeJb_00;oeJb_00Ko0000omJ][ooF[Joo0000omJ][_l00004
omR^[P03o`000?oG[k3oejn`00;oejn`00Ko0000omZb[ooJ/Zoo0000olN[__l00004omNc]003o`00
0?nm[LWo_Jg900?o_Jg900Go0000ojNdh_nW]>;o0000ojNdhP02o`0000GoYl3/00Ko0000ojO0k?l0
003o0000ojO0k?l00005ojO0k003o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
02;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ojO0k?nW`>`01?l00004ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW
`>`01?l0003oYl3/o`000?l00002ojO0k004o`000?nW`>coYl3/ojO0k0?o00000onW`>`00ol0003o
Yl3/ojO0k002ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/0ol000000onW`>co
0000o`000002o`0000;oW[g_00?o0000ocaMb_l000000om<Ild01?l0003oG7;@oeabd?l00002of]m
d`oo00000onFY^400ol0003oW:kToib^i002oib^i003o`000?nP]NOoX;GW00Co00001?nUb?84o`00
00?oX=[l1?l00002ohGPnago00000_n5`O/00ol0003oXK_/oj6kk003oj6kk003o`000?nb]=_o/[CK
00?o00001Ong/M<00ol0003o`Jg6ol6]aP02o`000003okf_c?l0003oaZc000CoaZc000?o0000ol^[
^_o;ZkX01?o;ZkX00ol0003ocj^eoln[]@04oln[]@03o`000?oBZk7odZ^a00;odZ^a00?o0000om>]
/_l000000ooE[:l01_l0003oeZf_omJ][ol0003oeZf^o`0000Cof:j^00Go0000omN_/?oG[k3oejn`
o`000003omZb[`03o`000?o7Zkko000000?oek>d00?o0000omZf]?l000000onm[LT01?l0003ockG1
o`000?nW]>82o`0000;o/:oG00Co0000ojO0k?nW`>coYl3/0ol00004ojO0k003o`000?nW`>coYl3/
00?o00005_ooool00ol0003oooooooooo`0=ooooo`008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool01oooool2o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/
00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`4
o`000004ojO0k?l0003o0000o`0000?oYl3/00Ko0000oijmkonN_NooW[g_o`000?llGLX2o`000003
odaWcOl0003oG7;@00;oG7;@00Co0000of]mdom[OM?o00000omiR=H01Ol0003oQI?JohFCf_n5Tm[o
000000CoSYgM00?o0000oiJVhOnFY^400_nFY^400ol0003oW:kToib^i004o`0000CoYL?_00Co0000
ojG8l_l0003o00000onVfOX01?l0003oX=[lo`000?l00003oi;Un`co000000KomNZjo`000?odi;[o
m>Bjo`000?oag;X2o`000003onSF`ol0003o000000Wo00000on5`O/01?l0003oXK_/oj6kk?nQ^n`4
o`0000;oY[OU00?o0000okNadong/M<00ong/M<00ol0003o`Jg6o`000004okf_c004o`000?o6[<3o
aZc0olJ/`0;o00001_o;ZkX00ol0003ocj^eoln[]@03oln[]@03o`000?o>[;Oo000000?odZ^a00?o
0000om>]/_l000000_oE[:l00ol0003oeZf_omJ][`02omJ][`03o`000?oH[Zkof:j^00;of:j^00?o
0000omVa[ol000000_oG[k000ol0003of[:_omZb[`02omZb[`03o`000?oG/kCoek>d00;oek>d00?o
0000omZf]?l000000_nm[LT01ol0003ockG1olne`Oo?]L7o0000ok2_eol000000_n`[mL4o`0000;o
Yl3/00Co0000ojO0k?nW`>coYl3/1?l00003ojO0k003o`000?oooooooooo01Cooooo00?o0000oooo
ooooool03?ooool002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0
k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Co0000ojO0
k?l0003o00000_nW`>`00ol0003oYl3/o`000003o`000005ojO0k?l0003o0000ojO0k?l000001?nW
`>`3o`000005oijmkol0003o?5g:o`000?m?JLd00_l00003oeabd005o`000?m[OM?oJggCof]mdol0
00000omiR=H01Ol0003oQI?JohFCf_n5Tm[o000000CoSYgM00?o0000oiJVhOnFY^401?l00003oj>l
j`03o`000?nU`nooYL?_00;oYL?_0ol00004ojKInPCo000000?oT^Gko`000?l000001?l000001oo=
o;Wo0000o`000?l0003ol_Bjo`000?odl;X00_l00002ooCT^P06o`000?oag;[olMbjo`000?o]e;[o
00000ooRbl401?l0003ofl6oom_1_ooK`Kl;o`0000;oQk_g00?o0000ojJgiOnV]nD00_nV]nD00ol0
003o]k7CokNad`02okNad`;o00001Onm[l`01?l0003oaZc0olJ/`?l00002ol>]a003o`000?o;Zk[o
bj^j00;obj^j00?o0000olV/_Ol000000oo?ZkD01?l0003ocZbgolj/]ol00002om:[/@04o`000?oC
[K;odjfbo`0000;oeJb_00?o0000omJ][ooF[Jl00_oF[Jl00ol0003of:j^omR^[P02omR^[P05o`00
0?oI/Joo0000omN_/?l000001OoJ/Zl01Ol0003oek>domNc]?oG/kCo000000;of[Jd00?o0000okf]
bOl000001?o?]L400ol0003o/:oGok2_e`02o`000003ol6hdOl0003oYl3/00?oYl3/1?l00002ojO0
k003o`000?nW`>coYl3/00;oYl3/0_l0000Eooooo`03o`000?oooooooooo00cooooo000/ooooo`03
o`000?oooooooooo00Wooooo00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0
k0?o00000onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k0;o00000_nW`>`3o`0000CoYl3/00Oo0000ojO0
k?l0003o0000ojO0k?l0003o@g7I00;o00000_llGLX00ol0003oCfW=odmYc@04o`0000?oJggC00Go
0000ogV8e_miR=KoNHSFo`000003ohFCfP04o`000?n>WMgoSYgMohjMg@Co00000onN/^H00ol0003o
Xkc[oj>lj`02oj>lj`04o`000?nU`noo0000o`0000?oZMCf00Co0000ojKIn_l0003o00000_nQio/6
o`000003oi3X/?l0003o000000?o000000Kol_Bjo`000?odl;[o0000ooGZ^_l00002ooCT^P03o`00
0?oag;[o000000;okMBj0_l000000ooRbl7o0000om_1_`02om_1_`03o`000?oD]kgo000000;obK72
1ol00003ohNkm`03o`000?nV]nGoY[OU00;oY[OU00Ko0000okNadol0003o0000ojfcg?l00005okf_
c003o`000?o6[<3o000000Co`jg400Co0000ol^[^_o;Zk[o00000_o9[;d01?l0003ocj^eoln[]Ol0
0003olj/]`03o`000?oBZk7o000000Codjfb0_l00004omJ][`03o`000?oG/;3o000000;of:j^00Ko
0000omVa[ooI/Joo0000omN_/?l00004omZb[`03o`000?oL]K3o000000;oek>d00Go0000omZf]?oJ
][Cof[Jdo`000004olne`@04o`000?oH^kco0000ok2_e`;o00000_o1^=401_l0003oYl3/o`000?l0
003oYkOUo`0000GoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l0000Fooooo`03o`000?oooooooooo
00_ooooo000/ooooo`;o00002oooool2o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0
003oYl3/ojO0k002ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/1ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003o@g7Iod=af@02o`000004ocaMb_l0003oCfW=o`0000;oHWKA1Ol00003ogV8eP03o`00
0?n5Tm[oQI?J00Go00000_nGZ>800ol0003oW[;VoijbiP03oijbiP03o`000?nS_>_oXkc[00Co0000
0onYe?H7o`000003oiC^l_l0003o000000Go000000OocObio`000?o^n;_o0000oo;d^_l0003om?2j
00;o00000_odi;X01_l0003olMbjoo7L^_l0003okMBjo`0000;oj<bj00Go0000om_1_ooK`Koofl6o
o`000002omBg_@03o`000?o9/L;o000000;o`jNn0ol000000ol4R]_o0000o`000003o`0000?oY[OU
0ol00004ojfcg003o`000?nm[lco_Jo<00;o_Jo<0_l00005ol>]a003o`000?o;Zk[o000000?obJbm
00Co0000oln[]Oo?ZkGo00001?o>[;L2o`0000Codjfb00?o0000omJ][ooF[Jl00ooF[Jl00ol0003o
ek2`o`000002omR^[P05o`000?oI/JoofK6_omVa[ol000001OoJ/Zl01Ol0003og;F`o`000?oG/kCo
000000Cof[Jd00Go0000olne`Oo?]L7ockG1o`000003omRk_004o`000?o1^=7o`KSAo`0000;o`KSA
00?o0000ojNgiOnW]nD00_nW]nD01?l0003oYl3/ojO0k?nW`>`3o`0000CoYl3/00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003oooooooooo`0=ooooo`03o`00
0?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0
k?l000001Ol00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`02?l0003oYl3/ojO0k?nW`>co
0000od=afOl0003o?Ug90_l00002odmYc@04o`000?mRM]7oHWKAo`0000;oLX?E1ol00002ohfLg@03
o`000?nGZ>;oUjSR00?oUjSR00?o0000oijbi_nN/^H00_nN/^H3o`0000?oZlca1?l00002ojgTn@04
o`000?n/lOKo[?7fojcamP;o000000?oW_CFo`000?l000000ol000001oo=o;Wo0000o`000?l0003o
l_Bjo`000?odl;X00_l00003ooCT^P03o`000?oag;[o000000;okMBj00Co0000onS<^_oXc;[o0000
0ooK`Kl01Ol0003oe;NmomBg_OoD]kgo000000Co`jNn00?o0000okJO`Ol000000ol000000omH[_[o
0000o`000002o`0000;oT;K`00?o0000ojfcg?n]/m`00_n]/m`00ol0003o_Jo<o`000002o`000003
okN`dol0003o`jg400Co`jg40_l00005olV/_@;o00001Oo>[;L00ol0003odjfbom>]/P03om>]/P03
o`000?oF[JooeZf_00;oeZf_00Ko0000omN`/?oG/;3o0000omR^[_l00004omVa[`03o`000?oJ/Zoo
f[:_00;of[:_00Ko0000ombe/?oL]K3o0000omNc]?l00003omZf]003o`000?oN^[Co000000;ockG1
00Go0000omRk_?oH^kcof;^lo`000002ol6hd@04o`000?o1^=7o0000o`0000CoYkOU1?l00003ojO0
k003o`000?nW`>coYl3/00?o00005Oooool00ol0003oooooooooo`0:ooooo`00:oooool00ol0003o
ooooooooo`0>ooooo`;o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?nW
`>`00ol00004ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`000005ojO0k?l0003o0000ojO0
k?l000001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`5o`0000;o@g7I00?o0000ociM
bOlnGLT00_l000001Om?JLgo0000of9fdOmRM]7o000000;oLX?E00Go0000oh6@fOn1T=WoPI3Io`00
0004ohfLg@03o`000?nGZ>;oUjSR00;oUjSR00?o0000oijbi_l000000_l00002ojS1k004o`000?n[
c?7o0000o`0000?o/]ce00?o0000ojgTnOl000000_n/lOH6o`000003olCmb?l0003o000000Co0000
00Kol_Bjo`000?odl;[o0000ooGZ^_l00002ooCT^P03o`000?oag;[o000000;okMBj00So0000onS<
^_oXc;[o0000on;4^_l0003ofl6oo`0000Coe;Nm00?o0000ol>W__o3Ykh00oo3Ykh01?l0003o/INm
ok6G_OnaUkd5o`0000CoT;K`00Co0000ojfcg?n]/mco[K?L0_l00005okN`d`07o`000?o3[LCo`jg4
ol>]a?l0003o_jo9o`000005olV/_@03o`000?o>[;OocZbg00CocZbg00?o0000om>]/_oC[K800_oC
[K800ol0003odjndo`000003omJ][`04o`000?oG/;3oek2`omN`/0;o00000ooI/Jl00ol0003ofk>`
o`000003omZb[`05o`000?oL]K3og;F`ombe/?l000001?oJ][@01Ol0003og[Zdo`000?o?]L7o0000
00?of;^l00?o0000ombo_Ol000000_o1^=401Ol0003oc[o<oljoc?l0003oYkOU00;o000000?o/;_R
o`000?nW`>`01?nW`>`3o`0000?oYl3/00?o0000ooooooooool04oooool00ol0003oooooooooo`09
ooooo`00:oooool00ol0003oooooooooo`0?ooooo`03o`000?nW`>coYl3/00;oYl3/0ol00004ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/0ol000000onW
`>co0000o`000002o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002
ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ofFVmOl000000_l000001Om3LMWo0000ociM
bOl0003oE6c>00;o00000omRM]401?l0003oLX?Eog:3eOl00003oh6@f@03o`000?n=W=goSIcM00;o
SIcM00?o0000oiNXh_nGZ>801?l00004ojS1k0?o00001?nbg?D:o`000003olCmb?l0003o000000?o
000000Gok_Rko`000?obm;[o0000ooC`^P04o`000006ooCT^_l0003olMbjo`000?o]e;[o00000ooX
c;X01?l0003oh/Bjon;4^_l00004omBg_@03o`000?o=[[_o000000?o`jNn0_l00004ok6G_@;o0000
00?o48_Uo`000?l000001?l000001On]/mco0000o`000?nN/nOo000000Go]k3C00Co0000ol>]a?o3
[LCo00000ono[lT01?l0003obJbmolV/_Oo9[;d2o`0000GocZbg00?o0000olj^^_l000000ooC[K80
1_l0003odjndom>_]?l0003oeZf_o`0000Coek2`00?o0000omVa[ooI/Jl00_oI/Jl01_l0003ofk>`
om^c/?l0003of[:_o`0000Cog;F`00Go0000omZf]?oJ][Cof[Jdo`000003omjj]003o`000?oH^kco
f;^l00;of;^l00Oo0000ombo_Ol0003o`KSAo`000?o>_lco000000;oc[o<00?o0000ok2kh_n`^n80
0_n`^n800ol0003oYl3/o`000002o`000003ojO1k?l0003oYl3/00?oYl3/0_l0000Cooooo`?o0000
2_ooool002_ooooo00?o0000ooooooooool04?ooool01?l0003oYl3/o`000?l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/0ol00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00004ojO0k0Oo0000
1?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k004o`00
0?mUY_Go0000obY?a0;o00000_lnGLT00ol0003oE6c>oeA/cP04o`0000?oLX?E00Go0000oh6@fOn1
T=WoPI3Io`000002ohfLg@Co00001?nR]NH01?l0003oZ<7/o`000?l00003ok?Al005o`000?nbg?Go
0000o`000?njk?D00_l000001?nnmnoo0000ol7mhoo1oN<4o`000004on7mbOl0003o0000on[j_@Ko
000000Com^>eo`000?oeg[GomMje1?l000001Oo]e;[o0000onS<^_oXc;[o000000?oh/Bj00Go0000
omBg_OoD]kgoe;Nmo`000002olf^^`04o`000?o3Ykko`jNno`0000;o_9nk00?o0000ok6G_OnaUkd0
0_naUkd3o`000004oa2;iOl0003oK:khofb^n0;o00001?nN/nL00ol0003o]k3CokN`d`02okN`d`03
o`000?o3[LCo000000Co_jo900Co0000olV/_Oo9[;go00000_o7[/401Ol0003ocZbgolj/]oo>[;Oo
000000;ocZjj00Co0000om>]/_oC[K;o00000ooC[k@00ol0003oeZf_o`000004omN`/005o`000?oI
/JoofK6_omVa[ol000000ooK/k000ol0003of[:_o`000003ombe/005o`000?oO^K7o0000omZf]?l0
00001?oN^[@01Ol0003of;^lomRk_?oH^kco000000?og;nm00Go0000oljoc?o>_lco0000oljoc002
o`0000Co/;_R0_l00005ojO1k0Co000000?oYl3/o`000?ooool03oooool3o`0000;ooooo00?o0000
ooooooooool02?ooool002_ooooo0_l0000Booooo`;o00001?nW`>`01?l0003oYl3/o`000?l00002
ojO0k006o`000?nW`>coYl3/ojO0k?l0003oYl3/0_l00002ojO0k003o`000?nW`>co000000Go0000
0onW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/
00?o0000ojO0k?nW`>`00ol000001?mUY_Go0000obY?a?lZCl@3o`0000;oE6c>00?o0000ofYldomZ
O=<02ol00003oiRXh@03o`000?nR]NKoX[GV00;oX[GV0_l00005ok?Al0?o000000Go^^ceo`000?nn
mnoo__O_o`000002ol7mh`Co000000CohOg9o`000?l0003oj_Zm0ol000000ooek;So0000ooKX]P02
o`0000?omMje00Go0000oo?I]Ol0003ol=>eo`000002onS<^P09o`000?oRa;[oh/Bjon;4^_l0003o
g;bio`000?oD]kgo000000?ocJjk00?o0000ol>W__l000000onlWk/01?l0003o/INmok6G_OnaUkd3
o`000004oj69^_l0003o0000o`0000;oK:kh00?o0000oijcionN/nL00onN/nL01?l0003o]k3CokN`
dong/=<2o`0000Go_jo900?o0000olV/_Ol000001?o7[/401?l0003ocZbgolj/]ol00002olj^^P03
o`000?oC[K;o000000Godjnd00?o0000omN`/?oG/;000_oG/;000ol0003ofK:bo`000002omVa[`03
o`000?oK/k3ofk>`00;ofk>`00?o0000ombe/?oL]K000_oL]K001Ol0003ogkVao`000?oJ][Co0000
00?og[Zd00Go0000on6n]Ol0003of;^lo`000004ombo_@05o`000?o>_lcoc[o<oljoc?l000000_oC
aL`01?l0003o/;_Ro`000?l00002okS1h003o`000?nW`NcoYl7/00?o00001OnW`>`00ol0003ooooo
ooooo`0:ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`00:oooool00ol0003ooooooooo
o`0Cooooo`03o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/0_l0
00000onW`>co0000o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00004ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00002obY?a003
o`000?m4H<[o000000?oE6c>00Co0000ofYldomZO=?o00000omlS=L01Ol0003oS9[LohbJg?n<V]co
000000GoV:SQ00Co0000oj:ei_l0003o00000_n^`nX00ol0003o/m7`o`000002o`0000;o_^3`2?l0
00001?oGo=go0000o`000?oQoLT4o`000008ooC_^ol0003omNbho`000?ofj;Ko0000ooKS]Ol00002
ooGN]@03o`000?ocfKGo000000;ol=>e0_l000001OoXc;[o0000on;4^_oRa;[o000000?og;bi00?o
0000olf^^oo=[[/00oo=[[/00ol0003o_9nkokbO^`02okbO^`06o`000?naUkgo0000o`000?n]TKWo
00001?nQRKX5o`0000CoW[?W00Ko0000okN`dol0003o0000ojfafol00005okn_b@;o00001Oo7[/40
0ol0003ocZbgo`000004olj^^P;o00001OoC[k@00ol0003oek2`omN`/002omN`/005o`000?oI/[;o
0000omVa[ol000001OoK/k001Ol0003og;F`ombe/?oL]K3o000000?ogkVa00?o0000omjj]?oN^[@0
0_oN^[@01Ol0003ohKjeo`000?oH^kco000000?og;nm00Oo0000omo5__l0003oc[o<o`000?oCaLco
000000;odlG<00?o0000okS1h?nh`N000_nh`N03o`0000?oYl;]00?o0000ojO0k?nW`>`00ol00008
ooooo`Co00002?ooool00ol0003oooooooooo`08ooooo`00:_ooool00ol0003oooooooooo`0Eoooo
o`;o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/1ol00004ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00002
ojO0k003o`000?nW`>coYl3/00;oYl3/0_l00003obY?a006o`000?m4H<[o0000o`000?mDK<ko0000
0omZO=<01Ol0003oO8cGogb<eomlS=Oo000000?oS9[L00Co0000oiRXhOnHZ>7oV:SQ0ol00004ojk3
jP?o00000onnh?001ol0003ob>g]olS]kOo8kNgo0000om7gi_l000000_oGo=d2o`0000;ohOg90_l0
00000ooal[oo0000o`000002ooG/^004o`000?ofj;Ko0000o`0000;omMje00Ko0000oo?I]OocfKGo
0000oo3C]Ol00002onc=]@05o`000?oRa;[oh/Bjon;4^_l000000ooL_;T00ol0003ocJjkolf^^`02
olf^^`;o00001OnlWk/00ol0003o[I6iojfA^@02ojfA^@08o`000?nQRK[oXHVjoj69^_l0003oU8:l
o`000?lbU_47o`0000Co[K7K00?o0000okn_bOno[lT00_l000000onj/=3o0000olN^`@04olN^`@;o
00001Oo>[[X00ol0003odjndom>_]003om>_]003o`000?oD/KOo000000;oek2`00Ko0000omVb/_oI
/[;o0000omVa[ol00004om^c/003o`000?oM]k7o000000;og;F`00Go0000omni/OoO^K7ogkVao`00
0003omjj]005o`000?oQ_[GohKjeon6n]Ol000000ooL_kd01Ol0003oglFnomo5__oOaKko000000?o
dlG<0_l000000ooGblko0000okS1h002o`0000;o_/KP00?o0000ojO2kOnW`^d01?l00003ojO0k003
o`000?oooooooooo00;ooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo000Zooooo`03o`00
0?oooooooooo01Kooooo00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/1ol00004ojO0k003o`00
0?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00Ko0000ojO0k?l0003o
0000ojO0k?l00004ojO0k006o`000?nW`>coYl3/ojO0k?l0003o5TC00_l000001OlZClCo0000odAP
b_l0003oGG;@00;o00000omZO=<01Ol0003oO8cGogb<eomlS=Oo000000;oS9[L1Ol00002ojFei005
o`000?n^`n[o[/?Zojk3j_l000000onkd^/00ol0003o_^3`o`000003olS]k@03o`000?oAmnKo0000
00;oeocM0_l00002on7mb@;o000000[olO:oo`000?odkk_o0000ooG/^?l0003om^Rfo`000?ofhkGo
00000_oeg[D00ol0003olmVeo`000002oo3C]@03o`000?o/cKGok<fe00;o000000?oh/Bjo`000?oL
_;T00_oL_;T00ol0003oe[Bho`000002olf^^`04o`000?o6Y[WoaZJio`0000?o_9nk0_l00004ojfA
^@05o`000?nQRK[oXHVjoj69^_l000000_nDP[`3o`0000CoQZo`00?o0000ojfafon]/M/00_n]/M/0
0ol0003o_jo9o`000004okZ`d007o`000?o7[/7oajk1olN^`Ol0003oaK36o`000005olj^^P03o`00
0?oC[kCodjnd00?odjnd00?o0000omBa]ol000000_oG/;001Ol0003ofK:bomVb/_oI/[;o000000Go
fk>`00Go0000omfg/Ol0003og;F`o`000003omni/@05o`000?oR_K?o0000omjj]?l000001?oQ_[D0
1Ol0003og;nmombo_OoL_kgo000000?oglFn00Go0000om?5c?oCaLcodlG<o`000003omO;cP03o`00
0?nna^3o_/KP00;o_/KP0ol00002ojG0k@03o`000?nW`>coYl3/00;oYl3/1Ol0000@ooooo`03o`00
0?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo01Oooooo00Co0000ojO0k?l0003o0000
0_nW`>`00ol0003oYl3/o`000004o`0000?oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/
ojO0k006o`000003oaI4`?l0003o;U7400;o00000_m4H<X00ol0003oGG;@oeebd00:o`0000;oV:KO
00?o0000ojFei?nU]N@00onU]N@00ol0003o[/?Zo`000004ok_Bj`Co000000Cob>g]o`000?oAmnKo
00000_oGo=d6o`0000;olO:o0_l00002ooG/^007o`000?ofj;Ko0000ooKS]Ol0003omMjeo`000002
oo?I]@03o`000?o`dkGo000000;ok<fe00Co0000onO7]_oWakKo00000ooL_;T01_l0003oe[BhomJd
^?l0003ocJjko`0000?oaZJi00Ko0000okbO^onlWk_o0000okNH^?l00004ojfA^@03o`000?nQRK[o
XHVj00;oXHVj00Co0000oiB2_?nDP[coU8:l0_l00004ohJ_l003o`000?n]/M_o[K7K00?o00001Onj
/=001?l0003oajk1olN^`Ol00003olF`aP07o`000?o>[[[ocZjjolj^^_l0003ocK6mo`000003om>_
]006o`000?oD/KOoe;6go`000?oG/;3o00001?oI/[800ol0003ofk>`om^c/002om^c/006o`000?oM
]k7ogKNao`000?oL]K3o00000ooO^K401Ol0003oh[fco`000?oN^[Co000000?ohKje00Go0000onC4
^?l0003og;nmo`000003omo5_P08o`000?oRc<7o0000om?5c?l0003oel_>o`000?oGblh2o`0000;o
_/KP0_l000000oo3bn7o0000ojG0k@03ojG0k@06o`000?nW`>co0000o`000?nW`^go00004oooool0
0ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`0Hooooo`;o00000_nW`>`3o`00
0005ojO0k?l0003oYl3/ojO0k?l000001?nW`>`01?l0003oYl3/o`000?l00002ojO0k004o`000?nW
`>coYl3/ojO0k0?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?l`O^Oo000000?o000000Go;U74o`000?l0003oA63:o`000002oeebd005
o`000?mdQ=GoM8CEogB4eOl000000on8U]X00ol0003oV:KOoiRVg`02oiRVg`03o`000?nU]NCoYKGT
00;oYKGT0ol00003ok_Bj`04o`000?o8gnWob=oYolSOj@Oo000000Coi?CEo`000?oZmLgoj_G=0_l0
00002_oal[oo0000ooC_^ol0003omNbho`000?ofj;Ko0000ooKS]Ol00002ooGN]@03o`000?ocfKGo
000000;ol=>e00Co0000onc=]Oo/cKGo00000_oWakH01Ol0003og;biombl^OoL_;Wo000000?oe[Bh
00?o0000olJV^Oo6Y[T00_o6Y[T00ol0003o_9nko`000003okNH^003o`000?n]TKWo[I6i00;o[I6i
00?o0000oj69^_l000003_l00002oijai@03o`000?nj/=3o^[3@00?o^[3@00?o0000olN^`Ol00000
1?o5/<H01?l0003ocZjjolj^^_l00003olfa_@03o`000?oC[kCo000000Coe;6g0_l00003omVb/P03
o`000?oJ][Go000000?ofk>`00Go0000omfg/OoM]k7ogKNao`000003omni/@05o`000?oR_K?oh[fc
on:m/ol000001?oQ_[D01?l0003oi<BhonC4^?l00003omo5_P05o`000?oRc<7oh/c1on;<`Ol00000
0ooGblh00ol0003ofM7AomWAd@02o`0000Co`l_Q00?o0000ojG0kOnU`>d00ol00004ojO2k@03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01oooool002[ooooo0_l0000Jooooo`?o000000Co
Yl3/o`000?l0003o00001?nW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o0000ojO0k?l00000
0_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000onW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Co
Yl3/00So0000ojO0k?nW`>coYl3/o`000?l`O^Oo0000oa@o_0;o000000Go;U74o`000?l0003oA63:
o`000002oeebd005o`000?mdQ=GoM8CEogB4eOl000000on8U]X00ol0003oV:KOoiRVg`02oiRVg`04
o`000?nU]NCo0000o`0000?o/l;U00?o0000ok_Bjol000000_o8gnT2o`0000;oe>WU00Co0000omg`
gOoMl=gogO3M0_l00002on[ec@;o000000ColO:oo`000?odkk_o00000_oek;P01ol0003om^Rfo`00
0?ofhkGo0000ooGN]Ol000000_ocfKD00ol0003ol=>eo`000002onc=]@08o`000?oWakKoilNfo`00
0?oR`KKo0000ombl^Ol00004omJd^003o`000?o6Y[WoaZJi00?oaZJi00?o0000okNH^?ngV;P00_ng
V;P01?l0003o[I6iojfA^On]TKT3o`0000;oX8Fg00Ko0000oiIo^?nFOkSoUWnho`000?n;NKX3o`00
00;oGZ?e00?o0000oijaiOnN/ND00_nN/ND00ol0003o^[3@okZ`d002okZ`d0;o00001Oo5/<H00ol0
003ocZjjo`000004olfa_@03o`000?oC[kCo000000Coe;6g00?o0000omVb/_oI/[800_oI/[801_l0
003of[JeomZf]Ol0003ofk>`o`0000CogKNa00Go0000omni/OoO^K7ogkVao`000003on:m/`05o`00
0?oQ_[GohKjeon6n]Ol000000ooTa;P01Ol0003oglFnomo5__oOaKko000000?oh/c100So0000omO;
c_oGblko0000omWAdOl0003ofM7Ao`0000Co`l_Q1?l00002ojBok@04o`000?nW`^goYl;]ojO2k@?o
00004Oooool00ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`0Fooooo`?o0000
0_ooool2o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>coYl3/00?o0000
1?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00;oYl3/00?o0000ojO0k?l0
00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Ko000000Oo<7kWo`000?lD?kco0000obiAa?l0003o
C6G<00;o00000omML]001Ol0003oM8CEogB4eOmdQ=Go000000?oR9KJ00?o0000oiRVgonHY]l01?l0
0004ok?2i@?o000000?ob=oYo`000?oDjND00_oDjND01?l0003ogO3Momg`gOoMl=d2o`0000;oj_G=
0_l00002oo7b_`03o`000?odkk_o000000co000000Gol=>eo`000?o/cKGok<feo`000002onO7]P04
o`000?oR`KKoh/6fo`0000Coe[Bh00?o0000oln^^?l000000oo6Y[T2o`0000Co]iRh00Ko0000ojfA
^On]TKWo0000ojV<]_l00003oj25]`03o`000?nFOkSoUWnh00;oUWnh00?o0000oh]i^_n;NKX01Ol0
0004oijai@06o`000?nj/=3o0000o`000?nb/]So00001Oo5/<H2o`0000KocK6m00?o0000omBa]ooD
/KL00ooD/KL01Ol0003ofK:bomVb/_oI/[;o000000?of[Je00?o0000om^c/?l000000ooM]k401Ol0
003oh;bdo`000?oO^K7o000000?oh[fc00Go0000onC3]_l0003ohKjeo`000003onC4^005o`000?oW
bk_o0000omo5__l000000ooRc<401?l0003oi=?5o`000?l00002omWAd@?o00000oo3bn401?l0003o
a<oSolC?hol00002ojBok@Go00000onUa>l00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Oooooo000Zooooo`03o`000?oooooooooo01?ooooo0ol00007ooooo`03o`000?nW`>coYl3/00?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00?o00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nH_?3oV;c`
00?o00000_lD?k`00ol0003o;U74o`000002odaUc0Co00000omdQ=D00ol0003oR9KJohRFfP04o`00
00CoY[;Q00Co0000ok?2iOl0003o00000_o1cnD4o`000003omCYiOl0003ogO3M00;ogO3M00Ko0000
onCdeOl0003oj_G=o`000?o^m<D6o`000008ooGT^?l0003om^:eo`000?ofg[?o0000ooGK/_l00002
oo?G/P03o`000?oadk;o000000;ok<fe00Co0000onO7]_oWakKo00000ooR`KH01Ol0003oe[BhomJd
^?oF];So000000;ocjjh00Co0000olJV^Oo6Y[Wo00000_o0WkP00ol0003o]iRhokNH^002okNH^0;o
00000_nYS;H00ol0003oX8Fgoj25]`02oj25]`05o`000?nFOkSoUWnhoiIo^?l000000on;NKX2o`00
0003obF9k?l0003o000000Go00001?nb/]P01ol0003oaK36olF`a_o5/<Ko0000ol6cc?l000001Oo=
/Kd2o`0000Coe;6g00Go0000omBe^_l0003ofK:bo`000005omZf]@03o`000?oM]k7ogKNa00;ogKNa
00Go0000on2l]?l0003ogkVao`000003on:m/`05o`000?oT`kKo0000on6n]Ol000000ooTa;P01?l0
003oil^konO;^ol00003on;<`@04o`000?oTdlGoi=?5o`0000?ofM7A0_l000001?oIf=Ko0000ol?;
hOl00003olC?h`?o00000onV`>`01?l0003oYLC_ojG4konUa>l3o`0000oooooo00?o0000oooooooo
ool01oooool002Wooooo00?o0000ooooooooool04_ooool2o`0000_ooooo0_l00002ojO0k003o`00
0?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003o`000?nH_?3oV;c`00;o0000
0_lD?k`3o`0000;oC6G<00?o0000ofQkd_mXNm801ol00002oiJQg003o`000?nV/^7oY[;Q00?oY[;Q
0_l00003ol7?i@03o`000?o>f^;oc][R00;oc][R0ol000000ooMl=go0000onCde@06o`00000<oo7Y
`Ol0003olnNlo`000?oei;So0000ooKR]Ol0003om]jco`000?oefk;o00000_ocek800ol0003olM>b
oo7C/P02o`000005onc=]Ol0003oilNfonO7]_l000000_oR`KH00ol0003ogK^go`000002omJd^006
o`000?o?[[Socjjho`000?o6Y[Wo00000oo0WkP01?l0003o]iRhokNH^?ngV;P2o`0000CoZHbf00Go
0000oj25]onPQKOoX8Fgo`000003oiIo^006o`000?n;NK[oRgVjoh]i^_l0003oOW>m0ol00004ohN]
k`03o`000?nb/]So/[;H00?o/[;H00?o0000olF`a_l000000oo1/l`01Ol0003ocK6molfa_Oo=/Kgo
000000;oc;C200Co0000omBa]ooD/KOo00000_oD]KX00ol0003ofK:bo`000005omZf]@05o`000?oM
]k7ogKNaomfg/Ol000000ooP_;@01Ol0003oh[fcon:m/ooR_K?o000000?oi<>f00Go0000onC4^?oT
a;Soi<Bho`000003onO;^`05o`000?oRc<7oh/c1on;<`Ol000000_oTdlD2o`000004omWAdOl0003o
fMSFomWHeP?o00000oo4cn<00ol0003o`]7Vo`000004ojK0k0Co00000_nQ_>`00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo00oooooo0ol0000=
ooooo`03o`000?nW`>coYl3/00;oYl3/00Co0000ojO0k?l0003o00000_nW`>`01?l0003oYl3/ojO0
k?nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000
1?nW`>`00ol0003oYl3/ojO0k005o`000004o`0^/ol0003o53nloa@o_0;o00000om<IL`01?l0003o
J7_BofQkd_l00003oh6>e`03o`000?nFXMcoUZ7L00;oUZ7L00?o0000ojJbhOl000000_l00002okFn
h@03o`000?o1cnGo000000Coc][R00?o0000omWRg?oIh]`01Ol000002_oYjLko0000onkYaol0003o
lNW1o`000?ocikco0000ooGT^?l00002ooKR]@05o`000?ofg[?o0000ooGK/_l000000_ocek800ol0
003olM>bo`000002onk?/P04o`000?oWakKoilNfo`0000?oh/6f00Go0000omfk]ol0003oe[Bho`00
0004oln^^003o`000?o0WkSo`9nh00;o`9nh00Ko0000okNH^?ngV;So0000ok6B]_l00004ojV<]P05
o`000?nPQKOoX8Fgoj25]ol000001?nFOkP01_l0003oRgVjoh]i^_n;NK[o0000ogic_@?o00001?n7
[Nl00ol0003o/[;Hok:bf002ok:bf0;o00001?o1/l`01?l0003ocK6molfa_Ol00003olbd`P04o`00
0?oD/KOoe;6go`0000?oe;Fj00?o0000omZf]OoJ][D00ooJ][D01Ol0003og;^ho`000?oM]k7o0000
00Coh;bd00Go0000on:m/ooR_K?oh[fco`000003onC3]P04o`000?oTa;Soi<Bho`0000?oil^k00Go
0000onWD_ol0003oh/c1o`000002onCCa@04o`000?oUg<_oiMc;o`0000?ofMSF0_l000001?oGg]go
0000olC?hol00003ol;AiP06o`000?nV`>co0000o`000?n[`N[o00001OnQ_>`00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo000Yooooo`?o00003?ooool3o`00017ooooo00?o0000
ojO0k?nW`>`01?l00004ojO0k003o`000?nW`>co000000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3
o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00002
ojO0k004o`000?l7GMKo0000o`0^/`;o000000?o53nlo`000?leELD00_l000000om<ILco0000ofQk
dP02ofQkdP05o`000?n1S]OoPHkGoh6>eol000000onFXM`2o`0000Go]KkQ0ol00003olkJhP04o`00
0?oIh]cofN;Lo`0000?oh^OE00Oo0000onWYc_l0003ok^W7o`000?oajL7o000000;olnNl00Wo0000
ooGT^?l0003om^:eo`000?ofg[?o0000ooGK/_l000000_ocek801?l0003olM>boo7C/_l00002onk?
/P;o000000GoilNfo`000?oR`KKoh/6fo`000003omfk]`03o`000?o?[[Socjjh00?ocjjh00?o0000
ol2O^?o0WkP00oo0WkP2o`0000?o/I:f00Go0000ojV<]_nYS;KoZHbfo`000004oj25]`03o`000?nF
OkSo000000oo000000Ko/[;Ho`000?l0003o0000ojJch_l00004ol6cc003o`000?o=/Kgo000000Co
c;C200?o0000omBa]ol000001?oD]KX00ol0003of[JeomZf]@02omZf]@06o`000?oL^kSog;^ho`00
0?oM]k7o00000ooP_;@01Ol0003oh/:ho`000?oR_K?o000000?oi<>f00Go0000onO;^Ol0003oi<Bh
o`000003onO;^`04o`000?oYe;oojMBoo`0000;oi=?500Co0000onGLbooUg<_oiMc;0_l000001OoI
f=Ko0000omONgOl0003oemkM00;o00001?o2dNH2o`0000CoZl7Z00?o0000oj6lk?nQ_>`00ol0000?
ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo00Wooooo0ol0000Eoooo
o`;o00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Co0000ojO0k?l0003o00000_nW`>`0
1_l0003oYl3/ojO0k?nW`>co0000ojO0k0;o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o0000
0onW`>`02?l0003oYl3/ojO0k?nW`>co0000o`MMe_l0003o02jc0ol000000oleELGo0000oeM]cP02
o`0000?oJ7_B00Ko0000oh6>eon1S]OoPHkGo`000?nFXM`2o`0000;oYJgM00Go0000okFnhOne_^7o
]KkQo`000003ol?9g`03o`000?o>f^;o000000;ofN;L00Oo0000on;WeOoRimGoh^OEo`000?oYjLko
000000;ok^W700Oo0000oo7Y`Ol0003olnNlo`000?oei;So000000;om^:e00Go0000ooKN/ol0003o
mM^bo`000002oo?G/P03o`000?oadk;o000000;ok/nb00Co0000on_:/oo[b[?o00000_oR`KH00ol0
003ogK^gomfk]`02omfk]`03o`000?o?[[Socjjh00;ocjjh00?o0000olRW^?l000000oo0WkP2o`00
00Co/I:f00?o0000ojV<]_nYS;H00_nYS;H00ol0003oX8Fgo`000003o`0000;oUgje00Go0000ohmj
]on?N[OoSgZgo`000002ohIf^@Co00000_mSXo@2o`0000GoY[?R00Co0000ol6cc?o1/lco`K?<0_l0
0005olbd`P;o00001?oD]KX00ol0003oeKZoo`000002omZf]@03o`000?oL^kSog;^h00;og;^h00?o
0000on2l]?oP_;@00_oP_;@01Ol0003oh/:ho`000?oR_K?o000000?oi<>f00Co0000onO;^OoWbkWo
00000ooWbk/01ol0003ojMBoonWD_ooYe;oo0000onCCaOl000000ooUg</01?l0003oi>KConCVdol0
0003omONg@05o`000?o@i>Kod>CVo`000?o2dNH00_l00002ok_Bj`03o`000?n[`N[oZl7Z00Co0000
0onS^^T00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00000ol0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o
00006_ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00004ojO0k003
o`000?nW`>coYl3/00?o00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/2Ol00000
1OlI@Kco0000o`000?leELGo000000;oEfg>2Ol00005ojF]g@03o`000?ne_^7o000000Go`lWO0_l0
00000ooIh]co0000on;We@02on;We@03o`000?oYjLko000000;ok^W700?o0000oo7Y`Ol000000_oc
ik`01ol0003omNBho`000?ofh[Go0000ooKN/ol000000_oefk801_l0003olmNboo?G/_l0003olM>b
o`0000;ok/nb00?o0000on_:/oo[b[<00_l000000ooR`KKo0000omfk]`02omfk]`03o`000?oG]KOo
000000;ocjjh00Co0000olRW^?o8YkSo00000_o0WkP00ol0003o^YVgo`000004ok6B]P04o`000?nY
S;KoZHbfojV<]P?o00000_nOPk@01Ol0003oUgjeoiMn]OnGO[Go000000?oSgZg00Co0000ohIf^On6
M[WoQWJi1?l00002of>Sm003o`000?nV/n;oY[?R00?oY[?R00Ko0000ol6cc?o1/lco0000okbge?l0
0004olbd`P03o`000?o;^LSo000000?oe;Fj00Co0000omFj_ooE^[oo00000_oJ][D00ol0003og;^h
ombk^002ombk^005o`000?oP_;Coh;bdon2l]?l000000ooR`[P01Ol0003oi<>fonC3]_oT`kKo0000
00?oil^i00Co0000onO;^ooWbk_o00000ooYe;l00ol0003ojmk5o`000003onGLb`0;o`000?oTi]?o
i>KCo`000?oOkm_o0000omONgOl0003od>CVo`000?o@i>H00_l00004ok_Bj`?o00000onZ`>T00ol0
003oXk[Yoj>jj@03o`0000gooooo00?o0000ooooooooool01_ooool00003oooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`?o00007_ooool2
o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oS[Scohjh
l`05o`000007oaU1_?l0003o0000ocEEaOl0003oEfg>o`000003ogJ4e003o`000?n@V]WoT9[I00;o
T9[I00?o0000ojF]gOnU[Md00_nU[Md2o`0000Go`lWO00?o0000om3Bfoo@d]/00ol000001ooRimGo
0000onWYc_oYjLko0000onkYaol000000_oajL401Ol0003olnNlo`000?oei;So000000;om^:e00Go
0000ooKN/ol0003omM^bo`000002oo?G/P06o`000?oadk;olM>bo`000?o^ck;o00000_o[b[<01?l0
003oilJdonO6]?l00004omfk]`06o`000?oG]KOoekFgo`000?o?[[So00000_o8YkP00ol0003o`9nh
o`000003okZI]`03o`000?naT[Ko/I:f00;o/I:f0ol000000onVR;Co0000oin3]002oin3]003o`00
0?nGO[GoUgje00;oUgje00Go0000ohmj]on?N[OoSgZgo`000002ohIf^@03o`000?mlL[goO7:m00Go
00001?nV/n800ol0003o`K?<o`000003okbge004o`000?o<]<;oc;C2o`0000?obkW800Co0000omBe
^_oD]K[o00000_oE^[l00ol0003of[Jeo`000004ombk^005o`000?oM`Kgo0000on2l]?l000001?oR
`[P01?l0003oi<>fonC3]_l00003onO;^@05o`000?oZe;ko0000onO;^ol000000_oYe;l00ol0003o
jmk5on_Na@02o`000005onGLbol0003oi>KConCVdol000000_oOkm/2o`000007om3Ti_l0003o0000
o`000?o4j>oo0000ok_Bj`03o`000003ok7=kol0003oZ/3Y00?oZ/3Y0ol00003ojO0k003o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool000;ooooo00?o410@ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo0ol0000Rooooo`03o`000?nW`>coYl3/00;o
Yl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?n>^??oS[Sc00Co000000?o6D6lo`000?lo
G<P00_l00002oeM]cP05o`000?mfQ=CoMXCDogJ4e?l000001?n@V]T01?l0003oYJgMo`000?l00002
ok>hg005o`000?o3bMoo`lWOol?9gol000000oo@d]/00ol0003of]WFom[IeP02o`000007onWYc_l0
003ok^W7onkYaol0003olNW1o`000002oo?W_0So000000OomM^bo`000?ocek;olmNbo`000?oadk;o
000000;ok/nb00Co0000on_:/oo[b[?o00000_oWa[@2o`0000;ogK^g00?o0000omNe]ooG]KL00_oG
]KL00ol0003ob:NholRW^002olRW^003o`000?njVKOo^YVg00;o^YVg00Co0000ok6B]_naT[Ko/I:f
0_l00003ojJ8]003o`000?nOPkCoWh>d00;oWh>d00Go0000oiMn]OnGO[GoUgjeo`000003ohmj]`05
o`000?n6M[WoQWJiohIf^Ol000000_mlL[d2o`000003oc6>k_l0003o000000Go00001?nl]m@00ol0
003oc;C2o`000004ol^ib003o`000?oD]K[o000000CoeKZo00?o0000ombk^?oL^kP00ooL^kP01Ol0
003ogL6mo`000?oP_;Co000000?oh/:h00Go0000onG:_?l0003oi<>fo`000003onO;^@04o`000?oZ
e;koj]Bno`0000?ojMBo00?o0000on_NaOl000000_o[jL/2o`000006onCVdol0003ognoKomo_fol0
003odoOU0_l00002olCXk`04o`000?o4j>oo0000o`0000Go/Lg_1?l000000onW`>co0000ojO0k003
ojO0k0;o00002oooool00ol0003oooooooooo`06ooooo`000_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01?ooool4o`0002Kooooo00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o
00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Go000000Ko01ZVo`000?l0;;7o0000oaU1_?l00002ocmLb0Co00000omfQ=@0
0ol0003oT9[Ioi2Jf@03o`0000Go/kSL00?o0000ol?9gol000000oo@d]/01_l0003of]WFom[Ie_oJ
fMKo0000on?Mc`Wo000000Sol]jio`000?ocg;Kolmbfo`000?odf[?o0000ooCH/PGo000000ColM>b
o`000?o^ck;o00000_o[b[<01?l0003oilJdonO6]?l00002on?1]P03o`000?oM^kOo000000CoekFg
00?o0000olRW^?o8YkP00_o8YkP00ol0003o^YVgokZI]`02okZI]`06o`000?naT[Ko/I:fo`000?n]
SKGo00001?nVR;@01Ol0003oWh>doin3]?nOPkCo000000?oUgje00Go0000ohmj]on?N[OoSgZgo`00
0003ohIf^@04o`000?mlL[goO7:mogab_@Co00001?nD/n`00ol0003o_;ODokbge002okbge0;o0000
1_o;^LP00ol0003oeKZoomFj_`03omFj_`03o`000?oL^kSog;^h00;og;^h00Go0000omg1_OoM`Kgo
gL6mo`000004on;2^004o`000?oUb[coiLZlo`0000?oil^i00Co0000on[D__oZe;koj]Bn0_l00000
1?oYe;oo0000on_NaOl00003on_Yb`08o`000?oVm=;o0000o`000?oOkm_o0000om?giOl00002okci
k004o`000?o4j>oo0000o`0000;o/]of00?o0000ok7=konacNl00ol00005ojO0k0Co000000?oYl3/
o`000?ooool02_ooool00ol0003oooooooooo`06ooooo`000_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01?ooool2o`0002Wooooo0_l00003ojO0k004o`000?nW`>co0000o`0000;oYl3/
00?o0000ojO0k?nW`>`00_nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`00_nW`>`3o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?l0B/Wo000000;o01ZV1?l00002ocmLb003o`00
0?mTMm3oI7O@00Oo00000_nOYMX00ol0003o/kSLok>hg003ok>hg0;o00000oo@d]/01Ol0003of]WF
om[Ie_oJfMKo000000;ohmg?00Ko0000onWObOoYglWo0000ongO`ol00002oo3O_P;o00000_ocg;H0
0ol0003om=Zco`000002ooCH/P05o`000?oce[7olmJao`000?obdk400_l000001Oo^ck;o0000on_:
/oo[b[?o000000;oilJd00Go0000on?1]_oS`KKohl6fo`000004omNe]`03o`000?o@[kSo000000;o
b:Nh00?o0000ol:Q]ol000001?njVKL2o`0000;o[Hfe00?o0000ojJ8]?nVR;@00_nVR;@01Ol0003o
Wh>doin3]?nOPkCo000000?oUgje00?o0000ohmj]on?N[L00_n?N[L01?l0003oQWJiohIf^Ol00003
ogab_@03o`000?m`Kl;o000000;o00001?nD/n`01_l0003o_;ODo`000?l0003o];[No`0000GobkW8
0_l00004omFj_`03o`000?oF`<Go000000;og;^h00?o0000omg1_OoM`Kd00_oM`Kd01Ol0003oh/:h
on;2^?oR`[So000000?oiLZl00Co0000onO;^OoWbkWo00000ooZe;h01?l0003ok=k4oncNa?l00002
on_Na@07o`000?o[jL_ojnW;o`000?oVm=;o0000omWmf002o`000003om?giOl0003o_?W/00;o_?W/
0ol000000onbgoKo0000o`000003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k003o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000;ooooo00?o410@ooooooooool02Ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool00ol0003oYl3/ojO0k003o`0000Co
Yl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co0000o`000?nW`>co0000
1?nW`>`3o`0000CoYl3/00Wo0000ojO0k?nW`>co0000o`1:bOl0003o01ZVo`000?l0;;400_l00003
ocmLb004o`000?mTMm3oI7O@o`0000?oQHoF00?o0000oinUf_nOYMX00_nOYMX00ol0003o/kSLo`00
0002o`0000;o`/;J00?o0000om3Bfol000000ooJfMH01?l0003ohmg?on?Mcol00002onWOb@03o`00
0?o]gl?o000000;ol=nn00?o0000oo;N^Ol000000_ocg;H01Ol0003om=Zco`000?odf;;o000000;o
lmJa00Ko0000oo;C/Oobdk7o0000oo3@/Ol00002on_:/`05o`000?oWa[CoilJdonO6]?l000000ooS
`KH01Ol0003oekFgomNe]ooG]KOo000000;od:nh00?o0000olRW^?l000000_o2XKL00ol0003o^YVg
okZI]`02okZI]`03o`000?n]SKGo[Hfe00;o[Hfe00Go0000ojJ8]?nVR;CoYXRdo`000004oin3]006
o`000?nGO[GoUgjeoiMn]Ol0003oSgZg1Ol000001On6M[Wo0000ogab_OmlL[go000000;oL6o22?l0
0004okBjgP05o`000?o;^LSobkW8ol^ib?l000000_o8_]001?l0003oeKZoomFj_ol00003omK0a@03
o`000?oL^kSo000000?ogL6m00Go0000omo9`_l0003oh/:ho`000003onG:_005o`000?oXdl7o0000
onO;^Ol000000_oZe;h01ol0003ok=k4oncNa?o/g/Co0000on_NaOl000000_o[jL/01_l0003oi_CB
o`000?oIoMSo0000okknf0?o000000Co_?W/o`000?l0003oZNkh1?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000_ooooo00?o0000ooooooooool01Oooool0
0003oooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo0_l0
0003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co
0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k002ojO0k0Ko00000_l06ZH2o`000005ob16
__l0003o0000ocmLb?l000000omTMm001Ol0003oQHoFohF?e_n5SmKo000000?oWjGJ0_l00005ol;2
fPCo000000Gof]WFo`000?oSgLoohmg?o`000002onWOb@04o`000?o]gl?okMo3o`0000;ol=nn0_l0
0002oo?L]P03o`000?odf[?o000000;om=Rb00Ko0000oo?F/Ooce[7o0000oo;C/Ol00002oo3@/@;o
000000GojlZco`000?oWa[CoilJdo`000003on?1]P03o`000?oM_;Oo000000;oekFg00Ko0000om2_
^?o@[kSo0000olRW^?l00003ol:Q]`03o`000?njVKOo^YVg00;o00001?n]SKD01Ol0003oYXRdojJ8
]?nVR;Co000000?oWh>d1ol00002oi=k]@03o`000?n>NKOoSWVg00Oo000000CoL6o2o`000?l0003o
00000omh[_@00ol0003o];[NokBjgP03okBjgP03o`000?o;^LSo000000?ob;k@00?o0000omFj_ol0
00001OoF`<D01Ol0003ogL6momg1_OoM`Kgo000000;oglW200?o0000on;2^?l000000ooUb[`01?l0
003oj=?1onSC`Ol00003on[D_P05o`000?o/g/Cok=k4o`000?o/jlX00_l000002Oo[jL_o0000onKd
d_l0003ofOgHo`000?nno]So0000oi?`c`06o`0000;oYl3/00Co0000ojO0k?l0003oYl3/1?l00003
ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00000ol0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oEEEEofIVI_l000002_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000CoYl3/00?o
0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00000_nA^_801?l0003o
04[9o`000?l06ZH2o`000003ob16__l0003oBfC;00;o00000omTMm001_l0003oQHoFohF?e_n5SmKo
0000oinUfP;o00000_n^/=T01Ol0003o`/;Jol;2f_o2`][o000000Coc/[F0_l000000ooSgLoo0000
onWOb@02onWOb@03o`000?o]gl?o000000;ol=nn00?o0000oo;N^Ol000000_ocg;H01Ol0003om=Zc
o`000?odf;;o000000;olmJa00Ko0000oo;C/Oobdk7o0000oo3@/Ol00002onk>/P;o00000_oWa[@0
2Ol0003ohl6fon?1]_oS`KKo0000omfl]ol0003oekFgo`000004om2_^003o`000?o2XKOo`Z6g00;o
`Z6g00Go0000okZI]ol0003o]9Bfo`000004ojf=]@03o`000?nVR;CoYXRd00;oYXRd0ol000000onN
PK?o0000oiUm/`02oiUm/`05o`000?nCNkGoTg^eoi=k]Ol000000on>NKL01_l0003oQgNkohMg^on7
Mk_o0000oh1g_`Go00000omh[_@01?l0003o];[NokBjg_nd^]h3o`0000Cob;k@0_l00005omK0a@;o
00000ooM`Kd01Ol0003oglW2omo9`_oObL;o000000?oiLZl00Co0000onSC`OoXdl7oj=?10_l00000
1OoZe;ko0000oncNa?o/g/Co000000;ok>_:00?o0000onOgcol000000_l000000ooIoMSo0000okkn
f005o`000003ojO0k?l0003oYl3/00?oYl3/1?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co0000
0_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Wooooo00?o0000ooooooooool01Oooool002gooooo
0_l0000Yooooo`;o00001?nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003oTK[boi6jlP04o`000004o`0]
/_l0003o0000o`0000;oBfC;1?l00002ohF?eP?o00001On^/=T00ol0003o`/;Jo`000004olk:eP03
o`000?oHd=7of=3A00?o000000CojMo9o`000?o]gl?o00000_o`gkh01?l0003ol]jioo;N^Ol00002
oo?L]P05o`000?odf[?o0000ooCH/_l000000_oce[400ol0003ol]>ao`000002oo3@/@08o`000?o^
c[;ok/jbo`000?o[bkCo0000onO6]?l00002on?1]P05o`000?oM_;OogKbgomfl]ol000001Oo@[kP0
0ol0003o`Z6gol:Q]`03ol:Q]`05o`000?ndU;Ko]9BfokBD]_l000001?n]SKD00ol0003oYXRdo`00
0002o`0000?oWX6c00Go0000oiUm/onIOK?oVGfco`000004oi=k]@04o`000?n>NKOoSWVgo`0000?o
QgNk00Co0000oh1g_on0MkooP7No2_l00002ojRnj@07o`000?o8_]3ob;k@olRnd?l0003oaLGJo`00
0004omK0a@06o`000?oFb<goe/S=o`000?oM`Kgo00001?oObL801?l0003oiLZlonG:_?l00003onSC
`@04o`000?oZglSoj]o8o`0000?ok=k400Ko0000onc[b_l0003oioO?o`000?oHom08o`0000CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00002ojO0k003o`000?nW`>co000000?o00000_nW`>`01?l0
003oYl3/ojO0k?nW`>`4o`0000;oYl3/00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`00;oooool00ol0003oooooooooo`0Wooooo`03o`000?nW`>coYl3/00;oYl3/0ol00003ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l000000onA^_;o0000o`000003o`000005obY=`_l0003o0000od]Tbol000000_mcP]<3
o`0000;oU9_G00?o0000ojj`fOn^/=T00on^/=T2o`0000Coc/[F00Go0000omS@dOoHd=7of=3Ao`00
0002on3Dc0;o000000OokMo3o`000?o`gkkol=nno`000?obg[Wo000000;olmbf00?o0000ooCJ/ol0
00000_odf;802?l0003olmJaoo?F/Ol0003ol]>ao`000?o`d;7o00000_o^c[801Ol0003ojl^don_;
]?o[bkCo000000;ohl6f00?o0000omfl]ooM_;L00_oM_;L00ol0003od:nhom2_^002om2_^003o`00
0?o:ZKWo000000?o`Z6g0_l00003okBD]P04o`000?n]SKGo[Hfeojf=]@?o00000_nSQK<00ol0003o
WX6coij1/`02oij1/`05o`000?nIOK?oVGfcoiUm/ol000000onCNkD01Ol0003oSWVgohii]on>NKOo
000000?oQgNk00Co0000oh1g_on0Mkoo00000_mgN<L2o`0000;oDJ;f00?o0000ojRnjOnX_^T00onX
_^T00ol0003ob;k@o`000003olG5fP04o`000?oF`<Goe/35o`0000?oe/S=0_l00004omo9`P05o`00
0?oQdlWo0000onG:_?l000000_oXdl401?l0003oj]o8on[Ob?oZglP2o`000007oncNa?l0003ok>_:
o`000?oWmloo0000omSod006o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW
`>co0000o`000?nW`>co00001OnW`>`3o`000003ojO0k?l0003oYl3/00?oYl3/0_l00008ooooo`03
o`000?oooooooooo00Gooooo000`ooooo`03o`000?oooooooooo02Oooooo00Ko0000ojO0k?l0003o
0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00004ojO0k0?o000000Ko01JTo`000?l0;K;o0000obY=`_l00002od]Tb`04o`000?mc
P]?oLh;Co`0000CoU9_G00Oo0000ojj`fOn^/=Wo[[3Io`000?nl^MOo000000?oc/[F00Go0000omS@
dOoHd=7of=3Ao`000003on3Dc003o`000?oVelKo000000Co000000Wol]jio`000?ocg;Kolmbfo`00
0?odf[?o0000ooCH/_l000000_oce[401_l0003ol]>aoo;C/Ol0003ol=2ao`0000;ok/jb00Co0000
on_;]?o[bkCojl^d0_l000000ooS`KKo0000omfl]`02omfl]`03o`000?oH^;Wo000000;od:nh00Co
0000olZY^Oo:ZKWo00000_o2XKL00ol0003o^i^ho`000003okBD]P06o`000?n]SKGo[Hfeo`000?nY
RKCo00000onSQK<00ol0003oWX6coij1/`02oij1/`05o`000?nIOK?oVGfcoiUm/ol000000onCNkD0
1Ol0003oSWVgohii]on>NKOo000000?oQgNk00Go0000oh1g_on0MkooP7Noo`000002ogMha`Go0000
0onX_^T3o`0000CoaLGJ00?o0000omK0aOl000000ooFb<d00ol0003oeM;Fo`000003omo9`P05o`00
0?oQdlWohM?9on7CbOl000000ooXdl401Ol0003oj]o8on[Ob?l0003ojNc?00;o000000Gok>_:o`00
0?oWmloo0000omSod003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00?o000000GoYl3/o`000?nW`>coYl3/o`000002ojO0k0?o00001?nW`>`01_l0003oYl3/o`00
0?l0003oYl3/o`0000Sooooo00?o0000ooooooooool01Oooool0037ooooo00?o0000ooooooooool0
9oooool2o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`00
00CoYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00So00000_lZCL82o`00
0005od]Tbol0003oLh;Cog>2dol000001?nDVmL00ol0003o[[3Io`000003okbie`03o`000?o>b]Ko
000000?of=3A00Go0000on3Dc?oPe<coh=C<o`000002onKGaP05o`000?oZf<7oj]S1o`000?o^f;d0
1ol000001oodf;;o0000oo?F/Ooce[7o0000oo;C/Ol000000_o`d;400ol0003ok/jbo`000003on_;
]004o`000?oXb;Koj<Rfo`0000?ogKbg00Ko0000omRh^OoH^;Wo0000om2_^?l00003olZY^@03o`00
0?o2XKOo000000?o^i^h00Co0000okBD]_ndU;Ko]9Bf0_l00002ojV9]003o`000?nSQK?oXhFc00;o
XhFc00Go0000oij1/onNPK?oWX6co`000003oiUm/`05o`000?nCNkGoTg^eoi=k]Ol000000on>NKL0
1Ol0003oQgNkohMg^on7Mk_o000000?oP7No00Co0000ogMhaomgN<OoMgS70_l000000olNRn_o0000
o`000002o`0000;oU/7e00?o0000olG5f_o5aMX00_o5aMX2o`0000?oe/S=00Oo0000omGBe_oEd]Ko
eM;Fo`000?oObL;o000000?ohM?900Go0000on;Od_l0003oj=?1o`000002on[Ob003o`000?oYk<oo
000000;ohoWC1ol00003ojO0k0Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000?oYl3/00?o
0000ojO0k?l000001?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo000booooo`;o0000:Oooool00ol0003oYl3/ojO0k003
o`0000CoYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k002ojO0k0?o00000_nW`>`0
0ol0003oYl3/ojO0k002ojO0k0?o00000_nQ_nh3o`000007o`0FY?l0003o0000o`000?lZCL;o0000
oeU_cP02o`0000?oLh;C00?o0000oiBKeonDVmL00ol00004okbie`?o00000ooHd=401?l0003oh=C<
on3Dc?l00002onKGaP04o`000?oZf<7oj]S1o`0000;ok]Rm00Oo0000oo3H^Oo`f;Wo0000oo7G]_l0
003ol]Jd00Go000000Col]>ao`000?o`d;7o00000_o^c[801Ol0003ojl^don_;]?o[bkCo000000;o
j<Rf00Go0000omfl]ooM_;OogKbgo`000003omRh^@03o`000?o:ZKWobZVi00?obZVi00?o0000ok^K
^?nkVkP00_nkVkP01Ol0003o]9BfokBD]_ndU;Ko000000CoZHVd00Go0000oj>5/onSQK?oXhFco`00
0003oij1/`03o`000?nIOK?oVGfc00;oVGfc00Go0000oi=k]OnCNkGoTg^eo`000003ohii]`05o`00
0?n7Mk_oQgNkohMg^ol000000_n0Mkl01_l0003oMgS7ogMhaomgN<Oo0000of]jd0Co00001?nF`OD0
1?l0003oaLGJo`000?l00002oko>iP03o`000?oFb<go000000CoeM;F0_l00003on7Cb@04o`000?oR
gm;oh]oBon;OdP;o000000Coj]o8o`000?oYk<oo00000_oSnM<00ol0003odOoAo`000002o`0000;o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001oooool00ol0
003oooooooooo`04ooooo`00=?ooool00ol0003oooooooooo`0Wooooo`;o00000onW`>`00ol0003o
Yl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co
0000o`000?nW`>co00001?nQ_nh4o`000005o`8a]?l0003o:Tg2obY=`_l000000_mIKlh6o`0000;o
XjGG00Go0000okbieonl^MOo_;WGo`000003olS1e003o`000?oHd=7o000000;oh=C<00Oo0000onKG
a_oVelKoi]O6o`000?oZf<7o000000;ok]Rm00Ko0000oo3H^Oo`f;Wo0000oo7G]_l00002oo;F]005
o`000?obeK?ol]Fco`000?obe;800_l000001?o`d;7o0000onk>/_l00003on_;]008o`000?oXb;Ko
j<Rfo`000?oTaKSo0000omfl]ol00004omRh^@03o`000?o:ZKWobZVi00?obZVi00?o0000ok^K^?nk
VkP00_nkVkP00ol0003o]9BfokBD]P02o`0000CoZHVd00Go0000oj>5/onSQK?oXhFco`000004oij1
/`03o`000?nIOK?o0000023o00001?noc^H2o`0000CoeM;F00Ko0000om?NhOoCg^7o0000on7CbOl0
0003on;OdP06o`000?oPk][o0000o`000?oYk<oo00000_oSnM<00ol0003odOoAo`000002o`000005
ojO0k?l0003o0000ojO0k?l000001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01Ol00002ojO0
k004o`000?nW`>co0000ojO0k0Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000?oYl3/00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`00=Oooool00ol0003oooooooooo`0W
ooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k004o`000?nQ_nkoXKo^oj6okPCo00000_l2<K@3o`0000;oFFo>00Go
0000oh>=eOn3SMGoPhgEo`000004oj>Ue`03o`000?nl^MOo000000Gob<7D0_l000000ooPe<co0000
onKGaP02onKGaP04o`000?oZf<7oj]S1o`0000;ok]Rm00?o0000oo3H^Ol000000_oaekH00ol0003o
l]Jdo`000002oo;E/`05o`000?obe;;ol]Bbo`000?oadk800_l000000oo^c[;o0000on_;]002on_;
]004o`000?oXb;Koj<Rfo`0000;oi<Fh00?o0000omRh^OoH^;T00_oH^;T00ol0003od[>ko`000003
olZY^@03o`000?o3Y;[o000000Co^i^h0_l00002ojj?]P05o`000?nYRKCoZHVdojV9]?l000000onS
QK<01?l0003oWX6coij1/onNPK<3o`0000;oVWfb00Go0000oiMl/onGO;?oUgbco`000003oiAk]P05
o`000?nAO;WoTGbioi5l^Ol000000on=O[d01Ol0003oRH74ohV1a?n9PLCo000000;oQ8O>1?l00004
ogZoo@06o`000?noc^Ko0000o`000?ndeo;o00000ooEd]H01?l0003odmkQom?NhOoCg^42o`0000?o
h]oB00?o0000on3^f_l000000_oGn]l2o`000005on?idol0003odOoAo`000?nW`>`00ol00004ojO0
k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01Ol0
0002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`0000Gooooo
00?o0000ooooooooool01?ooool003Kooooo00?o0000ooooooooool09oooool2o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00001?nW`>`00ol0003oYl3/ojO0
k007o`000006o`0FXol0003o0S6do`000?lfE/Ko00000omIKlh01Ol0003oPhgEoh>=eOn3SMGo0000
00?oXjGG0_l00005olS1e003o`000?oBam3od/O@00;o00000_oVelH01?l0003oj]S1on[H`Ol00002
onkH_@06o`000?o`f;Wol=Rio`000?oaekKo00000_obe[@01_l0003ol]Fcoo;E/ol0003ol]Bbo`00
00;olM>b00Co0000oo3A/ol0003o00000_o[bk@01?l0003oj<RfonS8]_l00003onC5^005o`000?oH
^;Wof;RiomRh^Ol000000_oB/k/01?l0003obZViolZY^Ol00002ol>T^P04o`000?nkVkSo^i^hok^K
^0;o00000on^SkH01Ol0003oZHVdojV9]?nYRKCo000000CoXhFc0ol000000onMOk;o0000oiYm/P02
oiYm/P05o`000?nGO;?oUgbcoiMl/ol000000onDNkH00ol0003oTGbioi5l^@02oi5l^@05o`000?n=
O[goSGjmohen_Ol000000on9PL@01?l0003oQ8O>ohB7c_l00002ogf@f`Ko00001?ndeo800ol0003o
eM;Fo`000003om?Nh@08o`000?o<k>_oc>c[o`000?oRgm;o0000on3^f_l00002omOjg`03o`000?o0
o]_o000000Go00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00004ojO0k0?o00000_nW`>`01Ol0003oYl3/ojO0k?l0003oYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k005o`0000;oYl3/00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`00=oooool2o`0002Wooooo00?o0000ojO0k?nW`>`00ol00004ojO0k003o`000?nW`>coYl3/00?o
00001?nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/1ol000000ol2<KCo0000ocIFaP02o`000003
oeU_c_l0003oPhgE00;oPhgE00Co0000oj>Ueol0003o00000_nb/=H01Ol0003ob<7DolS1e?o8`MCo
000000?od/O@00Go0000om_<bol0003oi]O6o`000002on[H`@06o`000?o^f;gok]Rmo`000?o`f;Wo
00000_oaekH00ol0003ol]Jdo`000002oo;E/`06o`000?obe;;ol]Bbo`000?oadk;o00000_o`dK<0
1Ol0003ok]2do`000?o[bkCo000000;oj<Rf00Ko0000onC5^?oTaKSo0000omo1^ol00002omRh^@06
o`000?oB/k_od[>ko`000?o:ZKWo00000oo3Y;X01_l0003o^i^hok^K^?l0003o]9Jho`0000Co[Xnf
00Ko0000ojV9]?nYRKCoZHVdo`000?nSQK<3o`0000?oWGnb00?o0000oiYm/_nJOK800_nJOK801Ol0
003oUgbcoiMl/onGO;?o000000?oU7^f00Go0000oi5l^OnAO;WoTGbio`000003ohen_@05o`000?n9
PLCoRH74ohV1a?l000000on4Qlh01?l0003oOI3Kogf@fol00004oe6enP03o`000?ndeo;o]=Ob00?o
00000ooCg^401?l0003oc>c[olc/joo<k>/2o`000006on3^f_l0003oeo[OomOjgol0003o`?kK0ol0
0003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko
0000ojO0k?l0003o0000ojO0k?l00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ooooo`03o`000?oooooooooo00Cooooo000ioooo
o`03o`000?oooooooooo02Oooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0
003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01_l000001ol05Z?o0000o`000?l0003o
=UK6o`000?mYNm800_l00002oh>=e@?o00001Onb/=H00ol0003ob<7Do`000003om;7d004o`000?oK
c<_oflc;om_<b`;o000000Goj]S1o`000?o^f;gok]Rmo`000002oo3H^@08o`000?oaekKolMNfo`00
0?obe[Co0000oo;E/ol00002oo;D/P06o`000?oadk;olM>bo`000?o`dK?o00000oo^d;@01?l0003o
j<RfonS8]_l00003onC5^005o`000?oO`K_o0000omRh^Ol000001?oB/k/00ol0003o`jBjol>T^P03
ol>T^P;o00000ondU[P01Ol0003o[Xnfojj?]_n^SkKo000000;oZHVd0ol00002oj62/P03o`000?nM
Ok;oWGnb00;oWGnb00Go0000oiYm/_nJOK;oVWfbo`000003oiMl/`05o`000?nDNkKoU7^foiAk]_l0
00000onAO;T01Ol0003oSGjmohen_On=O[go000000?oRH7400Go0000ohB7c_n4QlkoQ8O>o`000002
ogf@f`So00000onQg_`00ol0003odmkQo`000002olc/j`;o000000Oo^oGao`000?l0003o0000omOj
gol0003o`?kK00;o000000CoYl3/o`000?nW`>coYl3/1?l00003ojO0k003o`000?nW`>coYl3/00Co
00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000ojO0k?nW`>`00ol000001_nW`>co
0000ojO0k?nW`>co0000ojO0k0;o000000?oYl3/o`000?nW`>`00onW`>`3o`0000?oYl3/00Go0000
ooooooooooooooooo`000006ooooo`00>_ooool00ol0003oooooooooo`0Vooooo`03o`000?nW`>co
Yl3/00;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000;oYl3/00?o0000o`E_gOl000000ol000001Ol:>;So0000ocIFa_lfE/Ko000000;oJG_B0_l0
0002oi>IeP03o`000?nb/=Ko/[3F00?o/[3F0_l00003om;7d003o`000?oKc<_oflc;00;oflc;00?o
0000on7@a_l000000_l000001?o^f;go0000oo3H^Ol00002oo7G]P06o`000?obe[Col]Jdo`000?ob
eK?o00000_obe;800ol0003olM>bo`000002oo3A/`04o`000?o^d;Cok]2donk@]0;o000000Goj<Rf
o`000?oTaKSoi<Fho`000003omo1^`03o`000?oB/k_od[>k00;od[>k0_l00004ol>T^P;o00001?nd
U[P02Ol0003o[Xnfojj?]_n^SkKo0000ojV9]?l0003oYHJdo`000003oj62/P03o`000?nMOk;oWGnb
00;oWGnb00Go0000oiYm/_nJOK;oVWfbo`000003oiMl/`05o`000?nDNkKoU7^foiAk]_l000001?nA
O;T01_l0003oSGjmohen_On=O[go0000ohV1a0So00000_nFXM`6o`0000;oXMkl1?l000000oo<k>_o
0000ok_el@02o`000003oi[cj?l0003o000000?o00000_nW`>`4o`0000;oYl3/00Co0000ojO0k?nW
`>coYl3/1?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?l000000ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co0000
1?nW`>`2o`0000?ooooo00?o0000ooooooooool00oooool003_ooooo00?o0000ooooooooool09_oo
ool01?l0003oYl3/o`000?l00002ojO0k004o`000?nW`>coYl3/ojO0k0?o00001?nW`>`00ol0003o
Yl3/ojO0k003o`0000?oYl3/00Co0000ojO0k?nW`>coYl3/1_l000001ol:>;So0000o`000?lfE/Ko
0000ofUkd_l000001?nCVMH01Ol0003o/[3Fok:`e_nb/=Ko000000;o_kSD00?o0000om;7d?l00000
1?oKc</01?l0003ohM36on7@a_l00002onKB`PGo000000KolMNfo`000?obe[Co0000oo;E/ol00003
oo;D/P05o`000?oadk;o0000oo3A/ol000000oo^d;@01?l0003ok<ngonc?]ol00002onC5^003o`00
0?oO`K_ogl6k00;ogl6k00Go0000om:c^ooB/k_od[>ko`000002ol^^_@06o`000?o3Y;[o`jBjo`00
0?nkWkco00001?ndU[P01?l0003o[Xnfojj?]_n^SkH2o`0000;oYHJd00?o0000oj62/_nQP[800_nQ
P[801Ol0003oWGnboieo/_nMOk;o000000?oVWfb00?o0000oiMl/onGO;<00_nGO;<01_l0003oU7^f
oiAk]_nDNkKo0000oi5l^@So00000_nHSlP01Ol0003oUiKAoiNFdOnGU]7o000000CoUZ7L00?o0000
oi:_j_nB[nX04?l000000onW`>co0000o`000002o`0000;oYl3/00Co0000ojO0k?nW`>coYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000;oYl3/
00Co0000ojO0k?nW`>coYl3/1Ol000000onW`>co0000ojO0k002ojO0k0?o00001?nW`>`4o`000003
ojO0k?l0003ooooo00;ooooo00?o0000ooooooooool00oooool003cooooo0_l0000Wooooo`;o0000
1?nW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/0ol00003ojO0k003o`00
0?nW`>coYl3/00So000000Go01RUo`000?l:>;So0000odARb`02o`0000;oJG_B00?o0000oi>Ie_nC
VMH00_nCVMH00ol0003o/[3Fo`000004oknhe0;o00000ooKc</01?l0003ohM36on7@a_l00003onKB
`P03o`000?oZdkko000000;okMBk0_l000001?obe[Co0000oo;E/ol00002oo;D/P06o`000?oadk;o
lM>bo`000?o`dK?o00000oo^d;@00ol0003ok<ngonc?]`02o`000003onC5^?l0003ogl6k00;ogl6k
00Go0000omVn__l0003od[>ko`000003ol^^_@03o`000?o3Y;[o000000?o^inl00?o0000okBF^?nd
U[P00_ndU[P3o`000003ojV;]_l0003oYHJd00;oYHJd00Go0000oj62/_nQP[;oXH:bo`000003oieo
/P03o`000?nJOK;oVWfb00;oVWfb00?o0000oiMl/ol000001ol00002oiZ7_P05o`000?nIR/;oVH[2
oiV:`_l000001?nHSlP01Ol0003oUiKAoiNFdOnGU]7o000000;oUZ7L1?l00003ojO0k003o`000?nW
`>co000000Co00000onW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000GoYl3/0ol000000onW`>co
0000ojO0k003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW
`>`01Ol00002ojO0k003o`000?nW`>co000000Go00000_nW`>`00ol0003oYl3/ojO0k003o`0000Go
Yl3/00Co0000oooooooooooo00001Oooool003kooooo00?o0000ooooooooool09_ooool00ol0003o
Yl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`6
o`000004o`0HYOl0003o2SRho`0000;oA6;;1?l00002oi>IeP?o00001?no^=@01_l0003ob/3Aol[0
dOl0003oflc;o`0000;ohM3600Oo0000onKB`_oVd/;oi];2o`000?oZdkko000000?okMBk00?o0000
onoE^?l000001?l000001?obe;;o0000oo7C/_l00002oo3A/`04o`000?o^d;Cok]2do`0000;ok<ng
00Co0000onW=^_oYcK[o00000ooO`K/01Ol0003ofKjnomVn__oI_[ko000000Gobjjm00?o0000ok^O
_?nkWk`00_nkWk`01?l0003o]9JhokBF^?ndU[P2o`0000?oZH^f00Go0000ojF6]?nUQ[CoYHJdo`00
0003oj62/P03o`000?nMOk;oWGnb00;oWGnb00?o0000oiYm/_l000000ol00002oib4^@05o`000?nK
QK_oVhFkoi^5^ol000001?nJQkh01Ol0003oVH[2oiV:`_nIR/;o000000?oV8o800?o0000oiNFdOnG
U]401?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00002ooooo`03o`000?oooooo
oooo00?ooooo000oooooo`03o`000?oooooooooo02Kooooo0_l00003ojO0k003o`000?nW`>coYl3/
00?o00001?nW`>`01_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/1_l000001?l06:Go0000o`00
0?l00002odARb`03o`000?miQmGoNHOE00?o00000_nRY=H01Ol0003o_kSDoknhe?no^=Co000000Co
b/3A00Go0000on7@a_oQd<KohM36o`000003onKB`P03o`000?oZdkko000000;okMBk00Ko0000onoE
^?o_eKSo0000oo3E]ol00002oo3F]P;o000000ColM>bo`000?o`dK?o00000oo^d;@01?l0003ok<ng
onc?]ol00002onW=^P;o000000?ogl6ko`000?oI_[h00ooI_[h00ol0003objjmol^^_@02ol^^_@;o
00001?nkWk`01_l0003o]9JhokBF^?l0003o[Y6io`0000CoZH^f00Co0000ojF6]?nUQ[Co00000onQ
P[801?l0003oWGnboieo/_nMOk83o`0000;oWHBh00Go0000oib4^OnLQ;WoW8Bio`000004oi^5^`05
o`000?nJQkkoVXNnoiZ7__l000000onIR/800ol0003oV8o8oiR?b004o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW
`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co000000Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ooooool000001Oooool0043ooooo00?o0000
ooooooooool09_ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004
ojO0k005o`000?nW`>co0000o`000?nW`>`01_l000000ol06:Go0000o`000003odARb`04o`000?mi
QmGoNHOEo`0000CoXZCF00?o0000oknhe?l000001Oo:`=42o`000003on7@a_l0003oi];200;oi];2
00?o0000on[C__l000000oo]e;/01Ol0003okmFho`000?o`eKOo000000?ol=Jf00Ko0000oo7F]Ol0
003o0000oo3A/ol00002onk@]004o`000?o/ckOok<ngo`0000;ojLfj00Co0000onG<_OoUc;go0000
1?oI_[h00ol0003odk[2o`000002ol^^_@04o`000?o3ZL3o`jW0o`0000Co^inl0_l00002ojjA^@03
o`000?nYRkKoZH^f00;oZH^f00Co0000ojF6]?nUQ[Co00001?nQP[83o`000003oin5^?l0003oWHBh
00;oWHBh00?o0000oib4^OnLQ;T00_nLQ;T01Ol0003oVhFkoi^5^onKQK_o000000?oVXNn00Co0000
oiV:`_nIR/;oVH[20ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o
00000onW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00001Oooool0047ooooo0_l0000Wooooo`;o00001?nW`>`00ol0003oYl3/
ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k0Oo000000Go546no`000?l0003o
A6;;o`000003ogV7e@04o`000?nRY=KoXZCFoj:TeP;o00001Oo:`=400ol0003odlK=om?6c@02o`00
00;oi];200Co0000on[C__oZdkko00000_o]e;/01_l0003okmFhonoE^?l0003ol=Fgo`0000;ol=Jf
00Go0000oo7F]Ooae[Go0000oo7F]P03o`000004onk@]?l0003ok<ngo`0000;ojLfj00Go0000onG<
_OoUc;goiLbmo`000003omVn_P06o`000?oC^/;odk[2o`000?o;[[go00000oo3ZL001?l0003o^inl
ok^O_?nkWk`2o`0000Co[Y6i00Go0000ojV;]_nYRkKoZH^fo`000003ojF6]003o`000?nQP[;o0000
00;o00000onOQKP00ol0003oWHBhoif4^002oif4^005o`000?nLQ;WoW8Bioib4^Ol000000onKQK/0
0ol0003oVXNnoiZ7_P02oiZ7_P?o000000?oYl3/o`000?nW`>`00onW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`0
1_l0003oYl3/o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k004o`000?nW`>co0000ojO0k0Co
00000_nW`>`01?l0003oYl3/ojO0k?nW`>`4o`0000;oYl3/0_l00005ooooo`00@oooool00ol0003o
ooooooooo`0Vooooo`03o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000Co
Yl3/00?o0000ojO0k?nW`>`00ol000001ol008;o0000o`000?l0003o546no`000?mCK]000_l00003
ogV7e@04o`000?nRY=Ko0000o`0000;o/:kF00Go0000ol[0dOo:`=7ob/3Ao`000003om?6c@07o`00
0?oKb/Wo0000onKB`_l0003oj]>no`000003ongD^`05o`000?o_eKSo0000oo3E]ol000000oo`e[H0
0ol0003olMJeo`000002oo7F]P03o`000?o`e[Ool=Jg00;o000000Gok<ngo`000?oYcK[ojLfjo`00
0002onG<_@05o`000?oQb/;o0000omVn__l000001?oC^/800ol0003o`jW0ol>Y`002ol>Y`006o`00
0?nkWkco0000o`000?ncVKgo00001?n^TKT00ol0003oZH^fojV;]P02ojV;]P03o`000?nUQ[Co0000
00;o00000_nQQkT00ol0003oWhFhoin5^002oin5^005o`000?nMQ;SoWHBhoif4^?l000000onLQ;T0
0ol0003oVhFkoi^5^`02oi^5^`03o`000?nJQkko000000;o00001?nW`>`01_l0003oYl3/o`000?l0
003oYl3/o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000
0onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/1?l000000onW`>co0000ojO0k002ojO0k0Co0000
0_nW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00004ooooo`00A?oo
ool00ol0003oooooooooo`0Vooooo`;o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l000001onA^_;o0000o`000?l0003o0022o`000?l07:P00ol00002oe=^d0Go
00001On`[]H00ol0003ob/3Ao`000003om?6c@04o`000?oKb/Wofl[9om_:b@;o000000Goj]>no`00
0?o]e;_okMBko`000002onoE^003o`000?o`eKOo000000;ol=Jf00Ko0000oo7F]Ooae[Go0000oo7F
]_l00003oo3F]`06o`000?o_e[Wo0000o`000?oYcK[o00000_oUc;d01Ol0003ohL[2on7:`_oQb/;o
000000Codk[20_l00004ol>Y`0;o00001?ncVKd01Ol0003o[Y6iojjA^On^TKWo000000?oZH^f0ol0
00000onSRk[o0000oj67^@03oj67^@05o`000?nOQKSoWhFhoin5^?l000000onMQ;P00ol0003oW8Bi
oib4^@02oib4^@03o`000?nKQK_o000000?o00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/
00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`01?l0
003oYl3/ojO0k?nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00005ojO0k0?o00000_nW`>`0
0ol0003oYl3/o`000004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ooooo`03o`000?oooooo
oooo00;ooooo0015ooooo`03o`000?oooooooooo02Kooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oTK[boi6jlP02o`000005o`00P_l0003o0000
o`000?lPC<@00_l000000omCK]3o0000ohVDe`02ohVDe`03o`000?n`[]Ko/:kF00?o/:kF0_l00003
om?6c@05o`000?oKb/Wofl[9om_:bOl000000_oQc/H3o`000006ongD^ol0003okmFho`000?o`eKOo
00000oo`e[H00ol0003olMJeo`000002oo7F]P04o`000?o`e[Ool=Jgo`0000;okmJi00?o0000ongG
_Ol000000ooUc;d01Ol0003ohL[2on7:`_oQb/;o000000?odk[200Co0000ol^fa_o;]/Ko00000_o3
ZL000ol0003o^JC3o`000004ok>I_@03o`000?n^TKWo[Y6i00;o[Y6i0ol000000onVS[co0000oj>;
^P02oj>;^P05o`000?nQQkWoXHNioj67^Ol000000onOQKP00ol0003oWHBhoif4^002oif4^003o`00
0?nLQ;Wo000000?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`0
0ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0
k?nW`>`01?l00002ojO0k004o`000?nW`>coYl3/ojO0k0Co00000_nW`>`00ol0003oYl3/ojO0k005
o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00007ooooo`03o`000?oooooooooo00;ooooo0016oooo
o`;o00009oooool2o`0000CoYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/
00Oo000000Ko0022o`000?l07:So0000ob1<a?l00002oe=^d006o`000?n9U=OoRICGohVDeol0003o
/:kF0ol00002okfge003o`000?oCa/go000000?ofl[900Go0000on7>a_oQc/KohLk6o`000002onGA
`P;o000000CokmFho`000?o`eKOo00000_o`e[H01_l0003olMJeoo7F]Ol0003olMJfo`0000?ol=Jg
00?o0000onoF^Ol000000_o]ekd2o`000003onG<_Ol0003ohL[200;ohL[200Go0000om_9aol0003o
dk[2o`000003ol^faP03o`000?o3ZL3o000000?o^JC300Go0000ok>I_OncVKgo/iVmo`000003ojjA
^@;o00000onVS[`01Ol0003oXh^joj>;^_nSRk[o000000?oXHNi00?o0000oin5^?nOQKP00_nOQKP0
0ol0003oWHBho`000003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0
k?l00004ojO0k0?o00000_nW`>`00ol0003oYl3/ojO0k005o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/
00So0000ojO0k?l0003o0000ojO0k?l0003oYl3/o`0000;oYl3/0ol0000;ooooo`03o`000?oooooo
oooo00;ooooo0018ooooo`03o`000?oooooooooo02Kooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o;X[]o`000005o`0000;o84c40ol00002ohVD
e`?o00001_nm]m@01Ol0003ofl[9om_:bOoKb/Wo000000?ohLk600Ko0000onGA`_oUdL;oiM72o`00
0?oYdl05o`000006oo3F]_l0003olMJeo`000?oae[Ko00000oo`e[L01_l0003okmJionoF^Ol0003o
kMNmo`0000;ojmS100Go0000on7:`_oQb/;ohL[2o`000003om_9a`03o`000?o;]/KobkK600;obkK6
0_l00004okVT``03o`000?ncVKgo/iVm00;o/iVm0ol000000onYU<3o0000ojJ>_003ojJ>_005o`00
0?nSRk[oXh^joj>;^_l000000onQQkT00ol0003oWhFho`000003o`0000?oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00000onW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k004o`000?nW`>co
0000o`0000kooooo00?o0000ooooooooool00_ooool004Wooooo00?o0000ooooooooool09_ooool2
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00So00000_lPC<@0
0ol0003oI7cFofAleP02o`0000;oVJ3I00?o0000okfge?nm]m@00onm]m@01Ol0003ob;oBo`000?oK
b/Wo000000?ohLk600Go0000onGA`_oUdL;oiM72o`000002onWC`003o`000?o/e[go000000;ok]Nl
0_l000001?oae[Go0000oo7F]_l00002oo3F]`04o`000?o_e[WokmJio`0000;okMNm00?o0000on_H
`Oo[f<400_l000000ooQb/;o0000om_9a`02om_9a`;o00000oo;]/H00ol0003o`;;<o`000004okVT
``04o`000?ncVKgo/iVmok>I_@;o00001?nYU<001Ol0003oYXjlojJ>_?nVS[co000000?oXh^j00?o
0000oj67^OnQQkT00ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`01?l0003oYl3/ojO0k?nW`>`3o`000003ooooool0003ooooo00gooooo
00?o0000ooooooooool00_ooool004[ooooo00?o0000ooooooooool09Oooool00ol0003oYl3/ojO0
k002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/2?l000001?lPC<Co0000ofAl
e_l00004oiVPf@05o`000?nm]mCo_KODokfge?l000000oo8_m82o`0000?ohLk600Co0000onGA`_oU
dL;o00000_oYdl000ol0003ok=Jmo`000003onkG_003o`000?o_fK_o000000Co000000Col=Jgo`00
0?o_e[Wo00000_o]ekd01?l0003ojmS1on_H`Ol00002onOIa`05o`000?oKbLOoflW7om_9aol00000
0_oCalh00ol0003obkK6o`000003ol2bc003o`000?niY<?o^JC300;o^JC30ol000000on/VlGo0000
ojVD`003ojVD`005o`000?nVS[coYXjlojJ>_?l000000onSRkX01Ol0003oXHNio`000?nW`>co0000
00CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0
003oYl3/ojO0k003o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0
003oYl3/ojO0k004o`0000;oYl3/00Co0000ojO0k?nW`>coYl3/1?l00002ojO0k003o`000?nW`>co
Yl3/00Go00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo001;oooo
o`03o`000?oooooooooo02Gooooo00Ko0000ojO0k?l0003o0000ojO0k?l00004ojO0k0?o00000onW
`>`01?l0003oYl3/ojO0k?nW`>`6o`000003obeIc?l0003o000000;oI7cF00?o0000oiVPfOnIX=T0
0_nIX=T00ol0003o_KODo`000003olRodP06o`000?oAa/oodLK?o`000?oQc/Ko00000_oUdL801ol0
003ojM?0onWC`?oYdl3o0000oncF_Ol000000_o^ek`01_l0003okmVkonoI^ol0003ol=^ko`0000;o
l=fl0_l000001?o_e[Wo0000ongG_Ol00002on_H`@04o`000?oWfLOoimW7onOIa`;o000000?oflW7
o`000?oCalh00ooCalh00ol0003o`;;<ol2bc002ol2bc003o`000?niY<?o^JC300?o00001?n/VlD0
1Ol0003oZIC0ojVD`?nYU<3o000000CoYXjl00?o0000oj>;^_l000000_l00003ojO0k006o`000?nW
`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Go00000_nW`>`00ol0003oYl3/ojO0k004
o`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00C?ooool2o`00
02Kooooo0_l00003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`03?l00002
obeIc0Co00000_nIX=T3o`0000?ob;oB00?o0000om76cooAa/l00_oAa/l01Ol0003oiM72onGA`_oU
dL;o000000;ojM?000?o0000oncF_Ol000000oo^ek`01Ol0003okmVko`000?o`fk_o000000?ol=fl
00Ko0000oo3O__l0003o0000ongG_Ol00002on_H`@04o`000?oWfLOoimW7o`0000;oh][>0_l00003
om?7cP;o00001?o0//`3o`0000;o/:G<00?o0000ojbKaOn/VlD00_n/VlD00ol0003oZIC0ojVD`002
ojVD`003o`000?nVS[co000000?o00000onW`>`00ol0003oYl3/ojO0k002o`0000CoYl3/00Co0000
ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o
0000ojO0k?nW`>`00ol00004ojO0k006o`000?nW`>co0000o`000?nW`>co00001?nW`>`3o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00003oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001>ooooo`03o`000?oooooooooo02Gooooo
00?o0000ojO0k?nW`>`00ol00003ojO0k0?o00001?nW`>`00ol0003oRKOdo`000004o`000004o`0/
]?l0003o;EW<o`0000;oM8_K0ol00003ojR/fP03o`000?o8_m;o000000GodLK?0_l000001OoUdL;o
0000onWC`?oYdl3o000000;ok=Jm00Co0000onkG_?o^ekco00000_o_fK/00ol0003ol=^ko`000002
oo3M_005o`000?o`gkkol=nno`000?o_h/800_l000001Oo[f<7o0000onOIaooWfLOo000000?oh][>
00Go0000om[Keol0003odlO>o`000002olS4eP06o`000?o0//co0000o`000?ne/MGo00001?n`YL`0
1Ol0003o[9_5ojbKaOn/VlGo000000;oZIC01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW
`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000
ojO0k?l00003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0001Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`01ooooo`00Coooool00ol0003oooooooooo`0Uooooo`;o0000
0onW`>`00ol0003oYl3/o`000002ojO0k003o`000?nW`>coYl3/00;oYl3/1ol00002o`0/]0?o0000
0_mdRm/00ol0003oZ:cJojR/fP02ojR/fP;o00001OoAa/l00ol0003ofLc=omW<c@03o`000004onWC
`?l0003ok=Jmo`0000?ok]Nl00Go0000onoI^ol0003ol=^ko`000003oo3M_003o`000?o`gkko0000
00;okn;200Ko0000ongUa_l0003o0000onOIaol00003on;JcP03o`000?oJfmOof]_G00;o00000oo8
a=H2o`0000Co]K7E00Go0000ok2Uc?n`YLco/:G<o`000002ojbKa@Co00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k006o`000?nW`>co0000o`000?nW
`>co00001?nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/
00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0000Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0053ooooo00?o0000oooooooo
ool09Oooool00ol0003oYl3/ojO0k003o`0000CoYl3/00Ko0000ojO0k?l0003o0000ojO0k?l00002
oeVOm0Ko000000?o>fSDo`000?mdRm/00_mdRm/01?l0003oZ:cJo`000?l00002okJgfP05o`000?oA
a/oodLK?om76col000000ooIc<d00ol0003ogm7:omoAbP02o`000007oncF_Ol0003ok]NlonkG_?l0
003okmVko`000002oo3K^`06o`000?o`gKcol=flo`000?o`gkko00000_o_h/801Ol0003okNG6ongU
a_l0003oj^S<00?o000000Goh][>o`000?oJfmOof]_Go`000002olkKh`03o`000?o8a=Ko000000;o
^L7P00Go0000okFaeOne/MGo]K7Eo`000002ok2Uc0Co00000onW`>`00ol0003oYl3/ojO0k004o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`01_l0
003oYl3/o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol0000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00Oooool0057ooooo0_l0000Vooooo`;o00000onW`>`0
0ol0003oYl3/ojO0k003o`0000CoYl3/00?o0000oeVOm?l000000ol000001?l0=kco0000o`000?lk
J=@5o`0000Go][OJ00?o0000om76col000000ooIc<d01_l0003ogm7:omoAb_oOdL[o0000onCEb0?o
000000Kok]Nlo`000?o_fK_o0000oo3K^ol00002oo3M_006o`000?o`gkkol=nno`000?o_h/;o0000
0_o]iLH01Ol0003oj^S<on[Xc?l0003oiNgE00?o000000?of]_Go`000?o>fn<00_o>fn<2o`0000Co
^L7P00?o0000okFaeOne/MD00ol00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003o
Yl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o
00001?nW`>`01?l0003oYl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/
00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00008Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001Cooooo`03o`000?oooooooooo
02Gooooo00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00So000000Co03Nlo`00
0?lkJ=Co00001?n5V]l00ol0003o][OJokJgfP02okJgfP;o00000ooIc<d01Ol0003ogm7:omoAb_oO
dL[o000000;oi=G800?o0000onSIa_oXfLH01?l000001oo`fk_o0000oo3M_?o`gKco0000oo3O__l0
00000_o_h/800ol0003okNG6o`000002on[Xc003o`000?oUkMGo000000;ofo7O0ol000000oo>fn?o
0000o`000002ok[Ek@03o`000?ni`N3o^L7P00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o
Yl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00004ojO0k0?o00000_nW`>`00ol0003o
Yl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0000Sooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool005Cooooo00?o0000ooooooooool0
9Oooool2o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojG0k007o`000?lcQ>[o0000o`000?l0
1IOo0000o`0g_003o`0000CoQI[O00Co0000okJgf_l0003o00000_o1`MT00ol0003ofLc=o`000003
omoAbP04o`000?oTeLSoi=G8o`0000?oj=W600Co0000on_MaOl0003okN751ol000001?o_h/;o0000
ongUa_l00002on[Xc003o`000?oUkMGo000000;ofo7O00?o0000ol_cjoo;ln/00_l00004ok[Ek@?o
00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003
o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k006o`000?nW`>co0000o`000?nW`>co00000onW`>`3o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0000Wooooo`03o`000?oooooooooo00Sooooo0Ol00001
ooooo`7ooooo001Eooooo`03o`000?oooooooooo02Gooooo00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nU`>coYL3/00Go000000Co00FGo`000?l0003oBgWM0_l00002ohFJg`?o00001?o1`MT4
o`000005omoAb_l0003oi=G8onCEb?l000000ooXfLH00ol0003ojmg5o`000002ongQa@07o`000?o^
iLGok^G5o`000?o^jLKo0000ong^b@09o`000003om_agol0003obo?[00;o00000_nej?L01_l0003o
^]G]o`000?l0003oYl3/o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>co
Yl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003
ojO0k003o`000?nW`>coYl3/00Co0000;?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00E_ooool2o`0002Kooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co00000_nK_O000ol0
003o7g[Uo`000004o`0000;oBgWM0_l00002oiFXh`05o`000?o1`MWo`L7Iol71fOl000001?o;b]P0
1Ol0003oi=G8onCEb?oTeLSo000000;oj=W600?o0000on_MaOl000000_o]hLD01_l0003ok^G5onkU
aOl0003ok^W6o`0000;okNk90_l00002onGhd@04o`000?oLo=Oo0000ol_ng@Go00000_nej?L3o`00
00CoYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000
ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00;o00001?nW`>`3
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`00037ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0
05Sooooo00?o0000ooooooooool09?ooool00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000oi^m
l?nK_O001ol00002od]ig@03o`000?nEZ>?oUJSS00;oUJSS00?o0000ol71fOl000001?o;b]P01Ol0
003oe=;Go`000?oTeLSo000000;oj=W600Ko0000on_MaOo[gLGo0000ongQaOl00002onkUa@03o`00
0?o^jLKo000000;okNk90_l00002onGhd@03o`000?oLo=Oo000000Co000000?oWo7co`000?l00000
0_l00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`01?l0003oYl3/
o`000?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l0000eooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7o
oooo001Iooooo`03o`000?oooooooooo02Cooooo0_l00003ojO0k003o`000?nW`>coYl3/00Co0000
0onA_?@3o`000003o`14aOl0003o000000;o00000_nEZ><4o`0000?obl[H00Co0000omCBeooDd]Oo
e=;G0_l000001OoXfLKo0000on_MaOo[gLGo000000;okN7500Oo0000onkUaOo^iLGo0000onkYa_l0
003okNk900;o00000_oUn=400ol0003og?cGo`000006o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k004o`000?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`0
1?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/
0ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0003[ooooo
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool005[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000oi6lm?nA_?@01ol000001?mJRnKo0000o`00
0?l00004ojBgi`03o`000?o;b]So000000?oe=;G00?o0000om_Je_oKf]H01Ol000002?o]hLGo0000
onkUaOo^iLGo0000onkYa_l0003okNk92ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`0
0ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>co
Yl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0000oooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo001Kooooo`;o00009_ooool2o`0000?oYl3/00?o0000
ojO0k?nW`>`00ol00003ohNimP;o000000?o05?@o`000?l000000_mJRnH00ol0003oY;OWojBgi`02
ojBgi`;o00000ooDd]L01?l0003ofm[Fom_Je_l00003on3Qe@03o`000?oTj=Co000000Oo000000?o
g?kBo`000?l000001?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0
k004o`0000?oYl3/00Co0000ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/
00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/
ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o0000
1?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00014ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo001Mooooo`03o`000?oooooooooo02Cooooo00?o0000ojO0k?nW`>`01?l0
0002ojW1j`03o`000?n7^OKoQkWf00Co00000_l0Dm04o`000003ojBgiol0003o000000;o/LKY00?o
0000omCBeol000000_oKf]H01ol0003oh>7Eon3QeOoPhMGo0000onCXe?l000000ooVk]<2o`000003
on?jdol0003og?kB00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o00001?nW`>`3o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`01_l0003o
Yl3/o`000?l0003oYl3/o`0000;oYl3/1?l00018ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`00G_ooool00ol0003oooooooooo`0Tooooo`;o00000onW`>`00ol0003oZL7[ojW1j`03o`00
00?oP[Kf1?l00002ofZNk`;o00001?naa^T3o`000003om_Je_l0003oh>7E00;oh>7E00?o0000onCX
e?l000000ooVk]<2o`000003on?jdol0003og?kB00?o000000CoYl3/o`000?nW`>coYl3/0ol00003
ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000
ojO0k?l0003o00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0
0003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o
0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`3o`0004gooooo00?o
0000ooooooooool00oooool1o`00007ooooo001Oooooo`03o`000?oooooooooo02Cooooo00?o0000
ojO0k?nW`>`01?l00003ojc2j@03o`000?n2]_KoP[Kf00Go00000omZW^l01?l0003o/LKYo`000?l0
0002okgCj`Co000000Coh>7Eo`000?oTj=Co00000ooVk]<2o`000003on?jdol0003o000000;o0000
0_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0onW`>`00ol0003oYl3/ojO0k003o`0000CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co0000
0onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`00
0?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?l00000
DOooool00ol0003oooooooooo`02ooooo`7o00000Oooool0063ooooo0_l0000Uooooo`;o00000onW
`>`00ol0003o[<;Yojc2j@04o`0000?oQKGd00?o0000o`IUf_l000001?l00003okgCj`04o`000?o6
h>_oa^3[olKPj`Ko000000?oi^kCo`000?l000002?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k004o`00
0?nW`>co0000o`0000;oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0005?ooooo00Go0000oooooooo
ooooooooo`000001ooooo`00H_ooool00ol0003oooooooooo`0Tooooo`03o`000?nW`>coYl3/00?o
00000on]aN/9o`0000;oN;?g00?o0000okgCjol000000oo6h>/00ol0003oc>_[o`000003oloej@Co
000000Co/o_Ao`000?l0003o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0
k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`00
00CoYl3/0ol00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0
003oYl3/ojO0k004o`0005Kooooo00Go0000ooooooooooooooooo`000001ooooo`00Hoooool00ol0
003oooooooooo`0Tooooo`;o00000_nW`>`01_l0003o[LG[o`000?l0003oZ/;[o`0000CoSkOa00?o
0000o`ahh_l000001_l000001?o6h>_o0000olc[jol00003oloej@03o`000?o<o>Co000000?o0000
0_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00Co0000ojO0k?l0003o
00000_nW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003
o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l0001Kooooo`04o`000?ooooooooooo`00007ooooo001Tooooo`03o`000?oooooooooo02Co
oooo00?o0000ojO0k?nW`>`00ol00003oj[2j`03o`000?n?]o7oSkOa00Ko00000_n4aod7o`000003
oloejOl0003oc?cT00?o000000CoYl3/o`000?nW`>coYl3/0ol00003ojO0k003o`000?nW`>coYl3/
00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0
k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0
k?nW`>`01?l0001Pooooo`03o`000?oooooo0000007ooooo001Uooooo`;o00009Oooool2o`0000?o
Zl7Z00?o0000oj[2jonZ`^/00ol00003oibjk@03o`000?nB`?Ko000000;o000000?oSMSoo`000?l0
00000_n?iO/6o`0000;oYl3/1?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003o
Yl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co
00000onW`>`3o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co
00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001Tooooo`03
o`000?oooooooooo007o0000001Wooooo`03o`000?oooooooooo02?ooooo00?o0000oj_1j_n[`NX0
1?l00002ojJlj@03o`000?nL^^goW;[]00Co000000?oYl3/o`000?l000002?l000001?nW`>co0000
o`000?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`01?l0003o
Yl3/o`000?l00002ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`00
00;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00Co0000J?ooool1o`00
007ooooo0Ol0000006Sooooo00?o0000ooooooooool08oooool2o`0000?o[<7Z00?o0000ojJljOnV
_>T00ol00003ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0000?o
Yl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003o
Yl3/ojO0k004o`0006gooooo0_l0000006Wooooo00?o0000ooooooooool08oooool00ol0003o[<7Z
ojc1jP04o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/
00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/
ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000
0_nW`>`4o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`00ol0003oYl3/ojO0k004o`00073ooooo0ol0000006[ooooo0_l0000Tooooo`;o00000onW
`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co00000_nW
`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW
`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/0ol00003ojO0k003o`000?nW
`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
001`ooooo`Co00000oooool006cooooo00?o0000ooooooooool08oooool00ol0003oYl3/ojO0k003
o`0000;oYl3/1?l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`0
0ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000Koooool4
o`0000Oooooo001]ooooo`03o`000?oooooooooo02?ooooo0_l00002ojO0k0?o00000onW`>`00ol0
003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/
00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0
k003o`000?nW`>coYl3/00Co0000L?ooool3o`0000_ooooo001^ooooo`03o`000?oooooooooo02?o
oooo00?o0000ojO0k?l000000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW
`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`4o`0000;o
Yl3/00?o0000ojO0k?nW`>`01?l00003ojO0k003o`000?nW`>coYl3/00?o0000L?ooool4o`0000ko
oooo001_ooooo`;o00009?ooool2o`0000;oYl3/0ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`00
0?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`000003ojO0k?l0003o000000;o0000
0onW`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`01?l0001_ooooo`Co0000
4_ooool0077ooooo00?o0000ooooooooool08oooool2o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0
0003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o
0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`0000?oYl3/00?o
0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co0000Koooool4o`0001Kooooo001b
ooooo`03o`000?oooooooooo02?ooooo00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>co
Yl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003
ojO0k003o`000?nW`>coYl3/00?o00000_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00003
ojO0k003o`000?nW`>coYl3/00?o0000Koooool4o`0001[ooooo001cooooo`03o`000?oooooooooo
02?ooooo0_l00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`00
00?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`3o`00
00?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000K_ooool4o`00
01kooooo001dooooo`;o00009?ooool00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000ojO0k?nW
`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000;o
Yl3/1?l00002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006oo
oooo0ol0000Rooooo`00M_ooool00ol0003oooooooooo`0Rooooo`;o00000onW`>`00ol0003oYl3/
ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00Co0000
0_nW`>`3o`0000?oYl3/00?o0000ojO0k?nW`>`00ol00003ojO0k003o`000?nW`>coYl3/00?o0000
Koooool4o`0002Gooooo001gooooo`03o`000?oooooooooo02;ooooo00?o0000ojO0k?nW`>`01?l0
0002ojO0k003o`000?nW`>coYl3/00Co00000onW`>`00ol0003oYl3/ojO0k003o`0000;oYl3/1?l0
0002ojO0k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006kooooo1?l0
000Yooooo`00N?ooool00ol0003oooooooooo`0Rooooo`;o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k0?o00000onW`>`00ol0003oYl3/ojO0k003
o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001^ooooo`Co0000;Oooool007Wooooo0_l0000Toooo
o`03o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0000;oYl3/1?l00002ojO0
k003o`000?nW`>coYl3/00Co00000_nW`>`00ol0003oYl3/ojO0k004o`0006gooooo1?l0000aoooo
o`00Noooool00ol0003oooooooooo`0Rooooo`;o00000_nW`>`00ol0003oYl3/ojO0k004o`0000;o
Yl3/0ol00003ojO0k003o`000?nW`>coYl3/00?o00000onW`>`00ol0003oYl3/ojO0k003o`0006go
oooo1?l0000eooooo`00O?ooool00ol0003oooooooooo`0Rooooo`03o`000?nW`>coYl3/00?o0000
0_nW`>`4o`0000;oYl3/00?o0000ojO0k?nW`>`01?l00002ojO0k003o`000?nW`>coYl3/00Co0000
K?ooool4o`0003Wooooo001mooooo`03o`000?oooooooooo02;ooooo0_l00002ojO0k0?o00000onW
`>`00ol0003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001]ooooo`?o0000?Ooo
ool007kooooo0_l0000Tooooo`;o00000_nW`>`00ol0003oYl3/ojO0k004o`0000;oYl3/00?o0000
ojO0k?nW`>`01?l0001/ooooo`Co0000@?ooool0083ooooo00?o0000ooooooooool08_ooool00ol0
003oYl3/ojO0k003o`0000?oYl3/00?o0000ojO0k?nW`>`00ol0001/ooooo`Co0000A?ooool0087o
oooo00?o0000ooooooooool08_ooool2o`0000;oYl3/00?o0000ojO0k?nW`>`01?l0001[ooooo`Co
0000B?ooool008;ooooo00?o0000ooooooooool08_ooool00ol0003oYl3/ojO0k003o`0006_ooooo
1?l0001<ooooo`00Poooool2o`0002?ooooo0_l0001Zooooo`Co0000D?ooool008Gooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Vooooo`?o0000E?ooool008Kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Rooooo`Co0000Eoooool008Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Nooooo`Co0000Foooool008Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Jooooo`Co0000Goooool008Wooooo0_l0000Mooooo`03o`000?oo
oooooooo05Kooooo1?l0001Sooooo`00Roooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo05;ooooo1?l0001Wooooo`00S?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04oooooo0ol0001[ooooo`00SOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04_o
oooo1?l0001^ooooo`00S_ooool2o`0001Sooooo00?o0000ooooooooool0Aoooool4o`0007;ooooo
002@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool4o`0007Kooooo002A
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`0007[ooooo002Boooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>oooool4o`0007kooooo002Cooooo`;o
00004_ooool00ol0003oooooooooo`0iooooo`?o0000P_ooool009Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0eooooo`Co0000QOooool009Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0aooooo`Co0000ROooool009Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0]ooooo`Co0000SOooool009Sooooo0_l0000=ooooo`03o`000?oooooooooo
02Wooooo1?l0002Aooooo`00V_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo1?l0002Eooooo`00Voooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
1?l0002Iooooo`00W?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0ol0
002Mooooo`00WOooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:3ooooo002Ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:Cooooo002Pooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:Sooooo002Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000:cooooo002Rooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`Co0000/?ooool00:Cooooo00Co0000oooooooooooo00002Ooo
ool3o`000;Cooooo002Uooooo`03o`000?oooooo000000Gooooo1?l0002gooooo`00Y_ooool2o`00
0003ooooool0003o000000;o0000^oooool00:Oooooo0_l0002oooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00_oooool3o`000003oa0@
4?oooooooooo0:?ooooo002Mooooo`03okZj^_lb<S;ooooo00;ooooo00Co0000oooooooooooo0000
1oooool2o`0000_ooooo00?o0000okZj^_ooool01?ooool00ol@413o^[Zjooooo`05ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2Eooooo`00W_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`;o<S8b1Oooool00onHV9So<S8b
ooooo`06ooooo`03o`000?oooooooooo00?ooooo0_lb<S:Fooooo`00W?ooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool00ooMgMgo0000okZj^P06oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Kooooo00GoV9RHoa0@4?l0003o<S8bolc<c01fooooo`00W?ooool0
1_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o00002?ooool02_l0003oooooooooooooooook^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00?oEEEEogMgMom4A4@01_oo
ool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go0000oooooooooooooooo
o`000002ooooo`Ko000000Kooooooa0@4?nj^[[oooooogMgMolb<S9fooooo`00W?ooool01_lb<S;o
k^k^oiRHV?mEEEGogMgMoa0@40_ooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`:ooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`1dooooo`00W?ooool01onj^[[oA4A4
olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@
onk^kP[ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooooooo01;ooooo00Go
0000ooooooooooooooooo`000002ooooo`Ko00001?ooool00onYZJWo410@ooooo`1eooooo`00W?oo
ool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<PWooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03oooo
o`03o`000?oooooooooo01;ooooo00Go0000ohN7QoooooooZJVYo`00000;ooooo`03oa0@4?l0003o
^[Zj07Kooooo002Looooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool02?ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003oMgMg00;o0000
00?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1eooooo`00Woooool00omVIVKoQhN7oooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool01Ol@413oV9RHoooo
oonj^[[o000007Kooooo002Oooooo`03ojVYZOm4A4Cooooo00_ooooo0_l0000Jooooo`;o00008_oo
ool01OnYZJWo410@o`000?l@413oZJVY07Kooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.121594, 0.0187328, \
0.00374021, 0.00374021}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3.4 WKB Eigenmodes", "Subsubtitle",
  CellTags->"c:38"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["The Wave Equation", "Section",
  CellTags->"c:39"],

Cell["\<\
\tFor one-dimensional eigenmode problems, the WKB method can be \
used to determine analytic approximations to the eigenmodes. This provides an \
analytic alternative to the strictly numerical methods discussed \
previously.\
\>", "Text",
  CellTags->"i:43"],

Cell[TextData[{
  "\t Our model PDE for this section will be the 1D wave equation with \
arbitrary tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " and mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(\(L\&^\) 
            y = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\)\)\)]],
  ","
}], "NE3",
  CellTags->{"(3.1.7)", "(6.3.13)"}],

Cell[TextData[{
  "subject to homogeneous Dirichlet boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(L, t) = 0\)\)]],
  ". "
}], "Text"],

Cell["\<\
\tApproximate eigenmodes and eigenvalues for this problem can be \
obtained using WKB theory.  The WKB solution to  the eigenmode \
equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\[Rho](
                x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                x)\)\ \(\[PartialD]\/\[PartialD]x\) \[Psi]\_n)\) = \
\(\[Lambda]\_n\) \[Psi]\_n\)]],
  ","
}], "NE3",
  CellTags->"(6.3.14)"],

Cell["is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x) = \(C\_1\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\(1/4\)\) \
\[ExponentialE]\^\(\[ImaginaryI] \(\[Integral]\_0\%x\(\( k\_n\)(x)\) \(\(\
\[DifferentialD]x\)\(\ \)\)\)\) + \(\(C\_2\/\([\(T(x)\) \
\(\[Rho](x)\)]\)\^\(1/4\)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\) \(\
\[Integral]\_0\%x\(\( k\_n\)(
                        x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\(\ \
\)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\  = \ \[Omega]\_n/\(c(x)\)\)]],
  " is the local wavenumber for the waves, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = \@\(-\[Lambda]\_n\)\)]],
  " is the eigenfequency, and ",
  Cell[BoxData[
      \(TraditionalForm\`c(x) = \@\(\(T(x)\)/\(\[Rho](x)\)\)\)]],
  "is the local wave speed [see Eq. ",
  ButtonBox["(5.2.62)",
    ButtonData:>{"Chapter5.nb", "(5.2.62)"},
    ButtonStyle->"Hyperlink"],
  "]. Eigenmodes can be formed from this general solution simply by matching \
the boundary conditions.  The condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0) = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = \(-C\_1\)\)]],
  ", so that "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Psi]\_n\)(
        x)\  = \ \(\(2  \[ImaginaryI]\ C\_1\)\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\
\(1/4\)\) 
        sin \(\[Integral]\_0\%x\(\( k\_n\)(
              x)\) \[DifferentialD]x\)\)]]], "NE3",
  CellTags->"(6.3.16)"],

Cell[TextData[{
  "In order to match the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](L) = 0\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\(\( k\_n\)(
              x)\) \[DifferentialD]x = n\ \[Pi]\)]],
  ",    ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = 1, 2, 3,  ... \)]],
  "."
}], "NE3",
  CellTags->"(6.3.17)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(6.3.17)",
    ButtonData:>"(6.3.17)",
    ButtonStyle->"Hyperlink"],
  " provides us with the eigenfrequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " for the problem:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = n\ \[Pi]/\(\[Tau](L)\)\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          L) = \[Integral]\_0\%L\[DifferentialD]x\/\(c(x)\)\)]],
  " is the propagation time for waves to travel from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(0\)\(\ \)\)\)]],
  "to  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(L\)\(\ \)\)\)]],
  ". In the WKB approximation, the eigenfrequencies are evenly spaced with a \
fundamental frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1 = \[Pi]/\(\[Tau](L)\)\)]],
  ". Therefore the  resulting motion of the string is periodic in time, with \
this fundamental frequency. The eigenmodes of the string are "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(1\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\(1/4\)\) 
          sin\ \((n\ \[Pi] \( \[Tau](x)\)\/\(\[Tau](L)\))\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.19)"],

Cell[TextData[{
  "How well does the WKB approximation to the eigenmodes work?  The answer \
depends on how rapidly varying ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " are compared to ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\)]],
  ".   For high-order modes, where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_n\)]],
  " is large, the WKB approximation should be very accurate. For low-order \
modes, where ",
  Cell[BoxData[
      \(TraditionalForm\`1/k\_n\)]],
  " is of order ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", the method may not be very accurate.  "
}], "Text"],

Cell[TextData[{
  "\tLet's compare the WKB solution of the wave equation with a solution \
obtained using the Galerkin method. We will solve the wave equation, Eq. ",
  ButtonBox["(6.3.13)",
    ButtonData:>"(6.3.13)",
    ButtonStyle->"Hyperlink"],
  ", choosing  ",
  Cell[BoxData[
      \(TraditionalForm\`T(x) = constant\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) = 1/\((1 + x)\)\^2\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`c(x) = \(\@\(T/\[Rho]\)\  = \ 1 + x\)\)]],
  ". We take ",
  Cell[BoxData[
      \(TraditionalForm\`L = 2\)]],
  ". With this choice for ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\  = \ ln(1 + x)\)]],
  ", and according to Eq. ",
  ButtonBox["(6.3.18)",
    ButtonData:>"(6.3.18)",
    ButtonStyle->"Hyperlink"],
  " the WKB  eigenfrequencies are ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = n\ \[Pi]/ln\ 3\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tWe take initial conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(0, x) = \(\(y\_o\)(x) = 
          sin\ \[Pi]\ x\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 0)\) = 0\)]],
  ". Then the coefficients in the general solution, Eq. ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ", are ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n = 0\)]],
  " and"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \ \(\((\[Psi]\_n, \ y\_o)\)\/\((\[Psi]\_n, \
\[Psi]\_n)\) = \(\[Integral]\_0\%L\( \[Rho](x)\)\ \(\(\[Psi]\_n\)(x)\)\ sin\ \
\[Pi]\ x \[DifferentialD]x\)\/\(\[Integral]\_0\%L\( \[Rho](x)\)\ \
\(\(\[Psi]\_n\%2\)(x)\)\ \[DifferentialD]x\)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.20)"],

Cell[TextData[{
  "We will perform the required integrals numerically.  We construct the WKB \
solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " below:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(\(L = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Tau][x_]\  = Log[1 + x];\)\), "\n", 
    \(\(\[Rho][x_]\  = \ 1/\((1 + x)\)^2;\)\), "\n", 
    \(\(T[x_]\  = \ 1;\)\), "\n", 
    \(\(\(\[Psi]WKB[n_, x_]\  = \ 
        Sin[n\ Pi\ \[Tau][x]/\[Tau][L]]/\[Rho][x]^\((1/4)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Omega]WKB[n_]\  = \ n\ Pi/\[Tau][L];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(y0[x_]\  = \ Sin[\ Pi\ x];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A[n_]\  := \ \(A[n]\  = \ 
          NIntegrate[\[Rho][x]\ \[Psi]WKB[n, x]\ y0[x], {x, 0, L}]/
            NIntegrate[\[Rho][x]\ \[Psi]WKB[n, x]^2, {x, 0, L}]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[\[Omega]WKB[n]\ t]\ \[Psi]WKB[n, x], {n, 1, 
            10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.170"],

Cell[TextData[{
  "The solution found using WKB eigenmodes is a rather complex periodically \
repeating oscillation with fundamental period ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]/\[Omega]\_1\)]],
  ". In Fig. ",
  ButtonBox["6.12",
    ButtonData:>"Fig. 6.12",
    ButtonStyle->"Hyperlink"],
  " we plot the WKB solution (solid) superimposed on the solution found via \
the Galerkin method (dashed), over two periods of the WKB solution."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -40.625 0 ]
[.5 .63053 40.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -101.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36895 L
.10458 .42977 L
.14415 .47853 L
.18221 .51461 L
.20178 .52826 L
.21267 .53429 L
.22272 .53882 L
.23293 .54239 L
.23832 .54385 L
.24402 .54507 L
.24641 .54548 L
.24897 .54586 L
.25119 .54613 L
.25361 .54637 L
.25507 .54648 L
.25643 .54657 L
.25773 .54663 L
.2584 .54666 L
.25912 .54668 L
.25983 .5467 L
.26048 .54671 L
.26176 .54672 L
.26293 .54672 L
.26416 .5467 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54645 L
.27131 .54627 L
.27364 .54601 L
.27847 .54531 L
.2838 .54425 L
.29326 .54166 L
.30213 .5384 L
.32232 .52809 L
.34082 .51523 L
.38045 .47766 L
.41855 .43068 L
.45912 .37236 L
.49816 .3119 L
.53966 .24753 L
.57964 .18979 L
.61811 .14198 L
.63759 .12168 L
.65902 .10293 L
.67938 .08892 L
.69843 .0794 L
.70884 .07573 L
.71396 .07432 L
Mistroke
.71872 .07325 L
.72301 .07249 L
.72758 .07188 L
.7302 .07163 L
.73148 .07154 L
.73266 .07146 L
.73371 .07141 L
.73487 .07137 L
.73603 .07133 L
.73725 .07131 L
.73856 .07131 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74251 .07141 L
.74375 .07148 L
.74508 .07156 L
.74748 .07177 L
.74985 .07203 L
.75235 .07236 L
.7568 .07312 L
.76198 .07426 L
.7668 .07556 L
.77773 .07939 L
.78828 .08422 L
.79823 .08977 L
.81683 .10266 L
.85534 .13895 L
.89632 .18947 L
.93577 .24638 L
.97371 .30513 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Wooooo2Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo00?o0000ool00?oo0000
0_oo0009ooooo`?oo`000_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=;ooooo0_l0000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3?ooooo`?o00005oooool3o`0005Sooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0cOooool2o`0001gooooo0_l0001Fooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0<_ooooo00?oo`00o`000?ooool08?ooool00ooo003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`39ooooo`;oo`009?ooool2ool005?ooooo
000Qooooo`03o`000?oooooooooo0<Sooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`1@ooooo`008Oooool3o`000<Kooooo0_oo000Zooooo`;oo`00D?ooool0027ooooo00?o0000oooo
ooooool0aOooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo0<?ooooo0_oo000`ooooo`03ool00?l0003ooooo04cooooo000Qooooo`03o`00
0?oooooooooo0<;ooooo00?oo`00ooooooooool0<Oooool00ooo003o0000ooooo`1;ooooo`008Ooo
ool00ol0003oooooooooo`31ooooo`03ool00?oooooooooo03?ooooo00?oo`00o`000?ooool0B_oo
ool0027ooooo00?o0000ooooooooool0`?ooool00ooo003oooooooooo`0eooooo`03ool00?l0003o
oooo04Wooooo000Qooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooooooool0=oooool00ooo
003o0000ooooo`18ooooo`008Oooool3o`000;kooooo00?oo`00ooooooooool0>Oooool00ooo003o
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`008Ooo
ool3o`000;Oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2gooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool0?oooool0
027ooooo00?o0000ooooooooool0]_ooool00ooo003oooooooooo`19ooooo`03ool00?l0003ooooo
03oooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?oo`00ooooooooool0Boooool00ooo003o
0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2dooooo`03ool00?oooooooooo04gooooo
00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo0;?ooooo00?oo`00
ooooooooool0D?ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2boooo
o`03ool00?oooooooooo05;ooooo00?oo`00ooooooooool0>_ooool0027ooooo0ol0002aooooo`03
ool00?oooooooooo05?ooooo00?oo`00o`000?ooool0>_ooool0027ooooo00?o0000ooooooooool0
/?ooool00ooo003oooooooooo`1Eooooo`03ool00?l0003ooooo03Wooooo000Qooooo`03o`000?oo
oooooooo0:oooooo00?o0000ool00?ooool0Eoooool00ooo003o0000ooooo`0hooooo`008Oooool0
0ol0003oooooooooo`2_ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0=oooool0
027ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0G?ooool0
0ooo003oooooooooo`0eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo03Cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0002[ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<Ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02oooooo000Qoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ool00?ooool0JOooool00ooo003oooooooooo`0_oooo
o`008Oooool3o`000:Kooooo00?o0000ool00?ooool0JOooool00ooo003o0000ooooo`0_ooooo`00
8Oooool00ol0003oooooooooo`2Uooooo`03o`000?oo003ooooo06_ooooo00?oo`00o`000?ooool0
;_ooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oo
oooooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ool00?ooool0Koooool0
0ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo
06oooooo00?oo`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o
ooooooooo`1aooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo0:7ooooo
00?o0000ool00?ooool0Loooool00ooo003oooooooooo`0Zooooo`008Oooool3o`000:7ooooo00?o
o`00ooooooooool0Loooool00ooo003o0000ooooo`0Zooooo`008Oooool00ol0003oooooooooo`2P
ooooo`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool0Woooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Sooooo000Qooooo`03
o`000?oooooooooo09kooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0Wooooo`00
8Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1kooooo`03ool00?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool09Oooool0027ooooo0ol0002Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0=oooool00ol0003oooooooooo`03
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0>?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<03Wooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool02?oo003o0000ooooool0003o^[Zj
oooooonHV9So410@6oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000?ooooo00?o0000ool00?ooool0>Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000??ooool01ooo003ooooooiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`2:ooooo`03ool0
0?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0S?oo
ool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooo
oooo08cooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0U?ooool00ooo
003oooooooooo`2>ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0Toooool00ol0003oo`00ooooo`2@ooooo`03ool00?oooooooooo017o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
09?o000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo0000TOooool00ooo003oooooooooo`2Voooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?ooooooo`00093ooooo00?oo`00oooooooo
ool0/Oooool0027ooooo00Co0000ooooooooooooo`00S_ooool00ooo003o0000ooooo`2booooo`00
8Oooool01Ol0003oooooooooool0003oo`0008gooooo00?o0000ooooooooool0/_ooool0027ooooo
00Ko0000ooooooooooooooooo`000?oo002;ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`29ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?ooool0R?ooool00ol0003oooooooooo`2dooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo08Kooooo00?o0000ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oooooo
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool00ol0
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo08;o
oooo00?o0000ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003ooooooooo
o`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O_ooool00ooo003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2kooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oooooo
oooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool00ooo
003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo07Cooooo
00?oo`00ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`1booooo`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool0L?ooool00ol0003oo`00ooooo`30ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0`?ooool0027ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`008Ooo
ool3o`00017ooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`32ooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?o0000ooooooooool0`oooool0
027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03o`000?oooooooooo
0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ol0003o
ooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Gooooo
00?o0000ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ooooo`1Tooooo`03o`000?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo06;ooooo00?oo`00o`000?ooool0aoooool000Oooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03o`000?oooooooooo067o
oooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Oooooo`03
ool00?oooooooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooo
o`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ooo
003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00oooo
ooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0<co
oooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0Eoooool00ooo003ooooo
ooooo`3<ooooo`008Oooool3o`0001_ooooo00?oo`00o`000?ooool0E_ooool00ooo003ooooooooo
o`3=ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool00?l0003ooooo05Cooooo00?oo`00
ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07Oooool00ooo003o0000ooooo`1Boooo
o`03ool00?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?oo
ool0D?ooool00ooo003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`3Booooo`008Oooool3o`00
02;ooooo00?oo`00ooooooooool0BOooool00ol0003oooooooooo`3Cooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03ool00?oooooooooo04Kooooo0_l0003Fooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0e_ooool0027ooooo00?o
0000ooooooooool09Oooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo0=Oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`3H
ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03kooooo00?oo`00oooo
ooooool0fOooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03
ool00?oooooooooo0=[ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`3Kooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`3Looooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03Kooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0dooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02go
oooo00?o0000ool00?ooool0<_ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003ooooo
ooooo`0^ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o
0000ooooooooool0;oooool2ool002kooooo00?o0000ool00?ooool0h_ooool0027ooooo00?o0000
ooooooooool0<Oooool00ooo003oooooooooo`0Zooooo`03o`000?oo003ooooo0>?ooooo000Qoooo
o`?o0000<_ooool2ool002Wooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`00
0?oooooooooo03Gooooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=ooo
ool00ooo003oooooooooo`0Mooooo`?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool3
ool001[ooooo0_l0003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool01?oo003o0000o`000?l0000Dooooo`;oo`00koooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo0_oo003aoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo1ol00003ooooo`Oo
o`00loooool001[ooooo00?o0000ooooooooool01?ooool3o`0004Gooooo1Ooo003jooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_ooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0W?ooool008kooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Looooo`00Q_ooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0Poooool008Kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`23ooooo`00Q_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6
ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@4023ooooo`00Q_oo
ool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000Poooool008Kooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0
003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool0
0ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000ooo
ool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool00000Poooool008Oooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@4023ooooo`00WOoo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg08?ooooo002Mooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP23ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36461 L
.10458 .41979 L
.14415 .46266 L
.16408 .48001 L
.18221 .49301 L
.20178 .50387 L
.21254 .50838 L
.22272 .51169 L
.23241 .51395 L
.2373 .51476 L
.24012 .51513 L
.24269 .5154 L
.24504 .5156 L
.24728 .51574 L
.2485 .51579 L
.24964 .51583 L
.25088 .51586 L
.25158 .51587 L
.25221 .51588 L
.25336 .51588 L
.25442 .51587 L
.25558 .51585 L
.2568 .51582 L
.25787 .51577 L
.25887 .51572 L
.26113 .51558 L
.26373 .51535 L
.26614 .51509 L
.27158 .5143 L
.27638 .51339 L
.28148 .5122 L
.2903 .5096 L
.30004 .50595 L
.31939 .49639 L
.34024 .48284 L
.38138 .44755 L
.42101 .40533 L
.45912 .36018 L
.49968 .31078 L
.53872 .2653 L
.58022 .2226 L
.60102 .20434 L
.6202 .18972 L
.64007 .17703 L
.65867 .16756 L
.67743 .16045 L
.68738 .1577 L
.69293 .15647 L
.69807 .15553 L
Mistroke
.70298 .15481 L
.7082 .15423 L
.71119 .15398 L
.71265 .15388 L
.714 .15381 L
.7152 .15375 L
.71652 .1537 L
.71785 .15366 L
.71857 .15364 L
.71924 .15363 L
.7205 .15361 L
.7212 .15361 L
.72186 .15361 L
.72305 .15362 L
.72433 .15364 L
.72546 .15367 L
.72653 .1537 L
.72895 .15381 L
.73157 .15396 L
.73396 .15415 L
.73935 .15471 L
.7441 .15537 L
.74918 .15623 L
.75831 .15821 L
.76917 .16124 L
.77902 .16461 L
.81906 .18378 L
.85758 .20909 L
.89855 .24115 L
.938 .27497 L
.97594 .30879 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0coooool2ool000So0000
1ooo001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Coo`004Oooool6ool005kooooo000Q
ooooo`03o`000?oooooooooo0<Sooooo0ooo000Kooooo`;oo`0000?o0000ooooooooool0FOooool0
027ooooo00?o0000ooooooooool0aOooool2o`000003ool00?oooooooooo01kooooo00?oo`00o`00
0?l00000FOooool0027ooooo0ol00033ooooo`;o00009_ooool3o`0005Kooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0_l0000[ooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0_ooo
ool2o`0002oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2mooooo`;oo`00<oooool2
ool0053ooooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool0=Oooool2ool0
04kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0;[ooooo0_oo000jooooo`;oo`00C?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;Wooooo00?oo`00ooooooooool0??ooool00ooo003oooooooooo`19
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000]oooool2ool0043ooooo00?oo`00o`000?ooool0B?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0]_ooool0
0ooo003oooooooooo`11ooooo`;oo`00B?ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2eooooo`03ool00?oo
oooooooo04Cooooo00?oo`00o`000?ooool0AOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0]?ooool00ooo003ooooooooo
o`16ooooo`03ool00?l0003ooooo04Cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;?ooooo00?oo`00ooooooooool0B?oo
ool00ooo003o0000o`000013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo0;7ooooo0_oo001<ooooo`03ool00?oooooo000004;ooooo000Q
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0Coooool2o`00043ooooo000Qoooo
o`03o`000?oooooooooo0:kooooo0_l0001Dooooo`03o`000?oooooooooo03gooooo000Qooooo`?o
0000[Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`00
0?oooooooooo0:cooooo00?o0000ooooooooool0Eoooool2o`0003cooooo000Qooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0iooooo`008Oooool0
0ol0003oooooooooo`2[ooooo`03o`000?oooooooooo05[ooooo0_oo000jooooo`008Oooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool0=oooool0027o
oooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Oooooo`;oo`00=oooool0027ooooo
00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`1Rooooo`03ool00?oooooooooo03Cooooo
000Qooooo`?o0000Yoooool00ooo003oooooooooo`1Tooooo`03ool00?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo0:Kooooo00?oo`00ooooooooool0I_ooool00ooo003o0000ooooo`0b
ooooo`008Oooool00ol0003oooooooooo`2Uooooo`03ool00?oooooooooo06Sooooo00?oo`00o`00
0?ooool0<Oooool0027ooooo00?o0000ooooooooool0Y?ooool00ooo003oooooooooo`1Zooooo`03
ool00?l0003ooooo033ooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
K?ooool00ooo003o0000ooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo06kooooo00?oo`00o`000?ooool0;_ooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1`ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo
0:3ooooo00?oo`00ooooooooool0Loooool00ol0003oooooooooo`0[ooooo`008Oooool3o`0009oo
oooo00?oo`00ooooooooool0MOooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool01oooool00ooo003oooooooooo`0aoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0a
ooooo`03o`000?oooooooooo00Wooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<Oooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Sooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`0cooooo`;o00002Oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0m
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`;oo`002Oooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool01oooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`05
o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000Gooooo00?o0000oooo
ooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_ooool02Ooo003ooooooooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?l0
003ooooo08Oooooo0_oo000Qooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?oooooo
oooo08Wooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0U_ooool00ooo
003oooooooooo`2;ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Go
oooo00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0Booooo`;o00000_ooool2o`0000Co
oooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0Soooool00ooo003ooooo
ooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooWOl000000ooo003o
0000o`00002Ao`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03
o`000?oooooo0000097ooooo00?oo`00ooooooooool0Y_ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qooooo`04o`000?oo
ooooooooo`0008kooooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000oooooooooooooooo
o`00002<ooooo`03ool00?oooooooooo0;?ooooo000Qooooo`05o`000?ooooooooooooooool00000
Roooool00ooo003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00ooooooooool0Qooo
ool00ol0003oooooooooo`2eooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?l0003o
oooo08Kooooo00?o0000ooooooooool0]_ooool0027ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`25ooooo`03o`000?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool0Poooool00ol0003oooooooooo`2gooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0027ooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`20ooooo`03o`000?oooooooooo0;Wooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0O_ooool00ol0003oooooooooo`2j
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0O?ooool00ol0003oooooooooo`2koooo
o`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07_ooooo0_oo002mooooo`00
8Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo07[ooooo00?oo`00ooooooooool0
_?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1hooooo`03ool00?oo
oooooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?ooool0Moooool0
0ooo003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003ooooo
07Gooooo00?oo`00ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1cooooo`03o`000?oo003ooooo0<3ooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0LOooool00ol0003oo`00ooooo`31ooooo`008Oooool3o`0000gooooo00?o
0000ooooooooool0Koooool00ol0003oo`00ooooo`32ooooo`008Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0`_ooool0027ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo003ooooo0<?ooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oo`00ooooo`34ooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0
aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
003ooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0IOooool0
0ol0003oooooooooo`37ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0I?ooool00ol0
003oooooooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?o
oooo00?o0000ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooo
ooooo`1Qooooo`03o`000?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0Goooool00ol0003oooooooooo`3:ooooo`008Oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool0boooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool05oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo0<cooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0cOoo
ool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
000Hooooo`03ool00?oooooooooo05Sooooo00?o0000ool00?ooool0c_ooool000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06Ooo
ool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo0<kooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
6_ooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo0<oooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo
00?oo`00ooooooooool0Doooool00ooo003oooooooooo`3@ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03ool0
0?oooooooooo057ooooo00?oo`00ooooooooool0dOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04oooooo
00?oo`00ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1=ooooo`03ool00?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0B_ooool2ool00=Kooooo000Qooooo`?o00008?ooool00ol0003oooooooooo`18oooo
o`03ool00?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0A_ooool00ooo003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo04Cooooo00?oo`00ooooooooool0f?ooool0027ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0=Wooooo000Qooooo`03o`000?oooooo
oooo02Cooooo00?oo`00ooooooooool0?oooool2o`000=cooooo000Qooooo`03o`000?oooooooooo
02Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`3Looooo`008Oooool00ol0003o
ooooooooo`0Vooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool0gOooool0027ooooo
0ol0000Wooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool0g_ooool0027ooooo00?o
0000ooooooooool0:?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo0=oooooo000Q
ooooo`03o`000?oooooooooo02Wooooo0_oo000fooooo`03ool00?oooooooooo0>3ooooo000Qoooo
o`03o`000?oooooooooo02_ooooo00?oo`00ooooooooool0<Oooool2ool00>?ooooo000Qooooo`03
o`000?oooooooooo02cooooo0_oo000`ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`00
0?oooooooooo02kooooo00?oo`00ooooooooool0:oooool2ool00>Kooooo000Qooooo`03o`000?oo
oooooooo02oooooo0_oo000Zooooo`03ool00?oooooooooo0>Kooooo000Qooooo`03o`000?oooooo
oooo037ooooo0_l0000Vooooo`;oo`00jOooool0027ooooo0ol0000cooooo`;o00008_ooool2ool0
0>_ooooo000Qooooo`03o`000?oooooooooo03Gooooo0_l0000Nooooo`;oo`00kOooool0027ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`000?oo003ooooo0>kooooo
000Qooooo`03o`000?oooooooooo03Sooooo0_l00002ool001Cooooo0ol0003aooooo`008Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oo003oo`0000;oo`003?ooool4o`000?Cooooo000Qoooo
o`03o`000?oooooooooo043ooooo2_oo0002o`000?Sooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomV
IVKooooo01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgo
oooo00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7
QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo
1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Q
oooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool0
2oooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooM
gMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@
omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0Loooool007_ooooo
00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo
00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMg
Molb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o0000
3Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool0
1Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?oo
ool04oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool0
0ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04
ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOo
EEEE01Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnH
V9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo
00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`04ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35001 L
.10458 .38865 L
.12507 .40366 L
.14415 .41508 L
.16254 .42363 L
.17277 .42733 L
.18221 .43009 L
.19242 .43236 L
.19781 .43327 L
.20351 .43401 L
.2059 .43426 L
.20846 .43448 L
.21068 .43464 L
.2131 .43478 L
.21456 .43484 L
.21592 .43488 L
.21722 .43492 L
.21795 .43493 L
.21861 .43494 L
.21986 .43495 L
.22056 .43495 L
.22121 .43495 L
.2224 .43494 L
.22365 .43492 L
.22487 .43489 L
.2262 .43485 L
.22861 .43475 L
.23096 .43461 L
.23313 .43446 L
.23806 .434 L
.24329 .43336 L
.25201 .43195 L
.26163 .42993 L
.28097 .42447 L
.30183 .41681 L
.34297 .39779 L
.38259 .3771 L
.4207 .35768 L
.46126 .34006 L
.48 .33354 L
.50031 .32784 L
.51141 .32537 L
.52165 .3235 L
.53144 .32208 L
.53686 .32145 L
.5418 .32097 L
.54632 .32061 L
.55124 .3203 L
.55394 .32017 L
Mistroke
.55644 .32007 L
.55883 .31999 L
.56016 .31996 L
.56138 .31993 L
.56251 .31991 L
.56376 .3199 L
.56501 .31989 L
.56633 .31988 L
.5675 .31988 L
.56874 .31989 L
.56992 .3199 L
.57099 .31991 L
.5721 .31992 L
.57313 .31994 L
.57546 .32 L
.57751 .32006 L
.57969 .32014 L
.5846 .32038 L
.58909 .32065 L
.5992 .32148 L
.60812 .32243 L
.61749 .32361 L
.65566 .32995 L
.69627 .3377 L
.71504 .34098 L
.73537 .34398 L
.7465 .3453 L
.75675 .34628 L
.76655 .34698 L
.77149 .34724 L
.77409 .34735 L
.77692 .34745 L
.77963 .34752 L
.78083 .34755 L
.78215 .34758 L
.7833 .3476 L
.78455 .34761 L
.78587 .34762 L
.7871 .34763 L
.78823 .34763 L
.78947 .34763 L
.79075 .34763 L
.79195 .34762 L
.79308 .34761 L
.7941 .34759 L
.7964 .34755 L
.79908 .34748 L
.80156 .3474 L
.80715 .34715 L
.81208 .34686 L
Mistroke
.81731 .34648 L
.82673 .3456 L
.83686 .34439 L
.85516 .34154 L
.89641 .33244 L
.93614 .3213 L
.97435 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000:?l0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o
0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`000?oo003oo`00o`0001?ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l000000ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo1Ol00003ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo
<S8b1Oooool0027ooooo00Co0000ooooool0003oo`00oooooolKooooo`Co00006oooool2o`0000;o
oooo0_l00004ooooo`008Oooool01Ol0003oooooooooool0003oo`0009Wooooo1ol0000?ool000Ko
0000HOooool00ol0003oo`00ool0000Yooooo`008Oooool01_l0003ooooooooooooooooo0000ool0
097ooooo1?oo0003o`0001cooooo1?l0001Jooooo`04o`000?oo003oo`00ool002_ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0S?ooool3ool002Oooooo1Ooo0002o`00
053ooooo00Co0000ool00?oo003oo`00;_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ooooo`28ooooo`?oo`00;oooool8ool004Oooooo00Co0000ool00?oo003oo`00<Oooool0
027ooooo0ol00004ooooo`03o`000?oo003ooooo08?ooooo1?oo000jooooo`?oo`000ol0000loooo
o`03o`000?oo003oo`0000?oo`00=?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
o`00ooooo`20ooooo`;oo`0000?o0000ooooooooool0@Oooool6o`00033ooooo1_l0000jooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo07cooooo0ol0001<ooooo`03o`00
0?oo003oo`0000?oo`009?ooool6o`00043ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
0000ool00?ooool0NOooool2o`0005Gooooo1Ooo0003o`0001Oooooo00?o0000ool00?oo00001_oo
0012ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Kooooo0_l0001L
ooooo`Ooo`002_l0000:ool004[ooooo000Qooooo`03o`000?oooooooooo00Wooooo0_l0001coooo
o`?o0000`oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1^ooooo`03
o`000?oo003oo`000<Gooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`1[ooooo`?oo`00
aoooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Xooooo`;oo`00b_oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Uooooo`;oo`00c?ooool0
027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Qooooo`?oo`00c_ooool0027o
oooo00?o0000ooooooooool04?ooool2ool005oooooo0_oo00000ol0003oooooooooo`3>ooooo`00
8Oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo05_ooooo00?oo`00o`000?ooool0
dOooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`1Hooooo`;o0000e?oo
ool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1Eooooo`;o0000e_ooool0
027ooooo0ol0000Eooooo`03ool00?oooooooooo05;ooooo0_l0003Hooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo04oooooo0_l0003Jooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`;oo`00C?ooool2ool00003o`000?oooooooooo0=[ooooo000Qooooo`03o`000?oo
oooooooo01Wooooo00?oo`00ooooooooool0Aoooool2ool00003o`000?oooooooooo0=cooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0AOooool00ooo003o0000ooooo`3O
ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo04;ooooo0_oo003Roooo
o`008Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo03oooooo0_oo003Tooooo`00
8Oooool3o`0001gooooo0_l0000looooo`?oo`00i_ooool0027ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0gooooo`;oo`0000?o0000ooooooooool0i_ooool0027ooooo00?o0000
ooooooooool08?ooool2o`0003Gooooo00?o0000ool00?ooool0j_ooool0027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0`ooooo`;o0000kOooool0027ooooo00?o0000oooooooo
ool08oooool2o`0000;oo`00;?ooool2o`000>oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
02Kooooo00?o0000ool00?oo0000:?ooool2o`000?7ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Yoooo
o`?oo`008Oooool2ool000;o0000loooool000Oooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00;ooooo0ol0000[ooooo`04o`000?oo003oo`00ool001_ooooo0ooo0002
o`000?Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo02cooooo0ol00003ool001Gooooo0ooo00000ol0003oooooooooo`3g
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo03;ooooo0ooo000;ooooo`Ooo`00oOooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?oo
ool;o`000003ool00?l0003o000000;o0000ooooool1ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`00
01?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM
0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooo
oooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00Co
EEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool0
0_ooool00on7QhOoIVIVooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo1?l000000ol@413oooooooooo`1hooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo07[ooooo
001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So
8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0N_ooool007kooooo00CoEEEEojVY
ZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Ooo
ool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02ooo
ool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0N_ooool007kooooo00?o
gMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_oo
ool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool0
1Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMg
MomEEEGooooo01;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo07[o
oooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@
onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo07[ooooo002Fooooo`03o`000?oooooo
oooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7o
c<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omE
EEGoIVIVo`00001looooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .31681 L
.06244 .32413 L
.08255 .33017 L
.09409 .33289 L
.10458 .33484 L
.1094 .33556 L
.11464 .33623 L
.11917 .3367 L
.12415 .3371 L
.12688 .33727 L
.12944 .3374 L
.13213 .3375 L
.13365 .33755 L
.13504 .33758 L
.13632 .3376 L
.1375 .33761 L
.1388 .33761 L
.13953 .33761 L
.14019 .33761 L
.1414 .3376 L
.14271 .33758 L
.14395 .33756 L
.14509 .33753 L
.14755 .33745 L
.14979 .33736 L
.15482 .33706 L
.15949 .3367 L
.16391 .33627 L
.17381 .33504 L
.18458 .33331 L
.22536 .32412 L
.26462 .31399 L
.28432 .30961 L
.30238 .30655 L
.3118 .30542 L
.31654 .30499 L
.32172 .30464 L
.32446 .3045 L
.32695 .30441 L
.32832 .30437 L
.32905 .30435 L
.32982 .30434 L
.33049 .30433 L
.33123 .30432 L
.33253 .30431 L
.33383 .30431 L
.33503 .30432 L
.33569 .30433 L
.33641 .30434 L
Mistroke
.33772 .30437 L
.33894 .3044 L
.34024 .30444 L
.34258 .30454 L
.34519 .30469 L
.34795 .30489 L
.35289 .30535 L
.3582 .30601 L
.36403 .30691 L
.37447 .30904 L
.38421 .31163 L
.4046 .31892 L
.42317 .32774 L
.46307 .35306 L
.50145 .38369 L
.54229 .41941 L
.58161 .45266 L
.61941 .47973 L
.63879 .49069 L
.64877 .49541 L
.65966 .49979 L
.66938 .50298 L
.67974 .50562 L
.68548 .50673 L
.69069 .50753 L
.6932 .50784 L
.69592 .50812 L
.6983 .50831 L
.70086 .50848 L
.70217 .50854 L
.70342 .50859 L
.70454 .50863 L
.70576 .50865 L
.70692 .50867 L
.70814 .50867 L
.70919 .50867 L
.71035 .50865 L
.711 .50864 L
.71169 .50862 L
.71293 .50858 L
.71426 .50852 L
.71572 .50844 L
.71834 .50826 L
.72077 .50805 L
.7261 .50742 L
.73095 .50667 L
.74183 .50434 L
.75179 .50145 L
.76099 .49817 L
.78178 .48867 L
Mistroke
.82115 .46366 L
.859 .43252 L
.89931 .39352 L
.9381 .35181 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Fooooo`[oo`0000?o0000
ooooooooool00_ooool3ool00=;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oo
oomKo`0000Goo`004_l00006ool00<7o00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Ooo
ool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
oooo1_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool4o`0000?o
o`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04
o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`Co00002oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00Go0000ool00?oo003oo`00o`00000>
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool00oooool3ool003kooooo0ooo0002
o`0002[ooooo00?o0000ool00?ooool0[oooool00ol0003oooooooooo`0Booooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo00Kooooo0ooo000fooooo`Goo`0000?o0000oooo
ooooool0;_ooool2o`000:gooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool02Oooool3ool002kooooo1Ooo0002o`0003Kooooo0_l0002Zooooo`03o`000?oooooooooo01ko
oooo000Qooooo`03o`000?oooooooooo00cooooo0ooo000Xooooo`?oo`000ol0000looooo`;o0000
Yoooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0?ooooo`?oo`0000?o
0000ooooooooool08Oooool3o`0004;ooooo0_l0002Tooooo`03ool00?oooooooooo023ooooo000Q
ooooo`?o00004_ooool00ooo003o0000o`000002o`0001_ooooo1?l00017ooooo`;oo`00XOooool0
0ol0003oo`00ooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Gooooo`Go000000?oooooool0
0?oo00003_oo0005o`0004cooooo00?o0000ool00?oo0000W_ooool00ol0003oo`00ooooo`0Roooo
o`008Oooool00ol0003oooooooooo`0Looooo`oo0000EOooool00ol0003oo`00ooooo`2Kooooo`03
o`000?oo003ooooo02?ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo002Iooooo`03o`00
0?oo003ooooo02Cooooo000Qooooo`03o`000?oooooooooo08?ooooo00?o0000ool00?oo0000U_oo
ool00ol0003oo`00ooooo`0Uooooo`008Oooool00ol0003oooooooooo`25ooooo`03o`000?oo003o
oooo09?ooooo00?o0000ool00?ooool09_ooool0027ooooo00?o0000ooooooooool0Qoooool00ooo
003oooooooooo`2Aooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000R?ooool00ooo003o
ooooooooo`2?ooooo`03ool00?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo08Wooooo
00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0Xooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`03ool00?oooooooooo08_ooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000
ooooooooool0Roooool2o`0008[ooooo00?oo`00ooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02_ooooo000Qooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0/ooooo`00
8Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
;Oooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo02kooooo000Qooooo`?o0000TOooool2o`0007oooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool0Toooool2ool007cooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0U?ooool00ol0003oo`00ooooo`1iooooo`03o`000?oooooooooo037o
oooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0Moooool00ooo003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?oooooooooo07Cooooo0_oo
000dooooo`008Oooool00ol0003oooooooooo`2Hooooo`03ool00?oooooooooo07;ooooo00?oo`00
ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0VOooool2ool0077ooooo00?oo`00oooo
ooooool0=Oooool0027ooooo0ol0002Jooooo`03o`000?oo003ooooo06kooooo00?oo`00oooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool0W?ooool00ooo003oooooooooo`1[ooooo`03ool0
0?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?oo`00ooooooooool0JOoo
ool00ooo003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`2Nooooo`03ool00?l0003o
oooo06Oooooo00?oo`00ooooooooool0>Oooool0027ooooo00?o0000ooooooooool0Woooool00ooo
003o0000ooooo`1Uooooo`03ool00?oooooooooo03[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0X_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo03cooooo0007oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Xoooool0
0ol0003oooooooooo`1Nooooo`03ool00?oooooooooo03gooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0nooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool0FOooool2o`00047ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`11ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`;oo`00E_ooool00ol0003ooooooooo
o`12ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ool00?ooool0D_ooool2o`0004Gooooo000Qooooo`03o`000?oooooo
oooo0:Wooooo00?o0000ool00?ooool0D?ooool00ol0003oooooooooo`15ooooo`008Oooool00ol0
003oooooooooo`2Zooooo`03o`000?oo003ooooo04kooooo0_oo0017ooooo`008Oooool3o`000:co
oooo0_oo001<ooooo`03ool00?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo0:gooooo
00?o0000ool00?ooool0B?ooool00ol0003oo`00ooooo`19ooooo`008Oooool00ol0003ooooooooo
o`2^ooooo`03o`000?oo003ooooo04Kooooo00?o0000ool00?ooool0B_ooool0027ooooo00?o0000
ooooooooool0[oooool00ol0003oo`00ooooo`14ooooo`03o`000?oo003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0;3ooooo00?o0000ool00?ooool0@Oooool00ol0003oo`00ool0001=oooo
o`008Oooool00ol0003oooooooooo`2booooo`03ool00?l0003ooooo03kooooo0_oo001?ooooo`00
8Oooool00ol0003oooooooooo`2cooooo`03ool00?l0003ooooo03cooooo00?oo`00ooooooooool0
Coooool0027ooooo0ol0002eooooo`;o0000>Oooool2ool005;ooooo000Qooooo`03o`000?oooooo
oooo0;Oooooo0_l0000fooooo`03ool00?l0003ooooo05;ooooo000Qooooo`03o`000?oooooooooo
0;Wooooo00?o0000ooooooooool0<_ooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo0;[o
oooo0_l0000`ooooo`;o0000E_ooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooo
ooooo`0[ooooo`;o0000F?ooool0027ooooo00?o0000ooooooooool0_Oooool2ool00003o`000?oo
oooooooo02Kooooo0_l0001Jooooo`008Oooool00ol0003oooooooooo`2oooooo`;oo`000_l0000R
ooooo`?o0000G?ooool0027ooooo00?o0000ooooooooool0`Oooool3ool000;o00007Oooool3ool0
05kooooo000Qooooo`?o0000a?ooool3ool000;o00005oooool3ool0067ooooo000Qooooo`03o`00
0?oooooooooo0<Oooooo0ooo00000ol0003oooooooooo`0?ooooo`Coo`0000?o0000ooooooooool0
HOooool0027ooooo00?o0000ooooooooool0b_ooool2ool000co00001?oo001Xooooo`008Oooool0
0ol0003oooooooooo`3Fooooo`;oo`00K?ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKo
oooo01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo
00Kooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo
0000oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o
0000odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol0
0009ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000?o<S8bomgMgOooool0M?ooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7
QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo
00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6
o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^
oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo
00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Co
oooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ
8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEE
EOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgM
gOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo
00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooo
oiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooo
oooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o
8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28797 L
.10458 .26394 L
.14415 .24225 L
.18221 .22399 L
.20178 .2166 L
.21267 .21334 L
.22272 .21098 L
.22768 .21007 L
.23293 .20929 L
.23548 .20899 L
.23821 .20873 L
.23978 .2086 L
.24121 .2085 L
.24257 .20842 L
.24402 .20836 L
.24471 .20833 L
.24536 .20831 L
.24658 .20828 L
.24772 .20827 L
.24896 .20826 L
.24961 .20827 L
.25032 .20827 L
.25107 .20829 L
.25177 .2083 L
.25301 .20834 L
.25435 .2084 L
.25698 .20856 L
.25948 .20876 L
.26416 .2093 L
.26875 .21003 L
.27382 .21107 L
.28407 .21392 L
.29357 .21749 L
.30249 .22166 L
.32267 .23405 L
.34118 .24891 L
.3808 .2908 L
.41891 .34077 L
.45947 .39873 L
.49852 .45311 L
.54002 .50332 L
.56082 .52403 L
.58 .53999 L
.59868 .55246 L
.60822 .55763 L
.61846 .56226 L
.62869 .56595 L
.63804 .5685 L
.64253 .56946 L
Mistroke
.64743 .5703 L
.65206 .57091 L
.65415 .57112 L
.65635 .57131 L
.65762 .57139 L
.65901 .57147 L
.66028 .57153 L
.66144 .57158 L
.6621 .5716 L
.66282 .57161 L
.66358 .57163 L
.66429 .57164 L
.66496 .57164 L
.66567 .57164 L
.66695 .57163 L
.66812 .57161 L
.66939 .57157 L
.67059 .57153 L
.67169 .57148 L
.67424 .57132 L
.67691 .5711 L
.68153 .57058 L
.68581 .56996 L
.69553 .56802 L
.70608 .56512 L
.71603 .56167 L
.73463 .55341 L
.77315 .52954 L
.81412 .49542 L
.85358 .45557 L
.89151 .41247 L
.93191 .36376 L
.97078 .31582 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0?Oooool>ool00?Wooooo000Qooooo`03o`000?oooooooooo
03_ooooo0_oo000=o`000003ool00?oooooooooo0?Oooooo000Qooooo`?o0000=oooool4o`00013o
oooo1Ol0003dooooo`008Oooool00ol0003oooooooooo`0dooooo`?o00006Oooool00ol0003ooooo
ooooo`3aooooo`008Oooool00ol0003oooooooooo`0`ooooo`;oo`000_l0000Mooooo`?o000000?o
ooooool00?oo0000kOooool0027ooooo00?o0000ooooooooool0;_ooool2ool00003o`000?oooooo
oooo027ooooo0ol000000ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0/oooo
o`;oo`00:Oooool00ol0003oo`00ool0003Zooooo`008Oooool00ol0003oooooooooo`0Zooooo`;o
o`00;?ooool2o`000003ool00?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo02Sooooo
0_oo000`ooooo`03o`000?oo003ooooo0>Oooooo000Qooooo`?o00009_ooool2ool003?ooooo00?o
0000ool00?ooool0i_ooool0027ooooo00?o0000ooooooooool09?ooool2ool003Oooooo00?oo`00
ooooooooool0i?ooool0027ooooo00?o0000ooooooooool08_ooool2ool003[ooooo00?oo`00o`00
0?ooool0hoooool0027ooooo00?o0000ooooooooool08?ooool2o`0003gooooo00?oo`00o`000?oo
ool0h_ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`;oo`00
h_ooool0027ooooo00?o0000ooooooooool07Oooool2o`0004?ooooo00?o0000ooooooooool0gooo
ool0027ooooo00?o0000ooooooooool06oooool2o`0004Gooooo00?o0000ooooooooool0goooool0
027ooooo00?o0000ooooooooool06?ooool2ool00003o`000?oooooooooo04Kooooo00?o0000oooo
ooooool0g_ooool0027ooooo0ol0000Fooooo`;oo`000_l0001:ooooo`03o`000?oooooooooo0=go
oooo000Qooooo`03o`000?oooooooooo01Cooooo0_oo0002o`0002Gooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo00?o0000oooo
ooooool0:?ooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0Cooooo`03ool00?l0003o000002Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0l
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool04Oooool2
ool00003o`000?oooooooooo02Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0?ooooo`;oo`0000?o0000ooooooooool0:Oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05?ooool00ol0003oo`00ooooo`0Wooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ
8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0;?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`00
0?oo003ooooo02Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`;oo`00;oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool06?ooool00ol0003oo`00ooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000
2_ooool00ol0003oo`00ooooo`0`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oo003ooooo02Gooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Koooo
o`008Oooool00ol0003oooooooooo`08ooooo`;o0000<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l0000Iooooo`03o`000?oo003ooooo02;ooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo0_l0001Tooooo`03o`000?oo003ooooo0=Gooooo000Qooooo`03
o`000?oooooooooo00Cooooo0_l0001Wooooo`03ool00?oooooooooo0=Cooooo000Qooooo`03o`00
0?oooooooooo00;ooooo0_l0001Yooooo`03o`000?oo003ooooo0=Cooooo000Qooooo`04o`000?oo
ooooooooo`0000;oo`00Joooool00ol0003oo`00ooooo`39ooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`04o`000?oo003oo`00ool006kooooo00?o0000ool00?ooool0b?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo000000?oo`00o`000?l00000LOl000000ooo003o
0000o`00002co`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
003oooooo`00000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ooo
003o0000ooooo`0Booooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool01?l0003oooooool00?l0000>ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ooo003o0000o`00000Cooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0/?ooool0
0ooo003oooooooooo`0Booooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo0:cooooo00?oo`00ooooooooool07_ooool0027ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2[ooooo`03ool00?l0003ooooo01oooooo
000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Z_ooool00ooo003ooooooooo
o`0Oooooo`008Oooool3o`0007Kooooo00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`0P
ooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo0:Kooooo00?oo`00oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`2Vooooo`03
ool00?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0
Y?ooool00ooo003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oo
oooooooo0:;ooooo00?oo`00ooooooooool08oooool0027ooooo00?o0000ooooooooool0N_ooool0
0ooo003oooooooooo`2Pooooo`03ool00?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo
07[ooooo00?o0000ool00?ooool0Woooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0007_o
oooo00?oo`00ooooooooool0W_ooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003ooooo
ooooo`1looooo`03ool00?oooooooooo09cooooo00?o0000ooooooooool09_ooool0027ooooo00?o
0000ooooooooool0O?ooool00ol0003oo`00ooooo`2Kooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo07gooooo00?o0000ool00?ooool0VOooool00ol0003oooooooooo`0X
ooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?oooooooooo09Oooooo00?o0000oooo
ooooool0:Oooool0027ooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`2Eooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ool00?ooool0
U?ooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`20ooooo`03ool00?oo
oooooooo09;ooooo00?o0000ool00?ooool0;?ooool0027ooooo0ol00021ooooo`03ool00?oooooo
oooo097ooooo00?oo`00ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0POooool00ol0
003oo`00ooooo`2@ooooo`03ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0S_ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooooooo08cooooo00?oo`00ooooooooool0;oooool0027ooooo00?o
0000ooooooooool0Q?ooool00ol0003oooooooooo`2:ooooo`03ool00?oooooooooo033ooooo000Q
ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`0a
ooooo`008Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo08Oooooo00?o0000ool0
0?ooool0<_ooool0027ooooo0ol00026ooooo`03o`000?oooooooooo08Kooooo00?oo`00oooooooo
ool0<_ooool0027ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`25ooooo`03ool0
0?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0Pooo
ool00ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oo003o
oooo087ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0ROooool00ooo
003oooooooooo`1oooooo`03o`000?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo08Wooooo00?o0000ool00?ooool0Ooooool00ol0003oooooooooo`0fooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0R_ooool00ol0003oo`00ooooo`1mooooo`03o`000?oooooooooo03Oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Roooool0
0ol0003oo`00ooooo`1kooooo`03o`000?oooooooooo03Sooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08_ooooo00?o0000
ool00?ooool0N_ooool00ol0003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08cooooo00?o
0000ool00?ooool0N?ooool00ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`03o`000?oo
003ooooo07Oooooo00?o0000ooooooooool0>_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool00ol0003oo`00oooo
o`1dooooo`03ool00?l0003ooooo03cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0S_ooool00ol0003oo`00ooooo`1cooooo`03ool00?l0
003ooooo03gooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ool00?ooool0LOooool0
0ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo003ooooo
06oooooo00?oo`00o`000?ooool0?oooool0027ooooo0ol0002@ooooo`03o`000?ooooooo`0006ko
oooo00?oo`00o`000?ooool0@?ooool0027ooooo00?o0000ooooooooool0TOooool00ol0003ooooo
ooooo`1/ooooo`03ool00?l0003ooooo047ooooo000Qooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool0Joooool00ooo003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool0@_ooool0027ooooo00?o0000oooo
ooooool0Toooool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo04?ooooo000Qooooo`03
o`000?oooooooooo09Cooooo00?o0000ooooooooool0I_ooool00ooo003oooooooooo`14ooooo`00
8Oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo06Cooooo00?oo`00ooooooooool0
AOooool0027ooooo0ol0002Fooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0A_oo
ool0027ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`1Pooooo`03ool00?oooooo
oooo04Oooooo000Qooooo`03o`000?oooooooooo09Sooooo00?o0000ool00?ooool0G_ooool00ol0
003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`2Iooooo`03ool00?oooooooooo05co
oooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool0V_ooool00ooo003ooooo
ooooo`1Iooooo`;o0000C?ooool0027ooooo00?o0000ooooooooool0V_ooool00ol0003oo`00oooo
o`1Hooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo09_ooooo00?o0000
ool00?ooool0E_ooool00ol0003oooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`2Loooo
o`03o`000?oo003ooooo05Cooooo00?o0000ooooooooool0C_ooool0027ooooo0ol0002Mooooo`03
o`000?oo003ooooo057ooooo0_oo001Aooooo`008Oooool00ol0003oooooooooo`2Nooooo`03o`00
0?oo003ooooo04oooooo00?oo`00o`000?ooool0DOooool0027ooooo00?o0000ooooooooool0Wooo
ool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo05;ooooo000Qooooo`03o`000?oooooo
oooo0:3ooooo00?oo`00o`000?ooool0Boooool00ooo003oooooooooo`1Cooooo`008Oooool00ol0
003oooooooooo`2Qooooo`03ool00?l0003ooooo04Sooooo0_oo001Fooooo`008Oooool00ol0003o
ooooooooo`2Rooooo`03ool00?l0003ooooo04Kooooo00?oo`00o`000?ooool0E_ooool0027ooooo
00?o0000ooooooooool0Xoooool00ooo003o0000ooooo`14ooooo`03ool00?l0003ooooo05Oooooo
000Qooooo`?o0000YOooool00ol0003oooooooooo`11ooooo`03ool00?l0003ooooo05Sooooo000Q
ooooo`03o`000?oooooooooo0:Kooooo0_l00010ooooo`03ool00?oooooooooo05Wooooo000Qoooo
o`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0>oooool00ol0003oo`00ooooo`1Koooo
o`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo03Wooooo00?o0000ool00?oo
ool0G?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0fooooo`;o0000
Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0:_ooooo0_oo00000ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo063ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool2ool0
033ooooo0_l0001Sooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000[oooool2ool002go
oooo00?o0000ooooooooool0Hoooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2aooooo`;oo`00:Oooool2ool006Kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0/_ooool00ol0003oo`00ooooo`0Uooooo`;oo`00J?ooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2dooooo`?oo`008?ooool3ool006[ooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]Oooool2o`0000;oo`006oooool3ool0
0003o`000?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo0;Sooooo00Co0000ool00?l0
003o00005Oooool3ool00003o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooooooo0;co
oooo0ol0000?ooooo`?oo`0000?o0000ooooooooool0L?ooool0027ooooo0ol0002oooooo`Goo`00
1?ooool8o`0007Cooooo000Qooooo`03o`000?oooooooooo0<Cooooo1Ol0001kooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027
ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^
oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o
0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool0
1oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[o
A4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0007_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03
ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oM
gMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01koooo
o`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnY
ZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Go
oooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_o
oooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03
omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Ko
oooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`1jooooo`00Ooooool00onHV9SoMgMgooooo`02oooo
o`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo
00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omg
MgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`1i
ooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@
4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@07_ooooo002Fooooo`03
o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@
o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<07_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .24997 L
.10458 .19598 L
.12507 .17365 L
.14415 .15624 L
.16254 .14335 L
.17284 .13805 L
.18221 .13451 L
.18704 .13319 L
.18969 .13261 L
.19216 .13217 L
.19445 .13184 L
.19654 .1316 L
.19773 .1315 L
.19886 .13142 L
.20005 .13136 L
.20135 .13132 L
.20203 .13131 L
.20276 .13131 L
.20345 .13131 L
.20409 .13132 L
.2053 .13136 L
.20657 .13142 L
.20794 .13151 L
.20922 .13163 L
.21213 .13198 L
.21466 .13239 L
.21696 .13285 L
.22214 .13418 L
.22694 .13578 L
.23205 .13786 L
.24122 .14257 L
.26198 .15762 L
.28145 .17678 L
.29973 .19856 L
.33842 .25355 L
.37956 .31854 L
.41919 .37995 L
.45729 .4323 L
.47854 .45722 L
.49785 .47679 L
.51817 .49402 L
.5369 .50683 L
.55608 .5169 L
.56619 .521 L
.57688 .52446 L
.58632 .52679 L
.59152 .5278 L
.59646 .52857 L
.60103 .52913 L
Mistroke
.60345 .52937 L
.60603 .52958 L
.60841 .52973 L
.61056 .52984 L
.6116 .52988 L
.61273 .52991 L
.61379 .52994 L
.61477 .52996 L
.61604 .52997 L
.61724 .52997 L
.61831 .52997 L
.61948 .52995 L
.62076 .52993 L
.62211 .52989 L
.62453 .52979 L
.62676 .52967 L
.62886 .52953 L
.63363 .52911 L
.63883 .52849 L
.64359 .5278 L
.65431 .52578 L
.67327 .52075 L
.69399 .51336 L
.7346 .49404 L
.7737 .47061 L
.81525 .44178 L
.85528 .41112 L
.8938 .3797 L
.93477 .34493 L
.97422 .31073 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`0fooooo`Goo`00ooooool:ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_o
00000ooo003oooooo`Oooooo000Qooooo`03o`000?oooooooooo02_ooooo0_oo00000ooooooo0000
o`00000;ooooo`?o00000ooo003oooooo`Cooooo000Qooooo`?o0000:_ooool01?oo003o0000o`00
0?l0000@ooooo`?o000000?oo`00ooooooooool0ooooool1ooooo`008Oooool00ol0003ooooooooo
o`0Xooooo`;oo`0000?o0000ooooooooool05?ooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`007Oooool00ooo003o0000ooooo`3moooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo01oooooo00?o0000oooooooo
ool0noooool0027ooooo00?o0000ooooooooool08_ooool2ool002?ooooo00?o0000ooooooooool0
n_ooool0027ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Tooooo`03o`000?oo
oooooooo0?Wooooo000Qooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool09_ooool0
0ol0003oooooooooo`3hooooo`008Oooool3o`0001oooooo00?oo`00ooooooooool0:?ooool00ol0
003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oo003ooooo0?Gooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool00ol0003oo`00ooooo`3dooooo`008Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0loooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo0?;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo00?oo`00ooooooooool0lOoo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0001Wooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3`ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Gooooo`03ool00?l0003ooooo03Sooooo00?oo`00ooooooooool0koooool000Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool0k_ooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ooo003oooooooooo`0jooooo`03ool00?oooooooooo0>gooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3]ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
?Oooool00ooo003oooooooooo`3/ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo03kooooo00?oo`00o`000?ooool0k?ooool0027ooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`10ooooo`03ool00?oooooooooo0>_ooooo000Qooooo`?o00004_ooool00ooo
003oooooooooo`12ooooo`03o`000?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo01;o
oooo00?oo`00ooooooooool0@oooool00ol0003oooooooooo`3Yooooo`008Oooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo04Gooooo00?o0000ooooooooool0j?ooool0027ooooo00?o
0000ooooooooool04?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo0>Sooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0B?ooool00ol0003oooooooooo`3W
ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo04[ooooo00?o0000oooo
ooooool0i_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo0>Kooooo000Qooooo`?o00003Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C_oo
ool00ooo003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04oooooo00?oo`00o`000?ooool0i?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Aooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`3Rooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0hOooool0027ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0>7ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`3P
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`3Poooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00oooooo00?oo`00
ooooooooool0:oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo03Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0?ooooo`03ool00?oooooooooo02cooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`0eooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`0>ooooo`03ool00?oooooooooo02cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0fooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0@ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h0
6oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oo`00ooooo`0gooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo00?oo`00oooooooo
ool0:oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0=oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`0hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400K
ooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00005?ooool00ol0003oooooooooo`0Wooooo`03oeEEEOmVIVKo000003oooooo
00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`00
8Oooool01Ol0003oooooooooooooooooo`0006Gooooo00?o0000ooooooooool0f_ooool0027ooooo
00Go0000oooooooooooo0000ool0001Uooooo`03o`000?oooooooooo0=[ooooo000Qooooo`04o`00
0?oooooo0000ool006Oooooo00?o0000ooooooooool0fOooool0027ooooo00?o0000oooooooo0000
J?ooool00ol0003oooooooooo`3?ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000J_oo
ool00ol0003oooooooooo`3>ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo
ool0000bo`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ool00?ooool0
1oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool00ol0003oo`00o`00000Cooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`00
0?oo003oooooo`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool0Joooool00ol0003oo`00ooooo`2eooooo`03o`000?oo003ooooo01Cooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`2cooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo06cooooo00?o0000ool00?ooool0/_oo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo003o
oooo0;3ooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool0K_ooool00ooo
003oooooooooo`2^ooooo`03o`000?oooooooooo02;ooooo000Qooooo`?o0000K_ooool00ol0003o
o`00ooooo`2]ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo06oooooo
00?o0000ool00?ooool0Zoooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000
ooooooooool0L?ooool00ol0003oo`00ooooo`2Xooooo`03ool00?oooooooooo02Kooooo000Qoooo
o`03o`000?oooooooooo077ooooo00?oo`00ooooooooool0YOooool2ool002Wooooo000Qooooo`03
o`000?oooooooooo07;ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`0Yooooo`00
8Oooool00ol0003oooooooooo`1cooooo`03ool00?oooooooooo0:7ooooo00?oo`00ooooooooool0
:_ooool0027ooooo0ol0001cooooo`03o`000?oooooooooo0:3ooooo00?oo`00ooooooooool0:ooo
ool0027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`2Mooooo`;oo`00;_ooool0
027ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`2Kooooo`03ool00?l0003ooooo
02kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0V_ooool00ooo003o
ooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo09Sooooo
00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`2Fooooo`03ool00?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0UOooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo09;ooooo0_l0000eooooo`008Oooool3o`0007Wooooo00?oo`00oooooooo
ool0T?ooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1iooooo`03ool0
0?oooooooooo08oooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`2=ooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo07_ooooo00?oo`00ooooooooool0Roooool00ol0003oooooooooo`0hooooo`008Oooool00ol0
003oooooooooo`1kooooo`03o`000?oo003ooooo08Sooooo0_oo00000ol0003oooooooooo`0ioooo
o`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo08Kooooo00?oo`00o`000?oo
ool0??ooool0027ooooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`24ooooo`03ool0
0?l0003ooooo03gooooo000Qooooo`?o0000O_ooool00ooo003oooooooooo`22ooooo`03ool00?l0
003ooooo03kooooo000Qooooo`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0POooool0
0ooo003o0000ooooo`0oooooo`008Oooool00ol0003oooooooooo`1oooooo`03o`000?oo003ooooo
07kooooo0_oo00000ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`20ooooo`03
ool00?oooooooooo07cooooo00?oo`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0
P?ooool00ol0003oo`00ooooo`1kooooo`03ool00?l0003ooooo04?ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo087ooooo00?o0000ool00?ooool0NOooool00ooo003o0000ooooo`14ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0P_ooool00ol0003oo`00ooooo`1gooooo`03ool00?oooooooooo04Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o
0000Poooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo04Kooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`17ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool0LOooool2o`0004[ooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1:ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0Boooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo06_ooooo0_l0001>oooo
o`008Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo06Oooooo0_oo00000ol0003o
ooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo06Gooooo
00?oo`00ooooool00000DOooool0027ooooo0ol00028ooooo`03o`000?ooooooo`0006Cooooo00?o
o`00o`000?l00000D_ooool0027ooooo00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`1R
ooooo`03ool00?l0003ooooo05?ooooo000Qooooo`03o`000?oooooooooo08[ooooo00?o0000ool0
0?ooool0Goooool2ool00003o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo08_o
oooo00?o0000ool00?ooool0GOooool00ooo003o0000o`00001Fooooo`008Oooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oo003ooooo05_ooooo00?oo`00o`000?ooool0Eoooool0027ooooo00?o
0000ooooooooool0SOooool00ol0003oo`00ooooo`1Iooooo`03ool00?l0003ooooo05Sooooo000Q
ooooo`03o`000?oooooooooo08kooooo00?o0000ool00?ooool0E_ooool2ool00003o`000?oooooo
oooo05Sooooo000Qooooo`?o0000Soooool00ol0003oo`00ooooo`1Cooooo`;oo`0000?o0000oooo
ooooool0F_ooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oo`00ool0001Aooooo`;o
0000G_ooool0027ooooo00?o0000ooooooooool0TOooool2o`0000;oo`00COooool2o`00063ooooo
000Qooooo`03o`000?oooooooooo09?ooooo00?o0000oooooooo0000Boooool00ol0003ooooooooo
o`1Pooooo`008Oooool00ol0003oooooooooo`2Dooooo`;o0000BOooool2o`0006?ooooo000Qoooo
o`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0A?ooool2o`0006Gooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0@?ooool3ool006Oooooo000Qooooo`03o`00
0?oooooooooo09Sooooo0_l0000nooooo`;oo`0000?o0000ooooooooool0Ioooool0027ooooo0ol0
002Jooooo`03o`000?oooooooooo03Wooooo0_oo00000ol0003oooooooooo`1Yooooo`008Oooool0
0ol0003oooooooooo`2Kooooo`;o0000=oooool2ool00003o`000?oooooooooo06_ooooo000Qoooo
o`03o`000?oooooooooo09gooooo0ooo000booooo`;oo`0000?o0000ooooooooool0KOooool0027o
oooo00?o0000ooooooooool0W_ooool2o`0000;oo`00;_ooool2ool000;o0000L?ooool0027ooooo
00?o0000ooooooooool0X?ooool2o`0000;oo`00:_ooool2ool000;o0000L_ooool0027ooooo00?o
0000ooooooooool0X_ooool2o`0000;oo`00:?ooool2o`0007Cooooo000Qooooo`03o`000?oooooo
oooo0:Cooooo0_l000000ooo003oooooooooo`0Rooooo`?o0000M_ooool0027ooooo0ol0002Woooo
o`?oo`007_ooool3o`0007Wooooo000Qooooo`03o`000?oooooooooo0:[ooooo0ooo000Dooooo`Co
o`000ol0001looooo`008Oooool00ol0003oooooooooo`2]ooooo`?o00001?ooool=ool000Co0000
Ooooool0027ooooo00?o0000ooooooooool0/?ooool?o`0008Gooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMooo
ool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h0
6?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onH
V9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo
00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo
00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0003oooooooooo`02
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;o
oooo00?ok^k^o`000?ooool02oooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0M?ooool0
07_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo07?o
oooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0
003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6
o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0
000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^oooo
o`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000
ooooo`0Cooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003o
ooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03
oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Co
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03
omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM
01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Co
oooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKo
MgMgooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .23002 L
.08255 .19216 L
.10458 .15723 L
.11448 .14436 L
.12507 .13279 L
.13499 .12411 L
.14415 .11799 L
.14911 .11545 L
.15437 .11334 L
.15691 .11254 L
.15964 .11183 L
.16121 .1115 L
.16265 .11124 L
.16401 .11104 L
.16546 .11086 L
.16615 .11079 L
.1668 .11074 L
.16802 .11066 L
.16916 .11062 L
.17039 .1106 L
.17104 .11061 L
.17176 .11062 L
.1725 .11065 L
.1732 .11068 L
.17445 .11077 L
.17578 .1109 L
.17842 .11126 L
.18092 .11173 L
.1856 .11294 L
.19019 .11454 L
.19525 .11677 L
.20551 .12266 L
.22393 .13749 L
.24327 .15796 L
.26413 .18417 L
.30527 .24235 L
.34489 .298 L
.383 .34426 L
.40425 .36551 L
.42356 .38166 L
.44388 .39538 L
.46261 .40517 L
.48179 .41253 L
.4919 .41541 L
.50259 .41777 L
.51203 .41931 L
.51732 .41996 L
.52216 .42043 L
.52666 .42077 L
Mistroke
.52903 .42091 L
.53156 .42103 L
.53399 .42112 L
.53619 .42118 L
.53725 .4212 L
.5384 .42122 L
.53948 .42123 L
.54048 .42123 L
.54175 .42123 L
.54295 .42123 L
.54402 .42122 L
.54519 .42121 L
.54647 .42118 L
.54782 .42115 L
.55024 .42108 L
.55457 .4209 L
.55934 .42063 L
.56448 .42025 L
.57001 .41975 L
.58002 .41861 L
.6001 .41558 L
.62121 .4115 L
.65937 .40245 L
.69998 .39117 L
.73908 .37926 L
.78063 .36603 L
.82067 .35332 L
.85918 .34162 L
.90015 .32988 L
.93961 .31886 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09_ooool00ooo003o0000o`000007o`000?oooooo5Oooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Oooooo00?o0000ool00?oo00000_oo003ooooo
oa3ooooo000Qooooo`?o00008_ooool2ool000;o00003Oooool2o`000003ool00?oooooooooo0?oo
oooo3Oooool0027ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Booooo`;oo`00
ooooool=ooooo`008Oooool00ol0003oooooooooo`0Oooooo`;oo`005_ooool00ol0003oo`00oooo
o`3oooooo`_ooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?ooool05oooool0
0ol0003oo`00ooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00o`00
0?ooool06Oooool00ol0003oo`00ooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo01go
oooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`3oooooo`Oooooo000Qooooo`03o`00
0?oooooooooo01cooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`3oooooo`Kooooo
000Qooooo`?o00006oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo0?oooooo1_oo
ool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooo
oooo0?oooooo1Oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Ooo
ool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0?oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3oooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo
00?o0000ool00?ooool0oOooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooooooo
o`0^ooooo`03ool00?oooooooooo0?cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000
ool00?ooool0<?ooool00ooo003oooooooooo`3kooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0n_ooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool04_ooool00ooo003oooooooooo`0cooooo`03ool00?oooooooooo0?Wooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Booooo`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool0nOooool0
00Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3
o`00017ooooo00?oo`00ooooooooool0=Oooool00ooo003oooooooooo`3hooooo`001oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@
ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool0moooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo03Oooooo00?o0000ool00?ooool0moooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?Kooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o
0000ool00?ooool0>oooool00ooo003oooooooooo`3eooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0??oo
ool00ooo003oooooooooo`3dooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo03gooooo00?o0000ool00?ooool0m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0
003oo`00ooooo`0oooooo`03o`000?oooooooooo0??ooooo000Qooooo`?o00003?ooool00ooo003o
ooooooooo`10ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_oooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0koooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo0>kooooo000Qooooo`?o00002?ooool00ol0003oooooooooo`19ooooo`03ool00?oo
oooooooo0>gooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool0
0ooo003oooooooooo`3]ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
o`00ooooo`1<ooooo`03ool00?l0003ooooo0>cooooo000Qooooo`03o`000?oooooooooo00Kooooo
00?o0000ool00?ooool0COooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oo003ooooo04oooooo00?oo`00ooooooooool0j_ooool0027ooooo00?o0000
ooooooooool01Oooool00ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>Wooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0DOooool00ooo003o0000ooooo`3Yoooo
o`008Oooool3o`0000Cooooo00?o0000ool00?ooool0D_ooool00ooo003oooooooooo`3Xooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Oooooo00?oo`00oooo
ooooool0<oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`03ool00?l0003ooooo03Gooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0l
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`06ooooo`03ool00?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000
ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`08ooooo`03ool00?oooooooooo03?ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo00?oo`00ooooooooool0
<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`06o`000?ooooooooooooooool0
003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooool0
0?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Go0000
oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo
00?o0000ooooooooool0;_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo
1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00Co0000oooooooooooo
o`00Goooool00ol0003oooooooooo`3Qooooo`008Oooool00ol0003oooooo`00001Qooooo`03o`00
0?oooooooooo0>3ooooo000Qooooo`03o`000?oooooo0000067ooooo00?o0000ooooooooool0h?oo
ool0027ooooo0_l0001Sooooo`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0
027ooooo0_l0001Tooooo`03o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_oooom^o`000003ool00?l0003o00000;oo00000_oo0007o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ooo003o0000ooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`?oo`0000?oooooo`000?ooool04_ooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?oo00001?ooool0
0ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo
oooo06Kooooo00?oo`00ooooooooool0]?ooool3o`0001[ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0Ioooool00ooo003oooooooooo`2_ooooo`Co00009oooool0027o
oooo00?o0000ooooooooool0J?ooool00ooo003oooooooooo`2Yooooo`?oo`000_l0000[ooooo`00
8Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo0:Gooooo0ooo0002o`0002kooooo
000Qooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0XOooool4ool000;o0000<Ooo
ool0027ooooo0ol0001Zooooo`03o`000?oo003ooooo09cooooo1?oo0003o`0003Cooooo000Qoooo
o`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0VOooool2ool000?o0000>?ooool0027o
oooo00?o0000ooooooooool0K?ooool00ol0003oo`00ooooo`2Eooooo`Co0000??ooool0027ooooo
00?o0000ooooooooool0KOooool00ol0003oo`00ooooo`2Aooooo`?o0000@?ooool0027ooooo00?o
0000ooooooooool0KOooool00ol0003oo`00ooooo`2;ooooo`?oo`000ol00013ooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo08Oooooo0ooo0003o`0004Kooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0Poooool3ool000?o0000BOooool0027o
oooo0ol0001`ooooo`03o`000?oooooooooo07oooooo0ooo0003o`0004cooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0Noooool3ool000;o0000D?ooool0027ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`1iooooo`03ool00?l0003o000005?ooooo000Q
ooooo`03o`000?oooooooooo07?ooooo0_l0001fooooo`?o0000E_ooool0027ooooo00?o0000oooo
ooooool0MOooool00ol0003oo`00ooooo`1_ooooo`Co0000FOooool0027ooooo00?o0000oooooooo
ool0M_ooool00ol0003oo`00ooooo`1Yooooo`;oo`000ol0001Mooooo`008Oooool00ol0003ooooo
ooooo`1gooooo`03o`000?oo003ooooo06Gooooo0ooo0002o`00063ooooo000Qooooo`03o`000?oo
oooooooo07Sooooo00?o0000ool00?ooool0HOooool3ool000;o0000Hoooool0027ooooo0ol0001i
ooooo`03o`000?oo003oo`0005gooooo0ooo0002o`0006Kooooo000Qooooo`03o`000?oooooooooo
07[ooooo0_l00002ool005Sooooo0ooo0002o`0006Wooooo000Qooooo`03o`000?oooooooooo07co
oooo00?o0000oooooooo0000EOooool2ool000;o0000K?ooool0027ooooo00?o0000ooooooooool0
OOooool2o`0000;oo`00DOooool3o`0006oooooo000Qooooo`03o`000?oooooooooo07oooooo00?o
0000oooooooo0000COooool3o`0007;ooooo000Qooooo`03o`000?oooooooooo083ooooo0_l00000
0ooo003oooooooooo`14ooooo`;oo`0000Coooooo`000?l0003o0000MOooool0027ooooo00?o0000
ooooooooool0P_ooool2o`0004;ooooo0ooo0003o`0007Sooooo000Qooooo`?o0000Q?ooool2o`00
03cooooo1?oo0003o`0007_ooooo000Qooooo`03o`000?oooooooooo08Kooooo0_l0000eooooo`Go
o`001?l0001nooooo`008Oooool00ol0003oooooooooo`28ooooo`;o0000<Oooool2ool000Go0000
P_ooool0027ooooo00?o0000ooooooooool0R_ooool2o`0000?oo`00:_ooool4o`0008Oooooo000Q
ooooo`03o`000?oooooooooo08cooooo0ol00007ool001Sooooo0ooo0004ooooo`Co0000Roooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0Soooool3o`0000Cooooo1Ooo0005ooooo`koo`0000?o
ooooo`000?l000001?l0002?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0T_ooool7o`00017ooooo1Ol0
002Eooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0009Wooooo4Ol0002Jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`00
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?oo
ool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool0
0olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool0
07kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RH
ooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03
ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01OnH
V9So410@o`000?lb<S;oc<c<07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIV
IP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`00
0?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool0
1_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P1k
ooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?o
V9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo07Wooooo001nooooo`04oeEE
EOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413ooooo07[ooooo001noooo
o`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo
00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMgooooo`02
ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413o
oooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool0
0omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o8B4Qoooo
o`1jooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgM
oa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000007_ooooo002Foooo
o`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So
410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .273 L
.06244 .23719 L
.08255 .20715 L
.09409 .19365 L
.10458 .18392 L
.1094 .18027 L
.11464 .1769 L
.11917 .17448 L
.12415 .17231 L
.12944 .17059 L
.13233 .16989 L
.13504 .16938 L
.13633 .16919 L
.13757 .16904 L
.13869 .16893 L
.13988 .16884 L
.14117 .16877 L
.14237 .16873 L
.1431 .16872 L
.1438 .16872 L
.14509 .16874 L
.14625 .16879 L
.1475 .16886 L
.14867 .16896 L
.14974 .16907 L
.15237 .16942 L
.15485 .16986 L
.15979 .17102 L
.16517 .17271 L
.17476 .17672 L
.18364 .18144 L
.22291 .21027 L
.26066 .24263 L
.30086 .27345 L
.31934 .28479 L
.33955 .2947 L
.35959 .30185 L
.37052 .30464 L
.38069 .30656 L
.38574 .30728 L
.39121 .3079 L
.39372 .30813 L
.39638 .30833 L
.39868 .30847 L
.40114 .3086 L
.40237 .30865 L
.40353 .30869 L
.40467 .30872 L
.40572 .30874 L
Mistroke
.40671 .30876 L
.40776 .30877 L
.40893 .30878 L
.41 .30878 L
.41125 .30878 L
.41241 .30877 L
.41367 .30875 L
.41501 .30872 L
.41726 .30865 L
.41973 .30855 L
.42499 .30825 L
.42996 .30786 L
.43928 .30687 L
.44931 .30547 L
.46021 .30362 L
.50104 .29455 L
.54036 .2846 L
.57816 .27574 L
.59918 .27154 L
.61842 .26826 L
.6385 .26549 L
.65716 .26354 L
.66633 .26281 L
.67612 .26218 L
.68171 .2619 L
.68698 .26169 L
.69171 .26154 L
.69418 .26148 L
.69684 .26142 L
.6994 .26138 L
.70174 .26135 L
.70287 .26134 L
.70409 .26133 L
.70525 .26133 L
.70633 .26133 L
.70756 .26132 L
.70873 .26133 L
.71 .26133 L
.71072 .26133 L
.71138 .26134 L
.71263 .26135 L
.71399 .26136 L
.71675 .2614 L
.71951 .26145 L
.72202 .26151 L
.72765 .26168 L
.73287 .26189 L
.73781 .26213 L
.74751 .26272 L
.7578 .26353 L
Mistroke
.77624 .26541 L
.79579 .26802 L
.8141 .27099 L
.85289 .27875 L
.89413 .28848 L
.93386 .2983 L
.97207 .30791 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001oooooo2Ol0003ooooooago
oooo000Qooooo`03o`000?oooooooooo01cooooo0ol000000oooooooo`00ool00008ool000;o0000
oooooolIooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo0ooo
0002o`000?oooooo5_ooool0027ooooo00?o0000ooooooooool06Oooool2o`0001;ooooo0_oo0002
o`000?oooooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooo00000?oooooo4oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo4?ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01Gooooo0_oo000Looooo`03o`000?oooooooooo0?oooooo3oooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0001Cooooo00?oo`00
o`000?ooool07Oooool00ol0003oooooooooo`3oooooo`kooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01?ooooo00?oo`00
o`000?ooool07oooool2o`000?oooooo3_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo027ooooo00?o0000ooooooooool0ooooool;ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03ool00?oo
oooooooo02?ooooo0_l0003oooooo`_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool09?oo
ool2ool00003o`000?oooooooooo0?oooooo2?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo02Oooooo00?o
o`00o`000?ooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo02Sooooo00?oo`00o`000?ooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oo003ooooo02[ooooo0_oo003oooooo`Oooooo000Qooooo`?o00003_ooool00ol0003o
o`00ooooo`0]ooooo`03ool00?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo0?oooooo0oooool0027ooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0booooo`03ool00?oooooo
oooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0doooo
o`03ool00?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0=Oooool00ooo003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Oooooo00?oo`00ooooooooool0oOooool0027ooooo0ol00009ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo0?_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0??ooool2o`000?_ooooo000Qooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3hooooo`008Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0moooool0027ooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`11ooooo`03o`000?oo003oo`000?Kooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?ooool0@oooool00ol0003oooooool0003e
ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04Gooooo00?o0000oooo
oooo0000P?ooool2ool007;ooooo000Qooooo`?o00001Oooool00ooo003oooooooooo`16ooooo`;o
00000_oo001`ooooo`koo`003?ooool;ool005gooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ool00?ooool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oo0000?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb
<S;ogMgMool00004ool003Sooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool2o`00
0003ool00?oooooooooo03cooooo00?o0000ooooooooool07oooool4ool000Wooooo2?l0000;oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`Wo00001_oo000booooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0goooo
o`05oa0@4?ooooooooooooooool@41004?ooool2o`0000;oo`00??ooool00ol0003oooooooooo`0I
ooooo`Koo`000_ooool;o`0001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`Ko0000<Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00;o00000_oo000jooooo`03o`000?oooooooooo01Cooooo1Ooo0005ooooo`?o00007_ooool0
0ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00cooooo1_l00002ooooo`?oo`009oooool0
0onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00ooo
ool00ol0003oooooool0000iooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool00ooo
ool5o`00027ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo
1Ol00005ool002?ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`0hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`06ooooo`;o000000?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`Go0000
9_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo1?l00005ool001oooooo
00?o0000ooooooooool06Oooool0027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool01_ooool3ool000Oooooo1?l0000[ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool08Oooool3o`0000?oo`006?ooool01Ol0003o^[ZjoooooonHV9So410@01_o
oooo000Qooooo`05o`000?oooooooooooooooooo0000>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00008ooooo`;o0000=?ooool00omEEEGoIVIVo`000004ooooo`Coo`001_ooool4o`00
02gooooo00?oEEEEofIVI_l000003Oooool4o`0002Kooooo1Ol0000Cooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`06oooool0027ooooo00Co0000ooooooooooooo`00Foooool2o`0003Kooooo0ooo0006
ooooo`Co0000L?ooool5o`0002kooooo000Qooooo`04o`000?oooooo0000ool005gooooo0_l0000`
ooooo`Coo`001?ooool5o`0007Wooooo0ooo00000ol0003oooooooooo`0Xooooo`008Oooool00ol0
003oooooool0001Pooooo`?o00000ooo000Xooooo`;oo`001?ooool4o`00087ooooo1?oo00000ol0
003oooooooooo`0Tooooo`008Oooool2o`0006Cooooo0ol00003ool002Kooooo1Ol00029ooooo`Co
o`0000?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004ooooo`008Oooool2o`0006Oooooo
0ol00004ool001Cooooo0ooo0005ooooo`Ko0000T_ooool3ool000;o00005?ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000JooooogOo00001_oo0002o`0000coo`00Xol00002ool000Wo
00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Oooooo5Ol0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85oooo
o`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oo
oooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo
00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEE
EOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4
A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009oooo
o`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOo
IVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o
0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`00
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8boooo
ooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg
1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo
00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`00
00;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413o
k^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKo
ooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03ojVYZOl@413ooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooooooooooo
ool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool0
07cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o0000
00?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooo
ooooool02?ooool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@400>
ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000oooo
ooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj
^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29823 L
.0522 .2938 L
.06244 .29011 L
.0679 .28861 L
.07286 .28752 L
.07784 .28668 L
.08008 .28639 L
.08255 .28613 L
.08522 .28591 L
.08668 .28582 L
.08805 .28575 L
.08932 .2857 L
.09049 .28567 L
.09113 .28566 L
.09184 .28565 L
.09312 .28564 L
.09389 .28565 L
.09462 .28565 L
.09528 .28566 L
.09599 .28568 L
.09759 .28573 L
.09906 .28579 L
.10174 .28595 L
.10458 .28617 L
.10954 .28669 L
.11406 .28728 L
.12422 .28897 L
.14255 .29279 L
.16325 .29721 L
.17235 .29889 L
.1824 .30041 L
.18701 .30096 L
.19198 .30144 L
.19427 .30162 L
.19668 .30177 L
.19893 .30189 L
.20098 .30197 L
.2022 .30201 L
.20334 .30204 L
.20455 .30206 L
.20587 .30207 L
.20702 .30208 L
.20823 .30207 L
.20927 .30206 L
.21041 .30204 L
.2111 .30202 L
.21175 .30201 L
.21298 .30197 L
.21574 .30184 L
Mistroke
.21813 .30169 L
.22073 .30149 L
.22606 .30094 L
.23107 .30026 L
.24044 .29856 L
.25053 .29611 L
.26142 .29276 L
.2814 .28486 L
.30248 .27442 L
.3405 .25179 L
.38098 .2255 L
.41994 .20123 L
.46135 .17905 L
.48209 .16982 L
.50125 .16253 L
.52106 .15629 L
.53963 .15164 L
.55834 .14814 L
.56826 .14677 L
.5738 .14615 L
.57895 .14566 L
.58398 .14527 L
.58855 .14499 L
.59362 .14476 L
.59641 .14468 L
.59766 .14464 L
.59903 .14462 L
.60036 .14459 L
.6016 .14458 L
.60291 .14457 L
.60364 .14457 L
.60431 .14456 L
.6055 .14456 L
.6068 .14457 L
.60803 .14458 L
.60917 .1446 L
.61047 .14462 L
.6117 .14465 L
.61449 .14473 L
.61721 .14483 L
.62014 .14496 L
.62509 .14526 L
.6297 .14561 L
.64016 .14665 L
.65035 .14802 L
.66125 .14984 L
.68257 .15449 L
.70272 .16015 L
.74115 .17409 L
.78204 .19269 L
Mistroke
.82141 .21328 L
.85926 .23476 L
.89957 .25907 L
.93836 .28399 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0Z_ooool;ool008oooooo000Qooooo`03o`000?oooooooooo0:Gooooo1Ooo000Eoooo
o`Goo`00P?ooool0027ooooo00?o0000ooooooooool0YOoooolLo`0000?ooooo1Ooo001kooooo`00
8Oooool00ol0003oooooooooo`2Jooooo`03ool00?oooooooooo00;ooooo1_l0000Looooo`Oo0000
00?oooooool00?oo00000ooo001fooooo`008Oooool00ol0003oooooooooo`2Gooooo`?oo`000_oo
ool3o`0002Wooooo0ol00003ooooo`03ool00?oooooooooo07?ooooo000Qooooo`03o`000?oooooo
oooo09Cooooo0ooo00000ooooooo0000o`000002o`0002oooooo0ol0001fooooo`008Oooool00ol0
003oooooooooo`2Aooooo`?oo`0000Coooooo`000?l0003o0000=_ooool3o`0007?ooooo000Qoooo
o`?o0000S_ooool3ool00004ooooool0003o0000o`0003cooooo1?l0001_ooooo`008Oooool00ol0
003oooooooooo`2;ooooo`?oo`0000Coooooo`000?l0003o0000@oooool3o`000004oooooooo003o
o`00ool006Sooooo000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o000000Cooooo
ool00?oo003oo`00IOooool0027ooooo00?o0000ooooooooool0Roooool2o`0004kooooo0ol00000
0oooooooo`00ool0001Sooooo`008Oooool00ol0003oooooooooo`28ooooo`?o0000Doooool2o`00
0003oooooooo003oo`00067ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08Kooooo0_l0001H
ooooo`?o00000_oo001Oooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0P?ooool2ool000;ooooo0_l0001M
ooooo`;o00000_oo001Mooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000Ooooool00ooo003oooooooooo`02o`00067ooooo0_l00000
0ooo003oooooooooo`1Jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`1mooooo`;oo`0000?oooooo`000?l00000IOooool3
o`0000;oo`00F?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1kooooo`;oo`0000?oooooo`000?l00000J_oo
ool2o`000003ool00?oooooooooo05Gooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo00Coo`00ooooool0003o0000
K_ooool2o`0005Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07Sooooo0_oo0002o`0007;ooooo0_l0001Dooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo07Kooooo
0_oo00000ooooooo0000ooooo`1eooooo`?o0000DOooool0027ooooo00?o0000ooooooooool0MOoo
ool01?oo003oooooo`000?l0001jooooo`;o0000Coooool0027ooooo00?o0000ooooooooool0M?oo
ool00ooo003o0000o`00001nooooo`?oo`00C?ooool0027ooooo0ol0001dooooo`03o`000?oooooo
oooo083ooooo00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0L_ooool2o`00
08Gooooo00?o0000ool00?ooool0B?ooool0027ooooo00?o0000ooooooooool0L?ooool2o`0008Wo
oooo0_oo0017ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo08[ooooo
00?o0000ool00?oo0000AOooool0027ooooo00?o0000ooooooooool0KOooool2o`0008oooooo00?o
0000ool00?ooool0@oooool0027ooooo00?o0000ooooooooool0J_ooool2ool00003o`000?oooooo
oooo097ooooo0_oo0012ooooo`008Oooool00ol0003oooooooooo`1Xooooo`;oo`0000?o0000oooo
ooooool0U?ooool00ol0003oo`00ooooo`10ooooo`008Oooool3o`0006Kooooo0_oo0002o`0009Wo
oooo00?oo`00o`000?ooool0?_ooool0027ooooo00?o0000ooooooooool0IOooool00ooo003o0000
o`00002Mooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo06?ooooo0_oo
00000ol0003oooooooooo`2Nooooo`;o0000??ooool0027ooooo00?o0000ooooooooool0HOooool2
ool000;o0000Xoooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`1Ooooo
o`;oo`000_l0002Vooooo`;o0000>Oooool0027ooooo00?o0000ooooooooool0G_ooool00ooo003o
0000o`00002Zooooo`03o`000?oo003oo`0003Kooooo000Qooooo`03o`000?oooooooooo05gooooo
00?oo`00o`000?ooool0[?ooool2o`000003ool00?oooooooooo03?ooooo000Qooooo`03o`000?oo
oooooooo05_ooooo0_l0002aooooo`03o`000?oo003oo`0003?ooooo000Qooooo`?o0000F_ooool0
0ol0003oooooooooo`2booooo`;o000000?oo`00ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool2o`0003Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`03o`00
0?oo003oo`00013ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00_ooool2o`0003[ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0[ooooo`03o`000?oo003ooooo00kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool01?l0003o
ooooo`000?l0000looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0[ooooo`03o`000?oo003ooooo00kooooo00?oV9RHob4Q8Oo^k^h07?ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000oooooo00CoMgMgo`00
0?oo003oo`00?Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMg
oc8b<_ooool0;_ooool2ool000kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ob4Q8Ol000000_oo000o
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<037ooooo00?oo`00ooooooooool03?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool0
0ol0003oooooooooo`0Eooooo`;o00009_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ool00?oo0000@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=?ooool00ooo003o0000ooooo`0<ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o00003_ooool<ool000Oo00007?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o
0000ool00?oo0000@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=_ooool2o`0000Oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Ooo
ool00ol0003oooooooooo`0:ooooo`Co000000?oo`00ooooooooool02Oooool4ool000?ooooo1Ol0
000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3ool00003ooooool0003o000000;o0000
?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`;o0000
1Oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Sooooo
0_l0000Looooo`?o00007_ooool3ool00=Gooooo00?o0000ooooooooool08_ooool0027ooooo00?o
0000ooooooooool01Oooool3o`00023ooooo00Coo`00o`000?l0003o00005_ooool4o`000003ool0
0?l0003ooooo0=Oooooo0_l0000Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;oo`0000?o
0000ooooooooool08_ooool6ool000Co00002_ooool5o`000>3ooooo0_l0000Pooooo`008Oooool0
0ol0003oooooooooo`02ool002gooooo2Ooo00001Ol0003oo`00ool00?oo003o00000>Kooooo0_oo
000Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003oo`000?oooooo9_ooool2
ool001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0
003o00000?oo0000:?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVoooo
o`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07
ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`00
0?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo
07Wooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo
0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo
410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool0N_ooool007kooooo00Oo0000oooooooMgMgo
<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05oooo
o`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgM
gOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooo
ooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003o
ooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04
odA4A?oMgMgoooooo`0007cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000oooooooo
ool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003o
k^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^
k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
001looooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@
o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool0
0ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`00001looooo`00U_ooool00ol0003oooooooooo`07
ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@
41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Go
oooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0Noooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34079 L
.06244 .37024 L
.08255 .39386 L
.09396 .404 L
.09905 .40772 L
.10458 .41119 L
.11004 .41404 L
.11508 .41615 L
.11989 .41771 L
.12235 .41833 L
.125 .41888 L
.12738 .41925 L
.12956 .4195 L
.13061 .41959 L
.13175 .41966 L
.13283 .41971 L
.13384 .41974 L
.13511 .41974 L
.13631 .41972 L
.13738 .41967 L
.13855 .4196 L
.13982 .4195 L
.14117 .41936 L
.14357 .41902 L
.14612 .41856 L
.14853 .41801 L
.15305 .41672 L
.15792 .41495 L
.16321 .41259 L
.18154 .40116 L
.20132 .38382 L
.22233 .36084 L
.26008 .3116 L
.30028 .2544 L
.33897 .20095 L
.38011 .15082 L
.41973 .11204 L
.45784 .08474 L
.47745 .07455 L
.4984 .06646 L
.50864 .06351 L
.51975 .06102 L
.52484 .06012 L
.53023 .05933 L
.53528 .05874 L
.5399 .05832 L
.54222 .05815 L
.54474 .058 L
.54712 .05789 L
Mistroke
.54934 .05781 L
.55066 .05778 L
.55191 .05775 L
.55303 .05774 L
.55425 .05773 L
.55488 .05773 L
.55557 .05773 L
.5563 .05773 L
.55697 .05773 L
.55818 .05775 L
.55947 .05777 L
.5607 .0578 L
.56183 .05784 L
.5644 .05794 L
.56666 .05806 L
.56906 .0582 L
.57779 .05897 L
.58269 .05956 L
.58718 .06018 L
.5973 .06191 L
.61559 .06607 L
.63455 .07171 L
.65527 .07927 L
.69588 .09783 L
.73498 .11981 L
.77653 .14699 L
.81656 .17634 L
.85508 .20685 L
.89605 .24086 L
.9355 .27425 L
.97344 .30664 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Voooool7ool000Wooooo0_oo002Gooooo`008Ooo
ool00ol0003oooooooooo`2Loooooa7o00001_oo002Aooooo`006?ooool4o`000003oa0@4?oooooo
oooo00;ooooo00?o0000ooooooooool0Uoooool5o`0001;ooooo1Ol00003ool008kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T?ooool2ool000;ooooo0ol0000Moooo
o`;o00000ooo002;ooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`0008go
oooo0ooo00001?oooooo0000o`000?l0000Sooooo`;o00000_oo0029ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo08[ooooo0ooo00001?oooooo0000o`000?l0000Zoooo
o`Co0000QOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`;o
o`0000Coooooo`000?l0003o0000<Oooool2o`0008?ooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Q_ooool2ool00003ooooool0003o000003Kooooo0_l00021ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Gooooo00Coo`00ooooool0003o
0000>_ooool2o`0000;oo`00OOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`24ooooo`03ool00?l0003o000003kooooo0_l00003ool007[ooooo000Qooooo`03o`000?oo
oooooooo08?ooooo00?oo`00o`000?ooool0@_ooool2o`0000;oo`00N?ooool0027ooooo00?o0000
ooooooooool0P_ooool2o`0004Oooooo00Co0000ool00?oo003oo`00MOooool0027ooooo0ol00021
ooooo`03o`000?oooooooooo04Wooooo0_l00002ool007?ooooo000Qooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0COooool00ol0003oo`00ool0001aooooo`008Oooool00ol0003o
ooooooooo`1nooooo`;o0000D_ooool00ol0003oo`00ooooo`1_ooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0KOooool0027ooooo00?o
0000ooooooooool0N_ooool00ooo003o0000o`00001Hooooo`;o0000KOooool0027ooooo00?o0000
ooooooooool0NOooool00ooo003o0000ooooo`1Kooooo`;o0000Joooool0027ooooo00?o0000oooo
ooooool0N?ooool00ooo003o0000ooooo`1Nooooo`03o`000?oooooooooo06Sooooo000Qooooo`?o
0000Moooool00ooo003o0000ooooo`1Pooooo`;o0000J?ooool0027ooooo00?o0000ooooooooool0
M_ooool00ooo003o0000ooooo`1Sooooo`;oo`00I_ooool0027ooooo00?o0000ooooooooool0MOoo
ool00ooo003o0000ooooo`1Vooooo`03ool00?oooooooooo06?ooooo000Qooooo`03o`000?oooooo
oooo07Cooooo00?oo`00o`000?ooool0J?ooool2ool006?ooooo000Qooooo`03o`000?oooooooooo
07?ooooo00?oo`00o`000?ooool0J_ooool00ol0003oo`00ooooo`1Qooooo`008Oooool00ol0003o
ooooooooo`1booooo`03ool00?l0003ooooo06gooooo0_oo001Pooooo`008Oooool00ol0003ooooo
ooooo`1aooooo`03ool00?l0003ooooo06oooooo00?o0000ool00?ooool0G_ooool0027ooooo0ol0
001`ooooo`03ool00?l0003ooooo077ooooo00?o0000ool00?oo0000GOooool0027ooooo00?o0000
ooooooooool0Koooool00ooo003o0000ooooo`1dooooo`03o`000?oo003ooooo05_ooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool0MOooool00ol0003oo`00ool0001Joooo
o`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07Oooooo0_l0001Jooooo`00
8Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0
Eoooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1kooooo`;o0000Eooo
ool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo05Cooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0P?ooool2o`00
05Cooooo000Qooooo`?o0000J_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo057o
oooo000Qooooo`03o`000?oooooooooo06Oooooo00?oo`00ooooool00000Qoooool00ol0003oo`00
ool0001@ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?l0003ooooo08Wooooo00?o
0000ool00?ooool0C_ooool0027ooooo00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2;
ooooo`03o`000?oo003oo`0004gooooo000Qooooo`03o`000?oooooooooo06Gooooo00?oo`00o`00
0?ooool0S_ooool00ol0003oo`00ooooo`1;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`1U
ooooo`03ool00?l0003ooooo08oooooo00?o0000ool00?ooool0B_ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo06Cooooo00?oo`00o`000?ooool0TOooool00ol0003oo`00ool00019ooooo`001Ol00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Hoooool0
0ooo003o0000ooooo`2Dooooo`03o`000?oo003ooooo04Oooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo06;ooooo00?oo`00
o`000?ooool0U_ooool00ol0003oo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool0Uoooool00ol0003oo`00ooooo`15ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`03ool00?oo
oooooooo09Wooooo00?o0000ool00?ooool0A?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ooo003ooooooooo
o`2Looooo`03o`000?oooooooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Nooooo`03o`000?oo
oooooooo047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0X?ooool2
o`00047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0X_ooool00ol0
003oooooooooo`0nooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0Y?ooool00ol0003o
ooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`2Wooooo`03o`000?oo003oo`0003_ooooo000Qooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0ZOooool2o`000003ool00?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool0[?ooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo
00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo03Kooooo
000Qooooo`?o0000Eoooool00ooo003o0000ooooo`2booooo`03o`000?oo003ooooo03Gooooo000Q
ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0/oooool00ol0003oo`00ool0000d
ooooo`008Oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo0;Gooooo0_l000000ooo
003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0;So
oooo00?o0000ool00?ooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oo`00
ooooo`2jooooo`03o`000?oo003ooooo033ooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o
o`00ooooooooool0^oooool00ol0003oo`00ooooo`0_ooooo`008Oooool00ol0003oooooooooo`1C
ooooo`03o`000?oo003ooooo0;gooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0D_ooool00ol0003oo`00ooooo`2oooooo`;o0000;_ooool0027ooooo0ol0001Booooo`03
ool00?oooooooooo0<7ooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0
?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool0
0?oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM033ooooo00?o0000ooooooooool02_ooool5
o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oo`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oo`00ooooool00000?oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`09ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000=ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000oooooooooooooooo
o`00000<ooooo`05ool00?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00dooooo`;oo`002_ooool00omg
MgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`00
04?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Wooooo00?oo`00o`000?ooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo
000000?o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000i
ooooo`03ool00?l0003ooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0=7ooooo0_oo000Rooooo`008Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?oo`00ooooooooool07oooool0027o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo01ko
oooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0eoooool00ooo003o0000
ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1?ooool001[oooooD_l000000ooo003o0000o`00003Ko`0000;oo`001ol0000<ooooo`04omgM
gOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ooo003o0000ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o0000
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo
<S8b1Oooool0027ooooo00?o0000ooooool00000A_ooool00ooo003oooooooooo`3aooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`03o`000?oooooo000004Gooooo00?oo`00ooooooooool0o?oo
ool0027ooooo00Co0000oooooooooooo0000@oooool00ooo003oooooooooo`3mooooo`008Oooool0
1Ol0003ooooooooooooooooo000004;ooooo00?oo`00ooooooooool0oOooool0027ooooo00Go0000
ooooooooooooooooo`000011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`?o00000_ooool0
0ol0003oooooooooo`0mooooo`03ool00?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0>oooool00ol0003oo`00ooooo`3oooooo`7ooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oo`00ooooo`3oooooo`;o
oooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00o`000?ooool0>Oooool00ol0003oo`00
ooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00o`000?ooool0>?oo
ool00ooo003oooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0=_ooool00ol0003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00o`000?ooool0=Oooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`?o
00001_ooool00ooo003o0000ooooo`0cooooo`03o`000?oooooooooo0?oooooo1_ooool0027ooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo
1oooool0027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`0aooooo`03o`000?oo
oooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003o0000ooooo`0_
ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2Oooool0027ooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo2_ooool0027ooooo
00?o0000ooooooooool02oooool00ooo003oooooooooo`0Yooooo`03o`000?oo003ooooo0?oooooo
2oooool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0Wooooo`03o`000?oo
003ooooo0?oooooo3?ooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo02Gooooo00?o0000
ool00?ooool0ooooool=ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02?ooooo0_oo003oooooo`oooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ooo003oooooooooo`3oooooo`oooooo000Qooooo`03o`000?oooooooooo013ooooo
0_l0000Pooooo`03ool00?oooooooooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo0?oooooo4Oooool0027ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo0?oooooo4_ooool0
027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`;oo`00oooooolEoooo
o`008Oooool3o`0001?ooooo0_oo00000ol0003oooooooooo`0Eooooo`03ool00?oooooooooo0?oo
oooo5Oooool0027ooooo00?o0000ooooooooool05Oooool2ool001Cooooo00?o0000ool00?ooool0
oooooolGooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l0003o0000013ooooo00?o
0000ooooooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`0000?o0000
ooooooooool02oooool2o`000?oooooo6oooool0027ooooo00?o0000ooooooooool06_ooool3ool0
0003o`000?oooooooooo00Cooooo1?l0003ooooooagooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01gooooo1_oo00000ol0003oooooooooo`3ooooooaoooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`Go00002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
2oooool01?m4A4CogMgMooooool00008ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgM
gOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04
omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo
001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`00
0003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oo
oooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oo
oooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj
^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`00
0?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .4616 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47232 L
.1174 .47319 L
.11989 .47393 L
.12127 .47425 L
.12253 .4745 L
.12372 .47469 L
.125 .47485 L
.12624 .47495 L
.12736 .47501 L
.12849 .47503 L
.12955 .47501 L
.13079 .47495 L
.13194 .47485 L
.13319 .4747 L
.13452 .4745 L
.13675 .47404 L
.13884 .4735 L
.14357 .47182 L
.14858 .46942 L
.15402 .4661 L
.16392 .45834 L
.18248 .43849 L
.22326 .37753 L
.26253 .30785 L
.30028 .24068 L
.34048 .17577 L
.37917 .12341 L
.39882 .10119 L
.42031 .08041 L
.44107 .06382 L
.45994 .05166 L
.47955 .04185 L
.49045 .0376 L
.5005 .0344 L
.50981 .03205 L
.51968 .03017 L
.5248 .02943 L
.52958 .02889 L
.53484 .02846 L
.53778 .02829 L
.53917 .02822 L
Mistroke
.54048 .02817 L
.54168 .02814 L
.54299 .02811 L
.54417 .02809 L
.54526 .02808 L
.54644 .02807 L
.54774 .02808 L
.54839 .02808 L
.54909 .02809 L
.55035 .02812 L
.55153 .02815 L
.55281 .02819 L
.55514 .02829 L
.55741 .02841 L
.5595 .02855 L
.56429 .02895 L
.56956 .02954 L
.58024 .03116 L
.59036 .03321 L
.59962 .03552 L
.62049 .04209 L
.66017 .05934 L
.69833 .08087 L
.73894 .10798 L
.77804 .13721 L
.81959 .17076 L
.85963 .20482 L
.89814 .2387 L
.93912 .27545 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35778 L
.06244 .40451 L
.08255 .44142 L
.09396 .45658 L
.09905 .46193 L
.10458 .46675 L
.11004 .47048 L
.11243 .47181 L
.11508 .47306 L
.1174 .47397 L
.11989 .47475 L
.12127 .47509 L
.12253 .47536 L
.12372 .47556 L
.125 .47573 L
.12624 .47585 L
.12736 .47591 L
.12849 .47594 L
.12955 .47593 L
.13079 .47588 L
.13194 .47579 L
.13319 .47564 L
.13452 .47544 L
.13675 .47499 L
.13884 .47444 L
.14357 .47274 L
.14858 .47029 L
.15402 .46691 L
.16392 .45898 L
.18248 .43872 L
.22326 .37689 L
.26253 .30699 L
.30028 .24019 L
.34048 .17608 L
.37917 .12446 L
.42031 .08176 L
.44084 .06522 L
.45994 .05261 L
.47836 .04294 L
.49804 .03524 L
.50829 .03227 L
.51368 .03098 L
.51939 .02983 L
.52438 .029 L
.52987 .02826 L
.53228 .028 L
.53487 .02776 L
.53732 .02757 L
.53954 .02743 L
Mistroke
.54209 .0273 L
.54348 .02725 L
.5448 .02721 L
.54602 .02719 L
.54714 .02717 L
.54837 .02717 L
.54967 .02717 L
.55099 .02718 L
.55173 .02719 L
.5524 .0272 L
.5537 .02723 L
.55494 .02727 L
.55771 .02739 L
.56072 .02757 L
.56579 .028 L
.57116 .0286 L
.58082 .03009 L
.59021 .03202 L
.60033 .03459 L
.61862 .04049 L
.65981 .05896 L
.69949 .08218 L
.73765 .10814 L
.77826 .13849 L
.81736 .16963 L
.85891 .20441 L
.89894 .23932 L
.93746 .27382 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`Coo`00WOooool0027ooooo00?o0000ooooooooool0Uooo
ool6ool000[o00001ooo002Fooooo`008Oooool00ol0003oooooooooo`2Cooooo`Coo`005?ooool3
o`0000?oo`00Toooool0027ooooo00?o0000ooooooooool0T?ooool3ool00003o`000?oooooooooo
01_ooooo0_oo00000ol0003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
o`0000?o0000ooooooooool08Oooool3o`0008gooooo000Qooooo`03o`000?oooooooooo08_ooooo
0_l000000ooo003oooooooooo`0Wooooo`?o0000R_ooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`0002oooooo0ol00027ooooo`008Oooool3o`0008Oooooo0_l0000cooooo`;oo`0000?o0000
ooooooooool0Poooool0027ooooo00?o0000ooooooooool0QOooool2o`0003Oooooo0ooo0023oooo
o`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03[ooooo0ooo0020ooooo`00
8Oooool00ol0003oooooooooo`22ooooo`;oo`00@?ooool2ool007kooooo000Qooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool0@_ooool00ooo003o0000ooooo`1kooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool2ool004Kooooo0_oo001k
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?oo`00oooo
ooooool0B?ooool00ooo003o0000ooooo`1hooooo`003oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool3o`0007cooooo0_oo001<ooooo`03ool00?l0003o000007Oooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`1?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1hooooo`03o`000?oo003ooooo05Gooooo0_l0001booooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo0000F?ooool00ol0
003oooooooooo`1_ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo07Ko
oooo00?o0000oooooooo0000F_ooool2o`0006oooooo000Qooooo`03o`000?oooooooooo07Gooooo
00?o0000oooooooo0000Foooool2ool00003o`000?oooooooooo06cooooo000Qooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool0G_ooool00ooo003o0000o`00001/ooooo`008Oooool3
o`0007?ooooo00?o0000ooooooooool0H?ooool2ool00003o`000?oooooooooo06Wooooo000Qoooo
o`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Hoooool00ooo003o0000ooooo`1Yoooo
o`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo06Cooooo0_oo00000ol0003o
ooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Oooooo
00?oo`00o`000?ooool0I_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1Yooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oo`00ooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo
06kooooo00?o0000ool00?ooool0K_ooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006go
oooo00?o0000ool00?ooool0L?ooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0G_ooool0027ooooo00?o
0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Q
ooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2o`0005gooooo000Qoooo
o`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0003oooooooooo`1Joooo
o`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000oooooooo
ool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ol0003oo`00ooooo`1mooooo`;oo`00
FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`22ooooo`03ool00?oooooo
oooo05Gooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?ooool0Poooool00ooo
003o0000ooooo`1Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo003ooooo08Go
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003oo`00
ooooo`27ooooo`;oo`00Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`29ooooo`03ool00?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`1?ooooo`008Oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo08gooooo00?oo`00o`000?ooool0C_ooool0027ooooo0ol0001Rooooo`03
o`000?oooooooooo08oooooo00?oo`00o`000?ooool0COooool0027ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`2@ooooo`03ool00?l0003o000004cooooo000Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`19ooooo`008Oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0B?ooool0
027ooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Hooooo`03o`000?oooooooooo
04Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0VOooool0
0ol0003oooooooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`2K
ooooo`03o`000?oooooooooo04Gooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0001Nooooo`03ool00?oooooooooo09cooooo00?o0000
ooooooooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Mooooo`;oo`00AOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0:3ooooo00?oo`00ooooooooool0@_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0G?ooool00ooo003oooooooooo`2Qooooo`03ool00?oooooooooo047ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05_ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`10ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05_ooooo00?o
o`00ooooooooool0Y?ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00
ooooooooool0Yoooool00ooo003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Joooo
o`03ool00?oooooooooo0:Sooooo00?oo`00ooooooooool0??ooool0027ooooo0ol0001Iooooo`03
ool00?oooooooooo0:[ooooo00?oo`00ooooooooool0>oooool0027ooooo00?o0000ooooooooool0
F?ooool00ooo003oooooooooo`2/ooooo`03ool00?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo05Sooooo00?oo`00ooooooooool0[Oooool00ooo003o0000ooooo`0iooooo`008Oooool0
0ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0:oooooo00?oo`00o`000?ooool0>?ooool0
027ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
03Kooooo000Qooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Gooooo
00?o0000ooooooooool0=?ooool0027ooooo0ol0001Eooooo`03o`000?oooooooooo0;Kooooo0_l0
000dooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0_?ooool2ool0033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
_Oooool00ol0003oo`00ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?l0
003ooooo0<3ooooo00?o0000ool00?ooool0;Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ooo003oooooooooo`31ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo
053ooooo00?oo`00o`000?ooool0`oooool00ol0003oo`00ooooo`0[ooooo`008Oooool3o`00053o
oooo00?oo`00ooooooooool0a?ooool00ol0003oo`00ooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4ool00?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oo`00ooooo`09
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo
003ooooo00Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool01Ooo003o0000oooooooooooo000003oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003ooooooooooomgMgOo<S8b
03oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?oo`00o`000?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000002oooool01_oo003o0000ob4Q8Ol0003o
<S8bolc<c3oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0=Oooool00ooo003o0000ooooo`08ooooo`03ogMgMomVIVKooooo01[ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400;ooooo`03ool0
0?l0003ooooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00o`000?ooool02?ooool00ol0003oooooooooo`0Iooooo`008Ooo
ool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03ool00?oooooo000004?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o
0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09
o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooo
oooo04_ooooo00?oo`00ooooooooool0doooool2o`00027ooooo000Qooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0eOooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1:ooooo`03ool00?oooooooooo0=Oooooo00?o0000ooooooooool07Oooool0027ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo01;ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`3Iooooo`;oo`004oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000
<_l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`;o0000B?ooool00ol0003ooooo
ooooo`3`ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o000000?oo`00ooooooooool0A?oo
ool00ol0003oooooooooo`3kooooo`008Oooool00ol0003oooooool00016ooooo`03o`000?oooooo
oooo0?_ooooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?oo`00o`000?ooool0oOooool0
027ooooo00Co0000ooooool0003oo`00@oooool00ooo003oooooooooo`3mooooo`008Oooool3o`00
0003ool00?oooooooooo043ooooo00?oo`00o`000?ooool0o_ooool0027ooooo00Go0000oooooooo
oooo0000ool00011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`05o`000?oooooooooooooo
oooo0000@?ooool00ooo003o0000ooooo`3oooooo`008Oooool01Ol0003oooooooooooooooooo`00
043ooooo00?oo`00ooooooooool0ooooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000n
ooooo`03ool00?l0003ooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0looooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03ool00?l0003ooooo0?oooooo0_ooool0027ooooo
0ol00002ooooo`03o`000?oo003ooooo03_ooooo00?oo`00ooooooooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00o`000?ooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00
ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003ooooo03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo00?oo`00ooooooooool0ooooool5ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooo
ool5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0ooooool6ooooo`008Oooool3o`0000Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3o
ooooo`Wooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0;?ooool00ooo003o0000ooooo`3oooooo`_ooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0[ooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo
0?oooooo3Oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo0?oooooo3_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`3oooooo`oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo0?oooooo4Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0oooooolAooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0oooooolBooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0oooooolCooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool06oooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`3ooooooaGooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3ooooooaKo
oooo000Qooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo
5oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`;o0000oooooolKooooo`008Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool00ol0
003oooooooooo`3ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02oooool00ol0003oo`00ooooo`3ooooooagooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ool00?ooool02_ooool00ol0003oo`00ool0003ooooooakooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_oo00000ol0003oooooooooo`05ooooo`?oo`00oooooolPooooo`008Oooool3
o`0001[ooooo2?oo003oooooob?ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo
0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01So
oooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^
00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RH
oeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_oo
ool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;o
ooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1h
ooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`1iooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Ooo
ool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?oo
ool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool0
4_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01joooo
o`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l0
00000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003o
ooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_oo
ool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00So
MgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001kooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36391 L
.08255 .38793 L
.0932 .39807 L
.10458 .40662 L
.11009 .40988 L
.11531 .4124 L
.11999 .41421 L
.1224 .41497 L
.12507 .41568 L
.12739 .41618 L
.12988 .41661 L
.13126 .41679 L
.13252 .41692 L
.13379 .41703 L
.13499 .4171 L
.13609 .41714 L
.13726 .41715 L
.13837 .41714 L
.13937 .41712 L
.14055 .41706 L
.14183 .41697 L
.14304 .41685 L
.14415 .41672 L
.14661 .41635 L
.14885 .41592 L
.15389 .41462 L
.15855 .41301 L
.16298 .41114 L
.17287 .40581 L
.18364 .39831 L
.20341 .38054 L
.22442 .3571 L
.26217 .30757 L
.30238 .25138 L
.34106 .20025 L
.3822 .15348 L
.42183 .11792 L
.45994 .09294 L
.47955 .08349 L
.5005 .0758 L
.51074 .07292 L
.52184 .07041 L
.53233 .06861 L
.54199 .06743 L
.54667 .06703 L
.54924 .06685 L
.55169 .06671 L
.55396 .0666 L
.55515 .06655 L
Mistroke
.55643 .06651 L
.55761 .06648 L
.55867 .06645 L
.55975 .06644 L
.56076 .06642 L
.56196 .06641 L
.56327 .06641 L
.56394 .06641 L
.56465 .06642 L
.56593 .06643 L
.56721 .06645 L
.56841 .06648 L
.57068 .06654 L
.57335 .06665 L
.57582 .06678 L
.5814 .06717 L
.58604 .06759 L
.59105 .06816 L
.6001 .06945 L
.61086 .07142 L
.62072 .07364 L
.63968 .079 L
.66039 .0864 L
.701 .10526 L
.7401 .12814 L
.78165 .15637 L
.82169 .1861 L
.8602 .21601 L
.90118 .24852 L
.94063 .28029 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00002Oooool5ool000[ooooo0_oo0003ooooo`?o0000SOooool000oo
oooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0ol0002Aooooo`?o00007Oooool7ool000?o
0000ROooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2>ooooo`?o0000
0oooool2ool002;ooooo0ooo0004o`0008Gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Roooool3o`0000?ooooo0ooo000Wooooo`?oo`0000?oooooo`000?l00000Pooo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`29ooooo`;o00000oooool3
ool002gooooo00?oo`00ooooooooool00_l00021ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo0_l00002ooooo`?oo`00=Oooool2o`0007oooooo000Hooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0QOooool2o`000004oooooooo003oo`00ool0
03[ooooo0ol0001looooo`008Oooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooool0
043ooooo0ol0001iooooo`008Oooool00ol0003oooooooooo`22ooooo`;o0000A?ooool2ool00003
ooooool0003o000007Oooooo000Qooooo`?o0000POooool00ol0003oooooooooo`16ooooo`;oo`00
00Coooooo`000?l0003o0000M?ooool0027ooooo00?o0000ooooooooool0P?ooool00ol0003ooooo
ooooo`19ooooo`?oo`0000?oooooo`000?l00000L_ooool0027ooooo00?o0000ooooooooool0O_oo
ool2o`0004oooooo0_oo00000ooooooo0000o`00001`ooooo`008Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo057ooooo0_oo00000ooooooo0000ooooo`1^ooooo`008Oooool00ol0
003oooooooooo`1kooooo`;o00000_oo001Dooooo`;oo`000_l0001]ooooo`008Oooool00ol0003o
ooooooooo`1jooooo`03o`000?ooooooo`0005Sooooo00Coo`00ooooool0003o0000Joooool0027o
oooo00?o0000ooooooooool0NOooool00ol0003oooooool0001Jooooo`04ool00?ooooooooooo`00
06[ooooo000Qooooo`?o0000N?ooool00ol0003oo`00ool0001Oooooo`;o0000J?ooool0027ooooo
00?o0000ooooooooool0Moooool00ol0003oo`00ooooo`1Rooooo`;o0000I_ooool0027ooooo00?o
0000ooooooooool0M_ooool00ol0003oo`00ooooo`1Uooooo`03o`000?oooooooooo06?ooooo000Q
ooooo`03o`000?oooooooooo07Gooooo00?o0000ool00?ooool0Ioooool00ol0003oooooooooo`1R
ooooo`008Oooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo06Wooooo0_l0001Roooo
o`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oo003ooooo06Wooooo0_oo00000ooooooo
0000ooooo`1Pooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oo003ooooo06cooooo
00?oo`00ooooool00000H?ooool0027ooooo0ol0001aooooo`03o`000?oo003ooooo06kooooo0_oo
0002o`0005kooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0LOooool2
ool00003o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000oooo
ooooool0M?ooool00ooo003o0000ooooo`1Kooooo`008Oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo07Kooooo0_oo00000ol0003oooooooooo`1Hooooo`008Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo07Wooooo00?oo`00o`000?ooool0F?ooool0027ooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`1jooooo`;oo`0000?o0000ooooooooool0EOoo
ool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1mooooo`03ool00?l0003o
oooo05Gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0P?ooool2o`00
05Cooooo000Qooooo`?o0000J_ooool00ooo003oooooooooo`23ooooo`03o`000?oooooooooo057o
oooo000Qooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool0QOooool2o`00057ooooo
000Qooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0R?ooool00ol0003ooooooooo
o`1>ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo08[ooooo0_l0001>
ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo08gooooo00?o0000oooo
ooooool0Boooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0IOooool00ooo003o0000ooooo`2=
ooooo`;oo`0000?o0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo06Cooooo00?oo`00
o`000?ooool0T?ooool2ool00003o`000?oooooooooo04Sooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001Sooooo`03ool00?l0003o
oooo09?ooooo00?oo`00o`000?ooool0B?ooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0H_ooool00ooo003o0000ooooo`2E
ooooo`03ool00?l0003ooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0HOooool00ooo003o0000oooo
o`2Gooooo`03ool00?l0003ooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?oo`00o`000?ooool0VOoo
ool00ooo003o0000o`000015ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09[ooooo00?o
o`00ooooool00000A?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09_ooooo00?oo`00ooooool00000@ooo
ool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Mooooo`04ool00?oooooo
0000o`00047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Woooool0
1?oo003oooooooooool00010ooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0XOooool0
1?oo003oooooooooool0000oooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo0:Kooooo00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0ZOooool2o`0003_ooooo000Qooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03ool00?oooooooooo0:kooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000
ooooooooool0F?ooool00ol0003oo`00ooooo`2_ooooo`;oo`00>?ooool0027ooooo0ol0001Hoooo
o`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000oooooooo
ool0Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`00
0?oooooooooo05Kooooo00?oo`00ooooooooool0]Oooool00ooo003o0000ooooo`0cooooo`008Ooo
ool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo0;Oooooo0_oo000cooooo`008Oooool0
0ol0003oooooooooo`1Dooooo`03ool00?oooooooooo0;[ooooo00?oo`00ooooooooool0<?ooool0
027ooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`2kooooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool0_Oooool00ooo003o
ooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oo003ooooo0;oooooo
00?oo`00o`000?ooool0;Oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<3ooooo00?o
o`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?oMgMd0?Oooool4o`000003oa0@
4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02oooooo00?oo`00o`000?ooool02oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
o`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04o`000?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool0
6_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l00013ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`;o0000
1?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo000000?o0000?_ooool00omEEEGo
IVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000iooooo`;oo`000oooool01OnHV9So
410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0d_ooool00ooo003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo0=Cooooo00?oo`00ooooooooool07oooool0027ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`3Fooooo`;oo`007oooool0027ooooo00?o0000ooooooooool0BOooool0
0ooo003o0000ooooo`3Iooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3Jooooo`03ool00?oooooooooo
017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o
000004So000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb
<S85ooooo`008Oooool00ol0003oooooo`000016ooooo`03ool00?oooooooooo0?7ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000AOooool00ooo003oooooooooo`3loooo
o`008Oooool01?l0003oooooooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05
o`000?ooooooooooooooool00000@_ooool00ooo003oooooooooo`3mooooo`008Oooool01Ol0003o
oooooooooooooooo0000047ooooo00?oo`00ooooooooool0o_ooool0027ooooo0ol00002ooooo`03
o`000?oooooooooo03gooooo00?oo`00ooooooooool0ooooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0kooooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oo`00ooooo`0jooooo`03ool00?oooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooo
oooo0?oooooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0goooo
o`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
o`00ooooo`0fooooo`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool0
1_ooool00ol0003oo`00ooooo`0dooooo`03o`000?oooooooooo0?oooooo1Oooool0027ooooo0ol0
0007ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oo003ooooo037ooooo00?o0000ooooooooool0ooooool7
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo003ooooo033ooooo00?o0000oooo
ooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003ooooo02ko
oooo00?o0000ooooooooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`00
0?ooooooo`0002gooooo00?oo`00ooooooooool0ooooool9ooooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?ooooooo`0002_ooooo00?oo`00ooooooooool0ooooool:ooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?ooooooo`0002Wooooo00?oo`00ooooooooool0ooooool;
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?ooooooo`0002Oooooo00?oo`00oooo
ooooool0ooooool<ooooo`008Oooool3o`0000gooooo00?o0000ooooooooool09?ooool2ool00?oo
oooo3oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03ool0
0?l0003ooooo0?oooooo3oooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Pooooo`03ool00?l0003ooooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04?ooool2
o`0001oooooo00?oo`00o`000?ooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01_ooooo00?oo`00o`000?ooool0oooooolBooooo`008Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?oo`00o`000?ooool0oooooolCooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?oo`00o`000?ooool0
oooooolDooooo`008Oooool3o`0001Gooooo0_oo000Fooooo`03o`000?oooooooooo0?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool05_ooool00ol0003oo`00ooooo`0Booooo`;o0000oooooolH
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo003oo`00013ooooo00?o0000oooo
ooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Jooooo`?oo`002oooool2o`000?oo
oooo6oooool0027ooooo00?o0000ooooooooool06oooool2o`0000Soo`000ol0003ooooooagooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@04ooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o0000
5?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omE
EEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooo
oooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07
oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2oooo
o`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01Oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0
003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?oo
ool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool007_ooooo
00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo
00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Oooool00omgMgOo<S8boooo
o`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o
0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?o
MgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omE
EEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Doooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooM
gMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0D
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool0
2OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool4o`0007Kooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30003 L
.06244 .29044 L
.07286 .28645 L
.08255 .28366 L
.08813 .28249 L
.0932 .28169 L
.096 .28136 L
.09748 .28121 L
.09905 .28108 L
.10042 .28099 L
.10192 .2809 L
.1033 .28085 L
.10458 .28081 L
.10583 .28078 L
.10652 .28078 L
.10715 .28077 L
.10838 .28078 L
.10954 .28079 L
.1102 .2808 L
.1109 .28082 L
.11214 .28087 L
.11349 .28093 L
.11496 .28101 L
.11742 .28118 L
.12006 .28141 L
.12483 .28195 L
.13452 .28345 L
.14335 .28518 L
.16405 .28991 L
.1832 .29416 L
.19278 .29593 L
.20178 .29725 L
.2063 .29776 L
.21117 .2982 L
.2138 .29838 L
.21657 .29853 L
.21894 .29862 L
.22028 .29866 L
.22153 .29868 L
.2228 .2987 L
.22345 .2987 L
.22415 .2987 L
.22541 .29869 L
.22658 .29868 L
.22728 .29867 L
.22795 .29865 L
.22921 .29862 L
.23057 .29857 L
.23205 .2985 L
Mistroke
.23455 .29835 L
.2372 .29815 L
.24198 .29768 L
.24701 .29702 L
.25174 .29625 L
.26057 .29441 L
.27036 .2918 L
.28069 .28842 L
.29917 .28091 L
.3372 .26089 L
.37768 .2362 L
.41664 .21291 L
.45805 .1917 L
.47879 .18303 L
.49795 .17631 L
.51776 .17065 L
.53633 .16653 L
.55503 .16349 L
.56496 .16231 L
.5705 .16177 L
.57565 .16136 L
.58068 .16102 L
.58524 .16078 L
.59032 .16058 L
.5931 .1605 L
.59435 .16047 L
.59573 .16044 L
.59696 .16042 L
.59829 .16041 L
.59903 .1604 L
.59969 .16039 L
.601 .16039 L
.6022 .16038 L
.6035 .16039 L
.60473 .16039 L
.60586 .1604 L
.60717 .16041 L
.60839 .16043 L
.61118 .16048 L
.6139 .16056 L
.61684 .16066 L
.62179 .16087 L
.62639 .16113 L
.63686 .16192 L
.64705 .16295 L
.65795 .16434 L
.67927 .16791 L
.69941 .1723 L
.73785 .18339 L
.77873 .19891 L
Mistroke
.8181 .21704 L
.85596 .23679 L
.89627 .25969 L
.93506 .28317 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0:Gooooo7?l00023ooooo`008Oooool00ol0003oooooooooo`2Oooooo`Ko0000
7?ooool7o`0007cooooo000Qooooo`03o`000?oooooooooo09cooooo0ol0000Yooooo`?o0000NOoo
ool0027ooooo00?o0000ooooooooool0V?ooool4o`0001?ooooo4?oo000<ooooo`?o0000M_ooool0
027ooooo00?o0000ooooooooool0UOooool3o`0000Sooooo1Ooo000Jooooo`03ool00?oooooooooo
00cooooo0ol0001cooooo`008Oooool3o`0009;ooooo0ol00006ooooo`Goo`00:_ooool3ool000Co
oooo1?l0001_ooooo`008Oooool00ol0003oooooooooo`2?ooooo`?o00001Oooool4ool003;ooooo
0ooo0005ooooo`?o0000K?ooool0027ooooo00?o0000ooooooooool0SOooool2o`0000Kooooo0_oo
000iooooo`?oo`001Oooool3o`0006Wooooo000Qooooo`03o`000?oooooooooo08_ooooo0_l00016
ooooo`Goo`000oooool3o`0006Kooooo000Qooooo`03o`000?oooooooooo08Sooooo0ol0001=oooo
o`;oo`001?ooool2o`0006Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08Kooooo0_l00002
ooooo`;oo`00E?ooool3o`00067ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`24ooooo`;o00000_ooool2
ool005Wooooo0_l0001Oooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000P_ooool2o`0000;ooooo0_oo001Mooooo`;o0000GOooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0P?ooool2o`0000;ooooo0_oo001Mooooo`?oo`0000Coooooo`000?l0003o0000F_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`1nooooo`;o00000_ooool2ool006;ooooo0ooo00000ooooooo0000
o`00001Hooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1looooo`;o00000_ooool2ool006Oooooo0_oo00000ooooooo0000
o`00001Fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1jooooo`;o00000_ooool2ool006_ooooo0ooo0002o`0005Cooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
NOooool01Ol0003oooooooooooooooooo`00073ooooo00?oo`00ooooool000000_l0001Aooooo`00
8Oooool00ol0003oooooooooo`1gooooo`;o0000N_ooool2o`0004oooooo000Qooooo`03o`000?oo
oooooooo07Gooooo0_l0001nooooo`;o0000COooool0027ooooo0ol0001dooooo`03o`000?oooooo
oooo083ooooo0_l0001;ooooo`008Oooool00ol0003oooooooooo`1booooo`;o0000QOooool2o`00
04Wooooo000Qooooo`03o`000?oooooooooo073ooooo0_l00002ool008Cooooo0_oo00000ooooooo
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?ooooooo`0008Sooooo
0_oo0002o`0004Kooooo000Qooooo`03o`000?oooooooooo06gooooo0_l00002ool008_ooooo0_oo
0002o`0004Cooooo000Qooooo`03o`000?oooooooooo06_ooooo0_l000000oooooooo`00ooooo`2>
ooooo`03ool00?oooooo000004?ooooo000Qooooo`03o`000?oooooooooo06[ooooo00Co0000oooo
ooooooooo`00TOooool2ool000;o0000@Oooool0027ooooo0ol0001Xooooo`;o000000?oooooool0
0?oo0000U?ooool2ool000;o0000?oooool0027ooooo00?o0000ooooooooool0I_ooool2o`000003
oooooooo003oo`0009Sooooo0_oo00000ol0003oooooooooo`0looooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`04o`000?ooooooo`00ool009cooooo00?oo`00o`000?l00000??ooool0027ooooo
00?o0000ooooooooool0Hoooool2o`000003oooooooo003ooooo0:3ooooo00?o0000ooooooooool0
>Oooool0027ooooo00?o0000ooooooooool0HOooool2o`000:Kooooo0_l0000iooooo`008Oooool0
0ol0003oooooooooo`1Oooooo`;o0000Z_ooool00ol0003oooooooooo`0fooooo`008Oooool00ol0
003oooooooooo`1Mooooo`;o0000[Oooool2o`0003Kooooo000Qooooo`03o`000?oooooooooo05_o
oooo0_l0002aooooo`03o`000?oooooooooo03?ooooo000Qooooo`?o0000F_ooool00ol0003ooooo
ooooo`2booooo`;oo`00<oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`000003
oooooooo003oo`0003?ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`;oo`004Oooool5o`00
01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o000000?oooooool00?oo0000=oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
02_ooooo0_oo000?ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00Go0000ooooool0003o0000oooo
o`02ool003Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ool00?ooool03_ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo0000o`00
0002ooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0>ooooo`03ogMgMolb<S;ooooo02kooooo0_oo000>ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`06o`000?lQ
8B7o0000o`000?o<c<cooooo0_oo000looooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<037ooooo0_oo000=ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo00oooooo2_oo000Tooooo`05oa0@4?oooooooooooooo
ool@41003?ooool2o`0000;ooooo0_oo000nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0dooooo`03o`000?oo003ooooo00cooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000<ooooo`?oo`001ol000000ooooooo0000o`000008o`000003
oooooooo003oo`0000?oo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo0ol00003ool0
043ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Kooooo00?oo`00o`000?ooool01_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo00[ooooo0_oo0002o`0001?ooooo1Ol000000oooooooo`00ool00003ool0
017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o00000_ooool01?oo003o0000o`000?l0
000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003Kooooo00?o
o`00o`000?l000001Oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo0_oo000Looooo`?o00000oooool3ool001Wooooo0_l0003Eooooo`03o`000?oo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Qooooo`?o00000oooool4
ool000oooooo1_l0003Hooooo`;o00008_ooool0027ooooo00?o0000ooooooooool00_ooool3o`00
02Oooooo1ol0000:ooooo`Soo`00gOooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o
0000<Oooool:o`000>Oooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l00004ooooo`00
8Oooool3o`000?oooooo9_ooool2o`0001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4oooo
o`006_ooool7o`0000?oo`00ool0000Wo`0000;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b
<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>oooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_oo
ool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool0
1oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0
003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0
003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0B
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06oooo
o`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooo
oooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Noooool007kooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000007_ooooo001nooooo`04oeEEEOnYZJWo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo
00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo
00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05o`000?nHV9SooooooiRHV?lQ8B40Noooool007ko
oooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooooooo
ool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_oo
ool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Noooool007oooooo00?oV9RH
ogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7
o`0000;ooooo00?oMgMgoeEEEOooool04_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool0OOooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04
ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oM
gMd04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0OOooool009Ko
oooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRH
V?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@47_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27199 L
.06244 .23587 L
.08255 .20557 L
.09409 .19184 L
.10458 .18186 L
.11464 .17456 L
.11926 .17195 L
.12415 .16968 L
.12937 .16783 L
.13169 .16718 L
.13419 .16661 L
.13687 .16614 L
.13807 .16597 L
.13938 .16582 L
.14017 .16575 L
.14091 .16569 L
.14167 .16564 L
.14236 .16561 L
.14368 .16557 L
.14441 .16556 L
.14509 .16556 L
.14625 .16558 L
.1475 .16563 L
.14867 .16571 L
.14974 .16579 L
.15237 .1661 L
.15485 .1665 L
.15979 .16759 L
.16517 .16924 L
.17476 .17324 L
.18364 .17803 L
.2023 .19093 L
.22291 .2083 L
.26311 .24579 L
.3018 .27888 L
.32144 .29264 L
.34294 .30467 L
.35286 .30911 L
.36346 .31307 L
.3734 .31605 L
.38256 .3182 L
.3928 .31995 L
.3982 .32061 L
.40095 .32088 L
.40391 .32112 L
.4065 .32129 L
.40886 .32141 L
.41 .32146 L
.41124 .3215 L
Mistroke
.41241 .32154 L
.4135 .32156 L
.41417 .32157 L
.41489 .32159 L
.41616 .3216 L
.41687 .3216 L
.41763 .3216 L
.41827 .3216 L
.41898 .3216 L
.42025 .32158 L
.42096 .32157 L
.42161 .32156 L
.42406 .32149 L
.42635 .32141 L
.42888 .32128 L
.434 .32095 L
.43874 .32054 L
.44318 .32008 L
.46396 .31706 L
.48418 .31309 L
.5027 .30891 L
.54237 .29954 L
.58053 .29144 L
.60182 .28768 L
.62115 .2848 L
.6415 .2823 L
.66024 .28047 L
.67947 .27902 L
.69022 .27839 L
.70028 .27791 L
.70935 .27756 L
.71908 .27729 L
.72462 .27717 L
.72735 .27713 L
.72988 .2771 L
.73212 .27707 L
.7346 .27705 L
.73588 .27704 L
.73709 .27704 L
.73836 .27703 L
.73907 .27703 L
.73973 .27703 L
.74101 .27703 L
.74221 .27703 L
.74329 .27703 L
.74446 .27704 L
.74574 .27704 L
.74709 .27705 L
.74952 .27707 L
.75176 .27709 L
Mistroke
.75386 .27712 L
.75863 .27721 L
.76384 .27733 L
.7686 .27747 L
.77932 .2779 L
.78918 .27843 L
.79832 .27904 L
.81905 .28087 L
.83959 .28331 L
.8582 .28604 L
.89829 .29317 L
.93686 .30077 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001kooooo3?oo003ooooooa_o
oooo000Qooooo`03o`000?oooooooooo01cooooo0_oo00000ol0003oooooooooo`07ooooo`;o0000
00?oo`00o`000?ooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oo
oooooooo00kooooo0ol0003ooooooaKooooo000Qooooo`03o`000?oooooooooo01Wooooo0_l0000D
ooooo`;o0000oooooolDooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0oooooolAooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0ooooool@ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`;oo`00ooooool@ooooo`001Ol00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00005Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oo003oo`000?oooooo3_ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Nooooo`;o000000?oo`00ooooooooool0ooooool;ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00o`000?ooool08_ooool00ol0003oo`00ooooo`3oooooo`_ooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool08oooool00ol0003oo`00ooooo`3oooooo`[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`3oooooo`Sooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo0?oooooo1_ooool0
027ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo
0?oooooo1Oooool0027ooooo0ol0000>ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo
ool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo02oooooo
00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?l0
003ooooo037ooooo00?o0000ooooooooool0ooooool2ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0ooooool1ooooo`008Oooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo03Cooooo00?o0000ooooooooool0ooooool0027o
oooo00?o0000ooooooooool02_ooool00ooo003o0000ooooo`0fooooo`03o`000?oooooooooo0?ko
oooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00o`000?ooool0>?ooool00ol0003ooooo
ooooo`3mooooo`008Oooool3o`0000Wooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`3looooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0noooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0loooo
o`03ool00?l0003ooooo0?[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0?Oooool2ool00?[ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@?ooool00ooo003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo047ooooo00?oo`00ooooooooool0m_ooool0027ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`13ooooo`03ool00?oooooooooo0?Gooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0AOooool2ool00?Gooooo000Qooooo`?o00001Oooool00ol0003o
ooooooooo`16ooooo`03o`000?oo003ooooo0??ooooo000Qooooo`03o`000?oooooooooo00Cooooo
00?oo`00ooooooooool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003oo`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb
<S;ogMgMooooo`0looooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oo`00o`00
0?ooool0?_ooool00ol0003oooooooooo`0/ooooo`So00002oooool00ol0003oooooooooo`04oooo
o`;o8B4Q1_ooool;o`0003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@
ooooo`03ool00?l0003ooooo03gooooo00?o0000ooooooooool08Oooool;o`0001?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`Ko0000<Oooool00onHV9So8B4Qonk^kP0L
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;oo`0000;o0000??ooool00ol0003oooooooooo`0N
ooooo`?o00007_ooool00ol0003oooooooooo`06ooooo`Woo`0000?o<S8booooooooool02oooool6
o`0002cooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Iooooo`Go00004Ooo
ool?ool00003ooooool0003ooooo00cooooo00Co0000ob4Q8Ol0003o<S8b2Ooo000;ooooo`Ko0000
9oooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo03Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
0_l0000iooooo`03o`000?oooooooooo01Cooooo1Ol0000Eooooo`03ool00?oooooooooo00kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`Ooo`001_l0000Rooooo`03o`00
0?oooooooooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo013ooooo1?l0000<ooooo`Coo`006oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01_ooooo1_oo0006o`0001Sooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`00
8Oooool01Ol0003oooooooooooooooooo`0003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00002?ooool2o`0003Cooooo00?oEEEEofIVI_l000003_ooool4o`0000[ooooo1_oo000Moooo
o`03oeEEEOmVIVKo000000gooooo1?l0000Pooooo`?oo`000oooool5o`0001?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooooooooooo001Kooooo`;o0000?oooool4
o`0000Oooooo1ooo001Rooooo`Go0000;_ooool0027ooooo00?o0000oooooooo0000G?ooool2ool0
00;o0000>?ooool5o`0007Kooooo0ooo0004o`0002[ooooo000Qooooo`03o`000?ooooooo`0005ko
oooo0_oo0003o`00037ooooo1?l0001nooooo`?oo`0000?oooooo`000?l000000_l0000Vooooo`00
8Oooool00ol0003oo`00ooooo`1Pooooo`03ool00?oooooooooo00?o0000:Oooool5o`0000Oooooo
1?oo001jooooo`Ooo`000_l0000Hooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo
003ooooo067ooooo0ooo0002ooooo`?o00008?ooool6o`0000Oooooo1Ooo0025ooooo`Coo`000_l0
000Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000
o`00001To`0000;oo`00:ol00005ool009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00Oooooo5Ol0000;ooooo`;oo`00
00?oooooo`000?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGo
oooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo00000ooo0009ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0
P_ooool3ool00;Gooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0MOoo
ool=ool00<;ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMg
ooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^
kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool0
0omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oo
oooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`00
0?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002oooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05
ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool0
0004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo
00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4104ooooo`Co0000M_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .2282 L
.08255 .19146 L
.10458 .15819 L
.11448 .14607 L
.12507 .13522 L
.13499 .12711 L
.14415 .12143 L
.14911 .11909 L
.15437 .11716 L
.15709 .11639 L
.15964 .1158 L
.16245 .11531 L
.16402 .1151 L
.16546 .11496 L
.1667 .11487 L
.16802 .1148 L
.16926 .11478 L
.17039 .11478 L
.17109 .11479 L
.17173 .11481 L
.17243 .11485 L
.17317 .11489 L
.17441 .11499 L
.17578 .11513 L
.17823 .11548 L
.18086 .11598 L
.1856 .11722 L
.19088 .11909 L
.19577 .12126 L
.20684 .12769 L
.22696 .14425 L
.24562 .16432 L
.26622 .19047 L
.30643 .24823 L
.34512 .30452 L
.38626 .35718 L
.40678 .37897 L
.42588 .39611 L
.44548 .41045 L
.46399 .42098 L
.4738 .42542 L
.48444 .42938 L
.49405 .43223 L
.50303 .4343 L
.5125 .4359 L
.51752 .43652 L
.52291 .43702 L
.52561 .4372 L
.52855 .43736 L
Mistroke
.5299 .43742 L
.53133 .43746 L
.53268 .4375 L
.5339 .43752 L
.5352 .43754 L
.53639 .43755 L
.5377 .43755 L
.53836 .43755 L
.53908 .43754 L
.5403 .43753 L
.5416 .4375 L
.54283 .43747 L
.54395 .43744 L
.54625 .43735 L
.54877 .43723 L
.55389 .4369 L
.55863 .43649 L
.56307 .43603 L
.58385 .43298 L
.60407 .42887 L
.62259 .42442 L
.66227 .41361 L
.70043 .40257 L
.74104 .39062 L
.78014 .37884 L
.82169 .36563 L
.86172 .35195 L
.90024 .33794 L
.94121 .32244 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09oooool9o`000?oooooo5Oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`06ooooo`?oo`0000?o0000ooooooooool0ooooool@ooooo`008Oooool3o`0002;o
oooo0_l00002ool000cooooo00Coo`00o`000?l0003o0000ooooool?ooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oo003oo`0000oooooo0_oo00000ooooooo0000ooooo`3oooooo`go
oooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ool00?ooool04_ooool2ool00003o`00
0?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool07oooool2ool001Kooooo0_oo
003oooooo`cooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool06?ooool0
0ooo003o0000ooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00oooo
ooooool06_ooool00ooo003o0000ooooo`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo01co
oooo00?oo`00ooooooooool07?ooool00ooo003o0000ooooo`3oooooo`Oooooo000Qooooo`?o0000
6oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o
0000ooooooooool06_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo0?oooooo1Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Qooooo`03o`000?oooooo
oooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Soooo
o`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3o
ooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3noooo
o`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo00?oo`00oooooooo
ool0oOooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0]ooooo`03ool0
0?l0003ooooo0?gooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;ooo
ool00ooo003o0000ooooo`3looooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo037ooooo00?oo`00o`000?ooool0noooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_oo
ool00ooo003oooooooooo`0booooo`03ool00?l0003ooooo0?[ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Aooooo`03ool00?l0003ooooo03Cooooo00?oo`00ooooooooool0nOooool000Go00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo00?o
o`00ooooooooool0=Oooool00ooo003oooooooooo`3hooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo03Kooooo00?oo`00o`000?ooool0n?ooool000Oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo03Oooooo00?oo`00ooooooooool0moooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003ooooo
ooooo`0iooooo`03ool00?oooooooooo0?Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ool00?ooool0
>_ooool00ooo003o0000ooooo`3fooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0>oooool00ooo003o0000
ooooo`3eooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03gooooo00?o
o`00ooooooooool0m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oo`00ooooo`0o
ooooo`03o`000?oooooooooo0??ooooo000Qooooo`?o00003?ooool00ooo003oooooooooo`10oooo
o`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?oo
ool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0>ko
oooo000Qooooo`?o00002?ooool00ol0003oooooooooo`18ooooo`03ool00?l0003ooooo0>kooooo
000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool00ooo003ooooooooo
o`3]ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?oo`00
ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1=oooo
o`03ool00?oooooooooo0>_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0COooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oo003ooooo04oooooo00?oo`00ooooooooool0j_ooool0027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>Wooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ool00?ooool0DOooool00ooo003o0000ooooo`3Yooooo`008Oooool3o`00
00Cooooo00?o0000ool00?ooool0D_ooool00ooo003oooooooooo`3Xooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?oo`00o`000?ooool0=?ooool4
o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03o`000?oo003ooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`06ooooo`03ool00?l0003ooooo03Gooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`06ooooo`03ool0
0?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_oo
ool00ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`07ooooo`03ool00?l0003ooooo03Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o
0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?oo`00o`000?ooool0<oooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010oooo
o`03ogMgMomVIVKooooo01[ooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Go0000oooooooooooo0000
ool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000gooooo00?o0000oooooooo
ool0;_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00Co0000ooooooooooooo`00Goooool00ol0
003oooooooooo`3Qooooo`008Oooool01?l0003oooooo`000?oo001Pooooo`03o`000?oooooooooo
0>3ooooo000Qooooo`03o`000?ooooooo`00067ooooo00?o0000ooooooooool0h?ooool0027ooooo
0_l0001Sooooo`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
001Tooooo`03o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
6_oooom]o`000003ool00?l0003o00000<3o00000_oo0007o`0000cooooo00CogMgMo`000?l@413o
c<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ooo003oooooo`00000>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`05o`00
0?oo003oo`00ooooool000004oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`03ool00?l0003ooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Co0000ool00?oo003oo`000oooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo
06Gooooo00?oo`00o`000?ooool0]Oooool2o`0000;oo`006Oooool2o`0000;ooooo0_l00004oooo
o`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?l0003ooooo0;3ooooo1?l000000ooooooo
o`00ooooo`0Tooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooo00000:gooooo
0ol0000[ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooo00000:Wooooo0ol0
000^ooooo`008Oooool00ol0003oooooooooo`1Xooooo`03ool00?l0003ooooo0:Gooooo0ol0000a
ooooo`008Oooool3o`0006Wooooo00?oo`00o`000?ooool0X?ooool4o`0000;ooooo0ooo000_oooo
o`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooo000009cooooo1?l00002ooooo`Co
o`00<_ooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooo`00002Gooooo`Co0000
0oooool3ool003Kooooo000Qooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooool00000Tooo
ool3o`0000Gooooo0_oo000iooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?l0003o
oooo08oooooo0ol00005ooooo`?oo`00>oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`2:ooooo`?o00001oooool00ooo003oooooooooo`0looooo`008Oooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo08Kooooo0ol00019ooooo`008Oooool3o`00073ooooo
00?o0000ooooooooool0POooool4o`0004cooooo000Qooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool0OOooool3o`00053ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool0NOooool3o`0000Sooooo0ooo0018ooooo`008Oooool00ol0003oooooooooo`1coooo
o`;o0000M_ooool3o`0000Oooooo1?oo001;ooooo`008Oooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo06oooooo1?l00006ooooo`Coo`00Coooool0027ooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`1[ooooo`?o00001oooool3ool005?ooooo000Qooooo`03o`000?oo
oooooooo07?ooooo0_oo0002ooooo`03o`000?oooooooooo06Oooooo0ol00008ooooo`;oo`00E_oo
ool0027ooooo00?o0000ooooooooool0MOooool01?oo003oooooooooool0001Uooooo`?o0000Hooo
ool0027ooooo0ol0001fooooo`04ool00?ooooooooooo`00067ooooo0ol0001Vooooo`008Oooool0
0ol0003oooooooooo`1gooooo`03ool00?oooooooooo00;o0000G?ooool3o`0006Wooooo000Qoooo
o`03o`000?oooooooooo07Sooooo00Goo`00ooooooooooooooooo`00001Hooooo`?o00001oooool3
ool006;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00Coo`00oooooooooooooooo0_l0001C
ooooo`?o00001_ooool4ool006Gooooo000Qooooo`03o`000?oooooooooo07[ooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`1=ooooo`?o00001Oooool4ool006Wooooo000Qooooo`03
o`000?oooooooooo07_ooooo0_oo0003ooooo`;o0000B_ooool3o`0000Gooooo0ooo001]ooooo`00
8Oooool00ol0003oooooooooo`1mooooo`03ool00?oooooooooo00;ooooo0_l00015ooooo`?o0000
1_ooool2ool0073ooooo000Qooooo`?o0000O_ooool00ooo003oooooooooo`03ooooo`;o0000@?oo
ool3o`0007_ooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool01?ooool2
o`0003[ooooo1?l0001nooooo`008Oooool00ol0003oooooooooo`28ooooo`;o0000<oooool5o`00
00Gooooo0_oo001kooooo`008Oooool00ol0003oooooooooo`2:ooooo`;o0000;Oooool4o`0000Ko
oooo1?oo001mooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o00009_ooool4o`0000Kooooo
1?oo0021ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2?ooooo`?o00007Oooool6o`0000Ko
oooo1?oo0025ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0ROooool00ooo003oooooooooo`06ooooo`Oo
00004Oooool5o`0000[ooooo0_oo0029ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`0008[ooooo0ooo000<oooooa7o0000V_ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0SOooool3ool00;Cooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0T?ooool6ool001?ooooo1_oo002Eoooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Fooooo`?oo`001_ooool:ool009_ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o0000
4oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mE
EEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02
ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`1kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH0
0oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003o
gMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00Ko
EEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_oooooo
MgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001noooo
o`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^
kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04Oooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool0Noooool007kooooo00CoEEEEojVYZOoooooo
00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^
k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00cooooo00?o8B4Qooooooooool0N_ooool007kooooo00?ogMgMob4Q
8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omE
EEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oM
gMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool0
0omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGo
oooo01;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo07[ooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oo
oooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80Noooool009Kooooo00?o0000oooo
ooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q
8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
0000Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25452 L
.10458 .20111 L
.12507 .17917 L
.14415 .16236 L
.16254 .15021 L
.17284 .14535 L
.1773 .1437 L
.18221 .14222 L
.18704 .1411 L
.18969 .14063 L
.19216 .14028 L
.19335 .14015 L
.19448 .14004 L
.1955 .13996 L
.19659 .13989 L
.19777 .13984 L
.19887 .1398 L
.20017 .13979 L
.20135 .1398 L
.20266 .13983 L
.20331 .13986 L
.20403 .13989 L
.20531 .13997 L
.2065 .14007 L
.20918 .14037 L
.21206 .14081 L
.21733 .14194 L
.22214 .14332 L
.23205 .14724 L
.24122 .1521 L
.26198 .16731 L
.28065 .18551 L
.30125 .20983 L
.34145 .26663 L
.38014 .32713 L
.42128 .39051 L
.4609 .44482 L
.49901 .48706 L
.52026 .50556 L
.53957 .51906 L
.54921 .52461 L
.55966 .52974 L
.56945 .53372 L
.57862 .53674 L
.58808 .53914 L
.5931 .54014 L
.59849 .54098 L
.60119 .54133 L
.60414 .54164 L
Mistroke
.60673 .54186 L
.60815 .54196 L
.60949 .54204 L
.61081 .54211 L
.61223 .54217 L
.61352 .54221 L
.6147 .54223 L
.61583 .54225 L
.61706 .54226 L
.61834 .54226 L
.61954 .54224 L
.6208 .54222 L
.62144 .5422 L
.62215 .54218 L
.62456 .54208 L
.62592 .542 L
.62738 .54191 L
.63002 .5417 L
.63519 .54117 L
.63993 .54053 L
.64898 .53891 L
.6585 .53669 L
.67828 .53046 L
.69666 .52291 L
.73576 .50216 L
.77731 .47473 L
.81734 .44464 L
.85586 .41344 L
.89683 .37867 L
.93629 .34424 L
.97422 .31075 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo033ooooo2ol0003oooooo`[o
oooo000Qooooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`?o0000ooooool7ooooo`008Ooo
ool3o`0002_ooooo0ol0000:ooooo`?oo`000oooool3o`000?oooooo1?ooool0027ooooo00?o0000
ooooooooool0:?ooool3o`0000Coo`003?ooool3ool000?ooooo0_l0003oooooo`;ooooo000Qoooo
o`03o`000?oooooooooo02Oooooo00Co0000ooooooooooooo`004oooool3ool000;ooooo00?o0000
ooooooooool0o_ooool0027ooooo00?o0000ooooooooool09Oooool2o`000003oooooooo003oo`00
01Oooooo0_oo00000ooooooo0000o`00003nooooo`008Oooool00ol0003oooooooooo`0Tooooo`04
o`000?ooooooooooool001_ooooo00Coo`00oooooooooooo0000oOooool0027ooooo00?o0000oooo
ooooool08_ooool2o`000003oooooooo003oo`0001gooooo00Coo`00oooooooooooo0000o?ooool0
027ooooo00?o0000ooooooooool08Oooool01?l0003ooooooooooooo000Pooooo`04ool00?oooooo
ooooo`000?_ooooo000Qooooo`03o`000?oooooooooo023ooooo00Co0000oooooooo003oo`008_oo
ool01?oo003oooooooooool0003jooooo`008Oooool3o`0001oooooo00?o0000oooooooo0000:?oo
ool00ol0003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
o`0002[ooooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo0?Gooooo000Qooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3dooooo`008Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0loooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?;o
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo037ooooo00?oo`00ooooool0
0000loooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool3o`0001Wooooo00?o0000ooooooooool0<_ooool01?oo003oooooooooool0003boooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00Coo`00oooooooooooo0000lOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?ooooooo`0003Kooooo00Coo`00oooooooooooo0000
l?ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool05oooool00ol0003oo`00ooooo`0gooooo`04ool00?ooooooooooo`000>oo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Kooooo00?o0000ool00?ooool0>Oooool00ooo003oooooo`00003_ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Go
oooo00?o0000oooooooo0000>oooool00ooo003oooooo`00003^ooooo`008Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?ooooooo`0003gooooo00?oo`00ooooool00000kOooool0027ooooo00?o
0000ooooooooool04oooool00ol0003oooooool0000nooooo`03ool00?oooooo00000>gooooo000Q
ooooo`?o00004_ooool00ol0003oooooool00010ooooo`03ool00?oooooo00000>cooooo000Qoooo
o`03o`000?oooooooooo01;ooooo00?o0000ool00?ooool0@Oooool00ooo003oooooo`00003[oooo
o`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?ooooooo`0004;ooooo00Coo`00oooooooo
oooo0000j_ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003oooooool00014ooooo`03
ool00?oooooo00000>[ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo0000
A_ooool00ooo003oooooo`00003Yooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
ooooo`0004[ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool03_ooool0
0ol0003oo`00ooooo`1:ooooo`03o`000?oooooooooo0>Kooooo000Qooooo`?o00003Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0hoooool0027ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0>?ooooo000Q
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3R
ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0hOooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03
ool00?oooooo00000>?ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0
EOooool00ooo003oooooo`00003Rooooo`008Oooool3o`0000Oooooo00?o0000ool00?ooool0E_oo
ool00ooo003o0000ooooo`3Qooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003o
oooo03Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00kooooo00?oo`00o`000?ooool0;?ooool4o`000003oa0@4?oooooooooo03_ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03go
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo03Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0=ooooo`03
ool00?oooooo000002kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`0eooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo02gooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oo`00ooooo`0fooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0?ooooo`03ool00?l0003ooooo
02cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00oooool00ol0003o
o`00ooooo`0gooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<013ooooo00?oo`00o`000?ooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool04oooool00ooo003o0000ooooo`0[ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o00000_ooool00ol0003oo`00ooooo`0hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo02_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go
0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00004oooool00ooo003o0000ooooo`0Xoooo
o`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool01Ol0003oooooooooooooooooo`0006Cooooo00?oo`00
o`000?ooool0foooool0027ooooo00Go0000oooooooooooo0000ool0001Tooooo`03ool00?l0003o
oooo0=_ooooo000Qooooo`04o`000?oooooo0000ool006Kooooo00?oo`00o`000?ooool0f_ooool0
027ooooo00?o0000oooooooo0000J?ooool00ol0003oooooooooo`3?ooooo`;o00000_ooool2o`00
00Cooooo000Qooooo`;o0000J_ooool00ol0003oooooooooo`3>ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1?ooool001[oooooool0000bo`000003ool00?l0003o000000Go00003?ooool01?oM
gMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02_ooool2ool00003o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Wooooo00Coo`00oooooooooooo00004oooool01?lQ8B7oMgMgogMgMolb
<S85ooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo0;Gooooo00?oo`00
ooooooooool05?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo023ooooo000Qooooo`03o`00
0?oooooooooo06cooooo0_oo002booooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oo
oooooooo06gooooo00?oo`00o`000?ooool0[oooool00ol0003oooooooooo`0Rooooo`008Oooool3
o`0006kooooo00?oo`00ooooooooool0[Oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`1_ooooo`03ool00?oooooooooo0:_ooooo00?o0000ooooooooool09?ooool0027o
oooo00?o0000ooooooooool0Koooool00ooo003o0000ooooo`2Zooooo`03o`000?oooooooooo02Go
oooo000Qooooo`03o`000?oooooooooo073ooooo00?oo`00ooooooooool0Y_ooool3ool002Sooooo
000Qooooo`03o`000?oooooooooo073ooooo00?oo`00o`000?ooool0YOooool00ooo003o0000o`00
000Yooooo`008Oooool00ol0003oooooooooo`1aooooo`03ool00?l0003ooooo0:?ooooo00?oo`00
o`000?ooool0:_ooool0027ooooo00?o0000ooooooooool0L_ooool00ooo003o0000ooooo`2Qoooo
o`03ool00?l0003ooooo02_ooooo000Qooooo`?o0000L_ooool00ooo003o0000ooooo`2Pooooo`03
ool00?l0003ooooo02cooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00o`000?ooool0
W_ooool00ooo003o0000ooooo`0]ooooo`008Oooool00ol0003oooooooooo`1cooooo`03ool00?oo
oooo000009gooooo00?oo`00o`000?ooool0;_ooool0027ooooo00?o0000ooooooooool0M?ooool0
0ooo003o0000ooooo`2Kooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo
07Gooooo00?oo`00o`000?ooool0VOooool00ooo003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`1gooooo`03o`000?oooooooooo09Kooooo00?oo`00ooooooooool0<Oooool0027ooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo03;ooooo
000Qooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0T_ooool2o`0003Gooooo000Q
ooooo`?o0000NOooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Gooooo000Qoooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0foooo
o`008Oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo08gooooo00?o0000oooooooo
ool0=oooool0027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0ROoo
ool2o`0003_ooooo000Qooooo`03o`000?oooooooooo07_ooooo00?oo`00o`000?ooool0R?ooool2
ool003cooooo000Qooooo`03o`000?oooooooooo07_ooooo00?oo`00ooooool00000Qoooool00ooo
003oooooooooo`0looooo`008Oooool3o`0007cooooo00?oo`00ooooool00000QOooool00ooo003o
ooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1mooooo`03ool00?l0003ooooo08?ooooo
00?oo`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0OOooool00ooo003oooooo`00
0021ooooo`03o`000?oo003ooooo043ooooo000Qooooo`03o`000?oooooooooo07kooooo00?oo`00
ooooool00000Ooooool2ool004;ooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00o`00
0?ooool0OOooool00ooo003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`20
ooooo`03ool00?l0003ooooo07[ooooo00?o0000ool00?ooool0A?ooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo083ooooo00?oo`00ooooool00000NOooool00ol0003oo`00ooooo`15ooooo`001oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00087ooooo00?oo`00
ooooool00000Moooool00ol0003oo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`22ooooo`03ool00?l0003o
oooo07Gooooo00?o0000ool00?ooool0Aoooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`22ooooo`03ool00?oo
oooo000007?ooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`23ooooo`03ool00?oooooo0000077ooooo00?o
0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Q?ooool00ooo003o0000ooooo`1_ooooo`03o`000?oo
oooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`1[ooooo`;o0000C_ooool0027ooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04kooooo000Qoooo
o`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1?oooo
o`008Oooool3o`0008Sooooo00?o0000ooooooooool0IOooool2o`0000;oo`00D?ooool0027ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`1Sooooo`03o`000?ooooooo`0005;ooooo
000Qooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0HOooool00ol0003oo`00ool0
001Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo05kooooo0_l00000
0ooo003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03ool00?l0003ooooo
05gooooo00?o0000oooooooo0000E_ooool0027ooooo00?o0000ooooooooool0S?ooool00ooo003o
0000ooooo`1Kooooo`03o`000?oo003oo`0005Oooooo000Qooooo`03o`000?oooooooooo08gooooo
00?oo`00o`000?ooool0F?ooool2o`000003ool00?oooooooooo05Oooooo000Qooooo`?o0000S_oo
ool00ooo003o0000ooooo`1Eooooo`;o00000_oo001Jooooo`008Oooool00ol0003oooooooooo`2?
ooooo`03ool00?l0003ooooo05;ooooo0_l000000oooooooo`00ooooo`1Kooooo`008Oooool00ol0
003oooooooooo`2@ooooo`03ool00?l0003o000004oooooo0_l00002ooooo`03ool00?oooooooooo
05_ooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooool00000COooool00ol0003o
ooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`2Booooo`04ool00?oooooo0000o`0004Wo
oooo0_l0001Sooooo`008Oooool00ol0003oooooooooo`2Cooooo`04ool00?ooooooooooo`0004Ko
oooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Dooooo`04ool00?ooooooooooo`0004?o
oooo0_l0001Wooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo00;o0000
?oooool2o`0006Wooooo000Qooooo`?o0000U_ooool01Ooo003ooooooooooooooooo000003cooooo
0_l00004ooooo`03ool00?oooooooooo06Cooooo000Qooooo`03o`000?oooooooooo09_ooooo0_l0
000hooooo`;o00001?ooool2ool006Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`;oo`00JOooool0027ooooo00?o0000oooo
ooooool0W_ooool2o`0003;ooooo0_l00003ooooo`;oo`00Joooool0027ooooo00?o0000oooooooo
ool0X?ooool2o`0002kooooo0_l00002ooooo`?oo`00KOooool0027ooooo00?o0000ooooooooool0
X_ooool2o`0002[ooooo0_l00002ooooo`;oo`00L?ooool0027ooooo00?o0000ooooooooool0Wooo
ool00ooo003oooooooooo`02ooooo`?o00009?ooool3o`0000;ooooo0_oo001booooo`008Oooool3
o`000:3ooooo00?oo`00ooooooooool01?ooool3o`0001kooooo0ol00004ooooo`03ool00?oooooo
oooo07;ooooo000Qooooo`03o`000?oooooooooo0:7ooooo0ooo0006ooooo`?o00006?ooool3o`00
07cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0ooo0006ooooo`?o00003oooool6o`0007oo
oooo000Qooooo`03o`000?oooooooooo0:Oooooo00?oo`00ooooooooool01_ooool?o`0008Gooooo
000Qooooo`03o`000?oooooooooo0:Sooooo1_oo000Eooooo`?oo`00O_ooool001Sooooo1?l00000
0ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool03oooool3
ool0087ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]Oooool;ool0
08Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMg
Moooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^
k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b
<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool0
0onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWo
oooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooo
oooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1d
ooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?o
V9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000oooooooo
ool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=oooo
o`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04oooo
o`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:
ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo
0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^
k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^
k_l0003ooooo01?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Co
oooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomE
EED05?ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?o
oooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@
4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[Zj
odA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03
ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`00
07Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29243 L
.10458 .27268 L
.14415 .25276 L
.18221 .23522 L
.20178 .22811 L
.21274 .225 L
.21758 .22385 L
.22272 .22281 L
.22745 .222 L
.23267 .2213 L
.23496 .22105 L
.23742 .22083 L
.23974 .22067 L
.24186 .22055 L
.24314 .2205 L
.24384 .22048 L
.24451 .22046 L
.24579 .22044 L
.24696 .22043 L
.24763 .22043 L
.24835 .22043 L
.24963 .22045 L
.25034 .22047 L
.25101 .22048 L
.25252 .22054 L
.25383 .2206 L
.25508 .22068 L
.25741 .22085 L
.25992 .22109 L
.26265 .22141 L
.26749 .22215 L
.27205 .22304 L
.28242 .22576 L
.29253 .22939 L
.30343 .23437 L
.32347 .24644 L
.34457 .26309 L
.38268 .30223 L
.42324 .35344 L
.46228 .40714 L
.50378 .46295 L
.54376 .51004 L
.58223 .5451 L
.6021 .55839 L
.61225 .56382 L
.62315 .56859 L
.63338 .57206 L
.64272 .5744 L
.64722 .57523 L
Mistroke
.64959 .57559 L
.65212 .57593 L
.65455 .57619 L
.65674 .57638 L
.65896 .57653 L
.66004 .57659 L
.66104 .57663 L
.6622 .57667 L
.66345 .5767 L
.66461 .57672 L
.66571 .57672 L
.66698 .57671 L
.66816 .57668 L
.66945 .57664 L
.67082 .57659 L
.67336 .57644 L
.67574 .57624 L
.68115 .57562 L
.6858 .57489 L
.69005 .57406 L
.69964 .57163 L
.70947 .56838 L
.7186 .56469 L
.73931 .55407 L
.77841 .52656 L
.81996 .48883 L
.86 .44661 L
.89851 .4025 L
.93949 .35357 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0koooo
oa3o0000nOooool0027ooooo0ol0000gooooo`Co00004?ooool5o`000?Cooooo000Qooooo`03o`00
0?oooooooooo03Cooooo0ol0000Iooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oo
oooooooo037ooooo0ol0000;ooooo`coo`001_ooool3o`000?3ooooo000Qooooo`03o`000?oooooo
oooo02kooooo0ol0000Jooooo`Coo`001Oooool3o`000>gooooo000Qooooo`03o`000?oooooooooo
02cooooo0_l00005ooooo`;oo`008_ooool00ol0003oooooooooo`3Zooooo`008Oooool00ol0003o
ooooooooo`0Zooooo`;o00001?ooool3ool002Gooooo0_l0003Zooooo`008Oooool00ol0003ooooo
ooooo`0Xooooo`;o00001?ooool2ool002[ooooo00?o0000ooooooooool0ioooool0027ooooo0ol0
000Vooooo`;o00001?ooool2ool002gooooo0_l0003Wooooo`008Oooool00ol0003oooooooooo`0T
ooooo`;o00001?ooool2ool002cooooo0_oo0003ooooo`03o`000?oooooooooo0>Cooooo000Qoooo
o`03o`000?oooooooooo02;ooooo0_l00005ooooo`03ool00?oooooooooo02kooooo00Coo`00oooo
oooooooooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool2ool0
03;ooooo0_oo0003ooooo`03o`000?oooooooooo0>7ooooo000Qooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0dooooo`05ool00?oooooooooooooo
ool00000h_ooool0027ooooo00?o0000ooooooooool07Oooool2o`0003oooooo0_oo0002ooooo`03
o`000?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo0_l00013ooooo`03ool0
0?oooooo00000>7ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?oo
ool00ooo003oooooo`00003Pooooo`008Oooool3o`0001Sooooo0_l000000oooooooo`00ool00015
ooooo`03ool00?oooooo00000=oooooo000Qooooo`03o`000?oooooooooo01Kooooo0_l000000ooo
ooooo`00ool0000Rooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0?ooooo`04ool00?ooooooooooo`0002[ooooo1?l000000ol@413ooooo
ooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool05?ooool2o`0000;ooooo
00?oo`00ooooooooool08_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00oooooo00Coo`00oooooooooooo0000:oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0Booooo`;o00000_ooool2ool0
02Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00oooooo00Coo`00
oooooooooooo0000:_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0@
ooooo`;o00000_ooool2ool002Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo01Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool0
0ol0003oooooooooo`0>ooooo`;o000000Coooooool00?oo003oo`00:Oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0<ooooo`;o
000000?oooooool00?oo0000;?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
00002_ooool2o`0000;ooooo00?oo`00ooooooooool0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02?ooool2o`0003?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00006Oooool00ol0003oooooooooo`0Rooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;o0000I?ooool00ol0003oooooooooo`3E
ooooo`008Oooool00ol0003oooooooooo`04ooooo`;o0000Ioooool00ol0003oooooooooo`3Doooo
o`008Oooool00ol0003oooooooooo`02ooooo`;o0000J?ooool00ooo003o0000ooooo`3Eooooo`00
8Oooool00ol0003oooooooooo`02o`0000?oo`00J?ooool00ooo003o0000ooooo`3:ooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`;o00000ooo001[ooooo`03ool00?oooooo00000<[ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`0000;oo`00Kol000000ooo003o0000
o`00002fo`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`000?ooool0
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool01Ooo003o0000oooooooooooo000000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo01;o
oooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0LOooool00ooo003o
0000ooooo`2aooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo
00?o0000ooooooooool0L_ooool00ooo003o0000ooooo`2_ooooo`03ool00?oooooooooo01gooooo
000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooool00000[_ooool00ooo003ooooooooo
o`0Nooooo`008Oooool00ol0003oooooooooo`1cooooo`03ool00?l0003ooooo0:gooooo00?oo`00
ooooooooool07_ooool0027ooooo00?o0000ooooooooool0M?ooool00ooo003o0000ooooo`2[oooo
o`03ool00?oooooooooo01oooooo000Qooooo`?o0000MOooool00ooo003o0000ooooo`2Yooooo`03
ool00?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00o`000?ooool0
Yoooool00ooo003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo0:Gooooo00?oo`00o`000?ooool08_ooool0027ooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool09?ooool0027ooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo02Gooooo
000Qooooo`?o0000Noooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Q
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0V
ooooo`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo09_ooooo00?o0000oooo
ooooool09oooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003o0000ooooo`2Jooooo`03
o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00o`000?ooool0
V?ooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0
003ooooo09Kooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o0000ooooooooool0O_ooool0
0ooo003o0000ooooo`2Eooooo`03o`000?oo003ooooo02_ooooo000Qooooo`03o`000?oooooooooo
07oooooo00?oo`00o`000?ooool0Toooool00ol0003oo`00ooooo`0/ooooo`008Oooool3o`00083o
oooo00?oo`00o`000?ooool0T_ooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`21ooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool0;Oooool0027ooooo00?o
0000ooooooooool0POooool00ooo003o0000ooooo`2?ooooo`03ool00?oooooooooo02kooooo000Q
ooooo`03o`000?oooooooooo08;ooooo00?oo`00o`000?ooool0SOooool00ol0003oo`00ooooo`0_
ooooo`008Oooool00ol0003oooooooooo`23ooooo`03ool00?l0003ooooo08_ooooo00?o0000ool0
0?ooool0<?ooool0027ooooo00?o0000ooooooooool0Poooool00ooo003o0000ooooo`2:ooooo`03
o`000?oo003ooooo037ooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00o`000?ooool0
R?ooool00ol0003oo`00ooooo`0booooo`008Oooool3o`0008Gooooo00?oo`00o`000?ooool0Qooo
ool00ooo003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo08Gooooo00?oo`00ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0=_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo03Ko
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool0=oooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0002;ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0>?ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0S?ooool00ooo003oooooooooo`1gooooo`03ool00?l0003ooooo03_ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
08cooooo00?oo`00o`000?ooool0M_ooool00ooo003oooooo`00000looooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=oooo
o`03ool00?l0003ooooo07Cooooo00?oo`00ooooool00000?Oooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2>ooooo`03ool00?oooooooooo
07;ooooo00?oo`00ooooool00000?_ooool0027ooooo00?o0000ooooooooool0Soooool00ooo003o
ooooooooo`1`ooooo`03ool00?oooooo000003oooooo000Qooooo`03o`000?oooooooooo093ooooo
00?oo`00ooooooooool0Koooool00ooo003o0000ooooo`0oooooo`008Oooool3o`00093ooooo00?o
o`00ooooooooool0K_ooool00ooo003o0000ooooo`10ooooo`008Oooool00ol0003oooooooooo`2A
ooooo`03ool00?oooooooooo06cooooo00?oo`00o`000?ooool0@Oooool0027ooooo00?o0000oooo
ooooool0T_ooool00ooo003oooooooooo`1Zooooo`03ool00?l0003ooooo04;ooooo000Qooooo`03
o`000?oooooooooo09?ooooo00?oo`00ooooooooool0J?ooool00ooo003o0000ooooo`13ooooo`00
8Oooool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo06Oooooo00?oo`00o`000?ooool0
A?ooool0027ooooo00?o0000ooooooooool0U?ooool00ooo003oooooooooo`1Uooooo`03ool00?l0
003ooooo04Gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0I?ooool0
0ol0003oooooooooo`15ooooo`008Oooool3o`0009Kooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`16ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0V?ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo05Wooooo0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`1Eooooo`;oo`00Coooool0027ooooo00?o0000ooooooooool0
W?ooool00ol0003oo`00ooooo`1Cooooo`03ool00?l0003ooooo04oooooo000Qooooo`?o0000WOoo
ool00ooo003oooooooooo`1Aooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`000?oooooo
oooo09kooooo00?oo`00ooooooooool0Coooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0
003oooooooooo`2Oooooo`03ool00?oooooooooo04gooooo00?oo`00ooooooooool0D_ooool0027o
oooo00?o0000ooooooooool0X?ooool2ool004cooooo00?oo`00ooooooooool0Doooool0027ooooo
00?o0000ooooooooool0X_ooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo05Cooooo
000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0A_ooool00ooo003ooooooooo
o`1Eooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo04Cooooo00?oo`00
ooooooooool0E_ooool0027ooooo0ol0002Uooooo`03ool00?oooooooooo047ooooo00?o0000ool0
0?ooool0F?ooool0027ooooo00?o0000ooooooooool0Y_ooool00ooo003o0000ooooo`0oooooo`03
o`000?oo003ooooo05Wooooo000Qooooo`03o`000?oooooooooo0:Oooooo00?oo`00o`000?ooool0
??ooool2o`000003oooooooo003ooooo05Wooooo000Qooooo`03o`000?oooooooooo0:Sooooo00?o
o`00o`000?ooool0>_ooool00ol0003oooooooooo`1Looooo`008Oooool00ol0003oooooooooo`2Z
ooooo`03o`000?oooooooooo03Kooooo0_l0001Oooooo`006?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
05oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[?ooool2o`0003?o
oooo00?o0000ooooooooool0H?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2^ooooo`03o`000?oooooooooo02kooooo0_l0001Sooooo`006_ooool00ol0003ooooooooo
o`04ooooo`?o0000[oooool2o`0002gooooo00?o0000ool00?oo0000Hoooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo02Sooooo0_l00000
0ooo003oooooooooo`1Sooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo0_oo0002o`0002Kooooo0_l00002ool006Kooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0/_ooool2ool00003o`000?oooooooooo027ooooo00Co0000ool00?oo
003oo`00J?ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`2dooooo`04
ool00?l0003o0000o`0001gooooo0_l00002ool006_ooooo000Qooooo`03o`000?oooooooooo0;Go
oooo0ooo0004o`0001Kooooo0ol00002ool006gooooo000Qooooo`03o`000?oooooooooo0;Sooooo
1?oo0003o`00017ooooo0_l000000oooooooo`00ool0001_ooooo`008Oooool3o`000;cooooo0_oo
00000ooooooo0000o`000003o`0000Cooooo2?l00002ooooo`03ool00?oooooooooo06oooooo000Q
ooooo`03o`000?oooooooooo0;kooooo00?oo`00oooooooo00000oooool5o`0007_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo1ooo001looooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2S
ooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hoooo
o`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mE
EEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo
00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c01kooooo`00O_ooool01ol@413o
gMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So
8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0
003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40Noooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko
410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool0
0olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Ooo
ool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool0
0ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05
ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool0
0004ooooo`03onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<
c?l0003o0000o`000?o<c<`0Noooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEE
EOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool0
4_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@401koooo
o`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^
k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000007_ooooo002Fooooo`03o`00
0?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`00
0?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .32735 L
.08255 .33538 L
.0932 .33907 L
.10458 .34248 L
.11531 .34513 L
.12507 .34704 L
.12977 .34777 L
.13488 .34843 L
.1397 .34891 L
.14415 .34925 L
.14658 .34938 L
.14881 .34948 L
.15004 .34952 L
.15138 .34955 L
.15264 .34958 L
.15382 .34959 L
.155 .3496 L
.15612 .34959 L
.15712 .34959 L
.1582 .34957 L
.15939 .34955 L
.16064 .34952 L
.16288 .34944 L
.16533 .34933 L
.16796 .34917 L
.17271 .34879 L
.17836 .3482 L
.1835 .34752 L
.20259 .34403 L
.22335 .33886 L
.26413 .32697 L
.28438 .32155 L
.2943 .31928 L
.3034 .3175 L
.31207 .31611 L
.31666 .31552 L
.32156 .31499 L
.32415 .31476 L
.32651 .31458 L
.3289 .31443 L
.3311 .31431 L
.33358 .31421 L
.33489 .31418 L
.33555 .31416 L
.33627 .31415 L
.33747 .31413 L
.33859 .31412 L
.33928 .31412 L
.33993 .31412 L
Mistroke
.34115 .31413 L
.3424 .31414 L
.3431 .31416 L
.34375 .31417 L
.34491 .3142 L
.34619 .31425 L
.34841 .31435 L
.35076 .31449 L
.35605 .31492 L
.36099 .31548 L
.36988 .31686 L
.37939 .31887 L
.38959 .32166 L
.40067 .32541 L
.42081 .33406 L
.46164 .35801 L
.50096 .38679 L
.53876 .41657 L
.57902 .44698 L
.61776 .47188 L
.63744 .48207 L
.65895 .49091 L
.6689 .49412 L
.67951 .4969 L
.68467 .498 L
.68953 .49889 L
.69423 .4996 L
.69862 .50015 L
.70327 .50059 L
.70573 .50077 L
.70837 .50092 L
.7097 .50097 L
.71114 .50102 L
.7118 .50104 L
.7125 .50106 L
.71376 .50108 L
.71497 .50109 L
.7161 .50109 L
.71734 .50108 L
.71804 .50107 L
.71868 .50106 L
.71975 .50103 L
.7209 .501 L
.72297 .50091 L
.72543 .50077 L
.72767 .50061 L
.73254 .50015 L
.73714 .49957 L
.74685 .49788 L
.75713 .49541 L
Mistroke
.77558 .48923 L
.79513 .48025 L
.81343 .46966 L
.85222 .44069 L
.89347 .40168 L
.9332 .3586 L
.97141 .31462 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Looooo`Go0000fOooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0
003o410@olc<c0Gooooo000Qooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^
kPGooooo000Qooooo`04o`000?ooooooooooooooo`;oo`002Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`Co00002oooool00ol0003oo`00ool00004ool000;ooooo1_oo000:ooooo`?o000000?oooooo`00
0?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Coooo
o`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0_oo00000ol0
003oooooooooo`0mooooo`Co00002oooool4ool001_ooooo0_l0002`ooooo`03o`000?oooooooooo
01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool01Oooool2ool000;o
0000>?ooool4o`0000Wooooo1_oo000Looooo`?oo`000_ooool2o`000:gooooo00?o0000oooooooo
ool07Oooool0027ooooo00?o0000ooooooooool01oooool2ool000?o0000<Oooool4o`0000cooooo
00?oo`00ooooooooool08oooool2ool000;ooooo0_l0002Zooooo`03ool00?oooooooooo01kooooo
000Qooooo`03o`000?oooooooooo00Wooooo0ooo0003o`0002[ooooo1?l0000hooooo`;oo`000_oo
ool2o`000:Oooooo00?o0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool03?ooool3
ool000Co00008oooool3o`0003kooooo0_oo0002ooooo`;o0000Y?ooool00ol0003oo`00ooooo`0P
ooooo`008Oooool3o`0000oooooo00Coo`00oooooooooooooooo1?l0000Kooooo`Co00002oooool3
ool003Gooooo0_oo0002ooooo`03o`000?oooooooooo0:3ooooo00?o0000ool00?ooool08Oooool0
027ooooo00?o0000ooooooooool05oooool5o`0000oooooo1ol0000<ooooo`?oo`00>_ooool2ool0
0003ooooool0003o000009oooooo00?o0000ool00?ooool08_ooool0027ooooo00?o0000oooooooo
ool07?ooool?o`0000kooooo1Ooo000oooooo`03ool00?oooooooooo00;o0000W?ooool00ol0003o
o`00ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0eooooo`Coo`00AOooool01Ooo003ooooo
oooooooooooo000009[ooooo00?o0000ool00?ooool09?ooool0027ooooo00?o0000ooooooooool0
6_ooool6ool001Cooooo00?oo`00ooooooooool0C?ooool2o`0009Oooooo00?o0000ool00?ooool0
9Oooool0027ooooo00?o0000ooooooooool08?ooool:ool005_ooooo0_l0002Dooooo`03o`000?oo
003ooooo02Kooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0TOooool0
0ooo003oooooooooo`0Vooooo`008Oooool3o`0008Sooooo00?o0000ooooooooool0Soooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo08go
oooo00?oo`00ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0R?ooool2ool00003o`00
0?oooooooooo08_ooooo00?o0000ool00?ooool0:Oooool0027ooooo00?o0000ooooooooool0R_oo
ool00ooo003o0000o`00002:ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo08_ooooo00?oo`00ooooool00000R?ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0
003oooooooooo`2<ooooo`03ool00?oooooo000008Kooooo00?o0000ooooooooool0;?ooool0027o
oooo00?o0000ooooooooool0SOooool2ool00003o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0;Oooool0027ooooo00?o0000ooooooooool0Soooool00ooo003o0000ooooo`21ooooo`03o`00
0?oooooooooo02kooooo000Qooooo`?o0000T?ooool00ooo003o0000o`00001oooooo`03o`000?oo
oooooooo02oooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooool00000OOooool0
0ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2Booooo`;oo`0000?o0000oooo
ooooool0NOooool00ol0003oo`00ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Dooooo`03
ool00?l0003o000007Sooooo00?o0000ool00?ooool0<_ooool0027ooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo03?ooooo000Qooooo`03o`000?oo
oooooooo09Sooooo00?o0000ooooooooool0L_ooool00ol0003oo`00ooooo`0dooooo`008Oooool0
0ol0003oooooooooo`2Iooooo`03o`000?oooooooooo073ooooo00?o0000ool00?ooool0=Oooool0
027ooooo0ol0002Jooooo`;o0000Koooool00ol0003oo`00ooooo`0fooooo`008Oooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0=oooool0027ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Yooooo`03o`000?oo003ooooo03Sooooo
000Qooooo`03o`000?oooooooooo09gooooo00?oo`00o`000?l00000J?ooool00ol0003oo`00oooo
o`0iooooo`008Oooool00ol0003oooooooooo`2Nooooo`;oo`0000?o0000ooooooooool0I?ooool0
0ol0003oo`00ooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Pooooo`03ool00?l0
003ooooo06?ooooo00?o0000ool00?ooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:7ooooo00?o
o`00o`000?ooool0HOooool00ol0003oo`00ooooo`0looooo`001oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:;ooooo0_oo001Pooooo`03o`000?oo
oooooooo03gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0:Cooooo00?oo`00ooooooooool0G?ooool00ol0003ooooooooo
o`0nooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0:Gooooo0_oo001Jooooo`;o0000@Oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Y_ooool00ol0003oo`00ooooo`1Gooooo`03o`000?oooooooooo047ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Oooooo
00?o0000ool00?ooool0EOooool00ol0003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0
D_ooool2o`0004Gooooo000Qooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0D?oo
ool00ol0003oo`00ool00015ooooo`008Oooool00ol0003oooooooooo`2Zooooo`;o0000Coooool0
0ol0003oo`00ooooo`16ooooo`008Oooool3o`000:cooooo00?o0000ooooooooool0Boooool00ol0
003oo`00ooooo`17ooooo`008Oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo04So
oooo0_l000000ooo003oooooooooo`17ooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0[ooo
ool00ol0003oooooooooo`02ool004;ooooo00?o0000ool00?ooool0Boooool0027ooooo00?o0000
ooooooooool0/?ooool2o`0000;ooooo0_oo000nooooo`;o000000?oo`00ooooooooool0Boooool0
027ooooo00?o0000ooooooooool0/_ooool2o`0000;ooooo00?oo`00ooooooooool0>_ooool00ol0
003oooooool0001>ooooo`008Oooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00;o
o`00>Oooool00ol0003oo`00ool0001?ooooo`008Oooool3o`000;Gooooo0_l00002ooooo`;oo`00
=_ooool2ool0057ooooo000Qooooo`03o`000?oooooooooo0;Oooooo0_l00002ooooo`;oo`00<ooo
ool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`2iooooo`04o`000?oooooo
ooooooooo`;oo`00;oooool2o`0005Cooooo000Qooooo`03o`000?oooooooooo0;[ooooo0_l00003
ooooo`03ool00?oooooooooo02[ooooo0_l0001Fooooo`008Oooool00ol0003oooooooooo`2loooo
o`05o`000?oooooooooooooooooo0000:Oooool2o`0005Sooooo000Qooooo`03o`000?oooooooooo
0;gooooo0ol0000Vooooo`;oo`000_l0001Jooooo`008Oooool00ol0003oooooooooo`30ooooo`?o
00008?ooool3ool000;o0000G?ooool0027ooooo00?o0000ooooooooool0`oooool3o`0000Cooooo
0ooo000Eooooo`03ool00?l0003o000005oooooo000Qooooo`?o0000a_ooool3o`0000Cooooo3_oo
0006ooooo`;o0000HOooool0027ooooo00?o0000ooooooooool0bOooool2o`00017ooooo1Ol0001S
ooooo`008Oooool00ol0003oooooooooo`3;oooooa7o0000J?ooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKo
MgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@
onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o
<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03oooo
o`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVY
ZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMoooo
o`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401ooo
ool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@4100
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b
<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03
o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002
ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^
kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVoooo
ool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool0
00002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool0
1_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03o`000?oooooooooo
07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo
410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Doooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04
ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMooo
ool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04
ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35303 L
.10458 .39523 L
.12507 .41151 L
.14415 .42385 L
.16254 .43312 L
.17277 .43716 L
.18221 .44021 L
.19242 .44277 L
.19781 .44382 L
.20351 .4447 L
.20846 .44528 L
.2131 .44568 L
.21575 .44584 L
.21818 .44594 L
.21952 .44598 L
.22028 .446 L
.22099 .44601 L
.22228 .44603 L
.223 .44603 L
.22365 .44603 L
.22486 .44603 L
.22598 .44601 L
.22721 .44599 L
.22853 .44595 L
.22991 .4459 L
.23122 .44583 L
.23368 .44569 L
.2381 .44534 L
.2429 .44482 L
.24814 .44409 L
.25371 .44314 L
.26372 .44098 L
.28319 .43525 L
.30147 .42823 L
.34016 .40931 L
.3813 .38564 L
.42092 .3626 L
.45903 .34299 L
.48028 .33395 L
.49959 .32719 L
.50923 .32438 L
.51968 .32177 L
.52947 .31974 L
.53864 .3182 L
.5481 .31697 L
.55312 .31646 L
.55851 .31603 L
.56121 .31586 L
.56415 .3157 L
Mistroke
.56675 .31558 L
.56951 .31549 L
.57092 .31545 L
.57224 .31542 L
.57344 .3154 L
.57472 .31539 L
.57595 .31538 L
.57724 .31537 L
.57835 .31537 L
.57956 .31538 L
.58087 .31539 L
.58208 .31541 L
.5834 .31543 L
.58481 .31546 L
.58718 .31553 L
.58979 .31562 L
.5946 .31584 L
.5991 .31612 L
.60918 .31693 L
.62003 .31808 L
.66122 .32428 L
.7009 .3311 L
.72091 .33415 L
.73906 .33643 L
.7485 .33739 L
.75871 .33822 L
.76433 .33859 L
.7695 .33887 L
.77445 .33908 L
.77713 .33917 L
.77967 .33924 L
.78204 .3393 L
.78329 .33932 L
.78462 .33934 L
.78574 .33936 L
.78697 .33937 L
.78808 .33938 L
.78914 .33938 L
.79038 .33939 L
.79168 .33939 L
.7928 .33938 L
.79402 .33938 L
.79534 .33937 L
.79675 .33935 L
.79929 .33931 L
.80165 .33926 L
.80422 .33919 L
.80889 .33902 L
.81761 .33858 L
.82706 .33792 L
Mistroke
.83747 .33698 L
.8585 .33442 L
.87792 .33136 L
.89881 .32741 L
.94005 .31805 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00oooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo0ooo0002o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l000000ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Co
0000oooooooooooooooo1ooo0004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool3o`000003ool00?l0003ooooo00;ooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMg
ogMgMolb<S85ooooo`008Oooool01?l0003oooooo`000?oo002Looooo`Soo`004Oooool6ool005oo
oooo1?l0000Kooooo`;o00000_ooool2o`0000Cooooo000Qooooo`05o`000?ooooooooooo`000?oo
0000U_ooool5ool001[o00001Oooool6ool005?ooooo0ooo0003o`0002Wooooo000Qooooo`06o`00
0?ooooooooooooooool0003oo`00TOooool3o`000004ool00?l0003o0000o`0001cooooo1?l00007
ooooo`Coo`00Boooool4ool000?o0000;?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0
003oo`00ooooo`2<ooooo`?o00009oooool7o`0004[ooooo1Ooo00001?oooooo0000o`000?l0000_
ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo0ol0000aoooo
o`Ko00002?ooool5ool003?ooooo1?oo0003ooooo`?o0000<_ooool0027ooooo0ol00004ooooo`03
o`000?oooooooooo08Cooooo0ooo000jooooo`Ko00001oooool6ool002oooooo1Ol0000eooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo083ooooo0ooo0013ooooo`Ko0000
1oooool6ool001Kooooo1ooo0006ooooo`Ko0000>_ooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1looooo`03o`000?oo003oo`0004cooooo1_l0000@ooooo`goo`001ooo
ool6o`00043ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0NOooool0
0ol0003oo`00ool0001Dooooo`So00005oooool5o`0004Kooooo000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0M_ooool00ol0003oo`00ool0001NoooooaOo0000Boooool0027o
oooo00?o0000ooooooooool02Oooool2o`0007?ooooo0ol000000ooo003oooooooooo`30ooooo`00
8Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06kooooo0_l000000oooooooo`00
ool00033ooooo`008Oooool3o`0000[ooooo00?oo`00ooooool00000KOooool2o`0000;ooooo00?o
o`00ooooooooool0`oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooo`00001Z
ooooo`;o0000b_ooool0027ooooo00?o0000ooooooooool03?ooool00ooo003oooooo`00001Woooo
o`;o0000c?ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003oooooo`00001Tooooo`;o
0000c_ooool0027ooooo00?o0000ooooooooool03_ooool01?oo003oooooo`000?l0001Pooooo`;o
0000d?ooool0027ooooo00?o0000ooooooooool03oooool01?oo003oooooooooool0001Mooooo`;o
00000_ooool2ool00<kooooo000Qooooo`03o`000?oooooooooo013ooooo00Coo`00oooooooooooo
0000F_ooool2o`0000;ooooo0_oo003@ooooo`008Oooool00ol0003oooooooooo`0Aooooo`04ool0
0?ooooooooooo`0005Oooooo0_l00002ooooo`;oo`00d_ooool0027ooooo0ol0000Booooo`04ool0
0?ooooooooooo`0005Cooooo0_l00002ooooo`;oo`00e?ooool0027ooooo00?o0000ooooooooool0
4oooool01?oo003oooooooooool0001Aooooo`;o00000_ooool2ool00=Kooooo000Qooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool00_l0001=ooooo`;o00000oooool00ooo003ooooo
ooooo`3Fooooo`008Oooool00ol0003oooooooooo`0Eooooo`05ool00?ooooooooooooooool00000
B_ooool2o`0000?ooooo0_oo003Iooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04Gooooo0_l00004ooooo`03ool00?oooooooooo0=Wooooo000Qooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@_ooool2o`0000Gooooo00?oo`00ooooooooool0f_ooool0
027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0oooooo`;o0000i?ooool0027o
oooo0ol0000Mooooo`;o0000?Oooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0=oooool3o`000>Sooooo000Qooooo`03o`000?oooooooooo023ooooo0_l0
000eooooo`;o0000joooool0027ooooo00?o0000ooooooooool07Oooool2ool000?ooooo00?o0000
ooooooooool0<?ooool2o`0000Kooooo0_oo003Uooooo`008Oooool00ol0003oooooooooo`0Ooooo
o`;oo`000_ooool3o`0002gooooo0_l00006ooooo`;oo`00ioooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool08Oooool2ool000?ooooo0ol0000Xooooo`;o00001_ooool2ool00>Wooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Sooooo`;oo`001?ooool2o`0002Cooooo0_l00006ooooo`;oo`00joooool0
00Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000U
ooooo`;oo`001?ooool00ol0003oooooooooo`0Mooooo`Co00001_ooool2ool00>gooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo02Oooooo0_oo0003ooooo`Ko00005Oooool4o`0000Oooooo0ooo003_ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02Wooooo0_oo0007ooooo`;o00004?ooool3o`0000Wooooo0_oo003booooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0[ooooo`03ool00?oooooooooo00Kooooo4?l0003oooooo`7ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`14ooooo`;oo`00o_ooool0027ooooo00?o0000ooooooooool0=_ooool>ool00?oooooo0Oooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOo
oooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^
01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?o
V9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413o
gMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So
8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0
003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B46ooooo`03
oiRHV?l@413ogMgM07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8boooo
ooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000
ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oQhN7oeEEEOooool0N_oo
ool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[o
oooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Goc<c<ob4Q8Ol0
003oEEEEo`00001kooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o
00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_oo
ool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`00
0?ooool04_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go8B4QohN7QoooooooV9RHo`00
001kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@
o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool0
0ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oo
oooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_oo
ooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0Noooool009Kooooo00?o0000ooooooooool01oooool0
0onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03
ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000
oc8b<_o^k^h0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36768 L
.10458 .42297 L
.14415 .46615 L
.18221 .49767 L
.20178 .50932 L
.21274 .51436 L
.22272 .51798 L
.22755 .51939 L
.23267 .52064 L
.2371 .52152 L
.24186 .52225 L
.24453 .52256 L
.24697 .52279 L
.24814 .52288 L
.24942 .52296 L
.25062 .52302 L
.25175 .52306 L
.25244 .52308 L
.25319 .5231 L
.25449 .52312 L
.25523 .52312 L
.25601 .52312 L
.25667 .52311 L
.2574 .5231 L
.25871 .52306 L
.25945 .52303 L
.26011 .523 L
.26265 .52285 L
.26493 .52265 L
.26745 .52238 L
.27256 .52164 L
.27729 .52072 L
.28173 .51967 L
.29172 .51661 L
.30249 .51227 L
.32253 .50141 L
.34363 .48635 L
.38174 .45111 L
.4223 .40527 L
.46135 .35685 L
.50284 .30502 L
.54283 .25836 L
.58129 .21926 L
.60078 .20226 L
.62221 .18604 L
.6428 .17306 L
.66161 .16356 L
.68106 .15615 L
.69178 .15314 L
Mistroke
.69712 .15193 L
.70195 .15099 L
.70657 .15025 L
.71157 .1496 L
.71431 .14932 L
.71684 .1491 L
.71941 .14892 L
.7218 .1488 L
.72386 .14872 L
.72502 .14869 L
.72607 .14867 L
.72722 .14866 L
.72848 .14865 L
.72966 .14866 L
.73075 .14867 L
.73188 .14869 L
.73293 .14872 L
.73409 .14876 L
.73534 .14881 L
.73787 .14895 L
.7402 .14912 L
.74495 .14956 L
.75003 .15021 L
.75916 .15178 L
.77002 .15436 L
.77988 .15735 L
.7991 .1649 L
.81991 .17552 L
.86088 .20305 L
.90034 .23607 L
.93828 .27159 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3Eooooo`[oo`00IOooool0027o
oooo00?o0000ooooooooool0goooool5ool0063ooooo000Qooooo`03o`000?oooooooooo0<gooooo
0_oo000Ao`0000Cooooo00?oo`00ooooooooool0GOooool0027ooooo00?o0000ooooooooool0b_oo
ool3ool000;o00004Oooool6o`0005kooooo000Qooooo`03o`000?oooooooooo0<Oooooo0ooo0000
0ol0003oooooooooo`0Iooooo`?o0000Foooool0027ooooo00?o0000ooooooooool0a?ooool3ool0
0003o`000?oooooooooo01oooooo0_l00004ooooo`;oo`00Doooool0027ooooo0ol00033ooooo`03
ool00?l0003ooooo02Gooooo0ol00003ooooo`;oo`00DOooool0027ooooo00?o0000ooooooooool0
`Oooool2o`0002_ooooo0_l00003ooooo`03ool00?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0;oooooo0_l0000_ooooo`;o00000_ooool2ool004kooooo000Qooooo`03o`000?oooooo
oooo0;gooooo0_l0000cooooo`;o00000_ooool2ool004cooooo000Qooooo`03o`000?oooooooooo
0;cooooo00?o0000ooooooooool0=Oooool2o`0000;ooooo00?oo`00ooooooooool0BOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0^Oooool00ooo003o0000o`00000jooooo`;o000000?ooooo
ool00?oo0000BOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Oooooo0_oo00000ol0003oooooooooo`0l
ooooo`04o`000?ooooooooooool004Sooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002fooooo`03ool00?l0003o0000043ooooo0_l0
00000oooooooo`00ooooo`16ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04?ooooo00?o
0000ooooooooool0A_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2dooooo`03ool00?l0003ooooo04Gooooo
0_l00016ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2cooooo`03ool00?l0003ooooo04Sooooo00?o0000ooooooooool0
@oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0/Oooool2ool00003o`000?oooooooooo04Wooooo0_l00013ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0;3ooooo
00?oo`00o`000?l00000C_ooool00ol0003oooooooooo`10ooooo`008Oooool00ol0003ooooooooo
o`2_ooooo`03ool00?l0003ooooo053ooooo0_l000000oooooooo`00ool0000mooooo`008Oooool0
0ol0003oooooooooo`2^ooooo`03ool00?l0003ooooo05?ooooo00Co0000ooooooooooooo`00??oo
ool0027ooooo0ol0002]ooooo`03ool00?oooooooooo05Gooooo00Co0000ooooooooooooo`00>ooo
ool0027ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1Gooooo`;o000000?ooooo
ool00?ooool0>Oooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Joooo
o`03o`000?ooooooo`0003Wooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooool0000hooooo`008Oooool00ol0003oooooooooo`2Zooooo`03o`00
0?oooooooooo05gooooo00?o0000oooooooo0000=oooool0027ooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooooooo`1Oooooo`;o000000?oo`00ooooooooool0=?ooool0027ooooo00?o0000
ooooooooool0Z?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo003ooooo03Cooooo000Qoooo
o`?o0000Yoooool00ol0003oooooooooo`1Tooooo`03o`000?oo003oo`0003?ooooo000Qooooo`03
o`000?oooooooooo0:Gooooo00?oo`00o`000?ooool0Ioooool2o`000003ool00?oooooooooo033o
oooo000Qooooo`03o`000?oooooooooo0:Cooooo00?oo`00o`000?ooool0J_ooool00ol0003ooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?l0003ooooo06cooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o0000ooooo`1^
ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo0:7ooooo00?oo`00o`00
0?ooool0L?ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03
ool00?l0003ooooo07;ooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0
Woooool00ooo003o0000ooooo`1dooooo`03o`000?oooooooooo02_ooooo000Qooooo`?o0000Wooo
ool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`07ooooo`03ool00?oooooooooo037ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037o
oooo00?o0000ool00?ooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03
o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0=?ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo003ooooo00Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00?oo`00o`00
0?ooool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000ool0
0?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo
00Kooooo00?oo`00o`000?ooool0=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<03oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00fooooo`03ool00?oooooooooo00Oooooo00?o
MgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03ool00?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?o
o`00ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oo
oooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIV
o`000005ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo
00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000oooo
ooooool0V?ooool00ol0003oooooooooo`26ooooo`03ool00?l0003ooooo023ooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0R?ooool00ooo003o0000ooooo`0Oooooo`00
8Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo08[ooooo00?oo`00o`000?ooool0
7_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`2<ooooo`03ool00?l0
003ooooo01?ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0Toooool0
0ooo003o0000ooooo`2@ooooo`03o`000?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd4ooooo`006_oooonMo`000003ool00?l0003o000009Wo00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
o`00o`000?ooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo
000Qooooo`03o`000?oooooo0000093ooooo00?oo`00o`000?ooool0Yoooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qoooo
o`04o`000?ooooooooooo`0008kooooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000oooo
ooooooooooooool0002<ooooo`03ool00?oooooooooo0;?ooooo000Qooooo`05o`000?oooooooooo
oooooooo0000Roooool00ooo003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00oooo
ooooool0Qoooool00ol0003oo`00ooooo`2eooooo`008Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo08Gooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`25ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool0
0ol0003oooooooooo`04ooooo`03ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0
027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`20ooooo`03o`000?oooooooooo
0;Wooooo000Qooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0O_ooool00ol0003o
ooooooooo`2jooooo`008Oooool3o`0000Kooooo00?oo`00o`000?ooool0OOooool00ol0003ooooo
ooooo`2kooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07_ooooo00?o
0000ooooooooool0_?ooool0027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`1k
ooooo`03o`000?oooooooooo0;cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00
0?ooool0NOooool00ol0003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`09ooooo`;o
o`00N?ooool00ooo003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ool00?ooool0_oooool0027ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oo003ooooo0<3ooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0LOooool00ol0003oo`00ooooo`31ooooo`008Oooool3o`00
00gooooo00?o0000ooooooooool0Koooool00ol0003oo`00ooooo`32ooooo`008Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0`_ooool0027ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1]ooooo`03ool00?oooooooooo0<?ooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oo`00oooo
o`34ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000
ool00?ooool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1Woooo
o`03o`000?oo003ooooo0<Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?oo`00o`000?oo
ool0I_ooool00ol0003oo`00ooooo`37ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0
I?ooool00ol0003oo`00ooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo06?ooooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool0
0ooo003oooooooooo`1Qooooo`03o`000?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?oo`00o`000?ooool0H?ooool00ol0003oooooooooo`3:ooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03ool00?l0003ooooo05kooooo00?o0000ooooooooool0boooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool05_ooool00ooo003o0000ooooo`1Looooo`03o`000?oooooooooo
0<cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo05[ooooo00?o0000oooo
ooooool0cOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo0ol0000Gooooo`03ool00?l0003ooooo05Wooooo00?o0000ooooooooool0c_ooool000Oo
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool06?ooool00ooo003o0000ooooo`1Hooooo`03o`000?oooooooooo0<kooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool06Oooool00ooo003o0000ooooo`1Fooooo`03o`000?oooooooooo0<oooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01[ooooo00?oo`00o`000?ooool0E?ooool00ol0003oo`00ooooo`3@ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo057ooooo00?o0000ool00?ooool0dOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo04oooooo00?o0000ool00?ooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1=ooooo`03o`000?oo003ooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0B_ooool2o`000003ool00?oooooooooo0=?ooooo000Qooooo`?o0000
8?ooool00ol0003oooooooooo`18ooooo`03o`000?ooooooo`000=Kooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooool0003Gooooo`008Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo0000f?ooool0
027ooooo00?o0000ooooooooool08_ooool00ooo003o0000ooooo`13ooooo`03o`000?ooooooo`00
0=Wooooo000Qooooo`03o`000?oooooooooo02?ooooo0_oo0011ooooo`;o000000?oooooool00?oo
ool0fOooool0027ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`0mooooo`04o`00
0?ooooooooooool00=_ooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0
>oooool01?l0003ooooooooooooo003Looooo`008Oooool3o`0002Oooooo00?oo`00ooooooooool0
>Oooool00ol0003oooooooooo`3Nooooo`008Oooool00ol0003oooooooooo`0Xooooo`;oo`00>?oo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo003o
oooo03Gooooo00?o0000ooooooooool0h?ooool0027ooooo00?o0000ooooooooool0:oooool00ooo
003oooooooooo`0aooooo`;o0000hoooool0027ooooo00?o0000ooooooooool0;?ooool00ooo003o
0000ooooo`0_ooooo`03o`000?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo02gooooo
00?oo`00o`000?ooool0;?ooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
o`00o`000?l00000:_ooool01?l0003oooooool00?oo003Uooooo`008Oooool00ol0003ooooooooo
o`0aooooo`;o00009_ooool2o`000003oooooooo003ooooo0>Kooooo000Qooooo`?o0000<oooool2
o`0002;ooooo0_l000000oooooooo`00ool0003Xooooo`008Oooool00ol0003oooooooooo`0eoooo
o`;o00007_ooool2o`000003oooooooo003oo`000>[ooooo000Qooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool06Oooool2o`0000;ooooo00?oo`00ooooooooool0j_ooool0027ooooo
00?o0000ooooooooool0>?ooool3o`0001Gooooo0ol00002ooooo`;oo`00kOooool0027ooooo00?o
0000ooooooooool0=oooool3ool00003ooooool0003o000000?o00003?ooool4o`0000?ooooo0_oo
003_ooooo`008Oooool00ol0003oooooooooo`0jooooo`;oo`001?ooool<o`0000Gooooo0_oo003a
ooooo`008Oooool00ol0003oooooooooo`0looooo`Coo`00ooooool5ooooo`008Oooool3o`00043o
oooo1ooo003mooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIV
I_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@
413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`00
0?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?o
oooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGo
ZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b
<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003ooooooooo
o`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`07ooooo`03o`00
0?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo
00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8boooooooo
ool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000oooo
ooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?lQ8B7o
0000oeEEEOl000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03
ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHoooo
o`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@oooo
ool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000
ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo1?l0001fooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36745 L
.10458 .42888 L
.14415 .47887 L
.18221 .51541 L
.20178 .52887 L
.21274 .53472 L
.22272 .53897 L
.22755 .54066 L
.23267 .54218 L
.2371 .54328 L
.24186 .54424 L
.24453 .54467 L
.24697 .545 L
.24945 .54527 L
.25175 .54547 L
.25305 .54556 L
.25442 .54563 L
.25521 .54566 L
.25595 .54569 L
.25662 .54571 L
.25734 .54572 L
.25798 .54573 L
.25868 .54574 L
.25942 .54574 L
.2601 .54573 L
.26133 .54571 L
.26265 .54567 L
.26386 .54561 L
.26521 .54554 L
.26793 .54533 L
.27045 .54507 L
.27282 .54476 L
.27815 .54388 L
.28389 .54261 L
.29438 .53945 L
.30401 .53563 L
.32293 .52562 L
.34363 .51103 L
.38419 .47244 L
.42324 .42464 L
.46474 .3653 L
.50472 .30334 L
.54318 .24316 L
.5841 .18312 L
.62351 .13374 L
.66139 .09783 L
.68084 .08474 L
.69176 .07912 L
.70173 .07511 L
Mistroke
.70651 .07357 L
.7116 .07221 L
.716 .07126 L
.72076 .07048 L
.72368 .07013 L
.72496 .07 L
.72636 .06988 L
.7276 .0698 L
.72893 .06972 L
.72966 .06969 L
.73033 .06967 L
.73164 .06963 L
.7329 .06962 L
.73407 .06962 L
.73535 .06964 L
.73599 .06966 L
.7367 .06968 L
.73789 .06974 L
.73918 .06981 L
.74149 .06999 L
.7439 .07024 L
.74647 .07057 L
.75109 .07135 L
.75659 .07257 L
.76157 .07396 L
.77244 .07788 L
.78269 .08268 L
.80274 .09498 L
.8212 .10949 L
.86066 .14929 L
.8986 .19655 L
.93899 .25354 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`?oo`00
0_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo0_l0
000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3=
ooooo`;oo`000ol0000Gooooo`?o0000F?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3:ooooo`?oo`000_l0000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`38ooooo`;oo`0000?oooooo`000?l000008Oooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`37ooooo`04ool00?oooooo0000o`0002?o
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`35ooooo`;oo`00
00?oooooo`000?ooool09_ooool00ooo003o0000ooooo`1Aooooo`008Oooool3o`000<Cooooo00Co
o`00ooooool0003o0000:Oooool2ool00003o`000?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0<Cooooo00?oo`00o`000?ooool0;?ooool00ooo003o0000ooooo`1>ooooo`008Oooool0
0ol0003oooooooooo`33ooooo`03ool00?l0003ooooo02kooooo00?oo`00o`000?l00000COooool0
027ooooo00?o0000ooooooooool0`_ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooo0000
04cooooo000Qooooo`03o`000?oooooooooo0<7ooooo00?oo`00ooooooooool0<_ooool00ooo003o
ooooo`00001;ooooo`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo
00?oo`00ooooool00000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0fooooo`03ool00?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000oooo
ooooool0>_ooool00ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool0
0ol0003oooooooooo`2iooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool0
027ooooo00?o0000ooooooooool0^?ooool00ol0003oo`00ooooo`16ooooo`03o`000?oooooooooo
043ooooo000Qooooo`?o0000]oooool00ol0003oo`00ooooo`17ooooo`03o`000?oooooooooo043o
oooo000Qooooo`03o`000?oooooooooo0;Oooooo00?oo`00ooooooooool0B?ooool00ooo003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo04[ooooo00?o
o`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0]Oooool00ooo003oooooooooo`1;
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00oooo
ooooool0COooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003oooooooooo`2cooooo`03
ool00?oooooooooo04oooooo00?oo`00ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
/_ooool00ooo003o0000ooooo`1Aooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo0;7ooooo00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3
o`000;3ooooo00?oo`00o`000?ooool0E?ooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0
003oooooooooo`2_ooooo`03ool00?l0003ooooo05Kooooo00?oo`00o`000?ooool0>Oooool0027o
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wo
oooo000Qooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000
ooooo`0hooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0=?ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03
o`000?oooooooooo037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0IOooool00ol0003o
ooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Y_ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oo
oooooooo02oooooo000Qooooo`?o0000Y_ooool00ooo003oooooooooo`1Yooooo`03ool00?l0003o
oooo02oooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0Joooool00ooo
003o0000ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06go
oooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0Xoooool00ol0003oo`00
ooooo`1^ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o
o`00ooooooooool0Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2R
ooooo`03ool00?oooooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000oooo
ooooool0XOooool00ol0003oo`00ooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o
0000XOooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo0:3ooooo00?oo`00ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1hooooo`03ool00?l0003o
oooo02Sooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_o
oooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0moooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`00
0?oooooooooo00?ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo03So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03
o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0>Oooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`08ool00?l0003o
ooooo`000?nj^[[ooooooiRHV?l@410Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ol0003o
o`00ooooo`0iooooo`03oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo
08[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003o
o`00ooooo`2<ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03o`000?oo003ooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo003ooooo093ooooo00?oo`00
ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooigo000000?o
o`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Ooo
ool00ol0003oooooool0002Aooooo`03o`000?oooooooooo0:Kooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000oooooooo0000T?ooool00ol0003oooooooooo`2aooooo`008Oooool01?l0
003ooooooooooooo002?ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`05o`000?oooooooooo
o`000?oo0000SOooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo
o`0008cooooo00?o0000ooooooooool0/oooool0027ooooo0ol00002ooooo`03ool00?oooooooooo
08Wooooo00?o0000ooooooooool0/oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ooooo`28ooooo`03o`000?oooooooooo0;Cooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?ooool0Q_ooool00ol0003oooooooooo`2eooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ooooo`24ooooo`03o`000?oo003ooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0P_ooool00ol0003oo`00ooooo`2goooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo083ooooo00?o0000ool00?oo
ool0^?ooool0027ooooo0ol00006ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0
^?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`1nooooo`03o`000?oo
003ooooo0;Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool0
0ol0003oo`00ooooo`2jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`2looooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0_?ooool0027ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo0;gooooo000Qoooo
o`?o00003?ooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo0;kooooo000Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`2nooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo07;ooooo00?o0000ooooooooool0
_oooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1`ooooo`03o`000?oo
oooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Koooool0
0ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo
06kooooo00?o0000ooooooooool0`Oooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`1/ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`?o00004Oooool00ooo003ooooo
ooooo`1[ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ool00?ooool0J_ooool00ol0003oooooooooo`33ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oo003ooooo06Sooooo00?o0000ooooooooool0a?ooool0027ooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo0<Cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`35ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003ooooo06Cooooo00?oo`00oooo
ooooool0a_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0H_ooool00ooo
003o0000ooooo`37ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool3o`0001Kooooo00?oo`00ooooooooool0HOooool00ooo003oooooooooo`37oooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Gooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b?ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0bOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0<[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0F_ooool00ooo003o0000ooooo`3;ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`3;ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0c?ooool0027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0<gooooo000Qooooo`?o0000
7?ooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0<kooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3>ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0coooool0
027ooooo00?o0000ooooooooool07_ooool00ooo003o0000ooooo`1@ooooo`03o`000?oooooooooo
0=3ooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0Coooool00ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool08Oooool00ooo003ooooooooo
o`1;ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00008_ooool00ooo003oooooooooo`19
ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?oo`00oooo
ooooool0AOooool2ool00003o`000?oooooooooo0=Cooooo000Qooooo`03o`000?oooooooooo02Co
oooo00?oo`00ooooooooool0@oooool00ooo003o0000ooooo`3Gooooo`008Oooool00ol0003ooooo
ooooo`0Uooooo`03ool00?oooooooooo047ooooo00?oo`00o`000?ooool0f?ooool0027ooooo00?o
0000ooooooooool09_ooool00ooo003oooooooooo`0oooooo`03ool00?l0003ooooo0=Wooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0?Oooool00ooo003o0000ooooo`3J
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo03_ooooo00?oo`00o`00
0?ooool0foooool0027ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0iooooo`03
ool00?l0003ooooo0=cooooo000Qooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03ool0
0?l0003ooooo0=gooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0=Ooo
ool00ooo003o0000ooooo`3Nooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo03?ooooo00?oo`00o`000?ooool0goooool0027ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0aooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0<?ooool00ooo003oooooooooo`3Pooooo`008Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000;_ooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo033ooooo0_oo
000/ooooo`03o`000?oooooooooo0>?ooooo000Qooooo`?o0000<_ooool2ool002Wooooo00?o0000
ooooooooool0i?ooool0027ooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`0Uoooo
o`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Gooooo0_oo000Sooooo`;o
0000j?ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`0Mooooo`;oo`00
00?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0>?ooool3ool001Wooooo0ooo
003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0>oooool2
ool000;o00004_ooool3ool00003o`000?oooooooooo0>gooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0?Oooool2ool00003o`000?oooooooooo00cooooo0ooo0002o`00
0?7ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool7o`0000;o
oooo1Ooo0003o`000??ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol00016ooooo`Co0000
n_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo09oooooo002;ooooo`?o00004oooool00olQ8B7o
gMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Woooool008;ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHoooooooo
ool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomV
IVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4QP?ooool008;ooooo00Oo410@
omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RH
ob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko
0000ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4QP?ooool008;ooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo08Kooooo0022ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003ooooo
ooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`26ooooo`00P_ooool00ooMgMgo8B4Qonk^
kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnH
V9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@
413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`26ooooo`00Pooo
ool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol0
0005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003ooooooooo
o`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eooooo`03o`000?oooooooooo08Kooooo002J
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oo
oooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000oooooooo
ool0Q_ooool009[ooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMg
MomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEE
ofIVI_l00000R?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36178 L
.10458 .41672 L
.14415 .45819 L
.16408 .4745 L
.18221 .48653 L
.20178 .49648 L
.21254 .50059 L
.22272 .50359 L
.23241 .50565 L
.2373 .50639 L
.24012 .50672 L
.24269 .50697 L
.24504 .50715 L
.24728 .50728 L
.2485 .50733 L
.24964 .50737 L
.25088 .50739 L
.25158 .50741 L
.25221 .50741 L
.25336 .50741 L
.25442 .50741 L
.25558 .50739 L
.2568 .50735 L
.25787 .50732 L
.25887 .50727 L
.26113 .50714 L
.26373 .50694 L
.26614 .5067 L
.27158 .50599 L
.27638 .50516 L
.28148 .50407 L
.2903 .5017 L
.30004 .49835 L
.31939 .48951 L
.34024 .47686 L
.38138 .44339 L
.42101 .40266 L
.45912 .35859 L
.49968 .31013 L
.53872 .26562 L
.58022 .22428 L
.60102 .20685 L
.6202 .19306 L
.64007 .18126 L
.65867 .17261 L
.67743 .16628 L
.68738 .1639 L
.69293 .16286 L
.69807 .16209 L
Mistroke
.70298 .16151 L
.70549 .16128 L
.7082 .16107 L
.70976 .16098 L
.71119 .1609 L
.71253 .16084 L
.714 .16079 L
.71532 .16076 L
.71655 .16074 L
.71785 .16073 L
.71858 .16073 L
.71924 .16073 L
.72049 .16074 L
.72112 .16075 L
.72182 .16076 L
.72305 .16079 L
.7242 .16083 L
.72679 .16095 L
.72957 .16112 L
.73468 .16155 L
.73935 .16209 L
.74918 .16366 L
.75831 .16562 L
.77902 .17177 L
.79952 .18004 L
.81812 .18924 L
.85815 .21372 L
.89667 .24208 L
.93764 .27574 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0cooooolAo`0006Cooooo
000Qooooo`03o`000?oooooooooo0<_ooooo1?l0000Aooooo`Ko0000G_ooool0027ooooo00?o0000
ooooooooool0b?ooool3o`0000Gooooo0ooo000Cooooo`?o0000Foooool0027ooooo00?o0000oooo
ooooool0aOooool3o`0001Gooooo1_oo0006ooooo`;o0000FOooool0027ooooo0ol00033ooooo`;o
00007_ooool3ool000Gooooo0ol0001Fooooo`008Oooool00ol0003oooooooooo`31ooooo`;o0000
0_ooool00ooo003oooooooooo`0Nooooo`?oo`001Oooool2o`0005Cooooo000Qooooo`03o`000?oo
oooooooo0;oooooo0_l00002ooooo`;oo`009?ooool3ool000Cooooo0_l0001Booooo`008Oooool0
0ol0003oooooooooo`2mooooo`;o000000Coooooool00?oo003oo`00:Oooool00ooo003ooooooooo
o`03ooooo`;o0000D?ooool0027ooooo00?o0000ooooooooool0_?ooool01?l0003oo`00ool00?oo
000dooooo`;o0000C_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0^_ooool2o`000003ool0
0?oooooooooo03Oooooo0_l0001<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0^Oooool00ol0003oo`00
ool0000looooo`03o`000?oooooooooo04Wooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002gooooo`;o000000?oo`00ooooooooool0
>_ooool2ool00003ooooool0003o000004Wooooo0007ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Kooooo00?o0000oooooooo0000
?oooool01?oo003oooooooooool00018ooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool0@Oooool2ool00003ooooool0003o000004Kooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;Cooooo00?o0000oooo
ooooool0A?ooool01?oo003oooooooooool00015ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooo
oooo04Kooooo0_oo00000ooooooo0000o`000013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0;7ooooo0_l0001;ooooo`04ool00?oooooo
ooooo`0004;ooooo000Qooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool0C?ooool2
ool00003ooooool0003o0000043ooooo000Qooooo`03o`000?oooooooooo0:kooooo0_l0001Aoooo
o`04ool00?ooooooooooo`0003oooooo000Qooooo`?o0000[Oooool00ol0003oo`00ool0001Boooo
o`04ool00?ooooooooooo`0003kooooo000Qooooo`03o`000?oooooooooo0:cooooo00?o0000ool0
0?ooool0E?ooool00ooo003oooooooooo`02o`0003cooooo000Qooooo`03o`000?oooooooooo0:_o
oooo00?o0000ool00?ooool0F_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooo
ooooo`2[ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o
0000ooooooooool0Z_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo03Oooooo000Q
ooooo`03o`000?oooooooooo0:Wooooo00?oo`00ooooooooool0Goooool2o`0003Oooooo000Qoooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0H_ooool00ol0003oooooooooo`0doooo
o`008Oooool3o`000:Oooooo00?oo`00ooooooooool0H_ooool2ool00003o`000?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo0:Kooooo00?oo`00ooooooooool0IOooool2ool00003o`00
0?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J?oo
ool00ooo003o0000ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooo
oooo06[ooooo00?oo`00o`000?ooool0<?ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo
003oooooooooo`1/ooooo`03ool00?l0003ooooo02oooooo000Qooooo`03o`000?oooooooooo0:;o
oooo00?o0000ooooooooool0K_ooool00ooo003o0000ooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo073ooooo00?oo`00o`000?ooool0;Oooool0027ooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`1booooo`03ool00?l0003ooooo02cooooo000Q
ooooo`?o0000Woooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo02_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`07ooooo`03o`000?oo
oooooooo037ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM033ooooo00?oo`00o`000?ooool02_ooool5o`0001_ooooo000Qooooo`03o`000?oo
oooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0`ooooo`03ool00?l0003ooooo00Wooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oo
oooo00?oo`00o`000?ooool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`03
ogMgMolb<S;ooooo03?ooooo0_l00009ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0?oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Kooooo00?o0000ooooooooool01oooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000
ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmV
IVKo000000Gooooo00?oo`00ooooooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_oo
ool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003o
ooooooooo`2Gooooo`03ool00?l0003ooooo08Oooooo0_oo000Qooooo`008Oooool00ol0003ooooo
ooooo`2Gooooo`03ool00?oooooooooo08Wooooo00?oo`00ooooooooool07_ooool0027ooooo00?o
0000ooooooooool0U_ooool00ooo003oooooooooo`2;ooooo`03ool00?oooooooooo01gooooo000Q
ooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0SOooool00ooo003oooooooooo`0B
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00oooo
ooooool0Soooool00ooo003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?oo
ool001[ooooo1ol000000ooo003o0000o`00002Co`000003ool00?l0003o0000097o000000?oo`00
o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003o
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000
ooooool00000TOooool00ol0003oooooooooo`2Vooooo`;o00000_ooool2o`0000Cooooo000Qoooo
o`03o`000?oooooo0000093ooooo00?o0000ooooooooool0/Oooool0027ooooo00Co0000oooooooo
oooo0000S_ooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo0000
08cooooo00?o0000ooooooooool0/oooool0027ooooo00Go0000ooooooooooooooooo`00002;oooo
o`03o`000?oooooooooo0;Cooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo0;Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08Gooooo00?oo`00ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`23ooooo`03ool00?oooooooooo0;Oooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0POooool00ooo003oooooooooo`2hooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0^Oooool0027ooooo
00?o0000ooooooooool01_ooool00ol0003oo`00ooooo`1nooooo`03ool00?oooooooooo0;[ooooo
000Qooooo`?o00001oooool00ooo003oooooooooo`1looooo`03ool00?oooooooooo0;_ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0Noooool00ooo003oooooooooo`2l
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo003ooooo07Wooooo00?oo`00o`00
0?ooool0_Oooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1gooooo`03
ool00?l0003ooooo0;kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ool00?ooool0
M_ooool00ooo003o0000ooooo`2oooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
003ooooo07Cooooo00?oo`00o`000?ooool0`?ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oo`00ooooo`1booooo`03ool00?l0003ooooo0<7ooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ool00?ooool0LOooool00ol0003oooooooooo`31ooooo`008Oooool3o`0000go
oooo00?o0000ool00?ooool0Koooool00ol0003oooooooooo`32ooooo`008Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oo003ooooo06kooooo00?o0000ooooooooool0`_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`34
ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`37ooooo`008Oooool3o`0001;ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`38ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06;ooooo00?oo`00o`000?ooool0bOooool0027ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ooooo`1Pooooo`03ool00?l0003ooooo0<[ooooo000Qooooo`03o`000?oooooooooo01Go
oooo00?o0000ool00?ooool0G_ooool00ooo003o0000ooooo`3;ooooo`008Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oo003ooooo05cooooo00?oo`00o`000?ooool0c?ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Jooooo`03ool00?l0003ooooo0<go
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo003ooooo05Wooooo00?oo`00o`000?oo
ool0c_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000Hooooo`03o`000?oo003ooooo05Oooooo00?oo`00o`000?ooool0coooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oo`00ooooo`1Eooooo`03ool00?oooooo00000=3ooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oo`00ooooo`1Cooooo`03ool00?oooooo00000=7ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01_ooooo00?o0000ool00?ooool0DOooool00ooo003oooooo`00003Booooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oo003ooooo04oooooo00?oo`00ooooool00000doooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo003ooooo
04oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003o
o`00ooooo`1=ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ool00?ooool0B_ooool2o`000=Kooooo000Qooooo`?o00008?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0f?ooool0027ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0oooooo`;oo`0000?oooooo`000?ooool0f_ooool0027ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0mooooo`04ool00?oooooo0000o`000=co
oooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>oooool00ooo003ooooo
o`00003Nooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?ooooooo`0003Wooooo00?o
o`00ooooool00000goooool0027ooooo0ol0000Wooooo`04o`000?ooooooo`00ool003Kooooo00?o
o`00ooooool00000h?ooool0027ooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooooo
000cooooo`;oo`0000?oooooo`000?ooool0h?ooool0027ooooo00?o0000ooooooooool0:Oooool2
o`000003oooooooo003oo`00033ooooo00Coo`00oooooooooooo0000h_ooool0027ooooo00?o0000
ooooooooool0:oooool01?l0003ooooooooooooo000]ooooo`;oo`0000?oooooo`000?l00000hooo
ool0027ooooo00?o0000ooooooooool0;?ooool2o`000003oooooooo003oo`0002[ooooo00Coo`00
oooooooooooo0000iOooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02
ool002Kooooo0_oo00000ooooooo0000o`00003Vooooo`008Oooool00ol0003oooooooooo`0_oooo
o`;o00000_ooool2ool002Kooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000oooooooo
ool0<Oooool2o`0000;ooooo00?oo`00ooooooooool08Oooool2o`000>Wooooo000Qooooo`?o0000
<oooool2o`0002;ooooo0_l0003[ooooo`008Oooool00ol0003oooooooooo`0eooooo`;o00005_oo
ool3ool000Gooooo0_l0003]ooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00Kooooo3Ooo0006ooooo`;o0000koooool0027ooooo00?o0000ooooooooool0>?ooool3o`00
01Gooooo0ol0003aooooo`008Oooool00ol0003oooooooooo`0kooooo`Go00003?ooool4o`000?Co
oooo000Qooooo`03o`000?oooooooooo043ooooo3?l0003hooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@
ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7o
gMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02
ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV
5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q
8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@
4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^
k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo
00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;o
ooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mg
MgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMoooo
ool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo410@00Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo
00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@
4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIV
I_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eoooo
o`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l0
00000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003o
ooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o
^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .34994 L
.10458 .3822 L
.12507 .3944 L
.14415 .40388 L
.16254 .41125 L
.18221 .41715 L
.19242 .41937 L
.19781 .42031 L
.20351 .42112 L
.2085 .42168 L
.21114 .42191 L
.21399 .42212 L
.21659 .42228 L
.21898 .42238 L
.22012 .42242 L
.22137 .42245 L
.22256 .42248 L
.22365 .42249 L
.22494 .4225 L
.22559 .4225 L
.2263 .4225 L
.22756 .42249 L
.22873 .42247 L
.22944 .42245 L
.23012 .42244 L
.23138 .4224 L
.23422 .42228 L
.2367 .42214 L
.23899 .42198 L
.24418 .4215 L
.24846 .421 L
.2532 .42032 L
.26278 .4186 L
.28213 .4137 L
.30299 .40654 L
.34413 .38818 L
.38375 .36806 L
.42186 .3497 L
.44311 .34093 L
.46242 .33426 L
.47206 .33146 L
.4825 .32886 L
.4923 .32683 L
.50147 .32529 L
.51093 .32408 L
.51595 .3236 L
.52134 .32319 L
.52404 .32303 L
.52698 .32289 L
Mistroke
.52976 .32278 L
.53109 .32275 L
.53234 .32272 L
.53356 .32269 L
.53421 .32269 L
.53489 .32268 L
.5361 .32267 L
.5372 .32266 L
.53848 .32266 L
.53967 .32267 L
.54098 .32268 L
.54172 .32269 L
.54238 .3227 L
.54468 .32275 L
.54721 .32282 L
.54985 .32293 L
.55232 .32305 L
.56151 .32367 L
.56673 .32414 L
.57151 .32464 L
.58228 .326 L
.62196 .33302 L
.66012 .34097 L
.68141 .3451 L
.70073 .3483 L
.71039 .34965 L
.72086 .35089 L
.73066 .35183 L
.73983 .3525 L
.74441 .35276 L
.74932 .35298 L
.75212 .35308 L
.75477 .35316 L
.75715 .35321 L
.75849 .35323 L
.75974 .35325 L
.76095 .35327 L
.76226 .35328 L
.76297 .35328 L
.76371 .35328 L
.76435 .35328 L
.76504 .35328 L
.76578 .35328 L
.76645 .35328 L
.76723 .35328 L
.76796 .35327 L
.76926 .35326 L
.77068 .35324 L
.77323 .3532 L
.77594 .35313 L
Mistroke
.7808 .35297 L
.78572 .35275 L
.79022 .35249 L
.80035 .35174 L
.80974 .35084 L
.81865 .3498 L
.85687 .3435 L
.87656 .33919 L
.89753 .33385 L
.93914 .32124 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000<?l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003ooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02Oooool4o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0
000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`03o`000?oooooooooo017ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooool00000oooooolLooooo`04o`000?oo
003oo`00o`0001_ooooo0_l00002ooooo`;o00001?ooool0027ooooo00Co0000oooooooooooo0000
V_oooolLo`00067ooooo00Co0000ool00?oo003oo`00:?ooool0027ooooo00Go0000oooooooooooo
ooooo`00002Booooo`;o00001ooo000:ooooo`Coo`003?ooool4o`0005[ooooo00Co0000ool00?oo
003oo`00:oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`?o
00005oooool5ool000_ooooo1ol0001@ooooo`04o`000?oo003oo`00ool002kooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0P_ooool5ool00004ooooool0003o0000o`00
01oooooo1Ooo000=ooooo`Ko0000Aoooool01?l0003oo`00ool00?oo000aooooo`008Oooool3o`00
00Cooooo00?o0000ooooooooool0O_ooool3ool000?ooooo0ol0000Wooooo`;oo`004Oooool6o`00
03cooooo1?l00002ool003Cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool0N_ooool3ool000?ooooo0ol00013ooooo`Ko0000<?ooool6o`0003[ooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0M_ooool3ool000?ooooo0ol0000iooooo`Koo`00
3Oooool6o`0002Cooooo1_l00010ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo07Cooooo00?oo`00ooooooooool00_ooool2o`0004;ooooo0ooo000@ooooo`So00005ooo
ool5o`000003oooooooo003oo`0000Coo`00?oooool0027ooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`1booooo`04ool00?ooooooooooooooo`;o0000Aoooool5ool001?ooooo5ol0
0006ool004Gooooo000Qooooo`03o`000?oooooooooo00Wooooo0_oo001cooooo`?o0000C_ooool2
ool002?ooooo1Ooo001;ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo
06kooooo0_l0001Moooooa3oo`00FOooool0027ooooo0ol0000<ooooo`03ool00?oooooooooo06_o
oooo0_l00038ooooo`008Oooool00ol0003oooooooooo`0=ooooo`;oo`00Hoooool2ool000Cooooo
0_l0003:ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo003ooooo05oooooo0_oo
0004ooooo`;o0000c?ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oo`00ooooo`1M
ooooo`03ool00?oooooooooo00;ooooo0_l0003>ooooo`008Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oo003ooooo05[ooooo0_oo0003ooooo`;o0000d?ooool0027ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Fooooo`;oo`000oooool2o`000=;ooooo000Qooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0D_ooool3ool000?ooooo0_l0003Dooooo`008Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo0_oo0004ooooo`;o0000e_oo
ool0027ooooo0ol0000Eooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool00_ooool2
o`000=Sooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Coooool2o`00
0=[ooooo000Qooooo`03o`000?oooooooooo01Oooooo0_l000000oooooooo`00ool0001:ooooo`;o
0000g?ooool0027ooooo00?o0000ooooooooool06Oooool01?l0003ooooooooooooo0017ooooo`;o
0000g_ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ool004?ooooo
0_l0003Pooooo`008Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooooooo`;oo`00
>Oooool2ool000Cooooo0_l0003Rooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo0_oo000eooooo`;oo`001?ooool2o`000>Cooooo000Qooooo`?o00007Oooool2
o`0000Cooooo0_oo000aooooo`;oo`001?ooool2o`000>Kooooo000Qooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool00oooool3ool002_ooooo0ooo0003ooooo`?o0000j?ooool0027o
oooo00?o0000ooooooooool08?ooool2o`0000Kooooo00?oo`00ooooooooool09Oooool3ool000Co
oooo0_l0003[ooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo
1?oo0005ooooo`;o0000kOooool0027ooooo00?o0000ooooooooool08oooool3o`0002gooooo0_l0
003_ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Vooooo`?o00002Oooool5ool001[ooooo
0_l0003aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0:Oooool2o`0000cooooo3?oo000<ooooo`;o0000
loooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo
0ol0000[ooooo`03o`000?oooooooooo01gooooo1?l0003eooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0/ooooo`Ko0000
5Oooool4o`000?Wooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0<_ooool2o`00013ooooo0ol0003mooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0doooooa3o0000ooooool1ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003
oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo
00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o
8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001n
ooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oo
oooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7
QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo1?l000000ol@
413oooooooooo`1hooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMoooo
o`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo07[ooooo001nooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo07[ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04oooo
o`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0E
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
07[ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00U_ooool00ol0003oooooooooo`07
ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;o
oooo00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000007co
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .31783 L
.08255 .32215 L
.0932 .32407 L
.10458 .32572 L
.11009 .32635 L
.11531 .32682 L
.11999 .32716 L
.12263 .3273 L
.12507 .32741 L
.12616 .32745 L
.12734 .32749 L
.12836 .32751 L
.12947 .32754 L
.13077 .32756 L
.13201 .32757 L
.13321 .32757 L
.13433 .32757 L
.13561 .32756 L
.13682 .32755 L
.13791 .32753 L
.13908 .3275 L
.14172 .32742 L
.14415 .32731 L
.14885 .32703 L
.15389 .32662 L
.16298 .32558 L
.17378 .32391 L
.18364 .32199 L
.22348 .31151 L
.26181 .30033 L
.28159 .29555 L
.29157 .29364 L
.29694 .29278 L
.3026 .29201 L
.30742 .29148 L
.30997 .29125 L
.31269 .29104 L
.3152 .29088 L
.31748 .29077 L
.31858 .29072 L
.31978 .29068 L
.32082 .29065 L
.32194 .29063 L
.32324 .29061 L
.32445 .2906 L
.32519 .2906 L
.3259 .2906 L
.32721 .29061 L
.32789 .29062 L
Mistroke
.3286 .29064 L
.32988 .29067 L
.33141 .29072 L
.33279 .29078 L
.33527 .29091 L
.33795 .2911 L
.3428 .29155 L
.34773 .29216 L
.35233 .29288 L
.36278 .29503 L
.37296 .29782 L
.38385 .30158 L
.40514 .31116 L
.42527 .32281 L
.46365 .35089 L
.50448 .38643 L
.5438 .42231 L
.58161 .45462 L
.60262 .47044 L
.62186 .48308 L
.64194 .49405 L
.6606 .50197 L
.66977 .50501 L
.67956 .5076 L
.68515 .50878 L
.69042 .50968 L
.69515 .51033 L
.69763 .5106 L
.70028 .51084 L
.70284 .51102 L
.70518 .51114 L
.70631 .51119 L
.70754 .51123 L
.70869 .51126 L
.70977 .51127 L
.711 .51128 L
.71217 .51128 L
.71344 .51127 L
.71416 .51125 L
.71482 .51124 L
.71607 .5112 L
.71744 .51114 L
.72019 .51099 L
.72295 .51078 L
.72546 .51055 L
.7311 .50984 L
.73632 .50899 L
.74125 .508 L
.75095 .50553 L
.76124 .50219 L
Mistroke
.77968 .49435 L
.79923 .48358 L
.81754 .47134 L
.85633 .43934 L
.89757 .39818 L
.9373 .35412 L
.97551 .30981 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo05Cooooo2_oo003Vooooo`008Oooool00ol0003oooooooooo`1Wooooo`?o
o`00f_ooool0027ooooo00?o0000ooooooooool0BOooool2ool001oooooo0ooo003Gooooo`008Ooo
ool00ol0003oooooooooo`16ooooo`?oo`009?ooool3ool00<[ooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000ooooooooool0@_ooool4ool001Kooooo1Ol0000?ooooo`;oo`00b?ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000JooooodSo00001?oo000`o`0000;oo`00/ol0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00Co
0000ooooool0003o00002oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooool00002ool000[ooooo00Co0000oooooooooooo
oooo1_l00005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool6o`0000Co
oooo0_oo000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04o`000?oooooooooooooo
o`;o00000oooool3ool000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`08ooooo`?o000000Coooooo`000?ooooooo`003?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOo
MgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`Goo`00=oooool4
o`0002[ooooo0_l0002`ooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool01_ooool3o`0000Gooooo1Ooo000Kooooo`?oo`004?ooool4o`00
033ooooo0_l0002]ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Wo
oooo0ol00007ooooo`Coo`005?ooool3ool000oooooo1?l0000fooooo`;o0000Z_ooool00ol0003o
ooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0<ooooo`?o00004_ooool:ool000kooooo
1?l0000looooo`;o0000Yoooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0?ooooo`Co00008oooool3o`0004;ooooo0_l0002Tooooo`03o`000?oooooooooo023ooooo000Q
ooooo`?o00004oooool4o`0001_ooooo1?l00017ooooo`04o`000?ooooooo`00ool009oooooo00?o
0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool05oooool5o`0000oooooo1ol0001<
ooooo`;o000000?oooooool00?ooool0W?ooool00ooo003oooooooooo`0Rooooo`008Oooool00ol0
003oooooooooo`0Looooo`oo0000EOooool2o`0000;oo`00V_ooool00ol0003oo`00ooooo`0Soooo
o`008Oooool00ol0003oooooooooo`22ooooo`04o`000?ooooooo`00ool009Oooooo00?o0000ool0
0?ooool09?ooool0027ooooo00?o0000ooooooooool0Poooool2o`000003oooooooo003ooooo09Co
oooo00?o0000ool00?ooool09Oooool0027ooooo00?o0000ooooooooool0QOooool2o`000003ool0
0?oooooooooo097ooooo00?o0000ool00?ooool09_ooool0027ooooo00?o0000ooooooooool0Qooo
ool00ol0003oo`00ooooo`2Aooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000R?ooool0
0ol0003oo`00ooooo`2?ooooo`03o`000?oo003ooooo02Oooooo000Qooooo`03o`000?oooooooooo
08Wooooo00?o0000ool00?ooool0SOooool00ol0003oo`00ooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`2:ooooo`03o`000?oo003ooooo08_ooooo00?o0000ool00?ooool0:Oooool0027ooooo
00?o0000ooooooooool0Roooool2o`0008[ooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`26ooooo`03o`000?oo003ooooo02_ooooo000Q
ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0Q?ooool00ol0003oo`00ooooo`0/
ooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08;ooooo00?o0000ool0
0?ooool0;Oooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo02kooooo000Qooooo`?o0000TOooool2o`0007oooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo033ooooo000Qooooo`03o`000?oooooooooo09?ooooo0_oo001kooooo`03o`000?oooooo
oooo037ooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00o`000?ooool0Moooool00ol0
003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?l0003ooooo07Go
oooo00?o0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Uoooool00ooo003o0000
ooooo`1cooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo09Sooooo00?o
o`00o`000?ooool0LOooool00ol0003oooooool0000eooooo`008Oooool3o`0009Wooooo0_oo0000
0ol0003oooooooooo`1]ooooo`03o`000?ooooooo`0003Kooooo000Qooooo`03o`000?oooooooooo
09_ooooo00?oo`00o`000?ooool0K?ooool00ol0003oooooool0000gooooo`008Oooool00ol0003o
ooooooooo`2Looooo`03ool00?l0003ooooo06[ooooo00?o0000oooooooo0000>?ooool0027ooooo
00?o0000ooooooooool0WOooool00ooo003o0000o`00001Xooooo`03o`000?ooooooo`0003Wooooo
000Qooooo`03o`000?oooooooooo09kooooo00?oo`00ooooool00000I_ooool00ol0003oooooool0
000jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Oooooo`03ool00?oooooo000006Cooooo
00?o0000oooooooo0000>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooool0000looooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ool0000mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo0000
?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo05Wooooo0_l000000ooooooo
o`00ooooo`0nooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooo
ooooo`00@?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0Yoooool2ool005Cooooo0_l00015ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo053ooooo00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0
Z_ooool00ooo003o0000ooooo`1>ooooo`03o`000?oooooooooo04Kooooo000Qooooo`?o0000Zooo
ool00ooo003o0000ooooo`1<ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooo
oooo0:cooooo0_oo001:ooooo`;o0000B_ooool0027ooooo00?o0000ooooooooool0[_ooool00ooo
003oooooooooo`16ooooo`04o`000?ooooooo`00ool004Wooooo000Qooooo`03o`000?oooooooooo
0:oooooo00?oo`00ooooooooool0A?ooool00ol0003oooooool0001;ooooo`008Oooool00ol0003o
ooooooooo`2`ooooo`03ool00?l0003ooooo047ooooo0_l000000oooooooo`00ooooo`1;ooooo`00
8Oooool00ol0003oooooooooo`2aooooo`03ool00?l0003o000003oooooo00Co0000oooooooooooo
o`00COooool0027ooooo00?o0000ooooooooool0/_ooool2ool00003o`000?oooooooooo03_ooooo
00Co0000oooooooo003oo`00C_ooool0027ooooo0ol0002dooooo`03ool00?l0003o000003[ooooo
00?o0000oooooooo0000D?ooool0027ooooo00?o0000ooooooooool0]oooool2o`0003Oooooo00?o
0000oooooooo0000DOooool0027ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0b
ooooo`;o000000?oooooool00?ooool0DOooool0027ooooo00?o0000ooooooooool0^_ooool2o`00
033ooooo0_l000000oooooooo`00ool0001Cooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo02_ooooo0_l00002ooooo`03ool00?oooooooooo05?ooooo000Qooooo`03o`00
0?oooooooooo0;gooooo00?oo`00o`000?l00000:?ooool2o`0005[ooooo000Qooooo`03o`000?oo
oooooooo0;kooooo0_oo0003o`0002;ooooo0ol0001Looooo`008Oooool00ol0003oooooooooo`30
ooooo`;oo`0000Coooooo`000?l0003o00007Oooool2o`0005oooooo000Qooooo`?o0000`_ooool2
ool000;ooooo0ol0000Hooooo`;o0000HOooool0027ooooo00?o0000ooooooooool0a?ooool3ool0
00;ooooo0_l0000Aooooo`Go000000Coooooool00?oo003oo`00Goooool0027ooooo00?o0000oooo
ooooool0aoooool5ool0013o000000?oooooool00?oo00000ooo001Rooooo`008Oooool00ol0003o
ooooooooo`3<ooooo`03ool00?oooooooooo00Oooooo1ooo001Wooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0
003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEE
EOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Co
oooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo
00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo
001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRH
V?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooooooo
QhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_oooooo
k^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Ko
oooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`00
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool0
0olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?oo
ool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?o
gMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd0
5oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28165 L
.10458 .25635 L
.14415 .23311 L
.18221 .21278 L
.20178 .20445 L
.21267 .20076 L
.22272 .19809 L
.22758 .19707 L
.23293 .19618 L
.23553 .19583 L
.23832 .19552 L
.23985 .19538 L
.24126 .19526 L
.2426 .19518 L
.24402 .1951 L
.24536 .19504 L
.24658 .19501 L
.24781 .19499 L
.24896 .19498 L
.24961 .19498 L
.25031 .19499 L
.25155 .19501 L
.25224 .19503 L
.25288 .19505 L
.25435 .19511 L
.25562 .19518 L
.25683 .19527 L
.25908 .19546 L
.26152 .19573 L
.26416 .19608 L
.26901 .19692 L
.27356 .19793 L
.28394 .20104 L
.29405 .20516 L
.30494 .21083 L
.32498 .22451 L
.34608 .24326 L
.38419 .28677 L
.42475 .34253 L
.4638 .39954 L
.5053 .45708 L
.54528 .50409 L
.58374 .53802 L
.60362 .5506 L
.61377 .55568 L
.62466 .56012 L
.63489 .56334 L
.64424 .56549 L
.64873 .56626 L
Mistroke
.65111 .56659 L
.65363 .5669 L
.65606 .56715 L
.65826 .56733 L
.66047 .56747 L
.66255 .56756 L
.66372 .5676 L
.66497 .56763 L
.66615 .56765 L
.66722 .56765 L
.66848 .56764 L
.66919 .56764 L
.66985 .56762 L
.67106 .56759 L
.67234 .56755 L
.67488 .56742 L
.67725 .56725 L
.67986 .56702 L
.68267 .56671 L
.68737 .56605 L
.69232 .56518 L
.70115 .56318 L
.71072 .56038 L
.72093 .5567 L
.73931 .54834 L
.78086 .52197 L
.8209 .48802 L
.85942 .44886 L
.90039 .4021 L
.93984 .35429 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0mooooo`Ooo`00ooooool1ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`?oo`004?ooool2ool00?Gooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Oooooo0ooo000Eooooo`?oo`00l_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0dooooo`?oo`006oooool2ool00?3ooooo000Q
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0kOooool0027ooooo00?o0000oooo
ooooool0>oooool@o`0000[ooooo0_oo003]ooooo`008Oooool3o`0003Oooooo1?l0000@ooooo`Go
00001oooool00ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0dooooo`?o0000
6Oooool00ol0003oooooooooo`05ooooo`;oo`00j_ooool0027ooooo00?o0000ooooooooool0:Ooo
ool2ool000Kooooo0ol0000Mooooo`?o00001_ooool00ooo003oooooooooo`3Wooooo`008Oooool0
0ol0003oooooooooo`0Wooooo`;oo`001Oooool3o`0002?ooooo0ol00004ooooo`03ool00?oooooo
oooo0>Kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool00oooool2o`00
02Wooooo00?o0000ooooooooool0j_ooool0027ooooo00?o0000ooooooooool09?ooool2ool000Co
oooo0_l0000/ooooo`;o0000j_ooool0027ooooo00?o0000ooooooooool08_ooool2ool000Cooooo
0_l0000`ooooo`03o`000?oooooooooo0>Oooooo000Qooooo`?o00008?ooool2ool000Cooooo0_l0
000cooooo`;o0000ioooool0027ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`02
ooooo`;o0000=oooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0Moooo
o`;oo`000oooool2o`0003[ooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Looooo`04
ool00?ooooooooooooooo`;o0000?_ooool01?l0003ooooooooooooo003Pooooo`008Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo0000h?ooool0027o
oooo00?o0000ooooooooool07Oooool2o`0004?ooooo00?o0000oooooooo0000goooool0027ooooo
00?o0000ooooooooool06oooool2o`0004Gooooo00Co0000ooooooooooooo`00g_ooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooool00=go
oooo000Qooooo`?o00004_ooool2ool000Cooooo0_l0001:ooooo`04o`000?ooooooooooool00=co
oooo000Qooooo`03o`000?oooooooooo013ooooo0_oo0004ooooo`;o00009Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04_ooool01?l0
003ooooooooooooo000Wooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool2o`0002Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`03o`000?oo
ooooo`0002Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o
0000ooooooooool03Oooool2ool000?ooooo0_l0000Yooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`0Booooo`03o`000?ooooooo`0002Sooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool02oooool2ool000?ooooo0_l0000[ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Dooooo`03o`000?ooooooo`0002Oooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo
00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool02_ooool01?oo003ooooooooo
ooooool2o`0002gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`05Oooool01?l0003ooooooooooooo000Vooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_oo
ool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`02o`0002oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Sooooo00Co0000ooooooooooooo`00
9Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000Sooooo00Coo`00ooooool0003o0000
<Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool06Oooool01?l0003o
oooooooooooo000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooo
ooooool01oooool00ooo003o0000o`00000cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0001Wooooo00?o0000ooooooooool08_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo
000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000
ooooooooool01_ooool00ooo003o0000ooooo`1Sooooo`03o`000?oooooooooo0=Gooooo000Qoooo
o`03o`000?oooooooooo00Cooooo0_l0001Wooooo`03o`000?oooooooooo0=Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo0_l0001Yooooo`03o`000?oooooooooo0=Cooooo000Qooooo`03o`00
0?oooooooooo00;o0000K?ooool00ol0003oooooooooo`39ooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`?o0000Koooool00ol0003oooooooooo`38ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00Co0000ooooooooooooo`003_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qoooo
o`03o`000?oooooooooo07;ooooo00?o0000oooooooo0000/?ooool00ooo003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
0000[_ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`1dooooo`03o`00
0?ooooooo`000:cooooo00?o0000ool00?ooool07_ooool0027ooooo00?o0000ooooooooool0M?oo
ool01?l0003ooooooooooooo002[ooooo`03ool00?oooooooooo01kooooo000Qooooo`03o`000?oo
oooooooo07Gooooo00Co0000ooooooooooooo`00ZOooool00ooo003oooooooooo`0Oooooo`008Ooo
ool3o`0007Kooooo00?o0000oooooooo0000Z?ooool00ooo003oooooooooo`0Pooooo`008Oooool0
0ol0003oooooooooo`1gooooo`03o`000?ooooooo`000:Kooooo00?oo`00ooooooooool08Oooool0
027ooooo00?o0000ooooooooool0Moooool01?l0003ooooooooooooo002Tooooo`03ool00?l0003o
oooo02;ooooo000Qooooo`03o`000?oooooooooo07Sooooo00Co0000ooooooooooooo`00X_ooool0
0ooo003o0000ooooo`0Sooooo`008Oooool00ol0003oooooooooo`1iooooo`03o`000?ooooooo`00
0:7ooooo00?oo`00o`000?ooool09?ooool0027ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooool0002Oooooo`03ool00?l0003ooooo02Gooooo000Qooooo`03o`000?oooooooooo07[ooooo
00Co0000ooooooooooooo`00WOooool00ooo003o0000ooooo`0Vooooo`008Oooool3o`0007_ooooo
00?o0000ooooooooool0WOooool00ooo003o0000ooooo`0Vooooo`008Oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000
ooooooooool0O?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo02Oooooo000Qoooo
o`03o`000?oooooooooo07gooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`2Eooooo`03o`00
0?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo09;ooooo00?o0000ooooooooool0;?ooool0027ooooo0ol00021ooooo`03o`000?ooooooo`00
097ooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0POooool00ol0003o
ooooool0002@ooooo`03ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08;ooooo
00?o0000oooooooo0000S_ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003ooooooooo
o`23ooooo`03o`000?ooooooo`0008cooooo00?oo`00ooooooooool0;oooool0027ooooo00?o0000
ooooooooool0Q?ooool00ol0003oo`00ooooo`2:ooooo`03ool00?oooooooooo033ooooo000Qoooo
o`03o`000?oooooooooo08Cooooo00?o0000oooooooo0000ROooool00ooo003oooooooooo`0aoooo
o`008Oooool00ol0003oooooooooo`25ooooo`03o`000?ooooooo`0008Oooooo00?oo`00oooooooo
ool0<_ooool0027ooooo0ol00026ooooo`03o`000?oo003ooooo08Kooooo00?oo`00ooooooooool0
<_ooool0027ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooool00025ooooo`03ool00?oo
oooooooo03?ooooo000Qooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo0000Poooool0
0ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?ooooooo`00
087ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0ROooool00ol0003o
o`00ooooo`1oooooo`03ool00?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
08Wooooo00?o0000oooooooo0000O_ooool00ooo003o0000ooooo`0gooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0R_ooool00ol0003oooooool0001mooooo`03o`000?oooooooooo03Oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000Roooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo03Sooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool0>_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo03cooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo06oo
oooo0_oo0010ooooo`008Oooool3o`00093ooooo00Co0000ooooooooooooo`00K_ooool00ooo003o
ooooooooo`0oooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?ooooooo`0006gooooo
00?oo`00ooooooooool0@?ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003oooooool0
001[ooooo`03ool00?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000
ool00?ooool0JOooool00ooo003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`2Coooo
o`03o`000?ooooooo`0006Sooooo00?oo`00ooooooooool0@oooool0027ooooo00?o0000oooooooo
ool0U?ooool00ol0003oooooool0001Vooooo`03ool00?oooooooooo04Cooooo000Qooooo`03o`00
0?oooooooooo09Gooooo00?o0000oooooooo0000I?ooool00ooo003oooooooooo`15ooooo`008Ooo
ool3o`0009Kooooo00?o0000oooooooo0000H_ooool00ooo003oooooooooo`16ooooo`008Oooool0
0ol0003oooooooooo`2Gooooo`03o`000?ooooooo`00063ooooo00?oo`00ooooooooool0Aoooool0
027ooooo00?o0000ooooooooool0V?ooool00ol0003oooooool0001Nooooo`03ool00?oooooooooo
04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o0000oooooooo0000G?ooool00ooo003o
ooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03o`000?ooooooo`0005Wooooo
0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Jooooo`04o`000?ooooooooooool005Oooooo
00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0009gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo04oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo04gooooo00?oo`00ooooooooool0D_ooool0027ooooo00?o0000ooooooooool0X?oo
ool2o`0004cooooo00?oo`00ooooooooool0Doooool0027ooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`18ooooo`03ool00?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo
0:?ooooo00?o0000ool00?oo0000A_ooool00ooo003oooooooooo`1Eooooo`008Oooool00ol0003o
ooooooooo`2Tooooo`03o`000?ooooooo`0004Cooooo00?oo`00ooooooooool0E_ooool0027ooooo
0ol0002Uooooo`03o`000?ooooooo`00047ooooo0_oo001Iooooo`008Oooool00ol0003ooooooooo
o`2Vooooo`;o000000?oo`00ooooooooool0??ooool2ool005_ooooo000Qooooo`03o`000?oooooo
oooo0:Sooooo00?o0000ool00?ooool0>oooool00ooo003o0000ooooo`1Kooooo`008Oooool00ol0
003oooooooooo`2Yooooo`03o`000?oo003ooooo03Sooooo0_oo001Nooooo`008Oooool00ol0003o
ooooooooo`2Zooooo`03o`000?oo003ooooo03Kooooo00?oo`00o`000?ooool0G_ooool001Sooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0:_ooooo00?o0000ool00?oo0000
=?ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:cooooo0_l000000ooo003oooooooooo`0`ooooo`03o`000?oooooooooo063ooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[_ooool00ol0003oo`00ooooo`0^
ooooo`;o0000Hoooool001[ooooo00?o0000ooooooooool01?ooool3o`000:oooooo00?o0000ool0
0?ooool0;?ooool00ol0003oooooooooo`1Sooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool0:?ooool2o`0006Kooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool2o`0002Cooooo0_oo0002o`0006Sooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]?ooool00ol0003ooooooooo
o`0Oooooo`;oo`000_l0001Zooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooo
oooo0;Gooooo0ol00002ooooo`;oo`005oooool3ool000;o0000K?ooool0027ooooo00?o0000oooo
ooooool0^?ooool4o`0000Goo`003Oooool5ool000;o0000Koooool0027ooooo00?o0000oooooooo
ool0_?ooool3o`0000;ooooo00?oo`00ooooooooool01_ooool4ool000;ooooo0_l0001booooo`00
8Oooool3o`000;oooooo1Ol00004ooooo`So0000M?ooool0027ooooo00?o0000ooooooooool0a?oo
ool5o`0007_ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?o
IVIVogMgMoooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgM
oa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo
0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
0_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGo
ZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003
oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000Noooool007kooooo00Oo410@omgMgOmgMgOo
8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^ko
ooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;
ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A407_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool0
0_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEE
EOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool0
0ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^
00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRH
V?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@
4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool0N_ooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0=oooo
o`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo
00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo07Wooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@
400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooo
oonHV9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Ooo
ool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Doooo
o`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01kooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25198 L
.10458 .19094 L
.12507 .16576 L
.14415 .14666 L
.16254 .13303 L
.16783 .13006 L
.17284 .12765 L
.17768 .1257 L
.18221 .12421 L
.18682 .12304 L
.18927 .12256 L
.1919 .12215 L
.19322 .12199 L
.19466 .12185 L
.19601 .12174 L
.19727 .12167 L
.19852 .12162 L
.19965 .1216 L
.20095 .12161 L
.20218 .12164 L
.20325 .12168 L
.20443 .12175 L
.20565 .12185 L
.2068 .12196 L
.20884 .12221 L
.21104 .12255 L
.21605 .12363 L
.22062 .12495 L
.23054 .12891 L
.23971 .13388 L
.26047 .14942 L
.27913 .16793 L
.29973 .19252 L
.33994 .24927 L
.37862 .30891 L
.41976 .37076 L
.45939 .42348 L
.4975 .46454 L
.51875 .48266 L
.53806 .49601 L
.55814 .50675 L
.5771 .514 L
.58682 .51666 L
.59214 .51782 L
.59712 .51871 L
.60171 .51939 L
.6059 .51987 L
.61056 .52027 L
.61313 .52042 L
Mistroke
.61557 .52053 L
.61682 .52057 L
.61748 .52058 L
.61817 .5206 L
.61944 .52062 L
.62061 .52062 L
.62174 .52062 L
.62279 .52061 L
.62395 .52059 L
.62518 .52056 L
.6265 .52052 L
.62793 .52046 L
.63054 .52032 L
.63307 .52015 L
.63541 .51995 L
.64434 .51889 L
.64885 .51817 L
.65381 .51725 L
.6732 .51236 L
.69407 .505 L
.73526 .48518 L
.77494 .46103 L
.8131 .43471 L
.85371 .40468 L
.89281 .37465 L
.93436 .34205 L
.97439 .31042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_oo`00ooooool:ooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`;oo`002oooool3ool00?oooooo1oooool0027ooooo00?o0000
ooooooooool0?_ooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0<?ooool;o`000?oooooo2_ooool0027ooooo
00?o0000ooooooooool0;_ooool2o`0000_ooooo0ol0003oooooo`Oooooo000Qooooo`?o00009Ooo
ool00ooo003oooooooooo`03ooooo`?o00004?ooool3o`000?oooooo1?ooool0027ooooo00?o0000
ooooooooool09?ooool01?oo003oooooooooooooool3o`0001Kooooo0_l0003oooooo`;ooooo000Q
ooooo`03o`000?oooooooooo02?ooooo00Goo`00ooooooooooooooooo`00000Kooooo`05o`000?oo
oooooooooooooooo0000o?ooool0027ooooo00?o0000ooooooooool08_ooool00ooo003ooooooooo
o`02o`0001gooooo0_l000000oooooooo`00ool0003kooooo`008Oooool00ol0003oooooooooo`0Q
ooooo`04ool00?ooooooooooo`00027ooooo00Co0000ooooooooooooo`00n_ooool0027ooooo00?o
0000ooooooooool08?ooool01?oo003oooooo`000?l0000Sooooo`04o`000?ooooooooooool00?Wo
oooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooool000009_ooool01?l0003ooooo
oooooooo003hooooo`008Oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooo000002Sooooo
00Co0000ooooooooooooo`00moooool0027ooooo0ol0000Mooooo`03ool00?oooooo000002[ooooo
00Co0000ooooooooooooo`00m_ooool0027ooooo00?o0000ooooooooool07?ooool00ooo003ooooo
o`00000/ooooo`03o`000?ooooooo`000?Kooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o
o`00ooooool00000;_ooool00ol0003oooooool0003eooooo`008Oooool00ol0003oooooooooo`0J
ooooo`04ool00?ooooooooooo`0002oooooo00?o0000oooooooo0000m?ooool0027ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`03o`000?ooooooo`000??ooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooool0
003booooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo0?7ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Iooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0l?oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0>oooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0>kooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3]ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0kOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooo000003oooooo00?o0000ooooooooool0k?ooool0027ooooo00?o0000ooooooooool04ooo
ool00ooo003o0000ooooo`10ooooo`03o`000?oooooooooo0>_ooooo000Qooooo`03o`000?oooooo
oooo01;ooooo00?oo`00o`000?ooool0@Oooool00ol0003oooooool0003[ooooo`008Oooool3o`00
017ooooo00?oo`00o`000?ooool0@oooool00ol0003oo`00ooooo`3Zooooo`008Oooool00ol0003o
ooooooooo`0Aooooo`03ool00?l0003ooooo04Cooooo00?o0000ool00?ooool0jOooool0027ooooo
00?o0000ooooooooool04?ooool00ooo003o0000ooooo`16ooooo`03o`000?oo003ooooo0>Sooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0A_ooool00ol0003oo`00oooo
o`3Xooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo04Sooooo00?o0000
ool00?ooool0ioooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1:oooo
o`03o`000?oo003ooooo0>Kooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0B_ooool00ol0003oo`00ooooo`3Vooooo`008Oooool3o`0000gooooo00?oo`00ooooooooool0
C?ooool00ol0003oo`00ooooo`3Uooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
003ooooo04kooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oo`00ooooo`1@ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo
00[ooooo00?o0000ool00?ooool0DOooool00ol0003oo`00ooooo`3Sooooo`008Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ool00?ooool0h_ooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oo003ooooo0>7ooooo
000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`3Qooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool0h?ooool0027ooooo0ol00007ooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool0h?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0dooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?
ooooo`03o`000?oooooooooo02_ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0=Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0=_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool04?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0=ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Cooooo00?o0000oooooooo0000:_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000;ooooo00?oo`00ooooooooool0>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool05?ooool00ol0003oooooool0000Zooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0001Cooooo00?o0000oooooooo00009oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Go0000ooooooooooooooooool0001Uooooo`03o`000?ooooooo`000=[o
oooo000Qooooo`04o`000?ooooooooooool006Kooooo00?o0000oooooooo0000f_ooool0027ooooo
00?o0000oooooooo0000J?ooool00ol0003oooooool0003Iooooo`008Oooool00ol0003oooooool0
001Xooooo`03o`000?ooooooo`000<oooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ool00?ooool0JOooool00ol0003oooooool0003>ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
1?ooool001[ooooo1ol000000ooo003o0000o`00001/o`000003ool00?l0003o00000;So000000?o
o`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooool00007ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
003o000001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?ooooooo`0000Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo0000
4oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1[ooooo`04o`00
0?ooooooooooool00;Cooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03o`000?ooooooo`000;?ooooo00?o0000ooooooooool0
7oooool0027ooooo00?o0000ooooooooool0K?ooool01?l0003ooooooooooooo002aooooo`03o`00
0?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo0:kooooo00?o0000ooooooooool08_ooool0027ooooo0ol0001^ooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`2Yooooo`03ool00?oooooo000002Kooooo000Qooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0Z?ooool00ooo003o0000ooooo`0Vooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo0:Kooooo0_oo00000ol0003oooooooooo`0Vooooo`008Oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo0:Cooooo00?oo`00o`000?l00000:Oooool0
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2Rooooo`03ool00?l0003ooooo
02[ooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo0000Woooool2ool00003
o`000?oooooooooo02[ooooo000Qooooo`?o0000Loooool00ol0003oooooool0002Nooooo`03ool0
0?oooooo000002gooooo000Qooooo`03o`000?oooooooooo07Cooooo00?o0000oooooooo0000Vooo
ool2ool00003ooooool0003ooooo02gooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000
oooooooo0000VOooool01?oo003oooooo`000?l0000_ooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03o`000?ooooooo`0009Sooooo00?oo`00ooooool00000<Oooool0027ooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooool0002Fooooo`03ool00?oooooo000003;ooooo000Qooooo`03
o`000?oooooooooo07Oooooo00?o0000oooooooo0000U_ooool00ol0003oooooooooo`0aooooo`00
8Oooool00ol0003oooooooooo`1gooooo`03o`000?ooooooo`0009Gooooo00?o0000ooooooooool0
<_ooool0027ooooo00?o0000ooooooooool0N?ooool00ol0003oooooool0002Booooo`;o0000=Ooo
ool0027ooooo0ol0001iooooo`03o`000?ooooooo`00093ooooo00?o0000ooooooooool0=Oooool0
027ooooo00?o0000ooooooooool0NOooool01?l0003ooooooooooooo002>ooooo`03o`000?oooooo
oooo03Kooooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo0000SOooool00ol0
003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1kooooo`03o`000?ooooooo`0008Oo
oooo0_oo0002ooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo07_ooooo
00Co0000ooooooooooooo`00QOooool00ooo003oooooooooo`02o`0003_ooooo000Qooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool0Q?ooool01?oo003oooooooooool0000mooooo`00
8Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08;ooooo00Coo`00oooooooooooo
0000?_ooool0027ooooo0ol0001nooooo`03o`000?oooooooooo07oooooo0_oo0002ooooo`03o`00
0?oooooooooo03gooooo000Qooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0O_oo
ool01Ooo003ooooooooooooooooo0000043ooooo000Qooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0Noooool2ool000;ooooo0_l00011ooooo`008Oooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo07Wooooo00Goo`00ooooooooooooooooo`000013ooooo`008Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo07Sooooo00Goo`00ooooooooooooooooo`00
0014ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo07Kooooo
00?oo`00ooooooooool00_l00015ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0P_ooool01?l0003ooooo
oooooooo001fooooo`03o`000?oooooooooo04Gooooo0007ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`?o0000Poooool01?l0003ooooooooooooo001doooo
o`03o`000?oooooooooo04Kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooool0001b
ooooo`03o`000?oooooooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0Q?ooool01Ol0003ooooooooo
ooooooooo`0006oooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`05o`000?oooooooooooooooooo
0000KOooool00ol0003oooooooooo`1:ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool0JOooool00ol0003oooooooooo`1;ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`1Rooooo`;oo`000_ooool2o`0004kooooo000Qooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Pooooo`05ool0
0?ooooooooooooooool00000D?ooool0027ooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo05gooooo0_oo0003ooooo`03o`000?oooooooooo04oooooo
000Qooooo`?o0000R?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00Co
o`00oooooooooooooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool0F?ooool2ool000?ooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo05Kooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo05Wooooo0_oo0003ooooo`;o0000E_ooool0027o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Fooooo`;oo`001?ooool00ol0003o
ooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo05Cooooo
00?oo`00ooooooooool00oooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo05Oooooo0_l0001Jooooo`008Oooool3o`0008oooooo00?o0000
ooooooooool0E?ooool2o`0005cooooo000Qooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool0DOooool2o`0005kooooo000Qooooo`03o`000?oooooooooo097ooooo0_l00005ooooo`03
ool00?oooooooooo04Oooooo0_l0001Pooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo00;ooooo0_oo0017ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oo
oooooooo09Cooooo0_l00004ooooo`03ool00?oooooooooo03gooooo0_oo0003ooooo`;o0000Hooo
ool0027ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`02ooooo`;oo`00>oooool2
ool000?ooooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0=_ooool2ool000?ooooo0_l0001Wooooo`008Oooool00ol0003o
ooooooooo`2Hooooo`;o00001?ooool2ool003Cooooo0_oo0003ooooo`;o0000JOooool0027ooooo
0ol0002Jooooo`03o`000?oooooooooo00?ooooo0_oo000`ooooo`;oo`000oooool2o`0006_ooooo
000Qooooo`03o`000?oooooooooo09_ooooo0_l00005ooooo`;oo`00;?ooool2ool000?ooooo0_l0
001]ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Cooooo0_oo000V
ooooo`Coo`001?ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003oooooooooo`2Noooo
o`;o0000<_ooool2o`00073ooooo000Qooooo`03o`000?oooooooooo0:3ooooo0_l0000^ooooo`;o
0000L_ooool0027ooooo00?o0000ooooooooool0X_ooool2o`0001kooooo00?oo`00ooooooooool0
2Oooool2o`0007Cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0ol00008oooooa?oo`002Ooo
ool3o`0007Kooooo000Qooooo`?o0000Yoooool3o`0001kooooo0ol0001iooooo`008Oooool00ol0
003oooooooooo`2Zooooo`?o00006?ooool3o`0007cooooo000Qooooo`03o`000?oooooooooo0:go
oooo0ol0000?ooooo`Ko0000Ooooool0027ooooo00?o0000ooooooooool0/?ooool?o`0008Gooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000oooo
ooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool0
0ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooo
oooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0Looo
ool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko
00001Oooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Foooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o
^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@
413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22711 L
.08255 .19021 L
.10458 .15642 L
.11448 .14394 L
.12507 .13264 L
.13499 .12407 L
.14415 .11794 L
.14911 .11535 L
.15437 .11316 L
.15964 .11154 L
.16265 .11088 L
.16399 .11064 L
.16546 .11042 L
.1668 .11026 L
.16805 .11015 L
.16925 .11006 L
.17052 .11001 L
.17178 .10998 L
.17296 .10999 L
.17401 .11002 L
.17516 .11008 L
.17642 .11017 L
.1778 .11031 L
.1806 .1107 L
.18318 .1112 L
.1856 .11178 L
.1906 .11333 L
.19605 .11553 L
.20595 .12086 L
.22451 .13503 L
.24428 .15517 L
.26529 .18083 L
.30304 .23283 L
.34324 .28824 L
.38193 .33429 L
.40158 .35351 L
.42307 .37091 L
.4436 .38396 L
.46269 .3931 L
.47322 .39697 L
.48315 .39992 L
.49207 .40203 L
.49706 .403 L
.50174 .40377 L
.50668 .40445 L
.5112 .40496 L
.51622 .40541 L
.51902 .4056 L
.52161 .40575 L
Mistroke
.52412 .40586 L
.52678 .40595 L
.5283 .40599 L
.52905 .406 L
.52973 .40601 L
.53102 .40603 L
.5317 .40603 L
.53241 .40604 L
.53363 .40604 L
.53494 .40603 L
.53617 .40602 L
.5373 .40601 L
.53862 .40598 L
.54005 .40595 L
.54266 .40587 L
.545 .40577 L
.54752 .40565 L
.55208 .40537 L
.56247 .4045 L
.57344 .40325 L
.58349 .40186 L
.62317 .39461 L
.66133 .38598 L
.70194 .37584 L
.74104 .36554 L
.78259 .35444 L
.82262 .3441 L
.86114 .33485 L
.90211 .32564 L
.94157 .31673 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo02Wooooo0_oo003ooooooa[ooooo000Q
ooooo`03o`000?oooooooooo02Kooooo0ooo0007o`000?oooooo5Oooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Oooooo0ol0003ooooooa;ooooo000Qooooo`?o
00008_ooool2ool000;o00003Oooool00ol0003oo`00ool0003oooooo`oooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?oo`00ooooooooool04_ooool2ool00?oooooo3Oooool0027ooooo00?o
0000ooooooooool07oooool2ool001Kooooo00?o0000ool00?ooool0ooooool;ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?l0003ooooo01Oooooo00?o0000ool00?oo0000ooooool:
ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?l0003ooooo01Wooooo0_l000000ooo
003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?oo`00oooooooo
ool06oooool00ol0003oo`00ooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ooo003oooooooooo`3oooooo`Kooooo000Qooooo`?o00006ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oo003ooooo0?oooooo1_ooool0027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo003ooooo0?oooooo1Oooool0
027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo003ooooo
0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oo003ooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o0000
ooooooooool05_ooool00ooo003o0000ooooo`0Yooooo`03o`000?oooooooooo0?oooooo000Qoooo
o`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0:Oooool00ol0003oooooooooo`3ooooo
o`008Oooool3o`0001Gooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`3nooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03ool00?l0003ooooo02gooooo00?o0000ooooooooool0
oOooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0^ooooo`03o`000?oo
oooooooo0?cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0<?ooool0
0ol0003oooooool0003kooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo
03;ooooo00?o0000oooooooo0000n_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0cooooo`03o`000?oo003ooooo0?Wooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0A
ooooo`03ool00?l0003ooooo03Cooooo00?o0000oooooooo0000nOooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00013ooooo00?oo`00
o`000?ooool0=_ooool00ol0003oooooool0003hooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo03Oooooo00?o0000oooooooo0000moooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0?ooooo`03ool00?l0
003ooooo03Sooooo00?o0000oooooooo0000moooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ooo003o0000oooo
o`0jooooo`03o`000?ooooooo`000?Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?oo`00o`000?ooool0??oo
ool00ol0003oooooool0003eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0??ooool00ol0003oo`00oooo
o`3dooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03gooooo00?o0000
oooooooo0000m?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0ooooo
o`03o`000?ooooooo`000??ooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`10ooooo`03
o`000?ooooooo`000?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027ooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo0>kooooo
000Qooooo`?o00002?ooool00ooo003oooooooooo`19ooooo`03o`000?oooooooooo0>gooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`3]
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo04_ooooo00?o0000oooo
oooo0000k?ooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1=ooooo`03
o`000?oo003ooooo0>_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
C_ooool00ol0003oo`00ooooo`3Zooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
003ooooo04oooooo00?o0000oooooooo0000j_ooool0027ooooo00?o0000ooooooooool01Oooool0
0ooo003oooooooooo`1@ooooo`03o`000?oo003ooooo0>Wooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ool00?ooool0D_ooool00ol0003oo`00ooooo`3Xooooo`008Oooool3o`0000Co
oooo00?oo`00ooooooooool0D_ooool00ol0003oooooool0003Xooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Oooooo00?o0000oooooooo0000<oooool4o`00
0003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`07ooooo`03o`000?oo003ooooo03Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0g
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
003ooooo03?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool0
0ol0003oo`00ooooo`0hooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`08ooooo`03o`000?ooooooo`0003?ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000
ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00[ooooo00?o0000ool00?ooool0<_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03
ogMgMomVIVKooooo01[ooooo000Qooooo`05o`000?ooooooooooooooool00000>oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool03Oooool00ol0003oo`00ooooo`0aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01Wooooo000Qooooo`?o000000?oooooo`000?ooool0>_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool00ol0003oooooool0000aoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0ooooo
o`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00Co0000oooooooooooo0000??ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03o`000?oooooooooo02kooooo00?o
EEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0005oooooo00?o0000ooooooooool0
hOooool0027ooooo00?o0000ooooool00000HOooool00ol0003oooooooooo`3Pooooo`008Oooool0
0ol0003oooooo`00001Qooooo`03o`000?oooooooooo0>3ooooo000Qooooo`;o0000Hoooool00ol0
003oooooooooo`3Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000I?ooool00ol0003o
ooooooooo`3Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0000ao`00
00;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000oooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02?ooool01Ol0003oo`00ool00?oooooo000001?ooooo00Cok^k^
ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooool0000<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`?o00001?ooool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Q
ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo0000[oooool3ool000;ooooo0ol0000J
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
oooo0000Zoooool3ool00003ooooool0003o000000;o00009oooool0027ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooool0002Wooooo`?oo`0000Coooooo`000?l0003o0000:oooool0027o
oooo00?o0000ooooooooool0JOooool00ol0003oooooool0002Qooooo`Goo`0000Coooooo`000?l0
003o0000;_ooool0027ooooo00?o0000ooooooooool0JOooool01?l0003ooooooooooooo002Moooo
o`?oo`000oooool3o`00037ooooo000Qooooo`?o0000J_ooool01?l0003ooooooooooooo002Noooo
o`Co0000=?ooool0027ooooo00?o0000ooooooooool0Joooool01?l0003ooooooooooooo002?oooo
o`?oo`001oooool4o`0003Sooooo000Qooooo`03o`000?oooooooooo06cooooo00Co0000oooooooo
ooooo`00ROooool5ool000Kooooo1?l0000looooo`008Oooool00ol0003oooooooooo`1]ooooo`04
o`000?ooooooooooool008Cooooo1?oo0008ooooo`?o0000@?ooool0027ooooo00?o0000oooooooo
ool0KOooool01Ol0003oooooooooooooooooo`00083ooooo0ooo0009ooooo`?o0000@oooool0027o
oooo00?o0000ooooooooool0K_ooool01Ol0003oooooooooooooooooo`0007gooooo0_oo0009oooo
o`?o0000A_ooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`26ooooo`?o
0000BOooool0027ooooo0ol0001`ooooo`03o`000?oooooooooo087ooooo1?l0001<ooooo`008Ooo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo073ooooo0ooo000:ooooo`?o0000D?oo
ool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1Zooooo`Goo`002_ooool3
o`0005?ooooo000Qooooo`03o`000?oooooooooo07?ooooo0_l0001Wooooo`?oo`003?ooool3o`00
05Kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0HOooool3ool000_o
oooo1?l0001Iooooo`008Oooool00ol0003oooooooooo`1fooooo`04o`000?ooooooooooooooo`;o
o`00Foooool2ool000_ooooo0ol0001Mooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo00;ooooo00?oo`00ooooooooool0H_ooool3o`00063ooooo000Qooooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool00_ooool2ool004_ooooo0ooo000Aooooo`?o0000Hooo
ool0027ooooo0ol0001iooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0A?ooool4
ool0017ooooo0ol0001Vooooo`008Oooool00ol0003oooooooooo`1jooooo`;o00001?ooool2ool0
043ooooo1?oo000Booooo`?o0000JOooool0027ooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`03ooooo`;oo`00>oooool3ool001?ooooo0ol0001/ooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`;o00001Oooool2ool003Oooooo0_oo000Cooooo`?o0000Koooool0027ooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`04ooooo`?oo`00A_ooool3o`0007;ooooo000Q
ooooo`03o`000?oooooooooo083ooooo0_l0000]ooooo`Coo`006Oooool3o`0007Gooooo000Qoooo
o`03o`000?oooooooooo08;ooooo0_l0000Wooooo`Coo`006_ooool3o`0007Sooooo000Qooooo`?o
0000Q?ooool2o`0000cooooo1_oo000;ooooo`Soo`006oooool3o`0007_ooooo000Qooooo`03o`00
0?oooooooooo08Kooooo0_l0000@ooooo`;oo`00:?ooool4o`0007kooooo000Qooooo`03o`000?oo
oooooooo08Sooooo0_l0000cooooo`Go0000P_ooool0027ooooo00?o0000ooooooooool0R_ooool2
o`0002gooooo1?l00027ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o00009_ooool4o`00
08_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08oooooo0ol0000Mooooo`Ko0000Soooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo09;ooooo1ol0000Aooooo`Go0000UOooool000Oooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002Ioooooa7o0000V_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool0
0omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooM
gMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIV
I_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj
^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEE
EOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c01kooooo`00
O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooo
oooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3
ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44
ooooo`05oa0@4?nj^[[oooooogMgMolb<S80Noooool007kooooo00Oo0000oooooooMgMgo<S8boooo
ooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg
1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo
00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0NOooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooo
oooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00gooooo00?oZJVYoa0@4?ooool0N_ooool0
07kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooo
ooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIV
I_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000
ooooooooool03?ooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMgooooo`02oooo
o`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo
00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omg
MgOoEEEEooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool0N_ooool009Ko
oooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09omgMgOl@413ok^k^oooo
ool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd05_ooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?nHV9SooooookZj^_l00000Noooool009Kooooo00?o0000ooooooooool01ooo
ool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Boooo
o`03ofIVI_mgMgOooooo01Cooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413o
ZJVY07_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27247 L
.06244 .237 L
.08255 .20801 L
.09396 .19543 L
.10458 .18633 L
.10961 .1829 L
.11508 .17979 L
.11989 .17759 L
.125 .17577 L
.12959 .17458 L
.13221 .17408 L
.13346 .17389 L
.13466 .17373 L
.13573 .17362 L
.1369 .17351 L
.13796 .17344 L
.13895 .17339 L
.14012 .17335 L
.14119 .17334 L
.14242 .17335 L
.14357 .17338 L
.14473 .17344 L
.14598 .17352 L
.14823 .17374 L
.1509 .1741 L
.15334 .17452 L
.15863 .17575 L
.16365 .17727 L
.1725 .18071 L
.18212 .18544 L
.22291 .21286 L
.26217 .24277 L
.29992 .26786 L
.31927 .27805 L
.34013 .28664 L
.35051 .28996 L
.36017 .29248 L
.37024 .29453 L
.37553 .29538 L
.38127 .29613 L
.38674 .29668 L
.38914 .29687 L
.39179 .29705 L
.39411 .29717 L
.39661 .29728 L
.39799 .29732 L
.39925 .29735 L
.40052 .29738 L
.40172 .29739 L
Mistroke
.4029 .2974 L
.40396 .29741 L
.40518 .2974 L
.40634 .29739 L
.40741 .29738 L
.40839 .29736 L
.41062 .29731 L
.41287 .29723 L
.41533 .29711 L
.42031 .29681 L
.42557 .29637 L
.43054 .29586 L
.43986 .29466 L
.46079 .29093 L
.49917 .28146 L
.54 .26972 L
.57932 .25898 L
.61712 .25081 L
.63651 .24782 L
.6474 .24654 L
.65738 .24565 L
.66214 .24532 L
.66721 .24503 L
.672 .24482 L
.67411 .24475 L
.67634 .24469 L
.67761 .24466 L
.67901 .24463 L
.68029 .24461 L
.68146 .24459 L
.68212 .24459 L
.68284 .24458 L
.68361 .24457 L
.68433 .24457 L
.685 .24457 L
.68572 .24457 L
.687 .24457 L
.68819 .24458 L
.68947 .24459 L
.69067 .2446 L
.69178 .24462 L
.69435 .24467 L
.69706 .24474 L
.70205 .24492 L
.70659 .24514 L
.71677 .24583 L
.72621 .2467 L
.73513 .24771 L
.75512 .2506 L
.77357 .25393 L
Mistroke
.81294 .2627 L
.85079 .27247 L
.8911 .28362 L
.92989 .29495 L
.97114 .30751 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`0001oooooo2Ol0003ooooooago
oooo000Qooooo`03o`000?oooooooooo01cooooo0ol00009ooooo`Co0000oooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0ooo0004ooooo`?o0000oooo
oolFooooo`008Oooool00ol0003oooooooooo`0Iooooo`;o00003Oooool4ool000?ooooo0_l0003o
oooooaCooooo000Qooooo`03o`000?oooooooooo01Sooooo00Co0000ool00?oo003oo`004?ooool2
ool000?ooooo00?o0000ooooooooool0oooooolAooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oo003ooooo01Cooooo00Goo`00ooooooooooooooooo`00003ooooooa;ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0Fooooo`;oo`005oooool2ool000;ooooo00?o0000ooooooooool0
ooooool?ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o00005Oooool00ooo003oooooooooo`0Iooooo`04ool00?ooooooooooo`000?oo
oooo4?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00;o
0000ooooool>ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool07Oooool01Ooo
003ooooooooooooooooo00000?oooooo3Oooool000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oo`00ooooo`0S
ooooo`;o0000ooooool;ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo02Kooooo00?o0000
ooooooooool0ooooool8ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?ooool0:?ooool00ol0003oooooooooo`3o
ooooo`Oooooo000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00oooooooo
ool0:oooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`?o00003_ooool00ol0003ooooo
ooooo`0[ooooo`;oo`0000?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02gooooo00?oo`00o`000?ooool0ooooool4ooooo`008Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?oo`00o`000?ooool0ooooool3
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo0_oo003ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool00ooo003o
ooooooooo`3oooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Gooooo
00?oo`00ooooooooool0o_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0gooooo`;oo`00o_ooool0027ooooo0ol00009ooooo`03o`000?oooooooooo03Wooooo00?o0000
ool00?ooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0joooo
o`03o`000?oo003ooooo0?_ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0??ooool00ol0003oo`00ool0001jooooo`_oo`00MOooool0027ooooo00?o0000ooooooooool0
2?ooool00ooo003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo1_oo000Dooooo`Soo`00
I?ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`10ooooo`03o`000?oo
oooooooo09?ooooo1_oo001Nooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
oooo047ooooo00?o0000ooooooooool0Hoooool3ool003;ooooo1?oo001Jooooo`008Oooool00ol0
003oooooooooo`06ooooo`03ool00?oooooooooo04?ooooo00?o0000ooooooooool0G_ooool4ool0
03Wooooo1Ooo001Eooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04Go
oooo00?o0000ooooooooool0FOooool4ool004;ooooo1?oo001Aooooo`008Oooool3o`0000Gooooo
00?oo`00ooooooooool0A_ooool2o`0000;ooooo00?oo`00ooooooooool0DOooool3ool004[ooooo
0_oo001?ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01_m4A4Co0000o`000?lb<S;ogMgMool0
03cooooo1?l000000ol@413oooooooooo`0=ooooo`;oo`008ooooolLo`000003oc8b<_oMgMgooooo
03cooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool2o`000003oooooooo003oo`00
03cooooo00?o0000ooooooooool0;?ooool8o`0000_ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo2ol0000fooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool2
o`0000;ooooo0_oo000jooooo`03o`000?oooooooooo027ooooo2ol0000Cooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool6o`0000[ooooo1Ooo000Rooooo`03oiRHV?lQ8B7o
k^k^01cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00_l00002ooooo`;oo`00>?ooool0
0ol0003oooooooooo`03ooooo`?oo`006?ooool3o`0001kooooo00?o0000ooooooooool03_ooool0
0omgMgOo<S8booooo`0<ooooo`Ko00002Oooool4ool001oooooo00?oV9RHob4Q8Oo^k^h06oooool0
027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00Co0000oooooooooooooooo
0ooo000eooooo`03o`000?ooooooo`0000?oo`005_ooool5o`00027ooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo1_l00007ooooo`Coo`007?ooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`?o
o`00<?ooool4ool001Gooooo1Ol0000Vooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06oooool6o`0000Gooooo0_oo000Kooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000
00?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02Wooooo1?oo0002ooooo`03
o`000?oooooooooo013ooooo1?l0000[ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool08Oooool6o`000003oooooooo003ooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@400Koooo
o`008Oooool01Ol0003ooooooooooooooooo000003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00002?ooool2o`0002kooooo0_oo0004ooooo`03oeEEEOmVIVKo000000kooooo1?l0000]
ooooo`03oeEEEOmVIVKo000000gooooo1?l0000Vooooo`Go00004oooool01OnHV9So410@o`000?lQ
8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0005_ooooo0_l0000oooooo`Co0000L?oo
ool5o`0002kooooo000Qooooo`03o`000?oooooo000005kooooo0_l0000;ooooo`Coo`002oooool7
ool001Oooooo1Ol0001iooooo`;o00000ooo000Yooooo`008Oooool00ol0003oooooo`00001Poooo
o`?o00003?ooool;ool001[ooooo1?l00022ooooo`04o`000?oo003oo`00ool002Kooooo000Qoooo
o`;o0000I?ooool3o`0002Wooooo1Ol0002:ooooo`?oo`0000?o0000ooooooooool05_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool2o`0006Oooooo0ol0000Pooooo`Ko0000T_ooool3ool000;o
00005?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000;ol00004ool0
00Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo5Ol0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85
ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003ooooo
odGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOo
IVIV00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o
0000omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`00
00Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P07
ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@
4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o
<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003ooooo
ooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0
003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOl@413ooooo
00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003o
ooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0
003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool0
0oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o410@o`000?nj^[X01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool0
0omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0G
ooooo`03o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`1g
ooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@
4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool0
0ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003ooooooooo
o`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMg
ofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03
oeEEEOmVIVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000M_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30282 L
.06244 .29659 L
.06747 .29535 L
.07286 .29422 L
.07751 .29342 L
.08255 .29274 L
.08564 .29242 L
.08848 .2922 L
.0912 .29203 L
.09258 .29197 L
.09335 .29195 L
.09409 .29192 L
.09474 .29191 L
.09545 .29189 L
.0967 .29187 L
.0974 .29187 L
.09815 .29187 L
.09886 .29187 L
.0995 .29188 L
.10076 .29189 L
.10147 .29191 L
.10212 .29192 L
.10338 .29196 L
.10458 .29201 L
.10704 .29214 L
.10928 .29228 L
.11432 .29271 L
.1234 .2938 L
.14407 .29727 L
.16229 .30065 L
.17266 .30236 L
.17774 .30308 L
.1824 .30366 L
.18694 .30414 L
.19191 .30456 L
.1945 .30473 L
.19691 .30485 L
.19945 .30495 L
.20088 .30499 L
.20217 .30501 L
.20348 .30503 L
.20414 .30503 L
.20487 .30503 L
.20615 .30503 L
.20736 .30501 L
.20808 .305 L
.20877 .30499 L
.21007 .30495 L
.21146 .3049 L
Mistroke
.21298 .30483 L
.21554 .30468 L
.21827 .30447 L
.22318 .30398 L
.22855 .30325 L
.23349 .3024 L
.24463 .29987 L
.25445 .29693 L
.26481 .29312 L
.30284 .27354 L
.34331 .24574 L
.38227 .21646 L
.42369 .1871 L
.46359 .16373 L
.50197 .14739 L
.52178 .14146 L
.5319 .13907 L
.5428 .13696 L
.55299 .13542 L
.56231 .13436 L
.57123 .13364 L
.57571 .13338 L
.57826 .13327 L
.5806 .13319 L
.58315 .13312 L
.58449 .13309 L
.58591 .13306 L
.58714 .13305 L
.58829 .13304 L
.58955 .13303 L
.59026 .13303 L
.59091 .13303 L
.5921 .13304 L
.5932 .13305 L
.59442 .13306 L
.5957 .13308 L
.59787 .13313 L
.60025 .13319 L
.60545 .1334 L
.61106 .13371 L
.62122 .13452 L
.63077 .13554 L
.64123 .13695 L
.66233 .14065 L
.68191 .14509 L
.70285 .15086 L
.74432 .16543 L
.78427 .18339 L
.8227 .20419 L
.86359 .22958 L
Mistroke
.90296 .25632 L
.94082 .28324 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`2[ooooo`;oo`00Uoooool0027ooooo00?o0000ooooooooool0XOooool:ool000co
oooo1ooo0026ooooo`008Oooool00ol0003oooooooooo`2Looooo`Goo`007Oooool5ool0087ooooo
000Qooooo`?o0000`oooool4ool007gooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0TOooool2ool00;7ooooo000Qooooo`03o`000?oooooooooo08oo
oooo0_oo000Doooooaco00004?ooool2ool0077ooooo000Qooooo`03o`000?oooooooooo08cooooo
0ooo000@ooooo`Ko00007?ooool7o`0000_ooooo0ooo001^ooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`;oo`004?ooool3o`0002Wooooo0ol0000;ooooo`?oo`00Joooool0027ooooo00?o0000
ooooooooool0R?ooool2ool000kooooo1?l0000_ooooo`?o00002oooool2ool006Wooooo000Qoooo
o`03o`000?oooooooooo08Kooooo0_oo000=ooooo`?o0000=_ooool3o`0000[ooooo0ooo001Voooo
o`008Oooool3o`0008Gooooo00?oo`00ooooooooool02_ooool3o`0003cooooo1?l00009ooooo`;o
o`00I?ooool0027ooooo00?o0000ooooooooool0Q?ooool00ooo003oooooooooo`08ooooo`?o0000
@oooool3o`0006cooooo000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o0000JOoo
ool0027ooooo00?o0000ooooooooool0Roooool2o`0004kooooo0ol0001Vooooo`008Oooool00ol0
003oooooooooo`28ooooo`?o0000Doooool2o`0000Wooooo0_oo001Iooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`26ooooo`;o0000F?ooool3o`0000Sooooo0_oo001Gooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0NOooool2ool000Wooooo0_l0001Mooooo`;o00002?ooool2ool005Gooooo0005o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001h
ooooo`03ool00?oooooooooo00Oooooo0_l0001Qooooo`;o00002?ooool00ooo003oooooooooo`1B
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`1fooooo`;oo`002?ooool2o`0006Gooooo0ol00006ooooo`;oo`00D_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00Kooooo0_l0001Zooooo`;o00001_oo
ool2ool0053ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07?ooooo0_oo0007ooooo`;o0000K_ooool2o`0000Kooooo00?o
o`00ooooooooool0COooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0L_ooool00ooo003oooooooooo`05ooooo`;o0000L_oo
ool2o`0000Gooooo0_oo001=ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo077ooooo00?oo`00ooooooooool01Oooool00ol0003ooooooooo
o`1dooooo`?o00001?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`1_
ooooo`;oo`001_ooool2o`0007[ooooo0_l0001?ooooo`008Oooool00ol0003oooooooooo`1^oooo
o`03ool00?oooooooooo00Cooooo0_l0001nooooo`;o0000COooool0027ooooo0ol0001]ooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool0P?ooool2o`0004_ooooo000Qooooo`03o`00
0?oooooooooo07;ooooo0_l00025ooooo`;o0000BOooool0027ooooo00?o0000ooooooooool0L?oo
ool2o`0008Wooooo00?o0000ooooooooool0A_ooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oooooooooo`2:ooooo`;o00000_ooool2ool004;ooooo000Qooooo`03o`000?oooooooooo
06gooooo0_l0002?ooooo`;o00000_ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo06_o
oooo0_l0002Cooooo`05o`000?oooooooooooooooooo0000?oooool0027ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`2Dooooo`;o0000@Oooool0027ooooo0ol0001Tooooo`;oo`00
0_ooool2o`0009Wooooo0_l0000oooooo`008Oooool00ol0003oooooooooo`1Sooooo`03ool00?oo
oooooooo00;o0000WOooool00ol0003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`1R
ooooo`04ool00?ooooooooooo`000:3ooooo0_l00002ooooo`;oo`00>?ooool0027ooooo00?o0000
ooooooooool0H?ooool2ool00003ooooool0003o00000:?ooooo00Go0000ooooooooooooooooool0
000gooooo`008Oooool00ol0003oooooooooo`1Oooooo`04ool00?oooooo0000o`000:Kooooo0_l0
0002ooooo`;oo`00=Oooool0027ooooo00?o0000ooooooooool0GOooool2ool000;o0000Z_ooool0
1Ol0003oooooooooooooooooo`0003Cooooo000Qooooo`03o`000?oooooooooo05cooooo00?oo`00
o`000?l00000[Oooool2o`0000;ooooo0_oo000booooo`008Oooool00ol0003oooooooooo`1Joooo
o`;oo`0000?o0000ooooooooool0[oooool01Ol0003oooooooooooooooooo`00037ooooo000Qoooo
o`?o0000FOooool00ooo003o0000ooooo`2cooooo`;o00000_ooool2ool002oooooo000Qooooo`03
o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?oo`00o`000?ooool0=Oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM02[ooooo0_l00002ooooo`03ool00?oooooooooo00cooooo1Ol0000Kooooo`008Oooool0
0ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00_ooool2o`0003[ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0[ooooo`04o`000?ooooooooooool000gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@
4?ooooooooooooooool@41004?ooool01?l0003oooooo`000?l0000looooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`;o000000?oooooool0
0?ooool03?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo0000o`00000nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0^ooooo`;o00003_ooool00onH
V9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?l0003oc<c<03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ol0003ooooooooo
o`0<ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo01Gooooo0_l0000V
ooooo`05oa0@4?ooooooooooooooool@41002oooool2ool00003o`000?oooooooooo043ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_l0
000=ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00003_ooool8o`000003ooooool0003o
000000So00007?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_oo0002o`0004?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo0_l0
0007ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02_oo
ool4o`0001?ooooo1Ol0000Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool01?oo003o0000
ooooooooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co
0000=oooool2o`0000Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003o
ooooooooo`08ooooo`;o00001oooool<ool000Wooooo0ol0000Oooooo`;oo`00eOooool00ol0003o
o`00ool0000Rooooo`008Oooool00ol0003oooooooooo`05ooooo`?o00005Oooool4ool000Sooooo
0ol0000Fooooo`Co00000_oo003Hooooo`;o000000?oo`00ooooooooool07oooool0027ooooo00?o
0000ooooooooool00_ooool3o`0002Oooooo1ol0000:ooooo`Go00000_ooool2ool00=cooooo00?o
0000ool00?oo00007oooool0027ooooo00?o0000ooooooooool00_l00005ool002Cooooo0_oo0006
ooooo`[o00000oooool4ool00>3ooooo00?o0000ool00?ooool04oooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`0000?oo`00:oooool<ool00>cooooo00?o0000ool00?ooool04_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo00000_oo003oo`0002Wo000000?oo`00
o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo
oooo0?oooooo>oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2S
ooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hoooo
o`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mE
EEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo
00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`1iooooo`00O_ooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^
k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo
00_ooooo1_l00004ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo
07[ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0:ooooo`Go0000Noooool007kooooo00CoEEEEojVYZOoooooo00000_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@
onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIV
ooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00[o
oooo00CoA4A4omgMgOoooooo0000O?ooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003o
ooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03
o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004oooo
o`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool0001l
ooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`00
0?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0
003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eooooo`03o`000?oooooooooo
00_ooooo00?oMgMgolc<c?l00000O?ooool009Kooooo00?o0000ooooooooool01oooool00omEEEGo
V9RHooooo`04ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?o
k^k^oa0@4?oMgMd05_ooool00ol0003oooooooooo`0;ooooo`03onk^k_m4A4Co000007cooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonH
V9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000ko
oooo00?oMgMgo`000?ooool0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34081 L
.06244 .37178 L
.08255 .3972 L
.09396 .40818 L
.09905 .41222 L
.10458 .41598 L
.11004 .41906 L
.11508 .42133 L
.11989 .42301 L
.12232 .42367 L
.125 .42425 L
.12741 .42465 L
.12962 .42492 L
.13084 .42502 L
.13153 .42506 L
.13217 .42509 L
.13334 .42513 L
.13459 .42514 L
.13575 .42513 L
.13701 .42508 L
.1382 .425 L
.1393 .42491 L
.14138 .42466 L
.14357 .42432 L
.14612 .4238 L
.14853 .4232 L
.15305 .42179 L
.16321 .4173 L
.17199 .41206 L
.18154 .40502 L
.22233 .36247 L
.26159 .30927 L
.29934 .25431 L
.33955 .19786 L
.37823 .14972 L
.41937 .10801 L
.4399 .09132 L
.459 .07836 L
.4786 .06762 L
.49711 .05984 L
.50692 .05663 L
.51756 .05383 L
.52724 .0519 L
.53615 .05062 L
.54083 .05013 L
.5434 .04992 L
.54585 .04975 L
.54811 .04963 L
.54931 .04958 L
Mistroke
.55058 .04953 L
.55176 .04949 L
.55283 .04947 L
.55391 .04945 L
.55492 .04944 L
.55612 .04943 L
.55743 .04943 L
.55809 .04943 L
.5588 .04944 L
.56009 .04946 L
.56136 .04949 L
.56257 .04952 L
.56484 .04961 L
.56751 .04974 L
.56997 .0499 L
.57555 .05038 L
.5802 .0509 L
.58521 .05157 L
.59426 .05311 L
.61487 .05801 L
.63495 .0645 L
.65607 .07296 L
.69423 .09184 L
.73484 .11603 L
.77394 .14238 L
.81549 .173 L
.85552 .20465 L
.89404 .23679 L
.93501 .27241 L
.97447 .30748 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000X?ooool2
ool000Gooooo0ooo002Jooooo`008Oooool00ol0003oooooooooo`2Jooooo`Koo`002_ooool9ool0
097ooooo000Qooooo`03o`000?oooooooooo09Kooooo1?oo000Iooooo`?oo`00S_ooool0027ooooo
00?o0000ooooooooool0Toooool3ool0023ooooo0_oo002<ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00007Oooool3o`0008gooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000R?ooool2ool000Oooooo0ol0000Sooooo`Co00001_ooool2ool0087o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_ooool2ool000Kooooo
0ol0000Zooooo`Co00001?ooool2ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Q?ooool2ool000Gooooo0ol0000aooooo`;o00001?ooool2ool007gooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Poooool00ooo003oooooooooo`03
ooooo`;o0000=_ooool2o`0000Cooooo0_oo001kooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo087ooooo0_oo0004ooooo`;o0000>_ooool2o`0000Cooooo0_oo001ioooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo083ooooo00?oo`00oooooooo
ool00_ooool2o`0003kooooo0ol00003ooooo`;oo`00Moooool0027ooooo00?o0000ooooooooool0
Ooooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo047ooooo0ol00002ooooo`;oo`00
MOooool0027ooooo00?o0000ooooooooool0O_ooool01?oo003oooooooooooooool2o`0004Oooooo
0_l00002ooooo`03ool00?oooooooooo07;ooooo000Qooooo`?o0000OOooool01Ooo003ooooooooo
oooooooo000004_ooooo0ol0001dooooo`008Oooool00ol0003oooooooooo`1looooo`05ool00?oo
ooooooooooooool00000Coooool2o`0007;ooooo000Qooooo`03o`000?oooooooooo07kooooo0_l0
001Booooo`;o0000L?ooool0027ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo06gooooo000Qooooo`03o`000?oooooooooo07_ooooo0_l0001Hoooo
o`;o000000?oooooool00?oo0000J_ooool0027ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`1Jooooo`;o000000?oooooool00?ooool0J?ooool0027ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooo`00ool006Oooooo000Qooooo`?o0000
N?ooool00ol0003oooooooooo`1Oooooo`;o000000?oooooool00?ooool0IOooool0027ooooo00?o
0000ooooooooool0M?ooool01?oo003oooooooooool0001Tooooo`;o00000_oo001Tooooo`008Ooo
ool00ol0003oooooooooo`1dooooo`03ool00?oooooo000006Oooooo00?o0000oooooooo0000Hooo
ool0027ooooo00?o0000ooooooooool0Loooool00ooo003oooooo`00001Yooooo`03o`000?oooooo
o`0006;ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooool00000Joooool2o`00
00;oo`00H?ooool0027ooooo00?o0000ooooooooool0LOooool00ooo003oooooo`00001^ooooo`03
o`000?ooooooo`0005oooooo000Qooooo`03o`000?oooooooooo073ooooo00?oo`00ooooool00000
L?ooool00ol0003oooooool0001Nooooo`008Oooool3o`0006oooooo00?oo`00ooooool00000L_oo
ool2o`0005kooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooool00000MOooool0
0ol0003oooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`1]ooooo`03ool00?oooooo0000
07Oooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003o
ooooo`00001iooooo`;o0000F_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003o0000
ooooo`1kooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o
o`00ooooool00000OOooool2o`000003oooooooo003oo`0005Cooooo000Qooooo`03o`000?oooooo
oooo06[ooooo00?oo`00ooooool00000P?ooool01?l0003ooooooooooooo001Cooooo`008Oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo083ooooo0_l000000oooooooo`00ool0001A
ooooo`008Oooool3o`0006[ooooo00?o0000ooooooooool0Poooool01?l0003ooooooooooooo001@
ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo08Gooooo0_l000000ooo
ooooo`00ooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo08So
oooo00Co0000oooooooo003oo`00COooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`2:ooooo`;o000000?oooooool00?ooool0Boooool0027ooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`2=ooooo`03o`000?ooooooo`0004_ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooool0001:ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0Hoooool00ooo003oooooo`00002Booooo`;o000000?oo`00oooooooo
ool0Aoooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool3o`0006?ooooo00?oo`00o`000?ooool0U?ooool00ol0003oo`00ooooo`17ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`1Rooooo`03ool00?l0003ooooo09Kooooo00?o0000ooooooooool0A_ooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`1Qooooo`03ool00?l0003ooooo09Sooooo00?o0000ooooooooool0AOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0H?ooool00ooo003o0000ooooo`2Jooooo`;o0000AOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ooo
003oooooooooo`2Looooo`03o`000?oooooooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Noooo
o`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?oo
ool0X?ooool2o`00047ooooo000Qooooo`03o`000?oooooooooo05gooooo00?oo`00o`000?ooool0
Xoooool2ool003oooooo000Qooooo`?o0000G?ooool00ooo003o0000ooooo`2Uooooo`03o`000?oo
003ooooo03gooooo000Qooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool0Y_ooool0
0ol0003oo`00ooooo`0looooo`008Oooool00ol0003oooooooooo`1Kooooo`03ool00?l0003ooooo
0:Sooooo00?o0000ool00?ooool0>oooool0027ooooo00?o0000ooooooooool0F_ooool00ooo003o
0000ooooo`2Zooooo`03o`000?oo003oo`0003[ooooo000Qooooo`03o`000?oooooooooo05Wooooo
00?oo`00o`000?ooool0[Oooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo03Kooooo000Qoooo
o`?o0000F?ooool00ol0003oooooooooo`2aooooo`03o`000?oo003ooooo03Gooooo000Qooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0/oooool00ol0003oo`00ooooo`0dooooo`00
8Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;Gooooo00?o0000ool00?ooool0
<oooool0027ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2hooooo`03o`000?oo
oooooooo037ooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
0;_ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0Doooool00ooo003o
ooooooooo`2mooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo05;ooooo
00?o0000ool00?ooool0_oooool2o`0002kooooo000Qooooo`?o0000D_ooool00ooo003ooooooooo
o`31ooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?oo003ogMgM03gooooo
1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0`ooooo`;oo`002oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
o`00oc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oo`00ooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oo`00ool00009ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l000000ooo003oooooooooo`07ooooo`03oiRHV?lQ8B7o
k^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<
ooooo`05ool00?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oo003ooooo00Sooooo
00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oo`00ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0003oo`00ooooo`08ooooo`03o`00
0?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?oo`00o`000?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0>Oooool00ol0003oo`00ooooo`03ooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[o
oooo00?oo`00ooooool000000ol0000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l0
00003Oooool4o`0003[ooooo00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06ooo
ool0027ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`3Booooo`03ool00?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0e?ooool00ooo
003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`1:ooooo`03ool00?oooooooooo0=Ko
oooo00?oo`00o`000?ooool07_ooool0027ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`3Hooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`3Jooooo`03o`000?oooooooooo017ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool2o`0000kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo
00?o0000ooooool00000A_ooool00ol0003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000
oooooooooooo0000@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003ooooooooooooo
003o000004;ooooo00?oo`00ooooooooool0oOooool0027ooooo00Go0000ooooooooooooo`00o`00
0011ooooo`03o`000?oo003ooooo0?kooooo000Qooooo`?o000000?oooooool00?l00000?oooool0
0ol0003oo`00ooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?l0003ooooo
03cooooo00?o0000ool00?ooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo03[ooooo00?o0000ool00?ooool0ooooool2ooooo`008Oooool00ol0003ooooo
ooooo`03ooooo`03ool00?l0003ooooo03Wooooo00?o0000ool00?ooool0ooooool3ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03ool00?l0003ooooo03Sooooo00?oo`00ooooooooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo03Kooooo00?o0000
ool00?ooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?l0003ooooo
03Gooooo00?o0000ool00?ooool0ooooool5ooooo`008Oooool3o`0000Kooooo00?oo`00o`000?oo
ool0<oooool00ol0003oo`00ooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?oo`00ooooooooool0<Oooool00ol0003oo`00ooooo`3oooooo`Oooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?oo`00o`000?ooool0<Oooool00ooo003oooooooooo`3oooooo`Oooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0;oooool00ol0003oo`00ooooo`3o
ooooo`Sooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`_ooooo000Qooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`cooooo000Q
ooooo`?o00003Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
0?oooooo3_ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo0?oooooo3oooool0027ooooo00?o0000ooooooooool04?ooool2o`00023ooooo
00?o0000ool00?ooool0ooooool@ooooo`008Oooool00ol0003oooooooooo`0?ooooo`04ool00?oo
ooooooooo`0001kooooo00?o0000ool00?ooool0oooooolAooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`04ool00?ooooooooooo`0001cooooo00?o0000ool00?ooool0oooooolBooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`04ool00?ooooooooooo`0001Wooooo0_l000000ooo003ooooo
ooooo`3ooooooa;ooooo000Qooooo`?o00004_ooool01?oo003oooooooooool0000Gooooo`03o`00
0?ooooooo`000?oooooo5Oooool0027ooooo00?o0000ooooooooool04oooool01?oo003ooooooooo
ool0000Dooooo`;o000000?oooooool00?ooool0oooooolEooooo`008Oooool00ol0003ooooooooo
o`0Dooooo`03ool00?oooooooooo00?o00004?ooool01?l0003ooooooooooooo003ooooooaOooooo
000Qooooo`03o`000?oooooooooo01Gooooo0_oo0003ooooo`03o`000?oooooooooo00_ooooo0_l0
00000oooooooo`00ool0003ooooooaSooooo000Qooooo`03o`000?oooooooooo01Oooooo00Coo`00
oooooooooooooooo0ol00006ooooo`Co00000ooo003ooooooa[ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oooooooooo01Sooooo0ooo0003ooooo`Ko00000oooool00ooo003oooooooooo`3ooooooa_ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0Kooooo`;oo`00oooooolXooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMg
ooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^
kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8b
onk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03
oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgM
g@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003ooooo
ooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03
o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Sooooo
ooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001k
ooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Q
onk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0:ooooo`Go00002?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVY
ooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^
k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooo
oooo00[ooooo00CoA4A4omgMgOoooooo00002?ooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool0
2_ooool01?oMgMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007co
oooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o
00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooooooo
ool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02oooool00omgMgOo
c<c<o`000005ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo
00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@
41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00_ooooo00?ok^k^odA4A?l0
00001Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj
^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool0
0omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000kooooo00?oMgMgo`000?ooool01?ooool4
o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .4616 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47232 L
.1174 .47319 L
.11989 .47393 L
.12127 .47425 L
.12253 .4745 L
.12372 .47469 L
.125 .47485 L
.12624 .47495 L
.12736 .47501 L
.12849 .47503 L
.12955 .47501 L
.13079 .47495 L
.13194 .47485 L
.13319 .4747 L
.13452 .4745 L
.13675 .47404 L
.13884 .4735 L
.14357 .47182 L
.14858 .46942 L
.15402 .4661 L
.16392 .45834 L
.18248 .43849 L
.22326 .37753 L
.26253 .30785 L
.30028 .24068 L
.34048 .17577 L
.37917 .12341 L
.39882 .10119 L
.42031 .08041 L
.44107 .06382 L
.45994 .05166 L
.47955 .04185 L
.49045 .0376 L
.5005 .0344 L
.50981 .03205 L
.51968 .03017 L
.5248 .02943 L
.52958 .02889 L
.53484 .02846 L
.53778 .02829 L
.53917 .02822 L
Mistroke
.54048 .02817 L
.54168 .02814 L
.54299 .02811 L
.54417 .02809 L
.54526 .02808 L
.54644 .02807 L
.54774 .02808 L
.54839 .02808 L
.54909 .02809 L
.55035 .02812 L
.55153 .02815 L
.55281 .02819 L
.55514 .02829 L
.55741 .02841 L
.5595 .02855 L
.56429 .02895 L
.56956 .02954 L
.58024 .03116 L
.59036 .03321 L
.59962 .03552 L
.62049 .04209 L
.66017 .05934 L
.69833 .08087 L
.73894 .10798 L
.77804 .13721 L
.81959 .17076 L
.85963 .20482 L
.89814 .2387 L
.93912 .27545 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35671 L
.06244 .40297 L
.08255 .44006 L
.09396 .45554 L
.09905 .46107 L
.10458 .46609 L
.11004 .47005 L
.11508 .47283 L
.11989 .47472 L
.12232 .47539 L
.12369 .47569 L
.125 .47591 L
.12615 .47607 L
.12741 .4762 L
.12855 .47627 L
.12962 .4763 L
.13088 .47629 L
.13202 .47624 L
.13334 .47614 L
.13459 .47599 L
.13568 .47582 L
.13684 .47561 L
.1389 .47514 L
.14357 .47362 L
.14853 .47136 L
.15305 .46874 L
.16321 .46103 L
.18154 .44152 L
.22139 .38133 L
.25972 .31234 L
.3005 .23924 L
.33977 .17655 L
.37752 .12671 L
.41772 .08579 L
.45641 .05773 L
.47645 .04722 L
.48665 .04287 L
.49755 .03893 L
.50789 .03586 L
.51729 .03361 L
.52674 .03187 L
.53566 .03069 L
.54029 .03025 L
.54295 .03005 L
.54538 .02991 L
.54794 .02979 L
.54935 .02974 L
.5507 .0297 L
.55193 .02967 L
Mistroke
.55308 .02965 L
.55433 .02964 L
.55504 .02964 L
.55567 .02964 L
.55683 .02965 L
.55805 .02966 L
.5591 .02968 L
.56024 .02971 L
.5628 .02979 L
.56518 .0299 L
.5695 .03018 L
.57412 .03058 L
.57943 .03118 L
.58432 .03187 L
.5954 .03386 L
.60517 .03613 L
.61554 .03905 L
.65334 .05395 L
.6936 .07645 L
.73233 .10336 L
.77353 .136 L
.8132 .16965 L
.85136 .2027 L
.89198 .23772 L
.93107 .27102 L
.97262 .30604 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo09Oooooo3?l0
0008ool009Wooooo000Qooooo`03o`000?oooooooooo09Cooooo0_l00004ool0017ooooo2?oo002A
ooooo`008Oooool00ol0003oooooooooo`2Aooooo`;o00000ooo000Kooooo`;o000000?oo`00oooo
ooooool0S_ooool0027ooooo00?o0000ooooooooool0S_ooool2o`0000?oo`008Oooool3o`0008go
oooo000Qooooo`03o`000?oooooooooo08_ooooo0_l00003ool002Oooooo0ol0002:ooooo`008Ooo
ool00ol0003oooooooooo`29ooooo`;o000000?oooooool00?ooool0;?ooool3o`0008Oooooo000Q
ooooo`?o0000Qoooool2o`000003oooooooo003oo`00037ooooo0_oo0025ooooo`008Oooool00ol0
003oooooooooo`25ooooo`;o0000>?ooool3ool008;ooooo000Qooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool0>_ooool00ol0003oo`00ool00020ooooo`008Oooool00ol0003ooooo
ooooo`22ooooo`;o0000@?ooool2ool007kooooo000Qooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0@_ooool2ool007cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003oooooooooo`1oooooo`03o`000?oo003oo`0004Kooooo00?oo`00ooooooooool0NOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oo003ooooo
04Sooooo0_oo001iooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`0007co
oooo0_l000000ooo003oooooooooo`1:ooooo`03ool00?l0003ooooo07Kooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ol0003oo`00ool0001?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ol0003oo`00ooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1hooooo`;o000000?oo`00ooooooooool0Doooool2o`0007;ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Moooool00ol0003oooooool0001Hoooo
o`03o`000?oooooooooo06oooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooool0001Jooooo`;o0000Koooool0027ooooo00?o0000ooooooooool0
MOooool00ol0003oooooool0001Looooo`;oo`00K_ooool0027ooooo00?o0000ooooooooool0M?oo
ool00ol0003oooooool0001Oooooo`;oo`00K?ooool0027ooooo0ol0001cooooo`03o`000?oooooo
o`0006;ooooo00?oo`00ooooooooool0JOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1Tooooo`;oo`00JOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oo003ooooo06Oooooo000Qooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0J?ooool00ooo003oooooooooo`1Uooooo`008Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo06[ooooo00?oo`00o`000?ooool0I?ooool0027ooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qoooo
o`03o`000?oooooooooo06kooooo00?o0000ooooooooool0K_ooool00ooo003o0000ooooo`1Roooo
o`008Oooool3o`0006gooooo00?o0000ooooooooool0L?ooool00ooo003o0000o`00001Qooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0
G_ooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oo
oooooooo05gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2
o`0005gooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0
003oooooooooo`1Jooooo`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_o
oooo00?o0000ooooooooool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ooo003ooooo
ooooo`1mooooo`;o0000FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo07kooooo0_oo
00000ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo003o
oooo087ooooo00?oo`00o`000?ooool0E_ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo
003oooooooooo`22ooooo`03ool00?l0003o000005Gooooo000Qooooo`03o`000?oooooooooo06Ko
oooo00?o0000ool00?ooool0Q?ooool00ooo003oooooo`00001Dooooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oo003ooooo08Kooooo0_oo00000ol0003oooooooooo`1Aooooo`008Ooo
ool00ol0003oooooooooo`1Uooooo`03ool00?oooooooooo08Sooooo00?oo`00o`000?ooool0DOoo
ool0027ooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`2:ooooo`03ool00?l0003o
0000053ooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0S?ooool00ooo
003oooooo`00001?ooooo`008Oooool3o`0006;ooooo00?o0000ooooooooool0S_ooool00ooo003o
ooooo`00001>ooooo`008Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo08oooooo
00Coo`00ooooool0003o0000C?ooool0027ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Aooooo`04ool00?ooooooooooo`0004_ooooo000Qooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0U_ooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0Aoooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo04Kooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0
AOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool3o`0005gooooo00?oo`00o`000?ooool0WOooool00ol0003oooooooooo`14ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`1Mooooo`03ool00?oooooooooo09kooooo00?o0000ooooooooool0@oooool000Oooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003o
ooooooooo`1Looooo`03ool00?l0003ooooo09kooooo0_oo00000ol0003oooooooooo`12ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1Looooo`03ool00?oooooooooo0:3ooooo00?oo`00o`000?ooool0@_ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Foooool00ooo003oooooooooo`2Rooooo`;oo`00@_ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Jooooo`03ool00?l0003ooooo0:Go
oooo00?oo`00o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0F_ooool00ooo003ooooo
ooooo`2Vooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0Z?ooool00ooo003o0000ooooo`0mooooo`008Oooool3o`0005Wooooo00?oo`00
ooooooooool0ZOooool00ooo003o0000ooooo`0looooo`008Oooool00ol0003oooooooooo`1Hoooo
o`03ool00?oooooooooo0:_ooooo00?oo`00o`000?ooool0>oooool0027ooooo00?o0000oooooooo
ool0F?ooool00ooo003oooooooooo`2/ooooo`03ool00?l0003o000003[ooooo000Qooooo`03o`00
0?oooooooooo05Oooooo00?oo`00ooooooooool0[_ooool00ooo003oooooo`00000iooooo`008Ooo
ool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0;3ooooo00?oo`00ooooool00000>?oo
ool0027ooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`2cooooo`03o`000?oooooo
oooo03Gooooo000Qooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0]Oooool00ol0
003oooooooooo`0dooooo`008Oooool3o`0005Gooooo00?o0000ooooooooool0]_ooool2o`0003Co
oooo000Qooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0aooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`2l
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool0^oooool2ool00003o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0__ooool00ooo003o0000ooooo`0^ooooo`008Oooool00ol0003ooooo
ooooo`1Aooooo`03o`000?oooooooooo0<3ooooo00?oo`00o`000?ooool0;Oooool0027ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`31ooooo`;oo`00;Oooool0027ooooo0ol0001@
ooooo`03ool00?oooooooooo0<Cooooo00?oo`00ooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
o`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037ooooo00?oo`00ooooooooool0
2Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1_ooool01?oo003oooooogMgMolb<S8oooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0<Oooool00ooo003o
ooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Ol@413ooooooooooooooooo410@00gooooo00Coo`00oooooooooooo0000?oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Oooool0
0ooo003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo
03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?ooooooooooogMgMolb<S80?ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0<ooo
ool00ooo003o0000ooooo`08ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000;ooooo`06ool00?l0003o8B4Qo`000?lb<S;o
c<c<?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00eooooo`03ool00?l0003ooooo00Sooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oo`00o`00
0?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0>?ooool00ooo003o0000ooooo`08ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o
0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?oo`00ooooool00000@oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?oo`00ooooool000000ol0000n
ooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0
Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0027ooooo00?o0000ooooooooool0Booo
ool00ooo003oooooooooo`3Eooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooo
oooo04[ooooo00?oo`00ooooooooool0eoooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0
003oooooooooo`19ooooo`03ool00?oooooooooo0=Wooooo00?o0000ooooooooool04_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`19ooooo`03ool00?oooooooooo0=[o
oooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooo
oe;o000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85
ooooo`008Oooool2o`000003ool00?oooooooooo04Gooooo00?o0000ooooooooool0l?ooool2o`00
00;ooooo0_l00004ooooo`008Oooool2o`000003ool00?oooooooooo04Cooooo00?o0000oooooooo
ool0noooool0027ooooo00?o0000oooooooo0000A_ooool00ol0003oooooooooo`3kooooo`008Ooo
ool01?l0003oooooo`000?oo0014ooooo`03o`000?oooooooooo0?cooooo000Qooooo`04o`000?oo
oooo0000ool004?ooooo00?o0000ooooooooool0oOooool0027ooooo0ol000000ooo003ooooooooo
o`11ooooo`03o`000?oooooooooo0?gooooo000Qooooo`05o`000?ooooooooooo`000?oo0000@Ooo
ool00ooo003oooooooooo`3nooooo`008Oooool01Ol0003oooooooooooooooooo`00047ooooo00?o
o`00ooooooooool0o_ooool0027ooooo00Go0000ooooooooooooooooool00010ooooo`03ool00?oo
oooooooo0?oooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00?oooool00ooo003ooooo
ooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03cooooo00?o
o`00ooooooooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo03_ooooo00?oo`00o`000?ooool0ooooool2ooooo`008Oooool3o`0000;ooooo00?o0000ool0
0?ooool0>oooool00ooo003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3oooooo`?ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ooo003oooooooooo`3oooooo`?ooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool00ooo003ooooooooo
o`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=oooool0
0ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=?ooool00ooo003o0000ooooo`3oooooo`Kooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`3oooooo`Kooooo
000Qooooo`?o00001_ooool00ol0003oooooooooo`0booooo`03ool00?l0003ooooo0?oooooo1ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003o
o`00ooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000ooooooooool0
2?ooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo2Oooool0027ooooo00?o
0000ooooooooool02?ooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2_oo
ool0027ooooo00?o0000ooooooooool02?ooool00ol0003oo`00ooooo`0]ooooo`03o`000?oooooo
oooo0?oooooo2_ooool0027ooooo0ol00009ooooo`03ool00?oooooooooo02_ooooo00?o0000oooo
ooooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo02[o
oooo00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oo003ooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool0
0ol0003oooooooooo`0;ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0ooooool>
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo02Cooooo00?o
o`00ooooooooool0ooooool?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`03ool00?oooooooooo02;ooooo00?o
o`00ooooooooool0ooooool@ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo027ooooo00?o
0000ool00?ooool0oooooolAooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
8?ooool00ooo003oooooooooo`3ooooooa7ooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`3ooooooa;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7Oooool00ol0003oo`00ooooo`3ooooooa?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oo003ooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oo003ooooo0?oooooo5Oooool0027ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oo003ooooo0?oooooo5_ooool0027ooooo0ol0000Boooo
o`03o`000?oooooooooo01Kooooo00?o0000ool00?ooool0oooooolGooooo`008Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolHooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo0_l0003ooooooa_ooooo
000Qooooo`03o`000?oooooooooo01Gooooo0_oo000@ooooo`03o`000?oooooooooo0?oooooo6ooo
ool0027ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0;ooooo`;o0000oooooolN
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00[ooooo00?o0000oooo
ooooool0oooooolNooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`0000?o0000oooooooo
ool01Oooool2o`000003ool00?oooooooooo0?oooooo7_ooool0027ooooo0ol0000Jooooo`Coo`00
0_l00004ool00?oooooo8Oooool0027ooooo00?o0000ooooooooool07Oooool4ool00?oooooo9?oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mg
MgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413o
k^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb
<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo
00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOoo
ool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07
oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@
okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooo
oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?o
k^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;ooooo
ooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0N?ooool007kooooo
00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004
ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0NOooool007kooooo00?ogMgMob4Q
8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omE
EEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oM
gMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000
ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool0
0omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGo
oooo01Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1looooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0O?ooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4oooo
o`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo
01Cooooo00?oEEEEofIVI_l000003Oooool4o`0007_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33801 L
.06244 .36625 L
.08426 .39201 L
.0949 .40185 L
.10458 .40899 L
.10911 .41171 L
.11403 .41421 L
.11828 .41597 L
.12297 .41749 L
.12553 .41813 L
.12793 .41861 L
.13047 .41899 L
.13189 .41915 L
.13319 .41926 L
.13439 .41933 L
.13551 .41937 L
.13673 .41939 L
.13803 .41937 L
.13928 .41932 L
.14045 .41925 L
.1415 .41916 L
.14264 .41905 L
.14501 .41872 L
.14755 .41825 L
.15214 .4171 L
.1576 .41523 L
.16257 .41307 L
.17339 .40696 L
.18364 .39951 L
.22197 .36041 L
.26275 .30668 L
.30202 .25136 L
.33977 .20064 L
.37997 .15341 L
.41866 .11673 L
.43831 .10168 L
.4598 .08802 L
.48033 .07767 L
.49942 .07035 L
.50995 .06725 L
.51988 .0649 L
.5288 .06327 L
.53379 .06255 L
.53847 .062 L
.54303 .06158 L
.54793 .06124 L
.55072 .06111 L
.5521 .06106 L
.55337 .06102 L
Mistroke
.55452 .06099 L
.55575 .06096 L
.55645 .06096 L
.55711 .06095 L
.55834 .06094 L
.55957 .06094 L
.56026 .06095 L
.56091 .06095 L
.56222 .06097 L
.56295 .06098 L
.56362 .061 L
.5661 .06107 L
.56846 .06117 L
.57118 .06132 L
.5737 .06149 L
.57939 .06198 L
.58904 .06315 L
.59809 .06462 L
.61871 .06928 L
.63893 .07546 L
.65744 .08241 L
.69712 .10093 L
.73528 .12273 L
.77589 .14938 L
.81499 .17768 L
.85654 .20988 L
.89658 .24235 L
.93509 .2744 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .33623 L
.06244 .36302 L
.08255 .38544 L
.09396 .39536 L
.10458 .40257 L
.10961 .40528 L
.11508 .4077 L
.12023 .40948 L
.12269 .41016 L
.125 .4107 L
.12724 .41113 L
.12929 .41144 L
.13156 .4117 L
.13282 .41181 L
.13401 .41188 L
.13516 .41193 L
.13638 .41195 L
.13754 .41195 L
.13858 .41193 L
.13982 .41188 L
.14051 .41184 L
.14115 .41179 L
.14357 .41156 L
.14483 .4114 L
.14603 .41123 L
.14827 .41083 L
.15331 .40964 L
.15766 .40828 L
.1624 .40646 L
.17313 .40109 L
.18306 .39467 L
.20172 .37928 L
.22233 .35813 L
.26253 .3086 L
.30122 .25684 L
.34236 .20403 L
.38198 .15978 L
.42009 .12569 L
.44134 .11066 L
.46065 .09949 L
.48074 .09033 L
.4997 .08389 L
.50942 .08139 L
.51971 .0793 L
.5285 .07796 L
.53349 .07738 L
.53816 .07695 L
.54314 .0766 L
.54596 .07646 L
Mistroke
.5473 .07641 L
.54857 .07636 L
.54978 .07633 L
.55108 .0763 L
.55227 .07628 L
.55335 .07627 L
.55454 .07626 L
.55583 .07626 L
.55649 .07626 L
.55719 .07627 L
.55845 .07628 L
.55969 .0763 L
.56084 .07633 L
.56343 .07641 L
.56572 .0765 L
.56815 .07663 L
.57235 .07691 L
.57699 .0773 L
.58711 .07846 L
.59637 .07987 L
.61724 .08422 L
.6362 .08946 L
.65692 .09645 L
.69753 .11352 L
.73663 .13358 L
.77818 .1582 L
.81821 .18468 L
.85673 .21241 L
.8977 .24405 L
.93716 .27626 L
.9751 .3081 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`2Loooooa;o0000U_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo09Oooooo1Ol0000Booooo`Ko0000T?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Dooooo`?o00007Oooool3o`0008gooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000TOooool3o`0002?ooooo1?l00029ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08kooooo0ol0000Zooooo`Co0000QOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2;ooooo`?o00003?ooool?ool001Kooooo0_l0
0023ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Wooooo0_l00009
ooooo`Koo`006Oooool3ool000_ooooo0_l00021ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08Oooooo0_l00009ooooo`;oo`008_ooool4ool000Wooooo0_l0001ooooo
o`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08Gooooo0_l0000:ooooo`03
ool00?oooooooooo02Kooooo0ooo0008ooooo`?o0000O?ooool0027ooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`0fooooo`;oo`002Oooool3o`0007Wooooo000Qooooo`03o`000?oo
oooooooo08;ooooo0_l0000kooooo`?oo`002Oooool2o`0007Oooooo000Qooooo`?o0000POooool0
0ol0003oooooooooo`0nooooo`03ool00?oooooooooo00Sooooo0ol0001dooooo`008Oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo00;ooooo0ooo0018ooooo`;o0000L_ooool0027o
oooo00?o0000ooooooooool0O_ooool2o`0000?ooooo0_oo001=ooooo`;o0000L?ooool0027ooooo
00?o0000ooooooooool0OOooool01?l0003oooooooooooooool2ool0057ooooo00?o0000oooooooo
ool0KOooool0027ooooo00?o0000ooooooooool0Noooool2o`0000;ooooo0_oo001;ooooo`?oo`00
1_ooool2o`0006gooooo000Qooooo`03o`000?oooooooooo07[ooooo00Go0000oooooooooooooooo
ool0001@ooooo`?oo`001Oooool2o`0006_ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool00_oo001Dooooo`;oo`001Oooool00ol0003oooooooooo`1Xooooo`008Oooool3
o`0007Sooooo00Co0000ooooooooooooo`00F?ooool00ooo003oooooooooo`03ooooo`;o0000J?oo
ool0027ooooo00?o0000ooooooooool0Moooool01?l0003ooooooooooooo001Jooooo`;oo`001Ooo
ool2o`0006Kooooo000Qooooo`03o`000?oooooooooo07Kooooo00Co0000ooooooooooooo`00GOoo
ool2ool000Gooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0MOooool0
0ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool0
027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo
00?ooooo0_l0001Rooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0Goooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo05kooooo000Qooooo`?o0000LOooool00ol0003ooooooooo
o`1`ooooo`;o0000G_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000oooo
oooo0000LOooool2ool000;ooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooool0001dooooo`;oo`0000?oooooo`000?l00000F_ooool0027ooooo
00?o0000ooooooooool0KOooool00ol0003oooooool0001gooooo`;oo`0000?oooooo`000?ooool0
F?ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oo`00ooooo`1iooooo`;oo`000_l0
001Gooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo07cooooo00?oo`00
ooooool00000E_ooool0027ooooo00?o0000ooooooooool0Joooool00ol0003oo`00ooooo`1noooo
o`;oo`000_l0001Dooooo`008Oooool3o`0006[ooooo00?o0000ool00?ooool0POooool2ool00003
o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo06Wooooo00?o0000ool00?ooool0
Q?ooool00ooo003o0000o`00001Aooooo`008Oooool00ol0003oooooooooo`1Xooooo`03o`000?oo
003ooooo08Kooooo00?oo`00ooooool00000D?ooool0027ooooo00?o0000ooooooooool0Ioooool0
0ol0003oo`00ooooo`2:ooooo`;o0000C_ooool0027ooooo00?o0000ooooooooool0I_ooool00ol0
003oo`00ooooo`2=ooooo`03o`000?oooooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo06Kooooo00?oo`00ooooooooool0S_ooool00ol0003oooooooooo`1:ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`2@ooooo`;o0000B_ooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0006Cooooo00?o0000
ooooooooool0Toooool00ol0003oooooooooo`17ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool0A_ooool000Oooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo09Gooooo0_oo00000ol0003oooooooooo`15ooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo09Sooooo00?oo`00o`000?l00000AOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`2Jooooo`;oo`0000?o0000ooooooooool0@_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09cooooo00?o
o`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2N
ooooo`03ool00?l0003o0000047ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ool0
0?ooool0X?ooool2ool00003o`000?oooooooooo03kooooo000Qooooo`?o0000GOooool00ol0003o
ooooool0002Sooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo05cooooo
00?o0000oooooooo0000YOooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003ooooooooo
o`1Looooo`03o`000?oo003ooooo0:Kooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000
ooooooooool0Foooool00ol0003oo`00ooooo`2Xooooo`03ool00?l0003o000003_ooooo000Qoooo
o`03o`000?oooooooooo05[ooooo00?o0000oooooooo0000[?ooool00ol0003oooooooooo`0hoooo
o`008Oooool00ol0003oooooooooo`1Iooooo`03o`000?ooooooo`000:kooooo00?o0000oooooooo
ool0=oooool0027ooooo00?o0000ooooooooool0F?ooool00ol0003oooooool0002`ooooo`03o`00
0?oooooooooo03Kooooo000Qooooo`?o0000F?ooool00ol0003oo`00ooooo`2aooooo`03o`000?oo
oooooooo03Gooooo000Qooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo0000/oooool0
0ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`1Fooooo`03o`000?ooooooo`00
0;Gooooo0_l0000dooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?ooooooo`000;Oo
oooo0_oo000cooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?ooooooo`000;[ooooo
00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`2kooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0_Oooool2ool002oooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0_oooool00ol0003oo`00ooooo`0]ooooo`008Oooool3o`0005;ooooo00?o0000oooooooo
ool0`Oooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000omgMg@0moooo
o`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0<?ooool2ool000_ooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ogMgMolb<S80?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo033ooooo00?o0000ool00?ooool02Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo033ooooo00?o0000ool00?ooool02Oooool00onHV9So8B4Qonk^
kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003Ooo
ool01?l0003oooooogMgMolb<S8oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`0booooo`03o`000?oo003ooooo00Wooooo00?oV9RHob4Q8Oo^k^h0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ool00?l0003o<S8bolc<c00oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Gooooo00?o0000ooooooooool02?ooool00omg
MgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oo`00ooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oo`00ooooo`12ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0iooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oo003o
000000?o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000j
ooooo`09o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`00
0?oooooooooo04cooooo00?oo`00ooooooooool0d_ooool00ol0003oooooooooo`0Pooooo`008Ooo
ool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo0=Cooooo00?o0000ooooooooool07ooo
ool0027ooooo00?o0000ooooooooool0B_ooool00ol0003oo`00ooooo`3Fooooo`03ool00?l0003o
oooo01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ooo
003o0000ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wo
oooo00?oo`00ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`000018o`000003ool00?l0003o0000
0=_o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03ool00?l0003ooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooo
oooo0000A_ooool00ooo003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04
o`000?oooooo0000ool004Cooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000oooooooo
ooooo`00@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003oooooooooooooooooo`00
04;ooooo00?o0000ooooooooool0oOooool0027ooooo00Ko0000ooooooooooooooooo`000?oo0010
ooooo`03o`000?oooooooooo0?kooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooo`?ooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`3o
ooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool00ooo
003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00001oooool00ol0003oo`00
ooooo`0booooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool01ooo
ool00ol0003oo`00ooooo`0aooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000
ooooooooool02?ooool00ol0003oo`00ooooo`0_ooooo`03ool00?l0003ooooo0?oooooo2?ooool0
027ooooo00?o0000ooooooooool02Oooool00ol0003oo`00ooooo`0]ooooo`03ool00?l0003ooooo
0?oooooo2Oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooool0000/ooooo`03
ool00?l0003ooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ool0000Zooooo`03ool00?l0003ooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooool0000Xooooo`03ool00?l0003ooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooool0000Vooooo`03ool00?l0003ooooo0?oooooo3Oooool0
027ooooo0ol0000=ooooo`03o`000?ooooooo`0002Cooooo00?oo`00o`000?ooool0ooooool>oooo
o`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?ooooooo`0002?ooooo00?o0000oooooooo
ool0ooooool>ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooooooo`00027ooooo
00?o0000ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`0@ooooo`;o000000?o
o`00ooooooooool07Oooool00ol0003oooooooooo`3ooooooa3ooooo000Qooooo`03o`000?oooooo
oooo01;ooooo00?o0000ool00?ooool07?ooool00ol0003oooooooooo`3ooooooa7ooooo000Qoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooo
oa;ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ooo003o
ooooooooo`02o`000?oooooo5Oooool0027ooooo0ol0000Eooooo`03o`000?oooooooooo01;ooooo
00Coo`00oooooooooooo0000oooooolGooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00kooooo0ooo00000ooooooo0000o`00003ooooooaSooooo000Qooooo`03o`000?oo
oooooooo01Oooooo0ol00002ooooo`_oo`000oooool00ol0003oooooooooo`3ooooooaSooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool2o`000?oooooo6oooool0
027ooooo00?o0000ooooooooool06oooool3o`0000Kooooo1?l0003ooooooagooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^
k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_oo
ool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo0000
1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`00
0?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03
oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004oooo
o`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool01Oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04
o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04oooo
o`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003
ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@
413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?o
ooooogMgMomEEED05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@
413ogMgM01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool0
2OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Go
oooo00?oEEEEofIVI_l000003Oooool4o`0000Cooooo1?l0001fooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2992 L
.06244 .2907 L
.06747 .28902 L
.07286 .28747 L
.07751 .28635 L
.08255 .28536 L
.08564 .28488 L
.08848 .28452 L
.0912 .28424 L
.09259 .28412 L
.09409 .28402 L
.09543 .28394 L
.09666 .28389 L
.0979 .28385 L
.09908 .28382 L
.09974 .28381 L
.10044 .28381 L
.10171 .2838 L
.10248 .28381 L
.10321 .28382 L
.10387 .28384 L
.10458 .28385 L
.10582 .2839 L
.10695 .28395 L
.1095 .28409 L
.11185 .28427 L
.11409 .28448 L
.11908 .28507 L
.12452 .28588 L
.14558 .29021 L
.16497 .29472 L
.17526 .29687 L
.18067 .29785 L
.18637 .29876 L
.19141 .29943 L
.19693 .30001 L
.19936 .30021 L
.20195 .30038 L
.2044 .30051 L
.20662 .3006 L
.2078 .30063 L
.20906 .30065 L
.21013 .30067 L
.21131 .30068 L
.21258 .30067 L
.21329 .30067 L
.21394 .30066 L
.2152 .30063 L
.2164 .3006 L
Mistroke
.21869 .30051 L
.22082 .3004 L
.22315 .30025 L
.22563 .30004 L
.23101 .29946 L
.23594 .29875 L
.24708 .2966 L
.2569 .29406 L
.26727 .29078 L
.30529 .27423 L
.34577 .25127 L
.38473 .22714 L
.42614 .20245 L
.46604 .18192 L
.50442 .16653 L
.52423 .16048 L
.53436 .15791 L
.54525 .15554 L
.55544 .15369 L
.56476 .15232 L
.57368 .15128 L
.58306 .15049 L
.58807 .15019 L
.59263 .14999 L
.59515 .14992 L
.59648 .14988 L
.59788 .14985 L
.59911 .14983 L
.59976 .14983 L
.60046 .14982 L
.60169 .14981 L
.60284 .14981 L
.60406 .14981 L
.6052 .14981 L
.60645 .14982 L
.60708 .14983 L
.60777 .14984 L
.61018 .14989 L
.61245 .14995 L
.61667 .1501 L
.62122 .15034 L
.62617 .15067 L
.63077 .15105 L
.64123 .15217 L
.65143 .15358 L
.66233 .15544 L
.68365 .16008 L
.70379 .16562 L
.74222 .17899 L
.78311 .19671 L
Mistroke
.82248 .21655 L
.86034 .23763 L
.90064 .26165 L
.93944 .28575 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29825 L
.06244 .28751 L
.07286 .28306 L
.08255 .27987 L
.08813 .27848 L
.0932 .2775 L
.096 .27707 L
.09905 .27669 L
.10192 .27641 L
.10329 .27631 L
.10458 .27623 L
.10574 .27617 L
.10701 .27612 L
.10817 .27609 L
.10924 .27607 L
.11051 .27606 L
.11166 .27606 L
.1123 .27606 L
.11299 .27608 L
.11425 .2761 L
.11534 .27614 L
.11654 .27619 L
.11897 .27633 L
.12121 .27649 L
.12331 .27668 L
.12851 .27728 L
.13326 .27796 L
.14393 .27993 L
.18378 .28948 L
.202 .29329 L
.20699 .29413 L
.21237 .29491 L
.21702 .29548 L
.22211 .29597 L
.22454 .29616 L
.22713 .29632 L
.22857 .2964 L
.22987 .29646 L
.2312 .29651 L
.23242 .29654 L
.23356 .29657 L
.23476 .29659 L
.23596 .2966 L
.23665 .2966 L
.23729 .2966 L
.23844 .2966 L
.2395 .29658 L
.24072 .29656 L
.24188 .29653 L
Mistroke
.24321 .29649 L
.24441 .29644 L
.2471 .29629 L
.24959 .29612 L
.25193 .29593 L
.2572 .29536 L
.26289 .29456 L
.27242 .29279 L
.28287 .29022 L
.30394 .28325 L
.34442 .26456 L
.38338 .24308 L
.42479 .2205 L
.46469 .20197 L
.50307 .18868 L
.52289 .18372 L
.53301 .18169 L
.54391 .17985 L
.55409 .17846 L
.56342 .17746 L
.57233 .17672 L
.57682 .17643 L
.58171 .17618 L
.58426 .17607 L
.58701 .17597 L
.58944 .1759 L
.59201 .17584 L
.59433 .1758 L
.59565 .17579 L
.59688 .17578 L
.59801 .17577 L
.59904 .17576 L
.60023 .17576 L
.60136 .17576 L
.60256 .17577 L
.60324 .17577 L
.60389 .17578 L
.60518 .17579 L
.60657 .17581 L
.60909 .17585 L
.6114 .1759 L
.61672 .17607 L
.62232 .17631 L
.63185 .17687 L
.64204 .17767 L
.6604 .17964 L
.68172 .18274 L
.70186 .18646 L
.7403 .19576 L
.78119 .20901 L
Mistroke
.82056 .22509 L
.85841 .24328 L
.89872 .2648 L
.93751 .28663 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0:Gooooo7?l00023ooooo`008Oooool00ol0003oooooooooo`2Oooooo`Ko0000
7?ooool7o`0007cooooo000Qooooo`03o`000?oooooooooo09cooooo0ol0000Yooooo`?o0000NOoo
ool0027ooooo00?o0000ooooooooool0V?ooool4o`0002oooooo0ol0001fooooo`008Oooool00ol0
003oooooooooo`2Eooooo`?o0000=_ooool3o`0007?ooooo000Qooooo`?o0000T_ooool3o`0003co
oooo1?l0001_ooooo`008Oooool00ol0003oooooooooo`2?ooooo`?o0000@oooool3o`0006cooooo
000Qooooo`03o`000?oooooooooo08gooooo0_l00019ooooo`?o0000JOooool0027ooooo00?o0000
ooooooooool0Roooool2o`0001Sooooo1_oo000:ooooo`goo`006Oooool3o`0006Kooooo000Qoooo
o`03o`000?oooooooooo08Sooooo0ol0000Cooooo`Ooo`007Oooool3ool001Wooooo0_l0001Toooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`26ooooo`;o00004oooool3ool004;ooooo0ol0001Q
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Q?ooool2o`0004Wooooo1Ooo000?ooooo`;o0000Goooool0
00Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3
o`0008;ooooo0_l0001@ooooo`Coo`003Oooool2o`0005gooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo083ooooo0_l0000=
ooooo`;oo`00Aoooool4ool000_ooooo0ol0001Jooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo07kooooo0_l0
000<ooooo`?oo`00COooool3ool000_ooooo0_l0001Hooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1looooo`;o00002ooo
ool3ool0063ooooo0_l0001Fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`;o00002_ooool3ool006Gooooo0_l0
001Dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool02?ooool2ool006[ooooo0ol0001Aooooo`008Oooool0
0ol0003oooooooooo`1gooooo`;o00002Oooool2ool006Gooooo1?oo0006ooooo`;o0000Coooool0
027ooooo00?o0000ooooooooool0MOooool2o`0000[ooooo00?oo`00ooooooooool0JOooool3ool0
00Gooooo0_l0001=ooooo`008Oooool3o`0007Cooooo00?o0000ooooooooool0NOooool00ooo003o
ooooooooo`04ooooo`;o0000Boooool0027ooooo00?o0000ooooooooool0L_ooool2o`0008Gooooo
0_l00019ooooo`008Oooool00ol0003oooooooooo`1`ooooo`;o0000ROooool00ol0003ooooooooo
o`16ooooo`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo0_oo0023
ooooo`;o0000A_ooool0027ooooo00?o0000ooooooooool0KOooool2o`0000Kooooo0_oo0027oooo
o`;o0000A?ooool0027ooooo00?o0000ooooooooool0Joooool2o`0000Oooooo00?oo`00oooooooo
ool0Poooool2ool000Cooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`05ooooo`;oo`00R?ooool2ool000?ooooo0_l00011ooooo`008Ooo
ool3o`0006Sooooo0_l00006ooooo`;oo`00S?ooool2ool000?ooooo0_l0000oooooo`008Oooool0
0ol0003oooooooooo`1Vooooo`;o00001oooool00ooo003oooooooooo`2>ooooo`;oo`000oooool0
0ol0003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
00Gooooo0_oo002Cooooo`;oo`000_ooool2o`0003cooooo000Qooooo`03o`000?oooooooooo06?o
oooo0_l00006ooooo`;oo`00Uoooool2ool000;ooooo00?o0000ooooooooool0>Oooool0027ooooo
00?o0000ooooooooool0HOooool2o`0000Oooooo00?oo`00ooooooooool0VOooool2ool00003oooo
ool0003o000003Wooooo000Qooooo`03o`000?oooooooooo05oooooo0_l0002Wooooo`04ool00?oo
ooooooooo`0003Sooooo000Qooooo`03o`000?oooooooooo05gooooo0_l0002]ooooo`;o0000=_oo
ool0027ooooo00?o0000ooooooooool0Foooool2o`000;7ooooo00?o0000ooooooooool0<oooool0
027ooooo0ol0001Jooooo`03o`000?oooooooooo0;;ooooo0_l0000cooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`;o00001Oooool2ool002oooooo1?l000000ol@413oooooooooo`0k
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Zooooo`;o00004Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02ooooo`;o00001Ooo
ool2ool003?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Yooooo`;oo`0000?o0000ooooooooool03_ooool01OnHV9So8B4Qonk^
k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooo
oa0@400@ooooo`04o`000?oooooo0000o`0000Cooooo0ooo000eooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`;oo`0000?o0000oooooooo
ool03Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo0000o`000004ooooo`;oo`00>?ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0;Oooool2ool00003
o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
3oooool5ool000[ooooo2?oo000Gooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?l0003oc<c<00?ooooo0_oo000jooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<033ooooo0_oo000>ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo00cooooo0ooo0006ooooo`;o00003oooool3ool0
01Cooooo00Go410@oooooooooooooooooa0@400<ooooo`;o00001?ooool2ool003cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_oo000=
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00002_ooool2ool000;ooooo2?l000000ooo
oooo0000o`000008o`0000Sooooo0ooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool3
o`0000?ooooo0_oo000nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0fooooo`;oo`001oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`03o`000?oooooooooo00Sooooo0_oo0004o`0001?ooooo1Ol00006ooooo`;oo`003oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00002ooooo`Co0000?_ooool00omEEEGoIVIVo`00
000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`03ool00?l0003ooooo00Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;oo`000_l0
000Looooo`?o00007oooool2o`000=Cooooo00?oo`00o`000?ooool08oooool0027ooooo00?o0000
ooooooooool01Oooool00ooo003o0000o`00000Qooooo`?o00003?oooolAool00=Kooooo00?oo`00
o`000?l000008_ooool0027ooooo00?o0000ooooooooool00_ooool3o`0002Oooooo1ol0000:oooo
o`Go0000h?ooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o0000<Oooool:o`000>Oo
oooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l00004ooooo`008Oooool3o`000?oooooo
9_ooool2o`0001?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o
00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5oooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`3ooooooc_o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo
0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@
omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003o
ooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07oooo
o`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Co
oooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Noooool007kooooo00Oo410@omgMgOmgMgOo8B4Qoooo
oon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko
00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool0
0onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000Noooool007kooooo00Co
EEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l00004oooo
o`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool00ooM
gMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06oooo
o`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:oooo
o`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0:
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0Noooool007oooooo00?oV9RHogMgMoooool00_ooool0
0ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05
ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMg
oeEEEOooool05Oooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo07gooooo002Foooo
o`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo
0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool0
2_ooool00ooMgMgo410@oiRHV01mooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4
A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMg
Moooool05?ooool00omEEEGoIVIVo`00000=ooooo`04olc<c?m4A4Co0000oa0@47_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2729 L
.06244 .23786 L
.08426 .20581 L
.0949 .19333 L
.10458 .18398 L
.11403 .17675 L
.12297 .17168 L
.12787 .16962 L
.1324 .16817 L
.13476 .16758 L
.13737 .16707 L
.13868 .16686 L
.14009 .16668 L
.14142 .16654 L
.14264 .16645 L
.14392 .16638 L
.14514 .16635 L
.14622 .16635 L
.1474 .16637 L
.14869 .16642 L
.14934 .16646 L
.15005 .16651 L
.15132 .16662 L
.15248 .16676 L
.15476 .16709 L
.15721 .16755 L
.16162 .16864 L
.16672 .17032 L
.17226 .1726 L
.18234 .1779 L
.20212 .19176 L
.22313 .2098 L
.26088 .24447 L
.28185 .2622 L
.30108 .27638 L
.32112 .28865 L
.33977 .29763 L
.35869 .30437 L
.3687 .30702 L
.37939 .30919 L
.38963 .31067 L
.39541 .31125 L
.39816 .31147 L
.40074 .31164 L
.40317 .31178 L
.4054 .31187 L
.40787 .31195 L
.40923 .31198 L
.41053 .31201 L
Mistroke
.41177 .31202 L
.41247 .31203 L
.4131 .31203 L
.41433 .31203 L
.41548 .31202 L
.41614 .31202 L
.41684 .31201 L
.41808 .31199 L
.41942 .31196 L
.42089 .31192 L
.42341 .31184 L
.42615 .31171 L
.43112 .31142 L
.43596 .31104 L
.44044 .31062 L
.46137 .30786 L
.48007 .3045 L
.50068 .30011 L
.54094 .29065 L
.57968 .28184 L
.59937 .27788 L
.62087 .27411 L
.64167 .27113 L
.66055 .26903 L
.67066 .26815 L
.6802 .26749 L
.69026 .26696 L
.69594 .26674 L
.69867 .26665 L
.70116 .26659 L
.70341 .26654 L
.70585 .26649 L
.70719 .26647 L
.70843 .26646 L
.7097 .26644 L
.71088 .26643 L
.71189 .26643 L
.71297 .26642 L
.71418 .26642 L
.71528 .26642 L
.71637 .26642 L
.71756 .26642 L
.7188 .26643 L
.71996 .26644 L
.72125 .26645 L
.72265 .26647 L
.72519 .26651 L
.72994 .26661 L
.73549 .26678 L
.74062 .26698 L
Mistroke
.75029 .26748 L
.75936 .26808 L
.77999 .26993 L
.80025 .27235 L
.81878 .27503 L
.85851 .28207 L
.89672 .29013 L
.93739 .29959 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27083 L
.06244 .23352 L
.08255 .20253 L
.09396 .18883 L
.10458 .17875 L
.10961 .17489 L
.11508 .17135 L
.11989 .16879 L
.125 .16664 L
.12959 .16519 L
.13221 .16456 L
.13466 .1641 L
.13581 .16393 L
.1369 .16378 L
.13789 .16368 L
.13895 .16358 L
.1401 .16351 L
.14116 .16346 L
.14243 .16343 L
.14357 .16344 L
.14477 .16346 L
.1459 .16352 L
.14713 .1636 L
.14845 .16372 L
.15114 .16406 L
.1536 .16448 L
.15833 .16558 L
.16282 .16697 L
.17279 .17113 L
.18364 .17718 L
.20341 .19147 L
.22442 .20986 L
.26217 .24623 L
.30238 .28264 L
.34106 .31012 L
.3611 .32056 L
.3713 .32483 L
.3822 .32862 L
.39255 .3315 L
.40194 .33352 L
.40648 .3343 L
.41139 .33501 L
.41569 .33551 L
.42031 .33594 L
.42287 .33612 L
.4252 .33626 L
.42755 .33637 L
.42978 .33644 L
.43103 .33647 L
Mistroke
.43171 .33649 L
.43236 .3365 L
.43362 .33651 L
.43476 .33652 L
.43542 .33652 L
.43612 .33652 L
.43737 .33651 L
.43806 .33651 L
.43871 .3365 L
.44019 .33647 L
.4415 .33644 L
.44292 .33639 L
.44551 .33628 L
.45035 .336 L
.456 .33555 L
.46123 .33502 L
.47993 .33232 L
.50055 .32819 L
.5408 .31808 L
.57954 .3079 L
.59923 .30319 L
.62074 .2987 L
.64154 .29516 L
.66041 .2927 L
.67053 .29169 L
.68006 .29093 L
.69013 .29032 L
.6958 .29007 L
.70102 .28989 L
.70571 .28977 L
.70834 .28973 L
.71074 .28969 L
.71183 .28968 L
.71298 .28967 L
.71424 .28966 L
.71541 .28966 L
.71649 .28965 L
.71751 .28965 L
.71862 .28965 L
.71983 .28965 L
.72112 .28966 L
.72233 .28967 L
.72365 .28968 L
.72507 .28969 L
.72796 .28973 L
.7306 .28978 L
.73568 .2899 L
.74048 .29005 L
.75019 .29043 L
.76047 .29095 L
Mistroke
.77891 .29214 L
.81677 .29516 L
.85708 .29863 L
.89587 .3019 L
.93711 .30548 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool07_ooool3ool00?oooooo9?ooool0027ooooo0ol0000Looooo`;o
o`0000?oooooo`000?l000001ol0003ooooooagooooo000Qooooo`03o`000?oooooooooo01Wooooo
0ooo0003o`0000Wooooo0ol00003ool00?oooooo5oooool0027ooooo00?o0000ooooooooool06?oo
ool01?oo003oooooooooool0000@ooooo`;o000000?oo`00ooooooooool0oooooolDooooo`008Ooo
ool00ol0003oooooooooo`0Hooooo`03ool00?l0003o000001Cooooo0_oo003ooooooaCooooo000Q
ooooo`03o`000?oooooooooo01Kooooo0_oo00000ol0003oooooooooo`0Fooooo`03ool00?oooooo
oooo0?oooooo4Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05Oooool00ooo003oooooo`00
000Jooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Cooooo00?o
o`00ooooool000007?ooool00ooo003oooooooooo`3oooooo`oooooo0005o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Cooooo`03ool00?oo
oooo000001kooooo00?oo`00ooooooooool0ooooool>ooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01kooooo0_oo003oooooo`kooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Qooooo`03ool00?oooooooooo0?oooooo2oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Sooooo`03ool00?l0003ooooo0?oooooo2_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo0?oooooo2?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0ooooool5ooooo`008Oooool3o`00
00kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooo`Cooooo000Qooooo`03
o`000?oooooooooo00gooooo00?oo`00o`000?ooool0;oooool00ol0003oooooooooo`3oooooo`?o
oooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0<?ooool00ooo003ooooo
ooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0<_oo
ool00ooo003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00
ooooooooool0=?ooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03ool00?l0003ooooo03Kooooo00?oo`00ooooooooool0o_ooool0027ooooo00?o0000oooooooo
ool02Oooool00ooo003o0000ooooo`0hooooo`03ool00?oooooooooo0?gooooo000Qooooo`?o0000
2Oooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?cooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?oo`00o`000?ooool0>oooool00ooo003oooooooooo`3kooooo`008Oooool0
0ol0003oooooooooo`08ooooo`03ool00?oooooooooo03cooooo00?oo`00o`000?ooool0n_ooool0
027ooooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`0nooooo`03ool00?l0003ooooo
0?Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0?oooool00ooo003o
0000ooooo`3hooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?l0003ooooo047ooooo
00?oo`00o`000?ooool0moooool0027ooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`12ooooo`03ool00?l0003ooooo0?Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0AOooool00ol0003oooooooooo`3dooooo`008Oooool3o`0000Gooooo00?o0000oooo
ooooool0A_ooool2o`000?Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03;ooooo7?l000000olb<S;ogMgMooooo`0l
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0foooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo0_l0000oooooo`03o`000?oooooo
oooo02cooooo2?l0000;ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`_o0000=_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=oooool01Ol@413ooooooooooooooooo410@013ooooo0_l0000nooooo`03o`000?oo
oooooooo027ooooo2ol0000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool6o`00037ooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`02o`0003cooooo00?o0000ooooooooool07_ooool3o`0001kooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`0<ooooo`Ko0000;?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00
000<ooooo`06o`000?lQ8B7o0000oc8b<_o<c<coo`000_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo01Wooooo1Ol0000Qooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00Cooooo`Ko00009oooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03Sooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00?ooooo0_oo00000ooooooo0000o`00000iooooo`03o`000?oooooooooo
01Cooooo1Ol0000Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool6o`00
02;ooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`04ool00?oooooooooo
o`0003Sooooo00?o0000ooooooooool04?ooool4o`0002_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Qooooo`Ko00006?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`05o`000?ooooooooooooooool00000>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`;oo`0000?oooooo`000?l00000=?ooool00omEEEGoIVIVo`00000>ooooo`Co0000
:Oooool5ool00003ofIVI_l0003ooooo00Oooooo0ooo0002ooooo`Co00009_ooool5o`0001?ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooooooooooo001Hooooo`03
ool00?oooooooooo00;o0000?oooool4o`0002;ooooo2ooo000Booooo`coo`009Oooool5o`0002ko
oooo000Qooooo`04o`000?oooooo0000ool005Wooooo0_oo0002ooooo`;o0000>?ooool5o`0005Wo
oooo1ooo000Iooooo`Co0000:_ooool0027ooooo00?o0000oooooooo0000G?ooool01?oo003ooooo
ooooooooool3o`00037ooooo1?l0000Nooooo`?oo`00A?ooool9ool001Cooooo1?l0000Vooooo`00
8Oooool00ol0003oo`00ooooo`1Mooooo`;oo`001?ooool3o`0002Wooooo1Ol0000Oooooo`?oo`00
F_ooool7ool000Oooooo1?l0000Hooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo
003ooooo05oooooo00?oo`00ooooooooool01?ooool3o`00023ooooo1_l0000Oooooo`Goo`00I?oo
ool8ool000?ooooo1?l0000Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo
1ol000000ooo003o0000o`00001Po`000003ool00?l0003o000004Oo00001?oo001ao`0000;oo`00
3_l0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01ooooolEo`0000kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0W?ooool3ool009_ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0V?ooool4ool00:Sooooo000Q
ooooo`03o`000?oooooooooo06[ooooo0ooo000Wooooo`Coo`00[?ooool0027ooooo00?o0000oooo
ooooool0KOooool3ool0027ooooo0ooo002`ooooo`008Oooool00ol0003oooooooooo`1`ooooo`?o
o`007?ooool2ool00;?ooooo000Qooooo`?o0000Loooool5ool00<cooooo000Qooooo`03o`000?oo
oooooooo07Sooooo0_oo0003ooooo`Soo`00_oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo
0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?o
k^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOoo
ool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06
okZj^_m4A4Cooooooooooon7QhOoIVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo
001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_o
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@
4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`1dooooo`00
Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Looo
ool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko
00001Oooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omg
MgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`00
00gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo
00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003o
oooo01Kooooo00?o0000ooooooooool02_ooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oo
oooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?o
EEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05ooo
ool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o
0000ooooooooool02_ooool00ooMgMgo410@oiRHV006ooooo`03o`000?oooooooooo07Oooooo002B
ooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l0
00003Oooool01?o<c<coA4A4o`000?l@4104ooooo`Co0000M_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22809 L
.08255 .19129 L
.10458 .15782 L
.11448 .14552 L
.12507 .13442 L
.13499 .12602 L
.14415 .12002 L
.14911 .11749 L
.15437 .11536 L
.15964 .11379 L
.16265 .11315 L
.16399 .11292 L
.16546 .11271 L
.1668 .11256 L
.16805 .11246 L
.16925 .11238 L
.17052 .11233 L
.17178 .11232 L
.17296 .11234 L
.17401 .11237 L
.17516 .11244 L
.17642 .11254 L
.1778 .11269 L
.1806 .1131 L
.18318 .11362 L
.1856 .11422 L
.1906 .11582 L
.19605 .11808 L
.20595 .12357 L
.21559 .13051 L
.22451 .13824 L
.26377 .18409 L
.30152 .23854 L
.34173 .29654 L
.38041 .34459 L
.40006 .36475 L
.42155 .38326 L
.44231 .39766 L
.46118 .40792 L
.48079 .41591 L
.49156 .41924 L
.50174 .42173 L
.51146 .42356 L
.51678 .42434 L
.52175 .42494 L
.52634 .42539 L
.53054 .4257 L
.53277 .42584 L
.5352 .42596 L
Mistroke
.53777 .42606 L
.53895 .42609 L
.5402 .42612 L
.54154 .42615 L
.54277 .42617 L
.54409 .42618 L
.54484 .42618 L
.54553 .42618 L
.5468 .42618 L
.54796 .42617 L
.5486 .42616 L
.54929 .42615 L
.55055 .42613 L
.55291 .42606 L
.55542 .42598 L
.55992 .42576 L
.56507 .42542 L
.5699 .42501 L
.5809 .42381 L
.60112 .42068 L
.61964 .41695 L
.65932 .40694 L
.69748 .39568 L
.73809 .38286 L
.77719 .37025 L
.81874 .35694 L
.85877 .34438 L
.89729 .33258 L
.93826 .32028 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22922 L
.08255 .19343 L
.10458 .16071 L
.11448 .14865 L
.12507 .13779 L
.13499 .12961 L
.14415 .12385 L
.14911 .12146 L
.15437 .11948 L
.15691 .11873 L
.15964 .11808 L
.16121 .11777 L
.16265 .11754 L
.16401 .11735 L
.16546 .1172 L
.16615 .11714 L
.1668 .1171 L
.16802 .11703 L
.16916 .117 L
.17039 .117 L
.17104 .11701 L
.17176 .11703 L
.1725 .11707 L
.1732 .11711 L
.17445 .11721 L
.17578 .11735 L
.17842 .11774 L
.18092 .11823 L
.1856 .11948 L
.19019 .12111 L
.19525 .12337 L
.20551 .12936 L
.22393 .14447 L
.24327 .16549 L
.26413 .19264 L
.30527 .25379 L
.34489 .31332 L
.383 .36365 L
.40425 .38708 L
.42356 .40508 L
.44388 .42056 L
.46261 .43177 L
.48179 .44037 L
.4919 .44381 L
.50259 .44671 L
.51203 .44865 L
.51723 .4495 L
.52216 .45017 L
.52674 .45066 L
Mistroke
.53173 .45108 L
.53393 .45122 L
.53627 .45135 L
.53828 .45144 L
.54048 .45151 L
.54183 .45155 L
.54309 .45157 L
.54379 .45158 L
.54443 .45159 L
.54516 .4516 L
.54585 .4516 L
.54708 .4516 L
.54822 .4516 L
.54947 .45159 L
.5501 .45158 L
.55079 .45157 L
.55224 .45154 L
.55356 .45151 L
.55654 .45141 L
.55917 .45129 L
.56193 .45114 L
.57158 .45038 L
.57704 .44981 L
.58211 .4492 L
.60261 .44596 L
.62121 .44212 L
.66124 .43159 L
.69976 .4192 L
.74073 .40425 L
.78019 .38869 L
.81813 .37332 L
.85852 .35706 L
.8974 .34155 L
.93873 .32458 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09oooool9o`000?oooooo5Oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`07ooooo`?o0000oooooolBooooo`008Oooool3o`0002;ooooo1?l00009ooooo`;o
o`000_ooool3o`000?oooooo3oooool0027ooooo00?o0000ooooooooool08Oooool01?l0003ooooo
oooooooo000<ooooo`Coo`0000?oooooo`000?ooool0ooooool=ooooo`008Oooool00ol0003ooooo
ooooo`0Pooooo`04o`000?ooooooo`00ool0017ooooo00?oo`00ooooool00000ooooool=ooooo`00
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo003oo`0001Cooooo0_oo00000ol0003ooooo
ooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ool00?ooool05ooo
ool00ooo003o0000o`00003oooooo`[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000
ool00?ooool06Oooool00ooo003oooooo`00003oooooo`Wooooo000Qooooo`03o`000?oooooooooo
01cooooo00?o0000ool00?ooool06oooool00ooo003oooooo`00003oooooo`Sooooo000Qooooo`?o
00006oooool00ol0003oo`00ooooo`0Mooooo`03ool00?l0003ooooo0?oooooo1oooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oo`00ooooo`0Oooooo`03ool00?l0003ooooo0?oooooo
1_ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Qooooo`03o`000?oo
oooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0S
ooooo`03o`000?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool06?ooool00ooo
003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo0Oooool0027ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo
000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`3oooooo`008Oooool3o`0001Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02_ooooo00?oo`00o`00
0?ooool0o_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0/ooooo`03
ool00?oooooo00000?kooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
;_ooool00ooo003oooooo`00003mooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02oooooo00?oo`00ooooool00000o?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0aooooo`03ool00?oooooo00000?_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Booooo`03ool00?oooooooooo037ooooo00?oo`00ooooool00000noooool000Go00000_oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo
00?oo`00ooooooooool0<oooool00ooo003oooooo`00003jooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo03Gooooo00?oo`00ooooool00000nOooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo03Gooooo00?oo`00ooooool00000nOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`0gooooo`03ool00?oooooo00000?Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0>Oooool00ooo003oooooo`00003gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0>Oooool01?oo003o
ooooooooool0003fooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03_o
oooo00?oo`00ooooool00000m_ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oo`00
ooooo`0mooooo`03ool00?oooooo00000?Gooooo000Qooooo`?o00003?ooool00ooo003ooooooooo
o`10ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00
ooooooooool0@Oooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;oooo
o`03ool00?oooooooooo04;ooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`14ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`3_ooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0kooo
ool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo0>kooooo000Qooooo`?o00002?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
0>gooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool00ooo003o
0000ooooo`3^ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo
00?oo`00ooooool00000k_ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooo00000>gooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Boooool01?oo003oooooooooool0003/ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04gooooo00?oo`00ooooool00000k?ooool0027ooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1=ooooo`04ool00?ooooooooooo`000>_ooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Coooool01?oo003oooooooooool0003Z
ooooo`008Oooool3o`0000Cooooo00?oo`00ooooooooool0D?ooool00ooo003oooooo`00003Zoooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00Coo`00
oooooooooooo0000=Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04ool00?ooooooooooo`0003Ko
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`04ooooo`04ool00?ooooooooooo`0003Gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0
027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`05ooooo`04ool00?ooooooooooo`0003Gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?o
V9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0h
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo
00Coo`00oooooooooooo0000=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`06
o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool02_ooool01?oo003oooooooooool0000cooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000gooooo00?o0000ooooooooool0;_ooool00omEEEGoIVIVo`00000ooooo
o`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0
027ooooo00Co0000ooooooooooooo`00Goooool00ol0003oooooooooo`3Qooooo`008Oooool01?l0
003oooooo`000?oo001Pooooo`03o`000?oooooooooo0>3ooooo000Qooooo`04o`000?oooooo0000
ool0063ooooo00?o0000ooooooooool0h?ooool0027ooooo0_l000000ooo003oooooooooo`1Poooo
o`03o`000?oooooooooo0=Gooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Tooooo`03
o`000?oooooooooo0=Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`00
037o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool01Ooo003ooooooooooooooooo000000kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0ooo00000ooooooo0000ooooo`0B
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00Coo`00
oooooooooooo00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oo`00ool00004ooooo`03o`000?oooooooooo017ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0H_ooool01Ooo003ooooooooo
oooooooo00000;Kooooo0_l00002ool001Wooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0Hoooool01Ooo003ooooooooooooooooo00000;7ooooo0ol00003ool002Gooooo
000Qooooo`03o`000?oooooooooo06Cooooo00Goo`00ooooooooooooooooo`00002]ooooo`?o0000
0_ooool00ooo003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1Uooooo`05ool00?oo
ooooooooooooool00000ZOooool3o`0002kooooo000Qooooo`03o`000?oooooooooo06Gooooo00Go
o`00ooooooooooooooooo`00002Vooooo`?o0000<Oooool0027ooooo0ol0001Vooooo`05ool00?oo
ooooooooooooool00000XOooool4o`0003Cooooo000Qooooo`03o`000?oooooooooo06Oooooo00Go
o`00ooooooooooooooooo`00002Looooo`Co00001?ooool2ool003;ooooo000Qooooo`03o`000?oo
oooooooo06Sooooo00Goo`00ooooooooooooooooo`00002Gooooo`Co00001oooool00ooo003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool0TOooool3o`0000Wooooo0_oo000eooooo`008Oooool00ol0003oooooooooo`1Y
ooooo`05ool00?ooooooooooooooool00000T?ooool3o`0000Wooooo0ooo000gooooo`008Oooool0
0ol0003oooooooooo`1Zooooo`05ool00?ooooooooooooooool00000S?ooool3o`0000Wooooo0ooo
000jooooo`008Oooool00ol0003oooooooooo`1[ooooo`05ool00?ooooooooooooooool00000R?oo
ool3o`0000Wooooo0ooo000mooooo`008Oooool3o`00073ooooo00?o0000ooooooooool0POooool4
o`0000[ooooo0_oo0010ooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
07gooooo0ol0001@ooooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07Wo
oooo0ol0001Cooooo`008Oooool00ol0003oooooooooo`1cooooo`;o0000M_ooool3o`0005Kooooo
000Qooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Koooool4o`0000cooooo0_oo
001;ooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo06_ooooo0ol0000=
ooooo`?oo`00COooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1Woooo
o`?o00003_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo07;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`1Sooooo`?o00003_ooool3ool005;ooooo000Qooooo`?o0000
L_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo0ol0000?ooooo`;oo`00
EOooool0027ooooo00?o0000ooooooooool0Loooool00ooo003oooooooooo`04ooooo`;o0000G?oo
ool3o`00013ooooo0_oo001Gooooo`008Oooool00ol0003oooooooooo`1dooooo`;oo`001_ooool0
0ol0003oooooooooo`1Fooooo`?o00004_ooool00ooo003oooooooooo`1Gooooo`008Oooool00ol0
003oooooooooo`1fooooo`03ool00?oooooooooo00Cooooo0_l0001Cooooo`?o0000Koooool0027o
oooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo04go
oooo0ol0001booooo`008Oooool00ol0003oooooooooo`1hooooo`03ool00?oooooooooo00Gooooo
0_l0001:ooooo`?o0000MOooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooooooo
o`06ooooo`;o0000AOooool3o`0001;ooooo0_oo001Tooooo`008Oooool3o`0007[ooooo00?oo`00
ooooooooool01oooool2o`00043ooooo0ol0000Cooooo`;oo`00I_ooool0027ooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`08ooooo`;o0000>_ooool4o`0001?ooooo0ooo001Xoooo
o`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo00Wooooo0_l0000cooooo`Go
00005Oooool2ool006_ooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0
2_ooool2o`0002gooooo1?l0000Hooooo`;oo`00KOooool0027ooooo00?o0000ooooooooool0S?oo
ool3o`0002Kooooo1?l0000Iooooo`?oo`00Koooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
Soooool3o`0001gooooo1_l0000Looooo`03ool00?oooooooooo073ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`2Booooo`Oo00004Oooool5o`0009Gooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`02ooooo`?o0000VOoooolAo`0009[ooooo0007ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0<Gooooo
0_oo001mooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo08Kooooo0ooo000iooooo`?oo`00Ooooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ROooool3ool003;ooooo1?oo0022ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2<ooooo`?oo`00:oooool4ool008Ko
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooooooo
ool0Soooool4ool002Cooooo0ooo002:ooooo`008Oooool00ol0003oooooooooo`2Cooooo`;oo`00
[oooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`0?ooooo`Ooo`00U_oo
ool0027ooooo0ol0002Mooooo`[oo`00WOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3
o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004ooo
ool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xooo
ool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool0
2oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGo
V9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02oooo
o`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0
003ok^k^ooooo`1kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMoooo
o`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001nooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03
ojVYZOmEEEGooooo07_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb
<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool0
0ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooo
oooo07[ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04oooo
o`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0E
ooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool0N_ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo
07[ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b07_ooooo002Fooooo`03o`000?oo
oooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ
8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000cooooo1Ol0001koooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25154 L
.10458 .19627 L
.12507 .17427 L
.14415 .15756 L
.16254 .14545 L
.17284 .14055 L
.18221 .13731 L
.18704 .13611 L
.18969 .1356 L
.19216 .1352 L
.19427 .13493 L
.19654 .13471 L
.19783 .13462 L
.19905 .13455 L
.20015 .13451 L
.20135 .13448 L
.20203 .13448 L
.20276 .13448 L
.20345 .13449 L
.20409 .1345 L
.2053 .13454 L
.20657 .13461 L
.20794 .13471 L
.20922 .13482 L
.21213 .13517 L
.21466 .13557 L
.21696 .13602 L
.22214 .1373 L
.22694 .13883 L
.23205 .14082 L
.24122 .1453 L
.26198 .15973 L
.28145 .1783 L
.29973 .1997 L
.33842 .25468 L
.37956 .32064 L
.41919 .38294 L
.45729 .43548 L
.47854 .46022 L
.49785 .47952 L
.51817 .49647 L
.5369 .50904 L
.55608 .51896 L
.56619 .52302 L
.57688 .52648 L
.58632 .52882 L
.59152 .52985 L
.59646 .53064 L
.60103 .53123 L
Mistroke
.60345 .53148 L
.60603 .53171 L
.60841 .53188 L
.61056 .532 L
.6116 .53205 L
.61273 .53209 L
.61378 .53212 L
.61477 .53215 L
.61602 .53217 L
.61715 .53218 L
.61837 .53219 L
.61906 .53219 L
.6197 .53218 L
.62076 .53217 L
.62193 .53215 L
.62315 .53211 L
.6243 .53208 L
.62693 .53196 L
.62933 .53181 L
.63475 .53136 L
.63966 .5308 L
.64502 .53003 L
.65582 .52799 L
.67547 .52274 L
.69644 .51513 L
.73799 .49483 L
.77802 .47002 L
.81654 .44253 L
.85751 .41047 L
.89697 .37769 L
.93491 .34508 L
.9753 .3098 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25939 L
.10458 .20641 L
.12507 .18486 L
.14415 .16869 L
.1536 .1623 L
.16254 .15733 L
.16748 .15505 L
.17284 .15295 L
.17735 .15149 L
.18221 .15025 L
.18475 .14973 L
.18708 .14934 L
.18945 .14902 L
.19165 .1488 L
.19288 .14871 L
.1942 .14863 L
.19495 .1486 L
.19566 .14857 L
.19629 .14856 L
.19698 .14855 L
.19826 .14855 L
.19891 .14856 L
.19962 .14857 L
.20087 .14862 L
.20205 .14869 L
.20335 .14878 L
.20477 .14891 L
.20735 .14923 L
.20987 .14962 L
.21219 .15007 L
.21747 .15137 L
.22307 .15318 L
.23244 .15718 L
.24255 .16282 L
.26083 .17632 L
.28087 .19559 L
.30197 .22019 L
.34007 .27298 L
.38063 .33542 L
.41968 .39537 L
.46118 .45293 L
.50116 .49799 L
.51948 .51445 L
.53963 .52926 L
.5595 .54042 L
.57037 .54508 L
.58054 .54852 L
.58552 .54989 L
.59095 .55114 L
Mistroke
.59574 .55205 L
.60083 .55281 L
.60343 .55312 L
.60588 .55336 L
.60826 .55355 L
.61045 .55369 L
.61254 .55378 L
.61359 .55382 L
.61474 .55385 L
.61589 .55387 L
.61713 .55388 L
.6183 .55387 L
.61937 .55386 L
.62055 .55384 L
.62166 .55381 L
.62288 .55377 L
.62419 .55371 L
.62686 .55355 L
.62931 .55336 L
.63378 .5529 L
.63849 .55226 L
.64842 .55043 L
.65927 .54769 L
.67892 .54092 L
.69988 .5314 L
.74143 .5068 L
.78146 .47775 L
.81998 .44657 L
.86095 .41136 L
.90041 .37647 L
.93835 .34268 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo033ooooo2ol0003oooooo`[o
oooo000Qooooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`?o0000ooooool7ooooo`008Ooo
ool3o`0002_ooooo0ol0000@ooooo`?o0000ooooool4ooooo`008Oooool00ol0003oooooooooo`0X
ooooo`?o00005_ooool2o`000?oooooo0_ooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`07ooooo`Goo`003Oooool00ol0003oooooooooo`3nooooo`008Oooool00ol0003o
ooooooooo`0Uooooo`;o00001_ooool4ool001?ooooo0_l0003nooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00?ooooo0ooo000Iooooo`03o`000?oooooooooo0?_ooooo
000Qooooo`03o`000?oooooooooo02;ooooo0_l00004ooooo`;oo`005Oooool2ool000Kooooo00?o
0000ooooooooool0n_ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02
ooooo`;oo`006Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo0?Wooooo000Qoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool2ool000Gooooo00?o0000oooo
ooooool0n?ooool0027ooooo0ol0000Oooooo`03o`000?oooooooooo02;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`3gooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Cooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`3fooooo`008Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`3eooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Oooooo0_oo0004ooooo`03o`000?oooooooooo0?Cooooo000Qooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo
0??ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01_ooooo00Co0000ooooooooooooo`00:ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0?;ooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooool002gooooo00?oo`00ooooooooool00_ooool00ol0003ooooo
ooooo`3aooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o00006Oooool01?l0003ooooooooooooo000_ooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool0l?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06?ooool01?l0003ooooooooooooo000foooo
o`03o`000?oooooooooo0>oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool01?l0003ooooooooooooo
000hooooo`03o`000?oooooooooo0>kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo0000>_oo
ool00ol0003oooooooooo`3]ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?ooooooo`0003_ooooo00?o
0000ooooooooool0kOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?ooooooo`0003gooooo00?o0000ooooooooool0k?oo
ool0027ooooo00?o0000ooooooooool05?ooool01?l0003ooooooooooooo000nooooo`03o`000?oo
oooooooo0>_ooooo000Qooooo`03o`000?oooooooooo01?ooooo00Co0000ooooooooooooo`00?ooo
ool00ol0003oooooooooo`3[ooooo`008Oooool3o`0001;ooooo00Co0000ooooooooooooo`00?Ooo
ool01Ooo003ooooooooooooooooo00000>cooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000oooooooo0000?_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Wooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo0000@?ooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo0>Sooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0@Oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Sooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03
o`000?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
AOooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo0>Kooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0A_ooool01Ooo003ooooooooooooooooo00000>Sooooo
000Qooooo`?o00003Oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool0iOooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`19
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0i?ooool0027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo00;ooooo00?o0000oooo
ooooool0hoooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooool0001<ooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool0
2Oooool01?l0003ooooooooooooo001=ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool0h_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooool0001?ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool0hOooool0027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooool0001Aooooo`05ool00?ooooooooooooooool00000hoooool0027ooooo00?o
0000ooooooooool01oooool00ol0003oooooool0001Gooooo`03o`000?oooooooooo0>3ooooo000Q
ooooo`?o00001oooool00ol0003oooooool0001Gooooo`03o`000?oooooooooo0>3ooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000oooooooo0000=?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ol0003ooooooooo
o`0[ooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000oooooooo0000=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?ooooooo`0003Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?ooooooo`0003Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03o`000?ooooooo`0003Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oooooool0000gooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00002oooo
o`03o`000?ooooooo`0003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo017ooooo00Coo`00oooooooooooo0000;?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo
000Qooooo`07o`000?ooooooooooooooool0003oooooool0000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`00013ooooo00Goo`00ooooooooooooooooo`00000Yooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool01Ol0003ooooooooooooooooo0000067ooooo00Goo`00oooooooooooooooo
o`00003Looooo`008Oooool01?l0003oooooooooool0001Sooooo`04ool00?ooooooooooo`000=co
oooo000Qooooo`03o`000?oooooo000006Cooooo00Goo`00ooooooooooooooooo`00003Kooooo`00
8Oooool00ol0003oooooo`00001Uooooo`04ool00?ooooooooooo`000=7ooooo0_l00002ooooo`;o
00001?ooool0027ooooo0_l0001Wooooo`04ool00?ooooooooooo`000=3ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`006_oooomao`000003ool00?l0003o00000;go000000?oo`00o`00
0?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000oooooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o0000
01?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool01?l0
003ooooooooooooo0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo00004ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooo00000;Oooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`1Yooooo`04ool00?ooooooooooo`000;Gooooo00?o0000ool00?ooool07ooo
ool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooo`00002dooooo`03o`000?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooool00000/_ooool00ol0
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0:ko
oooo00?o0000ooooooooool08_ooool0027ooooo0ol0001^ooooo`03o`000?oooooooooo0:gooooo
00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`2[ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool0ZOooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`1`oooo
o`03o`000?oooooooooo0:Oooooo0_oo000Xooooo`008Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo0:Gooooo00?oo`00o`000?ooool0:?ooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo02Wooooo000Qooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooooooool0XOooool00ooo003oooooooooo`0Zooooo`008Oooool3
o`00077ooooo00?oo`00ooooool00000X_ooool00ooo003oooooooooo`0[ooooo`008Oooool00ol0
003oooooooooo`1aooooo`04ool00?ooooooooooo`0009oooooo0_oo000^ooooo`008Oooool00ol0
003oooooooooo`1booooo`04ool00?ooooooooooo`0009gooooo00?oo`00o`000?ooool0;_ooool0
027ooooo00?o0000ooooooooool0Loooool00ooo003oooooo`00002Looooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo07?ooooo00Coo`00oooooooooooo0000V_ooool00ooo
003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`1dooooo`04ool00?ooooooooooo`00
09Sooooo00?oo`00ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0MOooool00ooo003o
ooooo`00002Gooooo`03ool00?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo07Gooooo
00Coo`00oooooooooooo0000U?ooool2o`0003Gooooo000Qooooo`?o0000M_ooool01?oo003ooooo
ooooool0002Booooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo07Oooooo
00?oo`00ooooool00000TOooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003ooooooooo
o`1gooooo`04ool00?ooooooooooo`0008oooooo00?o0000ooooooooool0=oooool0027ooooo00?o
0000ooooooooool0N?ooool01?oo003oooooooooool0002=ooooo`03o`000?oooooooooo03Sooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooool00000Roooool2o`0003_ooooo000Q
ooooo`03o`000?oooooooooo07Wooooo00Coo`00oooooooooooo0000ROooool00ol0003ooooooooo
o`0kooooo`008Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08Gooooo00?o0000
ool00?oo0000??ooool0027ooooo0ol0001nooooo`03o`000?oooooooooo08?ooooo00?o0000ool0
0?ooool0?Oooool0027ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`22ooooo`03
o`000?oo003ooooo03kooooo000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
Ooooool00ol0003oo`00ool00010ooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo07gooooo00?o0000ool00?ooool0@Oooool0027ooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`1looooo`03o`000?oo003ooooo04;ooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo087ooooo00?o0000ooooooooool0NOooool2o`000003ool00?oooooooooo04;ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo0000AOoo
ool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
0020ooooo`04ool00?ooooooooooo`0007Oooooo00?o0000oooooooo0000A_ooool000Oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
P?ooool01?oo003oooooooooool0001fooooo`03o`000?ooooooo`0004Oooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0POooool01?oo003oooooooooool0001cooooo`;o000000?oooooool00?ooool0Aoooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0P_ooool01?oo003oooooooooool0001aooooo`03o`000?oooooooooo04[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08?ooooo00?oo`00ooooool00000L?ooool00ol0003oooooooooo`1;ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08?ooooo00Co
o`00oooooooooooo0000KOooool2o`0004kooooo000Qooooo`03o`000?oooooooooo08Cooooo00Co
o`00oooooooooooo0000Joooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0003ooooooooo
o`25ooooo`04ool00?ooooooooooo`0006Wooooo00?o0000ooooooooool0Coooool0027ooooo0ol0
0026ooooo`03ool00?oooooo000006Oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`26
ooooo`04ool00?ooooooooooo`0006Gooooo00?o0000ooooooooool00_oo001@ooooo`008Oooool0
0ol0003oooooooooo`27ooooo`04ool00?ooooooooooo`0006?ooooo00Co0000ooooooooooooo`00
D_ooool0027ooooo00?o0000ooooooooool0R?ooool01?oo003oooooooooool0001Pooooo`;o0000
0_ooool00ooo003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`29ooooo`04ool00?oo
ooooooooo`0005kooooo00?o0000ooooooooool00_oo001Dooooo`008Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo05[ooooo00Co0000ooooooooooooo`00E_ooool0027ooooo00?o
0000ooooooooool0S_ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool00ooo003ooooooooo
o`1Eooooo`008Oooool3o`0008oooooo00?o0000ooooooooool0E?ooool2o`0000?ooooo00?oo`00
ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1Aoooo
o`;o00000oooool2ool005Wooooo000Qooooo`03o`000?oooooooooo097ooooo0_l0001?ooooo`;o
00001?ooool00ooo003oooooooooo`1Iooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Jooooo`008Ooo
ool00ol0003oooooooooo`2Dooooo`;o0000BOooool2o`0006?ooooo000Qooooo`03o`000?oooooo
oooo097ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`14ooooo`;o0000IOooool0
027ooooo00?o0000ooooooooool0TOooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
047ooooo0_l0001Wooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo00?o
oooo0_l0000oooooo`;o0000JOooool0027ooooo0ol0002Cooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool0>_ooool2o`0006_ooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o
o`00ooooooooool01?ooool2o`0003Sooooo0_l0001]ooooo`008Oooool00ol0003oooooooooo`2E
ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`05
ooooo`?oo`00IOooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`05oooo
o`;o0000<_ooool2o`0000Oooooo00?oo`00ooooooooool0I_ooool0027ooooo00?o0000oooooooo
ool0Uoooool00ooo003oooooooooo`06ooooo`;o0000;_ooool2o`0000Oooooo0_oo001Yooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`;oo`002?ooool2o`0002[ooooo0_l00007ooooo`;oo`00
Joooool0027ooooo00?o0000ooooooooool0V_ooool00ooo003oooooooooo`07ooooo`?o00009?oo
ool3o`0000Sooooo00?oo`00ooooooooool0Joooool0027ooooo0ol0002Kooooo`03ool00?oooooo
oooo00Wooooo0ol0000Nooooo`?o00002Oooool2ool006kooooo000Qooooo`03o`000?oooooooooo
09cooooo00?oo`00ooooooooool02oooool3o`0001Sooooo0ol0000:ooooo`;oo`00L?ooool0027o
oooo00?o0000ooooooooool0[Oooool3o`0000oooooo1_l0000<ooooo`03ool00?oooooooooo073o
oooo000Qooooo`03o`000?oooooooooo0;3ooooo3ol0000Aooooo`03ool00?oooooooooo077ooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Vooooo`;oo`00W?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2Xooooo`?oo`006_ooool2ool007gooooo000Jooooo`03o`000?oooooooooo00Cooooo
0ol0002[ooooo`;oo`005Oooool3ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0[Oooool2ool000kooooo1Ooo0022ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;Oooooo1_oo0027ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Goooo
o`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03
omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGo
IVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co
^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool0
0omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5Oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0
003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnH
V9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo07Co
oooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onH
V9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0Loooool0
07_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oo
oooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko0000
1Oooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`00
0?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMg
MomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03
o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o
0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03
o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00go
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003ooooo
ooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[Zj
oooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0:ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003o
ooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o
0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000cooooo1Ol0
0004ooooo`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28891 L
.10458 .26589 L
.14415 .24424 L
.18221 .22597 L
.20178 .21869 L
.21274 .21551 L
.21758 .21435 L
.22272 .21328 L
.22745 .21246 L
.23267 .21174 L
.23496 .21149 L
.23742 .21127 L
.23974 .2111 L
.24186 .21099 L
.24314 .21093 L
.24384 .21091 L
.24451 .21089 L
.24579 .21087 L
.24696 .21086 L
.24763 .21085 L
.24835 .21086 L
.24963 .21087 L
.25034 .21089 L
.25101 .21091 L
.25252 .21096 L
.25383 .21102 L
.25508 .2111 L
.25741 .21127 L
.25992 .21151 L
.26265 .21183 L
.26749 .21257 L
.27205 .21346 L
.28242 .21619 L
.29253 .21984 L
.30343 .22487 L
.32347 .23711 L
.34457 .25411 L
.38268 .29454 L
.42324 .34795 L
.46228 .40387 L
.50378 .46112 L
.54376 .5082 L
.58223 .54229 L
.6021 .55497 L
.61225 .5601 L
.62315 .5646 L
.63338 .56787 L
.64272 .57007 L
.64722 .57085 L
Mistroke
.64959 .5712 L
.65212 .57152 L
.65455 .57177 L
.65674 .57196 L
.65896 .5721 L
.66104 .5722 L
.6622 .57224 L
.66345 .57228 L
.66463 .57229 L
.66571 .5723 L
.66697 .57229 L
.66768 .57229 L
.66834 .57227 L
.66954 .57224 L
.67082 .5722 L
.67205 .57214 L
.67336 .57207 L
.67574 .5719 L
.67856 .57164 L
.68115 .57135 L
.69016 .56992 L
.69469 .56897 L
.69964 .56775 L
.71929 .56114 L
.74025 .55114 L
.7818 .52332 L
.82184 .48811 L
.86035 .44824 L
.90132 .40124 L
.94078 .35321 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29399 L
.10458 .28043 L
.14415 .26499 L
.18221 .249 L
.20342 .24122 L
.21345 .23817 L
.22272 .23583 L
.23233 .23397 L
.23739 .23324 L
.23998 .23294 L
.24276 .23267 L
.24519 .23249 L
.24742 .23236 L
.24849 .23231 L
.24965 .23227 L
.25075 .23224 L
.25178 .23222 L
.25308 .23222 L
.2543 .23222 L
.2554 .23223 L
.25659 .23226 L
.25788 .23231 L
.25925 .23237 L
.26171 .23252 L
.26426 .23274 L
.26667 .23299 L
.27119 .23362 L
.27605 .23451 L
.28135 .23573 L
.29087 .23861 L
.29968 .24206 L
.31835 .25192 L
.33895 .26672 L
.37915 .30621 L
.41784 .3541 L
.45898 .40995 L
.4986 .46246 L
.53671 .50676 L
.55796 .52742 L
.57727 .5432 L
.59736 .55635 L
.61632 .5656 L
.62604 .56914 L
.63633 .572 L
.64512 .57373 L
.65011 .57442 L
.65237 .57466 L
.65478 .57488 L
.65614 .57498 L
Mistroke
.65737 .57506 L
.65862 .57512 L
.65976 .57517 L
.66111 .57522 L
.66181 .57523 L
.66256 .57525 L
.66381 .57526 L
.66453 .57526 L
.66519 .57526 L
.66647 .57525 L
.66769 .57522 L
.66878 .57519 L
.66996 .57514 L
.67262 .575 L
.67507 .57482 L
.67935 .57439 L
.68406 .57375 L
.69361 .57194 L
.70373 .56929 L
.71299 .56623 L
.73386 .5572 L
.75282 .54659 L
.77354 .5326 L
.81415 .49869 L
.85325 .45911 L
.8948 .41138 L
.93483 .36191 L
.97335 .31271 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0koooo
oa3o0000nOooool0027ooooo0ol0000gooooo`Co00004?ooool5o`000?Cooooo000Qooooo`03o`00
0?oooooooooo03Cooooo0ol0000Iooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oo
oooooooo037ooooo0ol0000Mooooo`?o0000l?ooool0027ooooo00?o0000ooooooooool0;_ooool3
o`0002?ooooo0ol0003]ooooo`008Oooool00ol0003oooooooooo`0/ooooo`;o0000:Oooool00ol0
003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`0Zooooo`;o00005oooool6ool000oo
oooo0_l0003Zooooo`008Oooool00ol0003oooooooooo`0Xooooo`;o00005oooool2ool000Gooooo
2Ooo0009ooooo`03o`000?oooooooooo0>Oooooo000Qooooo`?o00009_ooool2o`0002Wooooo00?o
o`00ooooooooool01oooool2o`000>Oooooo000Qooooo`03o`000?oooooooooo02Cooooo0_l0000>
ooooo`?oo`009_ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003oooooooooo`0Roooo
o`;o00003_ooool2ool002[ooooo0_l0003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o
00003_ooool2ool002kooooo00?o0000ooooooooool0hOooool0027ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0<ooooo`;oo`00<Oooool00ol0003oooooooooo`3Pooooo`008Ooo
ool00ol0003oooooooooo`0Mooooo`;o00003?ooool3ool002cooooo0_oo0006ooooo`03o`000?oo
oooooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo0_l0000<ooooo`;oo`00<Oooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0booooo`;oo`001?ooool00ol0
003oooooooooo`3Nooooo`008Oooool3o`0001Sooooo0_l00015ooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool0gOooool0027ooooo00?o0000ooooooooool05_ooool2o`0002Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00gooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`Co000000?o410@oooo
ooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo01Cooooo0_l0000Woooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03Oooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@06oooool0027ooooo00?o0000ooooooooool04_ooool2o`0000Sooooo0ooo000N
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0=ooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`0@ooooo`;o00001oooool3ool0027ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00oooooo00?oo`00ooooooooool00_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8boooo
o`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00kooooo0_l00006
ooooo`?oo`009?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Aooooo`05ool00?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo00cooooo0_l00005ooooo`?oo`009oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool01Ooo003ooooooooooooooooo
000002Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000:ooooo`;o00001?ooool3ool0
02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01Gooooo00Goo`00
ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o
0000ooooooooool02?ooool2o`0000Gooooo00?oo`00ooooooooool0:oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l0000Iooooo`03o`000?oooooooooo02;ooooo00?oEEEEofIVI_l00000
?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_o
oooo000Qooooo`03o`000?oooooooooo00Kooooo0_l0001Tooooo`03o`000?oooooooooo0=Gooooo
000Qooooo`03o`000?oooooooooo00Cooooo0_l0001Wooooo`03o`000?oooooooooo0=Cooooo000Q
ooooo`03o`000?oooooooooo00;ooooo0_l00002ool006Oooooo00?o0000ooooooooool0e?ooool0
027ooooo00Co0000oooooooooooo00000ooo001Zooooo`03o`000?oooooooooo0<Wooooo0_l00002
ooooo`;o00001?ooool0027ooooo00Co0000ool00?oo003oo`00K_ooool00ol0003oooooooooo`38
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`00
003oo`0002So000000?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ooo003oooooo`00
0003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`04ool00?ooooooooooo`0000;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?oo`00o`000?ooool04_ooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003ooooo
ooooo`1_ooooo`04ool00?ooooooooooo`000;;ooooo00?o0000ool00?ooool04_ooool2o`0000;o
oooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1`ooooo`04ool00?ooooooooooo`000;3o
oooo00?o0000ool00?ooool07Oooool0027ooooo00?o0000ooooooooool0LOooool01?oo003ooooo
ooooool0002^ooooo`03o`000?oo003ooooo01kooooo000Qooooo`03o`000?oooooooooo07;ooooo
00?oo`00ooooool00000[_ooool00ooo003oooooooooo`0Nooooo`008Oooool00ol0003ooooooooo
o`1cooooo`03ool00?oooooo00000:cooooo00?oo`00ooooooooool07oooool0027ooooo0ol0001c
ooooo`04ool00?ooooooooooo`000:[ooooo00?oo`00ooooooooool08?ooool0027ooooo00?o0000
ooooooooool0M?ooool01?oo003oooooooooool0002Xooooo`03o`000?oooooooooo027ooooo000Q
ooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooool00000Z?ooool00ol0003oooooooooo`0Q
ooooo`008Oooool00ol0003oooooooooo`1fooooo`03ool00?oooooo00000:Kooooo00?o0000oooo
ooooool08_ooool0027ooooo00?o0000ooooooooool0Moooool00ooo003oooooo`00002Tooooo`03
o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooool00000
X_ooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1jooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool09Oooool0027ooooo0ol0001kooooo`03o`000?oooooo
oooo09kooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0O?ooool00ol0
003oooooooooo`2Kooooo`03ool00?l0003ooooo02Oooooo000Qooooo`03o`000?oooooooooo07co
oooo00?o0000ooooooooool0Voooool00ooo003oooooooooo`0Wooooo`008Oooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo09Wooooo00?o0000ool00?ooool0:?ooool0027ooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`2Gooooo`03o`000?oo003ooooo02Wooooo000Q
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0UOooool00ol0003oo`00ooooo`0Z
ooooo`008Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo09Cooooo00?o0000ool0
0?ooool0:oooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003oooooo`00002Dooooo`03
o`000?oo003ooooo02cooooo000Qooooo`?o0000O_ooool01?oo003oooooooooool0002Cooooo`03
ool00?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo07oooooo00?oo`00ooooool00000
T_ooool00ol0003oo`00ooooo`0]ooooo`008Oooool00ol0003oooooooooo`20ooooo`03ool00?oo
oooo0000093ooooo00?o0000ool00?ooool0;_ooool0027ooooo00?o0000ooooooooool0P?ooool0
1?oo003oooooooooool0002>ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oooooo
oooo087ooooo00Coo`00oooooooooooo0000S?ooool00ol0003oo`00ooooo`0`ooooo`008Oooool0
0ol0003oooooooooo`22ooooo`03ool00?oooooo000008_ooooo00?o0000ool00?ooool0<Oooool0
027ooooo00?o0000ooooooooool0Poooool00ooo003oooooo`000029ooooo`03o`000?oooooooooo
03;ooooo000Qooooo`?o0000Poooool01?oo003oooooooooool00028ooooo`03o`000?oooooooooo
03;ooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00ooooool00000Qoooool00ol0003o
ooooooooo`0cooooo`008Oooool00ol0003oooooooooo`25ooooo`03ool00?oooooo000008Gooooo
00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0QOooool01?oo003ooooooooo
ool00023ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo08Kooooo00Co
o`00oooooooooooo0000POooool00ol0003oooooooooo`0fooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`27ooooo`03ool00?oooooo0000087ooooo00?o0000ooooooooool0=_ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0gooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008_o
oooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`0hooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo07[ooooo00?o0000ool00?ooool0>Oooool000Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0>_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`1gooooo`03ool00?oooooooooo03[ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo00?o0000oooo
ooooool0MOooool00ooo003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0M?ooool00ooo
003oooooooooo`0looooo`008Oooool00ol0003oooooooooo`2>ooooo`03ool00?l0003ooooo07?o
oooo00?oo`00ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0S_ooool00ooo003ooooo
o`00001booooo`03ool00?oooooooooo03kooooo000Qooooo`?o0000Soooool00ooo003o0000oooo
o`1`ooooo`03ool00?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo093ooooo00?oo`00
o`000?ooool0K_ooool00ooo003oooooooooo`10ooooo`008Oooool00ol0003oooooooooo`2Aoooo
o`03ool00?l0003ooooo06cooooo00?oo`00ooooooooool0@Oooool0027ooooo00?o0000oooooooo
ool0T_ooool00ooo003o0000ooooo`1Zooooo`03ool00?oooooooooo04;ooooo000Qooooo`03o`00
0?oooooooooo09;ooooo00?oo`00o`000?ooool0JOooool00ol0003oooooooooo`13ooooo`008Ooo
ool00ol0003oooooooooo`2Cooooo`03ool00?l0003ooooo06Oooooo00?o0000ooooooooool0A?oo
ool0027ooooo00?o0000ooooooooool0U?ooool00ooo003o0000ooooo`1Uooooo`03o`000?oooooo
oooo04Gooooo000Qooooo`?o0000UOooool00ooo003o0000ooooo`1Sooooo`03o`000?oooooooooo
04Kooooo000Qooooo`03o`000?oooooooooo09Kooooo00?oo`00o`000?ooool0HOooool00ol0003o
ooooooooo`17ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03ool00?l0003ooooo05oooooo
00?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool0V?ooool00ooo003o0000oooo
o`1Mooooo`03o`000?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo09[ooooo00?o0000
ooooooooool0FOooool00ol0003oo`00ooooo`1;ooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo05Sooooo00?o0000oooooooo0000C?ooool0027ooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`1Fooooo`03o`000?ooooooo`0004gooooo000Qooooo`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool0E?ooool00ol0003oooooool0001>ooooo`008Ooo
ool3o`0009gooooo00?o0000ooooooooool0D_ooool00ol0003oo`00ool0001?ooooo`008Oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo04oooooo0_l000000ooo003oooooooooo`1?
ooooo`008Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo04gooooo00?o0000oooo
oooo0000D_ooool0027ooooo00?o0000ooooooooool0X?ooool2o`0004cooooo00?o0000oooooooo
0000Doooool0027ooooo00?o0000ooooooooool0Woooool01?oo003oooooooooool0001:ooooo`03
o`000?ooooooo`0005Cooooo000Qooooo`03o`000?oooooooooo0:3ooooo00Coo`00oooooooooooo
0000B?ooool00ol0003oooooool0001Eooooo`008Oooool00ol0003oooooooooo`2Qooooo`04ool0
0?ooooooooooo`0004Kooooo00?o0000oooooooo0000E_ooool0027ooooo0ol0002Rooooo`04ool0
0?ooooooooooo`0004?ooooo0_l000000oooooooo`00ooooo`1Fooooo`008Oooool00ol0003ooooo
ooooo`2Sooooo`03ool00?oooooooooo00;o0000@?ooool00ol0003oooooooooo`1Iooooo`008Ooo
ool00ol0003oooooooooo`2Tooooo`;oo`000_ooool00ol0003oooooooooo`0kooooo`;o0000G?oo
ool0027ooooo00?o0000ooooooooool0Y_ooool01?oo003oooooooooool0000kooooo`03o`000?oo
oooooooo05cooooo000Qooooo`03o`000?oooooooooo0:Oooooo0_oo00000ooooooo0000ooooo`0g
ooooo`;o0000Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0:Wooooo00?oo`00ooooool00000=_ooool00ol0003oooooooooo`1Oooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:[ooooo00Coo`00ooooool0003o0000<oooool00ol0
003oooooool0001Pooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_o
oooo00Coo`00oooooooooooo0000<?ooool2o`000003oooooooo003ooooo063ooooo000Jooooo`03
o`000?oooooooooo00Cooooo0ol0002_ooooo`;o0000;Oooool01?l0003oooooool00?oo001Roooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool0:?ooool2o`0000;oo`00I?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2booooo`;o00009_ooool2o`0000;oo`00I_ooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo027ooooo0_l00002ool006Sooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]?ooool2ool000;o00007Oooool2
o`0000?oo`00J_ooool0027ooooo00?o0000ooooooooool0]_ooool2ool000Co00005_ooool3o`00
00;oo`00KOooool0027ooooo00?o0000ooooooooool0^?ooool01?oo003oooooooooooooool3o`00
017ooooo0_l0001booooo`008Oooool3o`000;Wooooo1_oo0005o`0000Cooooo2?l0001dooooo`00
8Oooool00ol0003oooooooooo`2oooooo`goo`00N?ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Sooooo
00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o
8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001n
ooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo
00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oo
oooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7
QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00ooo
ool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgM
ooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEE
oiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40Noooool007kooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00001kooooo`00O_ooool01?mEEEGoZJVYooooool0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^
k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o0000oooooooo
ool02_ooool01Olb<S;oV9RHoooooonHV9So<S8b07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00Goc<c<o`00
0?l0003o0000olc<c01kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMg
Moooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@401kooooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00[ooooo
00Go0000okZj^_oooooo^[Zjo`00001kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj
^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIV
ogMgMoooool05?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Nooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31688 L
.06244 .32452 L
.08426 .33148 L
.0949 .33416 L
.10458 .33613 L
.11403 .33761 L
.11837 .33814 L
.12297 .3386 L
.1253 .33879 L
.12787 .33897 L
.13024 .33911 L
.1324 .33921 L
.13494 .3393 L
.13635 .33933 L
.137 .33935 L
.13768 .33936 L
.13891 .33937 L
.14005 .33938 L
.14075 .33939 L
.14141 .33938 L
.14264 .33938 L
.1438 .33937 L
.14504 .33935 L
.14622 .33932 L
.14729 .33929 L
.14991 .3392 L
.1524 .33908 L
.15734 .33877 L
.16271 .33831 L
.17231 .33721 L
.18119 .33588 L
.19985 .33229 L
.22045 .32739 L
.26066 .31691 L
.27913 .31259 L
.2896 .31051 L
.29934 .30887 L
.30903 .30759 L
.31446 .30704 L
.31938 .30665 L
.32191 .30649 L
.32459 .30635 L
.32599 .30629 L
.32753 .30624 L
.32893 .3062 L
.33024 .30618 L
.33087 .30617 L
.33156 .30616 L
.33282 .30615 L
Mistroke
.33404 .30615 L
.33518 .30615 L
.33587 .30616 L
.33653 .30617 L
.33775 .30619 L
.33906 .30622 L
.34048 .30626 L
.34287 .30636 L
.34542 .3065 L
.35001 .30684 L
.35548 .30739 L
.36046 .30805 L
.37129 .30995 L
.38154 .31238 L
.40149 .31891 L
.41992 .32704 L
.45924 .3507 L
.49704 .38001 L
.5373 .41497 L
.57604 .4481 L
.59572 .46336 L
.61723 .47806 L
.63803 .48982 L
.65691 .49809 L
.66702 .50151 L
.67655 .50406 L
.68145 .50511 L
.68662 .50603 L
.68932 .50643 L
.69229 .50681 L
.69501 .50709 L
.69752 .50731 L
.70002 .50748 L
.70132 .50755 L
.70275 .50761 L
.70399 .50765 L
.70515 .50768 L
.70638 .5077 L
.70707 .50771 L
.70771 .50771 L
.70883 .5077 L
.70987 .50769 L
.71101 .50767 L
.71223 .50764 L
.71352 .50759 L
.71473 .50753 L
.717 .5074 L
.71954 .5072 L
.72222 .50694 L
.72703 .50635 L
Mistroke
.73221 .50552 L
.73791 .50438 L
.74806 .50179 L
.75733 .49879 L
.77822 .48993 L
.79722 .47949 L
.81795 .46573 L
.85861 .43258 L
.89776 .39464 L
.93936 .35014 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .33179 L
.08255 .3421 L
.0932 .34679 L
.10458 .35113 L
.11531 .3545 L
.12507 .35695 L
.12977 .35791 L
.13488 .35879 L
.13935 .35943 L
.14415 .35997 L
.1467 .3602 L
.14903 .36038 L
.15139 .36052 L
.15359 .36062 L
.15482 .36067 L
.15614 .3607 L
.15689 .36072 L
.1576 .36073 L
.15823 .36074 L
.15892 .36075 L
.16021 .36075 L
.16085 .36075 L
.16156 .36075 L
.16282 .36074 L
.16399 .36071 L
.16529 .36068 L
.16672 .36064 L
.1693 .36052 L
.17181 .36038 L
.17414 .36021 L
.17941 .35974 L
.18502 .35908 L
.19439 .35767 L
.20449 .35574 L
.22277 .35143 L
.26391 .33984 L
.28444 .33432 L
.30353 .33005 L
.31301 .32836 L
.32196 .3271 L
.32691 .32654 L
.33227 .32607 L
.33464 .3259 L
.33715 .32575 L
.3393 .32565 L
.34164 .32556 L
.34295 .32553 L
.34417 .3255 L
.34533 .32548 L
Mistroke
.34657 .32547 L
.34779 .32547 L
.34894 .32547 L
.34997 .32548 L
.35108 .3255 L
.3523 .32553 L
.35365 .32556 L
.35636 .32567 L
.35887 .3258 L
.36122 .32596 L
.36584 .32635 L
.37006 .32681 L
.37953 .32821 L
.38947 .33021 L
.39865 .33256 L
.41943 .33959 L
.43813 .34784 L
.45874 .35884 L
.499 .3848 L
.53774 .41294 L
.57893 .4427 L
.61861 .46777 L
.63861 .47809 L
.65677 .48575 L
.67642 .49196 L
.6816 .49321 L
.68721 .49438 L
.69247 .49529 L
.69738 .49598 L
.70196 .49648 L
.70431 .49668 L
.70687 .49686 L
.70832 .49694 L
.70967 .497 L
.71093 .49705 L
.7116 .49707 L
.71232 .49709 L
.71357 .49712 L
.71473 .49713 L
.71538 .49714 L
.71607 .49714 L
.7173 .49713 L
.71861 .49711 L
.71981 .49709 L
.7212 .49704 L
.7225 .49699 L
.72483 .49687 L
.72735 .4967 L
.73307 .49614 L
.73835 .49543 L
Mistroke
.74803 .49362 L
.75709 .49135 L
.77772 .48409 L
.79799 .47423 L
.81652 .46299 L
.85624 .43249 L
.89446 .39664 L
.93512 .35412 L
.97427 .31115 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Looooo`Go0000fOooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0
003o410@olc<c0Gooooo000Qooooo`04o`000?oo003oo`00o`0000_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool6o`0000Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^
kPGooooo000Qooooo`03o`000?oooooooooo00;oo`0000?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`Co00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo0ol000000ooooooo0000ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool00_ooool2ool000;o0000?oooool4o`0002[ooooo0_l0002_ooooo`03ool00?l0003ooooo01?o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool01?ooool00ooo003ooooo
o`000002o`0003Sooooo1?l0000`ooooo`;o0000[Oooool00ooo003oooooooooo`0Mooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`;oo`000_ooool3o`00037ooooo1?l0000Qooooo`;oo`004ooo
ool2o`000:[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool01oooool2
ool000?ooooo0ol0000Zooooo`Co00006_ooool3ool000[ooooo2_oo000;ooooo`;o0000Yoooool0
0ooo003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`09ooooo`;oo`001?ooool4o`00
02?ooooo0ol0000Iooooo`Goo`005oooool00ooo003oooooooooo`0:ooooo`;o0000Y?ooool00ooo
003oooooooooo`0Pooooo`008Oooool3o`0000_ooooo00?oo`00ooooooooool01Oooool4o`0001_o
oooo1?l0000Hooooo`Coo`00:oooool00ol0003oooooooooo`2Pooooo`03ool00?oooooooooo027o
oooo000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool02?ooool5o`0000oooooo
1ol0000Iooooo`?oo`00<?ooool2o`0009oooooo00?oo`00ooooooooool08_ooool0027ooooo00?o
0000ooooooooool07?ooool?o`0001kooooo0_oo000]ooooo`Coo`001?ooool2o`0009cooooo00?o
o`00ooooooooool08oooool0027ooooo00?o0000ooooooooool0O?ooool3ool000?ooooo00?o0000
ooooooooool0V?ooool00ooo003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1ooooo
o`;oo`000_ooool2o`0009Oooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000oooooooo
ool05_ooool00ooo003oooooooooo`0Uooooo`;oo`00@Oooool01?oo003oooooooooooooool2o`00
09Cooooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool05oooool3ool001oo
oooo1Ooo0014ooooo`;oo`000oooool00ol0003oooooooooo`2@ooooo`03ool00?l0003ooooo02Oo
oooo000Qooooo`?o00006_ooool4ool001Oooooo1?oo001;ooooo`05ool00?ooooooooooooooool0
0000T?ooool00ooo003o0000ooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Nooooo`Soo`00
2_ooool5ool0053ooooo00Goo`00ooooooooooooooooo`00002?ooooo`03o`000?oooooooooo02So
oooo000Qooooo`03o`000?oooooooooo08Kooooo00Goo`00ooooooooooooooooo`00002=ooooo`03
o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo08_ooooo0_l0002:ooooo`03o`00
0?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0008oooooo
0ooo00000ol0003oooooooooo`1mooooo`03ool00?oooooooooo02oooooo000Qooooo`03o`000?oo
oooooooo09;ooooo0_oo001mooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooo
oooo09Cooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0aooooo`008Oooool00ol0
003oooooooooo`2Eooooo`03ool00?l0003ooooo07Oooooo00?oo`00ooooooooool0<_ooool0027o
oooo00?o0000ooooooooool0U_ooool00ooo003o0000ooooo`1eooooo`03ool00?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo09Oooooo0_oo001dooooo`03ool00?oooooooooo03Cooooo
000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00ooooooooool0L?ooool00ooo003ooooooooo
o`0eooooo`008Oooool3o`0009[ooooo00?oo`00o`000?ooool0K_ooool00ooo003oooooooooo`0f
ooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?l0003ooooo06cooooo00?oo`00oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0W?ooool00ooo003o0000ooooo`1Zooooo`03
ool00?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo09kooooo0_l0001Xooooo`03ool0
0?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:;ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0looooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:?ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Tooooo`03o`000?oo003oo`0005cooooo
00?o0000ooooooooool0?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Uooooo`03o`000?ooooooo`0005Wo
oooo0_l00011ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Vooooo`04o`000?ooooooo`00ool005Kooooo00?o0000oooo
ooooool0@Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Yoooool01?l0003ooooooooooooo001Cooooo`;oo`00A?ooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2X
ooooo`03o`000?oooooooooo00;oo`00D?ooool00ooo003o0000ooooo`14ooooo`008Oooool00ol0
003oooooooooo`2Yooooo`05o`000?oooooooooooooooooo0000COooool2ool004Oooooo000Qoooo
o`03o`000?oooooooooo0:[ooooo0_l00002ooooo`;oo`00B_ooool00ooo003o0000ooooo`17oooo
o`008Oooool3o`000:cooooo00Go0000ooooooooooooooooool00018ooooo`03ool00?l0003ooooo
04Sooooo000Qooooo`03o`000?oooooooooo0:gooooo00Go0000ooooooooooooooooool00015oooo
o`;oo`0000?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool0[_ooool01Ol0003o
ooooooooooooooooo`0004?ooooo00?oo`00o`000?ooool0Boooool0027ooooo00?o0000oooooooo
ool0[oooool00ol0003oooooooooo`12ooooo`;oo`0000?o0000ooooooooool0Boooool0027ooooo
00?o0000ooooooooool0/?ooool2o`00047ooooo00?oo`00o`000?l00000C_ooool0027ooooo00?o
0000ooooooooool0/_ooool2o`0003kooooo00?oo`00o`000?ooool0Coooool0027ooooo00?o0000
ooooooooool0]?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04oooooo000Qoooo
o`?o0000]Oooool2o`0000Cooooo0_oo000dooooo`03o`000?oooooooooo053ooooo000Qooooo`03
o`000?oooooooooo0;Oooooo0_l00004ooooo`;oo`00<Oooool00ol0003oooooooooo`1Aooooo`00
8Oooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00?ooooo0_oo000]ooooo`;o0000
E?ooool0027ooooo00?o0000ooooooooool0^_ooool2o`0000Gooooo0_oo000Tooooo`;oo`000ooo
ool2o`0005Kooooo000Qooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool01?ooool4
ool001gooooo0ooo0003ooooo`;o0000F?ooool0027ooooo00?o0000ooooooooool0_Oooool3o`00
00Oooooo0ooo000Gooooo`?oo`001?ooool2o`0005[ooooo000Qooooo`03o`000?oooooooooo0<3o
oooo0ol00007ooooo`03ool00?oooooooooo01;ooooo0_oo0004ooooo`?o0000G?ooool0027ooooo
00?o0000ooooooooool0`oooool3o`0000oooooo2_oo0004ooooo`;o0000Goooool0027ooooo0ol0
0036ooooo`?o00006?ooool2o`00067ooooo000Qooooo`03o`000?oooooooooo0<Wooooo0_l0000A
ooooo`Go0000Hoooool0027ooooo00?o0000ooooooooool0booooolAo`0006Sooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oo
oooo00?oIVIVogMgMoooool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo
00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEE
EOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4
A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009oooo
o`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Go
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07oooo
o`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8b
ooooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`00
0?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03
oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004oooo
o`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooooooo00[ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^
00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9So
oooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003oooooooooo`0:ooooo`05olc<c?l0
003o0000o`000?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRH
V?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo
00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo
1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00[ooooo00Go410@okZj^_oooooo
^[Zjoa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo
00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@
41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_oo
oooo^[Zjo`000004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@o`00
0?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35043 L
.10458 .38922 L
.12507 .40438 L
.14415 .41594 L
.16254 .42461 L
.17277 .42837 L
.18221 .43117 L
.19242 .43349 L
.19781 .43441 L
.20351 .43517 L
.2059 .43542 L
.20846 .43565 L
.21068 .43581 L
.2131 .43595 L
.21456 .43602 L
.21592 .43607 L
.21722 .4361 L
.21795 .43612 L
.21861 .43613 L
.21986 .43614 L
.22056 .43614 L
.22121 .43614 L
.2224 .43614 L
.22365 .43612 L
.22487 .43609 L
.2262 .43605 L
.22861 .43595 L
.23096 .43582 L
.23313 .43567 L
.23806 .43522 L
.24329 .43458 L
.25201 .43318 L
.26163 .43115 L
.28097 .42568 L
.30183 .41796 L
.34297 .39872 L
.38259 .3778 L
.4207 .35825 L
.46126 .34046 L
.48 .33382 L
.50031 .32795 L
.51141 .32538 L
.52165 .3234 L
.53144 .32189 L
.53686 .3212 L
.5418 .32068 L
.54632 .32027 L
.55124 .31992 L
.55394 .31976 L
Mistroke
.55644 .31964 L
.55899 .31954 L
.56138 .31947 L
.56362 .31941 L
.56488 .31939 L
.56603 .31938 L
.56701 .31937 L
.56808 .31936 L
.5692 .31936 L
.57025 .31936 L
.57148 .31937 L
.57264 .31938 L
.57368 .3194 L
.57481 .31942 L
.57735 .31948 L
.57969 .31955 L
.58434 .31974 L
.58934 .32003 L
.59839 .32073 L
.60916 .32184 L
.61901 .32311 L
.65869 .32983 L
.69685 .33714 L
.71814 .34079 L
.73746 .34351 L
.74712 .3446 L
.75758 .34555 L
.76239 .34589 L
.76746 .3462 L
.77213 .34642 L
.77656 .34659 L
.77893 .34665 L
.78018 .34668 L
.78151 .34671 L
.78262 .34672 L
.78385 .34674 L
.78497 .34675 L
.78602 .34676 L
.78726 .34677 L
.78857 .34677 L
.78968 .34676 L
.7909 .34676 L
.79222 .34675 L
.79363 .34673 L
.79496 .34671 L
.79617 .34668 L
.80069 .34656 L
.80324 .34647 L
.80559 .34637 L
.8145 .34585 L
Mistroke
.81916 .3455 L
.82418 .34506 L
.83324 .34409 L
.85387 .34114 L
.87502 .33712 L
.89511 .33251 L
.93333 .32209 L
.97399 .3097 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35913 L
.10458 .40096 L
.12507 .4172 L
.14415 .42998 L
.16371 .44064 L
.18221 .44835 L
.192 .45147 L
.19716 .45283 L
.20263 .45407 L
.20722 .45494 L
.21228 .45573 L
.21689 .45627 L
.2212 .45665 L
.22377 .45681 L
.225 .45686 L
.22616 .45691 L
.22682 .45693 L
.22754 .45695 L
.22879 .45697 L
.22949 .45698 L
.23024 .45699 L
.23088 .45699 L
.23158 .45699 L
.23287 .45698 L
.23404 .45695 L
.23469 .45694 L
.2354 .45692 L
.23668 .45687 L
.23916 .45674 L
.24145 .45659 L
.24572 .4562 L
.25043 .45562 L
.25997 .45396 L
.27007 .45155 L
.27932 .44875 L
.30018 .44057 L
.3398 .41917 L
.37791 .3942 L
.41847 .36697 L
.45751 .34377 L
.47743 .33399 L
.49901 .3253 L
.50912 .32196 L
.51981 .31895 L
.52984 .3166 L
.53899 .31485 L
.54843 .31344 L
.55328 .31285 L
.55857 .31233 L
Mistroke
.56344 .31195 L
.56796 .31167 L
.57228 .31148 L
.5747 .3114 L
.57688 .31135 L
.57809 .31133 L
.57921 .31131 L
.58045 .3113 L
.58177 .31129 L
.58244 .31129 L
.58316 .31129 L
.58447 .31129 L
.58575 .3113 L
.58693 .31131 L
.58803 .31132 L
.58906 .31134 L
.59141 .31139 L
.5937 .31146 L
.59617 .31155 L
.60147 .31179 L
.60704 .31213 L
.617 .3129 L
.63678 .31497 L
.65516 .3173 L
.69426 .32256 L
.71421 .32495 L
.73581 .32705 L
.74594 .32783 L
.75665 .32849 L
.7658 .32893 L
.77061 .32911 L
.77584 .32927 L
.77856 .32933 L
.78107 .32939 L
.78343 .32943 L
.78603 .32946 L
.78835 .32949 L
.78942 .3295 L
.79054 .3295 L
.79174 .32951 L
.79284 .32952 L
.79403 .32952 L
.79533 .32952 L
.796 .32952 L
.79674 .32952 L
.79743 .32951 L
.79807 .32951 L
.79928 .32951 L
.80056 .3295 L
.80322 .32947 L
Mistroke
.80615 .32943 L
.81136 .32934 L
.81623 .32922 L
.82663 .32886 L
.8365 .32839 L
.85503 .32719 L
.87485 .32544 L
.89324 .32333 L
.93239 .31724 L
.97399 .30938 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009Ol0
0004ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo0002ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01Oooool4ool000Co00004oooool01?o^k^ko8B4Qoa0@
4?o^k^h5ooooo`008Oooool00ol0003oo`00ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo1?oo
00000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo2Ooo000=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`;oo`001?l0
0003ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o
0000oooooooo0000Uoooool6ool002Cooooo1Ooo001Eooooo`Co00006oooool2o`0000;ooooo0_l0
0004ooooo`008Oooool01?l0003ooooooooooooo002Cooooo`?oo`001?oooolLo`0000oooooo0_oo
0019ooooo`Coo`000oooool3o`0002Wooooo000Qooooo`05o`000?oooooooooooooooooo0000T?oo
ool2ool000Oo00007?ooool4o`0001Oooooo2?oo000/ooooo`_oo`001?ooool3o`0002cooooo000Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S?ooool00ooo003o0000o`00000W
ooooo`Oo00006?ooool9ool0027ooooo0_oo000<ooooo`?o0000;oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`28ooooo`?o0000<Oooool6o`0002Gooooo3Ooo000Eoooo
o`?o0000<_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo08Cooooo0ol0000jooooo`Ko
0000??ooool5o`0003Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
P?ooool3o`0004?ooooo1_l0000`ooooo`Ko0000>_ooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1looooo`03o`000?oo003oo`0004cooooo1_l0000Tooooo`Ko0000@?oo
ool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1iooooo`03o`000?oo003o
o`0005Cooooo2?l0000Gooooo`Go0000A_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1fooooo`03o`000?oo003oo`0005kooooo5ol0001;ooooo`008Oooool00ol0003o
ooooooooo`09ooooo`;o0000Loooool3o`000003ool00?oooooooooo0<3ooooo000Qooooo`03o`00
0?oooooooooo00Oooooo00Goo`00ooooooooooooooooo`00001`ooooo`;o000000?oooooool00?oo
0000`oooool0027ooooo0ol00008ooooo`05ool00?ooooooooooooooool00000KOooool2o`000003
oooooooo003oo`000<Gooooo000Qooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooo
ooooo`00001Zooooo`;o00000_ooool00ooo003oooooooooo`35ooooo`008Oooool00ol0003ooooo
ooooo`0:ooooo`05ool00?ooooooooooooooool00000Ioooool2o`0000;ooooo0_oo0038ooooo`00
8Oooool00ol0003oooooooooo`0;ooooo`05ool00?ooooooooooooooool00000I?ooool2o`0000?o
oooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool03?ooool01?oo003ooooo
ooooooooool2o`00063ooooo0_l0003@ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool0Foooool2o`000=;ooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`1Hooooo`;o0000e?oo
ool0027ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo05Gooooo0_l0003Fooooo`008Oooool3o`00013ooooo00?oo`00ooooooooool00_ooool00ol0
003oooooooooo`1Booooo`;o0000f?ooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo04oooooo0_l00005ooooo`;oo`00doooool0027ooooo
00?o0000ooooooooool04_ooool00ooo003oooooooooo`02ooooo`;o0000COooool2o`0000Kooooo
00?oo`00ooooooooool0doooool0027ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`18ooooo`;o00001oooool00ooo003oooooooooo`3Dooooo`008Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo04Gooooo0_l00007ooooo`;oo`00eoooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`12ooooo`;o00002?ooool00ooo003oooooooooo`3Goooo
o`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo0_l00008ooooo`;o
o`00f_ooool0027ooooo0ol0000Mooooo`;o0000?Oooool2o`0000Wooooo00?oo`00ooooooooool0
f_ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0gooooo`?o00002Ooo
ool2ool00=gooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo0004ooooo`;o0000=Oooool2
o`0000_ooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo0_l0000<ooooo`03ool00?oooooooooo
0=kooooo000Qooooo`03o`000?oooooooooo01gooooo0_oo0004ooooo`?o0000;Oooool2o`000>oo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool01?ooool3o`00
02Sooooo0_l0003aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08?ooool2ool000Oooooo0_l0000Toooo
o`;o0000loooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo0ol0000Rooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool07Oooool4o`00
0?Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo02?ooooo0_oo0007ooooo`Ko00005Oooool4o`0000kooooo0_oo003Yoooo
o`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool02_ooool2o`00013ooooo0ol0000@
ooooo`;oo`00joooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0;oooooa3o00004Oooool2
ool00>gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0:Oooool2ool00>oooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0D?ooool3
ool00?7ooooo000Qooooo`03o`000?oooooooooo04kooooo0_oo003dooooo`008Oooool00ol0003o
ooooooooo`1<ooooo`;oo`00m_ooool0027ooooo0ol0000aooooo`Coo`00ooooool@ooooo`008Ooo
ool00ol0003oooooooooo`0eooooo`Ooo`001Oooool00ooo003oooooooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo03cooooo1Ooo003oooooo`Cooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o
00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oM
gMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooo
ooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool0
1?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4oooo
o`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomV
IVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo
00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM07_ooooo001nooooo`07
o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<
ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0=ooooo`03ohN7QomEEEGooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h0
1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo
00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`05
olc<c?lQ8B7o0000oeEEEOl00000Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003o
ooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03
o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004oooo
o`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01OlQ8B7oQhN7oooooonHV9So
000007_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@
413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05oooo
o`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RH
oa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01OlQ8B7oV9RH
oooooomgMgOoEEEE07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool0
1Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0D
ooooo`03oeEEEOmVIVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36468 L
.10458 .42001 L
.14415 .46289 L
.16408 .48026 L
.18221 .49329 L
.20178 .50419 L
.21254 .50873 L
.22272 .51204 L
.23241 .51431 L
.2373 .51513 L
.24012 .5155 L
.24269 .51577 L
.24504 .51596 L
.24728 .5161 L
.2485 .51616 L
.24964 .5162 L
.25088 .51623 L
.25158 .51624 L
.25221 .51624 L
.25336 .51624 L
.25442 .51623 L
.25558 .51621 L
.2568 .51617 L
.25787 .51613 L
.25887 .51608 L
.26113 .51593 L
.26373 .5157 L
.26614 .51543 L
.27158 .51464 L
.27638 .51372 L
.28148 .51252 L
.2903 .50991 L
.30004 .50626 L
.31939 .49668 L
.34024 .48313 L
.38138 .44783 L
.42101 .4055 L
.45912 .36022 L
.49968 .31074 L
.53872 .26525 L
.58022 .22251 L
.60102 .20419 L
.6202 .18951 L
.64007 .17674 L
.65867 .16721 L
.67743 .16007 L
.68738 .15731 L
.69293 .15608 L
.69807 .15514 L
Mistroke
.70298 .15441 L
.7082 .15384 L
.71119 .1536 L
.71265 .1535 L
.714 .15343 L
.7152 .15337 L
.71652 .15332 L
.71785 .15329 L
.71857 .15327 L
.71924 .15326 L
.7205 .15325 L
.7212 .15325 L
.72186 .15325 L
.72305 .15326 L
.72433 .15328 L
.72546 .15331 L
.72653 .15335 L
.72895 .15346 L
.73157 .15363 L
.73396 .15382 L
.73935 .15439 L
.7441 .15506 L
.74918 .15594 L
.75831 .15795 L
.77902 .16441 L
.80041 .17365 L
.82057 .18449 L
.85909 .20996 L
.90006 .24213 L
.93952 .27616 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36516 L
.10458 .42504 L
.14415 .47198 L
.16408 .49075 L
.18221 .50461 L
.20178 .51599 L
.21254 .52062 L
.21738 .52233 L
.22272 .52394 L
.22739 .52512 L
.23241 .52614 L
.23518 .5266 L
.23772 .52695 L
.2403 .52725 L
.24269 .52746 L
.24488 .52761 L
.2461 .52767 L
.24721 .52771 L
.24843 .52775 L
.24975 .52777 L
.251 .52777 L
.25214 .52776 L
.25322 .52774 L
.25423 .52771 L
.25533 .52767 L
.25651 .52761 L
.25893 .52744 L
.26113 .52725 L
.26594 .52665 L
.27104 .52578 L
.28022 .52362 L
.29008 .52043 L
.30098 .51591 L
.32032 .50542 L
.34118 .4908 L
.38232 .45325 L
.42194 .40863 L
.46005 .36095 L
.50061 .30864 L
.53966 .26031 L
.58116 .21482 L
.60196 .19533 L
.62114 .17974 L
.64101 .16621 L
.6596 .15612 L
.67837 .14855 L
.68832 .14562 L
.69386 .14431 L
.69901 .1433 L
Mistroke
.70432 .14247 L
.70914 .1419 L
.71189 .14165 L
.71449 .14147 L
.71582 .14139 L
.71722 .14133 L
.71796 .1413 L
.71877 .14127 L
.71944 .14126 L
.72018 .14124 L
.72088 .14123 L
.72153 .14122 L
.72281 .14121 L
.72397 .14122 L
.72521 .14124 L
.72653 .14126 L
.72776 .1413 L
.72912 .14136 L
.73058 .14143 L
.73305 .14159 L
.73565 .14181 L
.74028 .14231 L
.7453 .14302 L
.74985 .14381 L
.76006 .1461 L
.77844 .15191 L
.79767 .16017 L
.81848 .17141 L
.85945 .19959 L
.8989 .23291 L
.93684 .2692 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000=7ooooo3_oo001Uooooo`008Oooool0
0ol0003oooooooooo`3Oooooo`?oo`00H_ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`36ooooo`;oo`00O?ooool0027ooooo00?o0000ooooooooool0
aOooool00ooo003oooooooooo`07oooooa7o00002oooool2ool005Oooooo000Qooooo`03o`000?oo
oooooooo0<?ooooo0_oo0006ooooo`Co00004Oooool6o`0000Oooooo0_oo001Eooooo`008Oooool0
0ol0003oooooooooo`31ooooo`;oo`001Oooool3o`0001_ooooo0ol00006ooooo`;oo`00Doooool0
027ooooo00?o0000ooooooooool0_oooool2ool000Cooooo0ol0000Qooooo`;o00001_ooool3ool0
053ooooo000Qooooo`?o0000_Oooool2ool000Cooooo0_l0000Vooooo`?o00001_ooool2ool004ko
oooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool00_ooool2o`0002_ooooo
0_l00006ooooo`03ool00?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo0;_ooooo00Co
o`00oooooooooooooooo0_l0000_ooooo`;o00001Oooool00ooo003oooooooooo`1:ooooo`008Ooo
ool00ol0003oooooooooo`2jooooo`03ool00?oooooooooo00;o0000<oooool2o`0000Cooooo00?o
o`00ooooooooool0BOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`0e
ooooo`;o00000oooool00ooo003oooooooooo`18ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`2jooooo`;o0000>_ooool2o`0004cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2iooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0BOooool000Go00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000;Oooooo0_l00010ooooo`;o0000BOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0]_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04Kooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0]Oooool00ol0003oooooooooo`14ooooo`;o0000A_ooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
/?ooool2ool000;ooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooooooool2ool0043o
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:oooooo00Goo`00ooooooooooooooooo`00001;ooooo`;o00000oooool00ooo
003oooooooooo`0mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool00_l0001>ooooo`05o`000?oooooooooo
oooooooo0000?_ooool0027ooooo00?o0000ooooooooool0[Oooool01?oo003oooooooooool0001A
ooooo`;o00000_ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2/oooo
o`04ool00?oooooo0000o`0005Cooooo00Co0000ooooooooooooo`00??ooool0027ooooo0ol0002[
ooooo`03ool00?oooooo000005Oooooo00?o0000ooooooooool00_oo000jooooo`008Oooool00ol0
003oooooooooo`2[ooooo`03ool00?l0003ooooo05Sooooo0_l00002ooooo`03ool00?oooooooooo
03Oooooo000Qooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0Foooool01?l0003o
oooooooooooo000hooooo`008Oooool00ol0003oooooooooo`2Yooooo`03ool00?oooooo000005go
oooo00Co0000ooooooooooooo`00=oooool0027ooooo00?o0000ooooooooool0Z?ooool00ooo003o
ooooo`00001Oooooo`04o`000?ooooooooooool003Kooooo000Qooooo`03o`000?oooooooooo0:Oo
oooo00?oo`00ooooool00000HOooool2o`000003oooooooo003ooooo03Cooooo000Qooooo`03o`00
0?oooooooooo0:Kooooo00?oo`00ooooool00000I?ooool00ol0003oooooooooo`0dooooo`008Ooo
ool3o`000:Oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo06Kooooo0_l0000cooooo`008Oooool00ol0
003oooooooooo`2Uooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo06oooooo00?o
0000oooooooo0000;Oooool0027ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1a
ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo09kooooo0_oo00000ol0
003oooooooooo`1cooooo`03o`000?oo003ooooo02_ooooo000Qooooo`?o0000W_ooool00ooo003o
0000ooooo`1fooooo`03o`000?oo003ooooo02[ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
03gooooo1?l000000ol@413oooooooooo`06ooooo`03ool00?l0003ooooo03;ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037ooooo00?o0000
ool00?ooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooo
oooo00Oooooo00?oo`00ooooool00000=Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0aooooo`03o`000?oo003oo`0000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooool00000=_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo00002?oo
ool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Kooooo00?o
o`00o`000?ooool0=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03?ooooo0_l0
00000ooo003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
?oooool00ol0003oooooooooo`05ooooo`03ool00?l0003ooooo03Oooooo00?o0000ooooooooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Kooooo00?o0000ool00?ooool01oooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?oo`00o`000?oo
ool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?o0000ool00?oo
ool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003o
0000ooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0003o
o`00ooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo0000
00Gooooo00?oo`00ooooooooool0=oooool00omEEEGoIVIVo`00000=ooooo`Co0000>_ooool02Ol0
003oo`00ooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooooooo
o`2Gooooo`03ool00?l0003ooooo08Oooooo0_l0000Qooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03ool00?l0003ooooo08[ooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooo
ooooool0UOooool00ooo003o0000ooooo`2<ooooo`03o`000?oooooooooo01gooooo000Qooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Booooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
Soooool00ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[o
ooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?oo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@
413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
0000TOooool00ol0003oooooooooo`2Vooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04o`00
0?oooooo0000ool008oooooo00?o0000ooooooooool0/Oooool0027ooooo00Co0000oooooooooooo
o`00SOooool00ooo003o0000ooooo`2cooooo`008Oooool01Ol0003oooooooooooooooooo`0008co
oooo00?oo`00ooooooooool0/oooool0027ooooo00Ko0000ooooooooooooooooo`000?oo002:oooo
o`03ool00?oooooooooo0;Cooooo000Qooooo`?o00000_ooool00ol0003oo`00ooooo`27ooooo`03
ool00?oooooooooo0;Gooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
QOooool00ol0003oo`00ooooo`2fooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
003ooooo08Gooooo00?oo`00ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`23ooooo`03ool00?oooooooooo0;Oooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0POooool00ol0003oo`00ooooo`2hooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oo003ooooo083ooooo00?o0000ool00?ooool0^Oooool0027ooooo
00?o0000ooooooooool01_ooool00ol0003oo`00ooooo`1nooooo`03o`000?oo003ooooo0;[ooooo
000Qooooo`?o00001oooool00ol0003oooooooooo`1looooo`03o`000?ooooooo`000;_ooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oooooool0002l
ooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo00?o0000ool0
0?ooool0_?ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1hooooo`03
o`000?oo003ooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo0<3ooooo000Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`31ooooo`008Oooool3o`0000go
oooo00?oo`00ooooooooool0Koooool00ol0003oooooooooo`32ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?l0003ooooo06oooooo00?o0000ooooooooool0`_ooool0027ooooo00?o
0000ooooooooool03_ooool00ooo003oooooooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Joooool00ol0003oo`00ooooo`34
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo06[ooooo00?o0000oooo
oooo0000aOooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o0000ooooo`1Xooooo`03
o`000?ooooooo`000<Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?oo`00o`000?ooool0
I_ooool00ol0003oooooool00037ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0I?oo
ool00ol0003oooooool00038ooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo06Cooooo00?o0000ool00?ooool0b?ooool0027ooooo00?o0000ooooooooool04oooool00ooo
003o0000ooooo`1Rooooo`03o`000?ooooooo`000<Wooooo000Qooooo`03o`000?oooooooooo01Co
oooo00?oo`00o`000?ooool0H?ooool00ol0003oooooool0003:ooooo`008Oooool00ol0003ooooo
ooooo`0Dooooo`03ool00?oooooo000005oooooo00?o0000oooooooo0000boooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool05Oooool00ooo003oooooo`00001Mooooo`03o`000?ooooooo`000<co
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Fooooo`03ool00?l0003ooooo05_ooooo00?o0000oooooooo
0000cOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000Hooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo0000c_ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Gooooo`03o`000?oo003ooooo0<kooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0<oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3@ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0dOooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01gooooo
00?oo`00ooooool00000C?ooool2o`000=Kooooo000Qooooo`?o00007Oooool01?oo003ooooooooo
ool0001:ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo01kooooo00Co
o`00oooooooooooo0000B?ooool00ol0003oooooool0003Gooooo`008Oooool00ol0003ooooooooo
o`0Oooooo`04ool00?ooooooooooo`0004Kooooo00?o0000oooooooo0000f?ooool0027ooooo00?o
0000ooooooooool08?ooool01?oo003oooooooooool00014ooooo`03o`000?ooooooo`000=Wooooo
000Qooooo`03o`000?oooooooooo027ooooo00Coo`00oooooooooooo0000@Oooool2o`000003oooo
oooo003ooooo0=Wooooo000Qooooo`03o`000?oooooooooo02;ooooo00Coo`00oooooooooooo0000
?oooool01?l0003ooooooooooooo003Kooooo`008Oooool00ol0003oooooooooo`0Sooooo`04ool0
0?ooooooooooo`0003gooooo00Co0000ooooooooooooo`00g?ooool0027ooooo0ol0000Sooooo`05
ool00?ooooooooooooooool00000>oooool01?l0003ooooooooooooo003Mooooo`008Oooool00ol0
003oooooooooo`0Tooooo`05ool00?ooooooooooooooool00000>Oooool01?l0003ooooooooooooo
003Nooooo`008Oooool00ol0003oooooooooo`0Uooooo`04ool00?ooooooooooooooo`;o0000=_oo
ool01?l0003ooooooooooooo003Oooooo`008Oooool00ol0003oooooooooo`0Vooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool0<Oooool2o`0000;ooooo00?oo`00ooooooooool0g_oo
ool0027ooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`02ooooo`;o0000<?ooool0
1Ol0003oooooooooooooooooo`000>7ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0:oooool2o`0000?ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o0000oooo
ooooool0;oooool2o`0002[ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000oooooooo
ool0<Oooool2o`0002Kooooo0_l0003Yooooo`008Oooool3o`0003?ooooo0_l0000Rooooo`;o0000
joooool0027ooooo00?o0000ooooooooool0=Oooool2o`0001kooooo0_l0003]ooooo`008Oooool0
0ol0003oooooooooo`0`ooooo`;oo`001Oooool00ol0003oooooooooo`0Iooooo`;o0000koooool0
027ooooo00?o0000ooooooooool0<_ooool2ool000Cooooo0ol0000Eooooo`?o00001?ooool2ool0
0>_ooooo000Qooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooooooool01?ooool5o`0000co
oooo1?l00005ooooo`;oo`00kOooool0027ooooo00?o0000ooooooooool0=Oooool3ool000Sooooo
3?l00007ooooo`;oo`00koooool0027ooooo00?o0000ooooooooool0>?ooool2ool001Gooooo1?oo
003aooooo`008Oooool3o`0003[ooooo0ooo000?ooooo`?oo`00mOooool0027ooooo00?o0000oooo
ooooool0?Oooool2ool000[ooooo0ooo003hooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Woooo
o`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03
onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02oooo
o`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGo
oooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool0
1_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool01?l@413o0000odA4A?o<c<`5ooooo`05odA4A?l0003o0000oc8b<_oMgMd0MOooool007_o
oooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000ooooooooool02oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0003ooooooooo
o`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj
^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q
8@Kooooo00?oV9RHoa0@4?oMgMd01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Ooo
ool00on7QhOoEEEEooooo`07ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWo
ooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^
k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo00?o0000oooooooo
ool02_ooool01Oo<c<co8B4Qo`000?mEEEGo000000Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo
00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo
00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooo
oooo00[ooooo00Go8B4QohN7QoooooooV9RHo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o
0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o
0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go
0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o0000ooooooooool0
2_ooool01OlQ8B7oV9RHoooooomgMgOoEEEE00Cooooo00?o0000ooooooooool0Moooool009;ooooo
00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonH
V9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000<
ooooo`05olc<c?l@413o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36699 L
.10458 .42815 L
.14415 .47767 L
.18221 .51376 L
.20178 .52707 L
.21274 .53286 L
.22272 .53707 L
.22755 .53875 L
.23267 .54027 L
.2371 .54136 L
.24186 .54231 L
.24453 .54275 L
.24697 .54308 L
.24945 .54335 L
.25175 .54356 L
.25315 .54365 L
.25442 .54372 L
.25583 .54378 L
.25661 .5438 L
.25734 .54382 L
.25798 .54383 L
.25867 .54383 L
.25989 .54383 L
.2612 .54381 L
.26195 .5438 L
.26265 .54377 L
.26391 .54372 L
.26525 .54365 L
.26765 .54347 L
.27024 .54322 L
.2731 .54286 L
.2782 .54203 L
.283 .541 L
.29193 .53851 L
.30156 .53496 L
.3216 .5248 L
.3427 .51023 L
.3808 .47473 L
.42136 .42581 L
.46041 .37054 L
.50191 .30663 L
.54189 .2442 L
.58036 .1876 L
.62127 .13576 L
.64163 .11457 L
.66068 .09807 L
.67894 .08558 L
.68912 .08011 L
.69856 .07603 L
Mistroke
.7087 .07273 L
.71404 .07144 L
.71678 .0709 L
.71974 .07042 L
.72257 .07004 L
.72517 .06977 L
.72766 .06959 L
.72892 .06952 L
.72962 .06949 L
.73029 .06946 L
.73154 .06943 L
.73268 .06942 L
.7339 .06942 L
.73459 .06943 L
.73523 .06944 L
.7363 .06947 L
.73747 .06952 L
.73869 .06958 L
.73984 .06966 L
.74228 .06987 L
.74455 .07013 L
.7497 .07091 L
.75471 .07195 L
.76006 .07336 L
.76977 .07668 L
.77858 .08053 L
.7978 .0916 L
.81862 .10742 L
.85959 .14855 L
.89904 .19783 L
.93698 .25109 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3_oo001Qooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`05o`00
0?oo003oo`00ool00?l00000GOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3?ooooo`;oo`0000?oooooo`000?l000004oooool2o`0005_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0c?ooool3ool000?o00005oooool3o`0005Sooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool01?oo003oooooo`000?l0
000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`39
ooooo`;oo`000_l0000Qooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo
0<Oooooo0_oo0002o`0002?ooooo0ooo001Cooooo`008Oooool00ol0003oooooooooo`35ooooo`;o
o`0000?oooooo`000?ooool09oooool00ooo003oooooooooo`1@ooooo`008Oooool3o`000<Cooooo
00Coo`00ooooool0003o0000:_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo0<Cooooo
00?oo`00o`000?ooool0;Oooool00ooo003oooooooooo`1=ooooo`008Oooool00ol0003ooooooooo
o`33ooooo`03ool00?l0003ooooo02oooooo00?oo`00o`000?ooool0C?ooool0027ooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0aooooo`03ool00?l0003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0<_ooool00ooo003oooooo`00001;oooo
o`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooool0
0000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0>_ooool0
0ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2kooooo`03ool00?l0003ooooo
03oooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0^_ooool00ooo003o
0000ooooo`11ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oooooooooo0;Wooooo
00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`2hooooo`03ool00?l0003ooooo04Gooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000
ooooooooool0^?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo000Qoooo
o`?o0000]oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo0;Kooooo00?oo`00o`000?ooool0BOooool00ol0003oooooooooo`0oooooo`00
8Oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04[ooooo00?oo`00o`000?ooool0
?oooool0027ooooo00?o0000ooooooooool0]?ooool00ooo003o0000ooooo`1;ooooo`03ool00?oo
oooo000003oooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00ooooooooool0C?ooool0
0ooo003oooooo`00000nooooo`008Oooool00ol0003oooooooooo`2cooooo`03ool00?oooooooooo
04kooooo00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/_ooool00ooo003o
0000ooooo`1@ooooo`03ool00?l0003ooooo03cooooo000Qooooo`03o`000?oooooooooo0;7ooooo
00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3o`000;7ooooo00?o
0000ooooooooool0Doooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooool00000>_ooool0027ooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wooooo000Qooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000ooooo`0hooooo`00
8Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0
=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Kooooo`03
ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05go
oooo00?oo`00o`000?ooool0=Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Zooooo`03ool00?l0003ooooo067ooooo00?o0000oooooooo
ool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo06;ooooo00?o0000oooo
ooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo
037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0IOooool00ol0003oooooooooo`0aoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Yooooo`03o`000?oooooooooo02oooooo
000Qooooo`?o0000YOooool00ooo003o0000ooooo`1Zooooo`03ool00?l0003ooooo02oooooo000Q
ooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J_ooool00ooo003oooooo`00000_
ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06cooooo00?oo`00o`00
0?ooool0;_ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1^ooooo`03
ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o0000XOooool00ol0
003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?ooool0027ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`0W
ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_ooooo00?oo`00oooo
ooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1looooo`03
ool00?l0003ooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?oo`00ooooooooool0Oooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Co0000
00?o410@ooooooooool01?ooool00ooo003oooooooooo`0dooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`000?oooooooooo00?o
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0mooooo`07ool00?oooooo0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ooo003oooooooooo`0iooooo`03
oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@4?l0003o8B4Qolc<c00K
ooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo08[ooooo00?oo`00oooo
ooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`2<ooooo`03
ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0
S?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oo
oooooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`2Cooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool04Oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`00
0005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03o`000?oo
oooooooo0:Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool0
0ol0003oooooooooo`2aooooo`008Oooool01?l0003ooooooooooooo002?ooooo`03o`000?oooooo
oooo0;7ooooo000Qooooo`04o`000?ooooooooooool008kooooo00?o0000ooooooooool0/_ooool0
027ooooo00Go0000ooooooooooooooooool0002<ooooo`03o`000?oooooooooo0;?ooooo000Qoooo
o`?o00000_ooool00ooo003oooooooooo`28ooooo`03ool00?l0003ooooo0;Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool0R?ooool00ooo003oooooooooo`2dooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool0
]Oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oo
003ooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool0
0ooo003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
08;ooooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`20ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003oo`00
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0O_ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oo003ooooo07gooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`2kooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0
_?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oo
oooooooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool0`?ooool0027ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`00
8Oooool3o`00017ooooo00?oo`00ooooooooool0J_ooool00ooo003o0000ooooo`33ooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0`ooo
ool0027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03ool00?oooooo
oooo0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ooo
003oooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Go
oooo00?oo`00ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`1Tooooo`03ool00?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0a_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03ool00?oooooooooo
067ooooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Ooooo
o`03o`000?oo003ooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1O
ooooo`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0GOooool0
0ooo003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00
ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo
0<cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`3<ooooo`008Oooool3o`0001cooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`3=ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00oooo
ooooool0Coooool00ol0003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
ool00?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool0
8?ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0B_ooool00ooo003o0000ooooo`3Cooooo`008Oooool3
o`0002;ooooo00?oo`00ooooooooool0Aoooool2ool00003o`000?oooooooooo0=?ooooo000Qoooo
o`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool0AOooool00ooo003o0000o`00003Foooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo04?ooooo00?oo`00o`000?oo
ool0eoooool0027ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`11ooooo`03ool0
0?l0003ooooo0=Sooooo000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0?ooo
ool00ooo003o0000ooooo`3Iooooo`008Oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooo
oooo03gooooo00?oo`00o`000?ooool0f_ooool0027ooooo00?o0000ooooooooool0:?ooool00ooo
003oooooooooo`0kooooo`03ool00?l0003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3Looooo`008Oooool3o`0002[ooooo
00?oo`00ooooooooool0=oooool00ooo003o0000ooooo`3Mooooo`008Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo03Gooooo00?oo`00o`000?ooool0g_ooool0027ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`03ool00?l0003ooooo0=oooooo000Qoooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`3Ooooo
o`008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0h?ooool0027ooooo00?o0000ooooooooool0;oooool2o`0002kooooo0_l0003Sooooo`008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0hooo
ool0027ooooo0ol0000booooo`?oo`00:?ooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0
003oooooooooo`0dooooo`03o`000?oo003oo`0002;ooooo0_oo00000ooooooo0000ooooo`3Voooo
o`008Oooool00ol0003oooooooooo`0eooooo`;o000000?oo`00ooooooooool07Oooool2ool00003
ooooool0003o00000>Sooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ool00?oo0000
6oooool2ool000?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool2o`0000;oo`005ooo
ool2ool000;o0000kOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo00Co0000ool00?oo003oo`004Oooool3ool000;o0000koooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0oooooo`;oo`002_ooool5ool00003ooooool0003o
00000?7ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool7o`00
00?ooooo1ol0003cooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000A_ooool4o`000?[o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo0000
00Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?oMgMg
ofIVI_ooool05oooool00omVIVKoMgMgooooo`2Oooooo`00Roooool3o`0001?ooooo00?o8B4QomgM
gOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM09oooooo0022ooooo`07
ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RH
o`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo
1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIV
ooooo`0Booooo`Go00001Oooool2ob4Q8H3ooooo0022ooooo`07oa0@4?oMgMgoMgMgob4Q8Ooooooo
QhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003oooo
o`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`00
0006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8H3ooooo0022ooooo`07o`000?oooooo
gMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@
4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool04_ooool00onHV9So8B4Qonk^kP28ooooo`00
P_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6
o`0000?ooooo00?oV9RHob4Q8Oo^k^h0Qoooool008;ooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05oooo
o`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004
ooooo`03onk^k_l0003ooooo01Gooooo00?oMgMgofIVI_ooool0Q_ooool008?ooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05_ooool00ol0003oooooooooo`25ooooo`00V_ooool00ol0003o
ooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[o
oooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05o`000?nj^[[ooooooiRHV?l@4100
Qoooool009[ooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomV
IVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c027ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}]
}, Closed]],

Cell["\<\
Fig. 6.12 (animation). WKB (solid) and Galerkin (dashed) solutions \
for oscillations of an inhomogeneous string.\
\>", "Caption",
  CellTags->"Fig. 6.12"],

Cell[TextData[{
  "The solutions start out being very close, but over time, they diverge \
noticeably. This divergence is due to a simple error in the WKB method: the \
WKB frequencies are only approximately correct. Recall that the Fourier \
coefficients in the WKB solution have the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t) = A\_n\ cos\ \[Omega]\_n\ t\)]],
  ". If there is an error \[Delta]\[Omega] in the WKB approximation to a mode \
frequency, a phase shift ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Omega]\ t\)]],
  " builds up over time, leading to error in the solution. "
}], "Text"],

Cell["\<\
\tAlso, there is a (small) error in the WKB eigenfunctions. While \
this error does not grow with time, it can still cause small errors in the \
solution. For both the eigenmodes and the frequencies, we expect the errors \
to be largest for the low-order WKB modes, and not so important for \
high-order modes, where WKB theory should work well.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenmode Correction Using the Shooting Method", "Section",
  CellTags->{"i:40", "c:40"}],

Cell[TextData[{
  "\tIn order to improve the WKB solution, we require more accurate \
eigenfrequencies and eigenfunctions.  These can be obtained using the \
shooting method. Recall that in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:31"},
    ButtonStyle->"Hyperlink"],
  " the shooting method was introduced as a numerical technique to solve \
boundary-value problems. Here, we adapt the method to solve the eigenvalue \
problem ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ".  Since the error in the WKB method is important only for the low-order \
modes, we need use this method only for the first few modes. "
}], "Text"],

Cell[TextData[{
  "\tIn the shooting method we first define a numerical solution to Eq. ",
  ButtonBox["(6.3.14)",
    ButtonData:>"(6.3.14)",
    ButtonStyle->"Hyperlink"],
  ", with the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " (or equivalently the eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  ") a free parameter. For homogeneous Dirichlet boundary conditions, the \
initial-value of \[Psi] is set to zero, but the initial-value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Psi]/\[DifferentialD]x\)]],
  " is arbitrary, corresponding to the arbitrary value of the normal-mode \
amplitude. Here we set ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Psi]/\[DifferentialD]x = 1\)]],
  " initially (for von Neumann  conditions, we would set ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]\[Psi]/\[DifferentialD]x\)\( | \
\_\(x = 0\)\)\) = 0\)]],
  "  and choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0)\)]],
  " arbitrarily):"
}], "Text"],

Cell[BoxData[
    \(Sol[\[Omega]_] := \(NDSolve[{1/\[Rho][x] 
                D[T[x] D[\[Psi]shooting[x], x], 
                  x] \[Equal] \(-\[Omega]\^2\)\ \[Psi]shooting[
                  x], \[Psi]shooting[0] \[Equal] 
              0, \(\[Psi]shooting'\)[0] \[Equal] 1}, \[Psi]shooting, {x, 0, 
            L}]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.171"],

Cell[TextData[{
  "We then define \[Psi]end as the value of the solution at the ",
  "end point",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi]end[\[Omega]_] := \ \[Psi]shooting[L] /. Sol[\[Omega]]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 6.172"],

Cell[TextData[{
  "The shooting-method frequency is then determined by finding the value of \
\[Omega] that makes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]end",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  ". We use ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  "to solve this equation, using the WKB eigenfrequency as the initial guess \
:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Omega]WKB[n_]\  = \ n\ Pi/\[Tau][L];\)\), "\n", 
    \(\[Omega]shooting[
        n_]\  := \ \[Omega] /. \(FindRoot[\[Psi]end[\[Omega]] \[Equal] 
              0, {\[Omega], \[Omega]WKB[n], 
              1.1  \[Omega]WKB[n]}]\)[\([1]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.173"],

Cell["\<\
Below, we compare the shooting-method frequencies and the WKB \
frequencies\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Join[{{"\<n\>", \*"\"\<\!\(\[Omega]\_WKB\)\>\"", \
\*"\"\<\!\(\[Omega]\_shooting\)\>\"", \*"\"\<\!\(\[Omega]\_shooting\)-\!\(\
\[Omega]\_WKB\)\>\""}}, 
        Table[{n, \((\[Omega]WKB[n] // N)\), \[Omega]shooting[
              n], \[Omega]shooting[n] - \[Omega]WKB[n]}, {n, 1, 
            10}]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.174"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"n\"\>", "\<\"\\!\\(\[Omega]\\_WKB\\)\"\>", \
"\<\"\\!\\(\[Omega]\\_shooting\\)\"\>", "\<\"\\!\\(\[Omega]\\_shooting\\)-\\!\
\\(\[Omega]\\_WKB\\)\"\>"},
          {"1", "2.8596008673801268`", "2.9029844906660083`", 
            "0.04338362328588152`"},
          {"2", "5.7192017347602535`", "5.741023072777916`", 
            "0.02182133801766284`"},
          {"3", "8.578802602140382`", "8.593362121086955`", 
            "0.014559518946573036`"},
          {"4", "11.438403469520507`", "11.449336088458773`", 
            "0.010932618938266359`"},
          {"5", "14.298004336900634`", "14.306740528407259`", 
            "0.008736191506624635`"},
          {"6", "17.157605204280763`", "17.164911015402836`", 
            "0.00730581112207318`"},
          {"7", "20.01720607166089`", "20.023446354803912`", 
            "0.006240283143021941`"},
          {"8", "22.876806939041014`", "22.88233658049111`", 
            "0.0055296414500958235`"},
          {"9", "25.73640780642114`", "25.741311611445788`", 
            "0.004903805024646601`"},
          {"10", "28.59600867380127`", "28.600426025434658`", 
            "0.004417351633389188`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
As expected, the high-order mode frequencies are accurately \
determined by the WKB method.  Therefore, in the solution we only use the \
shooting method for the first six mode frequencies. \
\>", "Text"],

Cell["\<\
\tThe shooting method also provides us with the eigenmodes. They \
are defined using our shooting solution for the frequency:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]s[n_, x_]\  := \ \[Psi]shooting[x] /. 
        Sol[\[Omega]shooting[n]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.175"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["6.176",
    ButtonData:>"Cell 6.176",
    ButtonStyle->"Hyperlink"],
  ", we compare these shooting method eigenmodes with the WKB modes. Both \
solutions must be properly normalized in order to perform the comparison. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(norms[n_]\  := \ \((f\  = \[Psi]s[n, x]; \ 
          Sqrt[NIntegrate[\[Rho][x]\ f^2, {x, 0, L}]])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(normWKB[n_]\  := \ \((f\  = \[Psi]WKB[n, x]; \ 
          Sqrt[NIntegrate[\[Rho][x] f^2, {x, 0, L}]])\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[Evaluate[{\[Psi]s[n, x]/norms[n], \[Psi]WKB[n, x]/
                normWKB[n]}], {x, 0, L}, 
          PlotLabel \[Rule] "\<WKB and shooting eigenmodes, n=\>" <> 
              ToString[n]], {n, 1, 5}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.176"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.326471 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09633 -24 -4.5 ]
[.01131 .09633 0 4.5 ]
[.01131 .17795 -18 -4.5 ]
[.01131 .17795 0 4.5 ]
[.01131 .25957 -24 -4.5 ]
[.01131 .25957 0 4.5 ]
[.01131 .34119 -6 -4.5 ]
[.01131 .34119 0 4.5 ]
[.01131 .4228 -24 -4.5 ]
[.01131 .4228 0 4.5 ]
[.01131 .50442 -18 -4.5 ]
[.01131 .50442 0 4.5 ]
[.01131 .58604 -24 -4.5 ]
[.01131 .58604 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09633 m
.03006 .09633 L
s
[(0.25)] .01131 .09633 1 0 Mshowa
.02381 .17795 m
.03006 .17795 L
s
[(0.5)] .01131 .17795 1 0 Mshowa
.02381 .25957 m
.03006 .25957 L
s
[(0.75)] .01131 .25957 1 0 Mshowa
.02381 .34119 m
.03006 .34119 L
s
[(1)] .01131 .34119 1 0 Mshowa
.02381 .4228 m
.03006 .4228 L
s
[(1.25)] .01131 .4228 1 0 Mshowa
.02381 .50442 m
.03006 .50442 L
s
[(1.5)] .01131 .50442 1 0 Mshowa
.02381 .58604 m
.03006 .58604 L
s
[(1.75)] .01131 .58604 1 0 Mshowa
.125 Mabswid
.02381 .03104 m
.02756 .03104 L
s
.02381 .04736 m
.02756 .04736 L
s
.02381 .06369 m
.02756 .06369 L
s
.02381 .08001 m
.02756 .08001 L
s
.02381 .11266 m
.02756 .11266 L
s
.02381 .12898 m
.02756 .12898 L
s
.02381 .1453 m
.02756 .1453 L
s
.02381 .16163 m
.02756 .16163 L
s
.02381 .19427 m
.02756 .19427 L
s
.02381 .2106 m
.02756 .2106 L
s
.02381 .22692 m
.02756 .22692 L
s
.02381 .24324 m
.02756 .24324 L
s
.02381 .27589 m
.02756 .27589 L
s
.02381 .29222 m
.02756 .29222 L
s
.02381 .30854 m
.02756 .30854 L
s
.02381 .32486 m
.02756 .32486 L
s
.02381 .35751 m
.02756 .35751 L
s
.02381 .37383 m
.02756 .37383 L
s
.02381 .39016 m
.02756 .39016 L
s
.02381 .40648 m
.02756 .40648 L
s
.02381 .43913 m
.02756 .43913 L
s
.02381 .45545 m
.02756 .45545 L
s
.02381 .47177 m
.02756 .47177 L
s
.02381 .4881 m
.02756 .4881 L
s
.02381 .52074 m
.02756 .52074 L
s
.02381 .53707 m
.02756 .53707 L
s
.02381 .55339 m
.02756 .55339 L
s
.02381 .56972 m
.02756 .56972 L
s
.02381 .60236 m
.02756 .60236 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .11604 L
.10458 .22108 L
.14415 .31085 L
.18221 .38691 L
.22272 .45552 L
.26171 .50897 L
.28158 .53143 L
.30316 .55221 L
.32216 .56745 L
.34309 .58099 L
.36292 .59078 L
.37378 .59491 L
.38395 .59802 L
.38891 .59927 L
.39433 .60044 L
.39911 .6013 L
.4042 .60205 L
.40924 .60262 L
.41381 .60299 L
.41601 .60312 L
.41717 .60317 L
.4184 .60322 L
.41947 .60326 L
.42065 .60329 L
.42172 .6033 L
.42272 .60331 L
.42398 .60332 L
.42462 .60332 L
.42532 .60331 L
.42656 .6033 L
.42773 .60327 L
.4291 .60323 L
.43035 .60318 L
.43317 .60304 L
.43548 .60289 L
.438 .60268 L
.44308 .60215 L
.44772 .60152 L
.45269 .6007 L
.46163 .59885 L
.47187 .59615 L
.48298 .59255 L
.50313 .58428 L
.54405 .56104 L
.58345 .53131 L
.62134 .49677 L
.66168 .45444 L
.7005 .40911 L
.74178 .35679 L
Mistroke
.78154 .30311 L
.81979 .2491 L
.86048 .18966 L
.89966 .13109 L
.9413 .06796 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .11604 L
.10458 .22108 L
.14415 .31085 L
.18221 .38691 L
.22272 .45552 L
.26171 .50897 L
.28158 .53143 L
.30316 .55221 L
.32216 .56745 L
.34309 .58099 L
.36292 .59078 L
.37378 .59491 L
.38395 .59802 L
.38891 .59927 L
.39433 .60044 L
.39911 .6013 L
.4042 .60205 L
.40924 .60262 L
.41381 .60299 L
.41601 .60312 L
.41717 .60317 L
.4184 .60322 L
.41947 .60326 L
.42065 .60328 L
.42172 .6033 L
.42272 .60331 L
.42398 .60332 L
.42462 .60332 L
.42532 .60331 L
.42656 .6033 L
.42773 .60327 L
.4291 .60323 L
.43035 .60318 L
.43317 .60304 L
.43548 .60289 L
.438 .60268 L
.44308 .60215 L
.44772 .60151 L
.45269 .6007 L
.46163 .59885 L
.47187 .59615 L
.48298 .59255 L
.50313 .58428 L
.54405 .56104 L
.58345 .53131 L
.62134 .49677 L
.66168 .45444 L
.7005 .40911 L
.74178 .35679 L
Mistroke
.78154 .30311 L
.81979 .2491 L
.86048 .18966 L
.89966 .13109 L
.9413 .06796 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Joooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03cooooo1Ol0
000Booooo`00Joooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0kooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04_ooool006_ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?oV9RHob4Q8Oo^k^h0
4oooool006_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03kooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03gooooo
00?oV9RHob4Q8Oo^k^h04_ooool006_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03ogMgMomVIVKooooo017ooooo001[ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
013ooooo001[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0noooo
o`05o`000?nj^[[ooooooiRHV?l@41004_ooool006_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000m
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04_ooool00?ooooooJOooool002cooooo00?o0000oooo
ooooool0ooooooljooooo`00;?ooool00ol0003oooooooooo`3ooooooc[ooooo000/ooooo`03o`00
0?oooooooooo0?oooooo>_ooool002cooooo00?o0000ooooooooool0ooooooljooooo`009Ooooooo
o`0003Wo00002oooool002cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo000/ooooo`;o0000B?ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool0A_ooool2o`0001?ooooo000/ooooo`;o0000
oooooolUooooo`03o`000?oooooooooo01?ooooo000/ooooo`;o0000oooooolUooooo`03o`000?oo
oooooooo01?ooooo000/ooooo`?o0000oooooolSooooo`03o`000?oooooooooo01Cooooo000/oooo
o`03o`000?oooooo00000?oooooo8_ooool00ol0003oooooooooo`0Eooooo`00;?ooool00ol0003o
ooooo`00003oooooob;ooooo00?o0000ooooooooool05Oooool002cooooo00Co0000oooooooooooo
0000oooooolPooooo`03o`000?oooooooooo01Kooooo000/ooooo`04o`000?ooooooooooo`000?oo
oooo7oooool00ol0003oooooooooo`0Gooooo`00;?ooool3o`000003ooooool0003ooooo0?oooooo
7Oooool00ol0003oooooooooo`0Gooooo`00;?ooool01Ol0003ooooooooooooooooo00000?oooooo
7Oooool00ol0003oooooooooo`0Hooooo`00;?ooool01Ol0003ooooooooooooooooo00000?oooooo
7Oooool00ol0003oooooooooo`0Hooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo6Oooool00ol0003oooooooooo`0Iooooo`00;?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0Jooooo`00;?ooool3o`00
00;ooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo01[ooooo000/ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo01_o
oooo000/ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolEooooo`03o`00
0?oooooooooo01cooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolDooooo`03o`000?oooooooooo01cooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolCooooo`03o`000?oooooooooo01gooooo000/ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooolBooooo`03o`000?oooooooooo01kooooo000/ooooo`?o
00001Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool07_ooool002cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0
7oooool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo023ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`kooooo00?o0000oooo
ooooool08?ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo3Oooool00ol0003oooooooooo`0Qooooo`002Oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00001oooool00ol0
003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool08_ooool000Wooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooo
oooo02?ooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooo`[ooooo00?o0000ooooooooool08oooool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo02Cooooo0009
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool7ooooo`03o`00
0?oooooooooo02Gooooo000/ooooo`?o00002?ooool00ol0003oooooooooo`3oooooo`Oooooo00?o
0000ooooooooool09Oooool002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3o
ooooo`Gooooo00?o0000ooooooooool09_ooool002cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3oooooo`Cooooo00?o0000ooooooooool09oooool002cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool09oooool002cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooo`;ooooo00?o0000ooooooooool0
:?ooool002cooooo0ol0000:ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooooooo
o`0Yooooo`00;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo00?o0000
ooooooooool0:Oooool002cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3noooo
o`03o`000?oooooooooo02[ooooo000/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0o?ooool00ol0003oooooooooo`0[ooooo`00;?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo0?cooooo00?o0000ooooooooool0:oooool002cooooo0ol0000<ooooo`03o`000?oo
oooooooo0?_ooooo00?o0000ooooooooool0;?ooool002cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3jooooo`03o`000?oooooooooo02cooooo000/ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0nOooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?Oooooo00?o0000ooooooooool0;_ooool002cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00003_ooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo02oooooo000/
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`0`
ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?Cooooo00?o
0000ooooooooool0<?ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0l_oo
ool00ol0003oooooooooo`0aooooo`004Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?7ooooo00?o
0000ooooooooool0<_ooool0017ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Aooooo`03o`000?oooooooooo0?3ooooo00?o0000ooooooooool0<_oo
ool0017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0>oooooo00?o0000ooooooooool0
<oooool0017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`3_ooooo`03o`000?oooooooooo03?ooooo
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`0dooooo`004Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0k?ooool00ol0003oooooooooo`0eooooo`00;?ooool3o`0001?ooooo00?o
0000ooooooooool0joooool00ol0003oooooooooo`0eooooo`00;?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool0=_ooool002cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo03Oooooo000/ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0j?ooool00ol0003oooooooooo`0gooooo`00
;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0>Oooooo00?o0000ooooooooool0
>?ooool002cooooo0ol0000Eooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool0>Ooo
ool002cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Uooooo`03o`000?oooooo
oooo03Wooooo000/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0i?ooool00ol0
003oooooooooo`0jooooo`00;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0>;o
oooo00?o0000ooooooooool0>oooool002cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3Rooooo`03o`000?oooooooooo03_ooooo000/ooooo`?o00005oooool00ol0003ooooooooo
o`3Pooooo`03o`000?oooooooooo03cooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0goooool00ol0003oooooooooo`0mooooo`00;?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0?Oooool002cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo03kooooo000/ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`0oooooo`00;?oo
ool3o`0001Wooooo00?o0000ooooooooool0foooool00ol0003oooooooooo`0oooooo`00;?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0=[ooooo00?o0000ooooooooool0@?ooool0
02cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Hooooo`03o`000?oooooooooo
047ooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^
k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`3Hooooo`03o`000?oooooooooo047ooooo0009ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0e_ooool00ol0003oooooooooo`12
ooooo`002Oooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`3Eooooo`03o`000?oooooo
oooo04?ooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3D
ooooo`03o`000?oooooooooo04?ooooo0009ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool0A?ooool000Wooooo00Go410@
oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0=7ooooo00?o0000ooooooooool0AOoo
ool000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
d?ooool00ol0003oooooooooo`16ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool3o`0001kooooo00?o0000ooooooooool0coooool00ol0003ooooo
ooooo`16ooooo`00;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0<kooooo00?o
0000ooooooooool0Aoooool002cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo04Sooooo000/ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`18ooooo`00;?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0<[ooooo00?o0000ooooooooool0BOooool002cooooo0ol0000Pooooo`03o`00
0?oooooooooo0<Wooooo00?o0000ooooooooool0B_ooool002cooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo04_ooooo000/ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`1;ooooo`00;?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0C?ooool002co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`34ooooo`03o`000?oooooooooo04go
oooo000/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0a?ooool00ol0003ooooo
ooooo`1=ooooo`00;?ooool3o`0002?ooooo00?o0000ooooooooool0`_ooool00ol0003ooooooooo
o`1>ooooo`00;?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0<7ooooo00?o0000
ooooooooool0Coooool002cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2ooooo
o`03o`000?oooooooooo053ooooo000/ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0__ooool00ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0DOooool002cooooo0ol0000Uooooo`03o`000?oo
oooooooo0;cooooo00?o0000ooooooooool0D_ooool002cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo05?ooooo000Rooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;Wooooo00?o0000oooo
ooooool0E?ooool002Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0;Oooooo00?o0000ooooooooool0EOooool002Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0;Kooooo00?o0000ooooooooool0
E_ooool002Cooooo00?o0000ooooooooool01Oooool3o`0002Sooooo00?o0000ooooooooool0]Ooo
ool00ol0003oooooooooo`1Fooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`1Gooooo`009?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`1Hooooo`009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Iooooo`008_ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0[oooool00ol0003ooooo
ooooo`1Jooooo`00;?ooool3o`0002[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`1Jooooo`00;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0:gooooo00?o0000
ooooooooool0Foooool002cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2/oooo
o`03o`000?oooooooooo05cooooo000/ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0Zoooool00ol0003oooooooooo`1Looooo`00;?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo0:[ooooo00?o0000ooooooooool0GOooool002cooooo0ol0000]ooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool0G_ooool002cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2Wooooo`03o`000?oooooooooo05oooooo000/ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`1Oooooo`00;?ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0H?ooool002cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo067ooooo
000/ooooo`?o0000;oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo067ooooo000/
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1R
ooooo`00;?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:3ooooo00?o0000oooo
ooooool0Hoooool002cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo06Cooooo000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`1Tooooo`00;?ooool3o`0003;ooooo00?o0000ooooooooool0W?oo
ool00ol0003oooooooooo`1Uooooo`00;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo09[ooooo00?o0000ooooooooool0I_ooool000[ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`1Vooooo`003?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo09Sooooo00?o0000
ooooooooool0Ioooool000cooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Goooo
o`03o`000?oooooooooo06Sooooo000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`04ooooo`?o0000=Oooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo06Wooooo000<ooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`2Cooooo`03o`000?oooooooooo06[ooooo000<ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1[ooooo`003?ooool00ol0003ooooooooo
o`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`1/ooooo`002_oo
ool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo06gooooo
000/ooooo`?o0000>?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo06kooooo000/
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1_
ooooo`00;?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08[ooooo00?o0000oooo
ooooool0L?ooool002cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo077ooooo000/ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`1booooo`00;?ooool3o`0003_ooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`1cooooo`00;?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0Loooool002cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo07Cooooo000/ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`1eooooo`00;?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0M_ooool002cooooo0ol0
000nooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0Moooool002cooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo07Sooooo000/oooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`1ioooo
o`00;?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0N_ooool002cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo07_ooooo000/ooooo`?o0000@_ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo07cooooo000/ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`1mooooo`00;?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool0O_ooool001;ooooo1?l000000ol@413oooooooooo`02ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`1_ooooo`;o0000POooool001Cooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool0POooool001Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`03ooooo`?o0000AOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo08;ooooo
000Dooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Poooool001Cooooo00?o0000
ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo08Cooooo000Dooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool0QOooool001Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`26ooooo`004_ooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool3o`0004Wo
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`27ooooo`00;?ooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0R?ooool002cooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08Wooooo000/
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`2:
ooooo`00;?ooool00ol0003oooooooooo`1=ooooo`;o0000Foooool2o`0008gooooo000/ooooo`?o
0000Coooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo08gooooo000/ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2>ooooo`00;?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05;ooooo0_l0002Aooooo`00;?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0TOooool0
02cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
09;ooooo000/ooooo`03o`000?oooooooooo05Cooooo0_l0001<ooooo`;o0000UOooool002cooooo
0ol0001Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0UOooool002cooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09Kooooo000/
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@oooool2o`0009Wooooo000/oooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0@?ooool2o`0009_ooooo000/ooooo`03
o`000?oooooooooo05[ooooo0_l0000nooooo`;o0000WOooool002cooooo0ol0001Looooo`;o0000
>_ooool2o`0009oooooo000/ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2Oooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46
ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo05oooooo0_l0000dooooo`;o0000X_ooool000cooooo00?o0000ooooooooool01?ooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo067ooooo0_l0000`ooooo`;o0000Y?ooool000cooooo00?o0000ooooooooool03?ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool2o`00
02cooooo0_l0002Vooooo`003?ooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Ko
oooo00?oMgMgoc8b<_ooool01?ooool3o`0006Gooooo0_l0000Xooooo`;o0000Z?ooool000cooooo
00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`1Wooooo`?o00008oooool2o`000:[ooooo000<ooooo`03o`00
0?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo06[ooooo0ol0000Nooooo`;o0000[?ooool000cooooo00?o0000ooooooooool02_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1]ooooo`;o00006?ooool4o`000:kooooo000:ooooo`03oeEEEOmVIVKo000000cooooo1Ol0
0004ooooo`Co00001_ooool00ol0003oooooooooo`1_ooooo`Co00003_ooool6o`000;;ooooo000/
ooooo`?o0000Loooool>o`000;Sooooo000/ooooo`03o`000?oooooooooo0?oooooo>_ooool002co
oooo00?o0000ooooooooool0ooooooljooooo`00;?ooool00ol0003oooooooooo`3ooooooc[ooooo
000/ooooo`03o`000?oooooooooo0?oooooo>_ooool002cooooo00?o0000ooooooooool0oooooolj
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00^oooool0
1OlQ8B7o0000o`000?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2=ooooo`00__oo
ool00omgMgOo<S8booooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0C?oo
ool00;oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bCOooool0
04Kooooo00OoQhN7ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000oooo
o`05o`000003oc8b<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04
oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007
ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^
k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000
o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?l0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEE
onk^k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4
A4Co^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj
^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01oooool4o`000003oa0@
4?oooooooooo02[ooooo0016ooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003o
oooooooooooooooo410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`00
0?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEE
EOl00005ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02oooo
o`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`00
00Kooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00001Ooo
ool00ol0003oooooooooo`0/ooooo`00A_ooool2oc8b<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go
0000ooooooooooooV9RHodA4A003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`06o`000?ooooooooooooooooo^k^ko00002Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01_l0003oooooooooooooooook^k^
o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?o
oooo00Gok^k^o`000?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@41005Oooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0;?ooool004Kooooo00Ko410@
ojVYZOmEEEGoEEEEojVYZOl@4102ooooo`05o`000?mEEEGo^[Zjoa0@4?oMgMd00oooool01_l0003o
ooooooooooo^k^koQhN7oc8b<PSooooo00?o^[Zjoa0@4?l000000_l00004ooooo`05o`000?oooooo
ooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Sooooo00Ko<S8bob4Q8Omg
MgOoMgMgohN7Qoo^k^h3ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooooooo
ooooooo^k^ko00001Oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ooooooook^k^o`0000;ooooo1_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00000ooo
ool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^hEoooo
o`06o`000?ooooooooooooooool0003ooooo1_l00005ooooo`03o`000?oooooooooo02cooooo0016
ooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_ooool01?l0003oV9RHo`000?nj^[X4ooooo`Co
000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000ooooo`03ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko0000okZj^_ooooook^k^
ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooooooooooo
MgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00ol0003o
ooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`0:o`000?o<c<coc<c<o`00
0?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[oMgMgoeEEEOooooooooooofIVI_mgMgOooooo
onk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko0000okZj^_oo
ooook^k^ogMgMol0000Eooooo`05o`000?n7QhOoooooojVYZOl000003?ooool00ol0003ooooooooo
o`0/ooooo`00AOooool00oo<c<co8B4Qooooo`02oeEEE@08oooooolb<S;o^[Zjooooool0003ooooo
ojVYZOmVIVH4ooooo`05o`000?oooooooooookZj^_l@41002_ooool01?lb<S;o0000o`000?nHV9P3
ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RHooooooooooook^k^oeEEEOl0003o410@olc<c?l0
00002?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000?ooooo00Go0000ogMgMol0003o0000oiRH
V002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool02?o^k^koEEEEo`000?l0003oEEEE
onk^k_oooooo410@1Ol00004ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l0
00002_nHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@4104ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^k_mEEEGo0000ob4Q8OnY
ZJWo0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o
000000goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o
000000[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0000Dooooo`03oa0@4?l0
003oMgMg00;o000000?oV9RHooooooooool02_ooool00ol0003oooooooooo`0/ooooo`00AOooool0
0onYZJWo<S8booooo`03ooooo`04odA4A?nHV9Soooooo`0000;ooooo00?oZJVYoeEEEOo^k^h00_oo
ool01Ol0003ooooooooooonj^[[o000001kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0/ooooo`00AOooool3o`0000;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00Co0000
00?o410@ojVYZOooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<_ooool00omEEEGoIVIVo`00000^ooooo`00N?ooool2o`00013ooooo00?o
410@o`000?ooool08?ooool00ol@413oooooooooo`0Pooooo`03oa0@4?oooooooooo02kooooo0_l0
001Uooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.303363, -0.149245, \
0.00845269, 0.0123291}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.349182 0.163562 [
[.2619 .33668 -9 -9 ]
[.2619 .33668 9 0 ]
[.5 .33668 -3 -9 ]
[.5 .33668 3 0 ]
[.7381 .33668 -9 -9 ]
[.7381 .33668 9 0 ]
[.97619 .33668 -3 -9 ]
[.97619 .33668 3 0 ]
[.01131 .02206 -12 -4.5 ]
[.01131 .02206 0 4.5 ]
[.01131 .10384 -24 -4.5 ]
[.01131 .10384 0 4.5 ]
[.01131 .18562 -12 -4.5 ]
[.01131 .18562 0 4.5 ]
[.01131 .2674 -24 -4.5 ]
[.01131 .2674 0 4.5 ]
[.01131 .43096 -18 -4.5 ]
[.01131 .43096 0 4.5 ]
[.01131 .51274 -6 -4.5 ]
[.01131 .51274 0 4.5 ]
[.01131 .59452 -18 -4.5 ]
[.01131 .59452 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .34918 m
.2619 .35543 L
s
[(0.5)] .2619 .33668 0 1 Mshowa
.5 .34918 m
.5 .35543 L
s
[(1)] .5 .33668 0 1 Mshowa
.7381 .34918 m
.7381 .35543 L
s
[(1.5)] .7381 .33668 0 1 Mshowa
.97619 .34918 m
.97619 .35543 L
s
[(2)] .97619 .33668 0 1 Mshowa
.125 Mabswid
.07143 .34918 m
.07143 .35293 L
s
.11905 .34918 m
.11905 .35293 L
s
.16667 .34918 m
.16667 .35293 L
s
.21429 .34918 m
.21429 .35293 L
s
.30952 .34918 m
.30952 .35293 L
s
.35714 .34918 m
.35714 .35293 L
s
.40476 .34918 m
.40476 .35293 L
s
.45238 .34918 m
.45238 .35293 L
s
.54762 .34918 m
.54762 .35293 L
s
.59524 .34918 m
.59524 .35293 L
s
.64286 .34918 m
.64286 .35293 L
s
.69048 .34918 m
.69048 .35293 L
s
.78571 .34918 m
.78571 .35293 L
s
.83333 .34918 m
.83333 .35293 L
s
.88095 .34918 m
.88095 .35293 L
s
.92857 .34918 m
.92857 .35293 L
s
.25 Mabswid
0 .34918 m
1 .34918 L
s
.02381 .02206 m
.03006 .02206 L
s
[(-2)] .01131 .02206 1 0 Mshowa
.02381 .10384 m
.03006 .10384 L
s
[(-1.5)] .01131 .10384 1 0 Mshowa
.02381 .18562 m
.03006 .18562 L
s
[(-1)] .01131 .18562 1 0 Mshowa
.02381 .2674 m
.03006 .2674 L
s
[(-0.5)] .01131 .2674 1 0 Mshowa
.02381 .43096 m
.03006 .43096 L
s
[(0.5)] .01131 .43096 1 0 Mshowa
.02381 .51274 m
.03006 .51274 L
s
[(1)] .01131 .51274 1 0 Mshowa
.02381 .59452 m
.03006 .59452 L
s
[(1.5)] .01131 .59452 1 0 Mshowa
.125 Mabswid
.02381 .03841 m
.02756 .03841 L
s
.02381 .05477 m
.02756 .05477 L
s
.02381 .07113 m
.02756 .07113 L
s
.02381 .08748 m
.02756 .08748 L
s
.02381 .1202 m
.02756 .1202 L
s
.02381 .13655 m
.02756 .13655 L
s
.02381 .15291 m
.02756 .15291 L
s
.02381 .16926 m
.02756 .16926 L
s
.02381 .20198 m
.02756 .20198 L
s
.02381 .21833 m
.02756 .21833 L
s
.02381 .23469 m
.02756 .23469 L
s
.02381 .25104 m
.02756 .25104 L
s
.02381 .28376 m
.02756 .28376 L
s
.02381 .30011 m
.02756 .30011 L
s
.02381 .31647 m
.02756 .31647 L
s
.02381 .33283 m
.02756 .33283 L
s
.02381 .36554 m
.02756 .36554 L
s
.02381 .38189 m
.02756 .38189 L
s
.02381 .39825 m
.02756 .39825 L
s
.02381 .41461 m
.02756 .41461 L
s
.02381 .44732 m
.02756 .44732 L
s
.02381 .46367 m
.02756 .46367 L
s
.02381 .48003 m
.02756 .48003 L
s
.02381 .49639 m
.02756 .49639 L
s
.02381 .5291 m
.02756 .5291 L
s
.02381 .54546 m
.02756 .54546 L
s
.02381 .56181 m
.02756 .56181 L
s
.02381 .57817 m
.02756 .57817 L
s
.02381 .0057 m
.02756 .0057 L
s
.02381 .61088 m
.02756 .61088 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34918 m
.06244 .4482 L
.08255 .49357 L
.10458 .53555 L
.12507 .56605 L
.13422 .57681 L
.14415 .58642 L
.14961 .59077 L
.15465 .59421 L
.15937 .59693 L
.16457 .59936 L
.16922 .60105 L
.17359 .6022 L
.17599 .60266 L
.17819 .60298 L
.17941 .60311 L
.18005 .60316 L
.18073 .60321 L
.18198 .60328 L
.18314 .60331 L
.18439 .60332 L
.18509 .60331 L
.18575 .60329 L
.18644 .60326 L
.18708 .60322 L
.1885 .60311 L
.18971 .60298 L
.19103 .60281 L
.19343 .6024 L
.19623 .60178 L
.19921 .60095 L
.20456 .59903 L
.21414 .59423 L
.22473 .587 L
.24407 .56892 L
.26493 .54319 L
.30607 .47768 L
.34569 .40266 L
.3838 .32625 L
.42436 .24667 L
.46341 .17673 L
.50491 .11368 L
.52571 .0874 L
.54489 .06661 L
.56476 .0487 L
.58335 .03536 L
.60212 .02527 L
.61207 .0213 L
.61762 .01949 L
.62276 .01808 L
Mistroke
.62807 .01688 L
.63289 .01602 L
.63824 .01532 L
.64117 .01505 L
.64249 .01496 L
.64393 .01487 L
.6452 .01481 L
.64638 .01477 L
.64763 .01474 L
.64833 .01472 L
.64897 .01472 L
.65011 .01472 L
.65135 .01473 L
.65252 .01475 L
.6536 .01478 L
.65484 .01483 L
.656 .01489 L
.65866 .01507 L
.66125 .01531 L
.66403 .01563 L
.66901 .01637 L
.67363 .01726 L
.68411 .01994 L
.69433 .02345 L
.70523 .02813 L
.72661 .04 L
.74678 .05427 L
.78529 .08896 L
.82627 .13493 L
.86572 .18608 L
.90366 .23984 L
.94405 .30014 L
.97619 .34918 L
Mfstroke
.02381 .34918 m
.06244 .4482 L
.08255 .49357 L
.10458 .53555 L
.12507 .56605 L
.13422 .57681 L
.14415 .58642 L
.14961 .59077 L
.15465 .59421 L
.15937 .59693 L
.16457 .59937 L
.16922 .60105 L
.17359 .6022 L
.17599 .60266 L
.17819 .60298 L
.17941 .60311 L
.18005 .60316 L
.18073 .60321 L
.18198 .60328 L
.18314 .60331 L
.18439 .60332 L
.18509 .60331 L
.18575 .60329 L
.18644 .60326 L
.18708 .60322 L
.1885 .60311 L
.18971 .60298 L
.19103 .60281 L
.19343 .6024 L
.19623 .60178 L
.19921 .60095 L
.20456 .59903 L
.21414 .59423 L
.22473 .587 L
.24407 .56892 L
.26493 .54319 L
.30607 .47768 L
.34569 .40266 L
.3838 .32625 L
.42436 .24667 L
.46341 .17673 L
.50491 .11368 L
.52571 .0874 L
.54489 .06661 L
.56476 .0487 L
.58335 .03536 L
.60212 .02527 L
.61207 .0213 L
.61762 .01949 L
.62276 .01808 L
Mistroke
.62807 .01688 L
.63289 .01602 L
.63824 .01532 L
.64117 .01505 L
.64249 .01496 L
.64393 .01487 L
.6452 .01481 L
.64638 .01477 L
.64763 .01474 L
.64833 .01472 L
.64897 .01472 L
.65011 .01472 L
.65135 .01473 L
.65252 .01475 L
.6536 .01478 L
.65484 .01483 L
.656 .01489 L
.65866 .01507 L
.66125 .01531 L
.66403 .01563 L
.66901 .01637 L
.67363 .01726 L
.68411 .01994 L
.69433 .02345 L
.70523 .02813 L
.72661 .04 L
.74678 .05427 L
.78529 .08896 L
.82627 .13493 L
.86572 .18608 L
.90366 .23984 L
.94405 .30014 L
.97619 .34918 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o9?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo0ol0003ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o
0000ooooooooool0oooooom2ooooo`006Oooool5o`0000Kooooo00?o0000ooooooooool0a?ooool>
o`0006oooooo000Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`31
ooooo`?o00003_ooool3o`0006cooooo000Aooooo`Ko00000oooool00onHV9So8B4Qonk^kP07oooo
o`?o0000_Oooool4o`0001Cooooo0ol0001Yooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo0;[ooooo0ol0000Kooooo`Co0000IOooool001cooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`2hooooo`;o00008_ooool2o`0006?ooooo000Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`0Tooooo`;o0000HOoo
ool001Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0;Gooooo0_l0
000Yooooo`03o`000?oooooooooo05kooooo000Iooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_oo
ool00ol0003oooooooooo`2cooooo`;o0000;?ooool2o`0005kooooo000Tooooo`?o0000/_ooool0
0ol0003oooooooooo`0^ooooo`;o0000G?ooool002Cooooo00?o0000ooooooooool0/?ooool2o`00
03?ooooo00?o0000ooooooooool0FOooool002Cooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`0dooooo`;o0000FOooool002Cooooo00?o0000ooooooooool0[_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo05Kooooo000Tooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`1Eooooo`009?ooool3o`000:cooooo00?o0000
ooooooooool0>oooool2o`0005Gooooo000Tooooo`03o`000?oooooooooo0:_ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1Booooo`009?ooool00ol0003oooooooooo`2Zooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo053ooooo000Tooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1?ooooo`009?ooool3
o`000:Sooooo00?o0000ooooooooool0AOooool2o`0004oooooo000Tooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1<ooooo`009?ooool00ol0003o
ooooooooo`2Vooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Boooool002Cooooo
00?o0000ooooooooool0YOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo04[ooooo
000Tooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`19ooooo`009?ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0B?ooool002Cooooo0ol0002Rooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0Aoooool002Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo04Oooooo000Tooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`16ooooo`002_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool0AOooool000cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`2Oooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0A?ooool00003ooooool0003o000000Co00001Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo0ol0002Nooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool0@oooool000cooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`12ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0@Oooool000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`10ooooo`00
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo043ooooo000:ooooo`03oeEEEOmV
IVKo000000gooooo1?l00006ooooo`?o0000V_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03oooooo000Tooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0nooooo`009?ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0?Oooool002Cooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo03cooooo000Tooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`0kooooo`009?ooool00ol0003ooooooooo
o`2Gooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0>_ooool002Cooooo0ol0002F
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0>_ooool002Cooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo03Wooooo000Tooooo`03
o`000?oooooooooo09Gooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0hooooo`00
9?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
=oooool002Cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo03Oooooo000Tooooo`?o0000Toooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo03Kooooo000Tooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0eooooo`009?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool0=?ooool002Cooooo00?o0000ooooooooool0TOooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo03?ooooo000Tooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`0cooooo`009?ooool00ol0003oooooooooo`2?
ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0<_ooool002Cooooo0ol0002?oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0<Oooool002Cooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo033ooooo000Jooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool0<?ooool001cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0;oooool0017ooooo1_l00005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo02kooooo000Looooo`03o`000?oooooooooo00Gooooo0ol0002<oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0;Oooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool0;Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool0;?ooool001cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0:ooo
ool001[ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo08Oooooo00?o0000ooooooooool0:oooool002Cooooo0ol00029ooooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool0:_ooool002Cooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`2:ooooo`03o`000?oooooooooo02Wooooo000Tooooo`03o`000?oooooooooo08Sooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0Yooooo`009?ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0:?ooool002Cooooo00?o0000
ooooooooool0Q_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo02Oooooo000Toooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Woooo
o`009?ooool3o`0008Gooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Vooooo`00
9?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0
9Oooool002Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`2Booooo`03o`000?oo
oooooooo02Gooooo000Tooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool0Toooool0
0ol0003oooooooooo`0Tooooo`009?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
09Gooooo00?o0000ooooooooool08oooool002Cooooo0ol00023ooooo`03o`000?oooooooooo09Go
oooo00?o0000ooooooooool08oooool002Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo02;ooooo000Tooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`0Qooooo`009?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool08Oooool002Cooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo023ooooo000Tooooo`?o
0000P?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo01oooooo000Tooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0Oooooo`009?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool07_oo
ool000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo01gooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool07Oooool00003ooooool0003o000000Co00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo0:;ooooo00?o0000ooooooooool07?ooool000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001mooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool06oooool000Wooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool06_ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2Uooooo`03
o`000?oooooooooo01[ooooo0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Yoooool00ol0003o
ooooooooo`0Iooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0Hooooo`00
9?ooool3o`0007[ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`0Hooooo`009?oo
ool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool05ooo
ool002Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2/ooooo`03o`000?oooooo
oooo01Kooooo000Tooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0[?ooool00ol0
003oooooooooo`0Fooooo`009?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:ko
oooo00?o0000ooooooooool05Oooool002Cooooo0ol0001hooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`2`ooooo`03o`000?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`0Cooooo`009?ooool00ol0003oooooooooo`10oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Pooooo`03o`000?oooooooooo01kooooo1?l000000ol@413oooooooooo`0oooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0jooooo`03o`00
0?oooooooooo00?ooooo1Ol0000:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0>Oooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@02_ooool002Cooooo00?o0000ooooooooool0@?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h02oooool002Cooooo0ol00010ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03_ooooo00?o0000oooooooo
ool00oooool00onHV9So8B4Qonk^kP0:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00looooo`03o`000?oooooooooo00Cooooo00?oMgMgofIVI_ooool02Oooool0
02Cooooo00?o0000ooooooooool0@?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool002Cooooo00?o0000ooooooooool0@?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`07o`000?oooooo
0000okZj^_ooooooV9RHoa0@400:ooooo`009?ooool00ol0003oooooooooo`10ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0001kooooo00?o0000ooooooooool08Oooool00omEEEGoIVIV
o`000013ooooo`03oeEEEOmVIVKo000000gooooo1?l00010ooooo`06o`000?nHV9So410@o`000?lQ
8B7oc<c<2_ooool002Cooooo0ol0001booooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool03Oooool002Cooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`2mooooo`03o`00
0?oooooooooo00cooooo000Tooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0_ooo
ool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo0;oooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`31ooooo`03o`000?oooooooooo00[ooooo000Moooooooo0000BOl00003ooooo`00
9?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`009?ooool2o`0000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo000Tooooo`;o0000Koooool0
0ol0003oooooooooo`3@ooooo`009?ooool2o`0006oooooo00?o0000ooooooooool0d?ooool002Co
oooo00?o0000ooooool00000KOooool00ol0003oooooooooo`3Aooooo`009?ooool3o`0006gooooo
00?o0000ooooooooool0dOooool002Cooooo00Co0000oooooooooooo0000K?ooool00ol0003ooooo
ooooo`3Aooooo`009?ooool01?l0003oooooooooool0001[ooooo`03o`000?oooooooooo0=;ooooo
000Tooooo`04o`000?ooooooooooo`0006_ooooo00?o0000ooooooooool0d_ooool002Cooooo00Go
0000ooooooooooooooooo`00001Yooooo`03o`000?oooooooooo0=?ooooo000Tooooo`?o000000?o
ooooo`000?ooool0J?ooool00ol0003oooooooooo`3Cooooo`009?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0e?ooool002Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo0=Cooooo000Tooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`3Eooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
eOooool002Cooooo0ol00003ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0e_oo
ool002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooo
oooo0=Kooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`3Gooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0eoooool002Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo0=Sooooo000Tooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`3Hooooo`009?ooool3o`0000Gooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`3Iooooo`009?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool0fOooool002Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0=[ooooo0009ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`3Koooo
o`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
0=_ooooo0009ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`?o00001oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0=cooooo0009ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3Looooo`002Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3Mooooo`002Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0gOooool000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0=kooooo0009ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo0=kooooo000Tooooo`?o00002_ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo0=oooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`3Oooooo`009?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0h?ooool002Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0>3ooooo000Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`3Qooooo`009?ooool3o`00
00cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`3Rooooo`009?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0h_ooool002Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0>?ooooo
000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`3Sooooo`009?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0i?ooool002Cooooo0ol0000>ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0i?ooool002Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo0>Gooooo000Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`3Vooooo`009?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0i_ooool002Cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo0>Oooooo000Tooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3Xooooo`009?ooool3o`00017o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3Xooooo`009?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0jOooool001[ooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`3Yooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3Zooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`3[ooooo`007?ooool00ol0003oooooooooo`05ooooo`?o00005?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo0>_ooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0>cooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo0>gooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0>gooooo000Joooo
o`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo0>kooooo000Tooooo`?o00005oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo0>oooooo000Tooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`3_ooooo`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0l?ooool002Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?3ooooo000Tooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3aooooo`009?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0l_ooool002Cooooo
0ol0000Jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0l_ooool002Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0??ooooo000T
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`3d
ooooo`009?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0mOooool002Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo0?Kooooo000Tooooo`?o00007Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo0?Oooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`3hooooo`009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0nOooool002Cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo0?[ooooo000Tooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3kooooo`009?ooool3o`00027ooooo
0_l0000Oooooo`03o`000?oooooooooo0?cooooo000Tooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`3mooooo`009?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0o_ooool000[ooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo000<oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo0Oooool000co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3oooooo`;ooooo000<ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool01?ooool3o`0002Sooooo0ol0000?ooooo`?o0000
ooooool5ooooo`003?ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`0[ooooo`;o00002oooool2o`000?oooooo2?ooool000cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo1?l0
0003ooooo`Co0000ooooool:ooooo`003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<?ooool4o`000?oooooo3_ooool000[ooooo00?oEEEEofIV
I_l000003Oooool4o`0000Kooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool3o`000?oo
oooo@_ooool002Cooooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003ooooooooo
o`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo002jooooo`05ob4Q8Ol0003o0000odA4A?oMgMd05oooool01OlQ8B7o0000o`00
0?m4A4CogMgM08gooooo002mooooo`03ogMgMolb<S;ooooo01Wooooo00?oMgMgoc8b<_ooool0??oo
ool00ol0003o^[Zjooooo`1=ooooo`00__ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03_ooooo0_lb<S9>ooooo`00AOooool01on7QhOo8B4QooooooooooooA4A4ogMgMoooool00ol0
0002ooooo`03ojVYZOl0003ooooo00Go000000?o<S8bonk^k_ooool01oooool01_nHV9So0000o`00
0?mgMgOo410@o`0000;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2
o`000003oiRHV?l0003o410@00Oooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`04oa0@
4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000001_mEEEGok^k^oooooooooooo
k^k^oeEEE@;o000000?oEEEEonk^k_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEEo`000?l@413o
c<c<o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`Go00000_ooool01_o^k^ko
EEEEo`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@o`000?l000000_ooool01ol0003oooooooooool0003o410@
onk^k_mEEED00_l000001_mEEEGok^k^ooooooooooook^k^oeEEE@;o000000KoV9RHo`000?l@413o
ooooonk^k_mEEED2o`000006odA4A?nj^[[oooooooooool@413o<S8b0_l000000ol@413oZJVYoooo
o`04ooooo`03ohN7Qol0003o^[Zj00_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`06ooooo`Go0000;_ooool004Gooooo00KoIVIVo`000?o^k^koooooo`000?mgMgL2ooooo`06
o`000?ooooooooooooooool@413o^[Zj0_ooool01_l0003oooooooooooo^k^koQhN7oc8b<PSooooo
00Go0000olc<c?o^k^koQhN7o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_mE
EEGoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`05
o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko
EEEEogMgMoooooooooooogMgMomEEED3ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@4105ooooo`03o`000?oooooooooo
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003ooooooeEEEOmgMgL2ooooo`0:ogMgMomEEEGooooooooooomEEEGoMgMgooooooo^k^koEEEE
o`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06o`000?nYZJWooooooooooonj
^[[o00001Oooool00oo<c<co0000oa0@400<ooooo`05o`000?ooooooooooooooool000000_ooool6
o`000006oooooonHV9So8B4Qonk^k_ooooooA4A4;_ooool004Gooooo0_lb<S801?nHV9SoZJVYoa0@
4?lb<S82ooooo`05o`000?oooooooooooiRHV?m4A4@00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Wooooo00Go^[ZjohN7QomVIVKo
IVIVoa0@4003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^
k^ko00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
ooooooooooooonk^k_l00002ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool01?l0003o
ooooooooool00003ooooo`05onk^k_l0003oooooooooool000002?ooool01Onj^[[oQhN7ofIVI_mV
IVKo410@01Cooooo00Go0000ooooooooooooooooo`00000:ooooo`03oiRHV?lQ8B7ok^k^02oooooo
0015ooooo`06oa0@4?nYZJWoEEEEoeEEEOnYZJWo410@0_ooool01Ol0003oEEEEokZj^_l@413ogMgM
00?ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`03okZj^_l@413o000000;o00001?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00008oooo
o`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Kooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ooooooooooooooooonk^k_l00002ooooo`Ko00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?oo
ooooooooo`0000?ooooo00Cok^k^o`000?oooooooooo1_l00002ooooo`06oc8b<_lQ8B7oMgMgogMg
Mon7QhOok^k^5?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^02kooooo0015ooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_ooool01?l0003oV9RH
o`000?nj^[X4ooooo`Co000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000ooooo`03ooooo`05
o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Sooooo00Ko
0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo0000
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00006ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`0:
o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[oMgMgoeEEEOoooooo
ooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;o
oooo00Ko0000okZj^_ooooook^k^ogMgMol0000Dooooo`05o`000?n7QhOoooooojVYZOl000003?oo
ool00omgMgOoIVIVooooo`0]ooooo`00A?ooool00oo<c<co8B4Qooooo`02oeEEE@08oooooolb<S;o
^[Zjooooool0003oooooojVYZOmVIVH4ooooo`05o`000?oooooooooookZj^_l@41002_ooool01?lb
<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RHooooooooooook^k^oeEE
EOl0003o410@olc<c?l000002?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000?ooooo00Go0000
ogMgMol0003o0000oiRHV002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool02?o^k^ko
EEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004ooooo`03oa0@4?l0003o000000Cooooo00?o
410@o`000?mgMgL00_l000002_nHV9Soooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@4105
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0oooool00ol@413o0000o`000004ooooo`0:onk^
k_mEEEGo0000ob4Q8OnYZJWo0000oa0@4?ooooook^k^oeEEE@;o000000OoA4A4onk^k_oooooooooo
oa0@4?l0003oMgMg00;o000000goV9RHooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY
ooooooo^k^koEEEE00;o000000[oEEEEonk^k_ooooooooooonk^k_mEEEGo0000oa0@4?o<c<co0000
0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0
000Cooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool02oooool00ol0003ooooooooo
o`0/ooooo`00A?ooool00onYZJWo<S8booooo`03ooooo`04odA4A?nHV9Soooooo`0000;ooooo00?o
ZJVYoeEEEOo^k^h00_ooool01Ol0003ooooooooooonj^[[o000001kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
<?ooool01Ol0003o^[ZjoooooonHV9So410@02kooooo0014ooooo`?o00000_ooool6o`000005oooo
ool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0;_ooool007Oooooo0_l0000@ooooo`03oa0@4?l0003ooooo023ooooo00?o410@oooooooo
ool08Oooool00ol@413oooooooooo`0^ooooo`;o0000IOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.23606, -2.13488, \
0.00802016, 0.0233497}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.282148 0.150351 [
[.2619 .26965 -9 -9 ]
[.2619 .26965 9 0 ]
[.5 .26965 -3 -9 ]
[.5 .26965 3 0 ]
[.7381 .26965 -9 -9 ]
[.7381 .26965 9 0 ]
[.97619 .26965 -3 -9 ]
[.97619 .26965 3 0 ]
[.01131 .1318 -12 -4.5 ]
[.01131 .1318 0 4.5 ]
[.01131 .4325 -6 -4.5 ]
[.01131 .4325 0 4.5 ]
[.01131 .58285 -6 -4.5 ]
[.01131 .58285 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .28215 m
.2619 .2884 L
s
[(0.5)] .2619 .26965 0 1 Mshowa
.5 .28215 m
.5 .2884 L
s
[(1)] .5 .26965 0 1 Mshowa
.7381 .28215 m
.7381 .2884 L
s
[(1.5)] .7381 .26965 0 1 Mshowa
.97619 .28215 m
.97619 .2884 L
s
[(2)] .97619 .26965 0 1 Mshowa
.125 Mabswid
.07143 .28215 m
.07143 .2859 L
s
.11905 .28215 m
.11905 .2859 L
s
.16667 .28215 m
.16667 .2859 L
s
.21429 .28215 m
.21429 .2859 L
s
.30952 .28215 m
.30952 .2859 L
s
.35714 .28215 m
.35714 .2859 L
s
.40476 .28215 m
.40476 .2859 L
s
.45238 .28215 m
.45238 .2859 L
s
.54762 .28215 m
.54762 .2859 L
s
.59524 .28215 m
.59524 .2859 L
s
.64286 .28215 m
.64286 .2859 L
s
.69048 .28215 m
.69048 .2859 L
s
.78571 .28215 m
.78571 .2859 L
s
.83333 .28215 m
.83333 .2859 L
s
.88095 .28215 m
.88095 .2859 L
s
.92857 .28215 m
.92857 .2859 L
s
.25 Mabswid
0 .28215 m
1 .28215 L
s
.02381 .1318 m
.03006 .1318 L
s
[(-1)] .01131 .1318 1 0 Mshowa
.02381 .4325 m
.03006 .4325 L
s
[(1)] .01131 .4325 1 0 Mshowa
.02381 .58285 m
.03006 .58285 L
s
[(2)] .01131 .58285 1 0 Mshowa
.125 Mabswid
.02381 .16187 m
.02756 .16187 L
s
.02381 .19194 m
.02756 .19194 L
s
.02381 .22201 m
.02756 .22201 L
s
.02381 .25208 m
.02756 .25208 L
s
.02381 .31222 m
.02756 .31222 L
s
.02381 .34229 m
.02756 .34229 L
s
.02381 .37236 m
.02756 .37236 L
s
.02381 .40243 m
.02756 .40243 L
s
.02381 .46257 m
.02756 .46257 L
s
.02381 .49264 m
.02756 .49264 L
s
.02381 .52271 m
.02756 .52271 L
s
.02381 .55278 m
.02756 .55278 L
s
.02381 .10173 m
.02756 .10173 L
s
.02381 .07166 m
.02756 .07166 L
s
.02381 .04159 m
.02756 .04159 L
s
.02381 .01152 m
.02756 .01152 L
s
.02381 .61292 m
.02756 .61292 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28215 m
.04262 .34962 L
.06244 .41301 L
.08255 .46283 L
.08806 .47334 L
.09396 .48296 L
.09948 .49041 L
.10458 .49593 L
.10954 .50002 L
.11204 .50161 L
.1148 .50299 L
.11621 .50355 L
.11755 .50399 L
.1191 .50438 L
.11979 .50451 L
.12052 .50463 L
.12122 .50472 L
.12185 .50478 L
.12309 .50483 L
.12378 .50483 L
.12453 .5048 L
.12523 .50475 L
.12589 .50468 L
.12705 .5045 L
.1283 .50424 L
.13055 .50357 L
.13323 .50246 L
.13568 .50115 L
.14099 .49734 L
.14603 .49256 L
.15568 .48036 L
.16593 .46336 L
.18435 .42395 L
.22211 .31943 L
.26231 .19888 L
.301 .10019 L
.32104 .06197 L
.33124 .04662 L
.34214 .03348 L
.34746 .02831 L
.35248 .0242 L
.35737 .0209 L
.36188 .01849 L
.36616 .01675 L
.36832 .01607 L
.37069 .01549 L
.37191 .01525 L
.37307 .01507 L
.37371 .01498 L
.37441 .0149 L
Mistroke
.37563 .0148 L
.37679 .01474 L
.37802 .01472 L
.37919 .01473 L
.38024 .01479 L
.38145 .01488 L
.38258 .01501 L
.38381 .01519 L
.38513 .01544 L
.38784 .01608 L
.39029 .01685 L
.39504 .0188 L
.39953 .0212 L
.40952 .02845 L
.42036 .03917 L
.44018 .06575 L
.4612 .1025 L
.499 .18495 L
.53926 .28499 L
.578 .38123 L
.61919 .47225 L
.63975 .51047 L
.65886 .54066 L
.67851 .56581 L
.69702 .58375 L
.70687 .59094 L
.71205 .59407 L
.71752 .59688 L
.72214 .59885 L
.72721 .6006 L
.73181 .60181 L
.7339 .60224 L
.73612 .60262 L
.73735 .6028 L
.73872 .60296 L
.73997 .60309 L
.74112 .60318 L
.74176 .60322 L
.74247 .60325 L
.74317 .60328 L
.74392 .6033 L
.74458 .60331 L
.74529 .60332 L
.74656 .6033 L
.74783 .60326 L
.74855 .60323 L
.74922 .60319 L
.75044 .6031 L
.75174 .60297 L
.75398 .60269 L
Mistroke
.75645 .60229 L
.76107 .60128 L
.76603 .5998 L
.775 .59616 L
.78511 .59056 L
.79615 .58272 L
.81624 .56406 L
.85691 .51094 L
.89606 .44438 L
.93766 .3627 L
.97619 .28215 L
Mfstroke
.02381 .28215 m
.04262 .34962 L
.06244 .41301 L
.08255 .46283 L
.08806 .47334 L
.09396 .48296 L
.09948 .49041 L
.10458 .49593 L
.10954 .50002 L
.11204 .50161 L
.1148 .50299 L
.11621 .50355 L
.11755 .50399 L
.1191 .50438 L
.11979 .50451 L
.12052 .50463 L
.12122 .50472 L
.12185 .50478 L
.12309 .50483 L
.12378 .50483 L
.12453 .5048 L
.12523 .50475 L
.12589 .50468 L
.12705 .5045 L
.1283 .50424 L
.13055 .50357 L
.13323 .50246 L
.13568 .50115 L
.14099 .49734 L
.14603 .49256 L
.15568 .48036 L
.16593 .46336 L
.18435 .42395 L
.22211 .31943 L
.26231 .19888 L
.301 .10019 L
.32104 .06197 L
.33124 .04662 L
.34214 .03348 L
.34746 .02831 L
.35248 .0242 L
.35737 .0209 L
.36188 .01849 L
.36616 .01675 L
.36832 .01607 L
.37069 .01549 L
.37191 .01525 L
.37307 .01507 L
.37371 .01498 L
.37441 .0149 L
Mistroke
.37563 .0148 L
.37679 .01474 L
.37802 .01472 L
.37919 .01473 L
.38024 .01479 L
.38145 .01488 L
.38258 .01501 L
.38381 .01519 L
.38513 .01544 L
.38784 .01608 L
.39029 .01685 L
.39504 .0188 L
.39953 .0212 L
.40952 .02845 L
.42036 .03917 L
.44018 .06574 L
.4612 .1025 L
.499 .18495 L
.53926 .28499 L
.578 .38123 L
.61919 .47225 L
.63975 .51047 L
.65886 .54066 L
.67851 .56581 L
.69702 .58375 L
.70687 .59094 L
.71205 .59407 L
.71752 .59688 L
.72214 .59885 L
.72721 .6006 L
.73181 .60181 L
.7339 .60224 L
.73612 .60262 L
.73735 .6028 L
.73872 .60296 L
.73997 .60309 L
.74112 .60318 L
.74176 .60322 L
.74247 .60325 L
.74317 .60328 L
.74392 .6033 L
.74458 .60332 L
.74529 .60332 L
.74656 .60331 L
.74783 .60326 L
.74855 .60323 L
.74922 .60319 L
.75044 .6031 L
.75174 .60297 L
.75398 .60269 L
Mistroke
.75645 .60229 L
.76107 .60128 L
.76603 .5998 L
.775 .59616 L
.78511 .59056 L
.79615 .58272 L
.81624 .56406 L
.85691 .51094 L
.89606 .44438 L
.93766 .3627 L
.97619 .28215 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o7Oooool0
0ol0003oooooooooo`3oooooodWooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001go
oooo00?o0000ooooooooool0oooooom9ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo
000Mooooo`;o0000oooooom:ooooo`007Oooool00ol0003oooooooooo`1^ooooo`Oo0000doooool0
01gooooo00?o0000ooooooooool0Joooool3o`0000Oooooo0ol0003@ooooo`007Oooool00ol0003o
ooooooooo`1Yooooo`;o00003Oooool2o`000<kooooo000Mooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`3;ooooo`007Oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0b_ooool001gooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<Wooooo000Moooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`38oooo
o`007Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0aoooool001gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo0<Kooooo000Mooooo`;o0000Hoooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0<Kooooo000Mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`35ooooo`007Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0a?ooool001gooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo0<Cooooo000Mooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`33ooooo`007Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0`_ooool001gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0<;ooooo000Moooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`31oooo
o`007Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0`?ooool001gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0<3ooooo000Mooooo`;o0000GOooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0;oooooo000Mooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2oooooo`007Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0__ooool001gooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0;gooooo000Mooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2mooooo`007Oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0_?ooool001gooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0;cooooo000Moooo
o`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2koooo
o`007Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0^_ooool001gooooo0_l0001Iooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
^_ooool001gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo0;Wooooo000Mooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`2iooooo`007Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0^?ooool001gooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo0;Sooooo000Mooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2gooooo`007Oooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0]oooool001gooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0;Oooooo000Coooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0]_ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0]_ooool000[ooooo
1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0001Dooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0]Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0]Oooool001Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0]?ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]?ooool001Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0/oooool001?ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0/oooool001gooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0;?ooooo000Mooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2booooo`007Oooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0/_ooool001go
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;7o
oooo000Mooooo`;o0000DOooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;7ooooo
000Mooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`2`ooooo`007Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0/?ooool001gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo0:oooooo000Mooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`2_ooooo`007Oooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0[oooool001gooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:kooooo000Mooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2^ooooo`007Oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0[Oooool001go
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo0:go
oooo000Mooooo`;o0000COooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0:cooooo
000Mooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2/ooooo`007Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0Zoooool001gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo0:_ooooo000Mooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`2[ooooo`007Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0Z_ooool001gooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0:[ooooo000Mooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Yooooo`007Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0ZOooool001go
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:So
oooo000Mooooo`;o0000B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:Sooooo
000Mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`2Xooooo`007Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool0Yoooool001gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo0:Oooooo000Mooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`2Vooooo`007Oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0Y_ooool001gooooo00?o0000ooooooooool0@?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0@Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooooooo
ool0>_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0@?ooool5o`00017ooooo000Mooooo`03o`000?oooooooooo043ooooo00OoMgMgoiRHV?oo
ooooV9RHogMgMooooooo000000?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo04;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Cooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo03oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Aooooo`007Oooool0
0ol0003oooooooooo`10ooooo`07oa0@4?ooooooooooooooool@413oooooo`00000>ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0?oooool00onHV9So8B4Qonk^kP0Booooo`007Ooo
ool00ol0003oooooooooo`10ooooo`07o`000?ooooooooooooooool0003oooooo`00000=ooooo`03
ogMgMolb<S;ooooo04;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0@Oooool00onHV9So8B4Qonk^kP0Aooooo`00
7Oooool2o`00047ooooo00Co0000oooooooooooooooo0_l0000;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0@oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<04?ooooo00?oMgMgofIVI_ooool04?ooool0
01gooooo00?o0000ooooooooool0@?ooool01_l@413ooooooooooooooooo410@o`0000_ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00oooooo000M
ooooo`03o`000?oooooooooo043ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0000;ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0@_ooool01Ol0003o^[ZjoooooonHV9So410@017o
oooo000Mooooo`03o`000?oooooooooo043ooooo00Gok^k^oc8b<_l0003o<S8bo`00000<ooooo`Co
0000@_ooool00omEEEGoIVIVo`000009ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l0
00003Oooool4o`00047ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`007Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0X_ooool001gooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0:7ooooo
000Mooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`2Qooooo`007Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool0XOooool001gooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo0:3ooooo000Eoooooooo0000BOl0000;ooooo`007Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0@ooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool2o`0001;ooooo000Mooooo`;o0000@_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo04[ooooo0_l0000Booooo`007Oooool2o`0004;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo01;ooooo000Mooooo`;o
0000@_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool04_ooool001gooooo0_l00011ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`0Cooooo`007Oooool00ol0003oooooo`000010ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Cooooo`007Oooool0
0ol0003oooooo`000010ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Q_ooool0
0ol0003oooooooooo`0Dooooo`007Oooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Dooooo`007Oooool3o`0003oo
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo01Go
oooo000Mooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo01Gooooo000Mooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo01Ko
oooo000Mooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0JOooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo01Kooooo000Mooooo`05o`000?ooooooooooooooool0
0000??ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo083ooooo00?o0000oooooooo
ool05oooool001gooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0Gooooo`007Oooool01Ol0003ooooo
oooooooooooo000003_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo01Oooooo000Mooooo`05o`000?ooooooooooooooool00000>oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool06?ooool001gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Hooooo`007Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo01Wooooo000Mooooo`;o00000oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0I
ooooo`007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01[ooooo000Mooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo07[ooooo00?o0000ooooooooool06_ooool001gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`0Kooooo`007Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooooooo01_ooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool07?ooool0
01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
07?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Looooo`007Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo01gooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooooooool07Oooool001gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`0Nooooo`007Oooool2o`0000Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool07_ooool001gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0Oooooo`007Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo01oooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
8?ooool001gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0Pooooo`007Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo027ooooo000Mooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`0Rooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02;ooooo
000Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool08oooool001gooooo0_l00009
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ooooool09?ooool001gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Uooooo`00
7Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
02Oooooo000Cooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo02Oooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0Xooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0:?ooool001Gooooo00?o0000ooooooooool01Oooool3
o`0000cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0:Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02Wooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Zooooo`005Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0:_ooool001?ooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02_ooooo000M
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2;
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0:oooool001gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`1Hooooo`03
o`000?oooooooooo02gooooo000Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
;Oooool001gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0^ooooo`007Oooool2
o`00017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool0;_ooool001gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`0_ooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo033o
oooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`2Dooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0<?ooool001gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0aooooo`007Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0<_ooool001gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo09Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0cooooo`00
7Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03?ooooo000Mooooo`;o00005ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0dooooo`007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo03Gooooo000Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool2o`00
0:3ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0eooooo`007Oooool00ol0003o
ooooooooo`0Iooooo`;o00001_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0=_ooool001gooooo00?o0000ooooooooool06oooool7o`000:?ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0fooooo`007Oooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0=oooool001gooooo00?o0000
ooooooooool0a_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03Sooooo000Moooo
o`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0hoooo
o`007Oooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0>Oooool001gooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo03[ooooo000Mooooo`;o0000bOooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03_ooooo000Mooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0kooooo`007Oooool00ol0003oooooooooo`3:ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0??ooool001gooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03gooooo000Mooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0mooooo`007Oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?_ooool001gooooo00?o0000
ooooooooool0cOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo000Moooo
o`03o`000?oooooooooo0<gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`10oooo
o`007Oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0@?ooool001gooooo00?o0000ooooooooool0coooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo047ooooo000Mooooo`;o0000dOooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo04;ooooo000Mooooo`03o`000?oooooooooo0=3ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`12ooooo`007Oooool00ol0003oooooooooo`3Aooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0@oooool001gooooo00?o0000ooooooooool0d_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo04Cooooo000Mooooo`03o`000?oooooooooo0=?ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`15ooooo`007Oooool00ol0003ooooooooo
o`3Dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0A_ooool001gooooo00?o0000
ooooooooool0eOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Oooooo000Boooo
o`Go00001_ooool00ol0003oooooooooo`3Fooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0B?ooool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0=Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`19ooooo`004oooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0=Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1:ooooo`005?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000fOooool00ol0003ooooo
ooooo`0Mooooo`;o0000COooool001Gooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`3Jooooo`03o`000?oooooooooo01[ooooo0_l0001?ooooo`005_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0=_ooooo00?o0000ooooooooool05oooool2o`00057ooooo000Boooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`3Looooo`;o00005_ooool0
0ol0003oooooooooo`1Aooooo`004_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0g_ooool3o`00017ooooo0_l0001Dooooo`007Oooool00ol0003oooooooooo`3Qoooo
o`;o00003?ooool3o`0005Kooooo000Mooooo`03o`000?oooooooooo0>?ooooo1Ol00003ooooo`Co
0000FOooool001gooooo00?o0000ooooooooool0ioooool5o`0005cooooo000Mooooo`03o`000?oo
oooooooo0?ooooooBOooool001gooooo00?o0000ooooooooool0oooooom9ooooo`007Oooool2o`00
0?ooooooB_ooool001gooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/oooool01OlQ8B7o0000
o`000?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo
<S8booooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bEOooool003kooooo00Oo
QhN7ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000ooooo`05o`000003
oc8b<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o
0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?oooooo
k^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2
o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o
000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_oooooo
ooooonk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooo
oooooooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01_ooool01OnHV9So410@o`000?lb<S;o
c<c<03Gooooo000nooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003ooooooooo
oooooooo410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<co
k^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo
00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_ooool01Ol@
413o^[ZjoooooomgMgOo<S8b03Gooooo000nooooo`;o<S8b00CoV9RHojVYZOl@413o<S8b0_ooool0
1Ol0003ooooooooooonHV9SoA4A400?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Ko0000ooooooooooooooooonk^k_l00009ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooooo^
k^ko00000_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo0000
0oooool01Oo^k^ko0000oooooooooooo000000Sooooo00Go^[ZjohN7QomVIVKoIVIVoa0@400Eoooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0cooooo`00?_ooool01_l@
413oZJVYoeEEEOmEEEGoZJVYoa0@40;ooooo00Go0000oeEEEOnj^[[o410@omgMg@03ooooo`06o`00
0?ooooooooooonk^k_n7QhOo<S8b2?ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00002?ooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
ooooooooonk^k_l00005ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooooooooo^k^ko00000_ooool6o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00003
ooooo`04onk^k_l0003oooooooooo`Ko00000_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kQGo
oooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Gooooo00?oZJVYoa0@4?ooool0=?ooool0
03kooooo00Ko0000oooooolQ8B7o410@ooooool00002ooooo`04o`000?nHV9So0000okZj^PCooooo
1?l000000omEEEGok^k^ooooo`0:ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7Qooooooo
ZJVYo`000002ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00002?ooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000?ooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooo
oomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGo
MgMgooooooo^k^koEEEEo`0000Gooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85ooooo`03o`00
0?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^
oooooon7QhOo<S8b0oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4QoooooomEEEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIVogMgMooo
ooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0001Gooooo00Go0000ohN7QoooooooZJVYo`00000;ooooo`03oa0@4?l0003o
^[Zj03Gooooo000mooooo`03olc<c?lQ8B7ooooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?oo
ooooZJVYofIVIPCooooo00Go0000oooooooooooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRH
V0?ooooo00?o410@o`000?mgMgL00_l000002OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<
o`000008ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003o
V9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mE
EEGok^k^ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02
o`00000:oiRHV?ooooooooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h3ooooo`03oa0@4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4Q
ojVYZOl0003o410@ooooooo^k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL0
0_l000003OnHV9Sooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED0
0_l000002_mEEEGok^k^ooooooooooook^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@
o`000?mgMgL00_l000000onHV9Soooooooooo`0:ooooo`03okZj^_lQ8B7ooooo03Cooooo000moooo
o`03ojVYZOlb<S;ooooo00?ooooo00CoA4A4oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02
ooooo`05o`000?oooooooooookZj^_l000007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0aooooo`05oa0@4?nH
V9SooooookZj^_l00000=Oooool003gooooo0ol00002ooooo`Ko000000Goooooo`000?l0003o0000
ooooo`04o`000003oa0@4?nYZJWooooo01gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo037ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0eooooo`00
L?ooool2o`00013ooooo00?o410@o`000?ooool08?ooool00ol@413oooooooooo`0Pooooo`03oa0@
4?oooooooooo02kooooo0_l0001]ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.187939, -1.87662, \
0.00802016, 0.0254013}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.329193 0.143993 [
[.2619 .31669 -9 -9 ]
[.2619 .31669 9 0 ]
[.5 .31669 -3 -9 ]
[.5 .31669 3 0 ]
[.7381 .31669 -9 -9 ]
[.7381 .31669 9 0 ]
[.97619 .31669 -3 -9 ]
[.97619 .31669 3 0 ]
[.01131 .04121 -12 -4.5 ]
[.01131 .04121 0 4.5 ]
[.01131 .1852 -12 -4.5 ]
[.01131 .1852 0 4.5 ]
[.01131 .47319 -6 -4.5 ]
[.01131 .47319 0 4.5 ]
[.01131 .61718 -6 -4.5 ]
[.01131 .61718 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .32919 m
.2619 .33544 L
s
[(0.5)] .2619 .31669 0 1 Mshowa
.5 .32919 m
.5 .33544 L
s
[(1)] .5 .31669 0 1 Mshowa
.7381 .32919 m
.7381 .33544 L
s
[(1.5)] .7381 .31669 0 1 Mshowa
.97619 .32919 m
.97619 .33544 L
s
[(2)] .97619 .31669 0 1 Mshowa
.125 Mabswid
.07143 .32919 m
.07143 .33294 L
s
.11905 .32919 m
.11905 .33294 L
s
.16667 .32919 m
.16667 .33294 L
s
.21429 .32919 m
.21429 .33294 L
s
.30952 .32919 m
.30952 .33294 L
s
.35714 .32919 m
.35714 .33294 L
s
.40476 .32919 m
.40476 .33294 L
s
.45238 .32919 m
.45238 .33294 L
s
.54762 .32919 m
.54762 .33294 L
s
.59524 .32919 m
.59524 .33294 L
s
.64286 .32919 m
.64286 .33294 L
s
.69048 .32919 m
.69048 .33294 L
s
.78571 .32919 m
.78571 .33294 L
s
.83333 .32919 m
.83333 .33294 L
s
.88095 .32919 m
.88095 .33294 L
s
.92857 .32919 m
.92857 .33294 L
s
.25 Mabswid
0 .32919 m
1 .32919 L
s
.02381 .04121 m
.03006 .04121 L
s
[(-2)] .01131 .04121 1 0 Mshowa
.02381 .1852 m
.03006 .1852 L
s
[(-1)] .01131 .1852 1 0 Mshowa
.02381 .47319 m
.03006 .47319 L
s
[(1)] .01131 .47319 1 0 Mshowa
.02381 .61718 m
.03006 .61718 L
s
[(2)] .01131 .61718 1 0 Mshowa
.125 Mabswid
.02381 .07 m
.02756 .07 L
s
.02381 .0988 m
.02756 .0988 L
s
.02381 .1276 m
.02756 .1276 L
s
.02381 .1564 m
.02756 .1564 L
s
.02381 .214 m
.02756 .214 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .2716 m
.02756 .2716 L
s
.02381 .30039 m
.02756 .30039 L
s
.02381 .35799 m
.02756 .35799 L
s
.02381 .38679 m
.02756 .38679 L
s
.02381 .41559 m
.02756 .41559 L
s
.02381 .44439 m
.02756 .44439 L
s
.02381 .50198 m
.02756 .50198 L
s
.02381 .53078 m
.02756 .53078 L
s
.02381 .55958 m
.02756 .55958 L
s
.02381 .58838 m
.02756 .58838 L
s
.02381 .01241 m
.02756 .01241 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32919 m
.04262 .41412 L
.0522 .45218 L
.06244 .48646 L
.0679 .50147 L
.07286 .51297 L
.0779 .52246 L
.08255 .5292 L
.08519 .53213 L
.08798 .53455 L
.08943 .53551 L
.09079 .53624 L
.09228 .53685 L
.09311 .5371 L
.09388 .53728 L
.09453 .53739 L
.09524 .53746 L
.0965 .53747 L
.09727 .53741 L
.098 .5373 L
.09866 .53716 L
.09936 .53697 L
.10068 .53649 L
.10208 .53582 L
.10458 .53418 L
.10713 .53196 L
.10954 .52935 L
.11406 .52316 L
.12422 .50347 L
.133 .48072 L
.14255 .45092 L
.18333 .29269 L
.20359 .21549 L
.2226 .15559 L
.23145 .13355 L
.24077 .11499 L
.24565 .10727 L
.25098 .10046 L
.25584 .09576 L
.25803 .09411 L
.26035 .09268 L
.2616 .09204 L
.26298 .09146 L
.26424 .09102 L
.2654 .09071 L
.26605 .09056 L
.26676 .09044 L
.26751 .09034 L
.26823 .09028 L
.26889 .09025 L
Mistroke
.2696 .09024 L
.27087 .09031 L
.27216 .09048 L
.27289 .09062 L
.27356 .09078 L
.27477 .09113 L
.27609 .09161 L
.27838 .09268 L
.28081 .09415 L
.28545 .09791 L
.29043 .10326 L
.2994 .11622 L
.3096 .13576 L
.32068 .16212 L
.34081 .22085 L
.38164 .36186 L
.40194 .4311 L
.42096 .48933 L
.43939 .53632 L
.45876 .57327 L
.46843 .58639 L
.4739 .59218 L
.47899 .59648 L
.48368 .59952 L
.48795 .60151 L
.49031 .6023 L
.49164 .60265 L
.49287 .6029 L
.49394 .60307 L
.49512 .60321 L
.49635 .6033 L
.4975 .60332 L
.49876 .60328 L
.4994 .60324 L
.5001 .60318 L
.50134 .60302 L
.5025 .60281 L
.50512 .60215 L
.50659 .60166 L
.50794 .60114 L
.51276 .59871 L
.51783 .59519 L
.52669 .58679 L
.53638 .57443 L
.55597 .5403 L
.57691 .49235 L
.61837 .37452 L
.65832 .25212 L
.69676 .14609 L
.71622 .10175 L
Mistroke
.73765 .06251 L
.74744 .04826 L
.75798 .03568 L
.76792 .02648 L
.77702 .02037 L
.78179 .01805 L
.78441 .01704 L
.78687 .01625 L
.78918 .01566 L
.79039 .01541 L
.79167 .01519 L
.79275 .01503 L
.79393 .0149 L
.79501 .01481 L
.79602 .01475 L
.7973 .01472 L
.79803 .01472 L
.7987 .01473 L
.79994 .01478 L
.80125 .01488 L
.80242 .01501 L
.80352 .01517 L
.80602 .01563 L
.80872 .01632 L
.81118 .01711 L
.81674 .01946 L
.82149 .02209 L
.82656 .02551 L
.83568 .03323 L
.85639 .05784 L
.87775 .09252 L
.89791 .1326 L
.93639 .22382 L
.97619 .32919 L
Mfstroke
.02381 .32919 m
.04262 .41412 L
.0522 .45218 L
.06244 .48646 L
.0679 .50147 L
.07286 .51297 L
.0779 .52246 L
.08255 .5292 L
.08519 .53213 L
.08798 .53455 L
.08943 .53551 L
.09079 .53625 L
.09228 .53685 L
.09311 .5371 L
.09388 .53728 L
.09453 .53739 L
.09524 .53746 L
.0965 .53747 L
.09727 .53741 L
.098 .5373 L
.09866 .53716 L
.09936 .53697 L
.10068 .53649 L
.10208 .53582 L
.10458 .53418 L
.10713 .53196 L
.10954 .52935 L
.11406 .52316 L
.12422 .50348 L
.133 .48072 L
.14255 .45092 L
.18333 .29269 L
.20359 .21549 L
.2226 .15559 L
.23145 .13355 L
.24077 .11499 L
.24565 .10727 L
.25098 .10046 L
.25584 .09576 L
.25803 .09411 L
.26035 .09268 L
.2616 .09204 L
.26298 .09146 L
.26424 .09102 L
.2654 .09071 L
.26605 .09056 L
.26676 .09044 L
.26751 .09034 L
.26823 .09028 L
.26889 .09025 L
Mistroke
.2696 .09024 L
.27087 .09031 L
.27216 .09048 L
.27289 .09062 L
.27356 .09078 L
.27477 .09113 L
.27609 .09161 L
.27838 .09268 L
.28081 .09415 L
.28545 .09791 L
.29043 .10326 L
.2994 .11622 L
.3096 .13576 L
.32068 .16212 L
.34081 .22085 L
.38164 .36186 L
.40194 .4311 L
.42096 .48933 L
.43939 .53632 L
.45876 .57327 L
.46843 .58639 L
.4739 .59218 L
.47899 .59648 L
.48368 .59952 L
.48795 .60152 L
.49031 .6023 L
.49164 .60265 L
.49287 .6029 L
.49394 .60307 L
.49512 .60321 L
.49635 .6033 L
.4975 .60332 L
.49876 .60328 L
.4994 .60324 L
.5001 .60318 L
.50134 .60302 L
.5025 .60281 L
.50512 .60215 L
.50659 .60166 L
.50794 .60114 L
.51276 .59871 L
.51783 .59519 L
.52669 .58679 L
.53638 .57443 L
.55597 .5403 L
.57691 .49235 L
.61837 .37452 L
.65832 .25212 L
.69676 .14609 L
.71622 .10175 L
Mistroke
.73765 .06251 L
.74744 .04826 L
.75798 .03569 L
.76792 .02648 L
.77702 .02038 L
.78179 .01806 L
.78441 .01704 L
.78687 .01625 L
.78918 .01567 L
.79039 .01541 L
.79167 .01519 L
.79275 .01503 L
.79393 .0149 L
.79501 .01481 L
.79602 .01475 L
.7973 .01472 L
.79803 .01472 L
.7987 .01473 L
.79994 .01478 L
.80125 .01489 L
.80242 .01501 L
.80352 .01517 L
.80602 .01563 L
.80872 .01632 L
.81118 .01711 L
.81674 .01946 L
.82149 .02209 L
.82656 .02551 L
.83568 .03323 L
.85639 .05784 L
.87775 .09252 L
.89791 .1326 L
.93639 .22382 L
.97619 .32919 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o7Oooool0
0ol0003oooooooooo`3oooooodWooooo000Mooooo`03o`000?oooooooooo0?ooooooBOooool001go
oooo00?o0000ooooooooool0oooooom9ooooo`007Oooool00ol0003oooooooooo`3oooooodWooooo
000Mooooo`;o0000oooooom:ooooo`007Oooool00ol0003oooooooooo`3gooooo`So0000BOooool0
01gooooo00?o0000ooooooooool0m?ooool3o`0000Sooooo0ol00016ooooo`007Oooool00ol0003o
ooooooooo`3booooo`;o00003_ooool2o`0004Cooooo000Mooooo`03o`000?oooooooooo0?7ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`11ooooo`007Oooool00ol0003ooooooooo
o`3`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@?ooool001gooooo00?o0000
ooooooooool0koooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03oooooo000Boooo
o`Go00001_ooool00ol0003oooooooooo`3^ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0?_ooool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0nooooo`002_ooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0?Oooool001Cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000>cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0looooo`005Oooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo0>_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0kooooo`005_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>[ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0kooooo`004_ooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0j_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03[ooooo000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3Y
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0>Oooool001gooooo00?o0000oooo
ooooool0j?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo000Mooooo`03
o`000?oooooooooo0>Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`00
7Oooool00ol0003oooooooooo`3Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
=oooool001gooooo00?o0000ooooooooool0i_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo03Kooooo000Mooooo`;o0000i_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo000Mooooo`03o`000?oooooooooo0>Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`007Oooool00ol0003oooooooooo`3Tooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0=?ooool001gooooo00?o0000ooooooooool0hoooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03Cooooo000Mooooo`03o`000?oooooooooo0>?ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0cooooo`007Oooool00ol0003oooooooooo`3R
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<oooool001gooooo00?o0000oooo
ooooool0h_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03;ooooo000Mooooo`03
o`000?oooooooooo04[ooooo1ol0002@ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0<Oooool001gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`007Ooo
ool2o`0004Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2;ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0<?ooool001gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0`ooooo`007Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02oooooo000Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001gooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo02kooooo000Mooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0;Oooool001gooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0]oooo
o`007Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02cooooo000Mooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool001gooooo0_l00013ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02_ooooo000Mooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:oooool0
01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Zooooo`007Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0OOooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo02[ooooo000Mooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Yooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Wooooo000Moooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Xooooo`007Oooool2o`0003oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
9oooool001gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Wooooo`007Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Gooooo
000Mooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09Oooool001?ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09?ooool0
01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
02Cooooo000:ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool09?ooool001Gooooo00?o0000ooooooooool01Oooool3o`0003_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool08oooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02?ooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool08_ooool001?ooooo00?oEEEEofIVI_l0
00001oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Qooooo`007Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo023ooooo000Mooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool08?ooool001go
oooo0_l0000iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01oooooo000Mooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Oooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01kooooo000Moooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07_ooool001gooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`0Mooooo`007Oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo01gooooo000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07Ooo
ool001gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Looooo`007Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo01cooooo000Mooooo`;o0000=oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`0Kooooo`007Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_ooooo
000Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06oooool001gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`007Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Mooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool06Oooool001gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`007Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool06?ooool001gooooo0_l0000dooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
01Sooooo000Mooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05oooool001gooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Gooooo`007Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo01Oooooo000Mooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool05_ooool001gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Foooo
o`007Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Gooooo00?o0000
ooooooooool0:Oooool4o`000003oa0@4?oooooooooo02[ooooo00?o0000ooooooooool04_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?_oo
ool00ol0003oooooo`000004o`00017ooooo000Mooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo01Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?Ooo
ool01ol0003ooooooiRHV?lQ8B7ok^k^oooooom4A4@04Oooool001gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0<ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool01_l0003o
oooooooooonHV9So8B4Qonk^kQ;ooooo000Mooooo`;o0000<_ooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool0?_ooool01_l0003ooooooooooonHV9So8B4Qonk^kQ7ooooo
000Mooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`06o`000?oooooooooooooooomgMgOoIVIV4Ooo
ool001gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo0000017ooooo000Mooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04;ooooo
00Go0000okZj^_ooooooV9RHoa0@400Aooooo`007Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00006?ooool00ol0003o
ooooooooo`0Wooooo`03oeEEEOmVIVKo000002cooooo00?o0000ooooooooool05?ooool00omEEEGo
IVIVo`00000=ooooo`Co0000@Oooool01Ol0003o410@o`000?lQ8B7oc<c<017ooooo000Mooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool04_ooool001gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0Booooo`007Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1/ooooo`03o`000?oo
oooooooo017ooooo000Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool04Oooool0
01gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Aooooo`005Oooooooo`0004Wo
00002oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool001gooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0@ooooo`007Oooool2o`0002kooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo08;ooooo000Mooooo`;o0000;_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0P_ooool0
01gooooo0_l0000^ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`23ooooo`007Oooool2o`0002kooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo08?ooooo000Mooooo`;o0000;Oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Poooool001gooooo00?o
0000ooooool00000;?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0Q?ooool001gooooo0ol0000/ooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`24ooooo`007Oooool00ol0003oooooo`00000/oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`24oooo
o`007Oooool00ol0003oooooo`00000[ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`25ooooo`007Oooool00ol0003oooooo`00000[ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`25ooooo`007Ooo
ool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`25ooooo`007Oooool01?l0003oooooooooool0000Zooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`26ooooo`007Ooo
ool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`26ooooo`007Oooool01?l0003oooooooooool0000Yooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`26ooooo`007Ooo
ool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo08Oooooo000Mooooo`05o`000?ooooooooooooooool00000
:?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
Qoooool001gooooo0_l00002ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo08Oooooo000Mooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0R?ooool001gooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`28ooooo`007Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo08Sooooo000Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0ROooool001gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`29ooooo`007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08Wooooo
000Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0R_ooool001gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`2:ooooo`007Oooool2o`0000Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0R_ooool001gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2;ooooo`00
7Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08_ooooo000Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0Roooool001gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`2<ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
08cooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0S?ooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`2=ooooo`007Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo08gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0SOooool001gooooo0_l00006ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08kooooo000Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0S_ooool001gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`2>ooooo`007Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo08oooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Soooool0
01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2?ooooo`004oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2@ooooo`00
5Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
T?ooool001Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo093ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ol00008ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo097ooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`2Aooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0TOooool001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo09;ooooo000Cooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`2Booooo`007Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo09;ooooo000Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0Toooool001gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`00
7Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Cooooo000Mooooo`;o00003?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`2Dooooo`007Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo09Gooooo000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0UOooool001go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Eooooo`007Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo09Kooooo000Mooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0U_ooool001gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2G
ooooo`007Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo09Oooooo000Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0V?ooool001gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`2Hooooo`007Oooool2o`0001;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0V?oo
ool001gooooo00?o0000ooooooooool04_ooool01?l0003oooooooooooooool2o`0006cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`2Iooooo`007Oooool00ol0003oooooooooo`0C
ooooo`Co0000K_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Wooooo000Moooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Joooo
o`007Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0V_ooool001gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo09_ooooo000Mooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`2Kooooo`007Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0W?ooool001gooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo09cooooo000Mooooo`;o0000ROooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo09gooooo000Mooooo`03o`000?oooooooooo08Wooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`2Nooooo`007Oooool00ol0003ooooooooo
o`29ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0W_ooool001gooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09oooooo000Moooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Ooooo
o`007Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0X?ooool001gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0:7ooooo000Mooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2Rooooo`007Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Xoooool001gooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0:Cooooo000Mooooo`;o0000T?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0:Gooooo000Mooooo`03o`000?oooooooooo093ooooo
0_l0000=ooooo`03o`000?oooooooooo0:Kooooo000Mooooo`03o`000?oooooooooo09;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Wooooo`007Oooool00ol0003oooooooooo`2C
ooooo`;o00001oooool2o`000:[ooooo000Mooooo`03o`000?oooooooooo09Gooooo0_l00002oooo
o`?o0000[?ooool001gooooo00?o0000ooooooooool0Uoooool3o`000:kooooo000Mooooo`03o`00
0?oooooooooo0?ooooooBOooool001;ooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooBOoo
ool001;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0?ooooooBOoo
ool001?ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000?ooooooBOooool001Cooooo00?oV9RHob4Q
8Oo^k^h0oooooomBooooo`005Oooool00omgMgOoIVIVooooo`3ooooooe7ooooo000Fooooo`03o`00
0?oooooooooo0?ooooooD?ooool001;ooooo00Go0000okZj^_ooooooV9RHoa0@403ooooooe;ooooo
000Booooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0oooooomBooooo`00/oooool01OlQ8B7o0000o`00
0?m4A4CogMgM01Kooooo00Go8B4Qo`000?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo<S8b
ooooo`0Hooooo`03ogMgMolb<S;ooooo03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o<S8bEOooool003kooooo00OoQhN7
ob4Q8OooooooooooodA4A?mgMgOooooo00?o00000_ooool00onYZJWo0000ooooo`05o`000003oc8b
<_o^k^kooooo00Oooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000
ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@4?lb
<S;o0000o`000?l@413oZJVY0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo
00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`00
0008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`000?m4
A4Co^[Zj0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?l0003o0000
00;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_oooooooooo
onk^k_mEEED2o`000006oiRHV?l0003o410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooo
oooo410@oc8b<P;o000000?o410@ojVYZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool02?ooool2o`000003oa0@4?oooooooooo03?o
oooo000nooooo`06ofIVI_l0003ok^k^ooooool0003oMgMg0_ooool01_l0003ooooooooooooooooo
410@okZj^P;ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<cok^k^ohN7
Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEE
EOl00008ooooo`06o`000?nYZJWooooooooooonj^[[o00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomg
MgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooomEEEGoMgMg
0_ooool02_mgMgOoEEEEooooooooooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo00?oc<c<
o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0dooooo`00?_ooool2oc8b<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go0000oooooooooooo
V9RHodA4A003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413o
QhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oooooo
ooooooooooo^k^ko00002Oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^o`00
0?ooooooooooo`000008ooooo`05okZj^_n7QhOoIVIVofIVI_l@41005Oooool01Ol0003ooooooooo
oooooooo000000Wooooo1Ol0000eooooo`00?_ooool01_l@413oZJVYoeEEEOmEEEGoZJVYoa0@40;o
oooo00Go0000oeEEEOnj^[[o410@omgMg@03ooooo`06o`000?ooooooooooonk^k_n7QhOo<S8b2?oo
ool00onj^[[o410@o`000002o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`00
0?ooooooooooooooooo^k^ko00002?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool6o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00003ooooo`04onk^k_l0003oooooooooo`Ko
00000_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kQGooooo00Ko0000ooooooooooooooooo`00
0?ooool6o`0000;ooooo00CoA4A4omgMgOoooooo0000=_ooool003kooooo00Ko0000oooooolQ8B7o
410@ooooool00002ooooo`04o`000?nHV9So0000okZj^PCooooo1?l000000omEEEGok^k^ooooo`0:
ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06ofIVI_mg
MgOoooooonk^k_mEEEGo00002?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000?ooooo00Go0000
ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mEEEGo
MgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Go
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S85ooooo`03o`000?oooooooooo00;ooooo00KoEEEE
ogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool01Ol0
003oQhN7oooooonYZJWo000000;ooooo00[o0000olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomE
EEGoMgMg0_ooool02_mgMgOoEEEEooooooooooooIVIVogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0001Gooooo
00Go0000ohN7QoooooooZJVYo`000009ooooo`04omgMgOmEEEGoooooo`0003Kooooo000mooooo`03
olc<c?lQ8B7ooooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?ooooooZJVYofIVIPCooooo00Go
0000oooooooooooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mg
MgL00_l000002OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<o`000008ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEE
EOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`00
00Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?oooooooooo
onk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3
ooooo`03oa0@4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^
k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@
4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^oooo
ooooooook^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`08ooooo`03ogMgMoo<c<co000003Kooooo000mooooo`03ojVYZOlb<S;ooooo00?o
oooo00CoA4A4oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02ooooo`05o`000?oooooooooo
okZj^_l000007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0booooo`03onk^k_m4A4Co000003Kooooo000moooo
o`?o00000_ooool6o`000005ooooool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0M
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0c
ooooo`03ogMgMol0003ooooo03Gooooo001`ooooo`;o00004?ooool00ol@413o0000ooooo`0Poooo
o`03oa0@4?oooooooooo023ooooo00?o410@ooooooooool0;_ooool2o`0006gooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.187939, -2.2862, \
0.00802016, 0.0265229}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.292863 0.140261 [
[.2619 .28036 -9 -9 ]
[.2619 .28036 9 0 ]
[.5 .28036 -3 -9 ]
[.5 .28036 3 0 ]
[.7381 .28036 -9 -9 ]
[.7381 .28036 9 0 ]
[.97619 .28036 -3 -9 ]
[.97619 .28036 3 0 ]
[.01131 .01234 -12 -4.5 ]
[.01131 .01234 0 4.5 ]
[.01131 .1526 -12 -4.5 ]
[.01131 .1526 0 4.5 ]
[.01131 .43312 -6 -4.5 ]
[.01131 .43312 0 4.5 ]
[.01131 .57339 -6 -4.5 ]
[.01131 .57339 0 4.5 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .29286 m
.2619 .29911 L
s
[(0.5)] .2619 .28036 0 1 Mshowa
.5 .29286 m
.5 .29911 L
s
[(1)] .5 .28036 0 1 Mshowa
.7381 .29286 m
.7381 .29911 L
s
[(1.5)] .7381 .28036 0 1 Mshowa
.97619 .29286 m
.97619 .29911 L
s
[(2)] .97619 .28036 0 1 Mshowa
.125 Mabswid
.07143 .29286 m
.07143 .29661 L
s
.11905 .29286 m
.11905 .29661 L
s
.16667 .29286 m
.16667 .29661 L
s
.21429 .29286 m
.21429 .29661 L
s
.30952 .29286 m
.30952 .29661 L
s
.35714 .29286 m
.35714 .29661 L
s
.40476 .29286 m
.40476 .29661 L
s
.45238 .29286 m
.45238 .29661 L
s
.54762 .29286 m
.54762 .29661 L
s
.59524 .29286 m
.59524 .29661 L
s
.64286 .29286 m
.64286 .29661 L
s
.69048 .29286 m
.69048 .29661 L
s
.78571 .29286 m
.78571 .29661 L
s
.83333 .29286 m
.83333 .29661 L
s
.88095 .29286 m
.88095 .29661 L
s
.92857 .29286 m
.92857 .29661 L
s
.25 Mabswid
0 .29286 m
1 .29286 L
s
.02381 .01234 m
.03006 .01234 L
s
[(-2)] .01131 .01234 1 0 Mshowa
.02381 .1526 m
.03006 .1526 L
s
[(-1)] .01131 .1526 1 0 Mshowa
.02381 .43312 m
.03006 .43312 L
s
[(1)] .01131 .43312 1 0 Mshowa
.02381 .57339 m
.03006 .57339 L
s
[(2)] .01131 .57339 1 0 Mshowa
.125 Mabswid
.02381 .04039 m
.02756 .04039 L
s
.02381 .06845 m
.02756 .06845 L
s
.02381 .0965 m
.02756 .0965 L
s
.02381 .12455 m
.02756 .12455 L
s
.02381 .18065 m
.02756 .18065 L
s
.02381 .20871 m
.02756 .20871 L
s
.02381 .23676 m
.02756 .23676 L
s
.02381 .26481 m
.02756 .26481 L
s
.02381 .32092 m
.02756 .32092 L
s
.02381 .34897 m
.02756 .34897 L
s
.02381 .37702 m
.02756 .37702 L
s
.02381 .40507 m
.02756 .40507 L
s
.02381 .46118 m
.02756 .46118 L
s
.02381 .48923 m
.02756 .48923 L
s
.02381 .51728 m
.02756 .51728 L
s
.02381 .54533 m
.02756 .54533 L
s
.02381 .60144 m
.02756 .60144 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WKB) show
87.000 13.000 moveto
(and) show
111.000 13.000 moveto
(shooting) show
165.000 13.000 moveto
(eigenmodes) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
249.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .29286 m
.03279 .34326 L
.04262 .39435 L
.053 .43941 L
.05753 .45531 L
.06244 .46958 L
.06526 .47629 L
.06786 .4815 L
.07051 .4858 L
.07298 .48892 L
.07434 .49025 L
.07559 .49124 L
.07697 .49206 L
.07773 .4924 L
.07846 .49264 L
.07915 .49281 L
.0799 .4929 L
.0806 .49292 L
.08123 .49287 L
.08198 .49274 L
.08279 .49251 L
.08355 .49221 L
.08426 .49186 L
.08543 .49111 L
.08669 .4901 L
.08897 .48771 L
.09167 .48396 L
.09414 .47969 L
.0995 .46778 L
.10458 .45337 L
.12449 .37383 L
.14291 .28225 L
.16316 .18437 L
.17308 .1439 L
.18218 .11347 L
.19103 .09105 L
.19548 .0827 L
.20034 .07588 L
.20291 .07327 L
.20525 .0715 L
.20654 .07077 L
.20722 .07045 L
.20794 .07017 L
.20857 .06997 L
.20927 .0698 L
.21049 .06961 L
.21172 .06958 L
.21284 .06969 L
.21413 .06998 L
.21536 .07042 L
Mistroke
.2165 .07095 L
.21755 .07157 L
.21993 .07337 L
.22258 .07604 L
.22502 .0791 L
.23052 .08806 L
.24049 .11109 L
.24955 .13873 L
.25911 .17355 L
.29713 .34061 L
.31832 .42901 L
.33761 .49177 L
.3472 .51435 L
.35262 .52425 L
.35763 .53149 L
.362 .53629 L
.36449 .53838 L
.36682 .53991 L
.36801 .54054 L
.36927 .54109 L
.37034 .54146 L
.37151 .54176 L
.37278 .54198 L
.37349 .54205 L
.37413 .54208 L
.37539 .54205 L
.37657 .54191 L
.37773 .54167 L
.37897 .54131 L
.38014 .54087 L
.38121 .54037 L
.38383 .53881 L
.38632 .53687 L
.39125 .53173 L
.39662 .52423 L
.40621 .50621 L
.41509 .48466 L
.45432 .34906 L
.49204 .19752 L
.51299 .12353 L
.52217 .09588 L
.53221 .06972 L
.54131 .05011 L
.55103 .03375 L
.55641 .02683 L
.5613 .02188 L
.56366 .01995 L
.56622 .0182 L
.56865 .01687 L
.57087 .01593 L
Mistroke
.57199 .01555 L
.57322 .01522 L
.57451 .01496 L
.57575 .0148 L
.57689 .01472 L
.57812 .01472 L
.57927 .01478 L
.58032 .01491 L
.58097 .01501 L
.58166 .01515 L
.58289 .01546 L
.58422 .01588 L
.58567 .01645 L
.58828 .01775 L
.59072 .01928 L
.59603 .02367 L
.60087 .02891 L
.61175 .04479 L
.62168 .0639 L
.63085 .08515 L
.65162 .14385 L
.6909 .2801 L
.72867 .41471 L
.74966 .48029 L
.7689 .53027 L
.78776 .56764 L
.79724 .5816 L
.80257 .58796 L
.80761 .59296 L
.81254 .59692 L
.81514 .59862 L
.81789 .60014 L
.82021 .60119 L
.82275 .6021 L
.82387 .60242 L
.82507 .6027 L
.82611 .60291 L
.82723 .60309 L
.82796 .60317 L
.82863 .60324 L
.82992 .60331 L
.83065 .60332 L
.83143 .60331 L
.83217 .60328 L
.83285 .60323 L
.83409 .6031 L
.83479 .60299 L
.83545 .60288 L
.83685 .60259 L
.83818 .60224 L
Mistroke
.84071 .60139 L
.84302 .60041 L
.84819 .59748 L
.8528 .59404 L
.85788 .58936 L
.86815 .57713 L
.88659 .54652 L
.90599 .50374 L
.92686 .44796 L
.96808 .31946 L
.97619 .29286 L
Mfstroke
.02381 .29286 m
.03279 .34326 L
.04262 .39435 L
.053 .43941 L
.05753 .45531 L
.06244 .46958 L
.06526 .47629 L
.06786 .4815 L
.07051 .4858 L
.07298 .48892 L
.07434 .49025 L
.07559 .49124 L
.07697 .49206 L
.07773 .4924 L
.07846 .49264 L
.07915 .49281 L
.0799 .4929 L
.0806 .49292 L
.08123 .49287 L
.08198 .49274 L
.08279 .49251 L
.08355 .49221 L
.08426 .49186 L
.08543 .49111 L
.08669 .4901 L
.08897 .48771 L
.09167 .48396 L
.09414 .47969 L
.0995 .46778 L
.10458 .45337 L
.12449 .37383 L
.14291 .28225 L
.16316 .18437 L
.17308 .1439 L
.18218 .11347 L
.19103 .09105 L
.19548 .0827 L
.20034 .07588 L
.20291 .07327 L
.20525 .0715 L
.20654 .07077 L
.20722 .07045 L
.20794 .07017 L
.20857 .06997 L
.20927 .0698 L
.21049 .06961 L
.21172 .06958 L
.21284 .06969 L
.21413 .06998 L
.21536 .07042 L
Mistroke
.2165 .07095 L
.21755 .07157 L
.21993 .07337 L
.22258 .07604 L
.22502 .0791 L
.23052 .08806 L
.24049 .11109 L
.24955 .13873 L
.25911 .17355 L
.29713 .34061 L
.31832 .42901 L
.33761 .49177 L
.3472 .51435 L
.35262 .52425 L
.35763 .53149 L
.362 .53628 L
.36449 .53837 L
.36682 .53991 L
.36801 .54054 L
.36927 .54108 L
.37034 .54146 L
.37151 .54176 L
.37278 .54198 L
.37349 .54205 L
.37413 .54208 L
.37539 .54204 L
.37657 .54191 L
.37773 .54167 L
.37897 .54131 L
.38014 .54086 L
.38121 .54037 L
.38383 .53881 L
.38632 .53687 L
.39125 .53173 L
.39662 .52423 L
.40621 .50621 L
.41509 .48466 L
.45432 .34906 L
.49204 .19752 L
.51299 .12353 L
.52217 .09588 L
.53221 .06972 L
.54131 .05011 L
.55103 .03375 L
.55641 .02683 L
.5613 .02188 L
.56366 .01995 L
.56622 .0182 L
.56865 .01687 L
.57087 .01593 L
Mistroke
.57199 .01555 L
.57322 .01522 L
.57451 .01496 L
.57575 .0148 L
.57689 .01472 L
.57812 .01472 L
.57927 .01478 L
.58032 .01491 L
.58097 .01501 L
.58166 .01515 L
.58289 .01546 L
.58422 .01588 L
.58567 .01645 L
.58828 .01775 L
.59072 .01928 L
.59603 .02367 L
.60087 .02891 L
.61175 .04479 L
.62168 .0639 L
.63085 .08515 L
.65162 .14385 L
.6909 .28009 L
.72867 .41471 L
.74966 .48029 L
.7689 .53027 L
.78776 .56764 L
.79724 .5816 L
.80257 .58796 L
.80761 .59297 L
.81254 .59692 L
.81514 .59862 L
.81789 .60014 L
.82021 .60119 L
.82275 .6021 L
.82387 .60242 L
.82507 .60271 L
.82611 .60291 L
.82723 .60309 L
.82796 .60317 L
.82863 .60324 L
.82992 .60331 L
.83065 .60332 L
.83143 .60331 L
.83217 .60328 L
.83285 .60323 L
.83409 .6031 L
.83479 .603 L
.83545 .60288 L
.83685 .60259 L
.83818 .60224 L
Mistroke
.84071 .60139 L
.84302 .60041 L
.84819 .59748 L
.8528 .59404 L
.85788 .58936 L
.86815 .57713 L
.88659 .54652 L
.90599 .50374 L
.92686 .44796 L
.96808 .31946 L
.97619 .29286 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`Go0000
1_ooool00ol0003oooooooooo`3oooooodSooooo000Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`3oooooodSooooo000;ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooB?ooool001Kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2^oooo
o`Ko0000Toooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2/ooooo`;o
00001_ooool3o`00093ooooo000Cooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`2[ooooo`;o00002_ooool00ol0003oooooooooo`2=ooooo`004oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo08gooooo000Nooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2<ooooo`007_ooool00ol0003oooooooooo`2Yooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0S?ooool001kooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08_ooooo000Nooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2:ooooo`007_ooool2o`000:So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`29ooooo`007_ooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0R?ooool001kooooo00?o
0000ooooooooool0Y_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Sooooo000N
ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`27
ooooo`007_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Qoooool001kooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo08Kooooo000Nooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`26ooooo`007_ooool00ol0003oooooooooo`2Sooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0QOooool001kooooo00?o0000ooooooooool0Xoooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08Gooooo000Nooooo`;o0000>_ooool3o`00
06Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`24ooooo`007_ooool00ol0003o
ooooooooo`0hooooo`;o000000?oooooo`000?l00000IOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo08Cooooo000Nooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`;o0000
H_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08?ooooo000Nooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Poooool001kooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
08;ooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0P_ooool001kooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`21ooooo`007_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo087ooooo000Nooooo`;o0000<oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`21
ooooo`007_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo083ooooo000Nooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0P?ooool001kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`20ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo07oooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Ooooool0
01kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1nooooo`007_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0O_ooool001kooooo0_l0000`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07gooooo000N
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0OOooool001kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1mooooo`007_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo07cooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
O?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1looooo`007_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07_ooooo000Dooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo07_ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1kooooo`00
2oooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`0002gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
N_ooool001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo07[ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`1jooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0NOooool001Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo07Wooooo000Dooooo`03oeEEEOmVIVKo000000Oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1iooooo`007_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo07Wooooo000Nooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0N?ooool001kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1hoooo
o`007_ooool2o`0002cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0N?ooool001kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1gooooo`007_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo07Oooooo000Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Moooool0
01kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1gooooo`007_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo07Kooooo000Nooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0M_ooool001kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`1fooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Gooooo000Noooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0MOooool001kooooo0_l0000Zooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo07Gooooo000Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
M?ooool001kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1dooooo`007_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo07Cooooo000Nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0M?ooool001kooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`1cooooo`007_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo07?ooooo
000Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Loooool001kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`1booooo`007_ooool2o`0002Sooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0L_ooool001kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1booooo`00
7_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo07;ooooo000Nooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0LOooool001kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`1aooooo`007_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01_l0003oA4A4o`000?l0
003o<S8bomgMgCcooooo00?o0000ooooooooool00_ooool4o`000003oa0@4?oooooooooo03Kooooo
00?o0000ooooooooool01Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd0?oooool5o`0001?ooooo000Nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool05_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06
o`000?oooooooooooooooomgMgOo<S8b>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0nooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04oooool001kooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?oo
ool01Ol0003ooooooooooooooooo000003_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`03oiRHV?lQ8B7ok^k^01Cooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooo
MgMgoc8b<P0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0@?ooool00onHV9So
8B4Qonk^kP0Cooooo`007_ooool2o`0002Kooooo00?o0000ooooooooool05oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c012ooooo`03ogMgMomVIVKooooo01;ooooo000Noooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool04Oooool001kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool2o`0003gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`11ooooo`05o`000?nj^[[ooooooiRHV?l@41004ooo
ool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0003_ooooo00?o0000ooooooooool01?ooool00omEEEGoIVIVo`00
000looooo`03o`000?oooooooooo00?ooooo00?oEEEEofIVI_l000003Oooool4o`00043ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Cooooo`007_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo06kooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0K_ooool0
01kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`1^ooooo`007_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0KOooool001Koooooool00017o`0000cooooo000Nooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool2o`0000gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo000Nooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`007_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo
0_l0000Sooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo0_l0
000Sooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool04oooool001kooooo0_l0000S
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04oooool001kooooo0_l0000Soooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo0_l0000Sooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo0ol0000Qooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooool000008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Gooooo000Nooooo`03o`000?oooooo
0000027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0
003oooooo`00000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool05Oooool001ko
oooo00?o0000ooooool000008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Ko
oooo000Nooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Fooooo`007_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool05_ooool001kooooo00Co0000oooooooooooo00007oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo01Oooooo000Nooooo`04o`000?ooooooooooo`0001oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`007_ooool2o`000003oooo
ool0003ooooo01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`007_oo
ool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
6?ooool001kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool06?ooool001kooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool06?ooool001kooooo00Go0000oooooooooooooooo
o`00000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06Oooool001kooooo00Go
0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
6Oooool001kooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06_ooool001kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool06_ooool001kooooo0_l00003ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`00
7_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`007_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Looooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Mooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01kooooo000Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo01oooooo000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01oooooo000Dooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo000Fooooo`03o`000?oo
oooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Pooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo027ooooo000Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool001Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02;ooooo000Dooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08_ooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08_ooool001kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
8oooool001kooooo0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Uooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0V
ooooo`007_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Vooooo`00
7_ooool2o`0000kooooo0_l00002ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
9oooool001kooooo00?o0000ooooooooool03_ooool3o`0005;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09ooo
ool001kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0:?ooool001kooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Xooooo`007_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02Wooooo000N
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Zooooo`007_ooool2o`0006Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0:_ooool001kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0[ooooo`007_oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02go
oooo000Nooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;Oooool001kooooo00?o
0000ooooooooool0K?ooool2o`0000?ooooo0_l0001mooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0K_ooool3o`00083ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0^ooooo`007_ooool2o`000?;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003oooooooooo`3booooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0;oooool001kooooo00?o0000ooooooooool0
l_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo000Nooooo`03o`000?oo
oooooooo0??ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0aooooo`007_ooool0
0ol0003oooooooooo`3cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0<Oooool0
01kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03;ooooo000Cooooo`Go00001_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0<_ooool001?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0?Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`00
5?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0dooooo`005Oooool00onHV9So8B4Qonk^kP06ooooo`?o0000m_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo000Fooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03Gooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0moooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03Gooooo000Cooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`3hooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0=_ooool001?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0?Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`007_ooool00ol0003o
ooooooooo`3jooooo`;o00004?ooool00ol0003oooooooooo`0hooooo`007_ooool00ol0003ooooo
ooooo`3looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>Oooool001kooooo00?o
0000ooooooooool0o?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo000N
ooooo`03o`000?oooooooooo0?gooooo0_l00009ooooo`;o0000?Oooool001kooooo0_l0003ooooo
o`7ooooo0ol00003ooooo`?o0000?oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`Co
0000@Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00/oooool01OlQ8B7o0000o`000?m4A4CogMgM01Kooooo00Go8B4Qo`00
0?l0003oA4A4omgMg@2Eooooo`00]_ooool00omgMgOo<S8booooo`0Hooooo`03ogMgMolb<S;ooooo
03gooooo00?o0000okZj^_ooool0E?ooool00;Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0looooo`;o<S8bEOooool003kooooo00OoQhN7ob4Q8OooooooooooodA4A?mgMgOooooo
00?o00000_ooool00onYZJWo0000ooooo`05o`000003oc8b<_o^k^kooooo00Oooooo00KoV9RHo`00
0?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^ko
EEEE0_l000000onHV9So0000oa0@4007ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
1?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_oooooo
ooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o
410@olc<c?l00005ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool5o`0000;ooooo00Ko
k^k^oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?l0003o000000;ooooo00Oo0000oooooooooooo0000
oa0@4?o^k^koEEEE00;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000006oiRHV?l0003o
410@ooooooo^k^koEEEE0_l000001_m4A4Co^[Zjoooooooooooo410@oc8b<P;o000000?o410@ojVY
ZOooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool01oooool01Om4A4Co0000o`000?lb<S;ogMgM03Cooooo000nooooo`06ofIVI_l0003o
k^k^ooooool0003oMgMg0_ooool01_l0003ooooooooooooooooo410@okZj^P;ooooo00Ko0000oooo
ooooooook^k^ohN7Qolb<S88ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00008ooooo`06o`000?nYZJWo
oooooooooonj^[[o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooomEEEGoMgMg0_ooool02_mgMgOoEEEEoooooooo
ooooEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_l0003oZJVYoooooooooooo^[Zjo`0000Kooooo00?oc<c<o`000?l@41003?ooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001_ooool00omgMgOo<S8booooo`0cooooo`00?_ooool2oc8b
<P04oiRHV?nYZJWo410@oc8b<P;ooooo00Go0000ooooooooooooV9RHodA4A003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00002Oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
ooooooooooooooooonk^k_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0004ooooo`04o`000?ooooooooooo`0000?ooooo00Gok^k^o`000?ooooooooooo`000008ooooo`05
okZj^_n7QhOoIVIVofIVI_l@41005Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool0<_ooool003kooooo00Ko410@ojVYZOmEEEGoEEEEojVYZOl@4102ooooo`05o`000?mE
EEGo^[Zjoa0@4?oMgMd00oooool01_l0003oooooooooooo^k^koQhN7oc8b<PSooooo00?o^[Zjoa0@
4?l000000_l00004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooo
ooook^k^o`0000Sooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h3ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool6o`0000Gooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooooooooook^k^o`0000;ooooo1_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Cooooo00Co0000oooooooooooo00000oooool01?o^k^ko0000ooooooooool6o`0000;ooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^hEooooo`06o`000?ooooooooooooooool0003ooooo1_l00006
ooooo`03ogMgMolb<S;ooooo03?ooooo000nooooo`06o`000?oooooo8B4Qoa0@4?oooooo00000_oo
ool01?l0003oV9RHo`000?nj^[X4ooooo`Co000000?oEEEEonk^k_ooool02_ooool00oo<c<co0000
ooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooo^k^koEEEE
o`0000Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?mgMgOoooooojVYZOl0
00000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMg
MomEEED3ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7
oooooonYZJWo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b1Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOoooooonk^k_mE
EEGo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7QoooooooZJVY
o`000002ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEogMgM`;ooooo00[o
MgMgoeEEEOooooooooooofIVI_mgMgOoooooonk^k_mEEEGo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P;ooooo00Ko0000okZj^_ooooook^k^ogMgMol0000Eooooo`05o`000?n7QhOooooo
ojVYZOl000002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Cooooo000mooooo`03olc<c?lQ8B7o
oooo00;oEEEE00Sooooooc8b<_nj^[[oooooo`000?ooooooZJVYofIVIPCooooo00Go0000oooooooo
oooo^[Zjoa0@400:ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l00000
2OnHV9Soooooooooooo^k^koEEEEo`000?l@413oc<c<o`000008ooooo`06ojVYZOlQ8B7o0000o`00
0?lb<S;o00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`0000Cooooo00?o
410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?ooooooooooonk^k_mEEEGo
0000ob4Q8OnYZJWo0000oa0@40Cooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h3ooooo`03oa0@
4?l0003o000000Cooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l0
00001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l000003OnHV9Sooooooa0@4?l0003o8B4Q
o`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000002_mEEEGok^k^ooooooooooook^k^
oeEEEOl0003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_nY
ZJWo8B4Qo`000?l0003o<S8bo`0001Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`08ooooo`03o`000?oooooooooo03Kooooo000mooooo`03ojVYZOlb<S;ooooo00?ooooo00CoA4A4
oiRHV?oooooo00000_ooool00onYZJWoEEEEonk^kP02ooooo`05o`000?oooooooooookZj^_l00000
7_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Kooooo000mooooo`?o00000_oo
ool6o`000005ooooool0003o0000o`000?ooool01?l000000ol@413oZJVYooooo`0Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0booooo`Co0000
=Oooool0073ooooo0_l0000@ooooo`03oa0@4?l0003ooooo023ooooo00?o410@ooooooooool08?oo
ool00ol@413oooooooooo`0^ooooo`;o0000KOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.197418, -2.12353, \
0.00808352, 0.0274438}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Surprisingly, there is no discernible difference between the WKB \
and shooting method eigenmodes, even for the lowest-order mode.  Therefore, \
we do not bother using the shooting eigenmodes in the solution shown below; \
the WKB eigenfunctions suffice.  However, we will use the shooting \
eigenfrequencies for the lowest six modes:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Omega][n_]\  := \ 
        n\ Pi/\[Tau][L]\  /; n \[GreaterEqual] 6;\)\), "\n", 
    \(\(\(\[Omega][n_]\  := \ \[Omega]shooting[n]\  /; \ n < 6;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][n_, x_]\  := \ \[Psi]WKB[n, x]\ ;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(y0[x_]\  = \ Sin[Pi\ x];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Clear[A];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A[n_]\  := \ \(A[n]\  = \ 
          NIntegrate[\[Rho][x]\ \[Psi][n, x]\ y0[x], {x, 0, L}]/
            NIntegrate[\[Rho][x]\ \[Psi][n, x]^2, {x, 0, 
                L}]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(y[x_, t_]\  = \ 
        Sum[A[n]\ Cos[\[Omega][n]\ t]\ \[Psi][n, x], {n, 1, 
            10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.177"],

Cell[TextData[{
  "In Fig. ",
  ButtonBox["6.13",
    ButtonData:>"Fig. 6.13",
    ButtonStyle->"Hyperlink"],
  ", we compare the Galerkin method solution (dashed) with the WKB/shooting \
method solution (solid):"
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -40.625 0 ]
[.5 .63053 40.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -101.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
140.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36897 L
.10458 .42975 L
.14415 .47855 L
.18221 .51463 L
.20178 .52826 L
.21267 .53427 L
.22272 .53879 L
.23293 .54236 L
.23832 .54382 L
.24402 .54504 L
.24641 .54546 L
.24897 .54584 L
.25119 .54611 L
.25361 .54635 L
.25507 .54647 L
.25643 .54655 L
.25773 .54662 L
.2584 .54665 L
.25912 .54667 L
.25983 .54669 L
.26048 .5467 L
.26176 .54672 L
.26293 .54671 L
.26416 .54669 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54646 L
.27131 .54627 L
.27364 .54602 L
.27847 .54532 L
.2838 .54427 L
.29326 .54169 L
.30213 .53843 L
.32232 .52812 L
.34082 .51523 L
.38045 .47762 L
.41855 .43067 L
.45912 .3724 L
.49816 .31194 L
.53966 .24751 L
.57964 .18973 L
.61811 .14196 L
.63759 .1217 L
.65902 .10299 L
.67938 .089 L
.69843 .07949 L
.70884 .0758 L
.71396 .07438 L
Mistroke
.71872 .0733 L
.72301 .07253 L
.72758 .07192 L
.7302 .07166 L
.73148 .07156 L
.73266 .07149 L
.73371 .07143 L
.73487 .07138 L
.73603 .07135 L
.73725 .07132 L
.73856 .07132 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74183 .07138 L
.74251 .07141 L
.7449 .07154 L
.74625 .07164 L
.74748 .07175 L
.75203 .07228 L
.7568 .07308 L
.76198 .0742 L
.7668 .07549 L
.77773 .0793 L
.78828 .08411 L
.79823 .08965 L
.81683 .10255 L
.85534 .13894 L
.89632 .1896 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36895 L
.10458 .42977 L
.14415 .47853 L
.18221 .51461 L
.20178 .52826 L
.21267 .53429 L
.22272 .53882 L
.23293 .54239 L
.23832 .54385 L
.24402 .54507 L
.24641 .54548 L
.24897 .54586 L
.25119 .54613 L
.25361 .54637 L
.25507 .54648 L
.25643 .54657 L
.25773 .54663 L
.2584 .54666 L
.25912 .54668 L
.25983 .5467 L
.26048 .54671 L
.26176 .54672 L
.26293 .54672 L
.26416 .5467 L
.26538 .54666 L
.26607 .54663 L
.26671 .5466 L
.26912 .54645 L
.27131 .54627 L
.27364 .54601 L
.27847 .54531 L
.2838 .54425 L
.29326 .54166 L
.30213 .5384 L
.32232 .52809 L
.34082 .51523 L
.38045 .47766 L
.41855 .43068 L
.45912 .37236 L
.49816 .3119 L
.53966 .24753 L
.57964 .18979 L
.61811 .14198 L
.63759 .12168 L
.65902 .10293 L
.67938 .08892 L
.69843 .0794 L
.70884 .07573 L
.71396 .07432 L
Mistroke
.71872 .07325 L
.72301 .07249 L
.72758 .07188 L
.7302 .07163 L
.73148 .07154 L
.73266 .07146 L
.73371 .07141 L
.73487 .07137 L
.73603 .07133 L
.73725 .07131 L
.73856 .07131 L
.73977 .07133 L
.7404 .07134 L
.7411 .07136 L
.74251 .07141 L
.74375 .07148 L
.74508 .07156 L
.74748 .07177 L
.74985 .07203 L
.75235 .07236 L
.7568 .07312 L
.76198 .07426 L
.7668 .07556 L
.77773 .07939 L
.78828 .08422 L
.79823 .08977 L
.81683 .10266 L
.85534 .13895 L
.89632 .18947 L
.93577 .24638 L
.97371 .30513 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Wooooo2Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo00?o0000ool00?oo0000
0_oo0009ooooo`?oo`000_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0=;ooooo0_l0000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3?ooooo`?o00005oooool3o`0005Sooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0cOooool2o`0001gooooo0_l0001Fooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0<_ooooo00?oo`00o`000?ooool08?ooool00ooo003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`39ooooo`;oo`009?ooool2ool005?ooooo
000Qooooo`03o`000?oooooooooo0<Sooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`1@ooooo`008Oooool3o`000<Kooooo0_oo000Zooooo`;oo`00D?ooool0027ooooo00?o0000oooo
ooooool0aOooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo0<?ooooo0_oo000`ooooo`03ool00?l0003ooooo04cooooo000Qooooo`03o`00
0?oooooooooo0<;ooooo00?oo`00ooooooooool0<Oooool00ooo003o0000ooooo`1;ooooo`008Ooo
ool00ol0003oooooooooo`31ooooo`03ool00?oooooooooo03?ooooo00?oo`00o`000?ooool0B_oo
ool0027ooooo00?o0000ooooooooool0`?ooool00ooo003oooooooooo`0eooooo`03ool00?l0003o
oooo04Wooooo000Qooooo`03o`000?oooooooooo0;oooooo00?oo`00ooooooooool0=oooool00ooo
003o0000ooooo`18ooooo`008Oooool3o`000;kooooo00?oo`00ooooooooool0>Oooool00ooo003o
0000ooooo`17ooooo`008Oooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0AOooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`008Ooo
ool3o`000;Oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2gooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool0?oooool0
027ooooo00?o0000ooooooooool0]_ooool00ooo003oooooooooo`19ooooo`03ool00?l0003ooooo
03oooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?oo`00ooooooooool0Boooool00ooo003o
0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`2dooooo`03ool00?oooooooooo04gooooo
00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo0;?ooooo00?oo`00
ooooooooool0D?ooool00ooo003oooooooooo`0kooooo`008Oooool00ol0003oooooooooo`2boooo
o`03ool00?oooooooooo05;ooooo00?oo`00ooooooooool0>_ooool0027ooooo0ol0002aooooo`03
ool00?oooooooooo05?ooooo00?oo`00o`000?ooool0>_ooool0027ooooo00?o0000ooooooooool0
/?ooool00ooo003oooooooooo`1Eooooo`03ool00?l0003ooooo03Wooooo000Qooooo`03o`000?oo
oooooooo0:oooooo00?o0000ool00?ooool0Eoooool00ooo003o0000ooooo`0hooooo`008Oooool0
0ol0003oooooooooo`2_ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool0=oooool0
027ooooo00?o0000ooooooooool0[_ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0:gooooo00?oo`00ooooooooool0G?ooool0
0ooo003oooooooooo`0eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo03Cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0002[ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo03?ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo03;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0<Ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo02oooooo000Qoooo
o`03o`000?oooooooooo0:Kooooo00?o0000ool00?ooool0JOooool00ooo003oooooooooo`0_oooo
o`008Oooool3o`000:Kooooo00?o0000ool00?ooool0JOooool00ooo003o0000ooooo`0_ooooo`00
8Oooool00ol0003oooooooooo`2Uooooo`03o`000?oo003ooooo06_ooooo00?oo`00o`000?ooool0
;_ooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oo
oooooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ool00?ooool0Koooool0
0ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooooooo
06oooooo00?oo`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0X_ooool00ooo003o
ooooooooo`1aooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo0:7ooooo
00?o0000ool00?ooool0Loooool00ooo003oooooooooo`0Zooooo`008Oooool3o`000:7ooooo00?o
o`00ooooooooool0Loooool00ooo003o0000ooooo`0Zooooo`008Oooool00ol0003oooooooooo`2P
ooooo`03ool00?oooooooooo07Gooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooo
ooooool0Woooool00ooo003oooooooooo`1gooooo`03ool00?oooooooooo02Sooooo000Qooooo`03
o`000?oooooooooo09kooooo00?oo`00ooooooooool0NOooool00ooo003oooooooooo`0Wooooo`00
8Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo07Wooooo00?oo`00ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1kooooo`03ool00?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0OOooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool09Oooool0027ooooo0ol0002Kooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`00
0003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0=oooool00ol0003oooooooooo`03
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0>?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<03Wooooo00?o0000ooooooooool01?ooool00omgMgOoIVIVooooo`0Jooooo`00
8Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0Iooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool02?oo003o0000ooooool0003o^[Zj
oooooonHV9So410@6oooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000nooooo`03oeEEEOmVIVKo000000?ooooo00?o0000ool00?ooool0>Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000??ooool01ooo003ooooooiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`2:ooooo`03ool0
0?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ool00?ooool0S?oo
ool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooo
oooo08cooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0U?ooool00ooo
003oooooooooo`2>ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooooooool0Toooool00ol0003oo`00ooooo`2@ooooo`03ool00?oooooooooo017o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
09?o000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ool0
0?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo0000TOooool00ooo003oooooooooo`2Voooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?ooooooo`00093ooooo00?oo`00oooooooo
ool0/Oooool0027ooooo00Co0000ooooooooooooo`00S_ooool00ooo003o0000ooooo`2booooo`00
8Oooool01Ol0003oooooooooool0003oo`0008gooooo00?o0000ooooooooool0/_ooool0027ooooo
00Ko0000ooooooooooooooooo`000?oo002;ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`?o
00000_ooool00ooo003oooooooooo`29ooooo`03o`000?oooooooooo0;?ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ool00?ooool0R?ooool00ol0003oooooooooo`2dooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo08Kooooo00?o0000ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oooooo
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool00ol0
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo08;o
oooo00?o0000ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003ooooooooo
o`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0O_ooool00ooo003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2kooooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oooooo
oooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool00ooo
003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo07Cooooo
00?oo`00ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`1booooo`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool0L?ooool00ol0003oo`00ooooo`30ooooo`008Oooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo06oooooo00?oo`00ooooooooool0`?ooool0027ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`008Ooo
ool3o`00017ooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`32ooooo`008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?o0000ooooooooool0`oooool0
027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03o`000?oooooooooo
0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ol0003o
ooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Gooooo
00?o0000ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ol0003o
o`00ooooo`1Tooooo`03o`000?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo06;ooooo00?oo`00o`000?ooool0aoooool000Oooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03o`000?oooooooooo067o
oooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Oooooo`03
ool00?oooooooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooo
o`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0GOooool00ooo
003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00oooo
ooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0<co
oooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0Eoooool00ooo003ooooo
ooooo`3<ooooo`008Oooool3o`0001_ooooo00?oo`00o`000?ooool0E_ooool00ooo003ooooooooo
o`3=ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool00?l0003ooooo05Cooooo00?oo`00
ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07Oooool00ooo003o0000ooooo`1Boooo
o`03ool00?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00o`000?oo
ool0D?ooool00ooo003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04oooooo00?o0000ooooooooool0d?ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo0=7ooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`3Booooo`008Oooool3o`00
02;ooooo00?oo`00ooooooooool0BOooool00ol0003oooooooooo`3Cooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03ool00?oooooooooo04Kooooo0_l0003Fooooo`008Oooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0e_ooool0027ooooo00?o
0000ooooooooool09Oooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo0=Oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`3H
ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03kooooo00?oo`00oooo
ooooool0fOooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0looooo`03
ool00?oooooooooo0=[ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`3Kooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`3Looooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03Kooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0dooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02go
oooo00?o0000ool00?ooool0<_ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003ooooo
ooooo`0^ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0h?ooool0027ooooo00?o
0000ooooooooool0;oooool2ool002kooooo00?o0000ool00?ooool0h_ooool0027ooooo00?o0000
ooooooooool0<Oooool00ooo003oooooooooo`0Zooooo`03o`000?oo003ooooo0>?ooooo000Qoooo
o`?o0000<_ooool2ool002Wooooo00?o0000ool00?ooool0i?ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`00
0?oooooooooo03Gooooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=ooo
ool00ooo003oooooooooo`0Mooooo`?o0000j_ooool0027ooooo00?o0000ooooooooool0>?ooool3
ool001[ooooo0_l0003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool01?oo003o0000o`000?l0000Dooooo`;oo`00koooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo0_oo003aoooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo1ol00003ooooo`Oo
o`00loooool001[ooooo00?o0000ooooooooool01?ooool3o`0004Gooooo1Ooo003jooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002_ooooo`03ogMgMomVIVKooooo
01Oooooo00?oIVIVogMgMoooool0W?ooool008kooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Ko
oooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Looooo`00Q_ooool01on7QhOo0000
oeEEEOmVIVKo0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00onHV9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009
ooooo`03oeEEEOnYZJWooooo00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHDooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0Poooool008Kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV
00;ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
omgMgOooool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_oo
ool01_mEEEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`23ooooo`00Q_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6
ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@4023ooooo`00Q_oo
ool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000oooooooo
ool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^
k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00002oooo
o`05o`000?ooooooooooooooool00000Poooool008Kooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0
003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool0
0ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000ooo
ool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool00000Poooool008Oooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@4023ooooo`00WOoo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg08?ooooo002Mooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP23ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36459 L
.10458 .41983 L
.14415 .46264 L
.16408 .47998 L
.18221 .49298 L
.20178 .50387 L
.21254 .5084 L
.22272 .51171 L
.23241 .51398 L
.2373 .51479 L
.24012 .51516 L
.24269 .51543 L
.24504 .51562 L
.24728 .51576 L
.2485 .51581 L
.24964 .51585 L
.25088 .51588 L
.25158 .51589 L
.25221 .5159 L
.25336 .5159 L
.25442 .51589 L
.25558 .51587 L
.2568 .51583 L
.25787 .51578 L
.25887 .51573 L
.26113 .51559 L
.26373 .51536 L
.26614 .51509 L
.27158 .5143 L
.27638 .51338 L
.28148 .51218 L
.2903 .50957 L
.30004 .50593 L
.31939 .49637 L
.34024 .48284 L
.38138 .44759 L
.42101 .40533 L
.45912 .36013 L
.49968 .31074 L
.53872 .26533 L
.58022 .22268 L
.60102 .2044 L
.6202 .18974 L
.64007 .177 L
.65867 .16749 L
.67743 .16036 L
.68738 .15761 L
.69293 .15638 L
.69807 .15544 L
Mistroke
.70298 .15473 L
.7082 .15415 L
.71119 .15391 L
.71265 .15382 L
.714 .15374 L
.7152 .15369 L
.71652 .15364 L
.71785 .1536 L
.71857 .15359 L
.71924 .15358 L
.7205 .15356 L
.7212 .15356 L
.72186 .15356 L
.72305 .15358 L
.72433 .1536 L
.72546 .15363 L
.72653 .15366 L
.72895 .15378 L
.73157 .15394 L
.73396 .15413 L
.73935 .15471 L
.7441 .15538 L
.74918 .15626 L
.75831 .15826 L
.77902 .16471 L
.80041 .17393 L
.82057 .18476 L
.85909 .21017 L
.90006 .24227 L
.93952 .27623 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36461 L
.10458 .41979 L
.14415 .46266 L
.16408 .48001 L
.18221 .49301 L
.20178 .50387 L
.21254 .50838 L
.22272 .51169 L
.23241 .51395 L
.2373 .51476 L
.24012 .51513 L
.24269 .5154 L
.24504 .5156 L
.24728 .51574 L
.2485 .51579 L
.24964 .51583 L
.25088 .51586 L
.25158 .51587 L
.25221 .51588 L
.25336 .51588 L
.25442 .51587 L
.25558 .51585 L
.2568 .51582 L
.25787 .51577 L
.25887 .51572 L
.26113 .51558 L
.26373 .51535 L
.26614 .51509 L
.27158 .5143 L
.27638 .51339 L
.28148 .5122 L
.2903 .5096 L
.30004 .50595 L
.31939 .49639 L
.34024 .48284 L
.38138 .44755 L
.42101 .40533 L
.45912 .36018 L
.49968 .31078 L
.53872 .2653 L
.58022 .2226 L
.60102 .20434 L
.6202 .18972 L
.64007 .17703 L
.65867 .16756 L
.67743 .16045 L
.68738 .1577 L
.69293 .15647 L
.69807 .15553 L
Mistroke
.70298 .15481 L
.7082 .15423 L
.71119 .15398 L
.71265 .15388 L
.714 .15381 L
.7152 .15375 L
.71652 .1537 L
.71785 .15366 L
.71857 .15364 L
.71924 .15363 L
.7205 .15361 L
.7212 .15361 L
.72186 .15361 L
.72305 .15362 L
.72433 .15364 L
.72546 .15367 L
.72653 .1537 L
.72895 .15381 L
.73157 .15396 L
.73396 .15415 L
.73935 .15471 L
.7441 .15537 L
.74918 .15623 L
.75831 .15821 L
.76917 .16124 L
.77902 .16461 L
.81906 .18378 L
.85758 .20909 L
.89855 .24115 L
.938 .27497 L
.97594 .30879 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0coooool2ool000So0000
1ooo001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Coo`004Oooool6ool005kooooo000Q
ooooo`03o`000?oooooooooo0<Sooooo0ooo000Kooooo`;oo`0000?o0000ooooooooool0FOooool0
027ooooo00?o0000ooooooooool0aOooool2o`000003ool00?oooooooooo01kooooo00?oo`00o`00
0?l00000FOooool0027ooooo0ol00033ooooo`;o00009_ooool3o`0005Kooooo000Qooooo`03o`00
0?oooooooooo0<7ooooo0_l0000[ooooo`;o0000E?ooool0027ooooo00?o0000ooooooooool0_ooo
ool2o`0002oooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`2mooooo`;oo`00<oooool2
ool0053ooooo000Qooooo`03o`000?oooooooooo0;cooooo00?oo`00ooooooooool0=?ooool00ol0
003oo`00ool0001>ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2jooooo`;oo`00>Oooool0
0ol0003oo`00ool0001<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0^Oooool00ooo003oooooooooo`0j
ooooo`;o000000?oo`00ooooooooool0BOooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`000;Oooooo0_oo000oooooo`03o`000?oo003o
oooo04Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo0;Kooooo00?oo`00ooooooooool0@Oooool2ool004Sooooo0007oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0]Oooool00ooo003oooooooooo`13ooooo`03o`000?oo003ooooo04Kooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0;Cooooo00?oo`00ooooooooool0A_ooool00ooo003o0000ooooo`14ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2cooooo`03ool00?oooooooooo04Sooooo00?oo`00o`000?ooool0@oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2aooooo`;oo`00C?oo
ool00ooo003o0000o`000012ooooo`008Oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooo
oooo04oooooo0_l00010ooooo`008Oooool00ol0003oooooooooo`2^ooooo`;o0000E?ooool00ol0
003oooooooooo`0mooooo`008Oooool3o`000:gooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`0looooo`008Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000
ooooooooool0F_ooool2ool003[ooooo000Qooooo`03o`000?oooooooooo0:[ooooo00?o0000oooo
ooooool0GOooool00ooo003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo05oooooo0_oo000gooooo`008Oooool00ol0003oooooooooo`2Xooooo`03ool0
0?oooooooooo067ooooo00?o0000ool00?ooool0=Oooool0027ooooo0ol0002Wooooo`03ool00?oo
oooooooo06?ooooo00?o0000ool00?ooool0=?ooool0027ooooo00?o0000ooooooooool0Y_ooool0
0ooo003oooooooooo`1Uooooo`03o`000?oo003ooooo03?ooooo000Qooooo`03o`000?oooooooooo
0:Gooooo00?oo`00ooooooooool0Ioooool00ol0003oo`00ooooo`0booooo`008Oooool00ol0003o
ooooooooo`2Tooooo`03ool00?oooooooooo06[ooooo00?oo`00ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo02oooooo
000Qooooo`03o`000?oooooooooo0:;ooooo00?oo`00ooooooooool0K_ooool00ooo003ooooooooo
o`0^ooooo`008Oooool00ol0003oooooooooo`2Qooooo`03ool00?oooooooooo073ooooo00?oo`00
ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0X?ooool00ooo003oooooooooo`1boooo
o`;o0000;Oooool0027ooooo0ol0002Oooooo`03ool00?oooooooooo07Gooooo00?o0000oooooooo
ool0:_ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
00Oooooo00?oo`00ooooooooool0<Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oooooooooo`09ooooo`Go00006oooool0
027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo037ooooo00?o0000
ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00kooooo00?oMgMgoc8b<_ooool0<oooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0=Oooool2ool000Wo
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool06Oooool0027ooooo0ol0000mooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[o
oooo00?oo`00ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03
o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omE
EEGoIVIVo`000005ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`00
03[ooooo00Woo`00oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o
0000ooooooooool0Uoooool00ooo003o0000ooooo`27ooooo`;oo`008Oooool0027ooooo00?o0000
ooooooooool0Uoooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo01kooooo000Qoooo
o`03o`000?oooooooooo09Kooooo00?oo`00ooooooooool0Roooool00ooo003oooooooooo`0Moooo
o`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo08gooooo00?oo`00oooooooo
ool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool0
0?oooooooooo08oooooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@Cooooo000Joooooigo000000?oo`00o`000?l00000TOl000000ooo003o0000o`000005o`0000co
oooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027o
oooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7o
MgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03ool00?oooooooooo0:Ko
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool00ooo003ooooo
ooooo`2aooooo`008Oooool01?l0003oooooooooool0002>ooooo`03ool00?oooooooooo0;;ooooo
000Qooooo`05o`000?ooooooooooooooool00000S?ooool00ooo003oooooooooo`2cooooo`008Ooo
ool01Ol0003ooooooooooooooooo000008_ooooo00?oo`00ooooooooool0]?ooool0027ooooo0ol0
0002ooooo`03ool00?oooooooooo08Oooooo00?o0000ooooooooool0]Oooool0027ooooo00?o0000
ooooooooool00_ooool00ooo003o0000ooooo`26ooooo`03o`000?oooooooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0QOooool00ol0003oooooooooo`2foooo
o`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo08?ooooo00?o0000oooooooo
ool0]oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003o0000ooooo`22ooooo`03o`00
0?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0P?oo
ool00ol0003oooooooooo`2iooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo07kooooo00?o0000ooooooooool0^_ooool0027ooooo0ol00007ooooo`03ool00?oooooooooo
07cooooo00?o0000ooooooooool0^oooool0027ooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`1kooooo`;oo`00_Oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`1jooooo`03ool00?oooooooooo0;cooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
o`00ooooooooool0N?ooool00ooo003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`09
ooooo`03o`000?oo003ooooo07Oooooo00?oo`00ooooooooool0__ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol0003oo`00ooooo`1eooooo`03ool00?oooooooooo0;oooooo000Qooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Loooool00ol0003oo`00ooooo`30ooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo077ooooo00?o0000ool00?ooool0
`Oooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo06oooooo00?o0000ool00?ooool0`_oo
ool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1^ooooo`03ool00?oooooo
oooo0<;ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0KOooool00ol0
003oo`00ooooo`33ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06_o
oooo00?o0000ool00?ooool0a?ooool0027ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oo003ooooo0<Gooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Ioooool00ol0003oo`00ooooo`36ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03ool00?oooooooooo06Gooooo00?o0000ooooooooool0aoooool0027ooooo0ol0000Boooo
o`03ool00?oooooooooo06Cooooo00?o0000ooooooooool0b?ooool0027ooooo00?o0000oooooooo
ool04oooool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo0<Sooooo000Qooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`39ooooo`008Ooo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool0b_oo
ool0027ooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo0<_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0Fooo
ool00ol0003oooooooooo`3<ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`1Jooooo`03ool00?oooooooooo0<gooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`02ooooo`?o00006?ooool00ooo003oooooooooo`1Hooooo`03o`000?oo
003ooooo0<kooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0Eoooool00ooo003ooooooooo
o`3>ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0EOooool00ooo003ooooo
ooooo`3?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo05?ooooo00?oo`00ooooooooool0
d?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo0=7ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1?ooooo`03ool00?oooooooooo0=;ooooo000Qooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`3Cooooo`008Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04[ooooo0_oo003Fooooo`008Oooool3o`00
023ooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`3Fooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo04Kooooo00?oo`00ooooooooool0eoooool0027ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`14ooooo`03ool00?oooooooooo0=Sooooo
000Qooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`3Iooooo`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo03oooooo0_l0003L
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo03gooooo00?o0000oooo
ooooool0g?ooool0027ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0kooooo`03
o`000?oooooooooo0=gooooo000Qooooo`?o00009oooool00ooo003oooooooooo`0iooooo`03o`00
0?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0=ooo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;oo`00=_ooool0
0ooo003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo
037ooooo0_oo003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`;oo`00<?ooool00ooo003o
ooooooooo`3Sooooo`008Oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo02_ooooo
0_oo003Vooooo`008Oooool00ol0003oooooooooo`0_ooooo`;oo`00:_ooool00ooo003ooooooooo
o`3Vooooo`008Oooool00ol0003oooooooooo`0aooooo`;o00009_ooool2ool00>Wooooo000Qoooo
o`?o0000<oooool2o`0002;ooooo0_oo003[ooooo`008Oooool00ol0003oooooooooo`0eooooo`;o
00007_ooool2ool00>gooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
6Oooool00ol0003oo`00ooooo`3^ooooo`008Oooool00ol0003oooooooooo`0hooooo`;o00000_oo
000Dooooo`?o0000lOooool0027ooooo00?o0000ooooooooool0>oooool00ol0003oo`00ool00002
ool000[ooooo1_l0003dooooo`008Oooool00ol0003oooooooooo`10ooooo`[oo`00n_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Nooo
ool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj
0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`1doooo
o`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003o
ooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`00
00gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo
00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooo
oooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00ooo
ool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo
00000oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool0
0onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006
ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08
ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oo
oooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj
^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0Moooool009;o
oooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooo
oonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000M_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35011 L
.10458 .38858 L
.12507 .40359 L
.14415 .41504 L
.16254 .42362 L
.17277 .42734 L
.18221 .4301 L
.19242 .43238 L
.19781 .43329 L
.20351 .43404 L
.2059 .43428 L
.20846 .4345 L
.21068 .43466 L
.2131 .4348 L
.21456 .43486 L
.21592 .43491 L
.21722 .43494 L
.21795 .43495 L
.21861 .43496 L
.21986 .43497 L
.22056 .43497 L
.22121 .43497 L
.2224 .43496 L
.22365 .43494 L
.22487 .43491 L
.2262 .43487 L
.22861 .43477 L
.23096 .43463 L
.23313 .43448 L
.23806 .43403 L
.24329 .43339 L
.25201 .43199 L
.26163 .42996 L
.28097 .42451 L
.30183 .41683 L
.34297 .39773 L
.38259 .37701 L
.4207 .35769 L
.46126 .34017 L
.48 .33366 L
.50031 .32793 L
.51141 .32543 L
.52165 .32352 L
.53144 .32207 L
.53686 .32142 L
.5418 .32092 L
.54632 .32054 L
.55124 .32022 L
.55394 .32008 L
Mistroke
.55644 .31997 L
.55883 .31989 L
.56016 .31985 L
.56138 .31982 L
.56251 .3198 L
.56376 .31978 L
.56501 .31977 L
.56633 .31976 L
.5675 .31976 L
.56874 .31976 L
.56992 .31977 L
.57099 .31978 L
.5721 .31979 L
.57313 .31981 L
.57546 .31986 L
.57751 .31992 L
.57969 .32 L
.5846 .32024 L
.58909 .32051 L
.5992 .32135 L
.60812 .32231 L
.61749 .32352 L
.65566 .33 L
.69627 .33785 L
.71504 .34112 L
.73537 .34407 L
.7465 .34535 L
.75675 .34629 L
.76655 .34694 L
.77149 .34718 L
.77409 .34728 L
.77692 .34737 L
.77963 .34744 L
.78083 .34746 L
.78215 .34748 L
.78339 .3475 L
.78455 .34751 L
.78578 .34752 L
.78647 .34752 L
.7871 .34752 L
.78822 .34752 L
.78927 .34752 L
.79041 .34751 L
.79163 .3475 L
.79292 .34748 L
.79413 .34746 L
.7964 .34741 L
.79893 .34735 L
.80162 .34725 L
.80643 .34704 L
Mistroke
.81161 .34674 L
.81731 .34633 L
.82745 .34538 L
.83673 .34428 L
.85762 .34104 L
.89734 .33233 L
.93556 .32164 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35001 L
.10458 .38865 L
.12507 .40366 L
.14415 .41508 L
.16254 .42363 L
.17277 .42733 L
.18221 .43009 L
.19242 .43236 L
.19781 .43327 L
.20351 .43401 L
.2059 .43426 L
.20846 .43448 L
.21068 .43464 L
.2131 .43478 L
.21456 .43484 L
.21592 .43488 L
.21722 .43492 L
.21795 .43493 L
.21861 .43494 L
.21986 .43495 L
.22056 .43495 L
.22121 .43495 L
.2224 .43494 L
.22365 .43492 L
.22487 .43489 L
.2262 .43485 L
.22861 .43475 L
.23096 .43461 L
.23313 .43446 L
.23806 .434 L
.24329 .43336 L
.25201 .43195 L
.26163 .42993 L
.28097 .42447 L
.30183 .41681 L
.34297 .39779 L
.38259 .3771 L
.4207 .35768 L
.46126 .34006 L
.48 .33354 L
.50031 .32784 L
.51141 .32537 L
.52165 .3235 L
.53144 .32208 L
.53686 .32145 L
.5418 .32097 L
.54632 .32061 L
.55124 .3203 L
.55394 .32017 L
Mistroke
.55644 .32007 L
.55883 .31999 L
.56016 .31996 L
.56138 .31993 L
.56251 .31991 L
.56376 .3199 L
.56501 .31989 L
.56633 .31988 L
.5675 .31988 L
.56874 .31989 L
.56992 .3199 L
.57099 .31991 L
.5721 .31992 L
.57313 .31994 L
.57546 .32 L
.57751 .32006 L
.57969 .32014 L
.5846 .32038 L
.58909 .32065 L
.5992 .32148 L
.60812 .32243 L
.61749 .32361 L
.65566 .32995 L
.69627 .3377 L
.71504 .34098 L
.73537 .34398 L
.7465 .3453 L
.75675 .34628 L
.76655 .34698 L
.77149 .34724 L
.77409 .34735 L
.77692 .34745 L
.77963 .34752 L
.78083 .34755 L
.78215 .34758 L
.7833 .3476 L
.78455 .34761 L
.78587 .34762 L
.7871 .34763 L
.78823 .34763 L
.78947 .34763 L
.79075 .34763 L
.79195 .34762 L
.79308 .34761 L
.7941 .34759 L
.7964 .34755 L
.79908 .34748 L
.80156 .3474 L
.80715 .34715 L
.81208 .34686 L
Mistroke
.81731 .34648 L
.82673 .3456 L
.83686 .34439 L
.85516 .34154 L
.89641 .33244 L
.93614 .3213 L
.97435 .30959 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000:?l0
00000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o
0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`?o00000_oo00000ol0003ooooooooo
o`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`04ob4Q8Omg
MgOoMgMgoc8b<PGooooo000Qooooo`04o`000?oooooo0000ool00?oooooo7?ooool3o`0001_ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00Go0000oooooooooooo0000ool0002Iooooo`Oo0000
3ooo0003o`0006Gooooo0_oo00000ol0003oooooooooo`0Vooooo`008Oooool01_l0003ooooooooo
oooooooo0000ool0097ooooo1?oo0003o`0001Wooooo1ol0001Kooooo`?oo`00:oooool0027ooooo
00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`2<ooooo`?oo`009oooool5ool00003o`00
0?oooooooooo053ooooo0ooo000^ooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
003ooooo08Sooooo0ooo000_ooooo`Soo`00B?ooool3ool0037ooooo000Qooooo`?o00001?ooool0
0ol0003oo`00ooooo`23ooooo`Coo`00>Oooool01?l0003oo`00ool00?oo0002o`0003kooooo1Ooo
000dooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo083ooooo0_oo0000
0ol0003oooooooooo`10ooooo`Ko0000<_ooool6o`0003Wooooo000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ool00?ooool0O?ooool3o`0004_ooooo0_l00005ool002Gooooo1_l0000ooooo
o`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo003ooooo07Wooooo0_l0001Eooooo`Go
o`006oooool8ool004;ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
M_ooool2o`0005cooooo1ooo000:o`0000[oo`00B_ooool0027ooooo00?o0000ooooooooool02Ooo
ool2o`0007?ooooo0ol00033ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo06kooooo00?o0000ool00?oo0000aOooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo
06_ooooo0ooo0037ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06So
oooo0_oo003:ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06Gooooo
0_oo003<ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo0ooo
003>ooooo`008Oooool00ol0003oooooooooo`0@ooooo`;oo`00Goooool2ool00003o`000?oooooo
oooo0<kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0Foooool00ooo
003o0000ooooo`3Aooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo05So
oooo0_l0003Dooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo05Gooooo
0_l0003Fooooo`008Oooool3o`0001Gooooo00?oo`00ooooooooool0D_ooool2o`000=Sooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0Coooool2o`000=[ooooo000Qoooo
o`03o`000?oooooooooo01Oooooo0_oo001<ooooo`;oo`0000?o0000ooooooooool0f_ooool0027o
oooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`17ooooo`;oo`0000?o0000oooooooo
ool0g?ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`15ooooo`03ool0
0?l0003ooooo0=oooooo000Qooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0@_oo
ool2ool00>;ooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0?oooool2
ool00>Cooooo000Qooooo`?o00007Oooool2o`0003cooooo0ooo003Vooooo`008Oooool00ol0003o
ooooooooo`0Oooooo`;o0000>?ooool2ool00003o`000?oooooooooo0>Kooooo000Qooooo`03o`00
0?oooooooooo027ooooo0_l0000dooooo`03o`000?oo003ooooo0>[ooooo000Qooooo`03o`000?oo
oooooooo02?ooooo0_l0000`ooooo`;o0000kOooool0027ooooo00?o0000ooooooooool09Oooool2
ool002cooooo0_l0003_ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Wooooo`;oo`009ooo
ool3o`000?7ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Yooooo`?oo`008Oooool2ool00003o`000?oo
oooooooo0?;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o0000;?ooool3ool001_ooooo0ooo003gooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0_ooooo`?oo`005Ooo
ool3ool00?[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0<_ooool3ool000;o00002Oooool7ool00?gooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03Oooooo2?l000000ooo003oooooooooo`3oooooo`?ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027
ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^
oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o
0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool0
1oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[o
A4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo07Sooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q
8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@
4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooo
oom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02ooo
ool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool0N_ooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02oooo
o`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0A
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1jooooo`00O_ooool0
1?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Q
onk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1jooooo`00
O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003ooooo
ooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool04_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool0N_ooool007oooooo00?oV9RHogMgMooo
ool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooMgMgo
410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`0000;o
oooo00?oMgMgoeEEEOooool04_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0N_ooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09
omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd04ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0N_ooool009Kooooo00?o
0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o
0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`03oeEEEOmVIVKo000007cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .31657 L
.06244 .3239 L
.08426 .33054 L
.0949 .33306 L
.10458 .33491 L
.10911 .33562 L
.11403 .33627 L
.11828 .33674 L
.12297 .33716 L
.12793 .33748 L
.13065 .3376 L
.13195 .33765 L
.13319 .33769 L
.13433 .33771 L
.13557 .33774 L
.1367 .33775 L
.13774 .33776 L
.13898 .33776 L
.14011 .33776 L
.14141 .33775 L
.14264 .33773 L
.1438 .33771 L
.14504 .33768 L
.14729 .3376 L
.14996 .33748 L
.1524 .33735 L
.1577 .33697 L
.16271 .3365 L
.17156 .33543 L
.18119 .33394 L
.20096 .33001 L
.22197 .32491 L
.25972 .31505 L
.28069 .31023 L
.28988 .30846 L
.29992 .30684 L
.30464 .3062 L
.30969 .30562 L
.31404 .30521 L
.31877 .30485 L
.32155 .30469 L
.32412 .30457 L
.32657 .30448 L
.3278 .30445 L
.3285 .30444 L
.32916 .30443 L
.33039 .30441 L
.33152 .3044 L
.33273 .3044 L
Mistroke
.33404 .30441 L
.33519 .30442 L
.33641 .30445 L
.33757 .30447 L
.33861 .30451 L
.34094 .3046 L
.3435 .30473 L
.34866 .3051 L
.35344 .30558 L
.35789 .30614 L
.36796 .30783 L
.37873 .31029 L
.40001 .31718 L
.42014 .32618 L
.45852 .34959 L
.49936 .38172 L
.53868 .41626 L
.57648 .44877 L
.59749 .46508 L
.61673 .47826 L
.63682 .48978 L
.65547 .49818 L
.66542 .50166 L
.67444 .50421 L
.68446 .50634 L
.68996 .50719 L
.69264 .50752 L
.69515 .50779 L
.69758 .508 L
.6998 .50815 L
.70226 .50828 L
.70361 .50833 L
.7049 .50836 L
.70614 .50838 L
.70746 .50839 L
.70859 .50839 L
.70983 .50838 L
.71053 .50837 L
.71116 .50835 L
.7126 .50831 L
.71387 .50826 L
.7152 .50819 L
.71741 .50806 L
.71977 .50787 L
.72402 .50743 L
.72907 .50673 L
.73367 .50593 L
.74363 .50368 L
.75283 .50099 L
.77362 .49276 L
Mistroke
.79236 .48297 L
.81299 .46979 L
.8533 .43776 L
.89209 .40074 L
.93333 .35694 L
.97306 .31254 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .31681 L
.06244 .32413 L
.08255 .33017 L
.09409 .33289 L
.10458 .33484 L
.1094 .33556 L
.11464 .33623 L
.11917 .3367 L
.12415 .3371 L
.12688 .33727 L
.12944 .3374 L
.13213 .3375 L
.13365 .33755 L
.13504 .33758 L
.13632 .3376 L
.1375 .33761 L
.1388 .33761 L
.13953 .33761 L
.14019 .33761 L
.1414 .3376 L
.14271 .33758 L
.14395 .33756 L
.14509 .33753 L
.14755 .33745 L
.14979 .33736 L
.15482 .33706 L
.15949 .3367 L
.16391 .33627 L
.17381 .33504 L
.18458 .33331 L
.22536 .32412 L
.26462 .31399 L
.28432 .30961 L
.30238 .30655 L
.3118 .30542 L
.31654 .30499 L
.32172 .30464 L
.32446 .3045 L
.32695 .30441 L
.32832 .30437 L
.32905 .30435 L
.32982 .30434 L
.33049 .30433 L
.33123 .30432 L
.33253 .30431 L
.33383 .30431 L
.33503 .30432 L
.33569 .30433 L
.33641 .30434 L
Mistroke
.33772 .30437 L
.33894 .3044 L
.34024 .30444 L
.34258 .30454 L
.34519 .30469 L
.34795 .30489 L
.35289 .30535 L
.3582 .30601 L
.36403 .30691 L
.37447 .30904 L
.38421 .31163 L
.4046 .31892 L
.42317 .32774 L
.46307 .35306 L
.50145 .38369 L
.54229 .41941 L
.58161 .45266 L
.61941 .47973 L
.63879 .49069 L
.64877 .49541 L
.65966 .49979 L
.66938 .50298 L
.67974 .50562 L
.68548 .50673 L
.69069 .50753 L
.6932 .50784 L
.69592 .50812 L
.6983 .50831 L
.70086 .50848 L
.70217 .50854 L
.70342 .50859 L
.70454 .50863 L
.70576 .50865 L
.70692 .50867 L
.70814 .50867 L
.70919 .50867 L
.71035 .50865 L
.711 .50864 L
.71169 .50862 L
.71293 .50858 L
.71426 .50852 L
.71572 .50844 L
.71834 .50826 L
.72077 .50805 L
.7261 .50742 L
.73095 .50667 L
.74183 .50434 L
.75179 .50145 L
.76099 .49817 L
.78178 .48867 L
Mistroke
.82115 .46366 L
.859 .43252 L
.89931 .39352 L
.9381 .35181 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oo003o
o`0000Soo`001Ol00003ool00003o`000?oooooooooo0<oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd4ooooo`006_oooomKo`0000Goo`004_l00006ool00<7o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?l00008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool2o`0000?oo`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool2o`0001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo
00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo1_l0000<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool2o`0000?oo`0000?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04
ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00?ooooo0ooo000kooooo`?o
00000ooo000[ooooo`;o000000?oo`00ooooooooool0[_ooool00ol0003oooooooooo`0Booooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00Kooooo0ooo000dooooo`;o0000
1Ooo000aooooo`;o0000[Oooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`09ooooo`?oo`00;_ooool5ool003Sooooo0_l0002Zooooo`03o`000?oooooooooo01kooooo000Q
ooooo`03o`000?oooooooooo00cooooo0ooo000Xooooo`?oo`00?oooool2o`000:Oooooo00?o0000
ooooooooool07oooool0027ooooo00?o0000ooooooooool03oooool3ool00003o`000?oooooooooo
01gooooo1Ol00014ooooo`;o0000Y?ooool00ooo003oooooooooo`0Pooooo`008Oooool3o`0001;o
oooo00?oo`00o`000?l000000ol0000Fooooo`Co0000Boooool2ool00:7ooooo00?o0000ool00?oo
ool08Oooool0027ooooo00?o0000ooooooooool06?ooool5o`00013oo`0000?o0000ooooooooool0
C_ooool00ol0003oo`00ool0002Nooooo`03o`000?oo003ooooo02;ooooo000Qooooo`03o`000?oo
oooooooo083ooooo00?o0000ool00?ooool0Voooool00ol0003oo`00ooooo`0Sooooo`008Oooool0
0ol0003oooooooooo`22ooooo`;oo`00VOooool00ol0003oo`00ooooo`0Tooooo`008Oooool00ol0
003oooooooooo`23ooooo`03o`000?oo003oo`0009Kooooo00?o0000ool00?ooool09Oooool0027o
oooo00?o0000ooooooooool0QOooool00ol0003oo`00ooooo`2Cooooo`03o`000?oo003ooooo02Ko
oooo000Qooooo`03o`000?oooooooooo08Oooooo00?oo`00ooooooooool0T?ooool00ol0003oo`00
ooooo`0Wooooo`008Oooool3o`0008Sooooo00?oo`00ooooooooool0S_ooool00ol0003oo`00oooo
o`0Xooooo`008Oooool00ol0003oooooooooo`29ooooo`03ool00?l0003ooooo08gooooo00?oo`00
ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0R_ooool00ooo003o0000ooooo`2;oooo
o`03ool00?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0R?ooool00ooo003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`2=ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0S_oo
ool2o`0008Gooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo
097ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0009;o
oooo0_l0001oooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo09?ooooo
0_oo001mooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo09Gooooo00?o
o`00ooooooooool0NOooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03ool00?oooooooooo07Kooooo00?oo`00o`000?ooool0<_ooool0027ooooo00?o0000oooo
ooooool0Uoooool00ooo003oooooooooo`1dooooo`;oo`00=?ooool0027ooooo00?o0000oooooooo
ool0V?ooool00ooo003oooooooooo`1booooo`03ool00?l0003ooooo03Cooooo000Qooooo`03o`00
0?oooooooooo09Wooooo0_oo001aooooo`03ool00?l0003ooooo03Gooooo000Qooooo`?o0000V_oo
ool00ol0003oo`00ooooo`1^ooooo`03ool00?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo09_ooooo00?o0000ool00?ooool0K?ooool00ooo003oooooooooo`0gooooo`008Oooool00ol0
003oooooooooo`2Looooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool0WOooool00ol0003oo`00ooooo`1Xooooo`03ool00?oooooooooo03Wo
oooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ool00?ooool0I_ooool00ooo003ooooo
ooooo`0jooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo06?o
oooo00?oo`00ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool0HOooool00ooo003oooooooooo`0looooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:;ooooo00?o0000ooooooooool0Goooool00ooo003o
ooooooooo`0mooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0?_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Tooooo`;o0000G?ooool00ol0003oooooooooo`0ooooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Vooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0@?ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Yoooool2ool005Kooooo0_l00013ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00005ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0Doooool00ol0
003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oo003ooooo057o
oooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003oo`00
ooooo`1>ooooo`;oo`00Aoooool0027ooooo0ol0002/ooooo`;oo`00C?ooool00ooo003o0000oooo
o`17ooooo`008Oooool00ol0003oooooooooo`2]ooooo`03o`000?oo003ooooo04Wooooo00?oo`00
o`000?ooool0B?ooool0027ooooo00?o0000ooooooooool0[oooool00ooo003oooooooooo`16oooo
o`03ool00?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo0;3ooooo00?oo`00oooooooo
ool0A?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`2aooooo`03ool0
0?l0003ooooo047ooooo0_oo001=ooooo`008Oooool00ol0003oooooooooo`2booooo`03ool00?l0
003ooooo03kooooo0_oo00000ol0003oooooooooo`1<ooooo`008Oooool00ol0003oooooooooo`2c
ooooo`03ool00?l0003o000003cooooo00?oo`00o`000?l00000Coooool0027ooooo0ol0002foooo
o`03o`000?oooooooooo03Oooooo0_oo00000ol0003oooooooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`2gooooo`;o0000=_ooool00ooo003o0000ooooo`1Booooo`008Oooool00ol0003ooooo
ooooo`2iooooo`03o`000?oooooooooo03;ooooo0_l0001Dooooo`008Oooool00ol0003ooooooooo
o`2jooooo`;o0000<?ooool2o`0005Kooooo000Qooooo`03o`000?oooooooooo0;cooooo00?o0000
ooooooooool0:oooool2o`0005Sooooo000Qooooo`03o`000?oooooooooo0;gooooo0_oo00000ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooooooo0;oo
oooo0_oo0002o`0002?ooooo0ol0001Kooooo`008Oooool00ol0003oooooooooo`31ooooo`?oo`00
00?o0000ooooooooool07?ooool3ool005kooooo000Qooooo`?o0000a?ooool3ool001Wooooo0ooo
001Qooooo`008Oooool00ol0003oooooooooo`36ooooo`04o`000?oo003oo`00ool000;o00004?oo
ool4ool006Cooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_oo0005o`0000Kooooo00?o0000
ool00?oo00000_oo00000ol0003oooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`3@oooo
o`Ko00000_oo001/ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omV
IVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo
410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0
003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb
<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMoooo
o`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003ooooo
ooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooo
oooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8boooo
ooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000
ooooooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Cooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo
410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003
oooooomgMgOoEEEE01Cooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGo
V9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aoooo
o`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj
^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo
00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00001Oooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .2881 L
.10458 .26431 L
.14415 .24213 L
.18221 .22354 L
.20178 .21618 L
.21274 .21298 L
.21758 .21181 L
.22272 .21074 L
.22745 .20991 L
.23267 .2092 L
.23496 .20895 L
.23742 .20873 L
.23974 .20857 L
.24186 .20845 L
.24314 .2084 L
.24384 .20838 L
.24451 .20836 L
.24579 .20834 L
.24696 .20833 L
.24763 .20833 L
.24835 .20834 L
.24963 .20836 L
.25034 .20837 L
.25101 .20839 L
.25252 .20845 L
.25383 .20852 L
.25508 .20859 L
.25741 .20877 L
.25992 .20902 L
.26265 .20935 L
.26749 .21011 L
.27205 .21101 L
.28242 .2138 L
.29253 .2175 L
.30343 .22259 L
.32347 .23496 L
.34457 .25212 L
.38268 .29283 L
.42324 .34653 L
.46228 .4027 L
.50378 .46016 L
.54376 .50738 L
.58223 .54158 L
.6021 .5543 L
.61225 .55945 L
.62315 .56397 L
.63338 .56726 L
.64272 .56946 L
.64722 .57026 L
Mistroke
.65212 .57093 L
.65436 .57117 L
.65674 .57137 L
.659 .57152 L
.66104 .57163 L
.66224 .57167 L
.66337 .5717 L
.6646 .57172 L
.66593 .57173 L
.66659 .57173 L
.66731 .57172 L
.66863 .5717 L
.6699 .57167 L
.67109 .57162 L
.67322 .57152 L
.67557 .57136 L
.68032 .5709 L
.6855 .57019 L
.69107 .5692 L
.70115 .56681 L
.71075 .56384 L
.72123 .55983 L
.74235 .5495 L
.78296 .52199 L
.82206 .48754 L
.86361 .44439 L
.90364 .39831 L
.94216 .35141 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28797 L
.10458 .26394 L
.14415 .24225 L
.18221 .22399 L
.20178 .2166 L
.21267 .21334 L
.22272 .21098 L
.22768 .21007 L
.23293 .20929 L
.23548 .20899 L
.23821 .20873 L
.23978 .2086 L
.24121 .2085 L
.24257 .20842 L
.24402 .20836 L
.24471 .20833 L
.24536 .20831 L
.24658 .20828 L
.24772 .20827 L
.24896 .20826 L
.24961 .20827 L
.25032 .20827 L
.25107 .20829 L
.25177 .2083 L
.25301 .20834 L
.25435 .2084 L
.25698 .20856 L
.25948 .20876 L
.26416 .2093 L
.26875 .21003 L
.27382 .21107 L
.28407 .21392 L
.29357 .21749 L
.30249 .22166 L
.32267 .23405 L
.34118 .24891 L
.3808 .2908 L
.41891 .34077 L
.45947 .39873 L
.49852 .45311 L
.54002 .50332 L
.56082 .52403 L
.58 .53999 L
.59868 .55246 L
.60822 .55763 L
.61846 .56226 L
.62869 .56595 L
.63804 .5685 L
.64253 .56946 L
Mistroke
.64743 .5703 L
.65206 .57091 L
.65415 .57112 L
.65635 .57131 L
.65762 .57139 L
.65901 .57147 L
.66028 .57153 L
.66144 .57158 L
.6621 .5716 L
.66282 .57161 L
.66358 .57163 L
.66429 .57164 L
.66496 .57164 L
.66567 .57164 L
.66695 .57163 L
.66812 .57161 L
.66939 .57157 L
.67059 .57153 L
.67169 .57148 L
.67424 .57132 L
.67691 .5711 L
.68153 .57058 L
.68581 .56996 L
.69553 .56802 L
.70608 .56512 L
.71603 .56167 L
.73463 .55341 L
.77315 .52954 L
.81412 .49542 L
.85358 .45557 L
.89151 .41247 L
.93191 .36376 L
.97078 .31582 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0?Oooool>ool00?Wooooo000Qooooo`03o`000?oooooooooo
03Oooooo1?l00002ool000gooooo00Coo`00o`000?l0003o0000m_ooool0027ooooo0ol0000doooo
o`?o00005oooool3o`000??ooooo000Qooooo`03o`000?oooooooooo03;ooooo0_l0000Mooooo`?o
0000l?ooool0027ooooo00?o0000ooooooooool0<?ooool2ool002;ooooo00?o0000ool00?oo0000
kOooool0027ooooo00?o0000ooooooooool0;_ooool2ool002Oooooo00?oo`00ooooooooool0j_oo
ool0027ooooo00?o0000ooooooooool0:oooool00ol0003oo`00ool0000Zooooo`;oo`00j_ooool0
027ooooo00?o0000ooooooooool0:Oooool00ol0003oo`00ool0000^ooooo`03ool00?oooooooooo
0>Oooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ool00?oo0000<Oooool00ooo003o
0000ooooo`3Vooooo`008Oooool3o`0002Cooooo0_l00002ool003Cooooo00?oo`00o`000?ooool0
iOooool0027ooooo00?o0000ooooooooool08_ooool2o`0000;oo`00=oooool00ooo003o0000oooo
o`3Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o00000_oo000jooooo`03ool00?l0003o
oooo0>?ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool00ooo
003o0000ooooo`3Rooooo`008Oooool00ol0003oooooooooo`0Mooooo`;o0000@Oooool2ool00>;o
oooo000Qooooo`03o`000?oooooooooo01_ooooo0_l00015ooooo`03o`000?oooooooooo0=oooooo
000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`3Oooooo`008Oooool00ol0003oooooooooo`0Hooooo`;oo`00BOooool00ol0003oooooooooo`3N
ooooo`008Oooool3o`0001Kooooo0_oo001<ooooo`03o`000?oooooooooo0=gooooo000Qooooo`03
o`000?oooooooooo01Cooooo0_oo000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Booooo`03o`000?oooooooooo02Sooooo1?l00000
0ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`0Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^
k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo017ooooo0_oo000Zooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo
00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool03oooool2ool002cooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Cooooo00?o0000ool00?ooool0
9oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0
?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
003ooooo02gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`05_ooool00ooo003oooooooooo`0Vooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool03?ooool2ool002oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000[ooooo00?o0000ool00?ooool0<?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool02?ooool2o`0003?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00006_ooool00ooo003oooooooooo`0Qooooo`03oeEEEOmVIVKo
000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`;o0000IOooool00ooo003oooooooooo`3D
ooooo`008Oooool00ol0003oooooooooo`04ooooo`;o0000Ioooool00ooo003oooooooooo`3Doooo
o`008Oooool00ol0003oooooooooo`02ooooo`;o0000J_ooool00ooo003oooooooooo`3Cooooo`00
8Oooool01?l0003oooooooooool00002ool006cooooo00?oo`00ooooooooool0b?ooool2o`0000;o
oooo0_l00004ooooo`008Oooool01?l0003oo`00ool00?oo001_ooooo`03ool00?oooooooooo0<Oo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o0000
077o000000?oo`00o`000?l00000/ol000000ooo003o0000o`000005o`0000cooooo00CogMgMo`00
0?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`04o`000?oo003oooooo`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03ool00?l0003ooooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o000000kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03ool00?l0003o000001?ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`2_
ooooo`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000oooo
ooooool0M?ooool00ol0003oooooooooo`2]ooooo`03ool00?oooooooooo01gooooo000Qooooo`03
o`000?oooooooooo07Cooooo00?o0000ooooooooool0[?ooool00ooo003oooooooooo`0Nooooo`00
8Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo0:[ooooo00?oo`00o`000?ooool0
7oooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Yooooo`03ool00?oo
oooooooo01oooooo000Qooooo`?o0000Moooool00ol0003oooooooooo`2Wooooo`03ool00?oooooo
oooo023ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Y_ooool00ooo
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:Go
oooo00?oo`00ooooooooool08Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooo
ooooo`2Sooooo`03ool00?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o
o`00o`000?ooool0X_ooool00ooo003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`1j
ooooo`03ool00?oooooooooo0:3ooooo00?oo`00ooooooooool09?ooool0027ooooo00?o0000oooo
ooooool0Noooool00ooo003oooooooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Qooooo`?o
0000Noooool00ooo003o0000ooooo`2Nooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`00
0?oooooooooo07cooooo00?oo`00ooooooooool0W?ooool00ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooooooo`1mooooo`03ool00?oooooooooo09[ooooo00?o0000ooooooooool09ooo
ool0027ooooo00?o0000ooooooooool0O_ooool00ooo003oooooooooo`2Hooooo`03o`000?oooooo
oooo02Sooooo000Qooooo`03o`000?oooooooooo07kooooo00?oo`00ooooooooool0Uoooool00ol0
003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo09Go
oooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0P?ooool00ooo003ooooo
ooooo`2Cooooo`03ool00?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo083ooooo00?o
o`00ooooooooool0Toooool00ooo003oooooooooo`0[ooooo`008Oooool3o`00087ooooo00?oo`00
ooooooooool0TOooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`22oooo
o`03ool00?oooooooooo08oooooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`2>ooooo`03ool00?oooooooooo02kooooo000Qooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool0S?ooool00ooo003oooooooooo`0_ooooo`008Ooo
ool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo08[ooooo00?oo`00ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`29ooooo`03o`000?oo003o
oooo037ooooo000Qooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0R?ooool00ooo
003oooooooooo`0aooooo`008Oooool3o`0008Kooooo00?o0000ooooooooool0Q_ooool00ooo003o
ooooooooo`0booooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Gooooo
00?oo`00ooooooooool0<oooool0027ooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`23ooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000
ool00?ooool0POooool00ooo003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`29oooo
o`03ool00?oooooooooo083ooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool0ROooool00ol0003oo`00ooooo`1oooooo`03o`000?oooooooooo03Kooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`2:ooooo`03o`000?oo003ooooo07gooooo00?o0000ooooooooool0=oooool0
00Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0002;
ooooo`03o`000?oo003ooooo07_ooooo00?o0000ooooooooool0>?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0Roooool0
0ol0003oo`00ooooo`1jooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0S?oo
ool00ol0003oo`00ooooo`1iooooo`03o`000?oooooooooo03Wooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08gooooo00?o
0000ool00?ooool0Moooool00ol0003oooooooooo`0jooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
003ooooo07Cooooo00?oo`00o`000?ooool0??ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2>ooooo`03o`000?oo003ooooo07?ooooo00?o
o`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1a
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo093ooooo00?o0000ool0
0?ooool0Koooool00ooo003o0000ooooo`0oooooo`008Oooool3o`00093ooooo00?o0000oooooooo
0000K_ooool00ooo003o0000ooooo`10ooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`00
0?oooooooooo06cooooo00?oo`00o`000?ooool0@Oooool0027ooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`1[ooooo`03ool00?oooooooooo047ooooo000Qooooo`03o`000?oooooo
oooo09?ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`12ooooo`008Oooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo06Sooooo00?oo`00ooooooooool0@oooool0027o
oooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo04Co
oooo000Qooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0I?ooool00ooo003ooooo
ooooo`15ooooo`008Oooool3o`0009Kooooo00?o0000ooooooooool0H_ooool00ooo003ooooooooo
o`16ooooo`008Oooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo063ooooo00?oo`00
ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0V?ooool00ol0003oo`00ooooo`1Noooo
o`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00oooooooo
ool0G?ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03ool0
0?oooooooooo05Wooooo0_l0001<ooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?oo
oooooooo05Oooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0W?ooool0
0ooo003oooooooooo`1Eooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo
09gooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0009ko
oooo00?oo`00ooooooooool0D?ooool2ool0057ooooo000Qooooo`03o`000?oooooooooo09oooooo
00?oo`00ooooooooool0C_ooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0003ooooooooo
o`2Oooooo`03ool00?l0003o000004gooooo00?oo`00ooooooooool0D_ooool0027ooooo00?o0000
ooooooooool0X?ooool00ooo003oooooo`00001;ooooo`03ool00?oooooooooo05?ooooo000Qoooo
o`03o`000?oooooooooo0:7ooooo00?oo`00ooooool00000B?ooool2ool005Kooooo000Qooooo`03
o`000?oooooooooo0:;ooooo00?oo`00ooooool00000A_ooool00ooo003o0000ooooo`1Fooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`03ool00?oooooo000004Cooooo00?oo`00o`000?ooool0
Eoooool0027ooooo0ol0002Vooooo`03o`000?oooooooooo043ooooo00?oo`00o`000?ooool0F?oo
ool0027ooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0nooooo`03ool00?oooooo
oooo05Wooooo000Qooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0>oooool00ol0
003oo`00ooooo`1Kooooo`008Oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo03Wo
oooo00?o0000ool00?ooool0G?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003ooooo
ooooo`0fooooo`;o0000Goooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo0:_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Oooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo0_oo00000ol0003oooooooooo`0`
ooooo`;o0000H_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`;oo`00<?ooool00ol0003oooooooooo`1Rooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000[oooool2ool002cooooo0_l0001Uooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0;7ooooo0_oo000Xooooo`03o`000?oo003oo`0006Kooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0/_ooool00ol0003oo`00ooooo`0Uooooo`;oo`00J?oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2dooooo`?oo`008?ooool3
ool006[ooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0]Oooool2o`00
00;oo`006oooool3ool00003o`000?oooooooooo06[ooooo000Qooooo`03o`000?oooooooooo0;So
oooo00Co0000ool00?l0003o00005Oooool3ool000;o0000K_ooool0027ooooo00?o0000oooooooo
ool0_?ooool3o`0000oooooo0ooo0002o`00077ooooo000Qooooo`?o0000_oooool5ool000co0000
M?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?oo
ool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool0
0olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool0
07kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RH
ooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03
ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooo
oooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo
0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo
410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A01kooooo`00O_ooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^
k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oo
oooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`1jooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo
00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMg
Moooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Boooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`1iooooo`00U_ooool00ol0
003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj
^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_oo
ool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<07_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25082 L
.10458 .1949 L
.12507 .17265 L
.14415 .15576 L
.16254 .14352 L
.17284 .13856 L
.18221 .13528 L
.18704 .13407 L
.18969 .13354 L
.19216 .13313 L
.19427 .13286 L
.19654 .13263 L
.19783 .13254 L
.19905 .13247 L
.20015 .13242 L
.20135 .13239 L
.20203 .13239 L
.20276 .13239 L
.20345 .13239 L
.20409 .13241 L
.2053 .13244 L
.20657 .13251 L
.20794 .1326 L
.20922 .13272 L
.21213 .13306 L
.21466 .13346 L
.21696 .1339 L
.22214 .13518 L
.22694 .13671 L
.23205 .13869 L
.24122 .14318 L
.26198 .15761 L
.28145 .1762 L
.29973 .19761 L
.33842 .2526 L
.37956 .31852 L
.41919 .38074 L
.45729 .43315 L
.47854 .45782 L
.49785 .47706 L
.51817 .49394 L
.5369 .50646 L
.55608 .51634 L
.56619 .52038 L
.57688 .52382 L
.58632 .52616 L
.59152 .52718 L
.59646 .52797 L
.60103 .52855 L
Mistroke
.60345 .52881 L
.60603 .52903 L
.60841 .5292 L
.61056 .52932 L
.6116 .52937 L
.61273 .52942 L
.61378 .52945 L
.61477 .52948 L
.61602 .5295 L
.61715 .52951 L
.61837 .52952 L
.61906 .52952 L
.6197 .52951 L
.62076 .5295 L
.62193 .52948 L
.62315 .52945 L
.6243 .52941 L
.62693 .52929 L
.62933 .52915 L
.63475 .5287 L
.63966 .52815 L
.64502 .52739 L
.65582 .52537 L
.67547 .52018 L
.69644 .51265 L
.73799 .49256 L
.77802 .46803 L
.81654 .44086 L
.85751 .40918 L
.89697 .37682 L
.93491 .34462 L
.9753 .30979 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .24997 L
.10458 .19598 L
.12507 .17365 L
.14415 .15624 L
.16254 .14335 L
.17284 .13805 L
.18221 .13451 L
.18704 .13319 L
.18969 .13261 L
.19216 .13217 L
.19445 .13184 L
.19654 .1316 L
.19773 .1315 L
.19886 .13142 L
.20005 .13136 L
.20135 .13132 L
.20203 .13131 L
.20276 .13131 L
.20345 .13131 L
.20409 .13132 L
.2053 .13136 L
.20657 .13142 L
.20794 .13151 L
.20922 .13163 L
.21213 .13198 L
.21466 .13239 L
.21696 .13285 L
.22214 .13418 L
.22694 .13578 L
.23205 .13786 L
.24122 .14257 L
.26198 .15762 L
.28145 .17678 L
.29973 .19856 L
.33842 .25355 L
.37956 .31854 L
.41919 .37995 L
.45729 .4323 L
.47854 .45722 L
.49785 .47679 L
.51817 .49402 L
.5369 .50683 L
.55608 .5169 L
.56619 .521 L
.57688 .52446 L
.58632 .52679 L
.59152 .5278 L
.59646 .52857 L
.60103 .52913 L
Mistroke
.60345 .52937 L
.60603 .52958 L
.60841 .52973 L
.61056 .52984 L
.6116 .52988 L
.61273 .52991 L
.61379 .52994 L
.61477 .52996 L
.61604 .52997 L
.61724 .52997 L
.61831 .52997 L
.61948 .52995 L
.62076 .52993 L
.62211 .52989 L
.62453 .52979 L
.62676 .52967 L
.62886 .52953 L
.63363 .52911 L
.63883 .52849 L
.64359 .5278 L
.65431 .52578 L
.67327 .52075 L
.69399 .51336 L
.7346 .49404 L
.7737 .47061 L
.81525 .44178 L
.85528 .41112 L
.8938 .3797 L
.93477 .34493 L
.97422 .31073 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`0booooo`Co00001Ooo003oooooo`[ooooo000Qooooo`03o`000?oooooooooo02ko
oooo1?l00007ooooo`;o00000ooo003oooooo`Oooooo000Qooooo`03o`000?oooooooooo02_ooooo
0_oo00000ol0003oooooooooo`0=ooooo`04o`000?oo003oo`00ool00?oooooo1?ooool0027ooooo
0ol0000Zooooo`03ool00?oooooooooo01?ooooo00?o0000ool00?ooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`0Xooooo`;oo`005oooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool06Oooool00ooo003o0000ooooo`3n
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`007Oooool00ooo003o0000ooooo`3moooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo01oooooo0_l0003looooo`00
8Oooool00ol0003oooooooooo`0Rooooo`;oo`009?ooool00ol0003oooooooooo`3iooooo`008Ooo
ool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0n?oo
ool0027ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`0Wooooo`03o`000?oooooo
oooo0?Oooooo000Qooooo`?o00007oooool00ooo003oooooooooo`0Yooooo`03o`000?oooooooooo
0?Kooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`3eooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02gooooo
00?oo`00ooooooooool0m?ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0^ooooo`03ool00?oooooooooo0??ooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0;oooool00ooo003oooooooooo`3cooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo037ooooo00?oo`00ooooooooool0l_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0<oooool00ooo003oooooooooo`3aooooo`001Ol00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00006Ooo
ool00ol0003oooooooooo`0eooooo`03ool00?oooooooooo0?3ooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Oooooo00?o
o`00o`000?ooool0>?ooool00ooo003oooooooooo`3_ooooo`001oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool0>Oooool00ooo003oooooooooo`3^ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03ool0
0?oooooooooo03[ooooo00?oo`00ooooooooool0kOooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ooo003ooooo
ooooo`0kooooo`03ool00?oooooooooo0>gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0mooooo`03ool0
0?oooooooooo0>cooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0?_oo
ool00ooo003o0000ooooo`3/ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
oooo043ooooo00?oo`00ooooooooool0joooool0027ooooo0ol0000Booooo`03ool00?oooooooooo
04;ooooo00?o0000ooooooooool0j_ooool0027ooooo00?o0000ooooooooool04_ooool00ooo003o
ooooooooo`13ooooo`03o`000?oooooooooo0>Wooooo000Qooooo`03o`000?oooooooooo017ooooo
00?oo`00ooooooooool0AOooool00ol0003oooooooooo`3Xooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo04Kooooo00?o0000ooooooooool0j?ooool0027ooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`18ooooo`03o`000?oooooooooo0>Oooooo000Qoooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`3Voooo
o`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0i_ooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
iOooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1>ooooo`03ool00?oo
oooooooo0>Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Coooool0
0ooo003o0000ooooo`3Tooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
057ooooo00?oo`00ooooooooool0hoooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Cooooo`03ool00?oooooooooo0>;ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0E?ooool00ooo003oooooooooo`3Qooooo`008Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0hOooool0027ooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo0>3ooooo000Qoooo
o`?o00001oooool00ooo003oooooooooo`1Gooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ooo003oooooooooo`0[
ooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00oooooo00?oo`00ooooooooool0;?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo03Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00kooooo
00?oo`00ooooooooool0;?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo013ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04Oooool00ooo003o0000ooooo`0[ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0gooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooooooo02[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00002ooooo`03
ool00?oooooooooo03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qoooo
o`06o`000?ooooooooooooooool0003oo`00>_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000Dooooo`03o`000?oooooooooo02Oooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIV
o`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`05o`00
0?oooooooooooooooooo0000IOooool00ol0003oooooooooo`3Jooooo`008Oooool01Ol0003ooooo
ooooool0003oo`0006Kooooo00?o0000ooooooooool0fOooool0027ooooo00Co0000ooooool0003o
o`00Ioooool00ol0003oooooooooo`3Iooooo`008Oooool00ol0003oooooool0001Yooooo`03o`00
0?oooooooooo0<kooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Zooooo`03o`000?oo
oooooooo0<kooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003;o0000
00?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oo003o000001?ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00Co0000ool00?oooooo
00004oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03
ool00?oooooooooo0;Cooooo00?o0000ool00?ooool05?ooool2o`0000;ooooo0_l00004ooooo`00
8Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo0;?ooooo00?o0000ooooooooool0
7oooool0027ooooo00?o0000ooooooooool0KOooool00ooo003oooooooooo`2aooooo`03o`000?oo
oooooooo023ooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0[_ooool2
o`0002?ooooo000Qooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0[Oooool00ol0
003oooooooooo`0Sooooo`008Oooool3o`0006oooooo00?oo`00ooooooooool0Zoooool00ol0003o
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo0:Wooooo
00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0L?ooool00ooo003ooooooooo
o`2Xooooo`03o`000?oo003ooooo02Kooooo000Qooooo`03o`000?oooooooooo077ooooo00?oo`00
ooooooooool0YOooool2o`000003ool00?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo
077ooooo00?oo`00o`000?ooool0Y?ooool00ol0003oo`00ool0000Yooooo`008Oooool00ol0003o
ooooooooo`1booooo`03ool00?oooooooooo0:;ooooo00?o0000ool00?ooool0:_ooool0027ooooo
00?o0000ooooooooool0Loooool00ooo003oooooooooo`2Pooooo`03o`000?oo003ooooo02_ooooo
000Qooooo`?o0000Loooool00ol0003oooooooooo`2Oooooo`03o`000?oo003ooooo02cooooo000Q
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0WOooool2ool002kooooo000Qoooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0Voooool00ooo003oooooooooo`0^oooo
o`008Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo09[ooooo00?oo`00oooooooo
ool0;oooool0027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`2Hooooo`03ool0
0?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0U_oo
ool00ooo003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo09Gooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`2Booooo`;o0000=Oooool0027ooooo0ol0001iooooo`03ool00?oooooooooo093o
oooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0NOooool00ooo003ooooo
ooooo`2?ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo07[ooooo00?o
o`00ooooooooool0SOooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1k
ooooo`03ool00?oooooooooo08_ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000oooo
ooooool0O?ooool00ooo003oooooooooo`27ooooo`;oo`0000?o0000ooooooooool0>Oooool0027o
oooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`26ooooo`03ool00?l0003ooooo03co
oooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0Q?ooool00ooo003o0000
ooooo`0mooooo`008Oooool3o`0007kooooo00?oo`00ooooooooool0P_ooool00ooo003o0000oooo
o`0nooooo`008Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo083ooooo00?oo`00
o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0Ooooool00ol0003oo`00ooooo`1noooo
o`;oo`0000?o0000ooooooooool0?oooool0027ooooo00?o0000ooooooooool0P?ooool00ooo003o
ooooooooo`1looooo`03ool00?l0003ooooo04;ooooo000Qooooo`03o`000?oooooooooo087ooooo
00?oo`00ooooooooool0N_ooool00ooo003o0000ooooo`13ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`22ooooo`03ool00?oooooooooo07Sooooo00?oo`00o`000?ooool0A?ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo08;ooooo00?o0000ool00?ooool0Moooool00ooo003oooooooooo`15ooooo`00
1oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008?o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`16ooooo`001oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool0Aoooool000Oooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo073ooooo0_l0001:ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool0B_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo04_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`1Zooooo`;o0000C_ooool0027o
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1Vooooo`;oo`0000?o0000oooooooo
ool0C_ooool0027ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1Uooooo`03ool0
0?l0003o0000057ooooo000Qooooo`?o0000ROooool00ol0003oo`00ooooo`1Sooooo`03ool00?l0
003ooooo05;ooooo000Qooooo`03o`000?oooooooooo08[ooooo00?oo`00ooooooooool0HOooool0
0ooo003o0000ooooo`1Cooooo`008Oooool00ol0003oooooooooo`2;ooooo`03ool00?oooooooooo
05kooooo0_oo001Fooooo`008Oooool00ol0003oooooooooo`2<ooooo`03ool00?oooooooooo05co
oooo00?oo`00o`000?ooool0E_ooool0027ooooo00?o0000ooooooooool0SOooool00ooo003ooooo
ooooo`1Jooooo`03ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo08kooooo00?o
o`00ooooooooool0Eoooool00ol0003oo`00ooooo`1Iooooo`008Oooool00ol0003oooooooooo`2?
ooooo`03ool00?oooooooooo05Gooooo0_oo001Kooooo`008Oooool3o`00093ooooo00?oo`00oooo
ooooool0D_ooool2ool005gooooo000Qooooo`03o`000?oooooooooo097ooooo0_oo001@ooooo`;o
0000Goooool0027ooooo00?o0000ooooooooool0Toooool2ool004gooooo00?o0000ooooooooool0
Goooool0027ooooo00?o0000ooooooooool0U?ooool00ol0003oo`00ooooo`19ooooo`;o0000H_oo
ool0027ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`15ooooo`;o0000I?ooool0
027ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
06Cooooo000Qooooo`03o`000?oooooooooo09Sooooo0_l00010ooooo`?oo`00Ioooool0027ooooo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0kooooo`;oo`0000?o0000ooooooooool0
Ioooool0027ooooo0ol0002Kooooo`;o0000>Oooool2ool00003o`000?oooooooooo06Wooooo000Q
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0=?ooool2ool00003o`000?oooooo
oooo06_ooooo000Qooooo`03o`000?oooooooooo09gooooo0ooo000booooo`;oo`00L?ooool0027o
oooo00?o0000ooooooooool0X?ooool2ool002kooooo0_oo001booooo`008Oooool00ol0003ooooo
ooooo`2Rooooo`;oo`00:_ooool2ool007Cooooo000Qooooo`03o`000?oooooooooo0:Cooooo0_oo
00000ol0003oooooooooo`0Rooooo`?o0000M_ooool0027ooooo00?o0000ooooooooool0Y_ooool0
1?oo003o0000o`000?l0000Nooooo`?o0000NOooool0027ooooo0ol0002Wooooo`?oo`000ol0000H
ooooo`?o0000O?ooool0027ooooo00?o0000ooooooooool0Z_ooool3ool000?o00004Oooool4ool0
07oooooo000Qooooo`03o`000?oooooooooo0;3ooooo1?l0000=ool008?ooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03
oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Co
oooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oo
oooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo
00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEE
oiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooo
ooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7ooooo
ohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?oo
ool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;oooo
o`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoo
oooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^
oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7
ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00000_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1dooooo`00Nooo
ool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool0
1oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool0
2_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01e
ooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`00
0?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0
003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05?ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0
003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0
003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo07Oooooo
002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooo
ooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007Kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22786 L
.08255 .19097 L
.10458 .15741 L
.11448 .14507 L
.12507 .13393 L
.13499 .1255 L
.14415 .11947 L
.14911 .11692 L
.15437 .11477 L
.15964 .11318 L
.16265 .11253 L
.16399 .1123 L
.16546 .11209 L
.1668 .11193 L
.16805 .11182 L
.16925 .11174 L
.17052 .11169 L
.17178 .11167 L
.17296 .11168 L
.17401 .11171 L
.17516 .11177 L
.17642 .11187 L
.1778 .11201 L
.1806 .11241 L
.18318 .11292 L
.1856 .11351 L
.1906 .11508 L
.19605 .11732 L
.20595 .12276 L
.21559 .12964 L
.22451 .13731 L
.26377 .18284 L
.30152 .23687 L
.34173 .29432 L
.38041 .34181 L
.40006 .36169 L
.42155 .37989 L
.44231 .39401 L
.46118 .40403 L
.48079 .4118 L
.49156 .41502 L
.50174 .41742 L
.51146 .41916 L
.51678 .4199 L
.52175 .42047 L
.52634 .42088 L
.53054 .42117 L
.53277 .42129 L
.5352 .42139 L
Mistroke
.53653 .42144 L
.53777 .42148 L
.53893 .42151 L
.5402 .42153 L
.5415 .42155 L
.5422 .42156 L
.54286 .42156 L
.54404 .42156 L
.5453 .42156 L
.54601 .42156 L
.54678 .42155 L
.5475 .42154 L
.54818 .42153 L
.54945 .42151 L
.5508 .42147 L
.55325 .4214 L
.55554 .4213 L
.56077 .42102 L
.56545 .42069 L
.56973 .42031 L
.57939 .41926 L
.59835 .41642 L
.61906 .41234 L
.65968 .40226 L
.69877 .39098 L
.74032 .37826 L
.78036 .36587 L
.81888 .35411 L
.85985 .34193 L
.8993 .33055 L
.93724 .31986 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .23002 L
.08255 .19216 L
.10458 .15723 L
.11448 .14436 L
.12507 .13279 L
.13499 .12411 L
.14415 .11799 L
.14911 .11545 L
.15437 .11334 L
.15691 .11254 L
.15964 .11183 L
.16121 .1115 L
.16265 .11124 L
.16401 .11104 L
.16546 .11086 L
.16615 .11079 L
.1668 .11074 L
.16802 .11066 L
.16916 .11062 L
.17039 .1106 L
.17104 .11061 L
.17176 .11062 L
.1725 .11065 L
.1732 .11068 L
.17445 .11077 L
.17578 .1109 L
.17842 .11126 L
.18092 .11173 L
.1856 .11294 L
.19019 .11454 L
.19525 .11677 L
.20551 .12266 L
.22393 .13749 L
.24327 .15796 L
.26413 .18417 L
.30527 .24235 L
.34489 .298 L
.383 .34426 L
.40425 .36551 L
.42356 .38166 L
.44388 .39538 L
.46261 .40517 L
.48179 .41253 L
.4919 .41541 L
.50259 .41777 L
.51203 .41931 L
.51732 .41996 L
.52216 .42043 L
.52666 .42077 L
Mistroke
.52903 .42091 L
.53156 .42103 L
.53399 .42112 L
.53619 .42118 L
.53725 .4212 L
.5384 .42122 L
.53948 .42123 L
.54048 .42123 L
.54175 .42123 L
.54295 .42123 L
.54402 .42122 L
.54519 .42121 L
.54647 .42118 L
.54782 .42115 L
.55024 .42108 L
.55457 .4209 L
.55934 .42063 L
.56448 .42025 L
.57001 .41975 L
.58002 .41861 L
.6001 .41558 L
.62121 .4115 L
.65937 .40245 L
.69998 .39117 L
.73908 .37926 L
.78063 .36603 L
.82067 .35332 L
.85918 .34162 L
.90015 .32988 L
.93961 .31886 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool09_ooool00ooo003o0000o`000008o`000?oooooo5?ooool0027ooooo00?o0000oooo
ooooool09?ooool2ool00003o`000?oooooooooo00Sooooo1?oo003ooooooa3ooooo000Qooooo`?o
00008_ooool2ool000oooooo0_l000000ooo003oooooooooo`3oooooo`gooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?oo`00ooooooooool04_ooool2ool00?oooooo3Oooool0027ooooo00?o
0000ooooooooool07oooool2ool001Oooooo00?oo`00ooooooooool0ooooool:ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?l0003ooooo01Sooooo00?oo`00ooooooooool0ooooool9
ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?l0003ooooo01[ooooo00?oo`00oooo
ooooool0ooooool8ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01_o
oooo00?oo`00ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Looooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool3o`0001_ooooo00?o
o`00ooooooooool07_ooool00ooo003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooo
oooo01[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3ooooo
o`Cooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3oooooo`008Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0ooooool0027o
oooo0ol0000Eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0o_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo003ooooo0?gooooo
000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0;_ooool00ooo003ooooooooo
o`3looooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo003ooooo033ooooo00?oo`00
ooooooooool0noooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo0?[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01;ooooo00?oo`00
ooooooooool0<oooool00ooo003oooooooooo`3iooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0cooooo`03ool00?oooooooooo0?Wooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Aooooo`03ool00?oooooo
oooo03Gooooo00?oo`00ooooooooool0n?ooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0g
ooooo`03ool00?oooooooooo0?Oooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`0gooooo`03o`000?oo003ooooo0?Oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0>Ooo
ool00ooo003oooooooooo`3fooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo003ooooo03_ooooo00?o
o`00ooooooooool0mOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo03cooooo00?oo`00ooooooooool0m?oo
ool0027ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0mooooo`03o`000?oo003o
oooo0?Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ool00?ooool0?oooool00ol0
003oooooooooo`3cooooo`008Oooool3o`0000cooooo00?oo`00ooooooooool0@?ooool00ol0003o
ooooooooo`3booooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool0l_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0koooool0027ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0>oooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3^ooooo`008Ooo
ool3o`0000Sooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3]ooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0kOooool0
027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo
0>cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ool00?ooool0C?ooool00ooo003o
0000ooooo`3/ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo04gooooo
00?oo`00o`000?ooool0joooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00oooo
o`1?ooooo`03ool00?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000
ool00?ooool0D?ooool00ooo003oooooooooo`3Yooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oo003ooooo057ooooo00?oo`00o`000?ooool0jOooool0027ooooo0ol00004ooooo`03
o`000?oo003ooooo05;ooooo00?oo`00ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oo`00ooooo`0gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@07ooooo`03ool00?oooooooooo03?ooooo1?l000000ol@
413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool00oooool00ol0
003oo`00ooooo`0gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01_ooool00ooo003o0000ooooo`0eooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0=oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01_ooool00ooo003o0000oooo
o`0dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ool00?ooool0>?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool02?oo
ool00ooo003oooooooooo`0cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03_oo
ool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00:ooooo`03ool00?oooooooooo03;ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOo
IVIVooooo`0Jooooo`008Oooool01_l0003ooooooooooooooooo0000ool003[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0Iooooo`008Oooool3o`000003oooooooo003ooooo03[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool0
1Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`05o`000?ooooooooooo`000?oo0000>ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`03o`000?oooooooooo02kooooo
00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@
o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005oooooo00?o0000oooooooo
ool0hOooool0027ooooo00?o0000ooooool00000HOooool00ol0003oooooooooo`3Pooooo`008Ooo
ool00ol0003oooooo`00001Qooooo`03o`000?oooooooooo0>3ooooo000Qooooo`;o0000Hoooool0
0ol0003oooooooooo`3Eooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000I?ooool00ol0
003oooooooooo`3Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooK_l00000
0ooo003o0000o`00002oo`0000;oo`001ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00[ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool3ool00003ooooool0003o
oooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooo
oooo0;Cooooo0ol0000Jooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo
06Oooooo00?oo`00ooooooooool0[oooool4o`0002Oooooo000Qooooo`03o`000?oooooooooo06So
oooo00?oo`00ooooooooool0ZOooool3ool000;o0000:oooool0027ooooo00?o0000ooooooooool0
JOooool00ooo003oooooooooo`2Uooooo`?oo`0000?o0000ooooooooool0;Oooool0027ooooo00?o
0000ooooooooool0JOooool00ol0003oo`00ooooo`2Qooooo`Coo`00<oooool0027ooooo0ol0001Z
ooooo`03o`000?oo003ooooo09cooooo1?oo000gooooo`008Oooool00ol0003oooooooooo`1[oooo
o`03o`000?oo003ooooo09Wooooo0_oo00000ol0003oooooooooo`0hooooo`008Oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oo003ooooo09Gooooo0ol0000mooooo`008Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oo003ooooo093ooooo1?l00010ooooo`008Oooool00ol0003ooooooooo
o`1^ooooo`03ool00?oooooooooo08[ooooo0ooo0002o`0004Cooooo000Qooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0Q_ooool3ool00003o`000?oooooooooo04Kooooo000Qoooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0P_ooool3ool004cooooo000Qooooo`?o
0000LOooool00ol0003oooooooooo`1nooooo`?oo`00Coooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oooooooooo`1jooooo`?oo`00D_ooool0027ooooo00?o0000ooooooooool0Looo
ool2o`0007Oooooo0_l000000ooo003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooooooo073ooooo1?l0001Hooooo`008Oooool00ol0003oooooooooo`1foooo
o`03ool00?l0003ooooo06cooooo0ol0001Looooo`008Oooool00ol0003oooooooooo`1gooooo`03
ool00?l0003ooooo06Sooooo0_oo00000ol0003oooooooooo`1Mooooo`008Oooool00ol0003ooooo
ooooo`1hooooo`03ool00?l0003ooooo06Cooooo0ooo001Rooooo`008Oooool00ol0003ooooooooo
o`1iooooo`03ool00?l0003o000005oooooo00Co0000ool00?oo003oo`00IOooool0027ooooo0ol0
001jooooo`;oo`0000?o0000ooooooooool0FOooool01?l0003oo`00ool00?oo001Xooooo`008Ooo
ool00ol0003oooooooooo`1looooo`;oo`00Eoooool01?l0003oo`00ool00?oo001[ooooo`008Ooo
ool00ol0003oooooooooo`1nooooo`03ool00?oooooooooo057ooooo0_l00002ool006kooooo000Q
ooooo`03o`000?oooooooooo07oooooo0_oo001=ooooo`Co0000L_ooool0027ooooo00?o0000oooo
ooooool0P?ooool00ol0003oo`00ooooo`17ooooo`Co0000M_ooool0027ooooo00?o0000oooooooo
ool0P_ooool00ooo003o0000ooooo`11ooooo`?o00000_oo001iooooo`008Oooool00ol0003ooooo
ooooo`24ooooo`;o0000??ooool4o`0000?oo`00Noooool0027ooooo0ol00026ooooo`?o0000=_oo
ool3o`0000Coo`00O_ooool0027ooooo00?o0000ooooooooool0ROooool3o`00033ooooo00?o0000
ool00?oo00000ooo0022ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o0000:_ooool2o`00
00;oo`00Qoooool0027ooooo00?o0000ooooooooool0S?ooool3ool000?o00008_ooool5o`0008_o
oooo000Qooooo`03o`000?oooooooooo08oooooo1ooo000Hooooo`?oo`000ol0002@ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01?ooool00ol0003oooooooooo`2Fooooo`Goo`001Ol0000>ool009Kooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o0000
4oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0
Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000oooooooo
ool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mE
EEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02
ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01OnHV9So410@o`000?lb<S;oc<c<07_ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8Ooooooo
QhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003oooo
o`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@0
2_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`00
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMg
oc8b<P1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo
017ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo07Wooooo001noooo
o`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oo
oooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ
8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<ooooo`03ojVYZOl@413ooooo07[ooooo
001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oo
oooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomV
IVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`00
0?ooooooooooooooool000003Oooool00ol@413o0000okZj^P1kooooo`00Ooooool00onHV9SoMgMg
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgM
gOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo0000
0_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00onj^[[o
8B4Qooooo`1jooooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo
00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000007_ooooo
002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooo
oonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY07_ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .2732 L
.06244 .23845 L
.08426 .20667 L
.0949 .1943 L
.10458 .18502 L
.11403 .17786 L
.12297 .17283 L
.12787 .17078 L
.1324 .16934 L
.13476 .16876 L
.13737 .16825 L
.13868 .16804 L
.14009 .16786 L
.14142 .16773 L
.14264 .16763 L
.14392 .16756 L
.14514 .16753 L
.14622 .16752 L
.1474 .16754 L
.14869 .16759 L
.14934 .16763 L
.15005 .16768 L
.15132 .16779 L
.15248 .16792 L
.15476 .16824 L
.15721 .16869 L
.16162 .16977 L
.16672 .17142 L
.17226 .17367 L
.18234 .17888 L
.20212 .1925 L
.22313 .21021 L
.26088 .24409 L
.28185 .26129 L
.30108 .27498 L
.32112 .28671 L
.33977 .29519 L
.35869 .30144 L
.3687 .30384 L
.37426 .30491 L
.37939 .30575 L
.38427 .3064 L
.38963 .30698 L
.39503 .3074 L
.39798 .30758 L
.40074 .3077 L
.40198 .30774 L
.40334 .30778 L
.40463 .30781 L
Mistroke
.40581 .30783 L
.40699 .30784 L
.40806 .30785 L
.40929 .30785 L
.41045 .30785 L
.41173 .30784 L
.41237 .30783 L
.41307 .30782 L
.41547 .30776 L
.41682 .30772 L
.41827 .30767 L
.42089 .30755 L
.42619 .30723 L
.43109 .30685 L
.44217 .30567 L
.45194 .30432 L
.4623 .30261 L
.50011 .29467 L
.54036 .28491 L
.5791 .276 L
.59879 .27205 L
.62029 .26834 L
.64109 .26545 L
.65997 .26348 L
.67008 .26268 L
.67962 .2621 L
.68486 .26186 L
.68968 .26167 L
.69498 .26152 L
.69765 .26147 L
.69917 .26144 L
.70058 .26142 L
.70177 .2614 L
.70309 .26139 L
.70441 .26138 L
.70513 .26138 L
.70581 .26137 L
.70706 .26137 L
.7082 .26137 L
.70945 .26137 L
.71077 .26138 L
.71188 .26138 L
.71307 .26139 L
.71521 .26142 L
.71775 .26146 L
.72007 .2615 L
.72522 .26164 L
.73082 .26185 L
.74097 .26235 L
.75042 .26299 L
Mistroke
.76083 .26386 L
.78186 .26615 L
.82217 .27232 L
.86096 .28008 L
.9022 .28975 L
.94193 .29993 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .273 L
.06244 .23719 L
.08255 .20715 L
.09409 .19365 L
.10458 .18392 L
.1094 .18027 L
.11464 .1769 L
.11917 .17448 L
.12415 .17231 L
.12944 .17059 L
.13233 .16989 L
.13504 .16938 L
.13633 .16919 L
.13757 .16904 L
.13869 .16893 L
.13988 .16884 L
.14117 .16877 L
.14237 .16873 L
.1431 .16872 L
.1438 .16872 L
.14509 .16874 L
.14625 .16879 L
.1475 .16886 L
.14867 .16896 L
.14974 .16907 L
.15237 .16942 L
.15485 .16986 L
.15979 .17102 L
.16517 .17271 L
.17476 .17672 L
.18364 .18144 L
.22291 .21027 L
.26066 .24263 L
.30086 .27345 L
.31934 .28479 L
.33955 .2947 L
.35959 .30185 L
.37052 .30464 L
.38069 .30656 L
.38574 .30728 L
.39121 .3079 L
.39372 .30813 L
.39638 .30833 L
.39868 .30847 L
.40114 .3086 L
.40237 .30865 L
.40353 .30869 L
.40467 .30872 L
.40572 .30874 L
Mistroke
.40671 .30876 L
.40776 .30877 L
.40893 .30878 L
.41 .30878 L
.41125 .30878 L
.41241 .30877 L
.41367 .30875 L
.41501 .30872 L
.41726 .30865 L
.41973 .30855 L
.42499 .30825 L
.42996 .30786 L
.43928 .30687 L
.44931 .30547 L
.46021 .30362 L
.50104 .29455 L
.54036 .2846 L
.57816 .27574 L
.59918 .27154 L
.61842 .26826 L
.6385 .26549 L
.65716 .26354 L
.66633 .26281 L
.67612 .26218 L
.68171 .2619 L
.68698 .26169 L
.69171 .26154 L
.69418 .26148 L
.69684 .26142 L
.6994 .26138 L
.70174 .26135 L
.70287 .26134 L
.70409 .26133 L
.70525 .26133 L
.70633 .26133 L
.70756 .26132 L
.70873 .26133 L
.71 .26133 L
.71072 .26133 L
.71138 .26134 L
.71263 .26135 L
.71399 .26136 L
.71675 .2614 L
.71951 .26145 L
.72202 .26151 L
.72765 .26168 L
.73287 .26189 L
.73781 .26213 L
.74751 .26272 L
.7578 .26353 L
Mistroke
.77624 .26541 L
.79579 .26802 L
.8141 .27099 L
.85289 .27875 L
.89413 .28848 L
.93386 .2983 L
.97207 .30791 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00027ooooo1_l0003ooooooako
oooo000Qooooo`03o`000?oooooooooo01gooooo0ol0000:ool000;o0000oooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`;o00003Oooool3ool00003o`000?oooooooooo0?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`;oo`00oooooolF
ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?oo`00o`00
0?ooool0oooooolCooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0oooooolAooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05Oooool2
ool00003o`000?oooooooooo01Sooooo0_l0003ooooooa7ooooo0005o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`03ool00?oooooo
000001gooooo00?o0000ooooooooool0ooooool>ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
000001oooooo0_l0003oooooo`kooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ooo003o0000oooo
o`0Qooooo`03o`000?oooooooooo0?oooooo2oooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ooo003ooooooooo
o`0Sooooo`03o`000?oooooooooo0?oooooo2_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`0Tooooo`;oo`00ooooool;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo013ooooo00?o0000ool00?ooool09oooool00ooo003ooooooooo
o`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool0
0ooo003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ool0
0?ooool0:_ooool2ool00?oooooo1oooool0027ooooo0ol0000>ooooo`03o`000?oo003ooooo02go
oooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo02kooooo00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0ooooool2ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool0ooooool1
ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?oo`00oooo
ooooool0ooooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0eooooo`03
ool00?oooooooooo0?kooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
=oooool00ooo003oooooooooo`3mooooo`008Oooool3o`0000Wooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`3looooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0noooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0looooo`;o0000noooool0027ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo0?Sooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@?ooool2o`000?Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0@_ooool2ool00?Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ool00?ooool0A?ooool00ol0003oo`00ooooo`3dooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oo003ooooo04Kooooo00?o0000ool00?ooool0Ooooool2ool000Co0000K_ooool0027o
oooo0ol00005ooooo`03ool00?oooooooooo04Sooooo0_oo001_ooooo`03o`000?oo003oo`0000co
o`0000?o0000ooooooooool00oooool6o`0000_oo`0000?o0000ooooooooool0F_ooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oo`00ooooo`0fooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o0000ool0000mooooo`Co000000?o410@oooo
ooooool09?ooool6o`00017ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Goo`000_l0000fooooo`Go00006oooool0027ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgo`000?oo0000?_ooool00ol0003oooooooooo`0Oooooo`Coo`000ol0000I
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo1_oo0003
o`0002oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`;o00000_oo
000looooo`03o`000?oooooooooo01Wooooo1_oo00000ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03?ooool6o`0002[ooooo00?oV9RHob4Q8Oo^k^h07?oo
ool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`02o`0000;oo`00>_ooool00ol0003ooooooooo
o`0Dooooo`Goo`009_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01?ooooo00Co
0000ool00?oo003oo`000_l0000Uooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`;o000000?oo`00ooooooooool0=oooool00ol0003o
ooooooooo`0@ooooo`?o000000?oo`00ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06?ooool5ool000;o00008Oooool00omgMgOoIVIVooooo`0Joooo
o`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool0=oooool00ol0
003oooooooooo`0<ooooo`Co0000;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01oooooo1Ooo0002o`0001gooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo
o`00ooooo`0jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09oooo
o`;o0000=_ooool00ol0003oooooooooo`06ooooo`?oo`000ol0000cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09?ooool3ool000?o00005Oooool01Ol0003o^[ZjoooooonHV9So
410@01_ooooo000Qooooo`05o`000?oooooooooooooooooo0000>oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000:ooooo`;o0000<_ooool00omEEEGoIVIVo`000004ooooo`Coo`000_l0
000eooooo`03oeEEEOmVIVKo000000gooooo1?l0000Yooooo`Co00004Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005gooooo0_l0000dooooo`?oo`00
00?o0000ooooooooool0NOooool3o`0002kooooo000Qooooo`04o`000?oooooo0000ool005oooooo
0ol0000/ooooo`03o`000?oo003oo`0000;oo`00P_ooool3ool002_ooooo000Qooooo`03o`000?oo
ooooo`0006?ooooo0ooo000Sooooo`Go00000_oo0029ooooo`Coo`009oooool0027ooooo0_l0001W
ooooo`?oo`007?ooool4o`0009?ooooo00?o0000ool00?oo00000_oo000Iooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`;o0000J_ooool4ool00003o`000?oooooooooo00oooooo0_l00003ool0
0003o`000?oooooooooo09Wooooo00Go0000ool00?oo003oo`00o`00000Eooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM1?ooool001[oooooMol00006ool000;o00003?oo002So`0000;oo`002Ol0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Nooo
ool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj
0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8booooo`1doooo
o`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RH
ob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03
o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03
oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:oooo
o`Ko00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?oZJVYoa0@4?ooool01_ooool0
0omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^ko
oooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0
003ooooo01?ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj00Cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`00
0?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo
00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED0
5?ooool01Ol@413ooooooooooooooooo410@00kooooo00?o^[Zjob4Q8Oooool00oooool00ol0003o
ooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo
00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oM
gMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oiRHV?oooooo^[Zjo`000004
ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4
A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIV
I_mgMgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29983 L
.06244 .29195 L
.06747 .29041 L
.07286 .289 L
.07751 .288 L
.08255 .28713 L
.08564 .28671 L
.08848 .2864 L
.0912 .28618 L
.09258 .28609 L
.09409 .28601 L
.09545 .28596 L
.0967 .28593 L
.09739 .28591 L
.09814 .2859 L
.09885 .2859 L
.0995 .2859 L
.10079 .28591 L
.10196 .28592 L
.10261 .28594 L
.10331 .28596 L
.10458 .28601 L
.10695 .28613 L
.1095 .28631 L
.11409 .28674 L
.11954 .28744 L
.12452 .28822 L
.14558 .29256 L
.16628 .29721 L
.17538 .29898 L
.18022 .29979 L
.18543 .30055 L
.19043 .30115 L
.19501 .30158 L
.19729 .30174 L
.1994 .30187 L
.2016 .30198 L
.20277 .30202 L
.20401 .30205 L
.20466 .30207 L
.20534 .30208 L
.20657 .3021 L
.20788 .30211 L
.20863 .3021 L
.20933 .3021 L
.2106 .30208 L
.21176 .30206 L
.21309 .30202 L
.21436 .30197 L
Mistroke
.21669 .30186 L
.21886 .30171 L
.22376 .30128 L
.22885 .30066 L
.23435 .29979 L
.24432 .29771 L
.25402 .29508 L
.26294 .29217 L
.30248 .27437 L
.3405 .25202 L
.38098 .22596 L
.41994 .20162 L
.46135 .17909 L
.48209 .16966 L
.50125 .1622 L
.52106 .15581 L
.53963 .15109 L
.55834 .14759 L
.56826 .14624 L
.5738 .14563 L
.57895 .14517 L
.58398 .14481 L
.58855 .14456 L
.59116 .14445 L
.59362 .14437 L
.59622 .14431 L
.59768 .14428 L
.59839 .14427 L
.59903 .14426 L
.60025 .14425 L
.60156 .14425 L
.60277 .14425 L
.60392 .14425 L
.60457 .14426 L
.60526 .14427 L
.60649 .14428 L
.60782 .14431 L
.60929 .14434 L
.61198 .14442 L
.61489 .14453 L
.62014 .14481 L
.62509 .14516 L
.6297 .14555 L
.64016 .14671 L
.65035 .14817 L
.66125 .15009 L
.68257 .15488 L
.70272 .16059 L
.74115 .17437 L
.78204 .19263 L
Mistroke
.82141 .21306 L
.85926 .23477 L
.89957 .25951 L
.93836 .28434 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29823 L
.0522 .2938 L
.06244 .29011 L
.0679 .28861 L
.07286 .28752 L
.07784 .28668 L
.08008 .28639 L
.08255 .28613 L
.08522 .28591 L
.08668 .28582 L
.08805 .28575 L
.08932 .2857 L
.09049 .28567 L
.09113 .28566 L
.09184 .28565 L
.09312 .28564 L
.09389 .28565 L
.09462 .28565 L
.09528 .28566 L
.09599 .28568 L
.09759 .28573 L
.09906 .28579 L
.10174 .28595 L
.10458 .28617 L
.10954 .28669 L
.11406 .28728 L
.12422 .28897 L
.14255 .29279 L
.16325 .29721 L
.17235 .29889 L
.1824 .30041 L
.18701 .30096 L
.19198 .30144 L
.19427 .30162 L
.19668 .30177 L
.19893 .30189 L
.20098 .30197 L
.2022 .30201 L
.20334 .30204 L
.20455 .30206 L
.20587 .30207 L
.20702 .30208 L
.20823 .30207 L
.20927 .30206 L
.21041 .30204 L
.2111 .30202 L
.21175 .30201 L
.21298 .30197 L
.21574 .30184 L
Mistroke
.21813 .30169 L
.22073 .30149 L
.22606 .30094 L
.23107 .30026 L
.24044 .29856 L
.25053 .29611 L
.26142 .29276 L
.2814 .28486 L
.30248 .27442 L
.3405 .25179 L
.38098 .2255 L
.41994 .20123 L
.46135 .17905 L
.48209 .16982 L
.50125 .16253 L
.52106 .15629 L
.53963 .15164 L
.55834 .14814 L
.56826 .14677 L
.5738 .14615 L
.57895 .14566 L
.58398 .14527 L
.58855 .14499 L
.59362 .14476 L
.59641 .14468 L
.59766 .14464 L
.59903 .14462 L
.60036 .14459 L
.6016 .14458 L
.60291 .14457 L
.60364 .14457 L
.60431 .14456 L
.6055 .14456 L
.6068 .14457 L
.60803 .14458 L
.60917 .1446 L
.61047 .14462 L
.6117 .14465 L
.61449 .14473 L
.61721 .14483 L
.62014 .14496 L
.62509 .14526 L
.6297 .14561 L
.64016 .14665 L
.65035 .14802 L
.66125 .14984 L
.68257 .15449 L
.70272 .16015 L
.74115 .17409 L
.78204 .19269 L
Mistroke
.82141 .21328 L
.85926 .23476 L
.89957 .25907 L
.93836 .28399 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0Z?ooool2o`0000_oo`002Ol00026ooooo`008Oooool00ol0003oooooooooo`2Qoooo
o`Co00001Ooo000Dooooo`03o`000?oo003oo`0000?oo`00P?ooool0027ooooo00?o0000oooooooo
ool0WOooool4o`0002?ooooo1Ooo001kooooo`008Oooool00ol0003oooooooooo`2Jooooo`03ool0
0?l0003o000002cooooo1Ooo001fooooo`008Oooool00ol0003oooooooooo`2Gooooo`?oo`00=?oo
ool00ooo003o0000o`00001cooooo`008Oooool00ol0003oooooooooo`2Dooooo`?oo`00>_ooool3
o`00073ooooo000Qooooo`03o`000?oooooooooo097ooooo0ooo0010ooooo`?o0000KOooool0027o
oooo0ol0002>ooooo`?oo`00A_ooool3o`0006[ooooo000Qooooo`03o`000?oooooooooo08_ooooo
0ooo001;ooooo`?oo`0000?o0000ooooooooool0IOooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`00057ooooo0ooo001Uooooo`008Oooool00ol0003oooooooooo`27ooooo`;o0000E_ooool2
ool006?ooooo000Qooooo`03o`000?oooooooooo08Gooooo0_l0001Jooooo`;oo`00HOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0Poooool2o`0005kooooo0_oo00000ol0003oooooooooo`1L
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0P?ooool2ool00003o`000?oooooooooo063ooooo0_oo0000
0ol0003oooooooooo`1Jooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o0000Ooooool00ooo003o0000ooooo`1Uooooo`03ool00?l0003o
000005[ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo07gooooo0_oo001[ooooo`;oo`00F?ooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`1kooooo`;oo`0000?o0000ooooooooool0K?ooool00ooo003o0000ooooo`1Eooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1jooooo`03ool00?l0003ooooo077ooooo0_l0001Dooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1hooooo`;oo`00M_oo
ool2o`0005;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0M_ooool2ool007[ooooo0_l0001@ooooo`008Oooool00ol0003oooooooooo`1e
ooooo`03ool00?oooooooooo07cooooo0_l0001>ooooo`008Oooool00ol0003oooooooooo`1coooo
o`03o`000?oo003ooooo07oooooo0ooo001<ooooo`008Oooool3o`00077ooooo0_l00025ooooo`;o
o`00B_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`27ooooo`03ool0
0?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo06kooooo0_l0002;ooooo`;oo`00Aooo
ool0027ooooo00?o0000ooooooooool0K?ooool2o`0008oooooo0_oo0015ooooo`008Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo097ooooo00?oo`00ooooooooool0@_ooool0027o
oooo00?o0000ooooooooool0JOooool00ol0003oo`00ool0002Dooooo`;oo`00@_ooool0027ooooo
00?o0000ooooooooool0J?ooool2ool009Sooooo00?oo`00o`000?ooool0?oooool0027ooooo0ol0
001Vooooo`;oo`00Voooool00ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03ool00?oooooooooo09gooooo0_l0000mooooo`008Oooool00ol0003oooooooooo`1Soooo
o`;oo`00X_ooool2o`0003_ooooo000Qooooo`03o`000?oooooooooo067ooooo0_oo00000ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo05oooooo
0_oo00000ol0003oooooooooo`2Vooooo`;o0000>?ooool0027ooooo00?o0000ooooooooool0G_oo
ool00ooo003o0000o`00002[ooooo`;oo`00=_ooool0027ooooo00?o0000ooooooooool0GOooool0
0ooo003o0000ooooo`2^ooooo`03ool00?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0/?ooool2ool003?ooooo000Qooooo`?o0000F_ooool2o`000;Go
oooo00?oo`00ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`00
03Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0[ooooo`;oo`004?ooool5o`0001_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0/ooooo`03ool00?oooooo
oooo00gooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0m
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02o`0003_ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?o
o`00o`000?ooool03Oooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0m
ooooo`05o`000?ooooooooooooooool000003oooool01?mgMgOo<S8bool00?oo000mooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0^ooooo`;oo`00
3_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oo
ooooooooooooool000003?ooool00ol0003o8B4Qo`000002ool003oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<Oooool00ooo003o
0000ooooo`0<ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo003oo`00047ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?oo`00o`000?oo
ool03?ooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000kooooo3?oo00000ol0003ooooo
ooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oo`00ool00013ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0fooooo`;o
00001oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo00co
oooo0_l000000ooo003o0000o`000009ooooo`Coo`000ol0000Looooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool01Ol0003oo`00ool00?oo003ooooo00Co0000?_ooool00omEEEGoIVIVo`00000o
ooooo`03oeEEEOmVIVKo000000gooooo1?l0000gooooo`;o00001Oooool01OnHV9So410@o`000?lQ
8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Sooooo1?l0000Eooooo`Go00008Oooool3
ool00=Gooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool01Oooool3o`00
01kooooo0_l000000ooo003oooooooooo`0Iooooo`;o000000?oo`00ooooooooool0eoooool2o`00
02;ooooo000Qooooo`03o`000?oooooooooo00;ooooo0_oo00000ol0003oooooooooo`0Rooooo`Ko
o`0000?o0000ooooooooool03?ooool6o`000=kooooo0_l0000Pooooo`008Oooool00ol0003ooooo
ooooo`02ool002gooooo2Ooo00001?l0003oo`00ool00?oo0002o`000>Gooooo0_oo000Eooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003oo`000?oooooo9_ooool2ool001?ooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo
0000:?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017o
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03
ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgM
gOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIV
o`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj
00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo07Wooooo001n
ooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooo
oooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?o
oooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2
ob4Q8@Oooooo00?o0000ooooooooool0N_ooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^
k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1ooo
ool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo0000
1Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0007_o
oooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03oooo
o`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:
ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oMgMgo
ooooo`0007cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=
ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000oooo
o`0Booooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0001looooo`00
Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l00000
0ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003ooooo
ooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`00001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEE
EOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool0
0oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
001looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0Noooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33858 L
.06244 .36737 L
.08426 .3936 L
.0949 .4036 L
.10458 .41087 L
.10911 .41363 L
.11403 .41616 L
.11828 .41795 L
.12297 .41949 L
.12553 .42014 L
.12793 .42062 L
.13047 .42101 L
.13189 .42117 L
.13319 .42128 L
.13439 .42135 L
.13551 .42138 L
.13673 .4214 L
.13803 .42138 L
.13928 .42133 L
.14045 .42126 L
.1415 .42117 L
.14264 .42104 L
.14501 .42071 L
.14755 .42023 L
.15214 .41905 L
.1576 .41714 L
.16257 .41494 L
.17339 .4087 L
.18364 .40112 L
.22197 .36133 L
.26275 .30672 L
.30202 .25053 L
.33977 .19905 L
.37997 .15114 L
.41866 .11395 L
.43831 .09869 L
.4598 .08484 L
.48033 .07435 L
.49942 .06694 L
.50995 .06379 L
.51988 .06142 L
.5288 .05977 L
.53379 .05904 L
.53847 .05848 L
.54303 .05805 L
.54793 .05772 L
.55072 .05758 L
.5521 .05753 L
.55337 .05749 L
Mistroke
.55452 .05746 L
.55575 .05744 L
.55645 .05743 L
.55711 .05742 L
.55834 .05742 L
.55957 .05742 L
.56026 .05742 L
.56091 .05743 L
.56222 .05745 L
.56295 .05746 L
.56362 .05748 L
.5661 .05755 L
.56846 .05765 L
.57118 .05781 L
.5737 .05798 L
.57939 .05847 L
.58904 .05967 L
.59809 .06117 L
.61871 .0659 L
.63893 .07218 L
.65744 .07923 L
.69712 .09803 L
.73528 .12014 L
.77589 .14718 L
.81499 .17589 L
.85654 .20853 L
.89658 .24144 L
.93509 .27393 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34079 L
.06244 .37024 L
.08255 .39386 L
.09396 .404 L
.09905 .40772 L
.10458 .41119 L
.11004 .41404 L
.11508 .41615 L
.11989 .41771 L
.12235 .41833 L
.125 .41888 L
.12738 .41925 L
.12956 .4195 L
.13061 .41959 L
.13175 .41966 L
.13283 .41971 L
.13384 .41974 L
.13511 .41974 L
.13631 .41972 L
.13738 .41967 L
.13855 .4196 L
.13982 .4195 L
.14117 .41936 L
.14357 .41902 L
.14612 .41856 L
.14853 .41801 L
.15305 .41672 L
.15792 .41495 L
.16321 .41259 L
.18154 .40116 L
.20132 .38382 L
.22233 .36084 L
.26008 .3116 L
.30028 .2544 L
.33897 .20095 L
.38011 .15082 L
.41973 .11204 L
.45784 .08474 L
.47745 .07455 L
.4984 .06646 L
.50864 .06351 L
.51975 .06102 L
.52484 .06012 L
.53023 .05933 L
.53528 .05874 L
.5399 .05832 L
.54222 .05815 L
.54474 .058 L
.54712 .05789 L
Mistroke
.54934 .05781 L
.55066 .05778 L
.55191 .05775 L
.55303 .05774 L
.55425 .05773 L
.55488 .05773 L
.55557 .05773 L
.5563 .05773 L
.55697 .05773 L
.55818 .05775 L
.55947 .05777 L
.5607 .0578 L
.56183 .05784 L
.5644 .05794 L
.56666 .05806 L
.56906 .0582 L
.57779 .05897 L
.58269 .05956 L
.58718 .06018 L
.5973 .06191 L
.61559 .06607 L
.63455 .07171 L
.65527 .07927 L
.69588 .09783 L
.73498 .11981 L
.77653 .14699 L
.81656 .17634 L
.85508 .20685 L
.89605 .24086 L
.9355 .27425 L
.97344 .30664 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Voooool7ool000Wo00000_oo00000ol0003ooooo
ooooo`2Dooooo`008Oooool00ol0003oooooooooo`2Gooooo`Go00004Oooool6ool000;o0000Sooo
ool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo09Cooooo0ol0000L
ooooo`?oo`001?l0002:ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
093ooooo0_oo0002o`0002;ooooo0ooo00001?oooooo0000o`000?l00027ooooo`003oooool6o`00
00Gooooo00?o0000ooooooooool01?ooool3o`0008gooooo0ooo00000ol0003oooooooooo`0Voooo
o`;oo`000_ooool2o`0008Gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0R_ooool3ool00003o`000?oooooooooo02oooooo0_l00023ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08Sooooo0_oo00000ol0003oooooooooo`0dooooo`;o0000
POooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`;oo`0000?o
0000ooooooooool0>?ooool2o`0007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0QOooool00ooo003o0000ooooo`0mooooo`;oo`0000?o0000ooooooooool0N_ooool0
01Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`24ooooo`03ool00?oooooooooo
043ooooo0ooo00000ol0003oooooooooo`1gooooo`008Oooool00ol0003oooooooooo`22ooooo`03
o`000?oo003ooooo04Gooooo0_oo00000ol0003oooooooooo`1eooooo`008Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooooooo04Sooooo0ooo00000ol0003oooooooooo`1booooo`008Ooo
ool3o`00083ooooo00?o0000ooooooooool0C?ooool2ool00003o`000?oooooooooo073ooooo000Q
ooooo`03o`000?oooooooooo07kooooo0_l0001Aooooo`;oo`0000?o0000ooooooooool0K_ooool0
027ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`1Cooooo`03ool00?l0003ooooo
06kooooo000Qooooo`03o`000?oooooooooo07_ooooo0_l0001Hooooo`;o0000KOooool0027ooooo
00?o0000ooooooooool0N_ooool00ooo003oooooooooo`1Jooooo`;o0000Joooool0027ooooo00?o
0000ooooooooool0NOooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo06Sooooo000Q
ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0Goooool2o`0006Sooooo000Qoooo
o`?o0000Moooool00ooo003oooooooooo`1Rooooo`;o0000I_ooool0027ooooo00?o0000oooooooo
ool0M_ooool00ooo003oooooooooo`1Sooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo
00?o0000ooooooooool0MOooool00ooo003oooooooooo`1Vooooo`03ool00?l0003ooooo06?ooooo
000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0J?ooool2ool00003o`000?oo
oooooooo063ooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00ooooooooool0Joooool0
0ooo003o0000ooooo`1Pooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo
06gooooo0_oo001Pooooo`008Oooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo073o
oooo00?oo`00o`000?ooool0GOooool0027ooooo0ol0001`ooooo`03ool00?oooooooooo07;ooooo
0_oo001Mooooo`008Oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo07Gooooo00?o
o`00ooooooooool0F_ooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1g
ooooo`;oo`00F_ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo07gooooo0_l0001Fooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo05;ooooo000Qooooo`?o0000JOooool00ol0
003oooooooooo`24ooooo`;o0000D_ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo003o
0000ooooo`28ooooo`;oo`00D?ooool0027ooooo00?o0000ooooooooool0Ioooool00ooo003ooooo
ooooo`29ooooo`03o`000?oo003ooooo04kooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o
o`00ooooooooool0Roooool00ol0003oo`00ool0001=ooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03ool00?l0003ooooo08kooooo00?o0000ool00?ooool0Boooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0IOooool00ooo003oooooooooo`2?ooooo`03o`000?oo003ooooo04[ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo097ooooo00?o0000ool00?oo0000BOoo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`0006?ooooo00?oo`00ooooooooool0U?ooool00ol0003oo`00ooooo`17ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo09Kooooo00?o0000ool00?ooool0A_ooool000Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oo003ooooo09Sooooo00?o0000ool00?ooool0AOooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
H?ooool00ol0003oo`00ooooo`2Jooooo`03o`000?oo003ooooo04Cooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo
00?oo`00ooooooooool0W?ooool00ol0003oooooooooo`12ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0
W_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`1Nooooo`03ool00?oo
oooooooo0:3ooooo0_l00011ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool0?_ooool0027ooooo0ol0001Mooooo`03o`000?oooooooooo
0:Cooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`2Vooooo`;o0000?Oooool0027ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`2Yooooo`;oo`00>oooool0027ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`2[ooooo`03o`000?oo003ooooo03Wooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool0[?ooool00ol0003oo`00ooooo`0hooooo`008Oooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo0:kooooo00?o0000ool00?ooool0=oooool0027ooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`2aooooo`03ool00?oooooooooo03Gooooo000Qooooo`?o0000
Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`000?oo
oooooooo05Oooooo00?oo`00ooooooooool0]?ooool2ool003Cooooo000Qooooo`03o`000?oooooo
oooo05Kooooo00?oo`00ooooooooool0]oooool00ooo003oooooooooo`0aooooo`008Oooool00ol0
003oooooooooo`1Eooooo`03ool00?oooooooooo0;Wooooo00?oo`00ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0E?ooool00ol0003oo`00ooooo`2kooooo`03ool00?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool0_?ooool00ooo003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Cooooo`03o`000?oo003ooooo0;kooooo0_l0
000^ooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oo003ooooo0<7ooooo00?o0000
ooooooooool0:oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<;ooooo00?o0000oooo
ooooool0:_ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?oMgMd0?Oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM037ooooo00?o0000ooooooooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oo`00oc8b
<P0oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0<Oooool00ol0003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<Oooool2o`0000Wooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000gooooo00Coo`00oooooomgMgOo
<S8b?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_oo
ool0=?ooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?lQ8B7o0000oc8b
<_o<c<`0?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00dooooo`;oo`0000?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0J
ooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0hooooo`03ool00?l0003ooooo00Sooooo00?o0000ooooooooool06Oooool0
027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool2o`0004?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Wooooo00?oo`00
o`000?ooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03o`000?oooooo000000?o0000?_oo
ool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000iooooo`03ool00?l0
003o000000;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo0=7ooooo0_oo00000ol0003oooooooooo`0Oooooo`008Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?oo`00o`000?ooool07oooool0
027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3Fooooo`03ool00?l0003ooooo
01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0eoooool00ooo003o
0000ooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool001[oooooD_l000000ooo003o0000o`00003Ko`0000;oo`001ol0000<ooooo`04
omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ooo003o0000ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o
00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003ooooo00gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomg
MgOo<S8b1Oooool0027ooooo00?o0000ooooool00000A_ooool00ooo003oooooooooo`3aooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooo000004Gooooo00?oo`00ooooooooool0
o?ooool0027ooooo00Co0000oooooooooooo0000@oooool00ooo003o0000ooooo`3mooooo`008Ooo
ool01?l0003oooooooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05o`000?oo
ooooooooooooool00000@Oooool00ooo003oooooooooo`3nooooo`008Oooool3o`0000;ooooo00?o
0000ooooooooool0?Oooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oo003ooooo03cooooo00?o0000ool00?ooool0ooooool1ooooo`008Oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool0ooooool1oooo
o`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03[ooooo00?oo`00oooooooo
ool0ooooool2ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo
00?oo`00ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo03Kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo03Kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool3o`00
00Kooooo00?oo`00ooooooooool0=?ooool00ol0003oooooooooo`3oooooo`Gooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0<_ooool00ol0003oooooooooo`3oooooo`Ko
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0<Oooool00ol0003ooooo
ooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0;ooo
ool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool0;Oooool00ol0003oooooooooo`3oooooo`Wooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ool00?ooool0;?ooool00ol0003oooooooooo`3oooooo`[ooooo000Qooooo`03
o`000?oooooooooo00[ooooo00?o0000ool00?ooool0:_ooool00ol0003oo`00ooooo`3oooooo`_o
oooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ool00?ooool0:?ooool00ol0003oo`00
ooooo`3oooooo`cooooo000Qooooo`?o00003?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
003ooooo0?oooooo3Oooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0T
ooooo`;oo`00ooooool?ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
02;ooooo00?oo`00ooooooooool0ooooool?ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo00?oo`00ooooooooool0ooooool@ooooo`008Oooool00ol0003ooooo
ooooo`0@ooooo`;o00007oooool00ooo003oooooooooo`3ooooooa7ooooo000Qooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`3ooooooa;ooooo000Q
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool2ool00?oooooo5Oooool0
027ooooo0ol0000Cooooo`;oo`0000?o0000ooooooooool05Oooool00ooo003oooooooooo`3ooooo
oaGooooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo000Dooooo`03o`000?oo003ooooo0?oo
oooo5oooool0027ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool06?ooool2ool000kooooo0_l0
003ooooooa_ooooo000Qooooo`03o`000?oooooooooo01[ooooo0ooo0009ooooo`;o0000oooooolM
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Looooo`03o`000?oo003oo`0000Coo`000ol0
003ooooooaoooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mg
MgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413o
k^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb
<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVY
ooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00_ooool01Om4A4Co0000o`000?lb
<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`00
0?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Go
oooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRH
V?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00002ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8b
ooooo`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo
01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002?ooool00ol0003oooooooooo`1c
ooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o
0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?o
V9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo
1_l00002ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00008oooo
o`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0
003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^
k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^
o`000?ooool04oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000005ooooo`03
o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool0
0oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko
410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000005oooo
o`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?oo
ool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mg
MgOooooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .35892 L
.06244 .4054 L
.08255 .44165 L
.09396 .45642 L
.09905 .46161 L
.10458 .46626 L
.11004 .46986 L
.11243 .47113 L
.11508 .47233 L
.1174 .47319 L
.11989 .47393 L
.12127 .47426 L
.12253 .47451 L
.12372 .4747 L
.125 .47485 L
.12624 .47496 L
.12736 .47501 L
.12849 .47503 L
.12955 .47502 L
.13079 .47496 L
.13194 .47486 L
.13319 .47471 L
.13452 .47451 L
.13675 .47405 L
.13884 .47351 L
.14357 .47183 L
.14858 .46943 L
.15402 .46612 L
.16392 .45836 L
.18248 .43852 L
.22326 .37758 L
.26253 .30793 L
.30028 .24078 L
.34048 .1759 L
.37917 .12355 L
.39882 .10134 L
.42031 .08057 L
.44107 .06398 L
.45994 .05183 L
.47955 .04202 L
.49045 .03777 L
.5005 .03458 L
.50981 .03222 L
.51968 .03034 L
.5248 .02961 L
.52958 .02907 L
.53484 .02863 L
.53778 .02846 L
.53917 .0284 L
Mistroke
.54048 .02835 L
.54168 .02831 L
.54299 .02828 L
.54417 .02826 L
.54526 .02825 L
.54644 .02825 L
.54774 .02825 L
.54839 .02826 L
.54909 .02827 L
.55035 .02829 L
.55153 .02832 L
.55281 .02836 L
.55514 .02846 L
.55741 .02858 L
.5595 .02872 L
.56429 .02913 L
.56956 .02971 L
.58024 .03133 L
.59036 .03338 L
.59962 .03569 L
.62049 .04226 L
.66017 .0595 L
.69833 .08101 L
.73894 .1081 L
.77804 .13731 L
.81959 .17084 L
.85963 .20489 L
.89814 .23874 L
.93912 .27547 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35778 L
.06244 .40451 L
.08255 .44142 L
.09396 .45658 L
.09905 .46193 L
.10458 .46675 L
.11004 .47048 L
.11243 .47181 L
.11508 .47306 L
.1174 .47397 L
.11989 .47475 L
.12127 .47509 L
.12253 .47536 L
.12372 .47556 L
.125 .47573 L
.12624 .47585 L
.12736 .47591 L
.12849 .47594 L
.12955 .47593 L
.13079 .47588 L
.13194 .47579 L
.13319 .47564 L
.13452 .47544 L
.13675 .47499 L
.13884 .47444 L
.14357 .47274 L
.14858 .47029 L
.15402 .46691 L
.16392 .45898 L
.18248 .43872 L
.22326 .37689 L
.26253 .30699 L
.30028 .24019 L
.34048 .17608 L
.37917 .12446 L
.42031 .08176 L
.44084 .06522 L
.45994 .05261 L
.47836 .04294 L
.49804 .03524 L
.50829 .03227 L
.51368 .03098 L
.51939 .02983 L
.52438 .029 L
.52987 .02826 L
.53228 .028 L
.53487 .02776 L
.53732 .02757 L
.53954 .02743 L
Mistroke
.54209 .0273 L
.54348 .02725 L
.5448 .02721 L
.54602 .02719 L
.54714 .02717 L
.54837 .02717 L
.54967 .02717 L
.55099 .02718 L
.55173 .02719 L
.5524 .0272 L
.5537 .02723 L
.55494 .02727 L
.55771 .02739 L
.56072 .02757 L
.56579 .028 L
.57116 .0286 L
.58082 .03009 L
.59021 .03202 L
.60033 .03459 L
.61862 .04049 L
.65981 .05896 L
.69949 .08218 L
.73765 .10814 L
.77826 .13849 L
.81736 .16963 L
.85891 .20441 L
.89894 .23932 L
.93746 .27382 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`2Sooooo`Coo`00WOooool0027ooooo00?o0000ooooooooool0Uooo
ool6ool000[o00001ooo002Fooooo`008Oooool00ol0003oooooooooo`2Cooooo`Coo`005?ooool3
o`0000?oo`00Toooool0027ooooo00?o0000ooooooooool0T?ooool3ool00003o`000?oooooooooo
01_ooooo0_oo00000ol0003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
o`0000?o0000ooooooooool08Oooool3o`0008gooooo000Qooooo`03o`000?oooooooooo08_ooooo
0_l000000ooo003oooooooooo`0Wooooo`?o0000R_ooool0027ooooo00?o0000ooooooooool0ROoo
ool2o`0002oooooo0ol00027ooooo`008Oooool3o`0008Oooooo0_l0000cooooo`;oo`0000?o0000
ooooooooool0Poooool0027ooooo00?o0000ooooooooool0QOooool2o`0003Oooooo0ooo0023oooo
o`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03[ooooo0ooo0020ooooo`00
8Oooool00ol0003oooooooooo`22ooooo`;oo`00@?ooool2ool007kooooo000Qooooo`03o`000?oo
oooooooo087ooooo00?oo`00ooooooooool0@_ooool00ooo003o0000ooooo`1kooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool2ool004Kooooo0_oo001k
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?oo`00oooo
ooooool0B?ooool00ooo003o0000ooooo`1hooooo`003oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool3o`0007cooooo0_oo001<ooooo`03ool00?l0003o000007Oooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`1?ooooo`03o`00
0?oooooooooo07Cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N_oo
ool00ooo003oooooooooo`1Aooooo`;o0000M?ooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1iooooo`03ool00?oooooooooo05Cooooo0_l0001booooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo00?o0000ool00?ooool0Eoooool00ol0
003oooooooooo`1_ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ool00?ooool0FOooool2o`0006oooooo000Qooooo`03o`000?oooooooooo07Kooooo
00?o0000ool00?ooool0F_ooool2ool00003o`000?oooooooooo06cooooo000Qooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool0GOooool00ooo003o0000o`00001/ooooo`008Oooool3
o`0007Cooooo00?o0000ooooooooool0Goooool2ool00003o`000?oooooooooo06Wooooo000Qoooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0H_ooool00ooo003o0000ooooo`1Yoooo
o`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo06Cooooo0_oo00000ol0003o
ooooooooo`1Vooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Oooooo
00?oo`00o`000?ooool0I_ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1Yooooo`;oo`0000?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0Koooool0
0ol0003oo`00ooooo`1/ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo
06kooooo00?o0000ool00?ooool0K_ooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006go
oooo00?o0000ool00?ooool0L?ooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oo003ooooo07Cooooo00?o0000ooooooooool0G_ooool0027ooooo00?o
0000ooooooooool0K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Q
ooooo`03o`000?oooooooooo06_ooooo00?o0000ool00?ooool0Moooool2o`0005gooooo000Qoooo
o`03o`000?oooooooooo06[ooooo00?o0000ool00?ooool0N_ooool00ol0003oooooooooo`1Joooo
o`008Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000oooooooo
ool0FOooool0027ooooo00?o0000ooooooooool0JOooool00ol0003oo`00ooooo`1mooooo`;oo`00
FOooool0027ooooo0ol0001Xooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`22ooooo`03ool00?oooooo
oooo05Gooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ool00?ooool0Poooool00ooo
003o0000ooooo`1Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo003ooooo08Go
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003oo`00
ooooo`27ooooo`;oo`00Doooool0027ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`29ooooo`03ool00?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`1?ooooo`008Oooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo08gooooo00?oo`00o`000?ooool0C_ooool0027ooooo0ol0001Rooooo`03
o`000?oooooooooo08oooooo00?oo`00o`000?ooool0COooool0027ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`2@ooooo`03ool00?l0003o000004cooooo000Qooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`19ooooo`008Oooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0B?ooool0
027ooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`2Hooooo`03o`000?oooooooooo
04Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0VOooool0
0ol0003oooooooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`2K
ooooo`03o`000?oooooooooo04Gooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0ol0001Nooooo`03ool00?oooooooooo09cooooo00?o0000
ooooooooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Mooooo`;oo`00AOooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0:3ooooo00?oo`00ooooooooool0@_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0G?ooool00ooo003oooooooooo`2Qooooo`03ool00?oooooooooo047ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05_ooooo00?oo`00ooooooooool0Xoooool00ooo003oooooooooo`10ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo05_ooooo00?o
o`00ooooooooool0Y?ooool2ool0043ooooo000Qooooo`03o`000?oooooooooo05[ooooo00?oo`00
ooooooooool0Yoooool00ooo003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`1Joooo
o`03ool00?oooooooooo0:Sooooo00?oo`00ooooooooool0??ooool0027ooooo0ol0001Iooooo`03
ool00?oooooooooo0:[ooooo00?oo`00ooooooooool0>oooool0027ooooo00?o0000ooooooooool0
F?ooool00ooo003oooooooooo`2/ooooo`03ool00?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo05Sooooo00?oo`00ooooooooool0[Oooool00ooo003o0000ooooo`0iooooo`008Oooool0
0ol0003oooooooooo`1Gooooo`03ool00?oooooooooo0:oooooo00?oo`00o`000?ooool0>?ooool0
027ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
03Kooooo000Qooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`0eooooo`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Gooooo
00?o0000ooooooooool0=?ooool0027ooooo0ol0001Eooooo`03o`000?oooooooooo0;Kooooo0_l0
000dooooo`008Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0_?ooool2ool0033ooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
_Oooool00ol0003oo`00ooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?l0
003ooooo0<3ooooo00?o0000ool00?ooool0;Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ooo003oooooooooo`31ooooo`03o`000?oo003ooooo02cooooo000Qooooo`03o`000?oooooooooo
053ooooo00?oo`00o`000?ooool0`oooool00ol0003oo`00ooooo`0[ooooo`008Oooool3o`00053o
oooo00?oo`00ooooooooool0a?ooool00ol0003oo`00ooooo`0Zooooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4ool00?l0
003o<S8bomgMg@0mooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<Oooool00ol0003oo`00ooooo`09
ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B46ooooo`04ool00?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0aooooo`03o`000?oo
003ooooo00Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05oa0@4?ooooooooooooooool@41003?ooool01Ooo003o0000oooooooooooo000003oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037o
oooo00?o0000ool00?ooool02?ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooo
ooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003ooooooooooomgMgOo<S8b
03oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
03?ooooo00?oo`00o`000?ooool02?ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003o
ooooooooo`0mooooo`05o`000?ooooooooooooooool000002oooool01_oo003o0000ob4Q8Ol0003o
<S8bolc<c3oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0=Oooool00ooo003o0000ooooo`08ooooo`03ogMgMomVIVKooooo01[ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400;ooooo`03ool0
0?l0003ooooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Sooooo00?oo`00o`000?ooool02?ooool00ol0003oooooooooo`0Iooooo`008Ooo
ool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03ool00?oooooo000004?ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o
0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09
o`000?oooooooooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooo
oooo04_ooooo00?oo`00ooooooooool0doooool2o`00027ooooo000Qooooo`03o`000?oooooooooo
04_ooooo00?oo`00ooooooooool0eOooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1:ooooo`03ool00?oooooooooo0=Oooooo00?o0000ooooooooool07Oooool0027ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo01;ooooo
0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`3Iooooo`;oo`004oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000
<_l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`;o0000B?ooool00ol0003ooooo
ooooo`3`ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o000000?oo`00ooooooooool0A?oo
ool00ol0003oooooooooo`3kooooo`008Oooool00ol0003oooooool00016ooooo`03o`000?oooooo
oooo0?_ooooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?oo`00o`000?ooool0oOooool0
027ooooo00Co0000ooooool0003oo`00@oooool00ooo003oooooooooo`3mooooo`008Oooool3o`00
0003ool00?oooooooooo043ooooo00?oo`00o`000?ooool0o_ooool0027ooooo00Go0000oooooooo
oooo0000ool00011ooooo`03ool00?oooooooooo0?kooooo000Qooooo`05o`000?oooooooooooooo
oooo0000@?ooool00ooo003o0000ooooo`3oooooo`008Oooool01Ol0003oooooooooooooooooo`00
043ooooo00?oo`00ooooooooool0ooooool0027ooooo00Ko0000ooooooooooooooooo`000?oo000n
ooooo`03ool00?l0003ooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`0looooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03ool00?l0003ooooo0?oooooo0_ooool0027ooooo
0ol00002ooooo`03o`000?oo003ooooo03_ooooo00?oo`00ooooooooool0ooooool2ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00o`000?ooool0oooo
ool3ooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo00?oo`00
ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003ooooo03Oooooo00?oo`00ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo00?oo`00ooooooooool0ooooool5ooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0oooo
ool5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0ooooool6ooooo`008Oooool3o`0000Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Qooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`Sooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3o
ooooo`Wooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`3oooooo`[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo
ool0;?ooool00ooo003o0000ooooo`3oooooo`_ooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0[ooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0?oooooo3Oooool0
027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo
0?oooooo3Oooool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo0?oooooo3_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`3oooooo`oooooo0007ooooo`05
oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00003Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo4?ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo0?oooooo4Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0oooooolAooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0oooooolBooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0oooooolCooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo00?oo`00
ooooooooool06oooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`3ooooooaGooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3ooooooaKo
oooo000Qooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo
5oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo6?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`;o0000oooooolKooooo`008Oooool00ol0003oooooooooo`0Eooooo`;o00004?ooool00ol0
003oooooooooo`3ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02oooool00ol0003oo`00ooooo`3ooooooagooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ool00?ooool02_ooool00ol0003oo`00ool0003ooooooakooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_oo00000ol0003oooooooooo`05ooooo`?oo`00oooooolPooooo`008Oooool3
o`0001[ooooo2?oo003oooooob?ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo
0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01So
oooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^
00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RH
oeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_oo
ool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07[ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;o
ooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0
003oooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1h
ooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`1iooooo`00O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Ooo
ool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?oo
ool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool0
4_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01joooo
o`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l0
00000ol00005ooooo`03omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003o
ooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEEooooo`0Booooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03
oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_oo
ool00oo^k^ko410@omgMg@0Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00So
MgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001kooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33731 L
.06244 .3649 L
.08426 .39009 L
.0949 .39972 L
.10458 .40672 L
.10911 .4094 L
.11403 .41184 L
.11828 .41358 L
.12297 .41507 L
.12553 .41571 L
.12793 .41619 L
.13047 .41657 L
.13189 .41672 L
.13319 .41683 L
.13439 .41691 L
.13551 .41695 L
.13673 .41697 L
.13803 .41695 L
.13928 .41691 L
.14045 .41684 L
.1415 .41676 L
.14264 .41665 L
.14501 .41633 L
.14755 .41588 L
.15214 .41477 L
.1576 .41295 L
.16257 .41085 L
.17339 .40489 L
.18364 .39763 L
.22197 .3594 L
.26275 .3068 L
.30202 .25258 L
.33977 .20282 L
.37997 .15647 L
.41866 .12045 L
.43831 .10567 L
.4598 .09224 L
.48033 .08207 L
.49942 .07487 L
.50995 .07182 L
.51988 .06951 L
.5288 .0679 L
.53379 .06719 L
.53847 .06665 L
.54303 .06623 L
.54793 .0659 L
.55072 .06576 L
.5521 .06571 L
.55337 .06567 L
Mistroke
.55452 .06564 L
.55575 .06562 L
.55645 .06561 L
.55711 .0656 L
.55834 .0656 L
.55957 .0656 L
.56026 .0656 L
.56091 .0656 L
.56222 .06562 L
.56295 .06563 L
.56362 .06565 L
.5661 .06572 L
.56846 .06581 L
.57118 .06596 L
.5737 .06612 L
.57939 .0666 L
.58904 .06774 L
.59809 .06918 L
.61871 .07374 L
.63893 .0798 L
.65744 .0866 L
.69712 .10476 L
.73528 .12613 L
.77589 .15228 L
.81499 .18006 L
.85654 .21167 L
.89658 .24354 L
.93509 .27502 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36391 L
.08255 .38793 L
.0932 .39807 L
.10458 .40662 L
.11009 .40988 L
.11531 .4124 L
.11999 .41421 L
.1224 .41497 L
.12507 .41568 L
.12739 .41618 L
.12988 .41661 L
.13126 .41679 L
.13252 .41692 L
.13379 .41703 L
.13499 .4171 L
.13609 .41714 L
.13726 .41715 L
.13837 .41714 L
.13937 .41712 L
.14055 .41706 L
.14183 .41697 L
.14304 .41685 L
.14415 .41672 L
.14661 .41635 L
.14885 .41592 L
.15389 .41462 L
.15855 .41301 L
.16298 .41114 L
.17287 .40581 L
.18364 .39831 L
.20341 .38054 L
.22442 .3571 L
.26217 .30757 L
.30238 .25138 L
.34106 .20025 L
.3822 .15348 L
.42183 .11792 L
.45994 .09294 L
.47955 .08349 L
.5005 .0758 L
.51074 .07292 L
.52184 .07041 L
.53233 .06861 L
.54199 .06743 L
.54667 .06703 L
.54924 .06685 L
.55169 .06671 L
.55396 .0666 L
.55515 .06655 L
Mistroke
.55643 .06651 L
.55761 .06648 L
.55867 .06645 L
.55975 .06644 L
.56076 .06642 L
.56196 .06641 L
.56327 .06641 L
.56394 .06641 L
.56465 .06642 L
.56593 .06643 L
.56721 .06645 L
.56841 .06648 L
.57068 .06654 L
.57335 .06665 L
.57582 .06678 L
.5814 .06717 L
.58604 .06759 L
.59105 .06816 L
.6001 .06945 L
.61086 .07142 L
.62072 .07364 L
.63968 .079 L
.66039 .0864 L
.701 .10526 L
.7401 .12814 L
.78165 .15637 L
.82169 .1861 L
.8602 .21601 L
.90118 .24852 L
.94063 .28029 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`2Q
ooooo`So0000Voooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Joooo
o`Ko00001Ooo0004ooooo`Ko00000_oo0003o`00093ooooo000?ooooo`Ko00001Oooool00ol0003o
ooooooooo`04ooooo`?o0000U?ooool6o`0001Oooooo1ooo002<ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo097ooooo0ol00002ool0027ooooo00Co0000ool00?oo003o
o`00ROooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2?ooooo`;o0000
0ooo000Vooooo`04o`000?oo003oo`00ool008Kooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0SOooool01?l0003oo`00ool00?oo000/ooooo`03o`000?oo003o000008Co
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Roooool3ool003;ooooo
0ol00021ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08Sooooo0ooo
000hooooo`;o0000Ooooool0027ooooo00?o0000ooooooooool0Qoooool00ooo003o0000ooooo`0k
ooooo`;o0000OOooool0027ooooo00?o0000ooooooooool0QOooool2o`00043ooooo00?o0000ool0
0?oo0000N_ooool0027ooooo0ol00023ooooo`;o0000A?ooool00ol0003oo`00ool0001hooooo`00
8Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo04Oooooo0ooo001eooooo`008Ooo
ool00ol0003oooooooooo`20ooooo`;o0000C?ooool00ol0003oo`00ool0001cooooo`008Oooool0
0ol0003oooooooooo`1nooooo`;o0000D?ooool00ol0003oo`00ool0001aooooo`008Oooool00ol0
003oooooooooo`1mooooo`;oo`00Doooool00ol0003oo`00ool0001_ooooo`008Oooool00ol0003o
ooooooooo`1kooooo`03o`000?oo003ooooo05Kooooo00?o0000ool00?ooool0KOooool0027ooooo
00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`1Iooooo`03ool00?l0003ooooo06_ooooo
000Qooooo`?o0000NOooool2ool005gooooo0_l0001Zooooo`008Oooool00ol0003oooooooooo`1h
ooooo`03ool00?oooooooooo05oooooo0_l0001Xooooo`008Oooool00ol0003oooooooooo`1goooo
o`03ool00?oooooooooo06;ooooo0_l0001Vooooo`008Oooool00ol0003oooooooooo`1fooooo`03
ool00?oooooooooo06Gooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0
MOooool00ooo003oooooooooo`1Wooooo`;o0000Hoooool0027ooooo00?o0000ooooooooool0M?oo
ool00ooo003oooooooooo`1Xooooo`;oo`0000?o0000ooooooooool0H?ooool0027ooooo00?o0000
ooooooooool0Loooool00ooo003oooooooooo`1[ooooo`03ool00?l0003o0000063ooooo000Qoooo
o`?o0000L_ooool00ooo003oooooooooo`1]ooooo`;oo`0000?o0000ooooooooool0GOooool0027o
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`1`ooooo`;oo`0000?o0000oooooooo
ool0Foooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1cooooo`03ool0
0?l0003ooooo05_ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0MOoo
ool2ool00003o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool0N?ooool00ooo003o0000ooooo`1Hooooo`008Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo07[ooooo0_oo001Hooooo`008Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo07cooooo00?oo`00o`000?ooool0EOooool0027ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo05?ooooo000Qooooo`?o0000J_oo
ool00ooo003o0000ooooo`22ooooo`03o`000?oooooooooo05;ooooo000Qooooo`03o`000?oooooo
oooo06Wooooo00?oo`00o`000?ooool0Q?ooool2o`0005;ooooo000Qooooo`03o`000?oooooooooo
06Sooooo00?oo`00o`000?ooool0Qoooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`1Wooooo`03ool00?l0003ooooo08Wooooo00?o0000ooooooooool0C_ooool0027ooooo
00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2;ooooo`;o0000C_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0IOooool00ooo003o0000ooooo`2=ooooo`;oo`00COooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo06Cooooo00?oo`00o`000?ooool0T?ooool2ool004_ooooo0005o`0000;ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001Sooooo`03
ool00?l0003ooooo09;ooooo00?o0000ool00?ooool0BOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0H_ooool00ooo003o
0000ooooo`2Eooooo`03ool00?oooooooooo04Oooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0HOooool00ooo
003o0000ooooo`2Gooooo`03ool00?oooooooooo04Kooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?oo`00o`00
0?ooool0VOooool00ooo003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo
09[ooooo00?oo`00o`000?ooool0A?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo09_ooooo00?oo`00o`00
0?ooool0@oooool0027ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Mooooo`03
ool00?l0003ooooo04;ooooo000Qooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
Woooool00ooo003o0000o`000011ooooo`008Oooool3o`0005gooooo00?o0000ooooooooool0XOoo
ool00ooo003oooooo`000010ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo0:Cooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`2Vooooo`;o0000?Oooool0027ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`2Yooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`1Iooooo`03ool00?l0003ooooo0:gooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`2^ooooo`;oo`00>?ooool0027ooooo0ol0001Hoooo
o`03ool00?oooooooooo0;7ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000oooooooo
ool0Eoooool00ooo003oooooooooo`2cooooo`03ool00?oooooooooo03Cooooo000Qooooo`03o`00
0?oooooooooo05Kooooo00?oo`00o`000?ooool0]Oooool00ooo003o0000ooooo`0cooooo`008Ooo
ool00ol0003oooooooooo`1Eooooo`03ool00?l0003ooooo0;Oooooo0_oo000cooooo`008Oooool0
0ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0;[ooooo00?oo`00ooooooooool0<?ooool0
027ooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`2kooooo`03ool00?oooooooooo
02oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00o`000?ooool0_Oooool00ooo003o
ooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo0;kooooo
00?oo`00o`000?ooool0;Oooool0027ooooo0ol0001Booooo`03ool00?oooooooooo0<3ooooo00?o
o`00o`000?ooool0;?ooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000ool00?l00000?Oooool4o`000003oa0@
4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM02oooooo00?oo`00o`000?ooool02oooool5o`0001_ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00ooo003o
<S8booooo`0nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0<?ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@
00kooooo00?oo`00ooooool00000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^
01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000=oooo
o`04o`000?ooooooMgMgoc8b<Soooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo03;ooooo0_l0000:ooooo`03oiRHV?lQ8B7ok^k^01_ooooo000Qoooo
o`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`?o000000?o<S8b
olc<c?ooool0?_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c00eooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIVI_ooool06_oo
ool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l00013ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0iooooo`;o00001?oo
ool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEE
EOmVIVKo000000gooooo1?l0000iooooo`;oo`000oooool01OnHV9So410@o`000?lQ8B7oc<c<01_o
oooo000Qooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0d_ooool00ooo003ooooo
ooooo`0Pooooo`008Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0=Cooooo00?o
o`00ooooooooool07oooool0027ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`3F
ooooo`;oo`007oooool0027ooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`3Ioooo
o`03ool00?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000oooooooo
ool0BOooool00ooo003oooooooooo`3Jooooo`03ool00?oooooooooo017ooooo00Kok^k^ob4Q8On7
QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o000004So000000?oo`00o`00
0?l00000g?l000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0
027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?oo`00o`000?ooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0
003oooooo`000016ooooo`03ool00?oooooooooo0?7ooooo0_l00002ooooo`;o00001?ooool0027o
oooo00?o0000ooooool00000AOooool00ooo003oooooooooo`3looooo`008Oooool01?l0003ooooo
ooooool00013ooooo`03ool00?oooooooooo0?gooooo000Qooooo`05o`000?ooooooooooooooool0
0000@_ooool00ooo003oooooooooo`3mooooo`008Oooool01Ol0003ooooooooooooooooo0000047o
oooo00?oo`00ooooooooool0o_ooool0027ooooo0ol00002ooooo`03o`000?oooooooooo03gooooo
00?oo`00ooooooooool0ooooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0kooooo`03ool00?oooooooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oo`00ooooo`0jooooo`03ool00?oooooooooo0?oooooo0_ooool0027ooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo0?oooooo0oooool0027o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo0?oo
oooo0oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`0fooooo`03o`00
0?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oo`00oooo
o`0dooooo`03o`000?oooooooooo0?oooooo1Oooool0027ooooo0ol00007ooooo`03ool00?oooooo
oooo03;ooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`07oooo
o`03o`000?oo003ooooo037ooooo00?o0000ooooooooool0ooooool7ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oo003ooooo02oooooo00?o0000ooooooooool0ooooool8ooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oo003ooooo02gooooo00?o0000ooooooooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?ooooooo`0002cooooo00?o
0000ool00?ooool0ooooool:ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
o`0002[ooooo00?o0000ool00?ooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`0;oooo
o`03o`000?ooooooo`0002Sooooo00?o0000ool00?ooool0ooooool<ooooo`008Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?ooooooo`0002Kooooo00?o0000ool00?ooool0ooooool=ooooo`00
8Oooool3o`0000gooooo00?o0000ooooooooool09?ooool2ool00?oooooo3oooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03ool00?oooooooooo0?oooooo3ooo
ool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooo
oooo0?oooooo4?ooool0027ooooo00?o0000ooooooooool04?ooool2o`0001oooooo00?oo`00oooo
ooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_o
oooo00?oo`00ooooooooool0oooooolBooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Sooooo00?o0000ool00?ooool0oooooolDooooo`008Oooool00ol0003ooooooooo
o`0Dooooo`;o00005oooool00ol0003oo`00ooooo`3ooooooaGooooo000Qooooo`?o00005Oooool2
ool001Cooooo0_l0003ooooooaSooooo000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`3ooooooaSooooo000Qooooo`03o`000?oooooooooo01So
oooo0_oo00000ol0003oooooooooo`0;ooooo`;o0000oooooolKooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`?oo`002?ooool3o`000?oooooo7Oooool0027ooooo00?o0000ooooooooool07Ooo
ool8ool00?oooooo8?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Pooo
ool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@
413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`00
0?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Ko
oooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[o
A4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7o
k^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Booooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo
001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So
8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`00
00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000oooo
o`0Cooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03
o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Co
oooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomE
EED05?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?o
oooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@
4?oMgMd05?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo
00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMg
ooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo1?l0001fooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29825 L
.06244 .28885 L
.07286 .28521 L
.07784 .28384 L
.08255 .28277 L
.08523 .28226 L
.08813 .28179 L
.09054 .28147 L
.0932 .28117 L
.09607 .28094 L
.09764 .28084 L
.09912 .28077 L
.09982 .28075 L
.10049 .28073 L
.10175 .2807 L
.10245 .28069 L
.1031 .28069 L
.10382 .28068 L
.10458 .28069 L
.10582 .28071 L
.10653 .28073 L
.10718 .28074 L
.10851 .2808 L
.10994 .28087 L
.11251 .28103 L
.11487 .28123 L
.12058 .28188 L
.12599 .2827 L
.14616 .28691 L
.16438 .29137 L
.17475 .29375 L
.18449 .29569 L
.19401 .2972 L
.19936 .29785 L
.2019 .29811 L
.20427 .29831 L
.20683 .2985 L
.20915 .29863 L
.21174 .29875 L
.21316 .29879 L
.2138 .29881 L
.2145 .29882 L
.21581 .29884 L
.21652 .29885 L
.21719 .29885 L
.21838 .29885 L
.21967 .29884 L
.22039 .29883 L
.22117 .29881 L
Mistroke
.2226 .29877 L
.22399 .29872 L
.22527 .29866 L
.22793 .29851 L
.23037 .29834 L
.23587 .2978 L
.24072 .29717 L
.24584 .29635 L
.25472 .29454 L
.26446 .29205 L
.284 .28553 L
.30493 .27666 L
.34635 .25505 L
.38624 .2319 L
.42462 .21022 L
.46546 .19006 L
.48575 .18164 L
.50478 .17486 L
.5232 .16938 L
.54258 .16479 L
.55224 .16297 L
.5628 .16132 L
.5724 .16015 L
.58132 .15932 L
.58639 .15897 L
.58905 .15882 L
.59187 .15868 L
.59434 .15859 L
.59705 .1585 L
.59824 .15847 L
.59951 .15845 L
.60063 .15843 L
.60182 .15841 L
.60306 .1584 L
.60421 .15839 L
.60544 .15839 L
.60615 .15839 L
.60681 .1584 L
.608 .1584 L
.60909 .15841 L
.61028 .15843 L
.61154 .15845 L
.61374 .1585 L
.61578 .15856 L
.62042 .15875 L
.62546 .15903 L
.63092 .15942 L
.64085 .16036 L
.65051 .16156 L
.65943 .16291 L
Mistroke
.67817 .16648 L
.6988 .1715 L
.73911 .18432 L
.7779 .19991 L
.81914 .21935 L
.85887 .24026 L
.89709 .26184 L
.93775 .28585 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30003 L
.06244 .29044 L
.07286 .28645 L
.08255 .28366 L
.08813 .28249 L
.0932 .28169 L
.096 .28136 L
.09748 .28121 L
.09905 .28108 L
.10042 .28099 L
.10192 .2809 L
.1033 .28085 L
.10458 .28081 L
.10583 .28078 L
.10652 .28078 L
.10715 .28077 L
.10838 .28078 L
.10954 .28079 L
.1102 .2808 L
.1109 .28082 L
.11214 .28087 L
.11349 .28093 L
.11496 .28101 L
.11742 .28118 L
.12006 .28141 L
.12483 .28195 L
.13452 .28345 L
.14335 .28518 L
.16405 .28991 L
.1832 .29416 L
.19278 .29593 L
.20178 .29725 L
.2063 .29776 L
.21117 .2982 L
.2138 .29838 L
.21657 .29853 L
.21894 .29862 L
.22028 .29866 L
.22153 .29868 L
.2228 .2987 L
.22345 .2987 L
.22415 .2987 L
.22541 .29869 L
.22658 .29868 L
.22728 .29867 L
.22795 .29865 L
.22921 .29862 L
.23057 .29857 L
.23205 .2985 L
Mistroke
.23455 .29835 L
.2372 .29815 L
.24198 .29768 L
.24701 .29702 L
.25174 .29625 L
.26057 .29441 L
.27036 .2918 L
.28069 .28842 L
.29917 .28091 L
.3372 .26089 L
.37768 .2362 L
.41664 .21291 L
.45805 .1917 L
.47879 .18303 L
.49795 .17631 L
.51776 .17065 L
.53633 .16653 L
.55503 .16349 L
.56496 .16231 L
.5705 .16177 L
.57565 .16136 L
.58068 .16102 L
.58524 .16078 L
.59032 .16058 L
.5931 .1605 L
.59435 .16047 L
.59573 .16044 L
.59696 .16042 L
.59829 .16041 L
.59903 .1604 L
.59969 .16039 L
.601 .16039 L
.6022 .16038 L
.6035 .16039 L
.60473 .16039 L
.60586 .1604 L
.60717 .16041 L
.60839 .16043 L
.61118 .16048 L
.6139 .16056 L
.61684 .16066 L
.62179 .16087 L
.62639 .16113 L
.63686 .16192 L
.64705 .16295 L
.65795 .16434 L
.67927 .16791 L
.69941 .1723 L
.73785 .18339 L
.77873 .19891 L
Mistroke
.8181 .21704 L
.85596 .23679 L
.89627 .25969 L
.93506 .28317 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`2^ooooo`_o0000Roooool0027ooooo00?o0000ooooooooool0Y?ooool:
o`000003oooooooo003oo`0000koo`001Ol00020ooooo`008Oooool00ol0003oooooooooo`2Noooo
o`;o00001Ooo000Jooooo`03ool00?oooooooooo00;ooooo1?l0001looooo`008Oooool3o`0009_o
oooo1Ooo000Xooooo`;o00000ooo00000ol0003oooooooooo`1dooooo`008Oooool00ol0003ooooo
ooooo`2Gooooo`Coo`00<_ooool3ool000?o0000LOooool0027ooooo00?o0000ooooooooool0Tooo
ool2o`0000;oo`00>Oooool3ool000?o0000K_ooool0027ooooo00?o0000ooooooooool0TOooool2
o`00043ooooo1Ooo00000ol0003oooooooooo`1Yooooo`008Oooool00ol0003oooooooooo`2?oooo
o`;o0000Aoooool2ool000;o0000J?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0R_ooool2
ool000?o0000COooool3o`0006Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`28ooooo`;oo`000_l0001C
ooooo`?o0000H_ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`0008Kooooo0_oo00000ol0003oooooooooo`1Gooooo`;o0000H?ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0Q?ooool2ool005gooooo0ooo001Nooooo`001oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08;ooooo0_oo
001Rooooo`?oo`00Foooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0P?ooool2ool00003o`000?oooooooooo06Cooooo0_oo
001Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1nooooo`;oo`0000?o0000ooooooooool0J?ooool3ool005Kooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0OOoo
ool00ooo003o0000ooooo`1]ooooo`03o`000?oo003ooooo05Cooooo000Qooooo`03o`000?oooooo
oooo07cooooo0_l0001aooooo`?o0000D_ooool0027ooooo00?o0000ooooooooool0N_ooool2o`00
07Kooooo0_l0001@ooooo`008Oooool3o`0007Sooooo0_l0001jooooo`;o0000C_ooool0027ooooo
00?o0000ooooooooool0M_ooool2o`0007kooooo0_l0001<ooooo`008Oooool00ol0003ooooooooo
o`1booooo`;oo`000_l00022ooooo`;oo`00B_ooool0027ooooo00?o0000ooooooooool0LOooool0
0ooo003o0000o`000026ooooo`;oo`00B?ooool0027ooooo00?o0000ooooooooool0Koooool2ool0
0003o`000?oooooooooo08Oooooo00?o0000ool00?oo0000A_ooool0027ooooo00?o0000oooooooo
ool0K_ooool00ooo003o0000ooooo`2<ooooo`03o`000?oo003ooooo04Cooooo000Qooooo`03o`00
0?oooooooooo06gooooo00?oo`00ooooooooool0Soooool2ool004?ooooo000Qooooo`?o0000Jooo
ool2ool009?ooooo00?o0000ool00?oo0000@Oooool0027ooooo00?o0000ooooooooool0JOooool2
ool009Oooooo00?o0000ool00?oo0000?oooool0027ooooo00?o0000ooooooooool0Ioooool2ool0
09_ooooo00?o0000ool00?ooool0?Oooool0027ooooo00?o0000ooooooooool0I_ooool00ooo003o
0000ooooo`2Mooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo06Cooooo
0_l0002Qooooo`;o0000>oooool0027ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`2Sooooo`;o0000>Oooool0027ooooo00?o0000ooooooooool0HOooool2o`000:Sooooo00?o0000
ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0Goooool2o`000:_ooooo0_l0000foooo
o`008Oooool3o`0005gooooo0_l0002_ooooo`03o`000?oo003oo`0003?ooooo000Qooooo`03o`00
0?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Oooooo00?o0000ool00?oo0000<oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM02Wooooo00?o0000ool00?oo00004Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oo003oo`0003Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Zooooo`03o`000?oo003oo`0000oooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool01Ol0003ooooooooooooooooo000000;oo`00>Oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00ol0003oo`00
ooooo`0>ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00;o000000?oo`00ooooooooool0
>Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0
;_ooool2ool000kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Co0000ob4Q8Ol0003o<S8b0_l00002ool003co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0<?ooool00ol0003oo`00ool0000=ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo00kooooo00?o0000ool00?oo00002?oo0009o`0001_ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`04o`000?oooooo0000o`0000;oo`00?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool00ol0003oo`00ooooo`0<
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00002oooool01?l0003oo`00ool00?oo000C
ooooo`Goo`005_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00Co0000ool00?oo003oo`00
@?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
=_ooool00ooo003o0000ooooo`06ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo
00?o0000ooooooooool02?ooool2o`0000;oo`006_ooool00ol0003oo`00ool00003ool0017ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP09ooooo`?o000000Coo`00o`000?l0003o0000?_ooool00omE
EEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000fooooo`03ool00?l0003o0000
00Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`06oooo
o`;o00000_oo000Oooooo`?o00000ooo000Iooooo`?o0000e?ooool00ol0003oooooooooo`0Roooo
o`008Oooool00ol0003oooooooooo`04ooooo`;o00009_ooool3o`0000Coo`003oooool6o`000=So
oooo0_l0000Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;o0000;oooool:o`0000Soo`00
gOooool2o`00023ooooo000Qooooo`03o`000?oooooooooo00;o0000oooooolSooooo`03o`000?oo
oooooooo01?ooooo0_l00002ooooo`;o00001?ooool0027ooooo0ol0003oooooobKooooo0_l0000C
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol00003ool00?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@
4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003ooooooooo
o`3ooooooc_ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xooo
ool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool0
0oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00ooo
ool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEE
ooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03
okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Noooool007kooooo00Oo410@omgM
gOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000
ooooo`0;ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@
4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o
<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo
00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00001kooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8b
ooooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o
0000ooooooooool02_ooool6o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o
0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Ooo
ool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
1?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<07_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGo
MgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo07gooooo002Fooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000
okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03omgMgOl@413oV9RH07gooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o
^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omV
IVKoMgMgooooo`0Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
411kooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27238 L
.06244 .23683 L
.08426 .20431 L
.0949 .19164 L
.10458 .18215 L
.11403 .17482 L
.12297 .16968 L
.12787 .16759 L
.1324 .16613 L
.13476 .16554 L
.13737 .16502 L
.13868 .16482 L
.14009 .16463 L
.14142 .1645 L
.14264 .16441 L
.14392 .16435 L
.14514 .16432 L
.14622 .16431 L
.1474 .16434 L
.14869 .1644 L
.14934 .16444 L
.15005 .16449 L
.15248 .16475 L
.15476 .1651 L
.15721 .16558 L
.16162 .16671 L
.16719 .16862 L
.17246 .1709 L
.18234 .17627 L
.20225 .19068 L
.22067 .20694 L
.25994 .2445 L
.29769 .27667 L
.31866 .29095 L
.33789 .30144 L
.35674 .3093 L
.36622 .31239 L
.37658 .31513 L
.38686 .31723 L
.39619 .31862 L
.40136 .3192 L
.40409 .31945 L
.40697 .31967 L
.40949 .31983 L
.41226 .31998 L
.41478 .32008 L
.41714 .32015 L
.41839 .32018 L
.41908 .32019 L
Mistroke
.41973 .3202 L
.42098 .32021 L
.42212 .32021 L
.42278 .32021 L
.42348 .32021 L
.42473 .32021 L
.42543 .3202 L
.42608 .32019 L
.42755 .32017 L
.42883 .32014 L
.43005 .3201 L
.43232 .32003 L
.43743 .31978 L
.44205 .31948 L
.44631 .31913 L
.45597 .31814 L
.47467 .31549 L
.49529 .31172 L
.53554 .30294 L
.57428 .29421 L
.61547 .28605 L
.63604 .28272 L
.65515 .28016 L
.67361 .27821 L
.68387 .27736 L
.69331 .27673 L
.70358 .2762 L
.70898 .27599 L
.7147 .27582 L
.71709 .27576 L
.71966 .27571 L
.72209 .27568 L
.7243 .27565 L
.72565 .27564 L
.7269 .27563 L
.72755 .27563 L
.72827 .27562 L
.72902 .27562 L
.72972 .27562 L
.73101 .27562 L
.73219 .27562 L
.73349 .27563 L
.73414 .27563 L
.73486 .27563 L
.73739 .27566 L
.73882 .27567 L
.74013 .27569 L
.74512 .27578 L
.74965 .2759 L
.75445 .27606 L
Mistroke
.76441 .2765 L
.77539 .27714 L
.79481 .27869 L
.8157 .28088 L
.85694 .28657 L
.89667 .29337 L
.93488 .30069 L
.97555 .30889 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27199 L
.06244 .23587 L
.08255 .20557 L
.09409 .19184 L
.10458 .18186 L
.11464 .17456 L
.11926 .17195 L
.12415 .16968 L
.12937 .16783 L
.13169 .16718 L
.13419 .16661 L
.13687 .16614 L
.13807 .16597 L
.13938 .16582 L
.14017 .16575 L
.14091 .16569 L
.14167 .16564 L
.14236 .16561 L
.14368 .16557 L
.14441 .16556 L
.14509 .16556 L
.14625 .16558 L
.1475 .16563 L
.14867 .16571 L
.14974 .16579 L
.15237 .1661 L
.15485 .1665 L
.15979 .16759 L
.16517 .16924 L
.17476 .17324 L
.18364 .17803 L
.2023 .19093 L
.22291 .2083 L
.26311 .24579 L
.3018 .27888 L
.32144 .29264 L
.34294 .30467 L
.35286 .30911 L
.36346 .31307 L
.3734 .31605 L
.38256 .3182 L
.3928 .31995 L
.3982 .32061 L
.40095 .32088 L
.40391 .32112 L
.4065 .32129 L
.40886 .32141 L
.41 .32146 L
.41124 .3215 L
Mistroke
.41241 .32154 L
.4135 .32156 L
.41417 .32157 L
.41489 .32159 L
.41616 .3216 L
.41687 .3216 L
.41763 .3216 L
.41827 .3216 L
.41898 .3216 L
.42025 .32158 L
.42096 .32157 L
.42161 .32156 L
.42406 .32149 L
.42635 .32141 L
.42888 .32128 L
.434 .32095 L
.43874 .32054 L
.44318 .32008 L
.46396 .31706 L
.48418 .31309 L
.5027 .30891 L
.54237 .29954 L
.58053 .29144 L
.60182 .28768 L
.62115 .2848 L
.6415 .2823 L
.66024 .28047 L
.67947 .27902 L
.69022 .27839 L
.70028 .27791 L
.70935 .27756 L
.71908 .27729 L
.72462 .27717 L
.72735 .27713 L
.72988 .2771 L
.73212 .27707 L
.7346 .27705 L
.73588 .27704 L
.73709 .27704 L
.73836 .27703 L
.73907 .27703 L
.73973 .27703 L
.74101 .27703 L
.74221 .27703 L
.74329 .27703 L
.74446 .27704 L
.74574 .27704 L
.74709 .27705 L
.74952 .27707 L
.75176 .27709 L
Mistroke
.75386 .27712 L
.75863 .27721 L
.76384 .27733 L
.7686 .27747 L
.77932 .2779 L
.78918 .27843 L
.79832 .27904 L
.81905 .28087 L
.83959 .28331 L
.8582 .28604 L
.89829 .29317 L
.93686 .30077 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool08Oooool6o`000?oooooo7_ooool0027ooooo0ol0000Mooooo`03
o`000?oo003oo`0000[oo`00oooooolKooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oo003oo`0000cooooo00Coo`00o`000?l0003o0000oooooolGooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oo003ooooo017ooooo00?o0000ooooooooool0oooooolDooooo`008Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo0_l0003ooooooaCooooo000Q
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3o
oooooa7ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?oo
ool2o`000?oooooo4Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_oo
ool2ool00?oooooo4?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool3o`0001Gooooo00?o0000ooooooooool07Oooool2ool00?oooooo3_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo0?oooooo2ooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo02?ooooo00?oo`00ooooooooool0
ooooool:ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0
ooooool9ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0
ooooool8ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`3oooooo`Oooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`3oooooo`Kooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00003_ooool00ooo003oooooooooo`0]oooo
o`03ool00?oooooooooo0?oooooo1?ooool0027ooooo00?o0000ooooooooool03Oooool00ooo003o
0000ooooo`0_ooooo`03ool00?oooooooooo0?oooooo0oooool0027ooooo00?o0000ooooooooool0
3?ooool00ooo003o0000ooooo`0aooooo`03o`000?oooooooooo0?oooooo0_ooool0027ooooo00?o
0000ooooooooool03?ooool00ooo003oooooooooo`0booooo`03o`000?oooooooooo0?oooooo0Ooo
ool0027ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0dooooo`03o`000?oooooo
oooo0?oooooo000Qooooo`03o`000?oooooooooo00[ooooo00?oo`00o`000?ooool0=_ooool00ol0
003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?l0003ooooo03So
oooo00?o0000ooooooooool0oOooool0027ooooo0ol00009ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0o?ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo0?_ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0??ooool00ooo003o0000ooooo`3jooooo`008Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03gooooo0_oo003jooooo`008Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo043ooooo00?oo`00ooooooooool0moooool0027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`11ooooo`03ool00?oooooooooo0?Kooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`3eooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo0_oo003eooooo`008Oooool3o`00
00Gooooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`3booooo`008Oooool00ol0003o
ooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000ool00?lb<S;ogMgM03gooooo1?l000000ol@413oooooooooo`0k
ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Go00006oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0f
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oo`00oc8b<_ooool0?_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03ool0
0?oooooooooo03gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0gooooo`05o`000?ooooooooooooooool000003oooool01?mgMgOo<S8b
ool00?l0000mooooo`03o`000?oooooooooo03Gooooo4ol00009ool000Ko0000>_ooool00onHV9So
8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03Sooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02_ooooo1?l0000?ool00003ooooool0003ooooo
00cooooo00Co0000ob4Q8Ol0003o<S8b2Ooo0004o`0003Cooooo00?oMgMgofIVI_ooool06_ooool0
027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09Oooool6o`0000?ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo1_l00007ool002Sooooo00?o0000ooooooooool06Oooool0
027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool07oooool0
0ol0003oo`00ool00002ool00003o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Hooooo`?o00001_oo000Nooooo`05o`000?nj^[[ooooooiRHV?l@41006ooo
ool0027ooooo00Go0000ooooooooooooooooool0000kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool0=Oooool00omEEEGoIVIVo`00000Looooo`Koo`00
7Oooool00omEEEGoIVIVo`00000=ooooo`Co00008?ooool3ool000?o00006?ooool01OnHV9So410@
o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooool005Sooooo0_l0001=ooooo`Oo
o`00GOooool5o`0003?ooooo000Qooooo`03o`000?ooooooo`0005_ooooo00?o0000ool00?oo0000
B?ooool5o`0006Kooooo0_l00003ool002kooooo000Qooooo`03o`000?ooooooo`0005gooooo00?o
0000ool00?oo0000@?ooool6o`0006oooooo00Co0000ool00?oo003oo`00:oooool0027ooooo00?o
0000ool00?ooool0Goooool00ol0003oo`00o`00000iooooo`Coo`0000?o0000ooooooooool0Mooo
ool7ool001[ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ool00?ooool0HOooool3
ool00003o`000?oooooooooo02oooooo1Ooo0023ooooo`;o00001?oo00000ol0003oooooooooo`0C
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`00
001To`0000;oo`00:ol00005ool009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00?o00002Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo00000_l0000>ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooool00003ool000Co00001Oooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooooooo`Oo00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo
00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Koooool4o`0000oooooo
0ooo0002o`000;?ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0Looo
ool2o`0000goo`0000?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3
o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMoooo
o`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go
00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMgob4Q8Ooo
ooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003ooooo00_o
oooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgM
oc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_oo
ool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oM
gMgoooooo`0000Cooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo001kooooo`04
oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06
ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omgMgOo
<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000go
oooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Go
oooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo
01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o
0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?oo
ool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEE
E@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`06ooooo`03o`00
0?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00ooo
ool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@
omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV006ooooo`03
o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool0
1?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOo
oooo01Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22868 L
.08255 .19214 L
.10458 .15892 L
.11448 .14672 L
.12507 .13572 L
.13499 .1274 L
.14415 .12149 L
.14911 .119 L
.15437 .11691 L
.15964 .11539 L
.16265 .11477 L
.16399 .11456 L
.16546 .11436 L
.1668 .11423 L
.16805 .11413 L
.16925 .11407 L
.17052 .11403 L
.17178 .11403 L
.17296 .11406 L
.17401 .1141 L
.17516 .11418 L
.17642 .11429 L
.1778 .11446 L
.1806 .1149 L
.18318 .11544 L
.1856 .11607 L
.1906 .11772 L
.19605 .12005 L
.20595 .12566 L
.22451 .14059 L
.24428 .16194 L
.26529 .18929 L
.30304 .24489 L
.34324 .30393 L
.38193 .35286 L
.40158 .37344 L
.42307 .39239 L
.44383 .40718 L
.46269 .41776 L
.4823 .42605 L
.49308 .42953 L
.50325 .43214 L
.51298 .43407 L
.51829 .43491 L
.52327 .43555 L
.52786 .43604 L
.53205 .43638 L
.53671 .43667 L
.53928 .43679 L
Mistroke
.54172 .43687 L
.54297 .4369 L
.54363 .43691 L
.54432 .43692 L
.54559 .43694 L
.54676 .43695 L
.54789 .43695 L
.54894 .43695 L
.5501 .43694 L
.55133 .43693 L
.55265 .43691 L
.55408 .43688 L
.55669 .4368 L
.55922 .43669 L
.56157 .43657 L
.57049 .43593 L
.575 .4355 L
.57997 .43495 L
.59935 .43205 L
.62022 .42782 L
.66141 .41698 L
.70109 .40451 L
.73925 .39151 L
.77986 .37721 L
.81896 .36334 L
.86051 .34872 L
.90054 .33484 L
.93906 .32164 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .2282 L
.08255 .19146 L
.10458 .15819 L
.11448 .14607 L
.12507 .13522 L
.13499 .12711 L
.14415 .12143 L
.14911 .11909 L
.15437 .11716 L
.15709 .11639 L
.15964 .1158 L
.16245 .11531 L
.16402 .1151 L
.16546 .11496 L
.1667 .11487 L
.16802 .1148 L
.16926 .11478 L
.17039 .11478 L
.17109 .11479 L
.17173 .11481 L
.17243 .11485 L
.17317 .11489 L
.17441 .11499 L
.17578 .11513 L
.17823 .11548 L
.18086 .11598 L
.1856 .11722 L
.19088 .11909 L
.19577 .12126 L
.20684 .12769 L
.22696 .14425 L
.24562 .16432 L
.26622 .19047 L
.30643 .24823 L
.34512 .30452 L
.38626 .35718 L
.40678 .37897 L
.42588 .39611 L
.44548 .41045 L
.46399 .42098 L
.4738 .42542 L
.48444 .42938 L
.49405 .43223 L
.50303 .4343 L
.5125 .4359 L
.51752 .43652 L
.52291 .43702 L
.52561 .4372 L
.52855 .43736 L
Mistroke
.5299 .43742 L
.53133 .43746 L
.53268 .4375 L
.5339 .43752 L
.5352 .43754 L
.53639 .43755 L
.5377 .43755 L
.53836 .43755 L
.53908 .43754 L
.5403 .43753 L
.5416 .4375 L
.54283 .43747 L
.54395 .43744 L
.54625 .43735 L
.54877 .43723 L
.55389 .4369 L
.55863 .43649 L
.56307 .43603 L
.58385 .43298 L
.60407 .42887 L
.62259 .42442 L
.66227 .41361 L
.70043 .40257 L
.74104 .39062 L
.78014 .37884 L
.82169 .36563 L
.86172 .35195 L
.90024 .33794 L
.94121 .32244 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0:oooool2o`000?oooooo6?ooool0027ooooo00?o0000ooooooooool09_ooool5o`00
0004ooooool0003o0000o`0000?oo`00oooooolCooooo`008Oooool3o`0002Cooooo0_oo000;oooo
o`04o`000?oo003o0000o`000?oooooo4?ooool0027ooooo00?o0000ooooooooool08_ooool2ool0
00oooooo0_oo00000ol0003oooooooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo027o
oooo00?oo`00ooooooooool04Oooool2ool00003o`000?oooooooooo0?oooooo2oooool0027ooooo
00?o0000ooooooooool07oooool2ool001Kooooo0_oo003oooooo`cooooo000Qooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`3oooooo`Wooooo000Q
ooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`3o
ooooo`Sooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00o`000?ooool07?ooool00ooo
003oooooooooo`3oooooo`Oooooo000Qooooo`?o00006oooool00ooo003o0000ooooo`0Nooooo`03
ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool06_ooool00ooo003o0000
ooooo`0Pooooo`03ool00?oooooooooo0?oooooo1Oooool0027ooooo00?o0000ooooooooool06_oo
ool00ooo003oooooooooo`0Qooooo`03o`000?oooooooooo0?oooooo1?ooool0027ooooo00?o0000
ooooooooool06Oooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo0oooool0
027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
0?oooooo0_ooool0027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0?oooooo0Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`008Oooool3o`0001Gooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0oOooool0027ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0]ooooo`03ool00?l0003ooooo0?gooooo000Qooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0;oooool00ooo003o0000ooooo`3looooo`008Ooo
ool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo037ooooo00?oo`00ooooooooool0nooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0booooo`03ool0
0?oooooooooo0?[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Aooooo`03ool00?l0003ooooo03Cooooo
00?oo`00ooooooooool0nOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`00017ooooo00?oo`00ooooooooool0=Oooool00ooo003ooooo
ooooo`3hooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool0
n?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Oooooo00?oo`00oooooooo
ool0moooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo0?Ko
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00kooooo00?o0000ool00?ooool0>_ooool00ooo003oooooooooo`3fooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3eooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo03gooooo00?oo`00ooooooooool0m?ooool0027ooooo00?o
0000ooooooooool03?ooool00ol0003oo`00ooooo`0oooooo`03o`000?oooooooooo0??ooooo000Q
ooooo`?o00003?ooool00ooo003oooooooooo`0oooooo`03o`000?oooooooooo0??ooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ool00?ooool0@Oooool00ol0003oooooooooo`3boooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo04;ooooo00?o0000oooooooo
ool0lOooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0koooool0027ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo0>kooooo000Qooooo`?o00002?ooool00ol0003o
ooooooooo`18ooooo`03ool00?oooooooooo0>kooooo000Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0B_ooool00ooo003oooooooooo`3]ooooo`008Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0k?ooool0027ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1<ooooo`03o`000?oo003ooooo0>cooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`3[oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo04oooooo00?oo`00oooooooo
ool0j_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oo`00ooooo`1?ooooo`03o`00
0?oo003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0DOoo
ool00ooo003oooooooooo`3Yooooo`008Oooool3o`0000Cooooo00?o0000ool00?ooool0DOooool0
0ol0003oo`00ooooo`3Yooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo
03Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Kooooo00?oo`00ooooooooool0=?ooool4o`000003oa0@4?oooooooooo03_ooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo
1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`03ool0
0?oooooooooo03Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003ooooo03Gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^
k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0hooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`07ooooo`03ool00?oooooooooo03Co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03ko
oooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003ooooo
ooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Wooooo00?oo`00ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qoooo
o`06o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo
000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooooiRHV?l@
41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000cooooo00?o0000ooooooooool0;oooool00omEEEGoIVIVo`00000ooooo
o`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0
027ooooo00Co0000ooooooooooooo`00GOooool00ol0003oooooooooo`3Sooooo`008Oooool01?l0
003oooooo`000?oo001Nooooo`03o`000?oooooooooo0>;ooooo000Qooooo`03o`000?ooooooo`00
05oooooo00?o0000ooooooooool0h_ooool0027ooooo0_l0001Qooooo`03o`000?oooooooooo0=Oo
oooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Rooooo`03o`000?oooooooooo0=Kooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooom]o`000003ool00?l0003o00000<3o
00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool01?l0003oo`00ooooool0000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`05o`000?oo003oo`00ooooool000004oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo003o
000000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Gooooo00Co0000ool00?oo003oo`000oooool00ol0003oooooooooo`0Aooooo`04ob4Q8Omg
MgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo06Cooooo00?o0000ool00?ooool0]_oo
ool2o`0000;oo`006Oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oo003ooooo0;;ooooo0ol000000oooooooo`00ooooo`0Tooooo`008Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oo003ooooo0:oooooo0ol0000Zooooo`008Oooool00ol0003o
ooooooooo`1Vooooo`03o`000?oo003ooooo0:_ooooo0ol0000]ooooo`008Oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oo003ooooo0:Oooooo0ol0000`ooooo`008Oooool3o`0006Sooooo00?o
0000ool00?ooool0Xoooool3o`000004oooooooo003oo`00ool002oooooo000Qooooo`03o`000?oo
oooooooo06Wooooo00?oo`00ooooooooool0Woooool3o`0000Coo`00<_ooool0027ooooo00?o0000
ooooooooool0JOooool00ol0003oo`00ooooo`2Mooooo`;o00000ooo000fooooo`008Oooool00ol0
003oooooooooo`1Zooooo`03o`000?oo003ooooo09[ooooo0_l00002ool003Wooooo000Qooooo`03
o`000?oooooooooo06_ooooo00?o0000ool00?ooool0U_ooool2o`0000?oo`00>oooool0027ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`2Booooo`?o000000?oooooool00?ooool0
?Oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`2>ooooo`?o0000@ooo
ool0027ooooo0ol0001^ooooo`03o`000?oooooooooo08[ooooo0ol00016ooooo`008Oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo08Kooooo0ol00019ooooo`008Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo08;ooooo0ol000001?ooooooo`00ool00?oo0018oooo
o`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo07kooooo0ol00004ool004_o
oooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0N_ooool2o`0000Coo`00
Coooool0027ooooo00?o0000ooooooooool0Loooool2o`0007Sooooo00Co0000ool00?oo003oo`00
Doooool0027ooooo00?o0000ooooooooool0Loooool2ool00003o`000?oooooooooo07;ooooo0_l0
0002ool005Kooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00o`000?ooool0L?ooool2
o`0005[ooooo000Qooooo`?o0000M_ooool00ooo003o0000ooooo`1/ooooo`?o0000G?ooool0027o
oooo00?o0000ooooooooool0Moooool00ooo003o0000ooooo`1Xooooo`?o0000Goooool0027ooooo
00?o0000ooooooooool0N?ooool00ooo003o0000ooooo`1Tooooo`?oo`00H_ooool0027ooooo00?o
0000ooooooooool0NOooool00ooo003o0000o`00001Oooooo`Coo`00IOooool0027ooooo00?o0000
ooooooooool0N_ooool00ooo003oooooo`00001Jooooo`Coo`0000?o0000ooooooooool0I_ooool0
027ooooo00?o0000ooooooooool0Noooool2ool000;o0000EOooool3ool000;o0000Joooool0027o
oooo00?o0000ooooooooool0OOooool00ooo003oooooo`00001Booooo`;oo`000_l0001^ooooo`00
8Oooool3o`0007kooooo00?oo`00ooooool00000C_ooool4o`00077ooooo000Qooooo`03o`000?oo
oooooooo07oooooo00Coo`00ooooool0003o0000BOooool3o`0007Gooooo000Qooooo`03o`000?oo
oooooooo08?ooooo0_l00012ooooo`;oo`000ol0001hooooo`008Oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo03_ooooo1?oo0002o`0007_ooooo000Qooooo`03o`000?oooooooooo
08Kooooo0_l0000gooooo`Coo`000ol0001nooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`28
ooooo`?o0000<?ooool4ool000?o0000P_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Wooooo00Coo`00
ooooool0003o0000;?ooool2ool000?o0000Q_ooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002:ooooo`?oo`000ol0000Vooooo`Co0000R_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0SOooool3ool000?o00008?ooool3o`0008kooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
T?ooool6ool000;o00004Oooool6ool000Co0000TOooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0U_ooool3ool000Ko0000
2_oo0005o`0009Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVoooo
o`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07
ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`00
0?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`1koooo
o`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ogMgMooooo`06ooooo`09o`000?oo
oooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj
^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Go
oooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo07_ooooo001nooooo`07o`000?oooooogMgMoc8b<_oo
ooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMg
M`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgooooo
o`0000Gooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00gooooo00?o
ZJVYoeEEEOooool0Noooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b
<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03
o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00co
oooo00?o8B4Qooooooooool0N_ooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003ooooo
ooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`00
0?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03
onk^k_l0003ooooo01;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o
0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03
o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01;ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03ojVYZOmgMgOooooo07[ooooo002Fooooo`03o`000?oooooooooo00Oo
oooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@
400Booooo`03onk^k_l@413ogMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S80Noooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4
ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOo
oooo01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000Noooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25375 L
.10458 .2005 L
.12507 .17924 L
.14415 .16309 L
.16254 .15139 L
.17284 .14665 L
.18221 .14355 L
.18704 .1424 L
.18969 .14191 L
.19216 .14154 L
.19427 .14129 L
.19654 .14108 L
.19783 .141 L
.19905 .14094 L
.20015 .14091 L
.20135 .14089 L
.20203 .14089 L
.20276 .1409 L
.20345 .14091 L
.20409 .14093 L
.2053 .14098 L
.20657 .14105 L
.20794 .14115 L
.20922 .14128 L
.21213 .14164 L
.21466 .14205 L
.21696 .1425 L
.22214 .1438 L
.22694 .14533 L
.23205 .14732 L
.24122 .15181 L
.26198 .16619 L
.28145 .18471 L
.29973 .20604 L
.33842 .26095 L
.37956 .32697 L
.41919 .3895 L
.45729 .44234 L
.47854 .46728 L
.49785 .48677 L
.51817 .50389 L
.5369 .5166 L
.55608 .52665 L
.56619 .53076 L
.57688 .53425 L
.58632 .53663 L
.59152 .53766 L
.59646 .53846 L
.60103 .53905 L
Mistroke
.60345 .53931 L
.60603 .53953 L
.60841 .5397 L
.61056 .53982 L
.6116 .53987 L
.61273 .53991 L
.61378 .53995 L
.61477 .53997 L
.61602 .53999 L
.61715 .54 L
.61837 .54 L
.61906 .54 L
.6197 .54 L
.62076 .53998 L
.62193 .53996 L
.62315 .53992 L
.6243 .53988 L
.62693 .53975 L
.62933 .5396 L
.63475 .53913 L
.63966 .53854 L
.64502 .53775 L
.65582 .53565 L
.67547 .53024 L
.69644 .52239 L
.73799 .50146 L
.77802 .47584 L
.81654 .44741 L
.85751 .41421 L
.89697 .38024 L
.93491 .34643 L
.9753 .30983 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25452 L
.10458 .20111 L
.12507 .17917 L
.14415 .16236 L
.16254 .15021 L
.17284 .14535 L
.1773 .1437 L
.18221 .14222 L
.18704 .1411 L
.18969 .14063 L
.19216 .14028 L
.19335 .14015 L
.19448 .14004 L
.1955 .13996 L
.19659 .13989 L
.19777 .13984 L
.19887 .1398 L
.20017 .13979 L
.20135 .1398 L
.20266 .13983 L
.20331 .13986 L
.20403 .13989 L
.20531 .13997 L
.2065 .14007 L
.20918 .14037 L
.21206 .14081 L
.21733 .14194 L
.22214 .14332 L
.23205 .14724 L
.24122 .1521 L
.26198 .16731 L
.28065 .18551 L
.30125 .20983 L
.34145 .26663 L
.38014 .32713 L
.42128 .39051 L
.4609 .44482 L
.49901 .48706 L
.52026 .50556 L
.53957 .51906 L
.54921 .52461 L
.55966 .52974 L
.56945 .53372 L
.57862 .53674 L
.58808 .53914 L
.5931 .54014 L
.59849 .54098 L
.60119 .54133 L
.60414 .54164 L
Mistroke
.60673 .54186 L
.60815 .54196 L
.60949 .54204 L
.61081 .54211 L
.61223 .54217 L
.61352 .54221 L
.6147 .54223 L
.61583 .54225 L
.61706 .54226 L
.61834 .54226 L
.61954 .54224 L
.6208 .54222 L
.62144 .5422 L
.62215 .54218 L
.62456 .54208 L
.62592 .542 L
.62738 .54191 L
.63002 .5417 L
.63519 .54117 L
.63993 .54053 L
.64898 .53891 L
.6585 .53669 L
.67828 .53046 L
.69666 .52291 L
.73576 .50216 L
.77731 .47473 L
.81734 .44464 L
.85586 .41344 L
.89683 .37867 L
.93629 .34424 L
.97422 .31075 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00033ooooo2?l00003ool00?oooooo2_oo
ool0027ooooo00?o0000ooooooooool0:oooool4ool00003o`000?oooooooooo00Wooooo0ooo003o
ooooo`Oooooo000Qooooo`03o`000?oooooooooo02[ooooo00Coo`00o`000?l0003o00004?ooool3
ool00?oooooo1?ooool0027ooooo00?o0000ooooooooool0:?ooool2ool00003o`000?oooooooooo
01Cooooo0_oo003oooooo`;ooooo000Qooooo`03o`000?oooooooooo02Oooooo00?oo`00oooooooo
ool06Oooool00ooo003oooooooooo`3nooooo`008Oooool00ol0003oooooooooo`0Uooooo`;oo`00
7Oooool00ooo003o0000ooooo`3mooooo`008Oooool00ol0003oooooooooo`0Tooooo`03ool00?oo
oooooooo01kooooo00?oo`00o`000?ooool0o?ooool0027ooooo00?o0000ooooooooool08_ooool2
ool002;ooooo00?oo`00o`000?ooool0noooool0027ooooo0ol0000Qooooo`03ool00?oooooooooo
02Cooooo00?o0000ooooooooool0nOooool0027ooooo00?o0000ooooooooool08?ooool00ooo003o
ooooooooo`0Vooooo`03o`000?oooooooooo0?Sooooo000Qooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3gooooo`008Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0m_ooool0027ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?Gooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`3dooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0`ooooo`03ool00?oo
oooooooo0??ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Jooooo`03o`000?oooooooooo037ooooo00?oo`00o`000?ooool0looo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`03ool00?l0003ooooo0?;ooooo0007
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool06?ooool00ol0003oo`00ooooo`0eooooo`03ool00?l0003ooooo0?7ooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ool00?ooool0=oooool00ooo003o0000ooooo`3`ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo03Sooooo00?oo`00o`000?ooool0koooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oo003ooooo03[ooooo00?oo`00o`000?ooool0k_ooool0027ooooo00?o0000ooooooooool05Ooo
ool00ol0003oo`00ooooo`0looooo`03ool00?oooooooooo0>gooooo000Qooooo`03o`000?oooooo
oooo01Cooooo00?o0000ool00?ooool0?Oooool00ooo003o0000ooooo`3]ooooo`008Oooool3o`00
01?ooooo00?o0000ool00?ooool0?oooool00ooo003o0000ooooo`3/ooooo`008Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oo003ooooo047ooooo00?oo`00ooooooooool0joooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oo`00ooooo`11ooooo`03ool00?l0003ooooo0>_ooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ool00?ooool0@oooool00ooo003o0000oooo
o`3Zooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo04Gooooo00?oo`00
o`000?ooool0jOooool0027ooooo00?o0000ooooooooool03oooool00ol0003oo`00ooooo`17oooo
o`03o`000?oooooooooo0>Sooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ool00?oo
ool0BOooool00ol0003oooooooooo`3Wooooo`008Oooool3o`0000kooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`3Vooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`3Tooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0hoooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0>?ooooo
000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D_ooool00ooo003o0000oooo
o`3Sooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo05Cooooo00?oo`00
o`000?ooool0h_ooool0027ooooo0ol00007ooooo`03o`000?oo003ooooo05Kooooo00?oo`00oooo
ooooool0hOooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0cooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0>
ooooo`03ool00?oooooooooo02cooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0dooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03Oooool00ooo003ooooooooo
o`0^ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ool00?ooool0=Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0=_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool03oooool00ooo003oooooooooo`0/ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0=_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00@ooooo`03
ool00?oooooooooo02cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool00omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`008Oooool3o`0000;ooooo00?o0000ool00?ooool0>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@41006oooool0027ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0001?ooooo00?oo`00ooooooooool0:?ooool0
0omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`06oooool0027ooooo00Go0000ooooooooooooooooool0001Sooooo`03o`000?oo
003ooooo0=cooooo000Qooooo`05o`000?ooooooooooo`000?oo0000I?ooool00ooo003ooooooooo
o`3Kooooo`008Oooool01?l0003oooooo`000?oo001Vooooo`03ool00?oooooooooo0=[ooooo000Q
ooooo`03o`000?ooooooo`0006Oooooo00?o0000ooooooooool0d?ooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`0006Wooooo00?o0000ooooooooool0coooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`000005o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo0_oo00000ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04ool0
0?ooooooooooo`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo01Cooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0/ooo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`1/ooooo`;oo`00/_ooool0
0ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1/ooooo`03o`000?oo003ooooo
0;3ooooo00?o0000ooooooooool08_ooool0027ooooo0ol0001]ooooo`03o`000?oo003ooooo0:ko
oooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oo`00
ooooo`2/ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo06kooooo00?o
0000ool00?ooool0Zoooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`1_
ooooo`03o`000?oo003ooooo0:Oooooo0ooo000Xooooo`008Oooool00ol0003oooooooooo`1`oooo
o`03ool00?oooooooooo0:Gooooo00?oo`00o`000?l00000:Oooool0027ooooo00?o0000oooooooo
ool0L?ooool00ol0003oo`00ooooo`2Tooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?o0000ool00?ooool0X_ooool00ooo003o0000ooooo`0[ooooo`008Ooo
ool3o`0007;ooooo00?oo`00ooooooooool0X?ooool00ooo003o0000ooooo`0/ooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03ool00?oooooooooo09kooooo00?oo`00o`000?ooool0;Oooool0
027ooooo00?o0000ooooooooool0Loooool00ooo003oooooooooo`2Mooooo`03ool00?l0003ooooo
02kooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0Voooool00ooo003o
0000ooooo`0_ooooo`008Oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo09Wooooo
00?oo`00o`000?ooool0<?ooool0027ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`2Hooooo`03ool00?l0003ooooo037ooooo000Qooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool0U_ooool00ooo003o0000ooooo`0booooo`008Oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0<_ooool0027ooooo0ol0001gooooo`03
o`000?oooooooooo09?ooooo0_l0000eooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`28ooooo`;oo`0000?o0000oooooooo
ool0>Oooool0027ooooo00?o0000ooooooooool0Noooool00ooo003oooooooooo`27ooooo`03ool0
0?l0003ooooo03cooooo000Qooooo`?o0000O?ooool00ooo003oooooooooo`25ooooo`03ool00?l0
003ooooo03gooooo000Qooooo`03o`000?oooooooooo07gooooo00?oo`00ooooooooool0Poooool0
0ooo003o0000ooooo`0nooooo`008Oooool00ol0003oooooooooo`1mooooo`03ool00?l0003ooooo
08;ooooo00?oo`00o`000?ooool0?oooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003o
ooooooooo`1oooooo`;oo`0000?o0000ooooooooool0?oooool0027ooooo00?o0000ooooooooool0
Ooooool00ooo003oooooooooo`1mooooo`03ool00?l0003ooooo04;ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo083ooooo00?oo`00ooooooooool0Noooool00ooo003o0000ooooo`13ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`1jooooo`03ool00?l0003ooooo04Co
oooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o
0000POooool00ooo003oooooooooo`1hooooo`03ool00?l0003ooooo04Gooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08;o
oooo00?oo`00ooooooooool0M_ooool00ooo003o0000ooooo`16ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
08;ooooo00?oo`00o`000?ooool0MOooool00ol0003oooooooooo`17ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`23oooo
o`03ool00?oooooooooo07?ooooo00?o0000ooooooooool0B?ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q?ooool00ooo
003oooooooooo`1aooooo`03o`000?oooooooooo04Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo06_ooooo0_l0001>ooooo`008Oooool3o`0008Oooooo00?o0000ooooooooool0J?oo
ool2ool0053ooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0I_ooool0
0ooo003o0000ooooo`1@ooooo`008Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
06Cooooo0_oo001Cooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo06;o
oooo00?oo`00o`000?ooool0Doooool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oo`00
ooooo`1Pooooo`03ool00?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo08_ooooo00?o
0000ool00?ooool0GOooool2ool005Oooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000
ool00?ooool0Foooool00ooo003oooooooooo`1Gooooo`008Oooool3o`0008gooooo00?o0000ool0
0?ooool0F?ooool2ool005[ooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ool00?oo
ool0E_ooool00ooo003oooooooooo`1Jooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`00
0?oo003ooooo05?ooooo00?o0000ool00?ooool0G?ooool0027ooooo00?o0000ooooooooool0T?oo
ool00ol0003oo`00ooooo`1@ooooo`;o0000Goooool0027ooooo00?o0000ooooooooool0TOooool0
0ol0003oo`00ooooo`1>ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo
09?ooooo00?oo`00ooooooooool0B_ooool2o`0006;ooooo000Qooooo`03o`000?oooooooooo09Co
oooo00?oo`00o`000?ooool0Aoooool2o`0006Cooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00o`000?ooool0AOooool00ol0003oooooooooo`1Tooooo`008Oooool3o`0009Kooooo00?o
o`00o`000?ooool0@_ooool2o`000003ool00?oooooooooo06Cooooo000Qooooo`03o`000?oooooo
oooo09Sooooo0_l0000oooooo`;o00000_oo001Wooooo`008Oooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo03[ooooo0_l00002ool006Wooooo000Qooooo`03o`000?oooooooooo09_o
oooo0_l0000hooooo`;o00000_oo001[ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo03Cooooo0ooo001]ooooo`008Oooool00ol0003oooooooooo`2Nooooo`;o0000<_oo
ool2ool0073ooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00o`000?l00000;_ooool2
ool007;ooooo000Qooooo`?o0000X?ooool01?oo003oooooo`000?l0000Zooooo`03o`000?oo003o
oooo07?ooooo000Qooooo`03o`000?oooooooooo0:7ooooo0ooo0002o`0002Gooooo0ol0001foooo
o`008Oooool00ol0003oooooooooo`2Tooooo`?oo`008Oooool3o`0007Wooooo000Qooooo`03o`00
0?oooooooooo0:Oooooo00?oo`00o`000?l000006oooool3o`0007cooooo000Qooooo`03o`000?oo
oooooooo0:Sooooo1_oo00000ol0003oooooooooo`0@ooooo`;o00000ooo001nooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0[_ooool00ooo003o0000o`00000?
o`0000?oo`00POooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2eoooo
o`_oo`00Q?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omV
IVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo
410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0
003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQCooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000
ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RH
oooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool0
4_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003o
ooooooooo`1cooooo`00Noooool01?mEEEGoZJVYooooool00002ooooo`04o`000?ooooooooooo`00
00gooooo00?o0000ooooooooool01_ooool00oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo
00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00004ooooo`03o`000?oooooo
oooo00[ooooo1_l00002ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000
ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o
0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo
00?ok^k^o`000?ooool04oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;o
oooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?oo
ool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000ooooooo
MgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03oooo
o`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?oo
ool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^
k^ko410@omgMg@0Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool0
0onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017o
oooo00?oIVIVogMgMoooool05?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004oooo
o`Co0000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29218 L
.10458 .27223 L
.14415 .25272 L
.18221 .23569 L
.20178 .22874 L
.21267 .22568 L
.22272 .22347 L
.22768 .22261 L
.23293 .22189 L
.23548 .22161 L
.23821 .22136 L
.23978 .22125 L
.24121 .22116 L
.24257 .22108 L
.24402 .22102 L
.24471 .221 L
.24536 .22098 L
.24658 .22096 L
.24772 .22094 L
.24896 .22094 L
.24961 .22094 L
.25032 .22095 L
.25107 .22096 L
.25177 .22098 L
.25301 .22101 L
.25435 .22107 L
.25698 .22122 L
.25948 .22141 L
.26416 .22192 L
.26875 .22261 L
.27382 .22358 L
.28407 .22625 L
.29357 .22958 L
.30249 .23349 L
.32267 .2451 L
.34118 .25911 L
.3808 .29907 L
.41891 .34753 L
.45947 .40439 L
.49852 .45793 L
.54002 .50729 L
.56082 .52759 L
.58 .54323 L
.59868 .55545 L
.60822 .56051 L
.61846 .56506 L
.62869 .56869 L
.63804 .57121 L
.64253 .57215 L
Mistroke
.64743 .57298 L
.65206 .57358 L
.65415 .57379 L
.65635 .57397 L
.65762 .57406 L
.65901 .57414 L
.66028 .5742 L
.66144 .57424 L
.6621 .57426 L
.66282 .57427 L
.66358 .57429 L
.66429 .57429 L
.66496 .5743 L
.66567 .5743 L
.66695 .57429 L
.66812 .57426 L
.66939 .57423 L
.67059 .57418 L
.67169 .57413 L
.67424 .57397 L
.67691 .57375 L
.68153 .57323 L
.68581 .5726 L
.69553 .57064 L
.70608 .5677 L
.71603 .56419 L
.73463 .55579 L
.77315 .53141 L
.81412 .49671 L
.85358 .4566 L
.89151 .41354 L
.93191 .36455 L
.97078 .31584 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29243 L
.10458 .27268 L
.14415 .25276 L
.18221 .23522 L
.20178 .22811 L
.21274 .225 L
.21758 .22385 L
.22272 .22281 L
.22745 .222 L
.23267 .2213 L
.23496 .22105 L
.23742 .22083 L
.23974 .22067 L
.24186 .22055 L
.24314 .2205 L
.24384 .22048 L
.24451 .22046 L
.24579 .22044 L
.24696 .22043 L
.24763 .22043 L
.24835 .22043 L
.24963 .22045 L
.25034 .22047 L
.25101 .22048 L
.25252 .22054 L
.25383 .2206 L
.25508 .22068 L
.25741 .22085 L
.25992 .22109 L
.26265 .22141 L
.26749 .22215 L
.27205 .22304 L
.28242 .22576 L
.29253 .22939 L
.30343 .23437 L
.32347 .24644 L
.34457 .26309 L
.38268 .30223 L
.42324 .35344 L
.46228 .40714 L
.50378 .46295 L
.54376 .51004 L
.58223 .5451 L
.6021 .55839 L
.61225 .56382 L
.62315 .56859 L
.63338 .57206 L
.64272 .5744 L
.64722 .57523 L
Mistroke
.64959 .57559 L
.65212 .57593 L
.65455 .57619 L
.65674 .57638 L
.65896 .57653 L
.66004 .57659 L
.66104 .57663 L
.6622 .57667 L
.66345 .5767 L
.66461 .57672 L
.66571 .57672 L
.66698 .57671 L
.66816 .57668 L
.66945 .57664 L
.67082 .57659 L
.67336 .57644 L
.67574 .57624 L
.68115 .57562 L
.6858 .57489 L
.69005 .57406 L
.69964 .57163 L
.70947 .56838 L
.7186 .56469 L
.73931 .55407 L
.77841 .52656 L
.81996 .48883 L
.86 .44661 L
.89851 .4025 L
.93949 .35357 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo03gooooo0_l0000<ool00?Wooooo000Qooooo`03o`000?oooooo
oooo03Oooooo1_l0000>ooooo`Coo`00mOooool0027ooooo00?o0000ooooooooool0<oooool2ool0
00;o00005oooool4o`000?;ooooo000Qooooo`03o`000?oooooooooo033ooooo0ooo00000ol0003o
ooooooooo`0Looooo`;o0000l?ooool0027ooooo00?o0000ooooooooool0;_ooool2ool00003o`00
0?oooooooooo027ooooo0_l0003^ooooo`008Oooool3o`0002cooooo0_oo000Xooooo`?o0000jooo
ool0027ooooo00?o0000ooooooooool0:_ooool2ool002cooooo0_oo00000ol0003oooooooooo`3W
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo003ooooo02oooooo00?oo`00o`00
0?ooool0ioooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oo`00ool0000booooo`;o
o`00ioooool0027ooooo00?o0000ooooooooool09?ooool2o`000003ool00?oooooooooo03Cooooo
00?oo`00ooooooooool0i?ooool0027ooooo00?o0000ooooooooool08_ooool2o`0003[ooooo0_oo
003Tooooo`008Oooool00ol0003oooooooooo`0Pooooo`;o0000?Oooool00ol0003oo`00ooooo`3R
ooooo`008Oooool00ol0003oooooooooo`0Nooooo`;o0000@?ooool00ol0003oo`00ooooo`3Qoooo
o`008Oooool3o`0001_ooooo0_oo00000ol0003oooooooooo`12ooooo`03ool00?oooooooooo0=oo
oooo000Qooooo`03o`000?oooooooooo01Wooooo0_oo00000ol0003oooooooooo`0Oooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0?oooo
o`03ool00?l0003ooooo02_ooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0
027ooooo00?o0000ooooooooool06?ooool00ooo003o0000ooooo`0Rooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ooo003o0000ooooo`0/
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool0??ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooo
oooo01Kooooo0_oo000Uooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0?ooooo`03ool00?l0003ooooo02_ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000
ooooooooool04oooool00ol0003oo`00ool0000Wooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06ooo
ool0027ooooo00?o0000ooooooooool04Oooool3ool002Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool03oooool2ool002cooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000cooooo0_l000000ooo003ooooo
ooooo`0/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`;o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000Hoooo
o`03o`000?oooooooooo02?ooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=oooo
o`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo
00Sooooo0_l0001Qooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo00Go
oooo0ol0001Tooooo`03o`000?oooooooooo0=Gooooo000Qooooo`03o`000?oooooooooo00?ooooo
0_l0001Wooooo`03ool00?l0003ooooo0=Gooooo000Qooooo`05o`000?ooooooooooooooool00000
0ooo001Xooooo`03ool00?oooooooooo0<[ooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
0003ool006_ooooo00?oo`00o`000?ooool0b_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Co
oooo000Jooooo`Oo00000_oo001_o`000003ool00?l0003o00000;Ko000000?oo`00o`000?l00000
1Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ooo003o0000ooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo01;ooooo
00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`05ool00?l0003oooooooooool000003_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ool00?l000004oooool01?lQ8B7oMgMgogMgMolb<S85oooo
o`008Oooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo0;7ooooo00?oo`00oooooooo
ool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1booooo`03ool0
0?oooooooooo0:oooooo00?oo`00ooooooooool07Oooool0027ooooo00?o0000ooooooooool0L_oo
ool00ooo003o0000ooooo`2^ooooo`03ool00?oooooooooo01kooooo000Qooooo`03o`000?oooooo
oooo07?ooooo00?oo`00o`000?ooool0[?ooool00ol0003oo`00ooooo`0Oooooo`008Oooool00ol0
003oooooooooo`1dooooo`03ool00?l0003ooooo0:_ooooo00?oo`00ooooooooool07oooool0027o
oooo0ol0001eooooo`03ool00?oooooooooo0:Wooooo00?oo`00ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0M_ooool00ooo003oooooooooo`2Wooooo`03ool00?oooooooooo027ooooo
000Qooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0YOooool00ooo003ooooooooo
o`0Rooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool08_ooool0027ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Roooo
o`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool0XOooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo09oooooo00?o0000ooooooooool09Oooool0027ooooo0ol0001kooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0Voooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003o
ooooooooo`1looooo`03ool00?l0003ooooo09[ooooo00?o0000ooooooooool0:?ooool0027ooooo
00?o0000ooooooooool0OOooool00ooo003oooooooooo`2Hooooo`03ool00?l0003ooooo02Wooooo
000Qooooo`03o`000?oooooooooo07kooooo00?oo`00ooooooooool0Uoooool00ooo003ooooooooo
o`0Yooooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0003ooooo09Kooooo00?oo`00
ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`2Doooo
o`03ool00?oooooooooo02_ooooo000Qooooo`?o0000P?ooool00ooo003oooooooooo`2Booooo`03
ool00?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo087ooooo00?oo`00ooooooooool0
T?ooool00ooo003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`21ooooo`03ool00?oo
oooooooo08oooooo00?oo`00ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0P_ooool0
0ooo003oooooooooo`2=ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oooooooooo
08?ooooo00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0_ooooo`008Oooool00ol0003o
ooooooooo`23ooooo`03ool00?oooooooooo08_ooooo00?oo`00ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool0Q?ooool00ooo003oooooooooo`29ooooo`03ool00?oooooooooo037ooooo
000Qooooo`?o0000QOooool00ooo003oooooooooo`27ooooo`03ool00?oooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0Q_ooool00ooo003oooooooooo`0c
ooooo`008Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool0=?ooool0027ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
POooool00ol0003oooooooooo`0eooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0=_ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0gooooo`001oooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008[ooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`0hooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0>Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2<ooooo`03ool00?oooooooooo
07Oooooo00?oo`00o`000?ooool0>oooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S?ooool00ooo003oooooooooo`1foooo
o`03ool00?l0003ooooo03cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo08gooooo00?oo`00ooooooooool0M?ooool00ooo
003o0000ooooo`0mooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo08kooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`0noooo
o`008Oooool00ol0003oooooooooo`2?ooooo`03ool00?oooooooooo073ooooo00?oo`00o`000?oo
ool0?oooool0027ooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1`ooooo`03ool0
0?oooooooooo03oooooo000Qooooo`?o0000T?ooool00ooo003oooooooooo`1^ooooo`03ool00?oo
oooooooo043ooooo000Qooooo`03o`000?oooooooooo097ooooo00?oo`00ooooooooool0K?ooool0
0ooo003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo
06[ooooo00?oo`00o`000?ooool0@_ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003o
o`00ooooo`1Yooooo`03ool00?l0003ooooo04?ooooo000Qooooo`03o`000?oooooooooo09?ooooo
00?oo`00ooooooooool0Ioooool00ooo003o0000ooooo`14ooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03ool00?oooooooooo06Gooooo00?oo`00o`000?ooool0AOooool0027ooooo00?o0000
ooooooooool0UOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo04Gooooo000Qoooo
o`?o0000U_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo04Kooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`17ooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
B?ooool0027ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo04Wooooo000Qooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool0Voooool00ol0003o
ooooooooo`1Eooooo`;oo`0000?o0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool0
W?ooool00ol0003oo`00ooooo`1Cooooo`03ool00?l0003o000004oooooo000Qooooo`?o0000WOoo
ool00ooo003oooooooooo`1Aooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`000?oooooo
oooo09kooooo00?oo`00ooooooooool0Coooool00ooo003o0000ooooo`1Aooooo`008Oooool00ol0
003oooooooooo`2Oooooo`03ool00?oooooooooo04gooooo00?oo`00o`000?ooool0D_ooool0027o
oooo00?o0000ooooooooool0Woooool00ol0003oo`00ool0001<ooooo`03ool00?l0003ooooo05?o
oooo000Qooooo`03o`000?oooooooooo0:3ooooo00?o0000oooooooo0000B_ooool00ooo003o0000
ooooo`1Dooooo`008Oooool00ol0003oooooooooo`2Qooooo`03o`000?ooooooo`0004Sooooo00?o
o`00ooooooooool0EOooool0027ooooo00?o0000ooooooooool0X_ooool00ol0003oooooool00016
ooooo`03ool00?oooooooooo05Kooooo000Qooooo`?o0000Xoooool00ol0003oooooool00014oooo
o`03ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?o0000oooooooo
0000@_ooool00ooo003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`2Uooooo`;o0000
00?oo`00ooooooooool0?_ooool00ol0003oo`00ooooo`1Iooooo`008Oooool00ol0003ooooooooo
o`2Wooooo`03o`000?oo003ooooo03cooooo0_l0001Looooo`008Oooool00ol0003oooooooooo`2X
ooooo`;o0000>_ooool2o`0005kooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0G_ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`;o0000=?ooool2o`00067o
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000Hoooool001[ooooo00?o0000ooooooooool01?ooool3o`000:kooooo0_l0
000^ooooo`03o`000?oo003oo`0006?ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0/?ooool00ol0003oooooooooo`0Yooooo`;o000000?oo`00ooooooooool0Hoooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`;oo`0000?o0000oooo
ooooool09Oooool2o`0000;oo`00I_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2booooo`;oo`009?ooool01?l0003oo`00ool00?oo001Xooooo`006?ooool00omEEEGo
IVIVo`000006ooooo`03o`000?oooooooooo0;Cooooo00?oo`00o`000?l000008?ooool2ool006_o
oooo000Qooooo`03o`000?oooooooooo0;Gooooo0ooo0002o`0001[ooooo00?o0000ool00?oo0000
KOooool0027ooooo00?o0000ooooooooool0^?ooool4ool00003o`000?oooooooooo01;ooooo0_l0
0002ool006oooooo000Qooooo`?o0000_?ooool2ool00003o`000?oooooooooo00gooooo0ol00000
0oooooooo`00ooooo`1`ooooo`008Oooool00ol0003oooooooooo`2nooooo`03ool00?l0003oo`00
00go0000M_ooool0027ooooo00?o0000ooooooooool0`Oooool7ool007cooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Goooo
o`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03
omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGo
IVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co
^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?o
EEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07_o
oooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo
00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000
oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@
okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool01ol0003ooooo
omgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@
413ogMgMooooool00005ooooo`03o`000?oooooooooo017ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool00000Noooool007kooooo00CoEEEEojVYZOoooooo0000
0_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko
410@onk^kP06ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOo
IVIVooooool00005ooooo`03o`000?oooooooooo00[ooooo1_l000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P1kooooo`00O_ooool00ooM
gMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06oooo
o`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:oooo
o`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool04_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c01kooooo`00Ooooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@
413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_oo
ool00omgMgOoEEEEooooo`0Booooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413o
gMgM01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
Noooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomV
IVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Noooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .32801 L
.08255 .33618 L
.0932 .33977 L
.10458 .34298 L
.11531 .34536 L
.12507 .34699 L
.12977 .34758 L
.13488 .34809 L
.13722 .34828 L
.1397 .34845 L
.14183 .34856 L
.14415 .34867 L
.14546 .34871 L
.14667 .34874 L
.14783 .34877 L
.14907 .34879 L
.15028 .3488 L
.15142 .3488 L
.15245 .3488 L
.15356 .34879 L
.15479 .34877 L
.15548 .34876 L
.15613 .34875 L
.15884 .34867 L
.16118 .34857 L
.16369 .34844 L
.1686 .3481 L
.17326 .34767 L
.18199 .34664 L
.19164 .34516 L
.2019 .34324 L
.22032 .3391 L
.25807 .32923 L
.27904 .32397 L
.29827 .31992 L
.30803 .31829 L
.31712 .31709 L
.32208 .31657 L
.32659 .31619 L
.3316 .31588 L
.33436 .31576 L
.33561 .31571 L
.33696 .31567 L
.33821 .31564 L
.33935 .31563 L
.3405 .31561 L
.34159 .31561 L
.34285 .31561 L
.34402 .31561 L
Mistroke
.34531 .31563 L
.34603 .31564 L
.34668 .31566 L
.34923 .31573 L
.35066 .31579 L
.35198 .31585 L
.35697 .31617 L
.36125 .31655 L
.36595 .31708 L
.37542 .31854 L
.38566 .32068 L
.39497 .32317 L
.4159 .3306 L
.43502 .3396 L
.4558 .35161 L
.49663 .38084 L
.53595 .41317 L
.57375 .44423 L
.61401 .4729 L
.63252 .48348 L
.65275 .49269 L
.66246 .49615 L
.67283 .49914 L
.67857 .50046 L
.68377 .50146 L
.68871 .50223 L
.69142 .50258 L
.69394 .50286 L
.69643 .50308 L
.69871 .50325 L
.70124 .50339 L
.70263 .50345 L
.70395 .50349 L
.70506 .50352 L
.70624 .50354 L
.70725 .50354 L
.70836 .50354 L
.70955 .50353 L
.71084 .50351 L
.71205 .50348 L
.71316 .50344 L
.71567 .50332 L
.718 .50316 L
.7233 .50267 L
.72846 .502 L
.73397 .50107 L
.7442 .49879 L
.7553 .4955 L
.77544 .48746 L
.79529 .47706 L
Mistroke
.81633 .46361 L
.85418 .4339 L
.89449 .39616 L
.93328 .35585 L
.97453 .31085 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .32735 L
.08255 .33538 L
.0932 .33907 L
.10458 .34248 L
.11531 .34513 L
.12507 .34704 L
.12977 .34777 L
.13488 .34843 L
.1397 .34891 L
.14415 .34925 L
.14658 .34938 L
.14881 .34948 L
.15004 .34952 L
.15138 .34955 L
.15264 .34958 L
.15382 .34959 L
.155 .3496 L
.15612 .34959 L
.15712 .34959 L
.1582 .34957 L
.15939 .34955 L
.16064 .34952 L
.16288 .34944 L
.16533 .34933 L
.16796 .34917 L
.17271 .34879 L
.17836 .3482 L
.1835 .34752 L
.20259 .34403 L
.22335 .33886 L
.26413 .32697 L
.28438 .32155 L
.2943 .31928 L
.3034 .3175 L
.31207 .31611 L
.31666 .31552 L
.32156 .31499 L
.32415 .31476 L
.32651 .31458 L
.3289 .31443 L
.3311 .31431 L
.33358 .31421 L
.33489 .31418 L
.33555 .31416 L
.33627 .31415 L
.33747 .31413 L
.33859 .31412 L
.33928 .31412 L
.33993 .31412 L
Mistroke
.34115 .31413 L
.3424 .31414 L
.3431 .31416 L
.34375 .31417 L
.34491 .3142 L
.34619 .31425 L
.34841 .31435 L
.35076 .31449 L
.35605 .31492 L
.36099 .31548 L
.36988 .31686 L
.37939 .31887 L
.38959 .32166 L
.40067 .32541 L
.42081 .33406 L
.46164 .35801 L
.50096 .38679 L
.53876 .41657 L
.57902 .44698 L
.61776 .47188 L
.63744 .48207 L
.65895 .49091 L
.6689 .49412 L
.67951 .4969 L
.68467 .498 L
.68953 .49889 L
.69423 .4996 L
.69862 .50015 L
.70327 .50059 L
.70573 .50077 L
.70837 .50092 L
.7097 .50097 L
.71114 .50102 L
.7118 .50104 L
.7125 .50106 L
.71376 .50108 L
.71497 .50109 L
.7161 .50109 L
.71734 .50108 L
.71804 .50107 L
.71868 .50106 L
.71975 .50103 L
.7209 .501 L
.72297 .50091 L
.72543 .50077 L
.72767 .50061 L
.73254 .50015 L
.73714 .49957 L
.74685 .49788 L
.75713 .49541 L
Mistroke
.77558 .48923 L
.79513 .48025 L
.81343 .46966 L
.85222 .44069 L
.89347 .40168 L
.9332 .3586 L
.97141 .31462 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool01?l0003oooooo`000?l0000;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000Cooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`04o`000?ooooooooooooooo`;o
o`002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ool00?oo
00001?oo0002o`0000Koo`003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool00oooool2ool004oooooo1?oo0007o`0000Kooooo2Ol0002gooooo`03
o`000?oooooooooo01;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0
1Oooool2ool004Oooooo1_oo00000ol0003oooooooooo`0Gooooo`;o00000ooo002aooooo`03o`00
0?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo00Oooooo0_oo0013ooooo`04o`000?oo
003o0000o`00027ooooo0_l00002ool00:kooooo00?oo`00ooooooooool07_ooool0027ooooo00?o
0000ooooooooool02Oooool3ool003gooooo0ol0000Xooooo`03o`000?oo003oo`000:_ooooo00?o
0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool02oooool01?l0003oo`00ool00?oo
000fooooo`Co0000;_ooool2ool00003o`000?oooooooooo0:Gooooo00?o0000ool00?ooool08?oo
ool0027ooooo0ol0000>ooooo`03o`000?oo003ooooo033ooooo0ooo00000ol0003oooooooooo`0b
ooooo`;oo`0000?o0000ooooooooool0X_ooool00ol0003oo`00ooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0@ooooo`?o0000:_ooool01?l0003oo`00ool00?oo000jooooo`;oo`0000?o0000
ooooooooool0Woooool00ol0003oo`00ooooo`0Rooooo`008Oooool00ol0003oooooooooo`0Coooo
o`?o00008_ooool00ol0003oo`00ool00003ool003oooooo00?oo`00o`000?l00000W_ooool00ol0
003oo`00ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Fooooo`Co00006_ooool00ol0003o
o`00ool00002ool004Gooooo00?oo`00ooooool00000W?ooool00ol0003oo`00ooooo`0Tooooo`00
8Oooool00ol0003oooooooooo`0Jooooo`Koo`003?ooool8o`000003ool00?oooooooooo04[ooooo
0_l0002Iooooo`03o`000?oo003ooooo02Gooooo000Qooooo`03o`000?oooooooooo023ooooo2_oo
0002o`0005Oooooo00?o0000ooooooooool0UOooool00ol0003oo`00ooooo`0Vooooo`008Oooool0
0ol0003oooooooooo`24ooooo`;o0000U?ooool00ol0003oo`00ooooo`0Wooooo`008Oooool3o`00
08Kooooo00?o0000ooooooooool0T?ooool00ol0003oo`00ooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`27ooooo`;o0000T?ooool00ooo003oooooooooo`0Xooooo`008Oooool00ol0003ooooo
ooooo`28ooooo`;oo`00S_ooool00ol0003oo`00ooooo`0Yooooo`008Oooool00ol0003ooooooooo
o`2:ooooo`03ool00?l0003ooooo08[ooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000
ooooooooool0Roooool00ooo003o0000ooooo`28ooooo`03o`000?oooooooooo02_ooooo000Qoooo
o`03o`000?oooooooooo08cooooo00?oo`00o`000?ooool0Q_ooool00ol0003oooooooooo`0/oooo
o`008Oooool00ol0003oooooooooo`2=ooooo`;oo`0000?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`2?ooooo`03ool00?l0003ooooo087ooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0002@ooooo`03ool00?l0003o000007oooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0TOooool00ooo003oooooo`00001m
ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo09;ooooo0_oo00000ol0
003oooooooooo`1iooooo`03o`000?oo003ooooo037ooooo000Qooooo`03o`000?oooooooooo09Co
oooo00?oo`00o`000?ooool0N?ooool00ol0003oo`00ooooo`0booooo`008Oooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oooooooooo07Gooooo00?o0000ool00?ooool0<oooool0027ooooo00?o
0000ooooooooool0Uoooool2o`0007?ooooo0_l000000ooo003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`2Iooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo0000=_ooool0
027ooooo0ol0002Jooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo0000=oooool0027o
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1[ooooo`03o`000?ooooooo`0003So
oooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ool0000iooooo`008Oooool00ol0003oooooooooo`2Mooooo`03ool00?l0003ooooo06Oooooo00?o
0000oooooooo0000>_ooool0027ooooo00?o0000ooooooooool0W_ooool2ool006Kooooo00?o0000
oooooooo0000>oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0X?ooool00ooo003ooooooooo
o`1Rooooo`03o`000?ooooooo`0003cooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Qooooo`03ool00?oo
oooooooo063ooooo00?o0000oooooooo0000?Oooool000Oooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00;ooooo0ol0002Rooooo`;oo`00Goooool00ol0003ooooooooo
o`0nooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`2Sooooo`03o`000?oo003ooooo05cooooo00?o0000ooooooooool0?ooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`2Uooooo`;oo`00FOooool2o`0004;ooooo0007ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Kooooo
00?o0000ool00?ooool0E_ooool00ol0003oooooooooo`12ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`03o`00
0?oo003ooooo05Cooooo00?o0000ooooooooool0@oooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Xooooo`03o`000?oo003ooooo05;ooooo
00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0ZOooool2o`00057ooooo00?o
0000ool00?oo0000AOooool0027ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`1<
ooooo`;o000000?oo`00ooooooooool0AOooool0027ooooo0ol0002/ooooo`;o0000Boooool00ol0
003oooooool00018ooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo04Oo
oooo00?o0000oooooooo0000BOooool0027ooooo00?o0000ooooooooool0[oooool2o`0004Kooooo
00?o0000ool00?oo0000B_ooool0027ooooo00?o0000ooooooooool0/Oooool00ol0003oo`00ool0
0012ooooo`03o`000?oo003ooooo04_ooooo000Qooooo`03o`000?oooooooooo0;;ooooo00Co0000
oooooooo003oo`00?_ooool2o`000003ool00?oooooooooo04_ooooo000Qooooo`03o`000?oooooo
oooo0;?ooooo0_l000000oooooooo`00ooooo`0jooooo`;o000000?oooooool00?ooool0COooool0
027ooooo00?o0000ooooooooool0]Oooool01?l0003oooooool00?oo000hooooo`04o`000?oooooo
o`00ool004oooooo000Qooooo`?o0000]_ooool2o`000003oooooooo003oo`0003Cooooo0_l00002
ool0057ooooo000Qooooo`03o`000?oooooooooo0;Sooooo0_l000000oooooooo`00ool0000`oooo
o`;o0000EOooool0027ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`02ool002co
oooo0_l0001Gooooo`008Oooool00ol0003oooooooooo`2kooooo`;o00000_ooool00ooo003ooooo
ooooo`0Wooooo`;o0000FOooool0027ooooo00?o0000ooooooooool0_Oooool3o`000003ool00?oo
oooooooo02Cooooo0_l0001Kooooo`008Oooool00ol0003oooooooooo`30ooooo`;o00008oooool0
0ol0003oo`00ool0001Looooo`008Oooool00ol0003oooooooooo`32ooooo`?o00007_ooool3ool0
05kooooo000Qooooo`03o`000?oooooooooo0<Gooooo0ol00002ooooo`?oo`004oooool2o`000003
ool00?oooooooooo05oooooo000Qooooo`?o0000b?ooool5o`0000koo`001Ol0001Tooooo`008Ooo
ool00ol0003oooooooooo`3=ooooo`go0000J_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@
ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7o
gMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02
ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV
5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oo
oooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04
oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo001k
ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooo
ooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Q
onk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801oooool0
0omgMgOo<S8booooo`1dooooo`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000
o`0000gooooo00?o0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^ko
oooo00Gooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0
003ooooo01?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;o
oooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?oo
ool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000ooooooo
MgMgoeEEE@0Dooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omE
EEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400A
ooooo`03onk^k_l@413ogMgM01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003ooooooooo
o`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q
8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35328 L
.10458 .39488 L
.12507 .41122 L
.14415 .42375 L
.16254 .43323 L
.17277 .43737 L
.18221 .44049 L
.19242 .4431 L
.19781 .44416 L
.20351 .44505 L
.20846 .44564 L
.21084 .44586 L
.2131 .44603 L
.21437 .44611 L
.21575 .44618 L
.21703 .44624 L
.21818 .44628 L
.21956 .44631 L
.22031 .44633 L
.22102 .44634 L
.22228 .44635 L
.223 .44635 L
.22365 .44635 L
.22492 .44634 L
.22611 .44631 L
.22718 .44629 L
.22835 .44625 L
.23097 .44613 L
.23339 .44598 L
.2378 .4456 L
.24248 .44507 L
.2523 .44352 L
.26314 .44115 L
.28249 .43534 L
.30334 .42709 L
.34448 .40639 L
.38411 .38365 L
.42222 .36208 L
.46278 .34202 L
.50182 .32735 L
.51207 .32441 L
.52317 .32169 L
.53276 .31971 L
.54332 .31796 L
.54827 .31729 L
.55359 .31668 L
.55819 .31623 L
.5632 .31584 L
.56612 .31565 L
Mistroke
.56884 .31551 L
.57165 .31538 L
.57419 .3153 L
.5754 .31527 L
.5767 .31524 L
.57782 .31521 L
.57906 .3152 L
.58037 .31518 L
.58109 .31518 L
.58176 .31518 L
.58296 .31518 L
.58424 .31518 L
.58546 .31519 L
.58616 .3152 L
.58681 .3152 L
.58813 .31522 L
.58954 .31525 L
.5921 .31532 L
.59444 .3154 L
.59984 .31565 L
.60552 .31601 L
.61514 .31681 L
.62565 .31795 L
.66627 .32416 L
.70536 .33108 L
.72531 .33426 L
.73581 .33572 L
.74691 .33707 L
.75684 .33807 L
.76776 .33894 L
.77254 .33924 L
.77768 .3395 L
.78252 .33969 L
.78695 .33982 L
.78923 .33986 L
.79054 .33988 L
.79174 .3399 L
.79301 .33991 L
.79367 .33992 L
.79437 .33992 L
.79555 .33993 L
.79684 .33993 L
.79805 .33993 L
.79914 .33992 L
.8004 .33991 L
.80159 .3399 L
.80371 .33987 L
.80601 .33982 L
.8085 .33976 L
.81125 .33967 L
Mistroke
.8168 .33944 L
.82194 .33916 L
.82676 .33884 L
.83715 .33796 L
.84702 .3369 L
.86555 .33436 L
.90377 .32713 L
.94443 .31736 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35303 L
.10458 .39523 L
.12507 .41151 L
.14415 .42385 L
.16254 .43312 L
.17277 .43716 L
.18221 .44021 L
.19242 .44277 L
.19781 .44382 L
.20351 .4447 L
.20846 .44528 L
.2131 .44568 L
.21575 .44584 L
.21818 .44594 L
.21952 .44598 L
.22028 .446 L
.22099 .44601 L
.22228 .44603 L
.223 .44603 L
.22365 .44603 L
.22486 .44603 L
.22598 .44601 L
.22721 .44599 L
.22853 .44595 L
.22991 .4459 L
.23122 .44583 L
.23368 .44569 L
.2381 .44534 L
.2429 .44482 L
.24814 .44409 L
.25371 .44314 L
.26372 .44098 L
.28319 .43525 L
.30147 .42823 L
.34016 .40931 L
.3813 .38564 L
.42092 .3626 L
.45903 .34299 L
.48028 .33395 L
.49959 .32719 L
.50923 .32438 L
.51968 .32177 L
.52947 .31974 L
.53864 .3182 L
.5481 .31697 L
.55312 .31646 L
.55851 .31603 L
.56121 .31586 L
.56415 .3157 L
Mistroke
.56675 .31558 L
.56951 .31549 L
.57092 .31545 L
.57224 .31542 L
.57344 .3154 L
.57472 .31539 L
.57595 .31538 L
.57724 .31537 L
.57835 .31537 L
.57956 .31538 L
.58087 .31539 L
.58208 .31541 L
.5834 .31543 L
.58481 .31546 L
.58718 .31553 L
.58979 .31562 L
.5946 .31584 L
.5991 .31612 L
.60918 .31693 L
.62003 .31808 L
.66122 .32428 L
.7009 .3311 L
.72091 .33415 L
.73906 .33643 L
.7485 .33739 L
.75871 .33822 L
.76433 .33859 L
.7695 .33887 L
.77445 .33908 L
.77713 .33917 L
.77967 .33924 L
.78204 .3393 L
.78329 .33932 L
.78462 .33934 L
.78574 .33936 L
.78697 .33937 L
.78808 .33938 L
.78914 .33938 L
.79038 .33939 L
.79168 .33939 L
.7928 .33938 L
.79402 .33938 L
.79534 .33937 L
.79675 .33935 L
.79929 .33931 L
.80165 .33926 L
.80422 .33919 L
.80889 .33902 L
.81761 .33858 L
.82706 .33792 L
Mistroke
.83747 .33698 L
.8585 .33442 L
.87792 .33136 L
.89881 .32741 L
.94005 .31805 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009ol0
0002ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00oooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Oooooo00Ko0000ool00?oo003oo`00ooooool0000Cooooo`04
onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`;o000000?oo`00ooooooooool02_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooooooo`Ooo`001ol0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo0ol000000ooo003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMg
MomgMgOo<S8b1Oooool0027ooooo00Co0000ooooool0003oo`00W?ooool8ool000kooooo0ol00006
ool00003o`000?oooooooooo05cooooo1?l0000Kooooo`;o00000_ooool2o`0000Cooooo000Qoooo
o`05o`000?ooooooooooo`000?oo0000U_ooool5ool00003o`000?oooooooooo01cooooo1_oo0002
o`00057ooooo0ooo0003o`0002Wooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00T_oo
ool2o`000003ool00?oooooooooo02Sooooo1?oo0004o`0004Oooooo1?oo00000ol0003ooooooooo
o`0/ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003ooooo08gooooo0ol0000e
ooooo`Ko0000??ooool5ool00003o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0ROooool3o`0003kooooo1Ooo00000ol0003oooooooooo`0_oooo
o`03o`000?oo003oo`0000;oo`0000?o0000ooooooooool0=Oooool0027ooooo0ol00003ooooo`03
o`000?oooooooooo08Gooooo0ooo00000ol0003oooooooooo`14ooooo`Koo`009_ooool6o`0003go
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool3ool00003o`00
0?oooooooooo04gooooo1_oo0004o`0001;ooooo1ooo0003o`0004?ooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0O_ooool2ool000;o0000Foooool5o`0000goo`000ol0
001:ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07_ooooo0_oo0000
0ol0003oooooooooo`2kooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo0_oo00000ol0003oooooooooo`2mooooo`008Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo07Kooooo00?oo`00o`000?ooool0`?ooool0027ooooo00?o0000ooooooooool0
2Oooool2o`0007Cooooo0_oo0033ooooo`008Oooool3o`0000[ooooo00?oo`00o`000?ooool0L?oo
ool00ol0003oo`00ooooo`34ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?l0003o
oooo06gooooo0_l00037ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?l0003ooooo
06[ooooo0_l00039ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03ool00?l0003ooooo06Oo
oooo0_l0003;ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03ool00?l0003ooooo06Gooooo
00?o0000ooooooooool0boooool0027ooooo00?o0000ooooooooool03oooool00ooo003o0000oooo
o`1Rooooo`;oo`00c_ooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o0000ooooo`1O
ooooo`;oo`00d?ooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o0000ooooo`1Loooo
o`;oo`00d_ooool0027ooooo0ol0000Booooo`03ool00?l0003ooooo05Wooooo0_oo00000ol0003o
ooooooooo`3Aooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?l0003ooooo05Kooooo
0_oo00000ol0003oooooooooo`3Cooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?l0
003ooooo05Cooooo00?oo`00o`000?ooool0e_ooool0027ooooo00?o0000ooooooooool05Oooool0
0ooo003o0000ooooo`1Aooooo`;oo`00fOooool0027ooooo00?o0000ooooooooool05oooool2o`00
04oooooo00?oo`00o`000?ooool0fOooool0027ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oo003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3Looooo`008Oooool3o`0001_ooooo00?o
0000ooooooooool0AOooool2o`000=oooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@_ooool2o`000>7ooooo000Qooooo`03o`000?oooooooooo01gooooo0_l00010oooo
o`;o0000hoooool0027ooooo00?o0000ooooooooool07Oooool2ool00003o`000?oooooooooo03_o
oooo0_oo003Uooooo`008Oooool00ol0003oooooooooo`0Oooooo`;oo`0000?o0000ooooooooool0
=_ooool00ol0003oo`00ool0003Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Qooooo`;o
o`00=Oooool00ol0003oo`00ool0003Yooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool2ool0037o
oooo00?o0000ool00?oo0000joooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00;ooooo0ol0000Uooooo`;oo`00;Oooool00ol0003oo`00ool0003]ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`0Wooooo`;oo`00:?ooool01?l0003oo`00ool00?oo003_ooooo`001oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo02Wooooo0_oo00000ol0003oooooooooo`0Qooooo`03o`000?oo003oo`000?;ooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02_ooooo00Coo`00o`000?l0003o00007_ooool2o`000?Gooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo0ol0
000Hooooo`?o0000moooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0booooo`;o00004?ooool2ool000Co0000n_ooool0027ooooo00?o0000
ooooooooool0=?ooool2o`0000koo`00ooooool1ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omE
EEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002X
ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo0ol0000Coooo
o`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Soooo
o`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnH
V9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo
00?oQhN7ofIVI_ooool04_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04
oa0@4?l0003oA4A4olc<c7cooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03
ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oM
gMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`000006oooooomg
MgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd0Noooool007kooooo
00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^
00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Aooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00on7QhOoEEEEooooo`1jooooo`00O_ooool01?mEEEGoZJVYooooool0
0002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05ooooo`03onk^
k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7
QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool02Oooool01Oo<c<co8B4Qo`000?mEEEGo000007_ooooo001nooooo`03
omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Ko
oooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[o
oooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Booooo`05o`000?oooooooooo
ooooool000002oooool01OlQ8B7oQhN7oooooonHV9So000007_ooooo001oooooo`03oiRHV?mgMgOo
oooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgM
oa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002
ooooo`03ogMgMomEEEGooooo01;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool00000Noooool009Kooooo00?o0000ooooooooool01oooool00omEEEGoV9RHoooo
o`04ooooo`09omgMgOl@413ok^k^ooooool0003o^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@
4?oMgMd04oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEE
E@1kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36621 L
.10458 .42311 L
.14415 .46724 L
.16408 .48513 L
.18221 .49855 L
.20178 .50979 L
.21254 .51447 L
.22272 .51789 L
.23241 .52023 L
.2373 .52107 L
.24012 .52145 L
.24269 .52174 L
.24504 .52194 L
.24728 .52208 L
.2485 .52214 L
.24964 .52218 L
.25088 .52221 L
.25158 .52223 L
.25221 .52223 L
.25336 .52223 L
.25442 .52222 L
.25558 .5222 L
.2568 .52216 L
.25787 .52212 L
.25887 .52207 L
.26113 .52192 L
.26373 .52168 L
.26614 .52141 L
.27158 .5206 L
.27638 .51966 L
.28148 .51843 L
.2903 .51575 L
.30004 .51199 L
.31939 .50215 L
.34024 .48821 L
.38138 .45187 L
.42101 .40826 L
.45912 .36155 L
.49968 .31045 L
.53872 .26341 L
.58022 .21916 L
.60102 .20017 L
.6202 .18493 L
.64007 .17167 L
.65867 .16177 L
.67743 .15432 L
.68738 .15144 L
.69293 .15016 L
.69807 .14917 L
Mistroke
.70298 .14841 L
.7082 .1478 L
.71119 .14755 L
.71265 .14744 L
.714 .14736 L
.7152 .1473 L
.71652 .14725 L
.71785 .14721 L
.71857 .14719 L
.71924 .14718 L
.7205 .14717 L
.7212 .14716 L
.72186 .14716 L
.72305 .14717 L
.72433 .14719 L
.72546 .14722 L
.72653 .14726 L
.72895 .14737 L
.73157 .14753 L
.73396 .14773 L
.73935 .14832 L
.7441 .149 L
.74918 .14991 L
.75831 .15197 L
.76917 .15513 L
.77902 .15864 L
.81906 .17853 L
.85758 .20474 L
.89855 .23804 L
.938 .27338 L
.97594 .30878 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36768 L
.10458 .42297 L
.14415 .46615 L
.18221 .49767 L
.20178 .50932 L
.21274 .51436 L
.22272 .51798 L
.22755 .51939 L
.23267 .52064 L
.2371 .52152 L
.24186 .52225 L
.24453 .52256 L
.24697 .52279 L
.24814 .52288 L
.24942 .52296 L
.25062 .52302 L
.25175 .52306 L
.25244 .52308 L
.25319 .5231 L
.25449 .52312 L
.25523 .52312 L
.25601 .52312 L
.25667 .52311 L
.2574 .5231 L
.25871 .52306 L
.25945 .52303 L
.26011 .523 L
.26265 .52285 L
.26493 .52265 L
.26745 .52238 L
.27256 .52164 L
.27729 .52072 L
.28173 .51967 L
.29172 .51661 L
.30249 .51227 L
.32253 .50141 L
.34363 .48635 L
.38174 .45111 L
.4223 .40527 L
.46135 .35685 L
.50284 .30502 L
.54283 .25836 L
.58129 .21926 L
.60078 .20226 L
.62221 .18604 L
.6428 .17306 L
.66161 .16356 L
.68106 .15615 L
.69178 .15314 L
Mistroke
.69712 .15193 L
.70195 .15099 L
.70657 .15025 L
.71157 .1496 L
.71431 .14932 L
.71684 .1491 L
.71941 .14892 L
.7218 .1488 L
.72386 .14872 L
.72502 .14869 L
.72607 .14867 L
.72722 .14866 L
.72848 .14865 L
.72966 .14866 L
.73075 .14867 L
.73188 .14869 L
.73293 .14872 L
.73409 .14876 L
.73534 .14881 L
.73787 .14895 L
.7402 .14912 L
.74495 .14956 L
.75003 .15021 L
.75916 .15178 L
.77002 .15436 L
.77988 .15735 L
.7991 .1649 L
.81991 .17552 L
.86088 .20305 L
.90034 .23607 L
.93828 .27159 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3?ooooo`Ko00002_oo00000ol0
003oooooooooo`1Rooooo`008Oooool00ol0003oooooooooo`3;ooooo`Co00004?ooool5ool000;o
0000G_ooool0027ooooo00?o0000ooooooooool0b?ooool3o`0000;ooooo0_oo000Eooooo`03ool0
0?oooooo000000;o0000Foooool0027ooooo00?o0000ooooooooool0aOooool3o`0000;ooooo0ooo
000Looooo`;o0000FOooool0027ooooo00?o0000ooooooooool0`oooool2o`0000;ooooo0ooo000Q
ooooo`;o0000Eoooool0027ooooo00?o0000ooooooooool0`Oooool2o`000004oooooooo003oo`00
ool002Kooooo0_l00002ool005?ooooo000Qooooo`?o0000_oooool2o`0000;ooooo00?oo`00oooo
ooooool0:Oooool2o`0000;oo`00DOooool0027ooooo00?o0000ooooooooool0_Oooool2o`0003;o
oooo00?o0000oooooooo0000D?ooool0027ooooo00?o0000ooooooooool0_?ooool00ol0003ooooo
ooooo`0cooooo`;o00000_oo001>ooooo`008Oooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo03Kooooo0_l00002ool004cooooo000Qooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool0>Oooool2o`000003ool00?oooooooooo04Wooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00ooooooooool0??ooool00ol0003oo`00ool00019ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0]oooool2ool0043ooooo0_l000000ooo003oooooooooo`16ooooo`001Ol00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000]_oo
ool00ooo003oooooooooo`12ooooo`03o`000?oo003ooooo04Kooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Cooooo00?o
0000ool00?ooool0AOooool2o`0004Kooooo0007ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0/oooool00ol0003oo`00
ooooo`18ooooo`03o`000?oooooooooo04?ooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0;7ooooo0_l000000ooo003ooooo
ooooo`19ooooo`;o0000@oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0/?ooool00ol0003oo`00ool0001>ooooo`03o`00
0?oooooooooo043ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool0[oooool00ol0003oo`00ooooo`1@ooooo`;o0000@?ooool0027ooooo00?o
0000ooooooooool0[_ooool00ol0003oo`00ooooo`1Cooooo`03o`000?oo003oo`0003gooooo000Q
ooooo`03o`000?oooooooooo0:gooooo00?o0000ool00?ooool0EOooool00ol0003oooooool0000l
ooooo`008Oooool3o`000:cooooo00?o0000ool00?ooool0Eoooool2o`000003ool00?oooooooooo
03Wooooo000Qooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0F_ooool00ol0003o
o`00ooooo`0iooooo`008Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo05_ooooo
00?o0000ool00?ooool0>?ooool0027ooooo00?o0000ooooooooool0Z_ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oo003ooooo03Oooooo000Qooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0Goooool00ol0003oo`00ooooo`0fooooo`008Oooool00ol0003oooooooooo`2Xoooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0=?ooool0027ooooo00?o0000oooooooo
ool0Yoooool00ol0003oooooooooo`1Tooooo`03ool00?oooooooooo03?ooooo000Qooooo`?o0000
Y_ooool00ol0003oooooooooo`1Vooooo`;oo`00<oooool0027ooooo00?o0000ooooooooool0YOoo
ool00ooo003oooooooooo`1Yooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooo
oooo0:Cooooo00?oo`00ooooooooool0Joooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0
003oooooooooo`2Sooooo`03ool00?oooooooooo06gooooo00?o0000ooooooooool0;_ooool0027o
oooo00?o0000ooooooooool0X_ooool00ooo003oooooooooo`1_ooooo`03o`000?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo0:7ooooo00?oo`00ooooooooool0LOooool00ol0003ooooo
ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03ool00?oooooooooo07?ooooo00?o
0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool0Woooool00ooo003oooooooooo`1e
ooooo`03o`000?oooooooooo02[ooooo000Qooooo`?o0000W_ooool00ol0003oo`00ooooo`1goooo
o`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1?l00000
0ol@413oooooooooo`07ooooo`03ool00?oooooooooo037ooooo1?l000000ol@413oooooooooo`02
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03;ooooo00?oo`00ooooooooool02?oo
ool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`0booooo`03ool00?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Ooo
ool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0=Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03;ooooo00?oo`00o`000?ooool01oooool00onHV9So8B4Q
onk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0nooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
=_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Cooooo00?oo`00o`000?ooool0
1oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<03oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00fooooo`03ool00?l0003ooooo00Oooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0iooooo`03ool00?l0003ooooo00Oooooo00?o0000oooo
ooooool06Oooool0027ooooo0ol0000mooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?oo`00o`000?ooool00_ooool01Ol0
003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000005ooooo`03o`000?oooooo
oooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Woo`00o`000?oooooooooooiRH
V?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0Uoooool00ol0003ooooo
ooooo`27ooooo`03ool00?l0003ooooo023ooooo000Qooooo`03o`000?oooooooooo09Kooooo00?o
0000ooooooooool0ROooool00ooo003o0000ooooo`0Oooooo`008Oooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooooooo08[ooooo00?oo`00o`000?ooool07_ooool0027ooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`2<ooooo`03ool00?l0003ooooo01?ooooo0_l00002oooo
o`;o00001?ooool0027ooooo00?o0000ooooooooool0Toooool00ooo003o0000ooooo`2@ooooo`03
o`000?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooonMo`00
0003ool00?l0003o000009Wo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^
k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool2o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo0000
093ooooo00?oo`00o`000?ooool0Yoooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooo`00002@ooooo`03ool00?oooooooooo0;7ooooo000Qooooo`04o`000?ooooooooooo`0008ko
oooo00?oo`00ooooooooool0/_ooool0027ooooo00Go0000ooooooooooooooooool0002<ooooo`03
ool00?oooooooooo0;?ooooo000Qooooo`05o`000?oooooooooooooooooo0000Roooool00ooo003o
0000ooooo`2dooooo`008Oooool3o`0000;ooooo00?oo`00ooooooooool0R?ooool00ooo003ooooo
ooooo`2dooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?o
o`00ooooooooool0]Oooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`25
ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00oooo
ooooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool00ol0003oooooooooo`04ooooo`03
ool00?l0003ooooo08;ooooo00?o0000ooooooooool0^?ooool0027ooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`21ooooo`03o`000?oooooooooo0;Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?oo`00ooooooooool0Ooooool00ol0003oooooooooo`2iooooo`008Oooool3
o`0000Kooooo00?oo`00o`000?ooool0O_ooool00ol0003oooooooooo`2jooooo`008Oooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo07cooooo00?o0000ooooooooool0^oooool0027o
oooo00?o0000ooooooooool01oooool00ooo003o0000ooooo`1kooooo`03o`000?oooooooooo0;co
oooo000Qooooo`03o`000?oooooooooo00Sooooo00?oo`00o`000?ooool0N_ooool00ol0003ooooo
ooooo`2looooo`008Oooool00ol0003oooooooooo`09ooooo`;oo`00N?ooool00ooo003o0000oooo
o`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Kooooo00?oo`00
ooooooooool0__ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1doooo
o`03ool00?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0L_ooool00ooo003oooooooooo`30ooooo`008Oooool3o`0000gooooo00?o0000ooooooooool0
L?ooool00ooo003oooooooooo`31ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo00?oo`00ooooooooool0`_ooool0027ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1]ooooo`03ool00?l0003ooooo0<?ooooo000Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`33ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool0a?ooool0027ooooo
00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oooooooooo0<Gooooo
000Qooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0Ioooool00ooo003ooooooooo
o`36ooooo`008Oooool3o`0001;ooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`37
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?ooooo00?oo`00oooo
ooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1Rooooo`03
o`000?oooooooooo0<Sooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0
HOooool00ol0003oooooooooo`39ooooo`008Oooool00ol0003oooooooooo`0Eooooo`03ool00?oo
oooooooo05oooooo00?o0000ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0
5_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo0<_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0c?ooool000Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Gooooo`03ool0
0?oooooooooo05[ooooo00?o0000ooooooooool0cOooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06?ooool00ooo003ooooo
ooooo`1Hooooo`03o`000?oooooooooo0<kooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06Oooool00ooo003o
ooooooooo`1Gooooo`03o`000?oooooooooo0<kooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?oo`00oooooooo
ool0EOooool00ooo003oooooooooo`3?ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05?o
oooo00?oo`00ooooooooool0d?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?oo`00oooooooo
ool0dOooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1?ooooo`03ool0
0?oooooooooo0=;ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0C_oo
ool00ooo003oooooooooo`3Cooooo`008Oooool3o`0001kooooo00?o0000ooooooooool0Boooool0
0ol0003oo`00ooooo`3Eooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
04Wooooo00?o0000ool00?ooool0e_ooool0027ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`17ooooo`03o`000?oo003ooooo0=Oooooo000Qooooo`03o`000?oooooooooo027ooooo
00?o0000ool00?ooool0AOooool00ol0003oo`00ooooo`3Hooooo`008Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oo003oo`0004?ooooo00?o0000ool00?ooool0fOooool0027ooooo00?o0000
ooooooooool08oooool2o`000003ool00?oooooooooo03kooooo0_l000000ooo003oooooooooo`3I
ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo003ooooo03gooooo00?o0000oooo
oooo0000g?ooool0027ooooo0ol0000Vooooo`03o`000?oo003ooooo03_ooooo00?o0000oooooooo
ool0gOooool0027ooooo00?o0000ooooooooool09oooool00ol0003oo`00ool0000iooooo`03o`00
0?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo0000=ooo
ool00ol0003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o000000?oo`00
ooooooooool0<oooool00ol0003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oo003ooooo037ooooo0_l0003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oo003ooooo02oooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool0
;Oooool00ol0003oo`00ooooo`0]ooooo`;oo`00iOooool0027ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0>Gooooo000Qooooo`?o0000;oooool2
o`0002Wooooo0_oo003Xooooo`008Oooool00ol0003oooooooooo`0aooooo`;o00009Oooool2ool0
0003o`000?oooooooooo0>Oooooo000Qooooo`03o`000?oooooooooo03?ooooo0_l0000Rooooo`03
ool00?l0003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo03Gooooo0_l0000Nooooo`;oo`00
kOooool0027ooooo00?o0000ooooooooool0=oooool3ool001Wooooo0_oo003_ooooo`008Oooool0
0ol0003oooooooooo`0hooooo`;o00000_oo000Dooooo`03o`000?oo003oo`000?7ooooo000Qoooo
o`03o`000?oooooooooo03_ooooo00?o0000ool00?oo00000_oo000:ooooo`Ko0000m?ooool0027o
oooo0ol00010ooooo`Ooo`000ol0003jooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ8B7ogMgMoooo
o`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_ooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHooooo`02ooooo`Go
00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOoIVIV5?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0
0ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko
00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM
00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko
410@00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;oMgMg1_ooool0
0olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001?oo
ool00ol0003oooooooooo`0Booooo`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEE
ooooo`07ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Go
oooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`00
00Cooooo00?o0000ooooooooool02_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05olc<c?lQ8B7o0000oeEEEOl000001oooool00omgMgOo<S8booooo`1dooooo`00Noooool0
0ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01ooo
ool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_oo
ool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Dooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00ol0003o
ooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo
00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0D
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo
1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36882 L
.10458 .42945 L
.14415 .47813 L
.18221 .51413 L
.20178 .52772 L
.21267 .53371 L
.22272 .53823 L
.23293 .54179 L
.23832 .54324 L
.24402 .54446 L
.24641 .54487 L
.24897 .54525 L
.25119 .54552 L
.25361 .54576 L
.25507 .54587 L
.25643 .54596 L
.25773 .54603 L
.2584 .54605 L
.25912 .54608 L
.25983 .5461 L
.26048 .54611 L
.26176 .54612 L
.26293 .54612 L
.26416 .5461 L
.26538 .54606 L
.26607 .54604 L
.26671 .54601 L
.26912 .54586 L
.27131 .54567 L
.27364 .54542 L
.27847 .54472 L
.2838 .54367 L
.29326 .54109 L
.30213 .53784 L
.32232 .52753 L
.34082 .51465 L
.38045 .47709 L
.41855 .43018 L
.45912 .37198 L
.49816 .31159 L
.53966 .24723 L
.57964 .18952 L
.61811 .14181 L
.63759 .12157 L
.65902 .10289 L
.67938 .08893 L
.69843 .07943 L
.70884 .07575 L
.71396 .07434 L
Mistroke
.71872 .07327 L
.72301 .0725 L
.72758 .07188 L
.7302 .07163 L
.73148 .07153 L
.73266 .07146 L
.73371 .0714 L
.73487 .07135 L
.73603 .07132 L
.73725 .0713 L
.73856 .07129 L
.73977 .0713 L
.7404 .07132 L
.7411 .07133 L
.74183 .07136 L
.74251 .07139 L
.7449 .07152 L
.74625 .07162 L
.74748 .07173 L
.75203 .07227 L
.7568 .07306 L
.76198 .07419 L
.7668 .07548 L
.77773 .07929 L
.78828 .08411 L
.79823 .08966 L
.81683 .10256 L
.85534 .13895 L
.89632 .18962 L
.93577 .24654 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36745 L
.10458 .42888 L
.14415 .47887 L
.18221 .51541 L
.20178 .52887 L
.21274 .53472 L
.22272 .53897 L
.22755 .54066 L
.23267 .54218 L
.2371 .54328 L
.24186 .54424 L
.24453 .54467 L
.24697 .545 L
.24945 .54527 L
.25175 .54547 L
.25305 .54556 L
.25442 .54563 L
.25521 .54566 L
.25595 .54569 L
.25662 .54571 L
.25734 .54572 L
.25798 .54573 L
.25868 .54574 L
.25942 .54574 L
.2601 .54573 L
.26133 .54571 L
.26265 .54567 L
.26386 .54561 L
.26521 .54554 L
.26793 .54533 L
.27045 .54507 L
.27282 .54476 L
.27815 .54388 L
.28389 .54261 L
.29438 .53945 L
.30401 .53563 L
.32293 .52562 L
.34363 .51103 L
.38419 .47244 L
.42324 .42464 L
.46474 .3653 L
.50472 .30334 L
.54318 .24316 L
.5841 .18312 L
.62351 .13374 L
.66139 .09783 L
.68084 .08474 L
.69176 .07912 L
.70173 .07511 L
Mistroke
.70651 .07357 L
.7116 .07221 L
.716 .07126 L
.72076 .07048 L
.72368 .07013 L
.72496 .07 L
.72636 .06988 L
.7276 .0698 L
.72893 .06972 L
.72966 .06969 L
.73033 .06967 L
.73164 .06963 L
.7329 .06962 L
.73407 .06962 L
.73535 .06964 L
.73599 .06966 L
.7367 .06968 L
.73789 .06974 L
.73918 .06981 L
.74149 .06999 L
.7439 .07024 L
.74647 .07057 L
.75109 .07135 L
.75659 .07257 L
.76157 .07396 L
.77244 .07788 L
.78269 .08268 L
.80274 .09498 L
.8212 .10949 L
.86066 .14929 L
.8986 .19655 L
.93899 .25354 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3Ooo001Rooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=Cooooo1Ol00009ooooo`?oo`00
0_l0001Mooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo0_l0
000Cooooo`;o0000Foooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3=
ooooo`;oo`000ol0000Gooooo`?o0000F?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3:ooooo`?oo`000_l0000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`38ooooo`;oo`0000?oooooo`000?l000008Oooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`37ooooo`04ool00?oooooo0000o`0002?o
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`35ooooo`;oo`00
00?oooooo`000?ooool09_ooool00ooo003o0000ooooo`1Aooooo`008Oooool3o`000<Cooooo00Co
o`00ooooool0003o0000:Oooool2ool00003o`000?oooooooooo04kooooo000Qooooo`03o`000?oo
oooooooo0<Cooooo00?oo`00o`000?ooool0;?ooool00ooo003o0000ooooo`1>ooooo`008Oooool0
0ol0003oooooooooo`33ooooo`03ool00?l0003ooooo02kooooo00?oo`00o`000?l00000COooool0
027ooooo00?o0000ooooooooool0`_ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooo0000
04cooooo000Qooooo`03o`000?oooooooooo0<7ooooo00?oo`00ooooooooool0<_ooool00ooo003o
ooooo`00001;ooooo`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo
00?oo`00ooooool00000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`0fooooo`03ool00?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000oooo
ooooool0>_ooool00ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2looooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oo
oooooooo0;Wooooo00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool0
0ol0003oooooooooo`2iooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool0
027ooooo00?o0000ooooooooool0^?ooool00ol0003oo`00ooooo`16ooooo`03o`000?oooooooooo
043ooooo000Qooooo`?o0000]oooool00ol0003oo`00ooooo`17ooooo`03o`000?oooooooooo043o
oooo000Qooooo`03o`000?oooooooooo0;Oooooo00?oo`00ooooooooool0B?ooool00ooo003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`2fooooo`03ool00?oooooooooo04[ooooo00?o
o`00ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0]Oooool00ooo003oooooooooo`1;
ooooo`03ool00?l0003ooooo03kooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00oooo
ooooool0COooool00ooo003o0000ooooo`0mooooo`008Oooool00ol0003oooooooooo`2cooooo`03
ool00?oooooooooo04oooooo00?oo`00ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
/_ooool00ooo003o0000ooooo`1Aooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo0;7ooooo00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3
o`000;3ooooo00?oo`00o`000?ooool0E?ooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0
003oooooooooo`2_ooooo`03ool00?l0003ooooo05Kooooo00?oo`00o`000?ooool0>Oooool0027o
oooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wo
oooo000Qooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000
ooooo`0hooooo`008Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?o
o`00o`000?ooool0=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0=?ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03
o`000?oooooooooo037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Sooooo00?o0000ool00?ooool0IOooool00ol0003o
ooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0Y_ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oo
oooooooo02oooooo000Qooooo`?o0000Y_ooool00ooo003oooooooooo`1Yooooo`03ool00?l0003o
oooo02oooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0Joooool00ooo
003o0000ooooo`0^ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06go
oooo00?oo`00ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0Xoooool00ol0003oo`00
ooooo`1^ooooo`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o
o`00ooooooooool0Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2R
ooooo`03ool00?oooooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000oooo
ooooool0XOooool00ol0003oo`00ooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o
0000XOooool00ooo003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`00
0?oooooooooo0:3ooooo00?oo`00ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`1hooooo`03ool00?l0003o
oooo02Sooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ooo
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_o
oooo00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`1mooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo09cooooo00?o
0000ooooooooool0OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0moooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@0mooooo`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0dooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`00
0?oooooooooo00?ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo03So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?o
oooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03
o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0>Oooool00ol0003oooooooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKo
oooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0looooo`08ool00?l0003o
ooooo`000?nj^[[ooooooiRHV?l@410Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ol0003o
o`00ooooo`0iooooo`03oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@
4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo
08[ooooo00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ol0003o
o`00ooooo`2<ooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo
00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0Mooooo`008Oooool00ol0003ooooooooo
o`2Dooooo`03o`000?oo003ooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l0
0004ooooo`008Oooool00ol0003oooooooooo`2Cooooo`03o`000?oo003ooooo093ooooo00?oo`00
ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooigo000000?o
o`00o`000?l00000TOl000000ooo003o0000o`000005o`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Ooo
ool00ol0003oooooool0002Aooooo`03o`000?oooooooooo0:Kooooo0_l00002ooooo`;o00001?oo
ool0027ooooo00?o0000oooooooo0000T?ooool00ol0003oooooooooo`2aooooo`008Oooool01?l0
003ooooooooooooo002?ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`05o`000?oooooooooo
o`000?oo0000SOooool00ol0003oooooooooo`2booooo`008Oooool01Ol0003ooooooooooooooooo
o`0008cooooo00?o0000ooooooooool0/oooool0027ooooo0ol00002ooooo`03ool00?oooooooooo
08Wooooo00?o0000ooooooooool0/oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003o
o`00ooooo`28ooooo`03o`000?oooooooooo0;Cooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ool00?ooool0Q_ooool00ol0003oooooooooo`2eooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0]_ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oo`00ooooo`24ooooo`03o`000?oo003ooooo0;Kooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0P_ooool00ol0003oo`00ooooo`2goooo
o`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo083ooooo00?o0000ool00?oo
ool0^?ooool0027ooooo0ol00006ooooo`03o`000?oo003ooooo083ooooo00?oo`00ooooooooool0
^?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oo`00ooooo`1nooooo`03o`000?oo
003ooooo0;Wooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool0
0ol0003oo`00ooooo`2jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
07cooooo00?oo`00ooooooooool0^_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1jooooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`2looooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0_?ooool0027ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo0;gooooo000Qoooo
o`?o00003?ooool00ol0003oooooooooo`1dooooo`03o`000?oo003ooooo0;kooooo000Qooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`2nooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo003ooooo07;ooooo00?o0000ooooooooool0
_oooool0027ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1`ooooo`03o`000?oo
oooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Koooool0
0ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo
06kooooo00?o0000ooooooooool0`Oooool0027ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`1/ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`?o00004Oooool00ooo003ooooo
ooooo`1[ooooo`03o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ool00?ooool0J_ooool00ol0003oooooooooo`33ooooo`008Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oo003ooooo06Sooooo00?o0000ooooooooool0a?ooool0027ooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo0<Cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooooooool0IOooool00ooo003oooooooooo`35ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo003ooooo06Cooooo00?oo`00oooo
ooooool0a_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0H_ooool00ooo
003o0000ooooo`37ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00_ooool3o`0001Kooooo00?oo`00ooooooooool0HOooool00ooo003oooooooooo`37oooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Gooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b?ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05kooooo00?oo`00o`000?ooool0bOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo0<[ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0F_ooool00ooo003o0000ooooo`3;ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`3;ooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0c?ooool0027ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`03ool00?l0003ooooo0<gooooo000Qooooo`?o0000
7?ooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0<kooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`3>ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0coooool0
027ooooo00?o0000ooooooooool07_ooool00ooo003o0000ooooo`1@ooooo`03o`000?oooooooooo
0=3ooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0Coooool00ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool08Oooool00ooo003ooooooooo
o`1;ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00008_ooool00ooo003oooooooooo`19
ooooo`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?oo`00o`00
0?ooool0AOooool2ool00003o`000?oooooooooo0=Cooooo000Qooooo`03o`000?oooooooooo02Co
oooo00?oo`00o`000?ooool0@oooool00ooo003o0000ooooo`3Gooooo`008Oooool00ol0003ooooo
ooooo`0Uooooo`03ool00?l0003ooooo047ooooo00?oo`00o`000?ooool0f?ooool0027ooooo00?o
0000ooooooooool09_ooool00ooo003o0000ooooo`0oooooo`03ool00?l0003ooooo0=Wooooo000Q
ooooo`03o`000?oooooooooo02Oooooo00?oo`00o`000?ooool0?Oooool00ooo003o0000ooooo`3J
ooooo`008Oooool00ol0003oooooooooo`0Xooooo`03ool00?l0003ooooo03_ooooo00?oo`00o`00
0?ooool0foooool0027ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0hooooo`03
ool00?l0003ooooo0=cooooo000Qooooo`?o0000:oooool00ol0003oooooooooo`0fooooo`03ool0
0?l0003ooooo0=gooooo000Qooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0=?oo
ool00ooo003o0000ooooo`3Nooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo03;ooooo00?oo`00o`000?ooool0goooool0027ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0`ooooo`03ool00?l0003ooooo0>3ooooo000Qooooo`03o`000?oooooooooo02oo
oooo0_l0000`ooooo`03ool00?oooooooooo0>3ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0:oooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo033ooooo0_oo
00000ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0>?ooooo000Qooooo`?o0000<_ooool2
ool002Wooooo00?o0000ooooooooool0i?ooool0027ooooo00?o0000ooooooooool0=?ooool00ooo
003oooooooooo`0Uooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Go
oooo0_oo000Sooooo`;o0000j?ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003ooooo
ooooo`0Mooooo`;oo`0000?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0>?oo
ool3ool001Wooooo0ooo003]ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool0>oooool2ool000;o00004_ooool3ool00003o`000?oooooooooo0>gooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?Oooool2ool000?o00003?ooool3ool0
00;o0000lOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`Oo
00001Ooo0003o`000??ooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:cooooo00?oMgMgofIV
I_ooool05oooool00omVIVKoMgMgooooo`2Oooooo`00Roooool3o`0001?ooooo00?o8B4QomgMgOoo
ool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM09oooooo0022ooooo`07ohN7
Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol0
0009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVoooo
o`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8H3ooooo0022ooooo`07oa0@4?oMgMgo
MgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^ko
MgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRHV?lQ8B7o
k^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^o`000?oo
ool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8H3ooooo0022ooooo`07o`00
0?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^kP0<oooo
o`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26
ooooo`00P_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00ooo
ool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool0
2_ooool6o`0000Cooooo00?o0000ooooooooool0Q_ooool008;ooooo00?ogMgMob4Q8Oo^k^h00ooo
ool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHoooo
o`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@oooo
ool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool0Q_ooool008?ooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Ooo
ool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?oo
ool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`26ooooo`00V_ooool0
0ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`00
0?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo08Ko
oooo002Jooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIV
oooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo
000008Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36269 L
.10458 .41601 L
.14415 .45728 L
.16408 .47398 L
.18221 .4865 L
.20178 .49698 L
.21254 .50133 L
.22272 .5045 L
.23241 .50667 L
.2373 .50745 L
.24012 .5078 L
.24269 .50805 L
.24504 .50824 L
.24728 .50836 L
.2485 .50842 L
.24964 .50845 L
.25088 .50848 L
.25158 .50849 L
.25221 .50849 L
.25336 .50849 L
.25442 .50848 L
.25558 .50845 L
.2568 .50841 L
.25787 .50837 L
.25887 .50832 L
.26113 .50817 L
.26373 .50794 L
.26614 .50768 L
.27158 .50691 L
.27638 .50601 L
.28148 .50484 L
.2903 .50231 L
.30004 .49877 L
.31939 .4895 L
.34024 .4764 L
.38138 .44232 L
.42101 .4015 L
.45912 .3579 L
.49968 .31034 L
.53872 .26667 L
.58022 .22574 L
.60102 .20821 L
.6202 .19418 L
.64007 .18201 L
.65867 .17294 L
.67743 .16616 L
.68738 .16355 L
.69293 .16239 L
.69807 .16151 L
Mistroke
.70298 .16084 L
.7082 .1603 L
.71119 .16008 L
.71265 .16 L
.714 .15993 L
.7152 .15988 L
.71652 .15984 L
.71716 .15983 L
.71785 .15981 L
.71857 .1598 L
.71924 .15979 L
.7199 .15979 L
.72059 .15979 L
.72184 .15979 L
.72253 .1598 L
.72318 .15981 L
.72389 .15982 L
.72465 .15984 L
.72595 .15988 L
.72732 .15994 L
.72977 .16007 L
.73214 .16023 L
.73434 .16042 L
.73935 .16095 L
.74441 .16166 L
.7499 .16261 L
.75984 .1648 L
.77844 .17047 L
.79836 .17863 L
.81942 .18935 L
.85735 .2132 L
.89775 .24333 L
.93662 .27522 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36178 L
.10458 .41672 L
.14415 .45819 L
.16408 .4745 L
.18221 .48653 L
.20178 .49648 L
.21254 .50059 L
.22272 .50359 L
.23241 .50565 L
.2373 .50639 L
.24012 .50672 L
.24269 .50697 L
.24504 .50715 L
.24728 .50728 L
.2485 .50733 L
.24964 .50737 L
.25088 .50739 L
.25158 .50741 L
.25221 .50741 L
.25336 .50741 L
.25442 .50741 L
.25558 .50739 L
.2568 .50735 L
.25787 .50732 L
.25887 .50727 L
.26113 .50714 L
.26373 .50694 L
.26614 .5067 L
.27158 .50599 L
.27638 .50516 L
.28148 .50407 L
.2903 .5017 L
.30004 .49835 L
.31939 .48951 L
.34024 .47686 L
.38138 .44339 L
.42101 .40266 L
.45912 .35859 L
.49968 .31013 L
.53872 .26562 L
.58022 .22428 L
.60102 .20685 L
.6202 .19306 L
.64007 .18126 L
.65867 .17261 L
.67743 .16628 L
.68738 .1639 L
.69293 .16286 L
.69807 .16209 L
Mistroke
.70298 .16151 L
.70549 .16128 L
.7082 .16107 L
.70976 .16098 L
.71119 .1609 L
.71253 .16084 L
.714 .16079 L
.71532 .16076 L
.71655 .16074 L
.71785 .16073 L
.71858 .16073 L
.71924 .16073 L
.72049 .16074 L
.72112 .16075 L
.72182 .16076 L
.72305 .16079 L
.7242 .16083 L
.72679 .16095 L
.72957 .16112 L
.73468 .16155 L
.73935 .16209 L
.74918 .16366 L
.75831 .16562 L
.77902 .17177 L
.79952 .18004 L
.81812 .18924 L
.85815 .21372 L
.89667 .24208 L
.93764 .27574 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0<oooooo00Co0000
ool00?oo003oo`003Ol0001Tooooo`008Oooool00ol0003oooooooooo`3;ooooo`Co00003_ooool6
ool000?o0000G_ooool0027ooooo0ol00038ooooo`?o00006?ooool3ool000?o0000Foooool0027o
oooo00?o0000ooooooooool0aOooool00ooo003o0000o`00000Nooooo`?oo`000_l0001Iooooo`00
8Oooool00ol0003oooooooooo`33ooooo`;oo`009?ooool3ool00003o`000?oooooooooo05Gooooo
000Qooooo`03o`000?oooooooooo0<3ooooo0ooo000Yooooo`03ool00?l0003o000005Gooooo000Q
ooooo`03o`000?oooooooooo0;gooooo0ooo00000ol0003oooooooooo`0/ooooo`;o0000Doooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo00?o0000ooooooooool0_?ooool00ooo003o0000o`00000booooo`?o0000D?oo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0;[ooooo0_oo00000ol0003oooooooooo`0eooooo`;o0000C_oo
ool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_oo
ool3o`000;Wooooo00?oo`00o`000?l00000>_ooool2ool004cooooo0007ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0;Sooooo00?o
o`00o`000?ooool0?Oooool00ooo003o0000ooooo`19ooooo`001oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0;Oooooo
0_l00010ooooo`;oo`00BOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`12ooooo`03ool0
0?l0003ooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0;Cooooo0_l00016ooooo`;oo`0000?o0000ooooooooool0
@oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooooooo04Sooooo00?oo`00o`000?ooool0@oooool0027ooooo00?o
0000ooooooooool0/Oooool2o`0004cooooo0_oo00000ol0003oooooooooo`10ooooo`008Oooool0
0ol0003oooooooooo`2`ooooo`03o`000?oooooooooo04kooooo00?oo`00o`000?l00000@?ooool0
027ooooo0ol0002^ooooo`;oo`00D_ooool00ooo003oooooo`00000oooooo`008Oooool00ol0003o
ooooooooo`2]ooooo`03ool00?oooooooooo05?ooooo00?oo`00ooooool00000?_ooool0027ooooo
00?o0000ooooooooool0[?ooool00ooo003oooooooooo`1Gooooo`03o`000?oooooooooo03_ooooo
000Qooooo`03o`000?oooooooooo0:_ooooo00?oo`00ooooooooool0FOooool00ol0003ooooooooo
o`0jooooo`008Oooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo05_ooooo0_l0000j
ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03ool00?oooooooooo05kooooo00?o0000oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0Z?ooool00ooo003oooooooooo`1Pooooo`03
o`000?oooooooooo03Kooooo000Qooooo`?o0000Yoooool00ooo003oooooooooo`1Rooooo`;oo`00
=_ooool0027ooooo00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Tooooo`03o`000?oo
003oo`0003Cooooo000Qooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0I_ooool2
o`000003ool00?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?oo`00oooo
ooooool0JOooool00ol0003oo`00ooooo`0aooooo`008Oooool00ol0003oooooooooo`2Sooooo`03
ool00?oooooooooo06_ooooo00?o0000ool00?ooool0<?ooool0027ooooo00?o0000ooooooooool0
X_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo003ooooo02oooooo000Qooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool0Koooool00ol0003oo`00ooooo`0^ooooo`008Oooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo077ooooo00?o0000ool00?ooool0;Oooool0
027ooooo0ol0002Oooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0:oooool0027o
oooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo00Oooooo00?o0000
ooooooooool0<Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0<?ooool00ooo003oooooooooo`0:ooooo`Go00006oooool0027ooooo00?o0000
ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo033ooooo00?oo`00ooooooooool02Ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
1oooool00ooo003o0000ooooo`0eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`09ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oo
oooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03kooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0<_ooool2o`0000[ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00oooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=_ooool00ol0003o
ooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0=Oooool00ol0003oooooooooo`08oooo
o`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01Oooool00ooo
003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0ioooo
o`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000005
ooooo`03ool00?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool4o`0003[ooooo00Wo0000
oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool0
Uoooool00ooo003o0000ooooo`27ooooo`;oo`008Oooool0027ooooo00?o0000ooooooooool0Uooo
ool00ooo003oooooooooo`28ooooo`03o`000?oo003ooooo01oooooo000Qooooo`03o`000?oooooo
oooo09Kooooo00?oo`00ooooooooool0R_ooool00ol0003oo`00ooooo`0Nooooo`008Oooool00ol0
003oooooooooo`2Eooooo`03ool00?oooooooooo08gooooo00?oo`00ooooooooool04_ooool2o`00
00;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oooooooooo08oo
oooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooo
o`Oo000000?oo`00o`000?l00000Tol000000ooo003o0000o`00002Ao`000003ool00?l0003o0000
00Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oo`00ooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5
ooooo`008Oooool2o`000003ool00?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo0000
097ooooo00?o0000ooooooooool0Y_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003o
ooooo`00002@ooooo`03o`000?oooooooooo0;7ooooo000Qooooo`04o`000?ooooooooooo`0008ko
oooo00?o0000ooooooooool0/_ooool0027ooooo00Go0000ooooooooooooooooo`00002<ooooo`03
o`000?oooooooooo0;?ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`2dooooo`008Oooool3o`0000;ooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`2eooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool0]_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`24ooooo`03ool00?oooooooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Co
oooo00?o0000ool00?ooool0Poooool00ooo003oooooooooo`2gooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03ool00?oooooooooo087ooooo00?oo`00ooooooooool0^?ooool0027ooooo00?o
0000ooooooooool01_ooool00ooo003oooooooooo`1oooooo`03ool00?oooooooooo0;Wooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0OOooool00ooo003oooooooooo`2j
ooooo`008Oooool3o`0000Oooooo00?oo`00ooooooooool0O?ooool00ooo003oooooooooo`2koooo
o`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo07[ooooo00?oo`00oooooooo
ool0_?ooool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1hooooo`03ool0
0?l0003ooooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0Mooo
ool00ooo003o0000ooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooo
oooo07Gooooo00?oo`00o`000?ooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1cooooo`03ool00?l0003ooooo0<3ooooo000Qooooo`03o`000?oooooooooo00co
oooo00?oo`00ooooooooool0LOooool00ooo003o0000ooooo`31ooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo073ooooo00?o0000ooooooooool0`Oooool0027ooooo0ol0
000>ooooo`03ool00?oooooooooo06kooooo00?o0000ooooooooool0`_ooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oo`00ooooo`1]ooooo`03o`000?oooooooooo0<?ooooo000Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`34oooo
o`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06Wooooo00?o0000oooooooo
ool0aOooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`37ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0b?ooool0027ooooo0ol0000Cooooo`03o`000?oooooooooo
06?ooooo00?oo`00ooooooooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Qooooo`03ool00?oooooooooo0<Wooooo000Qooooo`03o`000?oooooooooo01Gooooo
00?oo`00ooooooooool0Goooool00ooo003oooooooooo`3:ooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0boooool0027ooooo00?o0000
ooooooooool05oooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo0<cooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@04ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0F_ooool00ooo003ooooooooo
o`3=ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`1Hooooo`03ool00?oo
oooooooo0<kooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o00006Oooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo0<oooooo0007
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01[ooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`3@ooooo`001oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo01_ooooo00?oo`00ooooooooool0D_ooool00ooo003oooooooooo`3Aooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo053ooooo00?oo`00ooooooooool0d_ooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
7Oooool00ooo003oooooooooo`1>ooooo`03ool00?oooooooooo0=?ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`1;ooooo`;o0000e_ooool0027ooooo00?o0000ooooooooool07oooool00ooo003ooooooooo
o`19ooooo`03o`000?oooooooooo0=Kooooo000Qooooo`03o`000?oooooooooo023ooooo00?oo`00
ooooooooool0Aoooool00ol0003oooooooooo`3Gooooo`008Oooool3o`00027ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`3Hooooo`008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0fOooool0027ooooo00?o0000ooooooooool0
8oooool2o`00047ooooo0_l0003Looooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03gooooo0_oo003Mooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03_ooooo00?oo`00ooooooooool0gOooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0iooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02So
oooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`3Oooooo`008Oooool3o`0002Wooooo
0_oo000fooooo`03ool00?oooooooooo0>3ooooo000Qooooo`03o`000?oooooooooo02_ooooo00?o
o`00ooooooooool0<Oooool2ool00>?ooooo000Qooooo`03o`000?oooooooooo02cooooo0_oo000`
ooooo`03ool00?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?oo`00oooo
ooooool0:oooool2ool00>Kooooo000Qooooo`03o`000?oooooooooo02oooooo0_oo000Zooooo`03
ool00?oooooooooo0>Kooooo000Qooooo`03o`000?oooooooooo037ooooo0_oo000Vooooo`;oo`00
jOooool0027ooooo00?o0000ooooooooool0<oooool2ool002;ooooo0_l0003[ooooo`008Oooool0
0ol0003oooooooooo`0eooooo`03ool00?l0003o000001gooooo0_l0003]ooooo`008Oooool3o`00
03Sooooo0ol0000Hooooo`;o0000koooool0027ooooo00?o0000ooooooooool0>oooool4o`0000ko
oooo0ooo0003o`000?7ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o0000ool00?oo0000
2ooo0003o`000?Cooooo000Qooooo`03o`000?oooooooooo04;ooooo1ol0003kooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000H
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3
o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413o
gMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo
00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4
ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool0
1ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_oo
ool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00[ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo07?ooooo001koooo
o`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003ooooooooo
o`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^
kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?oMgMgoc8b<_oo
ool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03
o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<
ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOo
oooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000
ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0Mooo
ool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413o
k^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o
0000ooooooooool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0007Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34674 L
.10458 .38188 L
.12507 .39549 L
.14415 .40579 L
.16254 .41342 L
.17284 .41669 L
.18221 .41906 L
.18704 .42005 L
.19216 .42094 L
.19659 .42157 L
.20135 .42211 L
.20402 .42235 L
.20646 .42253 L
.20891 .42268 L
.21124 .42278 L
.21255 .42283 L
.21327 .42285 L
.21395 .42286 L
.21526 .42288 L
.21645 .4229 L
.21714 .4229 L
.21788 .4229 L
.21918 .42289 L
.21991 .42288 L
.22059 .42287 L
.22214 .42284 L
.2234 .4228 L
.22474 .42275 L
.22714 .42264 L
.22973 .42247 L
.23259 .42225 L
.2377 .42175 L
.24249 .42115 L
.25142 .41972 L
.26105 .41774 L
.28109 .41231 L
.30219 .40495 L
.34029 .38865 L
.38086 .36951 L
.4199 .35205 L
.43981 .34422 L
.4614 .33689 L
.48044 .3316 L
.49126 .32912 L
.50138 .32717 L
.51177 .32555 L
.52126 .3244 L
.52611 .32394 L
.5314 .32353 L
Mistroke
.5343 .32335 L
.53699 .32321 L
.53976 .32309 L
.5423 .323 L
.54478 .32294 L
.54602 .32292 L
.54739 .3229 L
.54811 .32289 L
.54877 .32288 L
.54952 .32288 L
.55024 .32288 L
.55151 .32288 L
.55223 .32288 L
.55289 .32288 L
.55408 .32289 L
.55519 .32291 L
.55642 .32293 L
.55773 .32296 L
.56041 .32303 L
.56286 .32312 L
.5672 .32332 L
.57194 .32361 L
.58148 .32439 L
.59178 .32552 L
.60113 .32679 L
.62209 .33029 L
.66213 .33857 L
.70065 .34658 L
.72017 .34997 L
.73052 .35147 L
.74162 .35282 L
.75228 .35382 L
.75734 .35419 L
.76202 .35447 L
.7667 .35469 L
.76917 .35478 L
.7718 .35486 L
.77407 .35491 L
.77511 .35493 L
.7762 .35495 L
.77743 .35496 L
.77855 .35497 L
.77975 .35497 L
.78107 .35497 L
.78239 .35497 L
.7836 .35496 L
.78424 .35495 L
.78494 .35495 L
.78635 .35492 L
.78892 .35487 L
Mistroke
.79133 .3548 L
.79583 .35463 L
.80066 .35437 L
.80627 .35399 L
.8116 .35354 L
.8216 .35248 L
.84142 .34953 L
.85981 .34587 L
.89896 .33553 L
.94057 .32184 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .34994 L
.10458 .3822 L
.12507 .3944 L
.14415 .40388 L
.16254 .41125 L
.18221 .41715 L
.19242 .41937 L
.19781 .42031 L
.20351 .42112 L
.2085 .42168 L
.21114 .42191 L
.21399 .42212 L
.21659 .42228 L
.21898 .42238 L
.22012 .42242 L
.22137 .42245 L
.22256 .42248 L
.22365 .42249 L
.22494 .4225 L
.22559 .4225 L
.2263 .4225 L
.22756 .42249 L
.22873 .42247 L
.22944 .42245 L
.23012 .42244 L
.23138 .4224 L
.23422 .42228 L
.2367 .42214 L
.23899 .42198 L
.24418 .4215 L
.24846 .421 L
.2532 .42032 L
.26278 .4186 L
.28213 .4137 L
.30299 .40654 L
.34413 .38818 L
.38375 .36806 L
.42186 .3497 L
.44311 .34093 L
.46242 .33426 L
.47206 .33146 L
.4825 .32886 L
.4923 .32683 L
.50147 .32529 L
.51093 .32408 L
.51595 .3236 L
.52134 .32319 L
.52404 .32303 L
.52698 .32289 L
Mistroke
.52976 .32278 L
.53109 .32275 L
.53234 .32272 L
.53356 .32269 L
.53421 .32269 L
.53489 .32268 L
.5361 .32267 L
.5372 .32266 L
.53848 .32266 L
.53967 .32267 L
.54098 .32268 L
.54172 .32269 L
.54238 .3227 L
.54468 .32275 L
.54721 .32282 L
.54985 .32293 L
.55232 .32305 L
.56151 .32367 L
.56673 .32414 L
.57151 .32464 L
.58228 .326 L
.62196 .33302 L
.66012 .34097 L
.68141 .3451 L
.70073 .3483 L
.71039 .34965 L
.72086 .35089 L
.73066 .35183 L
.73983 .3525 L
.74441 .35276 L
.74932 .35298 L
.75212 .35308 L
.75477 .35316 L
.75715 .35321 L
.75849 .35323 L
.75974 .35325 L
.76095 .35327 L
.76226 .35328 L
.76297 .35328 L
.76371 .35328 L
.76435 .35328 L
.76504 .35328 L
.76578 .35328 L
.76645 .35328 L
.76723 .35328 L
.76796 .35327 L
.76926 .35326 L
.77068 .35324 L
.77323 .3532 L
.77594 .35313 L
Mistroke
.7808 .35297 L
.78572 .35275 L
.79022 .35249 L
.80035 .35174 L
.80974 .35084 L
.81865 .3498 L
.85687 .3435 L
.87656 .33919 L
.89753 .33385 L
.93914 .32124 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo0000<?l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oo003ooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool3o`000003ooooool0003ooooo01;ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`04o`000?oo
ooooooooo`000?oooooo7?ooool2ool000;o00006_ooool2o`0000;ooooo0_l00004ooooo`008Ooo
ool01Ol0003ooooooooooooooooo00000?oooooo6?ooool3ool00003o`000?oooooooooo02Gooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0TOooool7ool000[o00001?oo
0004o`0006Oooooo0ooo0002o`0002Wooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Roooool7o`0001?ooooo1Ooo0006o`0005gooooo0ooo0002o`0002cooooo000Qoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0POooool5ool000Co00007oooool5ool0
0003ooooool0003o000000?o0000EOooool3ool000;o0000;oooool0027ooooo0ol00005ooooo`03
o`000?oooooooooo07gooooo0ooo0003o`0002[ooooo0_oo0004ooooo`Go0000C_ooool2ool000?o
0000<Oooool0027ooooo00?o0000ooooooooool01Oooool00ooo003o0000ooooo`1jooooo`?oo`00
0ol0000hooooo`Co0000BOooool3o`0003Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o
o`00o`000?ooool0M_ooool3ool000;o0000?Oooool6ool000;o0000?oooool5o`0003Oooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00o`000?ooool0M?ooool00ooo003o0000o`000016
ooooo`?oo`001Ol0000`ooooo`Koo`000ol0000looooo`008Oooool00ol0003oooooooooo`08oooo
o`03ool00?l0003o0000077ooooo00?o0000ool00?ooool0Boooool5ool000Ko00009?ooool6ool0
0003ooooool0003o000000;o0000@?ooool0027ooooo00?o0000ooooooooool02Oooool2ool00003
o`000?oooooooooo06cooooo0_l0001Cooooo`;oo`001?ooool5o`0001[ooooo1Ooo00000ooooooo
0000o`000004o`0004Cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool0
J_ooool2o`00063ooooo00?o0000ool00?oo00003_oo0006ooooo`Wo0000B_ooool0027ooooo0ol0
000<ooooo`03ool00?l0003ooooo06Kooooo0ol0001/ooooo`go0000Doooool0027ooooo00?o0000
ooooooooool03Oooool2ool00003o`000?oooooooooo063ooooo0_oo00000ol0003oooooooooo`3=
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo05kooooo0_oo00000ol0
003oooooooooo`3?ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?l0003ooooo05_o
oooo00?o0000ool00?l00000doooool0027ooooo00?o0000ooooooooool04Oooool00ooo003o0000
o`00001Hooooo`03o`000?oo003oo`000=Gooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Doooool00ol0003oo`00ool0003Gooooo`008Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo053ooooo0ooo003Iooooo`008Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04cooooo00?o0000ool00?oo0000g?ooool0027ooooo0ol0000Gooooo`;o
0000B_ooool2o`000003ool00?oooooooooo0=cooooo000Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0AOooool2o`000>7ooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo
0013ooooo`;o0000hoooool0027ooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0m
ooooo`?o0000iOooool0027ooooo00?o0000ooooooooool07Oooool2ool003_ooooo0_l0003Xoooo
o`008Oooool00ol0003oooooooooo`0Oooooo`;oo`00=oooool2o`0000;oo`00j?ooool0027ooooo
00?o0000ooooooooool08?ooool00ol0003oo`00ool0000booooo`?o00000_oo003Zooooo`008Ooo
ool3o`0002;ooooo00?o0000ool00?oo0000;_ooool2o`000003oooooooo003oo`000>cooooo000Q
ooooo`03o`000?oooooooooo02?ooooo0_l00003ool002Wooooo0_l00003ool00>kooooo000Qoooo
o`03o`000?oooooooooo02Kooooo0_l000000ooo003oooooooooo`0Tooooo`04o`000?oo003oo`00
ool00?7ooooo000Qooooo`03o`000?oooooooooo02Wooooo0ol0000Oooooo`03o`000?oo003oo`00
00;oo`00m?ooool0027ooooo00?o0000ooooooooool0;?ooool3o`0001Oooooo1Ol0003iooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0_ooooo`?o00001Ooo000:ooooo`Go0000o_ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo03?ooooo1?l0000<ool00?oooooo0_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodGooooo0007ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMg
Moooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^
k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b
<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool0
0onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVYoooo
o`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool0N?ooool007kooooo00Oo410@
omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RH
ob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko
0000ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`1jooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo
00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00O_ooool01?mE
EEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooooooo
o`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^
kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00O_ooool00ooMgMgo8B4Qonk^
kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnH
V9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@
413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Ooo
ool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgoooo
o`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00U_ooool00ol0003oooooooooo`07
ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@
41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0N_ooool009Kooooo00?o0000ooooooooool01oooool00onj^[[oA4A4ooooo`05ooooo`08ogMg
MomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`Booooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEE
ofIVI_l000003Oooool00omEEEGoIVIVo`00001looooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .3145 L
.06244 .31971 L
.08255 .32387 L
.08806 .32475 L
.09396 .32557 L
.09948 .3262 L
.10458 .32667 L
.10954 .32702 L
.11204 .32716 L
.1148 .32728 L
.11621 .32732 L
.11755 .32736 L
.1183 .32738 L
.1191 .32739 L
.11985 .3274 L
.12052 .32741 L
.12121 .32742 L
.12187 .32743 L
.12256 .32743 L
.1233 .32743 L
.12396 .32743 L
.12465 .32742 L
.12589 .32741 L
.12714 .3274 L
.12828 .32737 L
.13085 .3273 L
.13323 .32721 L
.13549 .32711 L
.14053 .32679 L
.14603 .32633 L
.15542 .32528 L
.1658 .32374 L
.18681 .31964 L
.22701 .30942 L
.2657 .29954 L
.28574 .29559 L
.29582 .29411 L
.30149 .29345 L
.30684 .29296 L
.31177 .29262 L
.31455 .29248 L
.31587 .29242 L
.31711 .29238 L
.31824 .29235 L
.31927 .29232 L
.32042 .2923 L
.32165 .29229 L
.32283 .29228 L
.32411 .29228 L
Mistroke
.32532 .29229 L
.32645 .2923 L
.32777 .29233 L
.32919 .29237 L
.33177 .29246 L
.33429 .29259 L
.3366 .29274 L
.34185 .29319 L
.3474 .29383 L
.3569 .29535 L
.36708 .29757 L
.38542 .30316 L
.4067 .31223 L
.42684 .3233 L
.46522 .35047 L
.50605 .3859 L
.54537 .42262 L
.58317 .45612 L
.60419 .47252 L
.62343 .48552 L
.64351 .49663 L
.66217 .50447 L
.67134 .50738 L
.68113 .50979 L
.68672 .51083 L
.69199 .5116 L
.69672 .5121 L
.69939 .51231 L
.70065 .51239 L
.70184 .51246 L
.70302 .51251 L
.7043 .51255 L
.70546 .51258 L
.70653 .5126 L
.70769 .51261 L
.70897 .51261 L
.70961 .5126 L
.71031 .5126 L
.71156 .51257 L
.71267 .51254 L
.71387 .51249 L
.7163 .51236 L
.71855 .5122 L
.72065 .51202 L
.72587 .51142 L
.73063 .51069 L
.7413 .50846 L
.75127 .50561 L
.76046 .50237 L
.78125 .49291 L
Mistroke
.82062 .46766 L
.85848 .43578 L
.89878 .39569 L
.93757 .35318 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .31783 L
.08255 .32215 L
.0932 .32407 L
.10458 .32572 L
.11009 .32635 L
.11531 .32682 L
.11999 .32716 L
.12263 .3273 L
.12507 .32741 L
.12616 .32745 L
.12734 .32749 L
.12836 .32751 L
.12947 .32754 L
.13077 .32756 L
.13201 .32757 L
.13321 .32757 L
.13433 .32757 L
.13561 .32756 L
.13682 .32755 L
.13791 .32753 L
.13908 .3275 L
.14172 .32742 L
.14415 .32731 L
.14885 .32703 L
.15389 .32662 L
.16298 .32558 L
.17378 .32391 L
.18364 .32199 L
.22348 .31151 L
.26181 .30033 L
.28159 .29555 L
.29157 .29364 L
.29694 .29278 L
.3026 .29201 L
.30742 .29148 L
.30997 .29125 L
.31269 .29104 L
.3152 .29088 L
.31748 .29077 L
.31858 .29072 L
.31978 .29068 L
.32082 .29065 L
.32194 .29063 L
.32324 .29061 L
.32445 .2906 L
.32519 .2906 L
.3259 .2906 L
.32721 .29061 L
.32789 .29062 L
Mistroke
.3286 .29064 L
.32988 .29067 L
.33141 .29072 L
.33279 .29078 L
.33527 .29091 L
.33795 .2911 L
.3428 .29155 L
.34773 .29216 L
.35233 .29288 L
.36278 .29503 L
.37296 .29782 L
.38385 .30158 L
.40514 .31116 L
.42527 .32281 L
.46365 .35089 L
.50448 .38643 L
.5438 .42231 L
.58161 .45462 L
.60262 .47044 L
.62186 .48308 L
.64194 .49405 L
.6606 .50197 L
.66977 .50501 L
.67956 .5076 L
.68515 .50878 L
.69042 .50968 L
.69515 .51033 L
.69763 .5106 L
.70028 .51084 L
.70284 .51102 L
.70518 .51114 L
.70631 .51119 L
.70754 .51123 L
.70869 .51126 L
.70977 .51127 L
.711 .51128 L
.71217 .51128 L
.71344 .51127 L
.71416 .51125 L
.71482 .51124 L
.71607 .5112 L
.71744 .51114 L
.72019 .51099 L
.72295 .51078 L
.72546 .51055 L
.7311 .50984 L
.73632 .50899 L
.74125 .508 L
.75095 .50553 L
.76124 .50219 L
Mistroke
.77968 .49435 L
.79923 .48358 L
.81754 .47134 L
.85633 .43934 L
.89757 .39818 L
.9373 .35412 L
.97551 .30981 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo05?ooooo00?o0000ool00?oo00002?oo0004o`000>;ooooo000Qooooo`03
o`000?oooooooooo04cooooo1ol0000?ooooo`Go00000ooo003Jooooo`008Oooool00ol0003ooooo
ooooo`17ooooo`;o00000_oo00000ol0003oooooooooo`0Jooooo`;o00000ooo003Gooooo`008Ooo
ool00ol0003oooooooooo`13ooooo`?o00000ooo000Rooooo`;o00000ooo003:ooooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`000?oooooooooo03oooooo0ol00004ool002Sooooo0_l00002
ool00<Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_oooom8o`0000Coo`00<?l0
0002ool00;?o000000?oo`00o`000?l000001Ol0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo
000Qooooo`03o`000?oooooooooo00?o00002Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool3o`0000?oo`002_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool2ool00003o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool00ooo
ool3o`0000?oo`000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool3o`000003ooooool0003ooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo003o0000
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q
8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00Kooooo0ol00005ool002Cooooo
0ol00013ooooo`;o0000Zoooool00ol0003oooooooooo`0Booooo`;o00000_ooool2o`0000Cooooo
000Qooooo`03o`000?oooooooooo00Wooooo1Ol00005ool001[ooooo00Go0000ool00?oo003oo`00
o`000018ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool07Oooool0027ooooo00?o
0000ooooooooool03_ooool5o`0000Coo`003_ooool6o`0000?oo`00COooool2o`000:Kooooo00?o
0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool04oooool>o`0000[oo`00D_ooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo
07kooooo0_l0002Qooooo`03o`000?oooooooooo023ooooo000Qooooo`?o0000Ooooool2ool00:3o
oooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0POooool00ooo003o0000
ooooo`2Kooooo`03ool00?l0003ooooo02;ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo
002Kooooo`03ool00?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo08Cooooo0_oo002H
ooooo`03ool00?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo08Kooooo00?oo`00oooo
ooooool0U?ooool00ooo003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`27ooooo`03
ool00?l0003ooooo09;ooooo00?oo`00ooooooooool09Oooool0027ooooo00?o0000ooooooooool0
R?ooool00ooo003o0000ooooo`2@ooooo`03ool00?oooooooooo02Kooooo000Qooooo`?o0000ROoo
ool00ooo003o0000ooooo`2?ooooo`03ool00?oooooooooo02Kooooo000Qooooo`03o`000?oooooo
oooo08[ooooo00?oo`00o`000?ooool0SOooool00ooo003oooooooooo`0Wooooo`008Oooool00ol0
003oooooooooo`2;ooooo`03ool00?l0003ooooo08_ooooo00?oo`00ooooooooool0:?ooool0027o
oooo00?o0000ooooooooool0SOooool2o`0008Wooooo00?oo`00ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0Soooool00ol0003oooooooooo`25ooooo`03ool00?oooooooooo02[ooooo
000Qooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0Poooool00ooo003ooooooooo
o`0[ooooo`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo087ooooo00?oo`00
ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo02gooooo000Qooooo`?o0000Toooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Cooooo`;oo`0000?o
0000ooooooooool0NOooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`2E
ooooo`03ool00?l0003ooooo07Sooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000oooo
ooooool0U_ooool00ooo003o0000ooooo`1fooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo09Oooooo00?oo`00o`000?ooool0M?ooool00ol0003oooooooooo`0cooooo`00
8Oooool00ol0003oooooooooo`2Hooooo`03ool00?l0003ooooo07;ooooo00?o0000ool00?ooool0
=?ooool0027ooooo0ol0002Iooooo`;oo`00LOooool00ol0003oo`00ooooo`0eooooo`008Oooool0
0ol0003oooooooooo`2Kooooo`03ool00?oooooooooo06gooooo00?o0000ool00?ooool0=_ooool0
027ooooo00?o0000ooooooooool0W?ooool00ooo003oooooooooo`1[ooooo`03o`000?oo003ooooo
03Oooooo000Qooooo`03o`000?oooooooooo09gooooo00?oo`00ooooooooool0JOooool00ol0003o
o`00ooooo`0hooooo`008Oooool00ol0003oooooooooo`2Nooooo`03ool00?oooooooooo06Oooooo
00?o0000ool00?ooool0>Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0Woooool00ooo003o
ooooooooo`1Uooooo`03o`000?oo003ooooo03[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2Pooooo`;o
0000I?ooool00ol0003oo`00ooooo`0kooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:;ooooo00?o0000ooooooooool0H?ooool00ol0003o
o`00ooooo`0looooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo05kooooo00?o0000ool00?oo
ool0?Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo05cooooo00?o0000ool0
0?ooool0?_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`1Iooooo`;o000000?oo`00oooo
ooooool0?_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Y_ooool2o`0005Sooooo00?o0000ooooooooool0@Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Woooo
o`;oo`00E_ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`2Yooooo`03
ool00?oooooooooo05;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool0
Z_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo04Cooooo000Qooooo`?o0000Zooo
ool00ooo003oooooooooo`1=ooooo`;o0000Aoooool0027ooooo00?o0000ooooooooool0[?ooool2
ool004cooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0[_ooool00ooo
003oooooooooo`18ooooo`;oo`00BOooool0027ooooo00?o0000ooooooooool0[oooool00ooo003o
0000ooooo`16ooooo`03ool00?oooooooooo04Wooooo000Qooooo`03o`000?oooooooooo0;3ooooo
00?oo`00o`000?ooool0A?ooool00ooo003oooooooooo`1:ooooo`008Oooool00ol0003ooooooooo
o`2aooooo`03ool00?l0003ooooo047ooooo00?o0000ool00?ooool0C?ooool0027ooooo00?o0000
ooooooooool0/_ooool2ool00003o`000?oooooooooo03gooooo0_oo001>ooooo`008Oooool3o`00
0;Cooooo00?oo`00o`000?ooool0>oooool00ol0003oo`00ooooo`1?ooooo`008Oooool00ol0003o
ooooooooo`2fooooo`;o0000>Oooool00ol0003oo`00ooooo`1@ooooo`008Oooool00ol0003ooooo
ooooo`2hooooo`03o`000?oooooooooo03Cooooo0_l000000ooo003oooooooooo`1@ooooo`008Ooo
ool00ol0003oooooooooo`2iooooo`;o0000<oooool00ol0003oo`00ool0001Cooooo`008Oooool0
0ol0003oooooooooo`2kooooo`03o`000?oooooooooo02kooooo0_l000000ooo003oooooooooo`1C
ooooo`008Oooool00ol0003oooooooooo`2looooo`03o`000?oo003ooooo02cooooo00?o0000oooo
ooooool0E_ooool0027ooooo00?o0000ooooooooool0__ooool2ool002Wooooo0_l0001Iooooo`00
8Oooool00ol0003oooooooooo`2oooooo`03o`000?oo003oo`0002Cooooo0ol0001Kooooo`008Ooo
ool3o`000<;ooooo0_oo00000ol0003oooooooooo`0Mooooo`;o0000G_ooool0027ooooo00?o0000
ooooooooool0a?ooool3ool00003o`000?oooooooooo01Sooooo0ooo001Oooooo`008Oooool00ol0
003oooooooooo`37ooooo`Goo`004Oooool5ool006;ooooo000Qooooo`03o`000?oooooooooo0<_o
oooo00?o0000ool00?l000002?ooool7ool000;o0000IOooool0027ooooo00?o0000ooooooooool0
c_ooool<o`0006[ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0
003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEE
EOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Co
oooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo
00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo
001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_o
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRH
V?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4oooooooooooo
QhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`1dooooo`00Noooool01ol@413ogMgMogMg
MolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`000?oooooogMgMoc8b<_oooooo
k^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2ogMgM`Ko
oooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`00
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoooooo00000_ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^oa0@4?o^k^h01Oooool0
0olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001?oo
ool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Kooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool0
1?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?oo
ool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo0000
0oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool0
1?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMg
oeEEE@0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?o
gMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd0
5oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomV
IVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Gooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .28407 L
.10458 .25647 L
.14415 .23164 L
.18221 .21149 L
.20178 .20371 L
.21274 .20037 L
.21758 .19916 L
.22272 .19807 L
.22745 .19724 L
.22997 .19687 L
.23267 .19653 L
.23515 .19627 L
.23742 .19608 L
.2397 .19593 L
.24081 .19588 L
.24186 .19583 L
.24317 .19579 L
.24436 .19577 L
.24563 .19575 L
.24635 .19575 L
.24702 .19575 L
.24813 .19577 L
.24934 .1958 L
.25061 .19584 L
.2518 .19589 L
.25454 .19607 L
.25703 .19628 L
.25992 .1966 L
.26265 .19698 L
.26724 .19777 L
.2723 .19887 L
.28256 .20187 L
.29206 .20557 L
.30098 .20986 L
.32116 .22248 L
.33966 .23753 L
.37929 .27995 L
.4174 .33086 L
.45796 .3902 L
.497 .44592 L
.5385 .49726 L
.5593 .51843 L
.57848 .5348 L
.59836 .54837 L
.61695 .5579 L
.62599 .56142 L
.63571 .5644 L
.64124 .56573 L
.6465 .56674 L
Mistroke
.65121 .56745 L
.65389 .56777 L
.65635 .56801 L
.65891 .5682 L
.66023 .56828 L
.66168 .56835 L
.66294 .5684 L
.66412 .56843 L
.66536 .56845 L
.66606 .56846 L
.6667 .56846 L
.6679 .56846 L
.669 .56844 L
.67022 .56841 L
.67151 .56837 L
.67263 .56832 L
.67368 .56827 L
.67606 .56811 L
.67863 .5679 L
.68134 .56761 L
.68617 .56695 L
.69137 .56604 L
.69705 .56482 L
.70735 .56197 L
.7167 .55873 L
.73766 .54927 L
.7777 .52363 L
.81621 .49104 L
.85719 .44981 L
.89664 .4055 L
.93458 .36018 L
.97497 .31052 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .28165 L
.10458 .25635 L
.14415 .23311 L
.18221 .21278 L
.20178 .20445 L
.21267 .20076 L
.22272 .19809 L
.22758 .19707 L
.23293 .19618 L
.23553 .19583 L
.23832 .19552 L
.23985 .19538 L
.24126 .19526 L
.2426 .19518 L
.24402 .1951 L
.24536 .19504 L
.24658 .19501 L
.24781 .19499 L
.24896 .19498 L
.24961 .19498 L
.25031 .19499 L
.25155 .19501 L
.25224 .19503 L
.25288 .19505 L
.25435 .19511 L
.25562 .19518 L
.25683 .19527 L
.25908 .19546 L
.26152 .19573 L
.26416 .19608 L
.26901 .19692 L
.27356 .19793 L
.28394 .20104 L
.29405 .20516 L
.30494 .21083 L
.32498 .22451 L
.34608 .24326 L
.38419 .28677 L
.42475 .34253 L
.4638 .39954 L
.5053 .45708 L
.54528 .50409 L
.58374 .53802 L
.60362 .5506 L
.61377 .55568 L
.62466 .56012 L
.63489 .56334 L
.64424 .56549 L
.64873 .56626 L
Mistroke
.65111 .56659 L
.65363 .5669 L
.65606 .56715 L
.65826 .56733 L
.66047 .56747 L
.66255 .56756 L
.66372 .5676 L
.66497 .56763 L
.66615 .56765 L
.66722 .56765 L
.66848 .56764 L
.66919 .56764 L
.66985 .56762 L
.67106 .56759 L
.67234 .56755 L
.67488 .56742 L
.67725 .56725 L
.67986 .56702 L
.68267 .56671 L
.68737 .56605 L
.69232 .56518 L
.70115 .56318 L
.71072 .56038 L
.72093 .5567 L
.73931 .54834 L
.78086 .52197 L
.8209 .48802 L
.85942 .44886 L
.90039 .4021 L
.93984 .35429 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0mooooo`Ooo`001Ol0003kooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`?o00000ooo000<ooooo`Co00000_oo
003eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0dooooo`?o00000ooo000Dooooo`04o`000?oo003oo`00ool00?;ooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
<_ooool2o`0000?oo`006_ooool00ol0003oo`00ool0003`ooooo`008Oooool00ol0003ooooooooo
o`0`ooooo`;o00008_ooool00ooo003o0000ooooo`3]ooooo`008Oooool00ol0003oooooooooo`0^
ooooo`;o00009Oooool2ool00>gooooo000Qooooo`?o0000;?ooool2o`0002Wooooo00?oo`00o`00
0?ooool0j_ooool0027ooooo00?o0000ooooooooool0:_ooool2o`0002cooooo0_oo003Zooooo`00
8Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo003oo`0002oooooo00?oo`00o`000?ooool0
ioooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oo`00ool0000booooo`03ool00?l0
003ooooo0>Kooooo000Qooooo`03o`000?oooooooooo02Cooooo0_l000000ooo003oooooooooo`0d
ooooo`03o`000?oooooooooo0>Cooooo000Qooooo`03o`000?oooooooooo02;ooooo0_l00002ool0
03Sooooo00?o0000ooooooooool0hoooool0027ooooo00?o0000ooooooooool08Oooool00ol0003o
o`00ool0000kooooo`03o`000?oooooooooo0>;ooooo000Qooooo`?o00007oooool00ol0003oo`00
ool0000nooooo`03o`000?oooooooooo0>7ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o
0000ool00?ooool0?oooool00ol0003oooooooooo`3Qooooo`008Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oo003oo`0004;ooooo00?o0000ooooooooool0h?ooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oo`00ooooo`14ooooo`03o`000?oo003ooooo0=oooooo000Qooooo`03
o`000?oooooooooo01Wooooo0_l00018ooooo`03ool00?oooooooooo0=kooooo000Qooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`3Mooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`;o0000COooool00ooo003oooooooooo`3Looooo`008Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool0foooool0
027ooooo0ol0000Booooo`;oo`0000?o0000ooooooooool0D?ooool00ooo003oooooooooo`3Joooo
o`008Oooool00ol0003oooooooooo`0@ooooo`;oo`0000?o0000ooooooooool0:?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool0
0ooo003oooooooooo`0Uooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?oo`00o`000?l00000:oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?oo`00o`000?ooool09ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003ooooooooo
o`0=ooooo`;oo`0000?o0000ooooooooool0:oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool05?ooool00ooo003o0000ooooo`0Vooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo00_ooooo0_oo00000ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`03ool00?l0003ooooo02Gooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo
00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool02_ooool00ooo003o0000o`00
000`ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01So
oooo00?oo`00o`000?ooool09?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?oo`00o`000?ooool0<Oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo000Qooooo`?o00002?ooool00ooo003o0000ooooo`0booooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo02;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000okZj
^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo
03Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00007?ooool00ol0003oooooooooo`0O
ooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003kooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003o
oooo06Oooooo00?o0000ooooooooool0d_ooool0027ooooo00?o0000ooooooooool00oooool2o`00
06[ooooo00?o0000ooooooooool0d_ooool0027ooooo00Co0000oooooooooooooooo0_l0001]oooo
o`03o`000?oooooooooo0=7ooooo000Qooooo`04o`000?ooooooooooo`00073ooooo00?o0000oooo
ooooool0a_ooool2o`0000;ooooo0_l00004ooooo`008Oooool3o`0007;ooooo00?o0000oooooooo
ool0aOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<oooo
o`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool2o`0000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`;o00004oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0_l0000Cooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qoooo
o`03o`000?oooooooooo07Cooooo00?oo`00o`000?ooool0[_ooool00ooo003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00oooooooo
ool0[?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`1fooooo`03ool0
0?oooooooooo0:[ooooo00?o0000ool00?ooool07_ooool0027ooooo00?o0000ooooooooool0Mooo
ool00ooo003oooooooooo`2Xooooo`03o`000?oo003ooooo01oooooo000Qooooo`03o`000?oooooo
oooo07Sooooo00?oo`00ooooooooool0Yoooool00ooo003oooooooooo`0Oooooo`008Oooool3o`00
07Sooooo00?oo`00ooooooooool0Y_ooool00ooo003oooooooooo`0Pooooo`008Oooool00ol0003o
ooooooooo`1iooooo`03ool00?oooooooooo0:Cooooo00?oo`00ooooooooool08Oooool0027ooooo
00?o0000ooooooooool0N_ooool00ooo003oooooooooo`2Rooooo`03ool00?oooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ool00?ooool0XOooool00ooo003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`1kooooo`03ool00?oooooooooo09oooooo00?oo`00
o`000?ooool09?ooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`2Moooo
o`03ool00?l0003ooooo02Gooooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000ool00?oo
ool0W?ooool00ooo003o0000ooooo`0Vooooo`008Oooool3o`0007gooooo00?o0000ooooooooool0
Voooool00ooo003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo09Wooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Xooooo`008Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo02[ooooo
000Qooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0T_ooool00ol0003ooooooooo
o`0[ooooo`008Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo093ooooo00?o0000
ooooooooool0;?ooool0027ooooo0ol00023ooooo`03ool00?oooooooooo08kooooo00?o0000oooo
ooooool0;Oooool0027ooooo00?o0000ooooooooool0Poooool00ooo003oooooooooo`2>ooooo`03
ool00?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08Cooooo00?oo`00ooooooooool0
S?ooool00ooo003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`25ooooo`03ool00?oo
oooooooo08[ooooo00?oo`00ooooooooool0;oooool0027ooooo00?o0000ooooooooool0QOooool0
0ooo003oooooooooo`29ooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo
08Kooooo00?oo`00ooooooooool0Qoooool00ooo003oooooooooo`0aooooo`008Oooool00ol0003o
ooooooooo`27ooooo`03ool00?oooooooooo08Gooooo00?oo`00ooooooooool0<_ooool0027ooooo
0ol00027ooooo`03ool00?oooooooooo08Cooooo00?o0000ool00?ooool0<oooool0027ooooo00?o
0000ooooooooool0R?ooool00ooo003oooooooooo`23ooooo`03ool00?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo08Wooooo00?oo`00ooooooooool0POooool00ooo003oooooooooo`0d
ooooo`008Oooool00ol0003oooooooooo`2:ooooo`03ool00?oooooooooo07oooooo00?oo`00oooo
ooooool0=Oooool0027ooooo00?o0000ooooooooool0R_ooool00ooo003oooooooooo`1nooooo`03
ool00?oooooooooo03Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo08_ooooo00?oo`00oooo
ooooool0O?ooool00ooo003oooooooooo`0gooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0S?ooool00ooo
003oooooooooo`1jooooo`03o`000?oooooooooo03Sooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000S?ooool00ol0003oooooooooo`1ioooo
o`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0jooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo03cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000
ooooooooool0T?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo03gooooo000Qoooo
o`03o`000?oooooooooo097ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0noooo
o`008Oooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo06kooooo0_oo0010ooooo`00
8Oooool3o`0009;ooooo00?o0000ool00?ooool0K?ooool00ol0003oo`00ooooo`10ooooo`008Ooo
ool00ol0003oooooooooo`2Cooooo`03ool00?oooooooooo06[ooooo00?o0000ool00?ooool0@Ooo
ool0027ooooo00?o0000ooooooooool0U?ooool00ooo003oooooooooo`1Xooooo`03o`000?oo003o
oooo04;ooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00o`000?ooool0Ioooool00ol0
003oo`00ooooo`13ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo06Go
oooo00?o0000ool00?ooool0A?ooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003ooooo
ooooo`1Sooooo`03o`000?oo003ooooo04Gooooo000Qooooo`03o`000?oooooooooo09Oooooo00?o
o`00ooooooooool0HOooool00ol0003oo`00ooooo`16ooooo`008Oooool3o`0009Sooooo00?oo`00
ooooooooool0Goooool00ol0003oo`00ooooo`17ooooo`008Oooool00ol0003oooooooooo`2Ioooo
o`03ool00?oooooooooo05gooooo00?o0000ool00?ooool0B?ooool0027ooooo00?o0000oooooooo
ool0V_ooool00ooo003oooooooooo`1Kooooo`03o`000?oo003ooooo04Wooooo000Qooooo`03o`00
0?oooooooooo09[ooooo00?o0000ool00?ooool0F_ooool00ol0003oo`00ooooo`1:ooooo`008Ooo
ool00ol0003oooooooooo`2Kooooo`03o`000?oo003ooooo05Sooooo00?o0000ooooooooool0Booo
ool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oo`00ooooo`1Eooooo`;o0000C_ooool0
027ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
04kooooo000Qooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`1?ooooo`008Oooool3o`0009oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`1@ooooo`008Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`1:
ooooo`03o`000?oo003ooooo05?ooooo000Qooooo`03o`000?oooooooooo0:;ooooo00?o0000oooo
ooooool0B?ooool00ol0003oo`00ooooo`1Dooooo`008Oooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo04Kooooo00?o0000ool00?ooool0EOooool0027ooooo00?o0000ooooooooool0
Y?ooool2ool004Gooooo00?o0000ool00?ooool0E_ooool0027ooooo00?o0000ooooooooool0YOoo
ool00ol0003oo`00ooooo`12ooooo`03o`000?oo003ooooo05Oooooo000Qooooo`?o0000Yoooool0
0ooo003oooooooooo`0nooooo`03o`000?oo003oo`0005Wooooo000Qooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0??ooool2ool005_ooooo000Qooooo`03o`000?oooooooooo0:Wo
oooo00?oo`00ooooooooool0>Oooool00ol0003oo`00ooooo`1Looooo`008Oooool00ol0003ooooo
ooooo`2Zooooo`03ool00?oooooooooo03Kooooo00?o0000ool00?oo0000G_ooool0027ooooo00?o
0000ooooooooool0Zoooool00ooo003o0000ooooo`0dooooo`03o`000?oo003ooooo05oooooo000H
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`2/ooooo`;oo`00<_ooool2
o`0006;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[_ooool00ooo
003o0000ooooo`0]ooooo`;o0000I?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2_ooooo`03ool00?l0003ooooo02_ooooo00?o0000ooooooooool0I?ooool001[ooooo
00?o0000ooooooooool01?ooool3o`000;3ooooo00?oo`00o`000?l00000:?ooool2o`0006Oooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool2o`0002Cooooo0_l0
001Yooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Gooooo0_l0000P
ooooo`03o`000?oo003oo`0006[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0]oooool2o`0001cooooo00?o0000ool00?oo0000K?ooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`2iooooo`03o`000?oo003oo`0001Kooooo00Co0000ool00?oo
003oo`00K_ooool0027ooooo00?o0000ooooooooool0_?ooool5ool000gooooo1Ooo001aooooo`00
8Oooool00ol0003oooooooooo`2nooooo`?o000000?oo`00o`000?l000001_l00004ool00003o`00
0?oooooooooo07?ooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002Xooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIV
ogMgMoooool0Xoooool008Oooooo0ol0000Cooooo`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@
4?o^k^h06?ooool00oo^k^ko410@omgMg@2Sooooo`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000
oc8b<_o^k^h00oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_oo
ool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnHV9Soooooooooo`Go00002Oooool00omEEEGoZJVY
ooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo00?oQhN7ofIVI_ooool04oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000Noooool007kooooo00Oo410@omgMgOmgMgOo8B4Q
oooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^kooooo
odA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;oooo
o`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A407_ooooo001nooooo`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_oo
ool00onHV9So8B4Qonk^kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^07cooooo001nooooo`04oeEEEOnY
ZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Go
oooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_o
oooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0
003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^07_ooooo001nooooo`03omgMgOlQ8B7ok^k^00?o
oooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?oEEEEoiRHV?oo
ool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oo
oooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00gooooo00?oMgMgofIV
I_ooool0N_ooool007oooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0=ooooo`03
oa0@4?l0003o000000?o00001Oooool00ooMgMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Go
oooo00?o0000ooooooooool02?ooool7o`0000;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07Wooooo002Fooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400B
ooooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonH
V9So410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool0
2?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03
oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01kooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .24805 L
.10458 .1896 L
.12507 .16639 L
.14415 .1488 L
.16254 .13606 L
.17284 .13087 L
.18221 .12743 L
.18704 .12614 L
.18969 .12558 L
.19216 .12514 L
.19445 .12482 L
.19654 .12459 L
.19765 .12449 L
.19886 .12441 L
.20014 .12434 L
.20135 .1243 L
.20203 .12429 L
.20276 .12428 L
.20345 .12428 L
.20409 .12429 L
.2053 .12432 L
.20657 .12438 L
.20723 .12441 L
.20794 .12446 L
.20922 .12456 L
.21213 .12489 L
.21482 .1253 L
.21737 .12579 L
.22214 .12696 L
.22673 .12839 L
.23179 .13033 L
.24205 .13538 L
.26047 .14811 L
.27981 .16624 L
.30067 .19061 L
.34181 .24964 L
.38143 .31309 L
.41954 .37239 L
.4601 .42715 L
.49915 .46818 L
.5205 .4853 L
.54065 .49803 L
.55037 .50301 L
.56066 .50748 L
.5703 .51095 L
.57911 .51352 L
.58855 .51567 L
.5934 .51653 L
.59869 .51729 L
Mistroke
.60356 .51783 L
.60593 .51804 L
.60808 .5182 L
.61016 .51832 L
.6124 .51842 L
.61364 .51846 L
.61477 .51849 L
.61586 .51852 L
.617 .51853 L
.61823 .51854 L
.61892 .51854 L
.61956 .51854 L
.62073 .51853 L
.62197 .51851 L
.62309 .51848 L
.62413 .51845 L
.6265 .51836 L
.62906 .51822 L
.6314 .51806 L
.63668 .51759 L
.64095 .51709 L
.64562 .51644 L
.65502 .51477 L
.67467 .50987 L
.69564 .50273 L
.73719 .48364 L
.77722 .46033 L
.81574 .43454 L
.85671 .40451 L
.89617 .37386 L
.93411 .34338 L
.9745 .3104 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25198 L
.10458 .19094 L
.12507 .16576 L
.14415 .14666 L
.16254 .13303 L
.16783 .13006 L
.17284 .12765 L
.17768 .1257 L
.18221 .12421 L
.18682 .12304 L
.18927 .12256 L
.1919 .12215 L
.19322 .12199 L
.19466 .12185 L
.19601 .12174 L
.19727 .12167 L
.19852 .12162 L
.19965 .1216 L
.20095 .12161 L
.20218 .12164 L
.20325 .12168 L
.20443 .12175 L
.20565 .12185 L
.2068 .12196 L
.20884 .12221 L
.21104 .12255 L
.21605 .12363 L
.22062 .12495 L
.23054 .12891 L
.23971 .13388 L
.26047 .14942 L
.27913 .16793 L
.29973 .19252 L
.33994 .24927 L
.37862 .30891 L
.41976 .37076 L
.45939 .42348 L
.4975 .46454 L
.51875 .48266 L
.53806 .49601 L
.55814 .50675 L
.5771 .514 L
.58682 .51666 L
.59214 .51782 L
.59712 .51871 L
.60171 .51939 L
.6059 .51987 L
.61056 .52027 L
.61313 .52042 L
Mistroke
.61557 .52053 L
.61682 .52057 L
.61748 .52058 L
.61817 .5206 L
.61944 .52062 L
.62061 .52062 L
.62174 .52062 L
.62279 .52061 L
.62395 .52059 L
.62518 .52056 L
.6265 .52052 L
.62793 .52046 L
.63054 .52032 L
.63307 .52015 L
.63541 .51995 L
.64434 .51889 L
.64885 .51817 L
.65381 .51725 L
.6732 .51236 L
.69407 .505 L
.73526 .48518 L
.77494 .46103 L
.8131 .43471 L
.85371 .40468 L
.89281 .37465 L
.93436 .34205 L
.97439 .31042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`0`ooooo`_oo`00ooooool:ooooo`008Ooo
ool00ol0003oooooooooo`0^ooooo`;oo`002ol00003ool00?oooooo1oooool0027ooooo00?o0000
ooooooooool0;_ooool2o`0000_ooooo0ol000000ooo003oooooooooo`3oooooo`Cooooo000Qoooo
o`03o`000?oooooooooo02_ooooo0ol0000@ooooo`?o0000ooooool4ooooo`008Oooool00ol0003o
ooooooooo`0Xooooo`?o00005_ooool3o`000?oooooo0Oooool0027ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?gooooo000Qooooo`?o00009Ooo
ool00ooo003o0000ooooo`0Mooooo`03o`000?oooooooooo0?cooooo000Qooooo`03o`000?oooooo
oooo02Cooooo00?oo`00ooooooooool07oooool00ol0003oooooooooo`3kooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0n_ooool0027o
oooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`0Rooooo`;oo`00noooool0027ooooo
00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo0?Sooooo
000Qooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`3gooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo02Wooooo00?oo`00
ooooooooool0m_ooool0027ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0[oooo
o`03ool00?oooooooooo0?Gooooo000Qooooo`?o00007Oooool00ooo003oooooooooo`0]ooooo`03
ool00?oooooooooo0?Cooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00o`000?ooool0
;_ooool00ooo003o0000ooooo`3dooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?l0
003ooooo033ooooo00?oo`00o`000?ooool0loooool0027ooooo00?o0000ooooooooool06_ooool0
0ooo003o0000ooooo`0booooo`03ool00?l0003ooooo0?;ooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0<oooool00ooo003o0000ooooo`3aooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Gooooo00?oo`00o`000?ooool0l?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3^
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o00005oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0>gooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`3]ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`3/ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0joooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0>_ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04oooool00ooo003ooooooooo
o`11ooooo`03o`000?oooooooooo0>[ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00
ooooooooool0@_ooool00ol0003oooooooooo`3Yooooo`008Oooool00ol0003oooooooooo`0Boooo
o`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0jOooool0027ooooo0ol0000Aooooo`03
ool00?oooooooooo04Cooooo00?oo`00o`000?ooool0jOooool0027ooooo00?o0000ooooooooool0
4?ooool00ol0003oo`00ooooo`16ooooo`03ool00?l0003ooooo0>Sooooo000Qooooo`03o`000?oo
oooooooo013ooooo00?oo`00ooooooooool0Aoooool00ooo003o0000ooooo`3Wooooo`008Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo04Sooooo00?oo`00o`000?ooool0ioooool0
027ooooo00?o0000ooooooooool03_ooool00ol0003oo`00ooooo`1:ooooo`03ool00?l0003ooooo
0>Kooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000ool00?ooool0C?ooool00ooo003o
0000ooooo`3Uooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?ooooooo`0004gooooo
00?oo`00o`000?ooool0iOooool0027ooooo0ol0000<ooooo`03o`000?oo003ooooo04kooooo00?o
o`00o`000?ooool0i?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooool0001@
ooooo`03ool00?l0003ooooo0>?ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
oooo0000DOooool00ooo003o0000ooooo`3Sooooo`008Oooool00ol0003oooooooooo`09ooooo`03
o`000?ooooooo`0005?ooooo00?oo`00o`000?ooool0h_ooool0027ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Dooooo`03ool00?l0003ooooo0>7ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`3Pooooo`008Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0goooool0
027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
0=kooooo000Qooooo`?o00001_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo0=ko
oooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04Oooool00ol0
003oooooooooo`0Yooooo`Co000000?o410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo013ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo03cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^
kP0Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oo003ooooo03Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0
0_ooool00ol0003oo`00ooooo`0hooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo02Sooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo
0ol00002ooooo`03ool00?oooooooooo03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo01Kooooo00?oo`00ooooooooool0:?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@
01_ooooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000Fooooo`03ool00?oooooooooo02Gooooo00?oEEEEofIVI_l00000?ooo
ool00omEEEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo
000Qooooo`05o`000?ooooooooooo`000?oo0000Ioooool00ooo003oooooooooo`3Hooooo`008Ooo
ool01?l0003ooooooooooooo001Xooooo`03ool00?oooooooooo0=Sooooo000Qooooo`03o`000?oo
ooooo`0006[ooooo00?oo`00ooooooooool0eoooool0027ooooo00?o0000oooooooo0000J_ooool0
0ooo003oooooooooo`3=ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oo003ooooo
06_ooooo00?oo`00ooooooooool0c?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000J
ooooo`Oo000000?oo`00o`000?l00000K?l000000ooo003o0000o`00002ho`000003ool00?l0003o
000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oo`00o`00000C
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`000?oo003oooooo`0001?ooooo00Co
8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oo`00oooo
o`2cooooo`03o`000?oo003ooooo01Cooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ooooooooool0K_ooool00ooo003oooooooooo`2aooooo`03o`000?oooooooooo01oooooo000Qoooo
o`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0[oooool00ol0003oooooooooo`0Poooo
o`008Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0:gooooo0_l0000Sooooo`00
8Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0
8oooool0027ooooo0ol0001aooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09?oo
ool0027ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`2Wooooo`03ool00?l0003o
oooo02Kooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Y_ooool00ooo
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0:?o
oooo0_oo000Yooooo`008Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo0:;ooooo
00?oo`00ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0M?ooool00ol0003ooooooooo
o`2Pooooo`03ool00?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo07Gooooo00?oo`00
ooooooooool0WOooool2ool002gooooo000Qooooo`?o0000MOooool00ooo003oooooooooo`2Loooo
o`03ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00oooooooo
ool0VOooool2ool00003o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo07Oooooo
00?oo`00ooooooooool0Uoooool00ooo003o0000ooooo`0`ooooo`008Oooool00ol0003ooooooooo
o`1gooooo`03ool00?oooooooooo09Kooooo00?oo`00o`000?ooool0<Oooool0027ooooo00?o0000
ooooooooool0N?ooool00ooo003oooooooooo`2Dooooo`03ool00?l0003ooooo03;ooooo000Qoooo
o`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0Toooool00ol0003oooooooooo`0boooo
o`008Oooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo097ooooo0_l0000eooooo`00
8Oooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool0027ooooo0ol0001kooooo`03ool00?oooooooooo08cooooo0_l0000hooooo`008Oooool0
0ol0003oooooooooo`1looooo`03ool00?oooooooooo08[ooooo00?o0000ooooooooool0>?ooool0
027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`28ooooo`;o0000>oooool0027o
oooo00?o0000ooooooooool0OOooool00ooo003oooooooooo`25ooooo`;oo`00?Oooool0027ooooo
00?o0000ooooooooool0O_ooool00ooo003oooooooooo`23ooooo`03ool00?l0003ooooo03gooooo
000Qooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0POooool00ooo003o0000oooo
o`0nooooo`008Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?oo`00
ooooooooool0?oooool0027ooooo0ol00020ooooo`03o`000?oooooooooo07gooooo0_oo0012oooo
o`008Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo07_ooooo00?oo`00oooooooo
ool0@_ooool0027ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`1hooooo`;oo`00
AOooool0027ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1fooooo`03ool00?l0
003ooooo04Gooooo000Qooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0MOooool0
0ooo003o0000ooooo`16ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`24ooooo`03o`000?oo
oooooooo07?ooooo00?oo`00o`000?ooool0Aoooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo08Gooooo00?o
o`00ooooooooool0LOooool00ol0003oooooooooo`18ooooo`001oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008Kooooo00?oo`00ooooooooool0Kooo
ool00ol0003oooooooooo`19ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`26ooooo`03o`000?oo003ooooo06kooooo00?o
0000ooooooooool0B_ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`27ooooo`03o`000?oo003ooooo06cooooo
00?o0000ooooooooool0Boooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0R?ooool00ol0003oo`00ooooo`1Yooooo`;o0000
C_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ROooool00ol0003oo`00ooooo`1Wooooo`03o`000?oooooooooo04kooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0
R_ooool00ol0003oo`00ooooo`1Sooooo`;oo`0000?o0000ooooooooool0Coooool0027ooooo00?o
0000ooooooooool0Roooool00ol0003oo`00ooooo`1Qooooo`03ool00?l0003ooooo05;ooooo000Q
ooooo`03o`000?oooooooooo08cooooo00?o0000ool00?ooool0G_ooool2ool00003o`000?oooooo
oooo05;ooooo000Qooooo`?o0000SOooool00ol0003oo`00ooooo`1Looooo`03ool00?l0003ooooo
05Gooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ool00?ooool0FOooool2ool00003
o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ool00?ooool0
Eoooool00ooo003o0000ooooo`1Hooooo`008Oooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo05Cooooo0_oo00000ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`2A
ooooo`03o`000?oooooooooo057ooooo0_oo00000ol0003oooooooooo`1Jooooo`008Oooool00ol0
003oooooooooo`2Booooo`;o0000D?ooool00ooo003o0000ooooo`1Mooooo`008Oooool00ol0003o
ooooooooo`2Dooooo`03o`000?oooooooooo04_ooooo0_l0001Pooooo`008Oooool3o`0009Gooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003ooooooooo
o`2Fooooo`03o`000?oooooooooo04Kooooo0_l0001Sooooo`008Oooool00ol0003oooooooooo`2G
ooooo`03o`000?oo003ooooo04?ooooo0_l0001Uooooo`008Oooool00ol0003oooooooooo`2Hoooo
o`;oo`00@Oooool2o`0006Oooooo000Qooooo`03o`000?oooooooooo09[ooooo00?oo`00o`000?oo
ool0??ooool00ol0003oo`00ool0001Xooooo`008Oooool00ol0003oooooooooo`2Kooooo`;oo`00
>_ooool00ol0003oo`00ool0001Zooooo`008Oooool00ol0003oooooooooo`2Mooooo`03ool00?l0
003ooooo03Cooooo0_l00002ool006cooooo000Qooooo`03o`000?oooooooooo09kooooo0_oo0000
0ol0003oooooooooo`0_ooooo`;o00000_oo001^ooooo`008Oooool3o`000:3ooooo0_oo000^oooo
o`;o00000_oo001`ooooo`008Oooool00ol0003oooooooooo`2Rooooo`;oo`0000?o0000oooooooo
ool09oooool2o`0000;oo`00L_ooool0027ooooo00?o0000ooooooooool0Y?ooool2ool000;o0000
8oooool00ol0003oo`00ool00002ool007Cooooo000Qooooo`03o`000?oooooooooo0:Sooooo0ol0
000Looooo`Co0000NOooool0027ooooo00?o0000ooooooooool0Zoooool3o`0001Kooooo0ol0001m
ooooo`008Oooool00ol0003oooooooooo`2^ooooo`Co00002_ooool6o`000003ool00?l0003ooooo
07oooooo000Qooooo`03o`000?oooooooooo0:oooooo4ooo0022ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgoooo
o`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0H
ooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^
kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRH
V?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00Noooool01ol@
413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0_ooool0
0oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo0000
oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00cooooo
00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGoZJVY
ooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool00oo^
k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7
QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1dooooo`00Noooool00ooM
gMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000ooooooooool01oooool0
0omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIVI_ooool02_ooool0
1?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?o
V9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o000000?o00001_oo
ool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000ooooooooool02?oo
ool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?oEEEE
oiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Ooo
ool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00Sooooo00?o
^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00Aoooo
o`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l0001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22726 L
.08255 .19009 L
.10458 .15629 L
.11448 .14385 L
.12507 .13261 L
.13499 .12408 L
.14415 .11797 L
.14901 .11542 L
.15437 .11317 L
.15975 .11149 L
.1627 .11083 L
.16402 .11058 L
.16546 .11036 L
.1668 .11019 L
.16805 .11006 L
.16925 .10997 L
.17052 .1099 L
.17178 .10987 L
.17296 .10986 L
.17401 .10988 L
.17516 .10993 L
.17642 .11001 L
.1778 .11013 L
.17925 .1103 L
.1806 .1105 L
.1856 .11152 L
.1882 .11224 L
.1906 .11302 L
.19605 .11517 L
.20595 .12043 L
.21495 .12664 L
.22451 .13459 L
.26226 .17702 L
.30246 .23293 L
.34115 .28644 L
.38229 .33467 L
.40281 .35403 L
.42191 .36903 L
.44151 .38149 L
.46002 .39065 L
.46984 .39455 L
.48048 .39807 L
.49008 .40065 L
.49906 .40258 L
.50853 .40414 L
.51355 .40478 L
.51894 .40533 L
.52164 .40556 L
.52458 .40576 L
Mistroke
.52718 .40591 L
.52994 .40604 L
.53135 .40609 L
.53267 .40613 L
.53396 .40616 L
.53515 .40619 L
.53628 .4062 L
.53747 .40622 L
.53867 .40622 L
.53998 .40622 L
.54129 .40622 L
.5425 .40621 L
.54314 .4062 L
.54383 .40619 L
.54524 .40616 L
.54781 .40609 L
.55022 .40601 L
.5547 .40579 L
.55953 .40548 L
.57046 .4045 L
.58046 .40331 L
.59942 .40035 L
.62014 .3963 L
.66075 .38667 L
.69985 .37631 L
.7414 .36501 L
.78143 .35434 L
.81995 .34451 L
.86092 .3346 L
.90038 .32556 L
.93832 .31719 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22711 L
.08255 .19021 L
.10458 .15642 L
.11448 .14394 L
.12507 .13264 L
.13499 .12407 L
.14415 .11794 L
.14911 .11535 L
.15437 .11316 L
.15964 .11154 L
.16265 .11088 L
.16399 .11064 L
.16546 .11042 L
.1668 .11026 L
.16805 .11015 L
.16925 .11006 L
.17052 .11001 L
.17178 .10998 L
.17296 .10999 L
.17401 .11002 L
.17516 .11008 L
.17642 .11017 L
.1778 .11031 L
.1806 .1107 L
.18318 .1112 L
.1856 .11178 L
.1906 .11333 L
.19605 .11553 L
.20595 .12086 L
.22451 .13503 L
.24428 .15517 L
.26529 .18083 L
.30304 .23283 L
.34324 .28824 L
.38193 .33429 L
.40158 .35351 L
.42307 .37091 L
.4436 .38396 L
.46269 .3931 L
.47322 .39697 L
.48315 .39992 L
.49207 .40203 L
.49706 .403 L
.50174 .40377 L
.50668 .40445 L
.5112 .40496 L
.51622 .40541 L
.51902 .4056 L
.52161 .40575 L
Mistroke
.52412 .40586 L
.52678 .40595 L
.5283 .40599 L
.52905 .406 L
.52973 .40601 L
.53102 .40603 L
.5317 .40603 L
.53241 .40604 L
.53363 .40604 L
.53494 .40603 L
.53617 .40602 L
.5373 .40601 L
.53862 .40598 L
.54005 .40595 L
.54266 .40587 L
.545 .40577 L
.54752 .40565 L
.55208 .40537 L
.56247 .4045 L
.57344 .40325 L
.58349 .40186 L
.62317 .39461 L
.66133 .38598 L
.70194 .37584 L
.74104 .36554 L
.78259 .35444 L
.82262 .3441 L
.86114 .33485 L
.90211 .32564 L
.94157 .31673 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo02Wooooo0_oo0005o`000?oooooo5Ooo
ool0027ooooo00?o0000ooooooooool09Oooool01?l0003oo`00ool00?oo0007ooooo`?o0000oooo
oolBooooo`008Oooool00ol0003oooooooooo`0Tooooo`;oo`003Oooool3o`000?oooooo3oooool0
027ooooo0ol0000Rooooo`;oo`004?ooool2ool000;o0000ooooool=ooooo`008Oooool00ol0003o
ooooooooo`0Qooooo`03ool00?oooooooooo01;ooooo0_oo00000ol0003oooooooooo`3oooooo`[o
oooo000Qooooo`03o`000?oooooooooo01oooooo0_oo000Gooooo`03ool00?l0003ooooo0?oooooo
2_ooool0027ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Hooooo`;oo`00oooo
ool:ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01_ooooo00?oo`00
ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool3o`0001_ooooo
00?o0000ooooooooool07oooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`3oooooo`Cooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`3o
ooooo`?ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool00ooo
003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3oooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03ool00?l0003ooooo02[ooooo00?o0000ooooooooool0o_ooool0027ooooo00?o0000
ooooooooool05_ooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo0?gooooo000Qoooo
o`?o00005Oooool00ooo003oooooooooo`0]ooooo`03o`000?oooooooooo0?cooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00o`000?ooool0;oooool00ol0003oooooooooo`3kooooo`00
8Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo033ooooo00?o0000ooooooooool0
n_ooool0027ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0booooo`03ool00?oo
oooooooo0?Wooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0<oooool0
0ol0003oo`00ooooo`3iooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Booooo`03ool00?oo
oooooooo03Cooooo00?oo`00ooooooooool0n?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool0=_ooool00ooo003oooooooooo`3gooooo`001Ol00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00004?ooool00ooo003ooooooooo
o`0gooooo`03o`000?oo003ooooo0?Oooooo0007ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0>?oo
ool00ol0003oo`00ooooo`3fooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0
>_ooool00ooo003oooooooooo`3eooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03ool00?l0003ooooo03_ooooo
00?o0000ool00?ooool0mOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ooo003o0000ooooo`0mooooo`03o`00
0?oo003ooooo0?Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo0??ooooo
000Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?_ooool00ol0003oo`00oooo
o`3cooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo00?o0000
ool00?ooool0l_ooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo047ooooo00?o0000ool0
0?ooool0lOooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo0?7ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`3`ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0koooool0027ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo0>oooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`3^ooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool0kOooool0027ooooo
0ol00008ooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool0kOooool0027ooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo0>cooooo000Q
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0C?ooool00ol0003oo`00ooooo`3[
ooooo`008Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo04kooooo00?oo`00oooo
ooooool0j_ooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1>ooooo`03
o`000?oo003ooooo0>[ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ool00?ooool0
D?ooool00ol0003oo`00ooooo`3Yooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo057ooooo00?oo`00ooooooooool0j?ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oo`00ooooo`1Cooooo`03ool00?oooooooooo0>Oooooo000Qooooo`?o00001?ooool00ooo
003oooooooooo`1Cooooo`03o`000?oo003ooooo0>Oooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ool00?ooool0=oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oo`00ooooo`0booooo`Co000000?o410@
ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool0=oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Sooooo00?oo`00ooooooooool0<oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo03Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
003ooooo03Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Wooooo
00?o0000ool00?ooool0<_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo03Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`02oooool00ooo003oooooooooo`0aooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIV
I_ooool06_ooool0027ooooo00Go0000ooooooooooooooooo`00000kooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo033ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo02oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00Go0000
okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01?l0003oooooooooool0000looooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000ooooooooool0;Oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Co0000oooooooooooo0000H?ooool00ol0003oooooooooo`3Pooooo`00
8Oooool00ol0003oooooo`00001Rooooo`03o`000?oooooooooo0=oooooo000Qooooo`03o`000?oo
oooo000006?ooooo00?o0000ooooooooool0g_ooool0027ooooo0_l0001Uooooo`03o`000?oooooo
oooo0=?ooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0001Vooooo`03o`000?oooooooooo
0=;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`00037o00000_oo0007
o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooool0000<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`06ooooo`?o00000_oo00000ooooooo0000ooooo`0Booooo`04onk^k_lQ8B7o
410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo00003?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool4
o`0000Kooooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool0
0ol0003oooooooooo`1Xooooo`03ool00?oooooooooo0:gooooo0ooo0002o`0001gooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`2Yoooo
o`?oo`0000?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003o
ooooooooo`2Tooooo`04o`000?oo003oo`00ool002oooooo000Qooooo`03o`000?oooooooooo06_o
oooo00?oo`00ooooooooool0W_ooool00ol0003oo`00ool00003ool003;ooooo000Qooooo`03o`00
0?oooooooooo06cooooo00?oo`00ooooooooool0Uoooool4o`0000?oo`00=oooool0027ooooo0ol0
001]ooooo`03ool00?l0003ooooo097ooooo1Ol0000nooooo`008Oooool00ol0003oooooooooo`1^
ooooo`03ool00?l0003ooooo08_ooooo0_l00003ool004?ooooo000Qooooo`03o`000?oooooooooo
06oooooo00?oo`00o`000?ooool0Q_ooool00ol0003oo`00ool00003ool004Kooooo000Qooooo`03
o`000?oooooooooo073ooooo00?oo`00o`000?ooool0P_ooool4ool004_ooooo000Qooooo`03o`00
0?oooooooooo077ooooo00?oo`00o`000?ooool0O_ooool3ool004oooooo000Qooooo`03o`000?oo
oooooooo07;ooooo00?oo`00o`000?ooool0N_ooool00ol0003oo`00ool0001Booooo`008Oooool0
0ol0003oooooooooo`1dooooo`;o0000M_ooool3o`0005Gooooo000Qooooo`?o0000M_ooool00ol0
003oooooooooo`1_ooooo`Co0000F?ooool0027ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`1Yooooo`05o`000?oo003oo`00ool00?l00000G?ooool0027ooooo00?o0000oooooooo
ool0N?ooool00ol0003oooooooooo`1Tooooo`Goo`00H?ooool0027ooooo00?o0000ooooooooool0
NOooool00ol0003oooooooooo`1Oooooo`04o`000?oo003oo`00ool006Gooooo000Qooooo`03o`00
0?oooooooooo07[ooooo0_l0001Jooooo`?o00000ooo001Xooooo`008Oooool00ol0003ooooooooo
o`1jooooo`;oo`0000?o0000ooooooooool0Doooool4o`000003oooooooo003oo`0006_ooooo000Q
ooooo`03o`000?oooooooooo07cooooo00?oo`00o`000?l00000D?ooool3o`0007;ooooo000Qoooo
o`03o`000?oooooooooo07gooooo0_oo00000ol0003oooooooooo`18ooooo`?oo`000_l0001eoooo
o`008Oooool3o`0007oooooo00?oo`00o`000?l00000A?ooool4ool000;o0000N?ooool0027ooooo
00?o0000ooooooooool0P?ooool2ool000;o0000?_ooool4ool000?o0000Noooool0027ooooo00?o
0000ooooooooool0P_ooool2ool000;o0000>Oooool3ool000Co0000O_ooool0027ooooo00?o0000
ooooooooool0Q?ooool2ool000?o0000=?ooool2ool000?o0000P_ooool0027ooooo00?o0000oooo
ooooool0Q_ooool3ool000?o0000;_ooool4o`0008Kooooo000Qooooo`03o`000?oooooooooo08co
oooo0ol0000Pooooo`Coo`000_ooool5o`0008[ooooo000Qooooo`03o`000?oooooooooo08oooooo
0ol0000Iooooo`Coo`001_l0002?ooooo`008Oooool3o`0009;ooooo1_oo00000ol0003ooooooooo
o`08ooooo`Soo`000ol0002Fooooo`008Oooool00ol0003oooooooooo`2Hooooo`;oo`002_l0002P
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03
ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgM
gOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIV
o`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj
00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEE
ojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<07_ooooo001n
ooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooo
oooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?o
oooo00?ok^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00Go410@okZj^_ooooooMgMgoc8b<P1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;ooooo
onk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7
ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool0
0005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1iooooo`00O_ooool01?mEEEGoZJVYooooool00002ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`05ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool0
0oooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000oooooooo
ool02_ooool6o`0000Cooooo00?o0000ooooooooool03Oooool00onYZJWo410@ooooo`1jooooo`00
O_ooool00ooMgMgo8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003ooooo
ooooo`06ooooo`03oeEEEOnHV9Sooooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003o
ooooooooo`0<ooooo`03oa0@4?l0003o^[Zj07_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo
00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool0
1Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMg
MomEEEGooooo01Gooooo00?o0000ooooooooool03Oooool00onj^[[o8B4Qooooo`1jooooo`00U_oo
ool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^kooooo
o`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo
00[ooooo00Go410@oiRHV?oooooo^[Zjo`00001kooooo`00U_ooool00ol0003oooooooooo`07oooo
o`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo
00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT0Noooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27411 L
.06244 .24026 L
.08426 .20932 L
.0949 .19729 L
.10458 .18827 L
.11403 .1813 L
.12297 .17641 L
.12787 .17442 L
.1324 .17301 L
.13476 .17244 L
.13737 .17194 L
.13868 .17174 L
.14009 .17156 L
.14142 .17143 L
.14264 .17133 L
.14392 .17127 L
.14514 .17123 L
.14622 .17122 L
.1474 .17124 L
.14869 .17128 L
.14934 .17132 L
.15005 .17136 L
.15131 .17147 L
.15248 .17159 L
.15479 .1719 L
.15689 .17226 L
.16162 .17335 L
.16672 .17492 L
.17226 .17707 L
.18234 .18204 L
.20212 .19501 L
.22313 .21176 L
.26088 .24339 L
.28185 .25913 L
.30108 .27138 L
.31993 .28105 L
.32952 .28505 L
.33977 .28863 L
.35011 .29156 L
.35951 .29363 L
.36404 .29443 L
.36896 .29517 L
.37326 .2957 L
.37788 .29616 L
.38043 .29636 L
.38277 .29652 L
.38514 .29665 L
.38734 .29674 L
.38868 .29679 L
Mistroke
.3899 .29682 L
.39125 .29685 L
.39199 .29686 L
.39268 .29687 L
.39395 .29688 L
.39512 .29689 L
.3964 .29688 L
.39705 .29688 L
.39775 .29687 L
.39843 .29686 L
.39917 .29685 L
.4005 .29682 L
.40301 .29674 L
.40594 .29662 L
.40864 .29647 L
.41357 .29612 L
.4188 .29565 L
.42819 .29456 L
.43831 .29305 L
.4566 .28962 L
.49779 .2797 L
.53747 .26922 L
.57563 .26004 L
.59692 .25573 L
.61624 .25248 L
.63636 .24983 L
.64541 .2489 L
.65534 .24807 L
.66508 .24745 L
.67041 .24719 L
.67539 .247 L
.67778 .24693 L
.68005 .24688 L
.68211 .24683 L
.6843 .2468 L
.68543 .24679 L
.68667 .24677 L
.68781 .24677 L
.68887 .24676 L
.69012 .24676 L
.69127 .24676 L
.69253 .24676 L
.69316 .24676 L
.69386 .24676 L
.69517 .24677 L
.69639 .24679 L
.69913 .24683 L
.70155 .24687 L
.70411 .24694 L
.70855 .24708 L
Mistroke
.71344 .24728 L
.72426 .2479 L
.73438 .24869 L
.75465 .25087 L
.77318 .25351 L
.81291 .26109 L
.85112 .27043 L
.89178 .28203 L
.93093 .29426 L
.97254 .30782 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27247 L
.06244 .237 L
.08255 .20801 L
.09396 .19543 L
.10458 .18633 L
.10961 .1829 L
.11508 .17979 L
.11989 .17759 L
.125 .17577 L
.12959 .17458 L
.13221 .17408 L
.13346 .17389 L
.13466 .17373 L
.13573 .17362 L
.1369 .17351 L
.13796 .17344 L
.13895 .17339 L
.14012 .17335 L
.14119 .17334 L
.14242 .17335 L
.14357 .17338 L
.14473 .17344 L
.14598 .17352 L
.14823 .17374 L
.1509 .1741 L
.15334 .17452 L
.15863 .17575 L
.16365 .17727 L
.1725 .18071 L
.18212 .18544 L
.22291 .21286 L
.26217 .24277 L
.29992 .26786 L
.31927 .27805 L
.34013 .28664 L
.35051 .28996 L
.36017 .29248 L
.37024 .29453 L
.37553 .29538 L
.38127 .29613 L
.38674 .29668 L
.38914 .29687 L
.39179 .29705 L
.39411 .29717 L
.39661 .29728 L
.39799 .29732 L
.39925 .29735 L
.40052 .29738 L
.40172 .29739 L
Mistroke
.4029 .2974 L
.40396 .29741 L
.40518 .2974 L
.40634 .29739 L
.40741 .29738 L
.40839 .29736 L
.41062 .29731 L
.41287 .29723 L
.41533 .29711 L
.42031 .29681 L
.42557 .29637 L
.43054 .29586 L
.43986 .29466 L
.46079 .29093 L
.49917 .28146 L
.54 .26972 L
.57932 .25898 L
.61712 .25081 L
.63651 .24782 L
.6474 .24654 L
.65738 .24565 L
.66214 .24532 L
.66721 .24503 L
.672 .24482 L
.67411 .24475 L
.67634 .24469 L
.67761 .24466 L
.67901 .24463 L
.68029 .24461 L
.68146 .24459 L
.68212 .24459 L
.68284 .24458 L
.68361 .24457 L
.68433 .24457 L
.685 .24457 L
.68572 .24457 L
.687 .24457 L
.68819 .24458 L
.68947 .24459 L
.69067 .2446 L
.69178 .24462 L
.69435 .24467 L
.69706 .24474 L
.70205 .24492 L
.70659 .24514 L
.71677 .24583 L
.72621 .2467 L
.73513 .24771 L
.75512 .2506 L
.77357 .25393 L
Mistroke
.81294 .2627 L
.85079 .27247 L
.8911 .28362 L
.92989 .29495 L
.97114 .30751 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool08Oooool6o`000?oooooo7_ooool0027ooooo00?o0000ooooooooool07Ooo
ool5o`0000?ooooo0ooo0004o`000?oooooo6Oooool0027ooooo00?o0000ooooooooool06oooool2
o`0000_ooooo1?oo0002o`000?oooooo5oooool0027ooooo00?o0000ooooooooool06Oooool3ool0
013ooooo0_oo00000ol0003oooooooooo`3ooooooaCooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01Sooooo00?oo`00o`000?ooool04oooool00ooo003o0000o`00003ooooooaCooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Fooooo`;oo`0000?o0000ooooooooool05?ooool2ool00003o`000?oooooo
oooo0?oooooo4Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`0001Gooooo00?oo`00o`000?l000006Oooool00ooo003o0000o`00003o
oooooa7ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Cooooo00?oo`00o`000?ooool06oooool00ooo003oooooo`00003o
oooooa3ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool04oooool00ooo003o0000ooooo`0Mooooo`04ool00?oo
oooo0000o`000?oooooo3_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Qooooo`03o`00
0?oooooooooo0?oooooo2oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0Sooooo`;o0000
ooooool;ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool09_ooool00ol0003oooooooooo`3oooooo`Sooooo
000Qooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0:?ooool00ol0003ooooooooo
o`3oooooo`Oooooo000Qooooo`03o`000?oooooooooo00oooooo00?oo`00o`000?ooool0:_ooool2
o`000?oooooo1oooool0027ooooo0ol0000?ooooo`03o`000?oooooooooo02[ooooo0_oo00000ol0
003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0;Oooool00ooo003o0000ooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0;_ooool00ooo003o0000ooooo`3oooooo`?ooooo000Qooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0<?ooool2ool00?oooooo0oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo0?oooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3noooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo0_oo003nooooo`00
8Oooool3o`0000[ooooo00?o0000ooooooooool0>?ooool00ol0003oo`00ooooo`3looooo`008Ooo
ool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo03[ooooo00?o0000ool00?ooool0nooo
ool0027ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0kooooo`03o`000?oo003o
o`0007[ooooo2ooo001eooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
03kooooo00?o0000ooooooooool0L_ooool6ool001Co00002?oo001Tooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo043ooooo0_l0001^ooooo`Oo00006_ooool5o`0000Ko
o`00G_ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`12ooooo`03o`00
0?oooooooooo06;ooooo0ooo0006o`0002cooooo1?oo00000ol0003oooooooooo`1Gooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool0GOoo
ool4ool000;o0000=oooool5ool000?o0000D_ooool0027ooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`15ooooo`;o0000F?ooool00ol0003oo`00ool00002ool004;ooooo1?oo0004
o`0004gooooo000Qooooo`?o00001Oooool00ooo003oooooooooo`18ooooo`03o`000?ooooooo`00
057ooooo0_l00003ool004[ooooo0_oo0002ooooo`Co0000BOooool0027ooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`0fooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00?oA4A4o`000?l000000_l000000ooo003oooooooooo`0jooooo`Co000000?o410@oooo
ooooool02Oooool4o`0000;oo`00;?ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd05?ooool4o`0002Gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8bo`000002ool003cooooo00?o0000ooooooooool01oooool4
o`0003Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool4
o`00027ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo03Oooooo00Go410@oooooooooooooooooa0@400@ooooo`04o`000?oo
oooo0000o`0000;oo`00>_ooool00ol0003oooooooooo`02ooooo`Go0000>?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Gooooo1Ooo0003o`0001oooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`02ooooo`;o00000_oo000hooooo`Go0000
00Coooooool00?oo003oo`00>Oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01_o
oooo1?oo0002o`0001gooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0
0_ooool00ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo0_l00003ool003;ooooo1?l000000oooooooo`00ool00002ool0
03cooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<023ooooo1?oo0000
0ol0003oooooooooo`0Iooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03o`000?oooooooooo
00;ooooo00?oo`00ooooooooool0>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool02Oooool3o`0000?oo`00:oooool4o`000003oooooooo003oo`0000;oo`00@?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_oo0002o`0001Wooooo00?o0000
ooooooooool06Oooool0027ooooo0ol000000oooooooo`00ooooo`0jooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0<ooooo`?o000000?oo`00ooooooooool09?ooool4
o`000003oooooooo003oo`0000;oo`000_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:?ooool00ooo003oooooo`000002o`0001;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01Ol0003ooooooooooooooooo000003_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool3o`0001oooooo1Ol00003ooooo`;oo`00
1?ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000/ooooo`?o0000
3oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`04o`000?ooooooooooo`0006;o
oooo0ol0000Hooooo`Co0000Toooool3o`0002cooooo000Qooooo`03o`000?oooooo000006Kooooo
1Ol00004ool000Kooooo1Ol00007ool009Oooooo0ooo00000ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooo`00001_ooooo`_oo`00XOooool3ool00003o`000?oooooooooo02?ooooo000Q
ooooo`;o0000oooooolPooooo`?oo`0000?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004
ooooo`008Oooool2o`000?oooooo8oooool3ool00003o`000?oooooooooo01?ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0002oo00001?oo0007o`0000cooooo00CogMgM
o`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4Q
ogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0oooooolkooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIV
I_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Y?ooool0
0omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?ooool00olQ
8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yoooool007_o
oooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGoV9RHoooo
o`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooooon7QhOo
IVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oMgMgoMgMg
ob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Q
onk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^k_l0003o
oooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S801oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003oooooomgMgOlb
<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgM
ooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07?ooooo001kooooo`04oeEEEOnYZJWoooooo`0000;o
oooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`06ooooo`03onk^k_l@413ok^k^
00Gooooo00?o<S8booooooooool01?ooool00onHV9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKooooo
o`0000Cooooo00?o0000ooooooooool02_ooool6o`0000Gooooo00?o0000ooooooooool03Oooool0
0onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^
00?ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9So
oooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0
003o^[Zj00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01eooooo`00O?ooool00onHV9SoMgMgoooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o410@o`000?l000000ol00006ooooo`03omgMgOl@
413ooooo00Cooooo00?oEEEEogMgMoooool01_ooool00ol0003oooooooooo`08ooooo`Oo000000?o
ooooogMgMomEEED05oooool00ol0003oooooooooo`0=ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o
0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00omEEEGoV9RHooooo`03
ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@
413ogMgM01Oooooo00?o0000ooooooooool02_ooool01Ol@413oV9RHoooooonj^[[o000000Cooooo
00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[oA4A4oooo
o`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMg
Moooool05Oooool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool4
o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .30147 L
.0522 .29812 L
.06244 .29516 L
.0679 .29389 L
.07286 .29294 L
.07784 .29218 L
.08255 .29166 L
.08522 .29144 L
.08668 .29135 L
.08805 .29128 L
.08931 .29122 L
.09046 .29119 L
.09174 .29116 L
.09244 .29115 L
.09312 .29114 L
.09384 .29114 L
.09449 .29114 L
.09525 .29114 L
.09596 .29115 L
.09723 .29118 L
.09794 .2912 L
.0986 .29122 L
.10151 .29135 L
.10297 .29144 L
.10458 .29156 L
.10982 .29206 L
.11478 .29268 L
.12409 .29419 L
.145 .29856 L
.16322 .30242 L
.1736 .30422 L
.17868 .30493 L
.18333 .30547 L
.18797 .30589 L
.1903 .30605 L
.19285 .30619 L
.1942 .30625 L
.19542 .30629 L
.1961 .30631 L
.19683 .30632 L
.19752 .30633 L
.19816 .30634 L
.19931 .30635 L
.20057 .30635 L
.20188 .30634 L
.20311 .30632 L
.20441 .30628 L
.20582 .30623 L
.2084 .3061 L
Mistroke
.21091 .30593 L
.21324 .30573 L
.21851 .30514 L
.22412 .30429 L
.23443 .30215 L
.24557 .299 L
.26575 .29126 L
.30681 .26898 L
.34635 .24238 L
.38437 .21539 L
.42485 .18826 L
.46381 .16595 L
.48366 .1565 L
.50522 .14785 L
.5242 .1417 L
.53499 .13882 L
.54512 .13654 L
.55546 .13461 L
.56493 .1332 L
.57505 .13208 L
.58037 .13165 L
.58324 .13147 L
.58595 .13132 L
.58836 .13121 L
.59097 .13111 L
.59212 .13108 L
.59334 .13105 L
.59448 .13103 L
.59552 .13101 L
.59674 .13099 L
.59804 .13099 L
.59924 .13098 L
.60039 .13098 L
.60103 .13099 L
.60172 .13099 L
.60295 .13101 L
.60363 .13102 L
.60427 .13103 L
.60573 .13106 L
.60798 .13112 L
.61034 .1312 L
.61457 .13141 L
.61913 .1317 L
.62411 .1321 L
.63437 .1332 L
.6437 .13452 L
.66464 .13854 L
.6838 .14344 L
.70459 .15 L
.74548 .16627 L
Mistroke
.78485 .18558 L
.8227 .20687 L
.86301 .23183 L
.9018 .25747 L
.94305 .28584 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .30282 L
.06244 .29659 L
.06747 .29535 L
.07286 .29422 L
.07751 .29342 L
.08255 .29274 L
.08564 .29242 L
.08848 .2922 L
.0912 .29203 L
.09258 .29197 L
.09335 .29195 L
.09409 .29192 L
.09474 .29191 L
.09545 .29189 L
.0967 .29187 L
.0974 .29187 L
.09815 .29187 L
.09886 .29187 L
.0995 .29188 L
.10076 .29189 L
.10147 .29191 L
.10212 .29192 L
.10338 .29196 L
.10458 .29201 L
.10704 .29214 L
.10928 .29228 L
.11432 .29271 L
.1234 .2938 L
.14407 .29727 L
.16229 .30065 L
.17266 .30236 L
.17774 .30308 L
.1824 .30366 L
.18694 .30414 L
.19191 .30456 L
.1945 .30473 L
.19691 .30485 L
.19945 .30495 L
.20088 .30499 L
.20217 .30501 L
.20348 .30503 L
.20414 .30503 L
.20487 .30503 L
.20615 .30503 L
.20736 .30501 L
.20808 .305 L
.20877 .30499 L
.21007 .30495 L
.21146 .3049 L
Mistroke
.21298 .30483 L
.21554 .30468 L
.21827 .30447 L
.22318 .30398 L
.22855 .30325 L
.23349 .3024 L
.24463 .29987 L
.25445 .29693 L
.26481 .29312 L
.30284 .27354 L
.34331 .24574 L
.38227 .21646 L
.42369 .1871 L
.46359 .16373 L
.50197 .14739 L
.52178 .14146 L
.5319 .13907 L
.5428 .13696 L
.55299 .13542 L
.56231 .13436 L
.57123 .13364 L
.57571 .13338 L
.57826 .13327 L
.5806 .13319 L
.58315 .13312 L
.58449 .13309 L
.58591 .13306 L
.58714 .13305 L
.58829 .13304 L
.58955 .13303 L
.59026 .13303 L
.59091 .13303 L
.5921 .13304 L
.5932 .13305 L
.59442 .13306 L
.5957 .13308 L
.59787 .13313 L
.60025 .13319 L
.60545 .1334 L
.61106 .13371 L
.62122 .13452 L
.63077 .13554 L
.64123 .13695 L
.66233 .14065 L
.68191 .14509 L
.70285 .15086 L
.74432 .16543 L
.78427 .18339 L
.8227 .20419 L
.86359 .22958 L
Mistroke
.90296 .25632 L
.94082 .28324 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`2Uooooo`Ko00000_oo000Bo`0008Gooooo000Qooooo`03o`000?oooooooooo0:7o
oooo2_oo000<ooooo`Ooo`0000?oooooo`000?l000000_l00021ooooo`008Oooool00ol0003ooooo
ooooo`2Looooo`Goo`0000?o0000ooooooooool06_ooool5ool000Go0000O?ooool0027ooooo0ol0
002Iooooo`?o00009oooool4ool00004ooooool0003o0000o`0007Wooooo000Qooooo`03o`000?oo
oooooooo09Kooooo0ol0000booooo`?o0000M_ooool0027ooooo00?o0000ooooooooool0TOooool2
ool000?o0000>?ooool3o`0007?ooooo000Qooooo`03o`000?oooooooooo08oooooo0_oo0002o`00
03kooooo0_oo00000ol0003oooooooooo`1^ooooo`008Oooool00ol0003oooooooooo`2<ooooo`?o
o`0000?o0000ooooooooool0@Oooool3ool00003o`000?oooooooooo06_ooooo000Qooooo`03o`00
0?oooooooooo08[ooooo0_oo0002o`0004Sooooo0ooo00000ol0003oooooooooo`1Xooooo`008Ooo
ool00ol0003oooooooooo`28ooooo`;oo`000_l0001=ooooo`;oo`0000?o0000ooooooooool0I_oo
ool0027ooooo00?o0000ooooooooool0Q_ooool2ool000;o0000DOooool3ool00003o`000?oooooo
oooo06?ooooo000Qooooo`?o0000QOooool00ooo003o0000o`00001Fooooo`;oo`0000?o0000oooo
ooooool0HOooool0027ooooo00?o0000ooooooooool0Q?ooool00ooo003o0000ooooo`1Jooooo`;o
0000HOooool0027ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`1Mooooo`;o0000
Goooool0027ooooo00?o0000ooooooooool0POooool2o`0006;ooooo0_l0001Mooooo`008Oooool0
0ol0003oooooooooo`1oooooo`;o0000I_ooool2o`0000;oo`00FOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`1Xooooo`;o00000_oo001Gooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool0NOooool2ool00003ooooool0003o000006gooooo0_l00002ool005Gooooo0005
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
001hooooo`04ool00?oooooo0000o`00077ooooo0_l000000ooo003oooooooooo`1Booooo`001ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`1fooooo`;oo`0000?oooooo`000?ooool0M?ooool00ol0003oo`00ool0001Booooo`001ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo07Gooooo00Coo`00ooooool0003o0000N?ooool00ol0003oo`00ool0001@oooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1cooooo`;oo`000_l0001looooo`03o`000?oo003ooooo04kooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07;ooooo00?oo`00ooooool00000P?ooool2ool004gooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0LOooool00ooo003o0000o`000023oooo
o`03ool00?l0003ooooo04[ooooo000Qooooo`03o`000?oooooooooo06oooooo0_oo00000ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo06kooooo
00?oo`00o`000?ooool0ROooool2o`0004Sooooo000Qooooo`?o0000KOooool00ooo003o0000oooo
o`2<ooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0S_ooool2o`0004Gooooo000Qooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0TOooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`1Yooooo`;o
0000UOooool2ool004;ooooo000Qooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
Uoooool2ool0043ooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0VOoo
ool00ol0003oo`00ooooo`0nooooo`008Oooool00ol0003oooooooooo`1Uooooo`;o0000W_ooool0
0ol0003oooooooooo`0looooo`008Oooool3o`0006Cooooo0_oo002Pooooo`;o0000??ooool0027o
oooo00?o0000ooooooooool0Hoooool00ooo003oooooooooo`2Rooooo`;o0000>_ooool0027ooooo
00?o0000ooooooooool0HOooool00ol0003oo`00ooooo`2Vooooo`;oo`00>?ooool0027ooooo00?o
0000ooooooooool0H?ooool2ool00:Wooooo00?o0000ool00?ooool0=_ooool0027ooooo00?o0000
ooooooooool0G_ooool00ol0003oo`00ooooo`2/ooooo`;oo`00=Oooool0027ooooo00?o0000oooo
ooooool0GOooool2ool00;3ooooo00?oo`00ooooooooool0<_ooool0027ooooo00?o0000oooooooo
ool0Foooool00ol0003oo`00ooooo`2booooo`;oo`00<_ooool0027ooooo00?o0000ooooooooool0
F_ooool2ool00;Kooooo00?oo`00ooooooooool0;oooool0027ooooo0ol0001Hooooo`03o`000?oo
003ooooo0;Sooooo0_oo000_ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`00
0?oo003ooooo03Kooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0]ooooo`03o`000?oo003ooooo00go
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooooooo0_l0000kooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0;_ooool00ooo
003oooooooooo`0;ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027ooooo00?o0000oooo
ooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo0ol0000mooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooo
oooo00_ooooo00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0
003ooooooooooooooooo000000oooooo0_l0000oooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool03_ooool00omgMgOo<S8booooo`0`ooooo`;o00003?ooool00onHV9So8B4Qonk^kP0K
ooooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool000003?ooool3
o`000003oc8b<_o<c<cooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0<oooool00ol0003oooooooooo`0:ooooo`03ogMgMomV
IVKooooo01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@
400;ooooo`;oo`00@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo000Q
ooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo0_oo0002o`0004?ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Oooooo0_l0
0006ooooo`05o`000?nj^[[ooooooiRHV?l@41006oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00Coo`00o`000?oooooooooo1?l0000nooooo`03
oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Oooool4o`0003Sooooo00?o0000oooooooo
ool00oooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00co
oooo1Ol0000<ool002_ooooo0_oo003Eooooo`03o`000?oo003oo`0002;ooooo000Qooooo`03o`00
0?oooooooooo00Sooooo1?l0000Aooooo`Coo`009?ooool00ol0003oo`00ool0003Iooooo`03o`00
0?oo003ooooo023ooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Iooooo`Ko00006_oo
ool3o`0000;oo`00gOooool2ool001oooooo000Qooooo`03o`000?oooooooooo00;ooooo1Ooo000P
ooooo`Co00000_oo000Aooooo`;o00001?oo003Pooooo`03o`000?oo003ooooo01?ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000oooooooo00000_oo000Zooooo`03o`000?oo003oo`00
00[oo`001Ol0003Xooooo`03ool00?oooooooooo017ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_ooool7o`0000;oo`00ool0000Yo`000003ool00?l0003o000000Go00003?ooool0
1?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo0_l00002
ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o
0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omE
EEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002X
ooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0Xoooool008Oooooo0ol0000Coooo
o`03ob4Q8OoMgMgooooo00Oooooo00?ogMgMoa0@4?o^k^h06?ooool00oo^k^ko410@omgMg@2Soooo
o`00O_ooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h00oooool00ol0003oooooooooo`0;
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool00onHV9SoEEEEooooo`07ooooo`04oeEEEOnH
V9Soooooooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`03okZj^_m4A4Cooooo00;ooooo
00?oQhN7ofIVI_ooool04oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`;o0000
00?o410@ooooooooool0NOooool007kooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00?o
oooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000omgM
gOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEE
EOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko00001?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003oooooooooo`1jooooo`00O_ooool01ol0003o
ooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool0
1?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_oo
ool5o`0007_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;ooooo
ooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003o
ooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`00
07cooooo001nooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03
o`000?oooooooooo00Kooooo00?oEEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03
ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo0000O?ooool007oooooo00?oV9RHogMg
Moooool00_ooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o000000?o00001Oooool00ooM
gMgo410@ooooo`05ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool02?ooool7o`00
00;ooooo00?oMgMgoeEEEOooool05Oooool00ol0003oooooooooo`0;ooooo`03ogMgMoo<c<co0000
07cooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo
410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o
0000ooooooooool02oooool00oo^k^koA4A4o`00001looooo`00U_ooool00ol0003oooooooooo`07
ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;o
oooo00?oIVIVogMgMoooool05?ooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo07_o
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33986 L
.06244 .36986 L
.08426 .39716 L
.0949 .40755 L
.10458 .41509 L
.10911 .41795 L
.11403 .42057 L
.11828 .42242 L
.12297 .42401 L
.12553 .42469 L
.12793 .42519 L
.13047 .42558 L
.13189 .42575 L
.13319 .42586 L
.13439 .42593 L
.13551 .42597 L
.13673 .42598 L
.13803 .42596 L
.13928 .4259 L
.14045 .42583 L
.1415 .42573 L
.14264 .4256 L
.14501 .42525 L
.14755 .42475 L
.15214 .42352 L
.1576 .42154 L
.16257 .41925 L
.17339 .41277 L
.18364 .40491 L
.22197 .3637 L
.26275 .30724 L
.30202 .24925 L
.33977 .1962 L
.37997 .14687 L
.41866 .1086 L
.43831 .09291 L
.4598 .07867 L
.48033 .06789 L
.49942 .06028 L
.50995 .05705 L
.51988 .05461 L
.5288 .05292 L
.53379 .05217 L
.53847 .0516 L
.54303 .05116 L
.54538 .05098 L
.54793 .05082 L
.55072 .05068 L
.55201 .05063 L
Mistroke
.55337 .05059 L
.55473 .05055 L
.55595 .05053 L
.55718 .05052 L
.55834 .05051 L
.55957 .05052 L
.56026 .05052 L
.56091 .05053 L
.56222 .05055 L
.56295 .05056 L
.56362 .05058 L
.5661 .05066 L
.56846 .05076 L
.57118 .05092 L
.5737 .0511 L
.57939 .05161 L
.58904 .05284 L
.59809 .05439 L
.61871 .05927 L
.63893 .06574 L
.65744 .073 L
.69712 .09234 L
.73528 .11509 L
.77589 .14288 L
.81499 .17237 L
.85654 .20589 L
.89658 .23967 L
.93509 .27301 L
.97607 .30891 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .34081 L
.06244 .37178 L
.08255 .3972 L
.09396 .40818 L
.09905 .41222 L
.10458 .41598 L
.11004 .41906 L
.11508 .42133 L
.11989 .42301 L
.12232 .42367 L
.125 .42425 L
.12741 .42465 L
.12962 .42492 L
.13084 .42502 L
.13153 .42506 L
.13217 .42509 L
.13334 .42513 L
.13459 .42514 L
.13575 .42513 L
.13701 .42508 L
.1382 .425 L
.1393 .42491 L
.14138 .42466 L
.14357 .42432 L
.14612 .4238 L
.14853 .4232 L
.15305 .42179 L
.16321 .4173 L
.17199 .41206 L
.18154 .40502 L
.22233 .36247 L
.26159 .30927 L
.29934 .25431 L
.33955 .19786 L
.37823 .14972 L
.41937 .10801 L
.4399 .09132 L
.459 .07836 L
.4786 .06762 L
.49711 .05984 L
.50692 .05663 L
.51756 .05383 L
.52724 .0519 L
.53615 .05062 L
.54083 .05013 L
.5434 .04992 L
.54585 .04975 L
.54811 .04963 L
.54931 .04958 L
Mistroke
.55058 .04953 L
.55176 .04949 L
.55283 .04947 L
.55391 .04945 L
.55492 .04944 L
.55612 .04943 L
.55743 .04943 L
.55809 .04943 L
.5588 .04944 L
.56009 .04946 L
.56136 .04949 L
.56257 .04952 L
.56484 .04961 L
.56751 .04974 L
.56997 .0499 L
.57555 .05038 L
.5802 .0509 L
.58521 .05157 L
.59426 .05311 L
.61487 .05801 L
.63495 .0645 L
.65607 .07296 L
.69423 .09184 L
.73484 .11603 L
.77394 .14238 L
.81549 .173 L
.85552 .20465 L
.89404 .23679 L
.93501 .27241 L
.97447 .30748 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000X?ooool2
ool000Gooooo0ooo002Jooooo`008Oooool00ol0003oooooooooo`2Jooooo`Koo`002_l00009ool0
097ooooo000Qooooo`03o`000?oooooooooo09Kooooo1?oo000Gooooo`;o00000ooo002>ooooo`00
8Oooool00ol0003oooooooooo`2Cooooo`?oo`0000?o0000ooooooooool07?ooool00ol0003oo`00
ool00002o`0008[ooooo000Qooooo`03o`000?oooooooooo097ooooo0ol0000Vooooo`?o0000Qooo
ool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo08kooooo0ol0000/
ooooo`;o0000QOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2;oooo
o`?o0000<Oooool2o`0008?ooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`?o
0000R?ooool2ool00003o`000?oooooooooo03Cooooo0_oo0021ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08Kooooo0_oo00000ol0003oooooooooo`0hooooo`;oo`00
Ooooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`24ooooo`;oo`0000?o
0000ooooooooool0??ooool2ool007gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Poooool00ooo003o0000ooooo`11ooooo`;oo`00Noooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`21ooooo`;oo`0000?o0000ooooooooool0@oooool2ool0
0003o`000?oooooooooo07Kooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0P?ooool00ooo003o0000ooooo`18ooooo`;oo`0000?o0000ooooooooool0M?ooool0027ooooo
00?o0000ooooooooool0Ooooool00ooo003o0000ooooo`1;ooooo`;oo`0000?o0000ooooooooool0
L_ooool0027ooooo00?o0000ooooooooool0O_ooool00ooo003o0000ooooo`1>ooooo`03ool00?l0
003o000007;ooooo000Qooooo`?o0000OOooool00ooo003oooooooooo`1Booooo`;o0000L?ooool0
027ooooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo
06gooooo000Qooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Eoooool2o`0006go
oooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0F_ooool2o`0006_ooooo
000Qooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0G?ooool2ool006[ooooo000Q
ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0Goooool00ooo003o0000ooooo`1W
ooooo`008Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo067ooooo0_oo00000ol0
003oooooooooo`1Tooooo`008Oooool3o`0007Kooooo00?o0000ooooooooool0I?ooool00ooo003o
0000ooooo`1Tooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo06Oooooo
0_oo00000ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?oo
oooooooo06Wooooo00?oo`00o`000?ooool0HOooool0027ooooo00?o0000ooooooooool0Loooool0
0ooo003oooooooooo`1[ooooo`03ool00?l0003o0000063ooooo000Qooooo`03o`000?oooooooooo
07;ooooo00?oo`00ooooooooool0KOooool2ool00003o`000?oooooooooo05gooooo000Qooooo`03
o`000?oooooooooo077ooooo00?oo`00ooooooooool0L?ooool00ooo003o0000o`00001Mooooo`00
8Oooool00ol0003oooooooooo`1`ooooo`03ool00?oooooooooo07;ooooo00?oo`00ooooool00000
G?ooool0027ooooo0ol0001_ooooo`03ool00?oooooooooo07Kooooo0_l0001Jooooo`008Oooool0
0ol0003oooooooooo`1^ooooo`03ool00?oooooooooo07Wooooo00?o0000ooooooooool0Eoooool0
027ooooo00?o0000ooooooooool0KOooool00ooo003oooooooooo`1kooooo`03o`000?oooooooooo
05Kooooo000Qooooo`03o`000?oooooooooo06cooooo00?oo`00o`000?ooool0OOooool00ol0003o
ooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo07kooooo
00?o0000ooooooooool0E?ooool0027ooooo00?o0000ooooooooool0Joooool00ooo003ooooooooo
o`20ooooo`;oo`00E?ooool0027ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`23
ooooo`03ool00?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0QOooool2ool0057ooooo000Qooooo`?o0000J?ooool00ol0003oooooooooo`27ooooo`03
o`000?oo003ooooo04oooooo000Qooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
ROooool00ol0003oo`00ooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo08_ooooo00?o0000ool00?oo0000COooool0027ooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`2=ooooo`03o`000?oo003ooooo04_ooooo000Qooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0Soooool00ol0003oo`00ooooo`1:ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo097ooooo00?o0000ool00?ooool0BOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo06?ooooo00?oo`00ooooooooool0U?ooool00ooo003oooooooooo`17
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`?o0000H_ooool00ol0003oo`00ooooo`2Fooooo`03ool00?oooooooooo04Kooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo067ooooo00?o0000ool00?ooool0V?ooool00ol0003oooooooooo`15ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo063ooooo00?o0000ool00?ooool0V_ooool2o`0004Gooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo00?o
o`00ooooooooool0W?ooool00ol0003oooooooooo`12ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
003ooooo09kooooo00?o0000ooooooooool0@Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`1Nooooo`03o`000?oo003ooooo0:3ooooo0_l0
0011ooooo`008Oooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo0:;ooooo00?o0000
ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`2Soooo
o`;oo`00?oooool0027ooooo0ol0001Looooo`03ool00?oooooooooo0:Kooooo00?oo`00oooooooo
ool0??ooool0027ooooo00?o0000ooooooooool0Foooool00ol0003oo`00ooooo`2Xooooo`03ool0
0?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0ZOoo
ool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`1Jooooo`03ool00?oooooo
oooo0:_ooooo0_oo000jooooo`008Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo
0:kooooo00?oo`00ooooooooool0=oooool0027ooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`2_ooooo`03ool00?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool0/Oooool00ooo003oooooooooo`0eooooo`008Oooool3o`0005Oooooo00?o
0000ooooooooool0/oooool00ooo003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo0;Gooooo00?oo`00o`000?ooool0<oooool0027ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2fooooo`03ool00?l0003ooooo03;ooooo000Qooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`0`ooooo`00
8Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2looooo`03o`000?oo
oooooooo02kooooo000Qooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool0__ooool2
o`0002kooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o0000ool00?ooool0`Oooool00ol0
003oooooooooo`0[ooooo`008Oooool3o`0005;ooooo00?oo`00ooooooooool0`_ooool00ol0003o
ooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003oo`00omgMg@0mooooo`Co000000?o410@oooo
ooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0<?ooool2ool000_ooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0moooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ool00?lb<S80?oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo037ooooo00?oo`00ooooooooool02?ooool01OnHV9So8B4Qonk^k_ooooooA4A401_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400>ooooo`03ool00?oo
oooo000003oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo037ooooo0_oo0009ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Qooooo`03o`000?oooooo
oooo03gooooo00Go0000ooooooooooooooooo`00000=ooooo`04ool00?ooooooMgMgoc8b<Soooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03Cooooo
00?oo`00ooooooooool01oooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`0mooooo`05o`000?ooooooooooooooool000003?ooool01Ooo003o8B4Qo`000?lb<S;oc<c<03oo
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0=_ooool00ooo003oooooooooo`07ooooo`03ogMgMomVIVKooooo01[ooooo000Qooooo`03
o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03ool00?oooooooooo
047ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03Wooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0003go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03ool00?l0003ooooo04;ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo00?oo`00oooo
ooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`03ool00?oooooo000000?o0000?_ooool0
0omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000jooooo`09ool00?l0003o
oooooooooonHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool0d_ooool00ooo003o0000ooooo`0Pooooo`008Oooool00ol0003ooooooooo
o`1;ooooo`03ool00?oooooooooo0=Cooooo00?oo`00o`000?ooool07oooool0027ooooo00?o0000
ooooooooool0B_ooool00ooo003oooooooooo`3Fooooo`03ool00?l0003ooooo01kooooo000Qoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0Boooo
o`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool0f_ooool00ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool0
01[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q
8Ol@413ok^k^1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aoooo
o`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooo000004Kooooo00?o0000oooo
ooooool0lOooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooo`000015ooooo`03
o`000?oooooooooo0?cooooo000Qooooo`04o`000?ooooooooooo`0004Cooooo00?o0000oooooooo
ool0o?ooool0027ooooo00Co0000ooooooooooooo`00@oooool00ooo003oooooooooo`3mooooo`00
8Oooool01Ol0003ooooooooooooo003o0000047ooooo00?o0000ool00?ooool0o_ooool0027ooooo
0ol000000oooooooo`00o`00000oooooo`03o`000?oo003ooooo0?oooooo000Qooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0??ooool00ol0003oo`00ooooo`3oooooo`7ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`3o
ooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ooo
003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?oo`00oooooooo
ool0>?ooool00ooo003oooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool0=_ooool00ol0003oo`00ooooo`3oooooo`Cooooo000Qooooo`03o`000?oo
oooooooo00Gooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`3oooooo`Cooooo000Q
ooooo`?o00001_ooool00ooo003oooooooooo`0dooooo`03ool00?oooooooooo0?oooooo1Oooool0
027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo
0?oooooo1_ooool0027ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0aooooo`03
ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0`ooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo2Oooool0
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
0?oooooo2_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0?oooooo2oooool0027ooooo0ol0000<ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0ooooool=ooooo`008Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0ooooool>ooooo`008Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0ooooool?oooo
o`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool0ooooool@ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03ool00?l0003ooooo01kooooo
00?oo`00ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Aooooo`03ool00?l0
003ooooo01cooooo00?oo`00ooooooooool0oooooolBooooo`008Oooool3o`0001;ooooo00?oo`00
o`000?ooool06_ooool00ooo003oooooooooo`3ooooooa?ooooo000Qooooo`03o`000?oooooooooo
01?ooooo00?oo`00o`000?l000006?ooool00ooo003oooooooooo`3ooooooaCooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooool000005_ooool00ooo003oooooooooo`3ooooooaGo
oooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo00000ol0003oooooooooo`0Aooooo`;oo`00
oooooolHooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?l0003o000000kooooo0ooo
003ooooooa[ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Sooooo0ooo000;ooooo`04o`00
0?oo003o0000o`000?oooooo6oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo0_oo00000ol0003o
ooooooooo`04ooooo`;o0000oooooolOooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`0001kooooo1_l0003oooooob7ooooo0007ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMooo
ool0Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h0
6?ooool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^
k^h00_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onH
V9SoEEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo
00;ooooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo00?o0000oooooooo
ool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOooool01Oooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooo
oooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`1dooooo`00Nooo
ool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^
k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool5o`0000Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVYZOoo
oooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?ok^k^
oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7
ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003ooooooooo
o`0:ooooo`04odA4A?oMgMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00[o
oooo00CogMgMoeEEEOoooooo00001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Gooooo001loooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@413o0000o`000003o`00
00Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06ooooo`03o`000?oooooooooo
00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<
c?l000001Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03
oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_ooool01Ol0003o^[ZjoooooonHV9So410@
017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003oooooooooo`0;ooooo`03onk^k_m4A4Co0000
00Gooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000ooooooooool02?ooool00onj^[[o
A4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So410@o`000?lQ8B7oc<c<017ooooo00?o
IVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo00Cooooo1?l0
001fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .3589 L
.06244 .40538 L
.08255 .44164 L
.09396 .45641 L
.09905 .46161 L
.10458 .46627 L
.11004 .46988 L
.11243 .47116 L
.11508 .47235 L
.1174 .47322 L
.11989 .47397 L
.12127 .4743 L
.12253 .47455 L
.12372 .47474 L
.125 .4749 L
.12624 .47501 L
.12736 .47507 L
.12849 .47509 L
.12955 .47507 L
.13079 .47501 L
.13194 .47492 L
.13319 .47478 L
.13452 .47458 L
.13675 .47413 L
.13884 .47359 L
.14357 .47192 L
.14858 .46954 L
.15402 .46624 L
.16392 .45852 L
.18248 .43875 L
.22326 .37799 L
.26253 .30853 L
.30028 .24156 L
.34048 .17686 L
.37917 .12467 L
.39882 .10252 L
.42031 .08181 L
.44107 .06527 L
.45994 .05315 L
.47955 .04337 L
.49045 .03913 L
.5005 .03595 L
.50981 .0336 L
.51968 .03173 L
.5248 .03099 L
.52958 .03045 L
.53484 .03002 L
.53778 .02985 L
.53917 .02978 L
Mistroke
.54048 .02973 L
.54168 .0297 L
.54299 .02967 L
.54417 .02965 L
.54526 .02964 L
.54644 .02963 L
.54774 .02964 L
.54839 .02964 L
.54909 .02965 L
.55035 .02967 L
.55153 .0297 L
.55281 .02974 L
.55514 .02984 L
.55741 .02996 L
.5595 .0301 L
.56429 .0305 L
.56956 .03109 L
.58024 .0327 L
.59036 .03474 L
.59962 .03703 L
.62049 .04357 L
.66017 .06072 L
.69833 .08214 L
.73894 .1091 L
.77804 .13817 L
.81959 .17154 L
.85963 .20541 L
.89814 .2391 L
.93912 .27564 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .35671 L
.06244 .40297 L
.08255 .44006 L
.09396 .45554 L
.09905 .46107 L
.10458 .46609 L
.11004 .47005 L
.11508 .47283 L
.11989 .47472 L
.12232 .47539 L
.12369 .47569 L
.125 .47591 L
.12615 .47607 L
.12741 .4762 L
.12855 .47627 L
.12962 .4763 L
.13088 .47629 L
.13202 .47624 L
.13334 .47614 L
.13459 .47599 L
.13568 .47582 L
.13684 .47561 L
.1389 .47514 L
.14357 .47362 L
.14853 .47136 L
.15305 .46874 L
.16321 .46103 L
.18154 .44152 L
.22139 .38133 L
.25972 .31234 L
.3005 .23924 L
.33977 .17655 L
.37752 .12671 L
.41772 .08579 L
.45641 .05773 L
.47645 .04722 L
.48665 .04287 L
.49755 .03893 L
.50789 .03586 L
.51729 .03361 L
.52674 .03187 L
.53566 .03069 L
.54029 .03025 L
.54295 .03005 L
.54538 .02991 L
.54794 .02979 L
.54935 .02974 L
.5507 .0297 L
.55193 .02967 L
Mistroke
.55308 .02965 L
.55433 .02964 L
.55504 .02964 L
.55567 .02964 L
.55683 .02965 L
.55805 .02966 L
.5591 .02968 L
.56024 .02971 L
.5628 .02979 L
.56518 .0299 L
.5695 .03018 L
.57412 .03058 L
.57943 .03118 L
.58432 .03187 L
.5954 .03386 L
.60517 .03613 L
.61554 .03905 L
.65334 .05395 L
.6936 .07645 L
.73233 .10336 L
.77353 .136 L
.8132 .16965 L
.85136 .2027 L
.89198 .23772 L
.93107 .27102 L
.97262 .30604 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo09_ooooo2?l0
0008ool009Wooooo000Qooooo`03o`000?oooooooooo09Cooooo0_l00004ool00003o`000?oooooo
oooo00_ooooo0ol00008ool0097ooooo000Qooooo`03o`000?oooooooooo097ooooo0_l00003ool0
01Sooooo1Ol000000ooo003oooooooooo`2>ooooo`008Oooool00ol0003oooooooooo`2>ooooo`;o
00000ooo000Qooooo`?o0000SOooool0027ooooo00?o0000ooooooooool0Roooool2o`0000?oo`00
9oooool3o`0008[ooooo000Qooooo`03o`000?oooooooooo08Wooooo0_l000000oooooooo`00oooo
o`0/ooooo`;o0000R?ooool0027ooooo0ol00027ooooo`;o000000?oooooool00?oo0000<?ooool0
0ol0003oo`00ool00025ooooo`008Oooool00ol0003oooooooooo`25ooooo`;o0000=oooool01?l0
003oo`00ool00?oo0022ooooo`008Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
03Wooooo0_l00002ool0083ooooo000Qooooo`03o`000?oooooooooo08;ooooo0_l0000nooooo`;o
00000_oo001nooooo`008Oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo043ooooo
0_l00002ool007cooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oo003oo`0004Cooooo0_l000000ooo003oooooooooo`1iooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0Aoooool0
0ol0003oo`00ool0001iooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`00
07cooooo0_l000000ooo003oooooooooo`18ooooo`;o000000?oo`00ooooooooool0M_ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1kooooo`03o`000?oo003oo`0004go
oooo0_l0001gooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07[ooooo
00?o0000ool00?ooool0D?ooool00ol0003oooooooooo`1dooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0D_ooool2o`0007Cooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?ooool00ol0003oo`00ooooo`1E
ooooo`;o0000L_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1goooo
o`03o`000?oo003ooooo05Sooooo00?o0000ooooooooool0Koooool0027ooooo00?o0000oooooooo
ool0M_ooool00ol0003oo`00ooooo`1Jooooo`03o`000?oo003oo`0006kooooo000Qooooo`03o`00
0?oooooooooo07Gooooo00?o0000ool00?ooool0GOooool00ol0003oo`00ool0001/ooooo`008Ooo
ool3o`0007Cooooo00?o0000ool00?ooool0H?ooool00ol0003oo`00ooooo`1Zooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03o`000?oooooooooo06;ooooo00?o0000ool00?oo0000JOooool0
027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo003ooooo
06Oooooo000Qooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0Ioooool00ooo003o
ooooooooo`1Uooooo`008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo06Wooooo
00?oo`00o`000?ooool0I?ooool0027ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`1[ooooo`03ool00?l0003ooooo06?ooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0KOooool00ooo003o0000ooooo`1Rooooo`008Oooool3o`0006kooooo00?o0000oooo
ooooool0Koooool00ooo003o0000o`00001Qooooo`008Oooool00ol0003oooooooooo`1]ooooo`03
ool00?oooooooooo07?ooooo00?o0000ooooooooool0G_ooool0027ooooo00?o0000ooooooooool0
K?ooool00ooo003oooooooooo`1eooooo`03o`000?oooooooooo05gooooo000Qooooo`03o`000?oo
oooooooo06cooooo00?oo`00ooooooooool0M_ooool2o`0005gooooo000Qooooo`03o`000?oooooo
oooo06_ooooo00?oo`00ooooooooool0NOooool00ol0003oooooooooo`1Jooooo`008Oooool00ol0
003oooooooooo`1Zooooo`03ool00?oooooooooo07_ooooo00?o0000ooooooooool0FOooool0027o
oooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`1mooooo`;o0000FOooool0027ooooo
0ol0001Yooooo`03ool00?oooooooooo07gooooo0_oo00000ol0003oooooooooo`1Fooooo`008Ooo
ool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo083ooooo00?oo`00o`000?ooool0E_oo
ool0027ooooo00?o0000ooooooooool0Ioooool00ooo003oooooooooo`22ooooo`03ool00?l0003o
000005Gooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o0000ool00?ooool0Q?ooool00ooo
003oooooo`00001Dooooo`008Oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo08Go
oooo0_oo00000ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool0
0?oooooooooo08Sooooo00?oo`00o`000?ooool0DOooool0027ooooo00?o0000ooooooooool0I?oo
ool00ooo003oooooooooo`2:ooooo`03ool00?l0003o0000053ooooo000Qooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0S?ooool00ooo003oooooo`00001?ooooo`008Oooool3o`00
06?ooooo00?o0000ooooooooool0SOooool00ooo003oooooo`00001>ooooo`008Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo08oooooo00Coo`00ooooool0003o0000C?ooool0027o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Aooooo`04ool00?ooooooooooo`00
04_ooooo000Qooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0U_ooool00ol0003o
ooooooooo`18ooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool0Aoooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`2Iooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool0AOooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0005gooooo00?oo`00o`000?oo
ool0WOooool00ol0003oooooooooo`14ooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo09ko
oooo00?o0000ooooooooool0@oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`1Looooo`03ool00?l0003ooooo
09kooooo0_oo00000ol0003oooooooooo`12ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo
0:3ooooo00?oo`00o`000?ooool0@_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`2Roooo
o`;oo`00@_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`1Jooooo`03ool00?l0003ooooo0:Gooooo00?oo`00o`000?ooool0?oooool0027o
oooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`2Vooooo`03ool00?l0003ooooo03ko
oooo000Qooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0Z?ooool00ooo003o0000
ooooo`0mooooo`008Oooool3o`0005Wooooo00?oo`00ooooooooool0ZOooool00ooo003o0000oooo
o`0looooo`008Oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooooooo0:_ooooo00?oo`00
o`000?ooool0>oooool0027ooooo00?o0000ooooooooool0F?ooool00ooo003oooooooooo`2/oooo
o`03ool00?l0003ooooo03[ooooo000Qooooo`03o`000?oooooooooo05Oooooo00?oo`00oooooooo
ool0[_ooool00ooo003o0000ooooo`0iooooo`008Oooool00ol0003oooooooooo`1Fooooo`03ool0
0?l0003ooooo0;3ooooo00?oo`00o`000?ooool0>?ooool0027ooooo00?o0000ooooooooool0E_oo
ool00ooo003oooooooooo`2booooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooo
oooo05Gooooo00?oo`00ooooooooool0]?ooool00ol0003oooooooooo`0eooooo`008Oooool3o`00
05Gooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo0;Oooooo0_l0000dooooo`008Oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool0<Oooool0027ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo033ooooo000Q
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0^oooool2ool0037ooooo000Qoooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0__ooool00ooo003oooooooooo`0^oooo
o`008Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0<3ooooo00?oo`00o`000?oo
ool0;Oooool0027ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`31ooooo`;oo`00
;Oooool0027ooooo0ol0001@ooooo`03ool00?oooooooooo0<Cooooo00?oo`00ooooooooool0:_oo
ool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003oo`00oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo03_ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM037o
oooo00?oo`00ooooooooool02Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo03gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool01?oo003oooooogMgMolb<S8ooooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool0<Oooool00ooo003oooooooooo`08ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0
027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@00gooooo00Coo`00
oooooooooooo0000?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<Oooool00ooo003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000<ooooo`05ool00?oo
ooooooooogMgMolb<S80?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0<oooool00ooo003o0000ooooo`08ooooo`03oiRHV?lQ8B7ok^k^01_ooooo
000Qooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000;ooooo`06ool0
0?l0003o8B4Qo`000?lb<S;oc<c<?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00eooooo`03ool00?l0003ooooo00Sooooo00?oMgMg
ofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oo`00o`000?ooool0@_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0>?ooool00ooo003o0000ooooo`08ooooo`03o`000?oooooo
oooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?oo`00
ooooool00000@oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41006ooo
ool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo00?o
o`00ooooool000000ol0000nooooo`03oeEEEOmVIVKo000003oooooo00?oEEEEofIVI_l000003Ooo
ool4o`0003[ooooo00Wo0000oooooooooooooooooiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027o
oooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0027ooooo
00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Eooooo`03o`000?oooooooooo01kooooo
000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ol0003ooooooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`19ooooo`03ool00?oooooooooo0=Wooooo00?o0000
ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`19oooo
o`03ool00?oooooooooo0=[ooooo00?oo`00ooooooooool04Oooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@Cooooo000Joooooe;o000000?oo`00o`000?l00000g?l000000ooo003o0000o`000005
o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^1Ooo
ool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`;o00003_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
1?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool2o`000003ool00?oooooooooo04Gooooo00?o0000
ooooooooool0l?ooool2o`0000;ooooo0_l00004ooooo`008Oooool2o`000003ool00?oooooooooo
04Cooooo00?o0000ooooooooool0noooool0027ooooo00?o0000oooooooo0000A_ooool00ol0003o
ooooooooo`3kooooo`008Oooool01?l0003oooooo`000?oo0014ooooo`03o`000?oooooooooo0?co
oooo000Qooooo`04o`000?oooooo0000ool004?ooooo00?o0000ooooooooool0oOooool0027ooooo
0ol000000ooo003oooooooooo`11ooooo`03o`000?oooooooooo0?gooooo000Qooooo`05o`000?oo
ooooooooo`000?oo0000@Oooool00ooo003oooooooooo`3nooooo`008Oooool01Ol0003ooooooooo
ooooooooo`00047ooooo00?oo`00ooooooooool0o_ooool0027ooooo00Go0000oooooooooooooooo
ool00010ooooo`03ool00?oooooooooo0?oooooo000Qooooo`06o`000?ooooooooooooooool0003o
o`00?oooool00ooo003oooooooooo`3oooooo`008Oooool00ol0003oooooooooo`02ooooo`03ool0
0?oooooooooo03cooooo00?oo`00ooooooooool0ooooool1ooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo03_ooooo00?oo`00o`000?ooool0ooooool2ooooo`008Oooool3
o`0000;ooooo00?o0000ool00?ooool0>oooool00ooo003oooooooooo`3oooooo`;ooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ooo003o
ooooooooo`3oooooo`?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=oooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0=oooool00ooo003oooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`3oooooo`Gooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003o0000ooooo`3ooooo
o`Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool00ooo003o
ooooooooo`3oooooo`Kooooo000Qooooo`?o00001_ooool00ol0003oooooooooo`0booooo`03ool0
0?l0003ooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027ooooo00?o0000oooo
ooooool01oooool00ol0003oo`00ooooo`0`ooooo`03o`000?oooooooooo0?oooooo2?ooool0027o
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0]ooooo`03o`00
0?oooooooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oo`00oooo
o`0]ooooo`03o`000?oooooooooo0?oooooo2_ooool0027ooooo0ol00009ooooo`03ool00?oooooo
oooo02_ooooo00?o0000ooooooooool0ooooool;ooooo`008Oooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo02[ooooo00?o0000ooooooooool0ooooool<ooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0ooooool=ooooo`00
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo003ooooo02Sooooo00?oo`00ooooooooool0
ooooool=ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo02Kooooo00?o
o`00ooooooooool0ooooool>ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0<ooooo`03ool0
0?oooooooooo02Cooooo00?oo`00ooooooooool0ooooool?ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo3oooool000Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`03ool0
0?oooooooooo02;ooooo00?oo`00ooooooooool0ooooool@ooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oo003ooooo027ooooo00?o0000ool00?ooool0oooooolAooooo`001oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`3ooooooa7ooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`3ooooooa;ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07Oooool00ol0003oo`00ooooo`3ooooooa?ooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oo003ooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo003ooooo0?oooooo5Oooool0027ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo003ooooo0?oooooo5_oo
ool0027ooooo0ol0000Booooo`03o`000?oooooooooo01Kooooo00?o0000ool00?ooool0oooooolG
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0oooooolHooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo017o
oooo0_l0003ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Gooooo0_oo000@ooooo`03o`00
0?oooooooooo0?oooooo6oooool0027ooooo00?o0000ooooooooool05oooool00ooo003ooooooooo
o`0;ooooo`;o0000oooooolNooooo`008Oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooo
oooo00[ooooo00?o0000ooooooooool0oooooolNooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`;oo`0000?o0000ooooooooool01Oooool2o`000003ool00?oooooooooo0?oooooo7_ooool0027o
oooo0ol0000Jooooo`Coo`000_l00004ool00?oooooo8Oooool0027ooooo00?o0000ooooooooool0
7Oooool4ool00?oooooo9?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_oo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIV
ooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMoooo
o`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7
o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000
o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`00
00Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo
01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM07[ooooo001nooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oo
oooooooo00_ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo
00Wo0000oooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooo
oooo410@okZj^P?ooooo00?ok^k^o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0NOooool007kooooo00Oo0000oooooooMgMgo<S8b
ooooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`;o
MgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co410@omgMgOoo
oooo00001Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0N?ooool007kooooo00CoEEEEojVYZOoooooo00000_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP06ooooo`03oc8b<_oooooo
oooo00?ooooo00?oV9RHob4Q8Oo^k^h02oooool01?n7QhOoIVIVooooool00005ooooo`03o`000?oo
oooooooo00[ooooo1_l00004ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0NOoo
ool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o0000
ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?oMgMg
ofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo00?o
0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07[ooooo001oooooo`03oiRHV?mg
MgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo00?o
gMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo1ol0
0002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1looooo`00U_ooool00ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00WogMgM
oa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@41004_ooool00oo^k^ko410@omgMg@0Fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0O?ooool009Kooooo00?o0000ooooooooool0
1oooool00onj^[[oA4A4ooooo`05ooooo`08ogMgMomVIVKooooooiRHV?l@413o0000ob4Q8Oo<c<`B
ooooo`03ofIVI_mgMgOooooo01Cooooo00?oEEEEofIVI_l000003Oooool4o`0007_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .33605 L
.06244 .36245 L
.08426 .38662 L
.0949 .3959 L
.10458 .40266 L
.10911 .40524 L
.11403 .40762 L
.11828 .40931 L
.12297 .41077 L
.12536 .41136 L
.12793 .41187 L
.12935 .4121 L
.13065 .41227 L
.13197 .41242 L
.13319 .41253 L
.13431 .4126 L
.13551 .41265 L
.13619 .41267 L
.13683 .41268 L
.13803 .41267 L
.13919 .41264 L
.14025 .41259 L
.14141 .41252 L
.14264 .41241 L
.14518 .4121 L
.14759 .4117 L
.15211 .41067 L
.15698 .40918 L
.16227 .40711 L
.1718 .40227 L
.18061 .39661 L
.19927 .38132 L
.21987 .36024 L
.26008 .31097 L
.29876 .25966 L
.3399 .20732 L
.37953 .16326 L
.41764 .12888 L
.43889 .11341 L
.4582 .10171 L
.47851 .09177 L
.49724 .08473 L
.51643 .07956 L
.52653 .07764 L
.53212 .0768 L
.53723 .07619 L
.54207 .07572 L
.54666 .07539 L
.54918 .07525 L
Mistroke
.55151 .07515 L
.55283 .0751 L
.55407 .07507 L
.55476 .07505 L
.5555 .07504 L
.5568 .07502 L
.55795 .07501 L
.55901 .07501 L
.56019 .07501 L
.56144 .07502 L
.56276 .07503 L
.56401 .07506 L
.56513 .07509 L
.56634 .07512 L
.56855 .07521 L
.5709 .07532 L
.57511 .07559 L
.58002 .076 L
.58451 .07646 L
.59462 .07783 L
.60354 .07939 L
.61292 .08137 L
.65108 .09271 L
.67073 .10042 L
.69169 .10986 L
.73324 .13185 L
.77327 .15645 L
.81179 .18261 L
.85276 .21245 L
.89222 .24258 L
.93016 .27237 L
.97055 .30451 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .33623 L
.06244 .36302 L
.08255 .38544 L
.09396 .39536 L
.10458 .40257 L
.10961 .40528 L
.11508 .4077 L
.12023 .40948 L
.12269 .41016 L
.125 .4107 L
.12724 .41113 L
.12929 .41144 L
.13156 .4117 L
.13282 .41181 L
.13401 .41188 L
.13516 .41193 L
.13638 .41195 L
.13754 .41195 L
.13858 .41193 L
.13982 .41188 L
.14051 .41184 L
.14115 .41179 L
.14357 .41156 L
.14483 .4114 L
.14603 .41123 L
.14827 .41083 L
.15331 .40964 L
.15766 .40828 L
.1624 .40646 L
.17313 .40109 L
.18306 .39467 L
.20172 .37928 L
.22233 .35813 L
.26253 .3086 L
.30122 .25684 L
.34236 .20403 L
.38198 .15978 L
.42009 .12569 L
.44134 .11066 L
.46065 .09949 L
.48074 .09033 L
.4997 .08389 L
.50942 .08139 L
.51971 .0793 L
.5285 .07796 L
.53349 .07738 L
.53816 .07695 L
.54314 .0766 L
.54596 .07646 L
Mistroke
.5473 .07641 L
.54857 .07636 L
.54978 .07633 L
.55108 .0763 L
.55227 .07628 L
.55335 .07627 L
.55454 .07626 L
.55583 .07626 L
.55649 .07626 L
.55719 .07627 L
.55845 .07628 L
.55969 .0763 L
.56084 .07633 L
.56343 .07641 L
.56572 .0765 L
.56815 .07663 L
.57235 .07691 L
.57699 .0773 L
.58711 .07846 L
.59637 .07987 L
.61724 .08422 L
.6362 .08946 L
.65692 .09645 L
.69753 .11352 L
.73663 .13358 L
.77818 .1582 L
.81821 .18468 L
.85673 .21241 L
.8977 .24405 L
.93716 .27626 L
.9751 .3081 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Pooooo`_o0000VOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2Iooooo`03o`000?oo003oo`0000goo`000_oo
ool7o`0009;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0U?ooool6
ool001Sooooo00Co0000ool00?oo003oo`000_l0002<ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo093ooooo0_l00002ool002;ooooo1?oo00000ol0003oooooooooo`27
ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo08kooooo0_l000000ooo
ooooo`00ooooo`0Wooooo`?oo`0000?o0000ooooooooool0Q?ooool0027ooooo00?o0000oooooooo
ool0S?ooool2o`0002oooooo0_oo0002o`0008?ooooo000Qooooo`03o`000?oooooooooo08[ooooo
0_l0000cooooo`?oo`000_l00020ooooo`008Oooool3o`0008Sooooo0_l0000hooooo`03ool00?oo
oooo000000;o0000OOooool0027ooooo00?o0000ooooooooool0QOooool3ool003oooooo0_l0001k
ooooo`008Oooool00ol0003oooooooooo`23ooooo`;oo`0000?o0000ooooooooool0@Oooool3o`00
07Sooooo000Qooooo`03o`000?oooooooooo087ooooo0_oo00000ol0003oooooooooo`16ooooo`;o
0000M_ooool0027ooooo00?o0000ooooooooool0Ooooool2ool00003o`000?oooooooooo04Sooooo
0ooo00000ol0003oooooooooo`1booooo`008Oooool00ol0003oooooooooo`1nooooo`03ool00?l0
003ooooo04kooooo0ooo001booooo`008Oooool00ol0003oooooooooo`1looooo`;oo`00E?ooool2
ool0073ooooo000Qooooo`?o0000Noooool00ooo003o0000ooooo`1Fooooo`03ool00?l0003ooooo
06gooooo000Qooooo`03o`000?oooooooooo07[ooooo00?oo`00ooooooooool0F?ooool2ool006go
oooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0Foooool2ool006_ooooo
000Qooooo`03o`000?oooooooooo07Oooooo0_l0001Pooooo`03ool00?l0003ooooo06Sooooo000Q
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0HOooool00ooo003o0000o`00001W
ooooo`008Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool0027ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`1Wooooo`;o
0000I?ooool0027ooooo0ol0001cooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
HOooool0027ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`1/ooooo`;o0000HOoo
ool0027ooooo00?o0000ooooooooool0LOooool00ooo003oooooooooo`1_ooooo`;oo`00Goooool0
027ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`1aooooo`03o`000?oo003oo`00
05gooooo000Qooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0M?ooool00ol0003o
o`00ool0001Kooooo`008Oooool00ol0003oooooooooo`1^ooooo`03ool00?oooooooooo07Kooooo
0_l00002ool005Wooooo000Qooooo`03o`000?oooooooooo06gooooo00?oo`00ooooooooool0NOoo
ool00ol0003oooooool0001Hooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooo
oooo07_ooooo0_l00002ool005Kooooo000Qooooo`?o0000Joooool00ooo003o0000ooooo`1noooo
o`04o`000?ooooooo`00ool005Cooooo000Qooooo`03o`000?oooooooooo06[ooooo00?oo`00o`00
0?ooool0P?ooool2o`000003oooooooo003ooooo05;ooooo000Qooooo`03o`000?oooooooooo06Wo
oooo00?oo`00o`000?ooool0Poooool00ol0003oooooool0001Booooo`008Oooool00ol0003ooooo
ooooo`1Xooooo`03ool00?l0003ooooo08Gooooo0_l0001Booooo`008Oooool00ol0003ooooooooo
o`1Wooooo`03ool00?l0003ooooo08Sooooo00?o0000ooooooooool0Coooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0I_ooool00ooo003o0000ooooo`2:ooooo`;o0000Coooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1<ooooo`001Ol0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000
I_ooool00ol0003oooooooooo`2=ooooo`;o0000C?ooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo04Wooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`2Booooo`03o`000?oo003oo`0004Sooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0UOooool00ol0003oo`00ooooo`16ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo09Oo
oooo00?o0000ool00?oo0000AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09Wooooo0_l000000ooo003o
ooooooooo`12ooooo`008Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09cooooo
00?o0000ool00?ooool0@_ooool0027ooooo00?o0000ooooooooool0Goooool00ooo003o0000oooo
o`2Nooooo`03o`000?oo003oo`00047ooooo000Qooooo`?o0000Goooool00ooo003oooooooooo`2P
ooooo`03o`000?oo003ooooo03oooooo000Qooooo`03o`000?oooooooooo05kooooo00?oo`00oooo
ooooool0X_ooool00ol0003oo`00ooooo`0nooooo`008Oooool00ol0003oooooooooo`1Mooooo`03
ool00?oooooooooo0:Cooooo00?o0000ool00?ooool0?Oooool0027ooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`2Wooooo`03ool00?oooooooooo03_ooooo000Qooooo`03o`000?oo
oooooooo05cooooo00?oo`00ooooooooool0Z?ooool00ol0003oooooooooo`0jooooo`008Oooool0
0ol0003oooooooooo`1Kooooo`03ool00?oooooooooo0:[ooooo00?o0000ooooooooool0>Oooool0
027ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`2/ooooo`;o0000>Oooool0027o
oooo0ol0001Iooooo`03ool00?oooooooooo0:oooooo00?o0000ooooooooool0=_ooool0027ooooo
00?o0000ooooooooool0F?ooool00ol0003oo`00ooooo`2aooooo`03o`000?oooooooooo03Gooooo
000Qooooo`03o`000?oooooooooo05Oooooo00?o0000ool00?ooool0/oooool2o`0003Gooooo000Q
ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0]Oooool2ool003?ooooo000Qoooo
o`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool0]oooool00ol0003oo`00ooooo`0aoooo
o`008Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;Wooooo00?o0000ool00?oo
ool0<?ooool0027ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2kooooo`03o`00
0?oo003oo`0002oooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0__oo
ool00ol0003oo`00ooooo`0]ooooo`008Oooool3o`0005?ooooo00?o0000ooooooooool0_oooool0
0ol0003oo`00ooooo`0/ooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bo`00000mooooo`Co000000?o
410@ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd0;oooool00ol0003oo`00ool0000;ooooo`Go00006oooool0027ooooo00?o
0000ooooooooool0?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03o`00
0?lb<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0_ooooo`03o`000?ooooooo`0000[ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooo`00000oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0_ooooo`;o000000?oo`00ooooooooool02?ooool00onHV9So
8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`0mooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oMgMgoc8b<P0oooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool03_ooool00omgMgOo<S8booooo`0booooo`03o`000?oo003ooooo00Wooooo00?oV9RHob4Q8Oo^
k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ool00?l0003o<S8bolc<c00oooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Cooooo00?o0000ooooooooool02Oooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oo`00ooooo`11ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o00002_ooool00ol0003oooooooooo`0I
ooooo`008Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oo003o
oooo04;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03ool00?l0
003o000000;o0000?_ooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0
000iooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Ooo
ool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo0=7ooooo00?o0000ooooooooool08Ooo
ool0027ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`3Cooooo`;o00008Oooool0
027ooooo00?o0000ooooooooool0B_ooool00ol0003oo`00ooooo`3Fooooo`03ool00?oooooooooo
01kooooo000Qooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0eoooool00ooo003o
ooooooooo`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo04Wooooo
00?oo`00ooooooooool0fOooool00ooo003o0000ooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0
003ogMgM1?ooool001[ooooo1ol000000ooo003o0000o`000018o`000003ool00?l0003o00000=_o
00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo00gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@
413ok^k^1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
ool00?l0003ooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000oooooooo
0000A_ooool00ooo003oooooooooo`3aooooo`;o00000_ooool2o`0000Cooooo000Qooooo`04o`00
0?oooooo0000ool004Cooooo00?o0000ooooooooool0o?ooool0027ooooo00Co0000oooooooooooo
o`00@oooool00ol0003oooooooooo`3mooooo`008Oooool01Ol0003oooooooooooooooooo`00047o
oooo00?o0000ooooooooool0o_ooool0027ooooo00Ko0000ooooooooooooooooo`000?oo0010oooo
o`03o`000?oooooooooo0?kooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo0?oooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`3oooooo`7ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`3oooooo`;ooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3oooooo`?ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`3ooooo
o`?ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Oooool00ooo003o
ooooooooo`3oooooo`Cooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=?ooool00ooo003oooooooooo`3oooooo`Gooooo000Qooooo`?o00001oooool00ol0003oo`00oooo
o`0booooo`03ool00?oooooooooo0?oooooo1_ooool0027ooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`0`ooooo`03ool00?oooooooooo0?oooooo1oooool0027ooooo00?o0000oooo
ooooool02Oooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo0?oooooo2?ooool0027o
oooo00?o0000ooooooooool02Oooool00ol0003oo`00ooooo`0]ooooo`03ool00?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oo`00ooooo`0[ooooo`03ool0
0?oooooooooo0?oooooo2_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oo`00oooo
o`0Yooooo`03ool00?oooooooooo0?oooooo2oooool0027ooooo00?o0000ooooooooool03?ooool0
0ol0003oo`00ooooo`0Wooooo`03ool00?oooooooooo0?oooooo3?ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol0003oo`00ooooo`0Uooooo`03ool00?oooooooooo0?oooooo3Oooool0027o
oooo0ol0000>ooooo`03o`000?oo003ooooo02;ooooo00?o0000ool00?ooool0ooooool?ooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo003ooooo023ooooo00?o0000ooooooooool0
ooooool@ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo003ooooo01kooooo00?o
0000ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003o
oooo01_ooooo00?o0000ooooooooool0oooooolBooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03ool00?l0003ooooo01Wooooo00?o0000ooooooooool0oooooolCooooo`008Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo0_l0003ooooooaKooooo000Qooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ooo003o0000ooooo`3ooooooaOooooo
000Qooooo`?o00005oooool3o`00013ooooo00?oo`00ooooooooool0oooooolHooooo`008Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo0ooo003ooooooa_ooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ool00?oo00002Ooo00000ol0003oooooooooo`3ooooo
oa_ooooo000Qooooo`03o`000?oooooooooo01kooooo1_l0003oooooob7ooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00
Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo
00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj
^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`05ooooo`03ogMgMolb<S;ooooo07Cooooo001kooooo`07o`00
0?oooooogMgMoc8b<_ooooook^k^oa0@4002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool2ogMgM`Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0<oooo
o`04oa0@4?oMgMgoooooo`0000Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEEojVY
ZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo00?o
k^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00Co
QhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00?o
gMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=ooooo`03o`000?oooooooooo00Oooooo
00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05ooooo`03ogMgMomVIVKooooo00[ooooo
00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000ooooo`0Fooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0MOooool0
07cooooo00?oV9RHogMgMoooool00_ooool00ol0003oooooooooo`0<ooooo`03oa0@4?l0003o0000
00?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEEEOmgMgOooooo00Kooooo00?o0000oooo
ooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07Oooooo002Booooo`03o`000?oooooooooo00So
oooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02ooooo`05o`000?nj^[[ooooooiRH
V?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1gooooo`00T_ooool00ol0003oooooooooo`08ooooo`03
okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`04Ooo
ool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo000000gooooo1?l00004ooooo`Co0000M_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .29673 L
.06244 .28587 L
.07286 .28156 L
.08255 .27858 L
.08813 .27733 L
.0932 .27649 L
.096 .27614 L
.09748 .276 L
.09905 .27586 L
.10042 .27577 L
.10192 .27569 L
.10258 .27566 L
.1033 .27563 L
.10458 .2756 L
.10526 .27559 L
.10591 .27558 L
.10712 .27558 L
.10841 .27559 L
.10915 .2756 L
.10982 .27562 L
.11095 .27566 L
.11219 .27572 L
.11468 .27587 L
.11744 .2761 L
.12039 .27642 L
.12571 .27715 L
.13622 .27912 L
.1458 .28136 L
.1665 .28686 L
.18565 .29162 L
.19524 .29357 L
.20423 .29501 L
.20913 .29563 L
.21362 .29608 L
.2186 .29645 L
.22122 .29658 L
.22254 .29664 L
.22398 .29668 L
.2253 .29671 L
.22652 .29674 L
.22715 .29674 L
.22785 .29675 L
.22858 .29675 L
.22926 .29675 L
.23052 .29674 L
.23167 .29673 L
.2323 .29671 L
.233 .2967 L
.23425 .29666 L
Mistroke
.2366 .29657 L
.2391 .29643 L
.24359 .2961 L
.24925 .29551 L
.25458 .29479 L
.26454 .29303 L
.27433 .29079 L
.28466 .28791 L
.30314 .2816 L
.34117 .26502 L
.38164 .24443 L
.4206 .22441 L
.46202 .2053 L
.50191 .19054 L
.52017 .18522 L
.5403 .18047 L
.56011 .17696 L
.57096 .17554 L
.57582 .17502 L
.58113 .17453 L
.5859 .17416 L
.59099 .17384 L
.59381 .17369 L
.59636 .17359 L
.59896 .17349 L
.60135 .17343 L
.60358 .17338 L
.6047 .17336 L
.60593 .17335 L
.60717 .17333 L
.60786 .17333 L
.60849 .17333 L
.60972 .17333 L
.61088 .17333 L
.61197 .17333 L
.61312 .17334 L
.6141 .17335 L
.61519 .17337 L
.6176 .17342 L
.61987 .17348 L
.62456 .17365 L
.62969 .1739 L
.63504 .17425 L
.64003 .17465 L
.65853 .17672 L
.66903 .1783 L
.67896 .18006 L
.69754 .18401 L
.73597 .1947 L
.77686 .20931 L
Mistroke
.81623 .22599 L
.85409 .24393 L
.89439 .26454 L
.93318 .28537 L
.97443 .30804 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .29825 L
.06244 .28751 L
.07286 .28306 L
.08255 .27987 L
.08813 .27848 L
.0932 .2775 L
.096 .27707 L
.09905 .27669 L
.10192 .27641 L
.10329 .27631 L
.10458 .27623 L
.10574 .27617 L
.10701 .27612 L
.10817 .27609 L
.10924 .27607 L
.11051 .27606 L
.11166 .27606 L
.1123 .27606 L
.11299 .27608 L
.11425 .2761 L
.11534 .27614 L
.11654 .27619 L
.11897 .27633 L
.12121 .27649 L
.12331 .27668 L
.12851 .27728 L
.13326 .27796 L
.14393 .27993 L
.18378 .28948 L
.202 .29329 L
.20699 .29413 L
.21237 .29491 L
.21702 .29548 L
.22211 .29597 L
.22454 .29616 L
.22713 .29632 L
.22857 .2964 L
.22987 .29646 L
.2312 .29651 L
.23242 .29654 L
.23356 .29657 L
.23476 .29659 L
.23596 .2966 L
.23665 .2966 L
.23729 .2966 L
.23844 .2966 L
.2395 .29658 L
.24072 .29656 L
.24188 .29653 L
Mistroke
.24321 .29649 L
.24441 .29644 L
.2471 .29629 L
.24959 .29612 L
.25193 .29593 L
.2572 .29536 L
.26289 .29456 L
.27242 .29279 L
.28287 .29022 L
.30394 .28325 L
.34442 .26456 L
.38338 .24308 L
.42479 .2205 L
.46469 .20197 L
.50307 .18868 L
.52289 .18372 L
.53301 .18169 L
.54391 .17985 L
.55409 .17846 L
.56342 .17746 L
.57233 .17672 L
.57682 .17643 L
.58171 .17618 L
.58426 .17607 L
.58701 .17597 L
.58944 .1759 L
.59201 .17584 L
.59433 .1758 L
.59565 .17579 L
.59688 .17578 L
.59801 .17577 L
.59904 .17576 L
.60023 .17576 L
.60136 .17576 L
.60256 .17577 L
.60324 .17577 L
.60389 .17578 L
.60518 .17579 L
.60657 .17581 L
.60909 .17585 L
.6114 .1759 L
.61672 .17607 L
.62232 .17631 L
.63185 .17687 L
.64204 .17767 L
.6604 .17964 L
.68172 .18274 L
.70186 .18646 L
.7403 .19576 L
.78119 .20901 L
Mistroke
.82056 .22509 L
.85841 .24328 L
.89872 .2648 L
.93751 .28663 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`2[oooooaOo0000P_oo
ool0027ooooo00?o0000ooooooooool0X_ooool3o`0000Koo`002_ooool=ool000Go0000OOooool0
027ooooo00?o0000ooooooooool0WOooool00ol0003oo`00ool00005ool001gooooo0ooo0002oooo
o`Oo0000M_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0V_ooool01?l0003oo`00ool00?oo
000`ooooo`Go0000LOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo09Kooooo1?l0000eooooo`Goo`000_l0
001^ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o0000T_ooool4o`0003kooooo1?oo00000ol0003oooooooooo`1Yooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`2?ooooo`;oo`0000?o0000ooooooooool0A?ooool4ool006Sooooo0007ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
S?ooool3ool004gooooo0ooo001Uooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`29ooooo`?oo`00Doooool3o`0006;ooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo08Kooooo0ooo00000ol0003oooooooooo`1Fooooo`?o0000Goooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`24ooooo`;oo`00
00?o0000ooooooooool0G?ooool3o`0005cooooo000Qooooo`03o`000?oooooooooo08;ooooo0_oo
00000ol0003oooooooooo`1Qooooo`03o`000?oo003oo`0000;oo`00Eoooool0027ooooo00?o0000
ooooooooool0POooool00ooo003o0000ooooo`1Wooooo`;o00000ooo001Dooooo`008Oooool3o`00
07kooooo0ol0001]ooooo`;o000000?oo`00ooooooooool0DOooool0027ooooo00?o0000oooooooo
ool0O?ooool2o`0007;ooooo0_l0001Booooo`008Oooool00ol0003oooooooooo`1jooooo`;o0000
M_ooool3o`0004oooooo000Qooooo`03o`000?oooooooooo07Oooooo0_oo00000ol0003ooooooooo
o`1iooooo`;o0000COooool0027ooooo00?o0000ooooooooool0MOooool2ool00003o`000?oooooo
oooo07gooooo0_l0001;ooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?l0003ooooo
08;ooooo00?o0000ool00?oo0000B?ooool0027ooooo00?o0000ooooooooool0L_ooool2ool008Oo
oooo00?o0000ool00?oo0000A_ooool0027ooooo0ol0001`ooooo`;oo`00Roooool00ol0003oo`00
ool00014ooooo`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oo003ooooo08kooooo00?o
0000ool00?oo0000@_ooool0027ooooo00?o0000ooooooooool0K?ooool00ol0003oo`00ool0002B
ooooo`03o`000?oo003oo`00043ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ool0
0?oo0000U_ooool00ol0003oo`00ool0000nooooo`008Oooool00ol0003oooooooooo`1Xooooo`;o
000000?oo`00ooooooooool0V?ooool00ol0003oo`00ool0000looooo`008Oooool00ol0003ooooo
ooooo`1Vooooo`;o0000Woooool00ol0003oo`00ooooo`0jooooo`008Oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo0:7ooooo0_l0000iooooo`008Oooool00ol0003oooooooooo`1S
ooooo`;o0000Y_ooool2o`0003Oooooo000Qooooo`?o0000HOooool2o`000:[ooooo0_l0000eoooo
o`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0<ooooo`;oo`00;oooool4o`000003oa0@4?oooooo
oooo03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM02Sooooo0_l0000Cooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Wooooo0_oo
000cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0:Oooool2ool0017ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Kooooo`008Ooo
ool00ol0003oooooooooo`0mooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`05ooooo`?oo`00=Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0:Oooool00ol0003oo`00ool0000@ooooo`03oiRHV?lQ8B7ok^k^01cooooo
000Qooooo`03o`000?oooooooooo017ooooo3ol0000Mooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`;oo`00>?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool0;?ooool00ol0003oo`00ool0000?ooooo`03oiRH
V?lQ8B7ok^k^01_ooooo000Qooooo`03o`000?oooooooooo00oooooo1Ooo000:ooooo`Soo`005ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`;o
o`00>_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c00_ooooo`03o`000?oo003oo`0000kooooo00?oMgMgofIVI_ooool06_ooool0027o
oooo00?o0000ooooooooool02oooool01?l0003oo`00ool00?oo000Dooooo`?o00000ooo000Doooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`03ooooo`;oo`00??ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool2
o`0000;oo`003Oooool00ol0003oooooooooo`0Iooooo`008Oooool3o`0000Sooooo0_l00002ool0
01cooooo00Go0000ool00?oo003oo`00o`00000@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool01?l0003oooooooooool00002ool003kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03Cooooo0_l00002ool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo003oo`0002;ooooo
0_oo0002o`0000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGo
IVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000eooooo`;o000000?oo`00oooooooo
ool01?ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ool00?oo0000:?ooool3o`0001Cooooo1ol0003?ooooo`03o`000?oo003ooooo02Co
oooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0;?ooool5o`00017oo`00
e_ooool00ooo003o0000ooooo`0Rooooo`008Oooool00ol0003oooooooooo`02ooooo`;o0000>?oo
ool4o`000>7ooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool00_l0003o
ooooob7ooooo0_l0000Fooooo`;o00000_ooool2o`0000Cooooo000Qooooo`?o0000oooooolUoooo
o`;o00005?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<
ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0A
ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo0?oooooo>oooool2
o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Co
oooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Hoooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Sooooo`00Qoooool3o`00
01?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM
0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP03ooooo`03o`000?oooooo
oooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`03oiRHV?mEEEGooooo00Oooooo00Co
EEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;ooooo00?o^[ZjodA4A?ooool0
0_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c01kooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40Nooo
ool007kooooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRH
V?lQ8B7ok^k^00cooooo00Co410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00001kooooo`00O_ooool01?mEEEGo
ZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05
ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o
0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q07_ooooo001nooooo`03omgMgOlQ
8B7ok^k^00?ooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00Kooooo00?o
EEEEoiRHV?ooool01Oooool00ol0003ok^k^ooooo`04ooooo`03ogMgMomVIVKooooo00[ooooo00Co
gMgMoa0@4?oooooo00001?ooool00oo^k^ko0000ooooo`0Eooooo`03o`000?oooooooooo00[ooooo
00Go0000oeEEEOl0003o410@olc<c01kooooo`00Ooooool00onHV9SoMgMgooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03omgMgOl@413ooooo00Gooooo
00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo00000_ooool00omgMgOoEEEE
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?oEEEEohN7Qoooool0OOooool009Kooooo00?o
0000ooooooooool01oooool00omEEEGoV9RHooooo`04ooooo`09omgMgOl@413ok^k^ooooool0003o
^[ZjoooooonHV9So410@01;ooooo00?ok^k^oa0@4?oMgMd05_ooool00ol0003oooooooooo`0:oooo
o`03omgMgOl@413oV9RH07gooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?oo
ool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgoooo
o`0Dooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4A?l0003o410@Noooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .27166 L
.06244 .2354 L
.08426 .20222 L
.0949 .18931 L
.10458 .17963 L
.11403 .17216 L
.12297 .16694 L
.12787 .16483 L
.1324 .16335 L
.13476 .16276 L
.13737 .16224 L
.13868 .16204 L
.14009 .16186 L
.14142 .16173 L
.14264 .16165 L
.14392 .16159 L
.14514 .16157 L
.14622 .16157 L
.1474 .1616 L
.14869 .16167 L
.14934 .16172 L
.15005 .16178 L
.15248 .16207 L
.15476 .16244 L
.15721 .16295 L
.16162 .16415 L
.16719 .16616 L
.17246 .16855 L
.18234 .17418 L
.20225 .18929 L
.22067 .2064 L
.25994 .24628 L
.29769 .28113 L
.31866 .29699 L
.33789 .30893 L
.35674 .31819 L
.36633 .32201 L
.37658 .32543 L
.38693 .32824 L
.39632 .33025 L
.40577 .33179 L
.41469 .33282 L
.41932 .33321 L
.42441 .33351 L
.42698 .33362 L
.42839 .33367 L
.42973 .33371 L
.43097 .33374 L
.43163 .33375 L
Mistroke
.43233 .33376 L
.43356 .33377 L
.4347 .33378 L
.43595 .33378 L
.4371 .33378 L
.43836 .33377 L
.439 .33376 L
.43969 .33375 L
.44087 .33373 L
.44212 .33371 L
.44439 .33364 L
.44675 .33355 L
.44898 .33345 L
.45316 .33322 L
.46284 .33245 L
.47311 .33134 L
.49154 .32869 L
.52934 .32149 L
.5696 .31275 L
.60834 .3047 L
.64953 .29754 L
.67009 .2947 L
.6892 .29256 L
.70767 .29097 L
.71799 .29029 L
.72737 .28979 L
.73223 .28959 L
.73737 .2894 L
.74182 .28927 L
.74659 .28916 L
.74927 .28911 L
.75171 .28908 L
.75417 .28905 L
.75651 .28903 L
.75782 .28902 L
.75854 .28902 L
.75921 .28901 L
.7604 .28901 L
.76172 .28901 L
.76241 .28901 L
.76315 .28901 L
.76445 .28901 L
.76518 .28902 L
.76586 .28902 L
.7674 .28903 L
.76867 .28904 L
.77002 .28905 L
.77244 .28908 L
.77791 .28917 L
.78263 .28928 L
Mistroke
.78783 .28943 L
.79743 .28978 L
.80641 .29021 L
.82667 .29148 L
.8452 .29297 L
.88493 .29705 L
.92315 .30179 L
.96381 .3073 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.04262 .27083 L
.06244 .23352 L
.08255 .20253 L
.09396 .18883 L
.10458 .17875 L
.10961 .17489 L
.11508 .17135 L
.11989 .16879 L
.125 .16664 L
.12959 .16519 L
.13221 .16456 L
.13466 .1641 L
.13581 .16393 L
.1369 .16378 L
.13789 .16368 L
.13895 .16358 L
.1401 .16351 L
.14116 .16346 L
.14243 .16343 L
.14357 .16344 L
.14477 .16346 L
.1459 .16352 L
.14713 .1636 L
.14845 .16372 L
.15114 .16406 L
.1536 .16448 L
.15833 .16558 L
.16282 .16697 L
.17279 .17113 L
.18364 .17718 L
.20341 .19147 L
.22442 .20986 L
.26217 .24623 L
.30238 .28264 L
.34106 .31012 L
.3611 .32056 L
.3713 .32483 L
.3822 .32862 L
.39255 .3315 L
.40194 .33352 L
.40648 .3343 L
.41139 .33501 L
.41569 .33551 L
.42031 .33594 L
.42287 .33612 L
.4252 .33626 L
.42755 .33637 L
.42978 .33644 L
.43103 .33647 L
Mistroke
.43171 .33649 L
.43236 .3365 L
.43362 .33651 L
.43476 .33652 L
.43542 .33652 L
.43612 .33652 L
.43737 .33651 L
.43806 .33651 L
.43871 .3365 L
.44019 .33647 L
.4415 .33644 L
.44292 .33639 L
.44551 .33628 L
.45035 .336 L
.456 .33555 L
.46123 .33502 L
.47993 .33232 L
.50055 .32819 L
.5408 .31808 L
.57954 .3079 L
.59923 .30319 L
.62074 .2987 L
.64154 .29516 L
.66041 .2927 L
.67053 .29169 L
.68006 .29093 L
.69013 .29032 L
.6958 .29007 L
.70102 .28989 L
.70571 .28977 L
.70834 .28973 L
.71074 .28969 L
.71183 .28968 L
.71298 .28967 L
.71424 .28966 L
.71541 .28966 L
.71649 .28965 L
.71751 .28965 L
.71862 .28965 L
.71983 .28965 L
.72112 .28966 L
.72233 .28967 L
.72365 .28968 L
.72507 .28969 L
.72796 .28973 L
.7306 .28978 L
.73568 .2899 L
.74048 .29005 L
.75019 .29043 L
.76047 .29095 L
Mistroke
.77891 .29214 L
.81677 .29516 L
.85708 .29863 L
.89587 .3019 L
.93711 .30548 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo1_l0003o
oooooakooooo000Qooooo`03o`000?oooooooooo01gooooo00Go0000ool00?oo003oo`00o`000004
ooooo`Co0000oooooolKooooo`008Oooool3o`0001cooooo0_oo000<ooooo`;o0000oooooolIoooo
o`008Oooool00ol0003oooooooooo`0Iooooo`?oo`003oooool3ool00003o`000?oooooooooo0?oo
oooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ooo003o0000o`00000Cooooo`03ool0
0?l0003o00000?oooooo5?ooool0027ooooo00?o0000ooooooooool06?ooool00ooo003ooooooooo
o`0Dooooo`;oo`0000?o0000ooooooooool0oooooolAooooo`008Oooool00ol0003oooooooooo`0F
ooooo`;oo`006Oooool00ooo003o0000ooooo`3ooooooa7ooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo01Gooooo00?oo`00o`000?ooool06_ooool00ooo003o0000ooooo`3ooooooa3ooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0Dooooo`03ool00?l0003ooooo01cooooo00?oo`00o`000?ooool0oooo
ool?ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`02ooooo`?o00004oooool00ooo003o0000ooooo`0Nooooo`03ool00?l0003o00000?oooooo3_oo
ool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`;oo`0000?o0000ooooooooool0oooo
ool;ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08_ooool00ooo003o0000
ooooo`3oooooo`_ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ooo003o0000
ooooo`3oooooo`[ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`3oooooo`Sooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0?oooooo
1oooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0?oooooo1oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0?oooooo1_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0ooooool5ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03
ool00?oooooooooo02kooooo00?o0000ooooooooool0ooooool4ooooo`008Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oo003ooooo033ooooo00?o0000ool00?ooool0ooooool3ooooo`008Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oo003ooooo03;ooooo00?o0000ool00?ooool0oooo
ool2ooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo03?ooooo00?o0000
ool00?ooool0ooooool1ooooo`008Oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo
03Gooooo00?o0000ool00?ooool0ooooool0027ooooo00?o0000ooooooooool02Oooool00ooo003o
ooooooooo`0gooooo`03o`000?oo003ooooo0?kooooo000Qooooo`?o00002Oooool00ooo003ooooo
ooooo`0hooooo`03o`000?oo003ooooo0?gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0>_ooool00ol0003oo`00ooooo`3looooo`008Oooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo03_ooooo00?o0000ool00?ooool0noooool0027ooooo00?o0000oooo
ooooool01oooool00ooo003oooooooooo`0mooooo`03o`000?oo003ooooo0?[ooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`3hooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo047ooooo00?oo`00ooooooooool0
moooool0027ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`12ooooo`03ool00?oo
oooooooo0?Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0A?ooool0
0ol0003oooooooooo`3eooooo`008Oooool3o`0000Gooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`3dooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool3o`000003oc8b<_oMgMgooooo
03cooooo1?l000000ol@413oooooooooo`0kooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go00006oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00Co0000oooooomgMgOo<S8b?oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oV9RHob4Q8Oo^k^h0
7?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`05o`000?oo
ooooooooooooool000003oooool00ol0003o<S8booooo`0nooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0nooooo`03oiRHV?lQ8B7ok^k^01_ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Ko0000ob4Q8Ol0003o<S8bo`000?oo000nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMg
ofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`02ooooo`03o`000?oo003o
o`0003cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol000000ooooooo0000ooooo`0joooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`04ooooo`03o`000?oo003o
oooo03[ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03oooooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool01Ol0003ooooooooooooo
oooo000003_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool00ol0003oo`00
ool0000gooooo`03oeEEEOmVIVKo000003_ooooo1Ooo00000omVIVKo0000ooooo`02ooooo`Go0000
0ooo000Fo`0002kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Kooooo`008Oooool01?l0003ooooo
oooooooo001Fooooo`03o`000?ooooooo`0006Wooooo2ooo000:o`0000Sooooo3?oo000:ooooo`co
0000@_ooool0027ooooo00Co0000ooooool0003oo`00Eoooool01?l0003oooooool00?oo001Xoooo
o`Ko0000;?ooool7ool000Gooooo1_l0000looooo`008Oooool00ol0003oooooool0001Iooooo`;o
000000?oooooool00?ooool0F?ooool3ool000Gooooo1_l0000iooooo`Woo`000_ooool9o`0003?o
oooo000Qooooo`03o`000?oo003ooooo05_ooooo0_l00002ool005Cooooo0ooo00000ooooooo0000
o`000005o`0005;ooooo1ooo0003o`00023ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ool00?ooool0GOooool2o`000003ool00?oooooooooo04cooooo1Ooo0004o`00063ooooo2?oo
0002o`0001Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool0
0?l0003o0000063o000000?oo`00o`000?l00000Aol00004ool0077o00000_oo000>o`0000cooooo
00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool2o`0000;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03ool00?l0003o000000;o0000
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`?o0000
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool0IOooool3o`0003Cooooo0ooo0006o`0009Gooooo0_l00002ooooo`;o
00001?ooool0027ooooo00?o0000ooooooooool0J?ooool3o`0002gooooo1?oo0002o`000:Kooooo
000Qooooo`03o`000?oooooooooo06[ooooo0ooo0002o`0002Gooooo1?oo00000ol0003ooooooooo
o`2Yooooo`008Oooool00ol0003oooooooooo`1]ooooo`?oo`000_l0000Oooooo`?oo`0000?o0000
ooooooooool0[Oooool0027ooooo00?o0000ooooooooool0L?ooool3ool000Co00004Oooool7o`00
00;oo`00/oooool0027ooooo0ol0001cooooo`Goo`004?l0002looooo`008Oooool00ol0003ooooo
ooooo`1hooooo`;oo`000oooool8ool00;oooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool05oooool00omVIVKoMgMgooooo`2Wooooo`00
Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_ooool00ooMgMgo410@onk^kP0Hooooo`03onk^
k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP02ooooo`03
o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03oiRHV?mEEEGooooo
00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool01_nj
^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1eooooo`00
Noooool01ol@413ogMgMogMgMolQ8B7oooooohN7QomVIVH00_ooool00ol0003oooooooooo`0;oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ogMgMooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o
^[Zj0_ooool00oo^k^ko0000ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_o
oooo00Oo0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7o
k^k^00cooooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07?ooooo
001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onHV9So
8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6o`00
00Gooooo00?o0000ooooooooool02_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Oooooo00?oMgMg
oc8b<_ooool0M?ooool007_ooooo00?ogMgMob4Q8Oo^k^h00oooool01?l0003oooooo`000?l0000=
ooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool00ol0003ok^k^ooooo`05
ooooo`03ogMgMomVIVKooooo00[ooooo00CogMgMoa0@4?oooooo00000oooool00oo^k^ko0000oooo
o`0Fooooo`03o`000?oooooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c004ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0MOooool007cooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03oa0@4?l0003o000000?o00001_ooool00ooMgMgo410@ooooo`04ooooo`03oeEE
EOmgMgOooooo00Kooooo00?o0000ooooooooool02?ooool7o`000003oooooomgMgOoEEEE01Oooooo
00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo07Oooooo
002Booooo`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^
kP02ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`00
0?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooooooo
oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo0000
00gooooo00Coc<c<odA4A?l0003o410@1?ooool4o`0007Kooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .22969 L
.08255 .19361 L
.10458 .16081 L
.11448 .14877 L
.12507 .13794 L
.13499 .12977 L
.14415 .12398 L
.14911 .12156 L
.15437 .11954 L
.15691 .11877 L
.15964 .11809 L
.16121 .11777 L
.16265 .11752 L
.16401 .11732 L
.16546 .11715 L
.1668 .11703 L
.16802 .11695 L
.16924 .1169 L
.17039 .11689 L
.17105 .11689 L
.17174 .1169 L
.17298 .11695 L
.17367 .11699 L
.17432 .11703 L
.17578 .11716 L
.17705 .11731 L
.17826 .11748 L
.18052 .11788 L
.1856 .11915 L
.19019 .12071 L
.19525 .12291 L
.20551 .12878 L
.21501 .13586 L
.22393 .14382 L
.26261 .19037 L
.30375 .25215 L
.34338 .31195 L
.38149 .36192 L
.40274 .38509 L
.42205 .40296 L
.44236 .41849 L
.46109 .42993 L
.48028 .43897 L
.49102 .44291 L
.50107 .44592 L
.51088 .44825 L
.51984 .44988 L
.5246 .45057 L
.52979 .45118 L
Mistroke
.53263 .45146 L
.53527 .45167 L
.53799 .45186 L
.54048 .452 L
.54296 .45211 L
.54557 .4522 L
.54693 .45223 L
.5482 .45225 L
.54892 .45226 L
.54959 .45226 L
.55035 .45227 L
.55107 .45227 L
.55228 .45227 L
.55356 .45226 L
.55465 .45224 L
.55585 .45222 L
.55714 .45219 L
.55853 .45215 L
.56104 .45206 L
.56578 .45182 L
.57076 .45146 L
.57966 .45059 L
.58923 .44934 L
.59944 .44768 L
.61782 .44394 L
.65937 .43262 L
.6994 .41915 L
.73792 .40477 L
.77889 .38863 L
.81835 .37272 L
.85629 .35732 L
.89668 .34097 L
.93556 .32532 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .22922 L
.08255 .19343 L
.10458 .16071 L
.11448 .14865 L
.12507 .13779 L
.13499 .12961 L
.14415 .12385 L
.14911 .12146 L
.15437 .11948 L
.15691 .11873 L
.15964 .11808 L
.16121 .11777 L
.16265 .11754 L
.16401 .11735 L
.16546 .1172 L
.16615 .11714 L
.1668 .1171 L
.16802 .11703 L
.16916 .117 L
.17039 .117 L
.17104 .11701 L
.17176 .11703 L
.1725 .11707 L
.1732 .11711 L
.17445 .11721 L
.17578 .11735 L
.17842 .11774 L
.18092 .11823 L
.1856 .11948 L
.19019 .12111 L
.19525 .12337 L
.20551 .12936 L
.22393 .14447 L
.24327 .16549 L
.26413 .19264 L
.30527 .25379 L
.34489 .31332 L
.383 .36365 L
.40425 .38708 L
.42356 .40508 L
.44388 .42056 L
.46261 .43177 L
.48179 .44037 L
.4919 .44381 L
.50259 .44671 L
.51203 .44865 L
.51723 .4495 L
.52216 .45017 L
.52674 .45066 L
Mistroke
.53173 .45108 L
.53393 .45122 L
.53627 .45135 L
.53828 .45144 L
.54048 .45151 L
.54183 .45155 L
.54309 .45157 L
.54379 .45158 L
.54443 .45159 L
.54516 .4516 L
.54585 .4516 L
.54708 .4516 L
.54822 .4516 L
.54947 .45159 L
.5501 .45158 L
.55079 .45157 L
.55224 .45154 L
.55356 .45151 L
.55654 .45141 L
.55917 .45129 L
.56193 .45114 L
.57158 .45038 L
.57704 .44981 L
.58211 .4492 L
.60261 .44596 L
.62121 .44212 L
.66124 .43159 L
.69976 .4192 L
.74073 .40425 L
.78019 .38869 L
.81813 .37332 L
.85852 .35706 L
.8974 .34155 L
.93873 .32458 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0Zooooo`Co0000oooooolGoooo
o`008Oooool3o`0002Kooooo1?l00003ooooo`;o00000_oo003ooooooaCooooo000Qooooo`03o`00
0?oooooooooo02Cooooo00?oo`00o`000?ooool02_ooool4ool00?oooooo4?ooool0027ooooo00?o
0000ooooooooool08_ooool2ool0017ooooo00?oo`00ooooooooool0ooooool=ooooo`008Oooool0
0ol0003oooooooooo`0Pooooo`;oo`005?ooool2ool00?oooooo3Oooool0027ooooo00?o0000oooo
ooooool07oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo0?oooooo2_ooool0027o
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo0?oo
oooo2Oooool0027ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo0?oooooo2?ooool0027ooooo0ol0000Looooo`03ool00?oooooooooo01cooooo00?o
o`00ooooooooool0ooooool7ooooo`008Oooool00ol0003oooooooooo`0Kooooo`03ool00?oooooo
oooo01kooooo00?oo`00ooooooooool0ooooool6ooooo`008Oooool00ol0003oooooooooo`0Joooo
o`03ool00?oooooooooo01oooooo00?o0000ooooooooool0ooooool6ooooo`008Oooool00ol0003o
ooooooooo`0Iooooo`03ool00?l0003ooooo027ooooo00?o0000ooooooooool0ooooool5ooooo`00
8Oooool00ol0003oooooooooo`0Hooooo`03ool00?l0003ooooo02?ooooo00?o0000ooooooooool0
ooooool4ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0ooooool3ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0ooooool2ooooo`008Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0ooooool1ooooo`008Oooool3o`0001Ko
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`008Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo02[ooooo00?o0000ool00?ooool0ooooool0027ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0?kooooo000Q
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;Oooool00ooo003oooooooooo`3m
ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02oooooo00?oo`00oooo
ooooool0o?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0a
ooooo`03ool00?oooooooooo0?_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Booooo`03ool00?oooooo
oooo037ooooo00?oo`00o`000?ooool0noooool000Go00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00_ooool3o`00017ooooo00?oo`00ooooooooool0<oooool0
0ooo003o0000ooooo`3jooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Gooooo00?oo`00
ooooooooool0nOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo03Gooooo00?o
o`00o`000?ooool0nOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0gooooo`03ool00?l0
003ooooo0?Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0>Oooool00ooo003ooooooooo
o`3gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0>Oooool00ooo003o0000ooooo`3gooooo`008Oooool0
0ol0003oooooooooo`0=ooooo`03ool00?oooooooooo03_ooooo00?oo`00o`000?ooool0m_ooool0
027ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0looooo`03ool00?oooooooooo
0?Gooooo000Qooooo`?o00003?ooool00ooo003oooooooooo`0nooooo`03o`000?oooooooooo0?Co
oooo000Qooooo`03o`000?oooooooooo00_ooooo00?oo`00o`000?ooool0@?ooool00ol0003ooooo
ooooo`3cooooo`008Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo043ooooo00?o
0000ooooooooool0loooool0027ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`12
ooooo`03o`000?oooooooooo0?;ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`3booooo`008Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0lOooool0027ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`?o00002?oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0?3ooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Aoooool00ol0003oo`00ooooo`3_ooooo`008Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool0k_ooool0027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`19ooooo`03o`000?oo003ooooo0>ko
oooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Boooool00ooo003ooooo
ooooo`3]ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04cooooo00?o
o`00ooooooooool0k?ooool0027ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1=
ooooo`03ool00?oooooooooo0>cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool0C_ooool00ooo003oooooooooo`3[ooooo`008Oooool3o`0000Cooooo00?oo`00oooooooo
ool0D?ooool00ooo003oooooooooo`3Zooooo`008Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo03Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?oo`00ooooooooool0=_ooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
03Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03ool00?oooooooooo03Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0looooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06ooo
ool0027ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0gooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?o
V9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`0h
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`05ooooo`03ool00?oo
oooooooo03Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`0hooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Oooooo00?oo`00ooooooooool0=Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c010ooooo`03ogMgMomVIVKooooo01[o
oooo000Qooooo`06o`000?ooooooooooooooool0003oo`00>_ooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0dooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01Wooooo000Qooooo`?o000000?oooooool00?ooool0>_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[o
oooooiRHV?l@41006oooool0027ooooo00Go0000oooooooooooo0000ool0000kooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo00?o0000ooooooooool0<Oooool00omEEEGoIVIV
o`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06oooool0027ooooo00Co0000ooooooooooooo`00G?ooool00ol0003oooooooooo`3Tooooo`00
8Oooool01?l0003oooooo`000?oo001Looooo`03o`000?oooooooooo0>Cooooo000Qooooo`04o`00
0?oooooo0000ool005gooooo00?o0000ooooooooool0hoooool0027ooooo0_l000000ooo003ooooo
ooooo`1Mooooo`03o`000?oooooooooo0=Sooooo0_l00002ooooo`;o00001?ooool0027ooooo0_l0
001Pooooo`03o`000?oooooooooo0=Sooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00
6_ooooooo`00037o00000_oo0007o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01oooool01Ooo003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0ooo00000ooooooo
0000ooooo`0Booooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ool00?ooooooooooo`00000>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Cooooo00?o0000oooo
ooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`1Roooo
o`03ool00?oooooooooo0;Wooooo00?o0000ool00?oo00006Oooool2o`0000;ooooo0_l00004oooo
o`008Oooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo0;Gooooo00Co0000ool00?oo
003oo`009Oooool0027ooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`2booooo`;o
000000?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool0I?ooool00ol0003oo`00
ooooo`2_ooooo`?o0000:oooool0027ooooo00?o0000ooooooooool0IOooool00ooo003ooooooooo
o`2/ooooo`;o0000;_ooool0027ooooo0ol0001Vooooo`03ool00?oooooooooo0:Wooooo0_l0000`
ooooo`008Oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo0:Gooooo00?o0000ool0
0?oo0000<_ooool0027ooooo00?o0000ooooooooool0Ioooool00ol0003oo`00ooooo`2Sooooo`;o
000000?oo`00ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0J?ooool00ooo003ooooo
ooooo`2Oooooo`?o00000_oo000eooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooooooo09_ooooo0ol00003ool003Oooooo000Qooooo`03o`000?oooooooooo06[ooooo00?oo`00
ooooooooool0V?ooool2o`0000?oo`00>_ooool0027ooooo00?o0000ooooooooool0J_ooool00ol0
003oo`00ooooo`2Eooooo`;o00000ooo000mooooo`008Oooool3o`0006_ooooo00?o0000oooooooo
ool0T_ooool2o`0000;oo`00@?ooool0027ooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`2>ooooo`?o0000A?ooool0027ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`2;ooooo`;o0000Aoooool0027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`28
ooooo`;o0000BOooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`24oooo
o`03o`000?oo003oo`0004_ooooo000Qooooo`03o`000?oooooooooo073ooooo00?o0000oooooooo
ool0POooool3ool004gooooo000Qooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
OOooool00ol0003oo`00ool0001@ooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oo
oooooooo07[ooooo0ooo001Booooo`008Oooool3o`0007;ooooo00?oo`00o`000?ooool0N?ooool2
ool005Gooooo000Qooooo`03o`000?oooooooooo07?ooooo00?oo`00o`000?ooool0M?ooool00ol0
003oo`00ool0001Gooooo`008Oooool00ol0003oooooooooo`1dooooo`;oo`00L_ooool2o`000003
ool00?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooooooool0
K?ooool3o`0005cooooo000Qooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0J?oo
ool3o`0005oooooo000Qooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool0IOooool2
o`0006;ooooo000Qooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool0HOooool00ol0
003oo`00ool0001Tooooo`008Oooool3o`0007[ooooo00?oo`00o`000?ooool0G_ooool00ol0003o
o`00ool0001Vooooo`008Oooool00ol0003oooooooooo`1kooooo`03ool00?l0003ooooo05[ooooo
00Co0000ool00?oo003oo`00J?ooool0027ooooo00?o0000ooooooooool0O?ooool00ooo003o0000
ooooo`1Gooooo`03o`000?oo003oo`0006_ooooo000Qooooo`03o`000?oooooooooo07gooooo00?o
o`00o`000?ooool0E?ooool00ol0003oo`00ool0001]ooooo`008Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo04oooooo00Co0000ool00?oo003oo`00Koooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0P?ooool2o`0004gooooo0_l000000ooo003oooooooooo`1`ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0P_ooool2o`0004Sooooo0ol0001eooooo`001oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0008Cooooo0_l00013ooooo`?o0000
N?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0Q_ooool2o`0003gooooo0_oo0002o`0007_ooooo0007ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0Q_ooool3ool00003o`000?oooooooooo03Kooooo0ooo00000ol0003oooooooooo`1looooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`29ooooo`?oo`00<Oooool00ol0003oo`00ool00002ool008;ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08co
oooo0ooo000Zooooo`03o`000?oo003oo`0000;oo`00Q_ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2?ooooo`Coo`008oooool01?l0003o
o`00ool00?oo002:ooooo`008Oooool00ol0003oooooooooo`2Booooo`03o`000?oo003oo`0001ko
oooo0ol0002>ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?l0003o000000;o0000
3Oooool7ool000Go0000TOooool0027ooooo0ol0002Jooooo`?o00002_oo0006o`0009Oooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`00
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Sooooo00?oMgMgofIVI_ooool05oooool00omVIVKo
MgMgooooo`2Sooooo`00Qoooool3o`0001?ooooo00?o8B4QomgMgOooool01oooool00ooMgMgo410@
onk^kP0Hooooo`03onk^k_l@413ogMgM0:?ooooo001nooooo`07ohN7Qol0003oEEEEofIVI_l0003o
<S8bonk^kP03ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003oA4A4okZj^P02oooo
o`03oiRHV?mEEEGooooo00Oooooo00CoEEEEoiRHV?oooooooooo1Ol00009ooooo`03oeEEEOnYZJWo
oooo00;ooooo00?o^[ZjodA4A?ooool00_ooool00on7QhOoIVIVooooo`0Cooooo`Co000000?o410@
ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool0Noooool007kooooo00Oo410@omgM
gOmgMgOo8B4Qoooooon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q
8Oo^k^koooooodA4A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000
ooooo`0;ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omEEEGoZJVY
ooooo`1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b<_oooooooooo00;o
oooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`1kooooo`00O_ooool01?mEEEGo
ZJVYooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`05
ooooo`03onk^k_l@413ok^k^00Kooooo00?o<S8booooooooool00oooool00onHV9So8B4Qonk^kP0;
ooooo`04ohN7QomVIVKoooooo`0000Gooooo00?o0000ooooooooool02_ooool6o`0000Cooooo00?o
0000ooooooooool03Oooool00olQ8B7oooooooooo`1jooooo`00O_ooool00ooMgMgo8B4Qonk^kP03
ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9So
oooo00Gooooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413o
ooooo`0000Cooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`0=ooooo`03oeEEEOo<
c<cooooo07[ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05
ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`1jooooo`00U_ooool00ol0003oooooooooo`07oooo
o`03oeEEEOnHV9Sooooo00Cooooo00WogMgMoa0@4?o^k^koooooo`000?nj^[[ooooooiRHV?l@4100
4_ooool00oo^k^ko410@omgMg@0Fooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooo
oooooc8b<P1kooooo`00U_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo
00SoMgMgofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool05?ooool0
0omEEEGoIVIVo`00000<ooooo`Go0000Noooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .25681 L
.10458 .20635 L
.12507 .18613 L
.14415 .17074 L
.16254 .15959 L
.17284 .15509 L
.18221 .15216 L
.18704 .15108 L
.18948 .15066 L
.19216 .15028 L
.19445 .15004 L
.19573 .14993 L
.19691 .14986 L
.198 .1498 L
.19919 .14976 L
.20031 .14974 L
.20135 .14973 L
.20266 .14975 L
.20339 .14976 L
.20407 .14979 L
.20532 .14985 L
.20663 .14993 L
.20891 .15014 L
.21141 .15044 L
.21409 .15087 L
.21696 .15143 L
.22214 .15274 L
.23231 .15638 L
.24338 .16195 L
.2635 .17629 L
.28327 .19537 L
.30428 .22044 L
.34203 .27494 L
.38223 .33968 L
.42092 .40065 L
.46206 .45715 L
.48259 .48073 L
.50169 .49957 L
.52129 .51571 L
.53979 .52797 L
.54961 .53332 L
.56025 .53824 L
.56986 .54191 L
.57884 .54469 L
.5883 .54696 L
.59332 .5479 L
.59872 .5487 L
.60141 .54903 L
.60436 .54932 L
Mistroke
.60695 .54953 L
.60837 .54963 L
.60971 .54971 L
.61103 .54977 L
.61245 .54983 L
.61374 .54987 L
.61492 .54989 L
.61605 .54991 L
.61728 .54992 L
.61856 .54992 L
.61976 .5499 L
.62103 .54988 L
.62166 .54987 L
.62237 .54985 L
.62478 .54975 L
.62614 .54968 L
.6276 .5496 L
.63024 .54941 L
.63541 .5489 L
.64015 .5483 L
.6492 .54677 L
.65872 .54466 L
.6785 .53869 L
.69688 .5314 L
.73598 .51106 L
.77753 .48357 L
.81756 .45276 L
.85608 .42021 L
.89705 .3834 L
.93651 .34662 L
.97445 .31067 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .25939 L
.10458 .20641 L
.12507 .18486 L
.14415 .16869 L
.1536 .1623 L
.16254 .15733 L
.16748 .15505 L
.17284 .15295 L
.17735 .15149 L
.18221 .15025 L
.18475 .14973 L
.18708 .14934 L
.18945 .14902 L
.19165 .1488 L
.19288 .14871 L
.1942 .14863 L
.19495 .1486 L
.19566 .14857 L
.19629 .14856 L
.19698 .14855 L
.19826 .14855 L
.19891 .14856 L
.19962 .14857 L
.20087 .14862 L
.20205 .14869 L
.20335 .14878 L
.20477 .14891 L
.20735 .14923 L
.20987 .14962 L
.21219 .15007 L
.21747 .15137 L
.22307 .15318 L
.23244 .15718 L
.24255 .16282 L
.26083 .17632 L
.28087 .19559 L
.30197 .22019 L
.34007 .27298 L
.38063 .33542 L
.41968 .39537 L
.46118 .45293 L
.50116 .49799 L
.51948 .51445 L
.53963 .52926 L
.5595 .54042 L
.57037 .54508 L
.58054 .54852 L
.58552 .54989 L
.59095 .55114 L
Mistroke
.59574 .55205 L
.60083 .55281 L
.60343 .55312 L
.60588 .55336 L
.60826 .55355 L
.61045 .55369 L
.61254 .55378 L
.61359 .55382 L
.61474 .55385 L
.61589 .55387 L
.61713 .55388 L
.6183 .55387 L
.61937 .55386 L
.62055 .55384 L
.62166 .55381 L
.62288 .55377 L
.62419 .55371 L
.62686 .55355 L
.62931 .55336 L
.63378 .5529 L
.63849 .55226 L
.64842 .55043 L
.65927 .54769 L
.67892 .54092 L
.69988 .5314 L
.74143 .5068 L
.78146 .47775 L
.81998 .44657 L
.86095 .41136 L
.90041 .37647 L
.93835 .34268 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`0aooooo`Goo`00ooooool?oooo
o`008Oooool00ol0003oooooooooo`0]ooooo`Coo`002_l0003oooooo`[ooooo000Qooooo`03o`00
0?oooooooooo02[ooooo0ooo00000ol0003oooooooooo`0;ooooo`?o0000ooooool7ooooo`008Ooo
ool00ol0003oooooooooo`0Xooooo`;oo`0000?o0000ooooooooool04Oooool01?l0003oo`00ool0
0?l0003oooooo`?ooooo000Qooooo`03o`000?oooooooooo02Kooooo0_oo0002o`0001Oooooo00?o
o`00o`000?l00000ooooool1ooooo`008Oooool00ol0003oooooooooo`0Vooooo`;o00006_ooool2
ool00003o`000?oooooooooo0?gooooo000Qooooo`?o00009?ooool2o`0001kooooo00?oo`00o`00
0?ooool0oOooool0027ooooo00?o0000ooooooooool08_ooool2o`00027ooooo00?oo`00o`000?oo
ool0o?ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03ool0
0?l0003ooooo0?_ooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09?oo
ool2ool00?_ooooo000Qooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09oooool0
0ooo003oooooooooo`3hooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Nooooo`03ool00?oo
oooooooo02Wooooo00?oo`00ooooooooool0moooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01gooooo00?o
o`00ooooooooool0:oooool00ooo003oooooooooo`3fooooo`001Ol00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00007?ooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo0?Gooooo0007ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0;ooo
ool00ol0003oooooooooo`3dooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0
<Oooool00ol0003oooooooooo`3cooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo03;ooooo
00?o0000ooooooooool0loooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0dooooo`03o`00
0?oooooooooo0?;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool05oooool00ooo003oooooooooo`0fooooo`03o`000?oooooooooo0?7ooooo
000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0=oooool00ol0003ooooooooo
o`3`ooooo`008Oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo03Wooooo00?o0000
ooooooooool0koooool0027ooooo0ol0000Eooooo`03ool00?oooooooooo03_ooooo00?oo`00oooo
ooooool0k_ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0looooo`03
ool00?l0003ooooo0>kooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0
?_ooool00ooo003o0000ooooo`3]ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03oooooo00?oo`00o`000?ooool0kOooool0027ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`11ooooo`03ool00?l0003ooooo0>cooooo000Qooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0@oooool00ooo003o0000ooooo`3[ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04Cooooo00?oo`00ooooooooool0j_ooool0027ooooo
0ol0000?ooooo`03o`000?oooooooooo04Gooooo00?oo`00o`000?ooool0j_ooool0027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`17ooooo`03ool00?l0003ooooo0>Wooooo000Q
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0BOooool00ooo003o0000ooooo`3X
ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo04[ooooo00?oo`00o`00
0?ooool0j?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oo`00ooooo`1<ooooo`03
ool00?l0003ooooo0>Oooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?ooool0
C_ooool00ooo003o0000ooooo`3Vooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
003ooooo053ooooo00?oo`00ooooooooool0iOooool0027ooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`1Aooooo`03o`000?oooooooooo0>Cooooo000Qooooo`?o00002?ooool00ol0
003oo`00ooooo`1Cooooo`03o`000?oooooooooo0>?ooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ool00?ooool0<oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd03?ooool00ol0003oooooooooo`0^ooooo`Co000000?o410@
ooooooooool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0?Oooool5o`0001_ooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ool00?ooool0=?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Kooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oo003ooooo03Cooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
003ooooo03Gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00gooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00kooooo
00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`008Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oo003ooooo03Kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043ooooo00?oMgMgofIV
I_ooool06_ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooool0000gooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06Oooool0027ooooo0ol00003ooooo`03o`000?oo003ooooo03Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo017ooooo00?oo`00o`00
0?ooool0;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0?oooool01Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo
00;ooooo00?o0000ool00?ooool0>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000@
ooooo`03ool00?l0003ooooo02_ooooo00?oEEEEofIVI_l00000?oooool00omEEEGoIVIVo`00000=
ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qooooo`05o`000?oooooo
ooooooooool00000HOooool00ooo003o0000ooooo`3Nooooo`008Oooool01?l0003oooooooooool0
001Sooooo`03ool00?oooooooooo0=gooooo000Qooooo`04o`000?ooooooooooo`0006?ooooo00?o
o`00o`000?ooool0gOooool0027ooooo00?o0000ooooool00000IOooool00ooo003o0000ooooo`3B
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`;o0000Ioooool00ooo003oooooooooo`3Aoooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooLOl000000ooo003o0000o`00002m
o`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?ooooooo`0000cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?l000004oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooool000_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Wooooo00Co0000ool00?oooooo00004oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`00
8Oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo0;Oooooo00?o0000ool00?ooool0
5?ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`1Yooooo`03ool00?oo
oooooooo0;Kooooo00?o0000ool00?ooool07oooool0027ooooo00?o0000ooooooooool0J_ooool0
0ooo003oooooooooo`2dooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo
06[ooooo00?o0000ool00?ooool0/oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool08_ooool0027ooooo
0ol0001/ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool08oooool0027ooooo00?o
0000ooooooooool0K?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Cooooo000Q
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0:[ooooo0_oo000Xoooo
o`008Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0:Sooooo00?oo`00o`000?oo
ool0:?ooool0027ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`2Vooooo`03ool0
0?l0003ooooo02Wooooo000Qooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0YOoo
ool00ooo003o0000ooooo`0Zooooo`008Oooool3o`00073ooooo00?o0000ool00?ooool0Xoooool0
0ooo003o0000ooooo`0[ooooo`008Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo003ooooo
0:7ooooo0_oo00000ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`1aooooo`03
o`000?oo003ooooo09oooooo00?oo`00ooooool00000;_ooool0027ooooo00?o0000ooooooooool0
L_ooool00ol0003oo`00ooooo`2Mooooo`03ool00?oooooo000002oooooo000Qooooo`03o`000?oo
oooooooo07;ooooo00?o0000ool00?ooool0W?ooool00ooo003oooooo`00000`ooooo`008Oooool0
0ol0003oooooooooo`1cooooo`03o`000?oo003ooooo09[ooooo00?oo`00ooooool00000<Oooool0
027ooooo00?o0000ooooooooool0M?ooool00ol0003oo`00ooooo`2Hooooo`03ool00?oooooo0000
03;ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?o0000ool00?ooool0VOooool00ol0003o
ooooooooo`0aooooo`008Oooool3o`0007Gooooo00?o0000ool00?ooool0Uoooool00ol0003ooooo
ooooo`0booooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo09Cooooo0_l0
000eooooo`008Oooool00ol0003oooooooooo`1fooooo`03o`000?oo003ooooo09?ooooo00?o0000
ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0Moooool00ol0003oo`00ooooo`2Aoooo
o`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
0000T?ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`1hooooo`03o`00
0?oo003ooooo08kooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`2:ooooo`;oo`0000?o0000ooooooooool0>Oooool0027ooooo0ol0001i
ooooo`03o`000?oooooooooo08Wooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`27ooooo`03ool00?l0003ooooo03gooooo000Qooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0Q?ooool2ool00003o`000?oooooooooo03go
oooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0P_ooool00ooo003ooooo
o`000010ooooo`008Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo087ooooo00?o
o`00ooooool00000@Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0OOooool00ol0003ooooo
ooooo`1oooooo`03ool00?l0003o000004;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo07gooooo00?oo`00o`000?ooool0@oooool000Oooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0001nooooo`03o`000?ooooooo`0007cooooo
00?oo`00o`000?ooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0Ooooool00ol0003oo`00ooooo`1jooooo`03ool0
0?l0003ooooo04Gooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0P?ooool00ol0003oo`00ooooo`1hooooo`03
ool00?l0003ooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo087ooooo00?o0000ool00?ooool0M_ooool2o`0004So
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo087ooooo00?o0000oooooooo0000MOooool00ol0003oooooooooo`18ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo08;o
oooo00?o0000ool00?ooool0Loooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003ooooo
ooooo`23ooooo`03o`000?oo003ooooo077ooooo00?o0000ooooooooool0B_ooool0027ooooo00?o
0000ooooooooool0Poooool00ol0003oooooool0001`ooooo`03o`000?oooooooooo04_ooooo000Q
ooooo`?o0000Q?ooool00ol0003oooooool0001]ooooo`;o0000C_ooool0027ooooo00?o0000oooo
ooooool0QOooool00ol0003oo`00ooooo`1Zooooo`;oo`00D?ooool0027ooooo00?o0000oooooooo
ool0Q_ooool00ol0003oo`00ooooo`1Xooooo`03ool00?l0003ooooo053ooooo000Qooooo`03o`00
0?oooooooooo08Oooooo00?o0000ool00?ooool0I_ooool00ooo003o0000ooooo`1Aooooo`008Ooo
ool00ol0003oooooooooo`28ooooo`03o`000?oo003ooooo06?ooooo0_oo00000ol0003ooooooooo
o`1Aooooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo067ooooo00?oo`00
o`000?l00000E?ooool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`1Ooooo
o`03ool00?l0003ooooo05Gooooo000Qooooo`?o0000Roooool00ol0003oooooooooo`1Mooooo`03
ool00?l0003ooooo05Kooooo000Qooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
F_ooool2ool00003o`000?oooooooooo05Kooooo000Qooooo`03o`000?oooooooooo08gooooo00?o
0000ooooooooool0F?ooool00ooo003oooooo`00001Iooooo`008Oooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo05Kooooo00?oo`00o`000?l00000F_ooool0027ooooo00?o0000oooo
ooooool0Soooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05[ooooo000Qooooo`03
o`000?oooooooooo093ooooo00?o0000ool00?ooool0D_ooool2o`0005gooooo000Qooooo`03o`00
0?oooooooooo097ooooo00?oo`00ooooooooool0Coooool2o`0005oooooo000Qooooo`03o`000?oo
oooooooo09;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`1Oooooo`008Oooool3
o`0009?ooooo00?oo`00o`000?ooool0B_ooool2o`0006;ooooo000Qooooo`03o`000?oooooooooo
09Cooooo00?oo`00o`000?ooool0Aoooool2o`0006Cooooo000Qooooo`03o`000?oooooooooo09Go
oooo00?oo`00o`000?ooool0A?ooool3ool006Gooooo000Qooooo`03o`000?oooooooooo09Kooooo
00?oo`00o`000?ooool0@_ooool00ooo003o0000ooooo`1Vooooo`008Oooool00ol0003ooooooooo
o`2Gooooo`03ool00?l0003ooooo03oooooo0_oo001Yooooo`008Oooool00ol0003oooooooooo`2H
ooooo`;oo`0000?o0000ooooooooool0>_ooool2ool006_ooooo000Qooooo`03o`000?oooooooooo
09[ooooo00?oo`00o`000?ooool0>Oooool00ooo003o0000ooooo`1[ooooo`008Oooool3o`0009_o
oooo00?oo`00o`000?l00000=_ooool2ool006kooooo000Qooooo`03o`000?oooooooooo09cooooo
00?oo`00ooooool00000<oooool2ool0073ooooo000Qooooo`03o`000?oooooooooo09oooooo0ol0
000_ooooo`03ool00?l0003ooooo073ooooo000Qooooo`03o`000?oooooooooo0:;ooooo0_l0000[
ooooo`03o`000?oo003ooooo07;ooooo000Qooooo`03o`000?oooooooooo0:Cooooo00?o0000oooo
ooooool09Oooool3o`0007Gooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`2Uooooo`?o00008Oooool3o`0007Sooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Y_ooool2ool000?o00006oooool3o`0007_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Z?ooool3ool000?o00005Oooool2o`0000;oo`00OOoo
ool001[ooooo00?o0000ooooooooool01?ooool3o`000:_ooooo0_oo00000ooooooo0000o`000005
o`0000Gooooo2?l00003ool007oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0[Oooool2ool000Gooooo1_l00003ooooo`Goo`00P_ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2gooooo`Koo`00Qoooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00:Cooooo00?oMgMgofIVI_ooool0
5oooool00omVIVKoMgMgooooo`2Wooooo`00Poooool3o`0001Cooooo00?o8B4QomgMgOooool01_oo
ool00ooMgMgo410@onk^kP0Hooooo`03onk^k_l@413ogMgM0:Oooooo001kooooo`07ohN7Qol0003o
EEEEofIVI_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00_ooooo00GoV9RHo`000?l0003o
A4A4okZj^P03ooooo`03oiRHV?mEEEGooooo00Kooooo00?oEEEEoiRHV?ooool00_ooool5o`0000Wo
oooo00?oEEEEojVYZOooool00_ooool01_nj^[[oA4A4ooooooooooooQhN7ofIVIQGooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd0MOooool007_ooooo00Oo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIV00;ooooo
00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000omgMgOoo
ool01Oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool01_mE
EEGoV9RHoooooooooooo410@okZj^P;ooooo00?ok^k^o`000?ooool02oooool6o`0000Gooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8boooo
o`1dooooo`00Noooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07?o
oooo001kooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0
003oooooooooo`06ooooo`03onk^k_l@413ok^k^00Gooooo00?o<S8booooooooool01?ooool00onH
V9So8B4Qonk^kP0;ooooo`04ohN7QomVIVKoooooo`0000Cooooo00?o0000ooooooooool02_ooool6
o`0000Gooooo00?o0000ooooooooool03Oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo07Cooooo001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool0
0ol0003oooooooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool0
0omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool05_oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003ooooooooo
o`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0Moooool009;ooooo00?o0000
ooooooooool02?ooool00omEEEGoV9RHooooo`03ooooo`03omgMgOl@413ok^k^00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400Aooooo`03onk^k_l@413ogMgM01Oooooo00?o0000ooooooooool02_oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0Moooool009;ooooo00?o
0000ooooooooool02?ooool00onj^[[oA4A4ooooo`04ooooo`09ogMgMomVIVKooooooooooonHV9So
410@o`000?lQ8B7oc<c<017ooooo00?oIVIVogMgMoooool05Oooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0007Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .29627 L
.10458 .28019 L
.14415 .26335 L
.18221 .24786 L
.20342 .24083 L
.21345 .23817 L
.22272 .23619 L
.22729 .23539 L
.23233 .23466 L
.23739 .2341 L
.24016 .23387 L
.24276 .23369 L
.24393 .23363 L
.24521 .23358 L
.24641 .23354 L
.24753 .23351 L
.24864 .23349 L
.24964 .23348 L
.2508 .23347 L
.25189 .23348 L
.25308 .2335 L
.25435 .23353 L
.25542 .23357 L
.25661 .23362 L
.25925 .23377 L
.26171 .23397 L
.26672 .23451 L
.27216 .23534 L
.2773 .23635 L
.28206 .2375 L
.29106 .24021 L
.30062 .24389 L
.32009 .25399 L
.33837 .26667 L
.37706 .30306 L
.4182 .35321 L
.45782 .40729 L
.49593 .45866 L
.53649 .50674 L
.57554 .54246 L
.59688 .55674 L
.60667 .56199 L
.61703 .56663 L
.62656 .57008 L
.63162 .57159 L
.63705 .57297 L
.64203 .57401 L
.64658 .57478 L
.65116 .57538 L
Mistroke
.65324 .57559 L
.6555 .57578 L
.65685 .57587 L
.6581 .57595 L
.65926 .576 L
.66054 .57605 L
.66169 .57608 L
.66277 .5761 L
.6639 .57612 L
.66511 .57612 L
.66643 .5761 L
.66717 .57609 L
.66786 .57607 L
.66913 .57603 L
.67047 .57598 L
.67279 .57584 L
.67534 .57565 L
.67992 .57517 L
.68484 .57447 L
.69374 .57273 L
.70334 .57018 L
.71382 .56662 L
.73494 .55713 L
.75459 .54568 L
.77555 .53093 L
.8171 .495 L
.85713 .4536 L
.89565 .40926 L
.93662 .359 L
.97608 .30916 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .29399 L
.10458 .28043 L
.14415 .26499 L
.18221 .249 L
.20342 .24122 L
.21345 .23817 L
.22272 .23583 L
.23233 .23397 L
.23739 .23324 L
.23998 .23294 L
.24276 .23267 L
.24519 .23249 L
.24742 .23236 L
.24849 .23231 L
.24965 .23227 L
.25075 .23224 L
.25178 .23222 L
.25308 .23222 L
.2543 .23222 L
.2554 .23223 L
.25659 .23226 L
.25788 .23231 L
.25925 .23237 L
.26171 .23252 L
.26426 .23274 L
.26667 .23299 L
.27119 .23362 L
.27605 .23451 L
.28135 .23573 L
.29087 .23861 L
.29968 .24206 L
.31835 .25192 L
.33895 .26672 L
.37915 .30621 L
.41784 .3541 L
.45898 .40995 L
.4986 .46246 L
.53671 .50676 L
.55796 .52742 L
.57727 .5432 L
.59736 .55635 L
.61632 .5656 L
.62604 .56914 L
.63633 .572 L
.64512 .57373 L
.65011 .57442 L
.65237 .57466 L
.65478 .57488 L
.65614 .57498 L
Mistroke
.65737 .57506 L
.65862 .57512 L
.65976 .57517 L
.66111 .57522 L
.66181 .57523 L
.66256 .57525 L
.66381 .57526 L
.66453 .57526 L
.66519 .57526 L
.66647 .57525 L
.66769 .57522 L
.66878 .57519 L
.66996 .57514 L
.67262 .575 L
.67507 .57482 L
.67935 .57439 L
.68406 .57375 L
.69361 .57194 L
.70373 .56929 L
.71299 .56623 L
.73386 .5572 L
.75282 .54659 L
.77354 .5326 L
.81415 .49869 L
.85325 .45911 L
.8948 .41138 L
.93483 .36191 L
.97335 .31271 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo04?o
oooo1_oo003kooooo`008Oooool00ol0003oooooooooo`0mooooo`Co00000_oo0005o`0000Woo`00
loooool0027ooooo0ol0000gooooo`Ko00004?ooool4o`000003ool00?oooooooooo0?3ooooo000Q
ooooo`03o`000?oooooooooo03Cooooo0ooo000Jooooo`?o0000l?ooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oo`00ool0000Pooooo`;o0000k_ooool0027ooooo00?o0000oooooooo
ool0;_ooool2o`0000;oo`009?ooool2o`000>cooooo000Qooooo`03o`000?oooooooooo02_ooooo
0ol00002ool002Sooooo0_l0003Zooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o00000ooo
000/ooooo`;oo`00j?ooool0027ooooo00?o0000ooooooooool09oooool2o`0000;oo`00<Oooool0
0ooo003oooooooooo`3Uooooo`008Oooool00ol0003oooooooooo`0Tooooo`?o000000?oooooool0
0?ooool0<oooool2ool00>Gooooo000Qooooo`?o00008_ooool2o`0003_ooooo00?oo`00oooooooo
ool0h_ooool0027ooooo00?o0000ooooooooool07oooool3o`0001_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00gooooo00?oo`00o`00
0?ooool0;Oooool4o`000003oa0@4?oooooooooo03_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03gooooo1Ol0000Kooooo`008Oooool00ol0
003oooooooooo`0Mooooo`;o00007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00gooooo00?oo`00o`000?ooool0;_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0Kooooo`04o`000?oo003o
o`00ool001kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00gooooo
00?oo`00o`000?ooool0;Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0??ooool00onHV9So8B4Qonk^kP0Looooo`008Oooool00ol0003ooooooooo
o`0Hooooo`04o`000?oo003oo`00ool0027ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00oooooo00?oo`00o`000?ooool0;?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool0?_ooool00onHV9So8B4Qonk^kP0Kooooo`00
8Oooool00ol0003oooooooooo`0Fooooo`?oo`009?ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Aooooo`03ool00?l0003ooooo02_ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0@?ooool0
0omgMgOoIVIVooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Cooooo`?oo`009oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool00ooo003o0000ooooo`0Z
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo01Wooooo000Qooooo`?o00004?ooool3ool002[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo01Gooooo00?oo`00o`000?ooool0:Oooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool0
1Ol0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo00gooooo0_l00000
0ooo003oooooooooo`0[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0001Kooooo00?o
0000ooooooooool09Oooool00omEEEGoIVIVo`00000oooooo`03oeEEEOmVIVKo000000gooooo1?l0
000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06oooool0027ooooo00?o0000ooooooooool02_oo
ool3o`0005cooooo00?o0000ooooooooool0f?ooool0027ooooo00?o0000ooooooooool02?ooool2
o`00063ooooo00?o0000ooooooooool0eoooool0027ooooo00?o0000ooooooooool01?ooool2ool0
00;o0000Hoooool00ol0003oooooooooo`3Fooooo`008Oooool01?l0003oooooooooooooool3ool0
0003o`000?oooooooooo06Gooooo00?o0000ooooooooool0boooool2o`0000;ooooo0_l00004oooo
o`008Oooool01Ol0003oo`00ool00?oo003o000006[ooooo00?o0000ooooooooool0boooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Jooooo`Oo000000?oo`00o`000?l00000ool0000X
o`000003ool00?l0003o000000Go00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`0Aooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01_ooool00ooo003o0000ooooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?l0003o
oooo01;ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool0Koooool0
0ooo003o0000ooooo`2cooooo`03o`000?oo003ooooo01;ooooo0_l00002ooooo`;o00001?ooool0
027ooooo00?o0000ooooooooool0L?ooool00ooo003oooooooooo`2aooooo`03o`000?oo003ooooo
01gooooo000Qooooo`03o`000?oooooooooo077ooooo00?oo`00ooooooooool0[oooool00ol0003o
o`00ooooo`0Nooooo`008Oooool00ol0003oooooooooo`1booooo`03ool00?oooooooooo0:kooooo
00?oo`00ooooooooool07_ooool0027ooooo00?o0000ooooooooool0Loooool00ooo003ooooooooo
o`2/ooooo`03ool00?oooooooooo01oooooo000Qooooo`?o0000Loooool00ooo003o0000ooooo`2[
ooooo`03ool00?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00o`00
0?ooool0ZOooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1eooooo`03
ool00?oooooooooo0:Oooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool0
M_ooool00ooo003oooooooooo`2Uooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oo
oooooooo07Oooooo00?oo`00ooooooooool0Y?ooool00ol0003oooooooooo`0Sooooo`008Oooool0
0ol0003oooooooooo`1hooooo`03ool00?oooooooooo0:;ooooo00?o0000ooooooooool09?ooool0
027ooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
02Gooooo000Qooooo`?o0000NOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo02Ko
oooo000Qooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0WOooool00ooo003ooooo
ooooo`0Wooooo`008Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo09cooooo00?o
o`00ooooooooool09oooool0027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2K
ooooo`03o`000?oo003ooooo02Sooooo000Qooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool0VOooool00ol0003oo`00ooooo`0Yooooo`008Oooool00ol0003oooooooooo`1mooooo`03
o`000?oooooooooo09Oooooo00?o0000ool00?ooool0:_ooool0027ooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo02[ooooo000Qooooo`03o`000?oo
oooooooo07kooooo00?oo`00ooooooooool0UOooool00ooo003oooooooooo`0[ooooo`008Oooool3
o`0007kooooo00?oo`00o`000?ooool0U?ooool00ooo003oooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`1oooooo`03ool00?l0003ooooo09;ooooo00?o0000ool00?ooool0;Oooool0027o
oooo00?o0000ooooooooool0P?ooool00ooo003oooooooooo`2Aooooo`03ool00?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo083ooooo00?oo`00o`000?ooool0T?ooool00ooo003ooooo
ooooo`0^ooooo`008Oooool00ol0003oooooooooo`21ooooo`03ool00?l0003ooooo08kooooo00?o
o`00ooooooooool0;oooool0027ooooo00?o0000ooooooooool0P_ooool00ooo003o0000ooooo`2<
ooooo`03ool00?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo08?ooooo00?oo`00oooo
ooooool0Roooool00ol0003oooooooooo`0`ooooo`008Oooool3o`0008?ooooo00?oo`00o`000?oo
ool0R_ooool00ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`24ooooo`03ool0
0?l0003ooooo08Sooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000ooooooooool0QOoo
ool00ooo003oooooooooo`26ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooo
oooo08Gooooo00?oo`00o`000?ooool0Q_ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0
003oooooooooo`26ooooo`03ool00?l0003ooooo08Cooooo00?o0000ooooooooool0=?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0Qoooool00ooo003o0000ooooo`22ooooo`03o`000?oooooo
oooo03Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool0=_ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol00029ooooo`03o`000?oooooooooo07gooooo00?oo`00o`000?ooool0>?ooool0
00Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool0R_ooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo03Sooooo0007oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo03Wooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool0NOooool00ooo003o0000ooooo`0jooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo07Oooooo00?oo`00o`000?ooool0>oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2=ooooo`03o`000?oo
oooooooo07Gooooo00?oo`00o`000?ooool0??ooool0027ooooo00?o0000ooooooooool0S_ooool0
0ooo003oooooooooo`1cooooo`03ool00?l0003ooooo03gooooo000Qooooo`03o`000?oooooooooo
08kooooo00?oo`00ooooooooool0L_ooool00ooo003o0000ooooo`0nooooo`008Oooool3o`0008oo
oooo00?oo`00ooooooooool0L?ooool00ooo003o0000ooooo`0oooooo`008Oooool00ol0003ooooo
ooooo`2@ooooo`03ool00?oooooooooo06kooooo00?oo`00o`000?ooool0@?ooool0027ooooo00?o
0000ooooooooool0TOooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo047ooooo000Q
ooooo`03o`000?oooooooooo097ooooo00?o0000ool00?ooool0Joooool00ooo003oooooooooo`12
ooooo`008Oooool00ol0003oooooooooo`2Booooo`03ool00?oooooooooo06Wooooo00?o0000oooo
ooooool0@oooool0027ooooo00?o0000ooooooooool0Toooool00ooo003oooooooooo`1Wooooo`03
o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo09Cooooo00?oo`00ooooooooool0
IOooool00ol0003oooooooooo`15ooooo`008Oooool3o`0009Gooooo00?oo`00ooooooooool0Hooo
ool00ol0003oooooooooo`16ooooo`008Oooool00ol0003oooooooooo`2Eooooo`03o`000?oo003o
oooo06;ooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool0U_ooool00ol0
003oo`00ooooo`1Pooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo09Oo
oooo00?o0000ool00?ooool0G_ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool0B_ooool0027ooooo00?o
0000ooooooooool0VOooool00ol0003oooooooooo`1Jooooo`03o`000?oo003ooooo04_ooooo000Q
ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0F?ooool2o`000003ool00?oooooo
oooo04_ooooo000Qooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0E_ooool00ol0
003oooooool0001>ooooo`008Oooool3o`0009_ooooo00?o0000ooooooooool0E?ooool00ol0003o
o`00ool0001?ooooo`008Oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo05;ooooo
00?o0000ool00?ooool0D?ooool0027ooooo00?o0000ooooooooool0WOooool2o`00057ooooo00?o
0000ool00?ooool0DOooool0027ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`1=
ooooo`03o`000?oo003ooooo05;ooooo000Qooooo`03o`000?oooooooooo09oooooo00?oo`00o`00
0?ooool0C?ooool00ol0003oo`00ooooo`1Cooooo`008Oooool00ol0003oooooooooo`2Pooooo`03
ool00?l0003ooooo04[ooooo00?o0000ool00?ooool0E?ooool0027ooooo00?o0000ooooooooool0
XOooool00ooo003o0000ooooo`18ooooo`03o`000?oo003ooooo05Gooooo000Qooooo`?o0000X_oo
ool00ooo003o0000o`000016ooooo`03o`000?oo003ooooo05Kooooo000Qooooo`03o`000?oooooo
oooo0:?ooooo00?oo`00ooooool00000A?ooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0
003oooooooooo`2Tooooo`;oo`0000?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool00ol0003oooooooooo`2Vooooo`03ool00?l0003ooooo03kooooo0_l0001Kooooo`00
8Oooool00ol0003oooooooooo`2Wooooo`;oo`00?Oooool00ol0003oooooooooo`1Kooooo`006?oo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0ZOooool00ooo003ooooooooo
o`0hooooo`;o0000G_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Z
ooooo`03ool00?l0003ooooo03Kooooo00?oo`00ooooooooool0G_ooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2[ooooo`03ool00?l0003ooooo03?ooooo00?o0000ool0
0?ooool0H?ooool001[ooooo00?o0000ooooooooool01?ooool3o`000:gooooo00?o0000oooooooo
ool0;oooool00ol0003oo`00ool0001Rooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0:kooooo00?o0000ooooooooool0;Oooool2ool006Cooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0Zooooo`;oo`00I_oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`?o00009oooool2
ool006Sooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0/oooool00ol0
003oo`00ool0000Qooooo`?oo`00J_ooool0027ooooo00?o0000ooooooooool0]Oooool00ol0003o
o`00ool0000Mooooo`;oo`0000?o0000ooooooooool0J_ooool0027ooooo00?o0000ooooooooool0
]oooool00ol0003oo`00o`00000Jooooo`;o0000K_ooool0027ooooo0ol0002iooooo`Koo`004_oo
ool3o`00073ooooo000Qooooo`03o`000?oooooooooo0;gooooo0_l0000=ool000Go0000Loooool0
027ooooo00?o0000ooooooooool0`Oooool9o`0007[ooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOo
oooo0:?ooooo0027ooooo`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^
01Sooooo00?ok^k^oa0@4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;o
k^k^00?ooooo00?o0000ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?o
V9RHoeEEEOooool01oooool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool0
0_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<07_ooooo001nooooo`07oa0@
4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP03ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj
^_o^k^koMgMgoa0@4003ooooo`03o`000?oMgMgooooo00Kooooo00Wo0000oooooooooooooooooiRH
V?lQ8B7ok^k^oooooom4A4@02_ooool01_mEEEGoV9RHoooooooooooo410@okZj^P?ooooo00?ok^k^
o`000?ooool02oooool6o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@1kooooo`00O_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@4100
0oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0_mgMgL7ooooo`03oc8b
<_oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@413ogMgMooooool00005ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
07_ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003ooooooooo
o`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80
Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003oooooooooo`02o`0000gooooo00?o
0000ooooooooool01_ooool00omEEEGoV9RHooooo`05ooooo`03o`000?o^k^kooooo00Cooooo00?o
MgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004ooooo`03onk^k_l0003ooooo01Gooooo
00?o0000ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<07_ooooo001oooooo`03oiRH
V?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool00ol@413o0000o`000003o`0000Gooooo
00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05ooooo`03o`000?oooooooooo00Sooooo
1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000ooooooooool02_ooool01Ol@413o^[Zj
oooooonj^[[o410@07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?oEEEEoiRHV?ooool0
1?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_ooooooV9RHoa0@400Booooo`03onk^k_l@413o
gMgM01Kooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o000007_ooooo002F
ooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?ooool01Oooool02?mgMgOoIVIVoooooonH
V9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgooooo`0Dooooo`03oeEEEOmVIVKo000000co
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@1kooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33202 L
.08255 .34212 L
.0932 .34667 L
.10458 .35084 L
.11531 .35407 L
.12507 .35642 L
.12977 .35734 L
.13488 .35819 L
.13935 .35881 L
.14415 .35934 L
.1467 .35957 L
.14903 .35974 L
.15139 .35989 L
.15359 .36 L
.15614 .36009 L
.15749 .36012 L
.15824 .36014 L
.15892 .36015 L
.16018 .36016 L
.16088 .36017 L
.16153 .36017 L
.16273 .36016 L
.16399 .36015 L
.1653 .36013 L
.16649 .3601 L
.16787 .36006 L
.16917 .36002 L
.17401 .35977 L
.17675 .35958 L
.17928 .35937 L
.18502 .35879 L
.19465 .3575 L
.20368 .35597 L
.22428 .35151 L
.26297 .34118 L
.28262 .33595 L
.30411 .33102 L
.31404 .32918 L
.32464 .3276 L
.32979 .32699 L
.33464 .32652 L
.33901 .32618 L
.34374 .32591 L
.34609 .32582 L
.34742 .32578 L
.34863 .32575 L
.34975 .32573 L
.35097 .32571 L
.35213 .3257 L
Mistroke
.3532 .3257 L
.35386 .3257 L
.35456 .32571 L
.35585 .32572 L
.3571 .32574 L
.35824 .32577 L
.36086 .32586 L
.36361 .32599 L
.36612 .32614 L
.36881 .32635 L
.37365 .32681 L
.37941 .32753 L
.38465 .32835 L
.39459 .33032 L
.40378 .33265 L
.42455 .33972 L
.44325 .34816 L
.46387 .35958 L
.50413 .38708 L
.54287 .41723 L
.58406 .44872 L
.60462 .46274 L
.62373 .47411 L
.64338 .48376 L
.6619 .49072 L
.67174 .49351 L
.67692 .49471 L
.68239 .49578 L
.68701 .49653 L
.69208 .49717 L
.6943 .4974 L
.69669 .49761 L
.69873 .49775 L
.70099 .49788 L
.70231 .49793 L
.70355 .49797 L
.70486 .49801 L
.70559 .49802 L
.70627 .49803 L
.7074 .49804 L
.70864 .49803 L
.70994 .49802 L
.71115 .498 L
.71184 .49798 L
.71259 .49796 L
.71395 .4979 L
.71649 .49777 L
.71947 .49756 L
.72221 .49731 L
.72686 .49677 L
Mistroke
.73197 .496 L
.74232 .4939 L
.75247 .49115 L
.76175 .48804 L
.78263 .47908 L
.82236 .45516 L
.86057 .42502 L
.90124 .38719 L
.94039 .34713 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .33179 L
.08255 .3421 L
.0932 .34679 L
.10458 .35113 L
.11531 .3545 L
.12507 .35695 L
.12977 .35791 L
.13488 .35879 L
.13935 .35943 L
.14415 .35997 L
.1467 .3602 L
.14903 .36038 L
.15139 .36052 L
.15359 .36062 L
.15482 .36067 L
.15614 .3607 L
.15689 .36072 L
.1576 .36073 L
.15823 .36074 L
.15892 .36075 L
.16021 .36075 L
.16085 .36075 L
.16156 .36075 L
.16282 .36074 L
.16399 .36071 L
.16529 .36068 L
.16672 .36064 L
.1693 .36052 L
.17181 .36038 L
.17414 .36021 L
.17941 .35974 L
.18502 .35908 L
.19439 .35767 L
.20449 .35574 L
.22277 .35143 L
.26391 .33984 L
.28444 .33432 L
.30353 .33005 L
.31301 .32836 L
.32196 .3271 L
.32691 .32654 L
.33227 .32607 L
.33464 .3259 L
.33715 .32575 L
.3393 .32565 L
.34164 .32556 L
.34295 .32553 L
.34417 .3255 L
.34533 .32548 L
Mistroke
.34657 .32547 L
.34779 .32547 L
.34894 .32547 L
.34997 .32548 L
.35108 .3255 L
.3523 .32553 L
.35365 .32556 L
.35636 .32567 L
.35887 .3258 L
.36122 .32596 L
.36584 .32635 L
.37006 .32681 L
.37953 .32821 L
.38947 .33021 L
.39865 .33256 L
.41943 .33959 L
.43813 .34784 L
.45874 .35884 L
.499 .3848 L
.53774 .41294 L
.57893 .4427 L
.61861 .46777 L
.63861 .47809 L
.65677 .48575 L
.67642 .49196 L
.6816 .49321 L
.68721 .49438 L
.69247 .49529 L
.69738 .49598 L
.70196 .49648 L
.70431 .49668 L
.70687 .49686 L
.70832 .49694 L
.70967 .497 L
.71093 .49705 L
.7116 .49707 L
.71232 .49709 L
.71357 .49712 L
.71473 .49713 L
.71538 .49714 L
.71607 .49714 L
.7173 .49713 L
.71861 .49711 L
.71981 .49709 L
.7212 .49704 L
.7225 .49699 L
.72483 .49687 L
.72735 .4967 L
.73307 .49614 L
.73835 .49543 L
Mistroke
.74803 .49362 L
.75709 .49135 L
.77772 .48409 L
.79799 .47423 L
.81652 .46299 L
.85624 .43249 L
.89446 .39664 L
.93512 .35412 L
.97427 .31115 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@
4?o<c<`5ooooo`008Oooool00ol0003oo`00ool0000<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003ooooooooo
o`02ool000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool2o`0001?ooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool00_ooool2ool00?oooooo8Oooool00ooo003o0000oooo
o`0Cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ool00?ooool0oooooolOooooo`03ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo
00Gooooo0_oo001Kooooo`;oo`00_oooool00ooo003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oo003oo`0004kooooo0ooo000:o`0000[oo`000ol0002aooooo`03
ool00?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ool00?oo0000
Aoooool5ool000?o00005?ooool00ooo003oooooooooo`03o`000:gooooo00?oo`00ooooooooool0
8?ooool0027ooooo0ol00009ooooo`;o000000?oo`00ooooooooool0@?ooool4ool00003o`000?oo
oooooooo01oooooo0ol0002Yooooo`03ool00?oooooooooo027ooooo000Qooooo`03o`000?oooooo
oooo00_ooooo00?o0000ool00?l00000?Oooool3ool000;o00009oooool3o`000:Gooooo00?oo`00
ooooooooool08_ooool0027ooooo00?o0000ooooooooool03_ooool2o`0003Oooooo0_l00002ool0
02gooooo1?oo00000ol0003oooooooooo`2Oooooo`03ool00?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo013ooooo0ol0000aooooo`?o0000=Oooool3ool009kooooo00?oo`00oooooooo
ool09?ooool0027ooooo00?o0000ooooooooool04oooool3o`0002_ooooo0ol0000kooooo`;oo`00
Voooool00ooo003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0Fooooo`04ool00?l0
003o0000o`0002Cooooo0_oo00000ol0003oooooooooo`0mooooo`03o`000?oo003ooooo09Sooooo
00?oo`00ooooooooool09_ooool0027ooooo00?o0000ooooooooool05oooool3ool000?o00007?oo
ool5ool004Cooooo0_oo00000ol0003oooooooooo`2Cooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`?o00006_ooool4ool000;o00004_ooool3o`0000Coo`00Boooool00ooo003o0000o`00002B
ooooo`03ool00?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo01kooooo2?oo000:o`00
00Goo`00D?ooool01?oo003oooooo`000?l0002?ooooo`03o`000?oooooooooo02Wooooo000Qoooo
o`03o`000?oooooooooo08Kooooo00Coo`00oooooooooooo0000SOooool00ol0003oooooooooo`0Z
ooooo`008Oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0:oooool0027ooooo00?o0000ooooooooool0Roooool2o`0008Sooooo00?o0000oooooooo
ool0;?ooool0027ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`2?ooooo`;o0000POooool0
0ol0003oooooooooo`0_ooooo`008Oooool3o`0008oooooo0ooo001oooooo`03o`000?oo003ooooo
033ooooo000Qooooo`03o`000?oooooooooo09;ooooo0_oo001looooo`03o`000?oo003ooooo037o
oooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000ool00?ooool0NOooool00ol0003oo`00
ooooo`0booooo`008Oooool00ol0003oooooooooo`2Eooooo`03ool00?oooooooooo07Kooooo00?o
0000ool00?ooool0<oooool0027ooooo00?o0000ooooooooool0U_ooool00ooo003oooooooooo`1d
ooooo`03o`000?oo003ooooo03Cooooo000Qooooo`03o`000?oooooooooo09Oooooo0_oo001coooo
o`03o`000?oo003ooooo03Gooooo000Qooooo`03o`000?oooooooooo09Wooooo00?oo`00oooooooo
ool0Koooool00ol0003oo`00ooooo`0fooooo`008Oooool3o`0009[ooooo00?oo`00ooooooooool0
KOooool00ol0003oo`00ooooo`0gooooo`008Oooool00ol0003oooooooooo`2Kooooo`03ool00?l0
003ooooo06_ooooo00?o0000ool00?ooool0>?ooool0027ooooo00?o0000ooooooooool0W?ooool0
0ooo003o0000ooooo`1Yooooo`03o`000?oo003ooooo03Wooooo000Qooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool0I_ooool00ol0003oo`00ooooo`0jooooo`008Oooool00ol0003o
ooooooooo`2Oooooo`;o0000IOooool00ol0003oo`00ooooo`0kooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0??ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0moooo
o`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00
0:?ooooo0_l0001Mooooo`;o0000@?ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0YOooool2ool005[ooooo00?o0000oooo
ooooool0@?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Vooooo`03o`000?oo003ooooo05Oooooo00?o0000
ooooooooool0@Oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Yoooool00ol0003oo`00ool0001Dooooo`;o0000A?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0Z?ooool2o`000003ool00?oooooooooo053ooooo00?o0000ool00?oo0000A?ooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Z
ooooo`03o`000?oo003oo`0004oooooo00?o0000ool00?ooool0AOooool0027ooooo00?o0000oooo
ooooool0Zoooool00ol0003oooooool0001<ooooo`03o`000?oo003oo`0004Oooooo000Qooooo`03
o`000?oooooooooo0:cooooo0_l00002ool004Wooooo00?o0000ool00?ooool0B?ooool0027ooooo
0ol0002^ooooo`;o000000?oo`00ooooooooool0AOooool00ol0003oo`00ooooo`19ooooo`008Ooo
ool00ol0003oooooooooo`2`ooooo`03o`000?oo003ooooo04?ooooo00?o0000ool00?oo0000Booo
ool0027ooooo00?o0000ooooooooool0/Oooool00ol0003oo`00ooooo`10ooooo`;o000000?oo`00
ooooooooool0Boooool0027ooooo00?o0000ooooooooool0/oooool2o`0003gooooo0_l00002ool0
04kooooo000Qooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0>?ooool2o`000003
oooooooo003ooooo04oooooo000Qooooo`03o`000?oooooooooo0;Kooooo0_l0000gooooo`04o`00
0?ooooooooooool0057ooooo000Qooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
<_ooool2o`0005Gooooo000Qooooo`?o0000^Oooool2o`0000;oo`00;_ooool2o`0005Oooooo000Q
ooooo`03o`000?oooooooooo0;_ooooo0_l00002ool002[ooooo0_l0001Iooooo`008Oooool00ol0
003oooooooooo`2mooooo`;o00000_oo000Vooooo`;o0000Foooool0027ooooo00?o0000oooooooo
ool0_oooool2o`0000;oo`008_ooool2o`0000;oo`00Foooool0027ooooo00?o0000ooooooooool0
`_ooool00ol0003oo`00ool00002ool001cooooo00Co0000ool00?oo003oo`00GOooool0027ooooo
00?o0000ooooooooool0aOooool2o`0000?oo`005_ooool01?l0003oo`00ool00?oo001Pooooo`00
8Oooool00ol0003oooooooooo`38ooooo`;o000000?oo`00ooooooooool04?ooool2o`0000;oo`00
Hoooool0027ooooo00?o0000ooooooooool0boooool:o`0000[oo`00IOooool0027ooooo0ol0003o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3
o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
Y?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:Oooooo0023ooooo`?o00005?oo
ool00olQ8B7ogMgMooooo`06ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Yooo
ool007_ooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool0
2oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oV9RHoeEEEOooool01_ooool00omEEEGo
V9RHooooo`02ooooo`Go00002Oooool00omEEEGoZJVYooooo`02ooooo`06okZj^_m4A4Cooooooooo
oon7QhOoIVIV5Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo001kooooo`07oa0@4?oM
gMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_ooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000ooooooooool00_ooool01OnH
V9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X2ooooo`03onk^
k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`1dooooo`00Noooool01ol0003ooooo
omgMgOlb<S;oooooonk^k_l@41000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_mgMgL6ooooo`03oc8b<_oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h03?ooool01?l@
413ogMgMooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Loooool007_ooooo00CoEEEE
ojVYZOoooooo00000_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Kooooo
00?ok^k^oa0@4?o^k^h01Oooool00olb<S;oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00_ooooo
00CoQhN7ofIVI_oooooo00001?ooool00ol0003oooooooooo`0:ooooo`Ko00001Oooool00ol0003o
ooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801oooool00omgMgOo<S8booooo`1doooo
o`00Noooool00ooMgMgo8B4Qonk^kP03ooooo`04o`000?oooooo0000o`0000gooooo00?o0000oooo
ooooool01oooool00omEEEGoV9RHooooo`04ooooo`03o`000?o^k^kooooo00Gooooo00?oMgMgofIV
I_ooool02_ooool01?oMgMgo410@ooooool00003ooooo`03onk^k_l0003ooooo01Kooooo00?o0000
ooooooooool02_ooool01Oo<c<co0000o`000?l0003oc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01eooooo`00O?ooool00onHV9SoMgMgooooo`02ooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?l000000ol00006ooooo`03omgMgOl@413ooooo00Cooooo00?oEEEEogMgMoooool01_oo
ool00ol0003oooooooooo`08ooooo`Oo000000?oooooogMgMomEEED05oooool00ol0003ooooooooo
o`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00ol0003oooooooooo`1gooooo`00T_oo
ool00ol0003oooooooooo`08ooooo`03oeEEEOnHV9Sooooo00?ooooo00?ogMgMoa0@4?o^k^h00_oo
ool01Ol0003o^[ZjoooooonHV9So410@017ooooo00?ok^k^oa0@4?oMgMd05oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00ol0003oooooooooo`1gooooo`00
T_ooool00ol0003oooooooooo`08ooooo`03okZj^_m4A4Cooooo00Cooooo00WoMgMgofIVI_oooooo
oooooiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00omVIVKoMgMgooooo`0Eooooo`03oeEEEOmVIVKo
000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`Co0000M_ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -46.625 0 ]
[.5 .63053 46.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -107.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
152.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35624 L
.10458 .40076 L
.12507 .41833 L
.14415 .43187 L
.16254 .44218 L
.17277 .44672 L
.18221 .45017 L
.19242 .45308 L
.1977 .45426 L
.20351 .45531 L
.20856 .45601 L
.21329 .45649 L
.2159 .45668 L
.21828 .45681 L
.2196 .45686 L
.22029 .45689 L
.22104 .45691 L
.22175 .45693 L
.22239 .45694 L
.22365 .45695 L
.22486 .45695 L
.22598 .45695 L
.22721 .45693 L
.22853 .4569 L
.22991 .45685 L
.23122 .45679 L
.23368 .45666 L
.23597 .45649 L
.2381 .4563 L
.2429 .45576 L
.2477 .45507 L
.253 .45414 L
.26372 .4517 L
.28307 .44558 L
.30392 .43683 L
.34506 .41461 L
.38469 .38987 L
.4228 .36603 L
.46336 .34337 L
.5024 .32621 L
.52375 .31924 L
.53354 .31666 L
.5439 .31436 L
.55343 .31263 L
.56391 .31116 L
.56851 .31065 L
.57345 .3102 L
.57777 .30988 L
.58237 .30962 L
Mistroke
.58512 .3095 L
.58762 .30941 L
.58883 .30938 L
.59013 .30935 L
.59136 .30932 L
.5925 .30931 L
.5932 .3093 L
.59383 .30929 L
.59454 .30929 L
.5953 .30929 L
.59603 .30929 L
.59682 .30929 L
.59756 .30929 L
.59825 .30929 L
.59947 .3093 L
.60017 .30931 L
.60082 .30932 L
.60354 .30937 L
.606 .30944 L
.60859 .30953 L
.61322 .30975 L
.6182 .31005 L
.62364 .31045 L
.64329 .3125 L
.66426 .31545 L
.70581 .32231 L
.72665 .3256 L
.74584 .32822 L
.76456 .33024 L
.774 .33102 L
.77931 .33138 L
.78436 .33167 L
.78924 .3319 L
.79181 .332 L
.79455 .33209 L
.79684 .33215 L
.79937 .33221 L
.80168 .33225 L
.80384 .33228 L
.80506 .33229 L
.80576 .3323 L
.8064 .3323 L
.80707 .3323 L
.80779 .33231 L
.80909 .33231 L
.81028 .33231 L
.81156 .3323 L
.81278 .33229 L
.8139 .33228 L
.81641 .33225 L
Mistroke
.81917 .33219 L
.82205 .33212 L
.82475 .33204 L
.82972 .33184 L
.83514 .33157 L
.84501 .33092 L
.86354 .3292 L
.88323 .3267 L
.90421 .3234 L
.94581 .31544 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .35913 L
.10458 .40096 L
.12507 .4172 L
.14415 .42998 L
.16371 .44064 L
.18221 .44835 L
.192 .45147 L
.19716 .45283 L
.20263 .45407 L
.20722 .45494 L
.21228 .45573 L
.21689 .45627 L
.2212 .45665 L
.22377 .45681 L
.225 .45686 L
.22616 .45691 L
.22682 .45693 L
.22754 .45695 L
.22879 .45697 L
.22949 .45698 L
.23024 .45699 L
.23088 .45699 L
.23158 .45699 L
.23287 .45698 L
.23404 .45695 L
.23469 .45694 L
.2354 .45692 L
.23668 .45687 L
.23916 .45674 L
.24145 .45659 L
.24572 .4562 L
.25043 .45562 L
.25997 .45396 L
.27007 .45155 L
.27932 .44875 L
.30018 .44057 L
.3398 .41917 L
.37791 .3942 L
.41847 .36697 L
.45751 .34377 L
.47743 .33399 L
.49901 .3253 L
.50912 .32196 L
.51981 .31895 L
.52984 .3166 L
.53899 .31485 L
.54843 .31344 L
.55328 .31285 L
.55857 .31233 L
Mistroke
.56344 .31195 L
.56796 .31167 L
.57228 .31148 L
.5747 .3114 L
.57688 .31135 L
.57809 .31133 L
.57921 .31131 L
.58045 .3113 L
.58177 .31129 L
.58244 .31129 L
.58316 .31129 L
.58447 .31129 L
.58575 .3113 L
.58693 .31131 L
.58803 .31132 L
.58906 .31134 L
.59141 .31139 L
.5937 .31146 L
.59617 .31155 L
.60147 .31179 L
.60704 .31213 L
.617 .3129 L
.63678 .31497 L
.65516 .3173 L
.69426 .32256 L
.71421 .32495 L
.73581 .32705 L
.74594 .32783 L
.75665 .32849 L
.7658 .32893 L
.77061 .32911 L
.77584 .32927 L
.77856 .32933 L
.78107 .32939 L
.78343 .32943 L
.78603 .32946 L
.78835 .32949 L
.78942 .3295 L
.79054 .3295 L
.79174 .32951 L
.79284 .32952 L
.79403 .32952 L
.79533 .32952 L
.796 .32952 L
.79674 .32952 L
.79743 .32951 L
.79807 .32951 L
.79928 .32951 L
.80056 .3295 L
.80322 .32947 L
Mistroke
.80615 .32943 L
.81136 .32934 L
.81623 .32922 L
.82663 .32886 L
.8365 .32839 L
.85503 .32719 L
.87485 .32544 L
.89324 .32333 L
.93239 .31724 L
.97399 .30938 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00;ooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?oo
ooooAOooool0027ooooo00?o0000ooooooooool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo
03_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM03gooooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oiRHV?lQ8B7ok^k^01cooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb
<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<043o
oooo00?oMgMgofIVI_ooool06_ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Iooooo`00
8Oooool3o`0003gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oo
oooo00Go0000okZj^_ooooooV9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l00000?oooool00omE
EEGoIVIVo`00000=ooooo`Co0000?_ooool01OnHV9So410@o`000?lQ8B7oc<c<01_ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>ooo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`3ooooooc_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooool7o`000003ool00?l0003o00000?oo00009Ol0
0004ool000Oo00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo0ol0000:ool000;ooooo00Co0000oooooooooooooooo
3ol0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`Coo`0000Co0000oooooooooooo00004oooool01?o^k^ko8B4Qoa0@4?o^k^h5oooo
o`008Oooool00ol0003oo`00ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo1?oo00000ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo2Ooo0002ooooo`Go00001_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ol00002ool000Oo
oooo00?o0000ooooooooool04Oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003o
ooooool0002Gooooo`Koo`000_l0000Rooooo`Goo`000_ooool5o`0004Wooooo1Ol0000Oooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`04o`000?ooooooooooool009?ooooo0ooo00001?oooooo
0000o`000?l0000[ooooo`;oo`001Oooool4o`00043ooooo1?oo00000ol0003oooooooooo`0/oooo
o`008Oooool01Ol0003oooooooooooooooooo`00093ooooo0_oo00001?oooooo0000o`000?l0000i
ooooo`03o`000?oo003oo`0000Koo`00;?ooool;ool00003o`000?oooooooooo033ooooo000Qoooo
o`05o`000?ooooooooooooooool00000Soooool01?oo003o0000o`000?l00012ooooo`?o00002Ooo
000Qooooo`;oo`0000?oooooo`000?l000001?l0000gooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo08[ooooo0ol0001Aooooo`Wo000000?oooooool00?oo00002ooo000=
o`0003gooooo000Qooooo`?o00000oooool00ol0003oooooooooo`27ooooo`;o0000GOooool<o`00
04cooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q?ooool2o`000;Oo
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0O_ooool2ool000?o0000
^Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1looooo`;oo`000_l0
002looooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Wooooo0_oo0002
o`000;kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Moooool00ooo
003o0000o`000030ooooo`008Oooool00ol0003oooooooooo`07ooooo`03ool00?l0003ooooo07Go
oooo0_oo00000ol0003oooooooooo`30ooooo`008Oooool3o`0000Sooooo00?oo`00o`000?ooool0
L_ooool2ool00003o`000?oooooooooo0<;ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
o`00o`000?ooool0L?ooool00ooo003o0000o`000035ooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03ool00?l0003ooooo06gooooo0_oo00000ol0003oooooooooo`35ooooo`008Oooool00ol0
003oooooooooo`0;ooooo`03ool00?l0003ooooo06_ooooo00?oo`00o`000?ooool0b?ooool0027o
oooo00?o0000ooooooooool03?ooool00ooo003o0000ooooo`1Yooooo`03o`000?oooooooooo0<Wo
oooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00o`000?ooool0I_ooool2o`000<cooooo
000Qooooo`03o`000?oooooooooo00kooooo00?oo`00o`000?ooool0I?ooool00ol0003ooooooooo
o`3<ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03ool00?l0003ooooo067ooooo0_l0003?
ooooo`008Oooool3o`00013ooooo00?oo`00o`000?ooool0Goooool00ol0003oooooooooo`3?oooo
o`008Oooool00ol0003oooooooooo`0Aooooo`03ool00?l0003ooooo05_ooooo0_oo00000ol0003o
ooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Booooo`03ool00?l0003ooooo05Wooooo
00?oo`00o`000?ooool0doooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Fooooo`03ool00?l0003ooooo0=Cooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Doooool2ool00=Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0DOooool00ooo003oooooooooo`3Gooooo`008Oooool00ol0003oooooooooo`0Gooooo`;o
0000Coooool2ool00=[ooooo000Qooooo`?o00006Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oo003ooooo0=_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?oo
ool2ool00=gooooo000Qooooo`03o`000?oooooooooo01[ooooo0_oo0017ooooo`03o`000?oo003o
oooo0=kooooo000Qooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0@_ooool2o`00
0003ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo01gooooo0_oo0010ooooo`;o
0000hoooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0koooo
o`;o0000iOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo023ooooo0_oo000iooooo`;o0000ioooool000Oo
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Qoooo
o`03o`000?oo003ooooo03Kooooo00?o0000ooooooooool0ioooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08_ooool00ol0
003oo`00ool0000cooooo`03o`000?oo003oo`000>Wooooo0007ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool08oooool2
o`000003ool00?oooooooooo02kooooo00?o0000ool00?oo0000joooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09Oooool0
0ol0003oo`00ooooo`0/ooooo`03o`000?oo003oo`000>gooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?oo`00
o`000?ooool09oooool2o`0000;oo`00koooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001Oooool00ol0003oooooooooo`0Yooooo`?o00008oooool01?l0003oo`00ool00?oo
003aooooo`008Oooool00ol0003oooooooooo`0/ooooo`?o00007_ooool00ol0003oo`00ool0003d
ooooo`008Oooool00ol0003oooooooooo`0_ooooo`?o00006?ooool2o`0000;oo`00m_ooool0027o
oooo0ol0000aooooo`Coo`004_ooool3o`000?[ooooo000Qooooo`03o`000?oooooooooo03Cooooo
00?o0000ool00?oo00001Ooo0002ooooo`?o000000?oo`00o`000?l000000ol0003mooooo`008Ooo
ool00ol0003oooooooooo`0jooooo`;o00001Ooo003oooooo`Cooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0
003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00Z?ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo0:?ooooo0027oooo
o`?o00004oooool00olQ8B7ogMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@
4?oMgMd0Xoooool007kooooo00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000
ooooooooool02oooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01ooo
ool01?mEEEGoV9RHooooooooool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4
ooooo`02ooooo`03ohN7QomVIVKooooo01?ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1?ooool01?l@413o0000odA4A?o<c<alooooo`00O_ooool01ol@413ogMgMogMgMolQ8B7oooooohN7
QomVIVH00oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool0
0ol0003ogMgMooooo`06ooooo`09o`000?oooooooooooooooonHV9So8B4Qonk^k_ooooooA4A400[o
oooo00KoEEEEoiRHV?oooooooooooa0@4?nj^[X3ooooo`03onk^k_l0003ooooo00_ooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oiRHV?l@413ogMgM07_ooooo001noooo
o`07o`000?oooooogMgMoc8b<_ooooook^k^oa0@4003ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01Oooool2ogMgM`Oooooo00?o<S8booooooooool00_ooool00onHV9So8B4Qonk^
kP0<ooooo`04oa0@4?oMgMgoooooo`0000Gooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0=ooooo`03ohN7QomEEEGooooo07[ooooo001nooooo`04oeEEEOnYZJWoooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^
k^h01_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oo
oooo00001Oooool00ol0003oooooooooo`0:ooooo`Ko00001?ooool00ol0003oooooooooo`0:oooo
o`05olc<c?lQ8B7o0000oeEEEOl00000Noooool007kooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0
003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_ooool00omEEEGoV9RHooooo`05oooo
o`03o`000?o^k^kooooo00Cooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgo410@ooooool00004
ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool02_ooool01OlQ8B7oQhN7oooooonH
V9So000007_ooooo001oooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol@413o0000o`000003o`0000Gooooo00?ogMgMoa0@4?ooool01Oooool00omEEEGoMgMgooooo`05
ooooo`03o`000?oooooooooo00Sooooo1ol00002ooooo`03ogMgMomEEEGooooo01Gooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000007_ooooo002Fooooo`03o`000?oooooo
oooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj^_oooooo
V9RHoa0@400Booooo`03onk^k_l@413ogMgM01Kooooo00?o0000ooooooooool02_ooool01OlQ8B7o
V9RHoooooomgMgOoEEEE07_ooooo002Fooooo`03o`000?oooooooooo00Oooooo00?o^[ZjodA4A?oo
ool01Oooool02?mgMgOoIVIVoooooonHV9So410@o`000?lQ8B7oc<c<4_ooool00omVIVKoMgMgoooo
o`0Dooooo`03oeEEEOmVIVKo000000cooooo00Goc<c<oa0@4?l0003o<S8bonk^kP1kooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -49.625 0 ]
[.5 .63053 49.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -110.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
158.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36755 L
.10458 .42582 L
.14415 .47106 L
.16408 .4894 L
.18221 .50317 L
.20178 .5147 L
.21254 .5195 L
.22272 .52301 L
.23241 .52541 L
.2373 .52627 L
.24012 .52666 L
.24269 .52695 L
.24504 .52716 L
.24728 .52731 L
.2485 .52737 L
.24964 .52741 L
.25088 .52744 L
.25158 .52745 L
.25221 .52746 L
.25336 .52746 L
.25442 .52745 L
.25558 .52743 L
.2568 .52739 L
.25787 .52734 L
.25887 .52729 L
.26113 .52713 L
.26373 .52689 L
.26614 .52661 L
.27158 .52578 L
.27638 .52481 L
.28148 .52354 L
.2903 .52079 L
.30004 .51693 L
.31939 .50682 L
.34024 .4925 L
.38138 .45513 L
.42101 .41025 L
.45912 .36215 L
.49968 .30946 L
.53872 .2609 L
.58022 .21516 L
.6202 .17975 L
.63852 .16699 L
.65867 .15575 L
.67854 .14766 L
.68941 .14452 L
.69959 .14242 L
.70457 .14168 L
.70719 .14137 L
Mistroke
.70999 .14109 L
.71268 .14088 L
.71512 .14074 L
.7163 .14069 L
.71757 .14065 L
.71877 .14062 L
.71987 .1406 L
.72095 .14059 L
.7221 .14059 L
.72319 .1406 L
.72418 .14061 L
.72534 .14064 L
.7266 .14068 L
.72889 .14079 L
.73129 .14095 L
.73384 .14116 L
.73841 .14165 L
.74331 .14235 L
.74781 .14315 L
.75792 .14545 L
.77621 .15136 L
.79517 .15971 L
.81589 .17117 L
.8565 .19953 L
.8956 .23239 L
.93715 .27105 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36516 L
.10458 .42504 L
.14415 .47198 L
.16408 .49075 L
.18221 .50461 L
.20178 .51599 L
.21254 .52062 L
.21738 .52233 L
.22272 .52394 L
.22739 .52512 L
.23241 .52614 L
.23518 .5266 L
.23772 .52695 L
.2403 .52725 L
.24269 .52746 L
.24488 .52761 L
.2461 .52767 L
.24721 .52771 L
.24843 .52775 L
.24975 .52777 L
.251 .52777 L
.25214 .52776 L
.25322 .52774 L
.25423 .52771 L
.25533 .52767 L
.25651 .52761 L
.25893 .52744 L
.26113 .52725 L
.26594 .52665 L
.27104 .52578 L
.28022 .52362 L
.29008 .52043 L
.30098 .51591 L
.32032 .50542 L
.34118 .4908 L
.38232 .45325 L
.42194 .40863 L
.46005 .36095 L
.50061 .30864 L
.53966 .26031 L
.58116 .21482 L
.60196 .19533 L
.62114 .17974 L
.64101 .16621 L
.6596 .15612 L
.67837 .14855 L
.68832 .14562 L
.69386 .14431 L
.69901 .1433 L
Mistroke
.70432 .14247 L
.70914 .1419 L
.71189 .14165 L
.71449 .14147 L
.71582 .14139 L
.71722 .14133 L
.71796 .1413 L
.71877 .14127 L
.71944 .14126 L
.72018 .14124 L
.72088 .14123 L
.72153 .14122 L
.72281 .14121 L
.72397 .14122 L
.72521 .14124 L
.72653 .14126 L
.72776 .1413 L
.72912 .14136 L
.73058 .14143 L
.73305 .14159 L
.73565 .14181 L
.74028 .14231 L
.7453 .14302 L
.74985 .14381 L
.76006 .1461 L
.77844 .15191 L
.79767 .16017 L
.81848 .17141 L
.85945 .19959 L
.8989 .23291 L
.93684 .2692 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o
0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000<oooooo0_l0000>ool006Gooooo000Q
ooooo`03o`000?oooooooooo0<cooooo0ol0000@ooooo`?oo`000ol0001Oooooo`008Oooool00ol0
003oooooooooo`39ooooo`?o00006Oooool3o`0005cooooo000Qooooo`03o`000?oooooooooo0<Ko
oooo0_oo00000ol0003oooooooooo`0Mooooo`;o0000F_ooool0027ooooo00?o0000ooooooooool0
aOooool00ooo003o0000ooooo`0Rooooo`03o`000?oo003oo`0005Oooooo000Qooooo`03o`000?oo
oooooooo0<?ooooo0_oo000Wooooo`03o`000?oo003oo`0005Gooooo000Qooooo`03o`000?oooooo
oooo0<3ooooo00?o0000ool00?oo0000:oooool00ol0003oo`00ool0001Cooooo`008Oooool00ol0
003oooooooooo`2nooooo`03o`000?oo003oo`0002oooooo00Co0000ool00?oo003oo`00D?ooool0
027ooooo0ol0002looooo`03o`000?oo003oo`0003Cooooo00?o0000ool00?oo0000C_ooool0027o
oooo00?o0000ooooooooool0^oooool00ol0003oo`00ooooo`0gooooo`03o`000?oo003ooooo04co
oooo000Qooooo`03o`000?oooooooooo0;[ooooo00?o0000ool00?ooool0>_ooool00ooo003ooooo
ooooo`1:ooooo`008Oooool00ol0003oooooooooo`2iooooo`03o`000?oo003ooooo03cooooo00?o
o`00ooooooooool0BOooool0027ooooo00?o0000ooooooooool0]oooool2o`00043ooooo00?oo`00
o`000?ooool0B?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0]_ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2eooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0AOooool000Go00000_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool3o`000;Cooooo00?o0000ooooooooool0A_oo
ool2o`0004Gooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`12ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0;7ooooo0_l0001=ooooo`03o`000?oooooooooo047ooooo
0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0;3ooooo0_oo001?ooooo`03o`000?oo003oo`00043ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:oooooo
00?oo`00ooooooooool0DOooool00ol0003oo`00ooooo`0nooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo0:kooooo00?oo`00ooooooooool0
Doooool00ol0003oo`00ooooo`0mooooo`008Oooool00ol0003oooooooooo`2]ooooo`03ool00?oo
oooooooo05Gooooo00?o0000ool00?ooool0??ooool0027ooooo00?o0000ooooooooool0[?ooool0
0ooo003oooooooooo`1Hooooo`03ool00?oooooooooo03[ooooo000Qooooo`?o0000Zoooool00ooo
003oooooooooo`1Jooooo`;oo`00>_ooool0027ooooo00?o0000ooooooooool0Zoooool00ooo003o
ooooooooo`1Kooooo`03o`000?oo003ooooo03Sooooo000Qooooo`03o`000?oooooooooo0:[ooooo
00?oo`00ooooooooool0GOooool00ol0003oo`00ooooo`0gooooo`008Oooool00ol0003ooooooooo
o`2Yooooo`03ool00?oooooooooo063ooooo00?oo`00ooooooooool0=Oooool0027ooooo00?o0000
ooooooooool0Z?ooool00ooo003oooooooooo`1Rooooo`03ool00?oooooooooo03Cooooo000Qoooo
o`03o`000?oooooooooo0:Oooooo00?oo`00ooooooooool0I?ooool00ooo003oooooooooo`0coooo
o`008Oooool00ol0003oooooooooo`2Vooooo`03ool00?oooooooooo06Kooooo00?o0000oooooooo
ool0<_ooool0027ooooo0ol0002Uooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
<Oooool0027ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo033ooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool0L_ooool00ol0003oo`00ooooo`0/ooooo`008Oooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000
ooooooooool0W_ooool2ool007Oooooo00?oo`00ooooooooool0:_ooool0027ooooo0ol0002Noooo
o`03ool00?oooooooooo07Oooooo00?oo`00ooooooooool0:Oooool0027ooooo00?o0000oooooooo
ool0?Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0?Oooool4o`000003oa0@4?oooooooooo00Kooooo00?oo`00ooooooooool0<_ooool4
o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0<_oo
ool00ooo003oooooooooo`08ooooo`Go00006oooool0027ooooo00?o0000ooooooooool0?Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03kooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo03;ooooo0_oo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
6oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03o`000?oo003ooooo00Oooooo
00?oV9RHob4Q8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oo003ooooo03Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0eooooo`03ool0
0?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0=oooool00ooo003oooooooooo`06ooooo`03ogMgMomVIVKooooo
01[ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
03Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0kooooo`09ool00?oooooooooo
ooooool0003o^[ZjoooooonHV9So410@01_ooooo000Qooooo`03o`000?oooooooooo03gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000?_ooool00omEEEGoIVIVo`000004ooooo`03o`00
0?oo003ooooo03Sooooo00?oEEEEofIVI_l000003Oooool4o`0003_ooooo00Soo`00oooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c1_ooooo000Qooooo`03o`000?oooooooooo09Kooooo00?o0000ool0
0?ooool0ROooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`2Fooooo`03
ool00?oooooooooo08[ooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool0
UOooool00ooo003oooooooooo`2<ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0Booooo`;o00000_oo
ool2o`0000Cooooo000Qooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0
000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ool00?ooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo00?o0000ool00?ooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool2o`0000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooool0002@ooooo`03o`000?oo
oooooooo0:Oooooo0_l00002ooooo`;o00001?ooool0027ooooo00Co0000ooooool0003oo`00S_oo
ool00ol0003oooooooooo`2booooo`008Oooool01?l0003ooooooooooooo002=ooooo`03ool00?l0
003ooooo0;?ooooo000Qooooo`05o`000?ooooooooooo`000?oo0000S?ooool00ooo003ooooooooo
o`2cooooo`008Oooool01_l0003ooooooooooooooooo0000ool008[ooooo00?oo`00ooooooooool0
]?ooool0027ooooo0ol00002ooooo`03o`000?oo003ooooo08Oooooo00?oo`00ooooooooool0]Ooo
ool0027ooooo00?o0000ooooooooool00_ooool00ol0003oo`00ooooo`26ooooo`03o`000?oo003o
oooo0;Kooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ool00?ooool0QOooool00ooo
003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo003ooooo08?o
oooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oo`00
ooooo`22ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ool00?ooool0P?ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oo003ooooo07oooooo00?oo`00ooooooooool0^Oooool0027ooooo0ol00006oooo
o`03o`000?oooooooooo07kooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1looooo`03o`000?oo003ooooo0;_ooooo000Qooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Noooool00ol0003oo`00ooooo`2looooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07[ooooo00?oo`00ooooooooool0_?oo
ool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo0;gooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Moooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool0_oooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo0<3ooooo000Qooooo`?o00003?ooool00ol0003oo`00oooo
o`1booooo`03o`000?oooooooooo0<3ooooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00
ooooooooool0L?ooool00ol0003oooooooooo`31ooooo`008Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oo003ooooo06oooooo00?o0000ooooooooool0`_ooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oo`00ooooo`1]ooooo`03ool00?oooooooooo0<?ooooo000Qooooo`03o`00
0?oooooooooo00oooooo00?oo`00ooooooooool0Joooool00ol0003oo`00ooooo`34ooooo`008Ooo
ool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo06[ooooo00?oo`00ooooooooool0a?oo
ool0027ooooo00?o0000ooooooooool04?ooool00ol0003oo`00ooooo`1Yooooo`03ool00?oooooo
oooo0<Gooooo000Qooooo`?o00004Oooool00ol0003oo`00ooooo`1Wooooo`03ool00?oooooooooo
0<Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0IOooool00ooo003o
ooooooooo`37ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06?ooooo
00?o0000ool00?ooool0b?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003ooooooooo
o`1Rooooo`03ool00?oooooooooo0<Sooooo000Qooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool0HOooool00ooo003oooooooooo`39ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooooooo
o`0Eooooo`03ool00?oooooooooo05oooooo00?oo`00ooooooooool0b_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo01Kooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`3;ooooo`001oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0001Oooooo00?o
0000ooooooooool0Foooool00ooo003oooooooooo`3<ooooo`001oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo05[ooooo00?oo`00ooooooooool0cOooool000Oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0c_ooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo0<kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`3?ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`1?
ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`?o00007Oooool00ooo003oooooooooo`1>oooo
o`03o`000?oooooooooo0=?ooooo000Qooooo`03o`000?oooooooooo01kooooo00?oo`00oooooooo
ool0Boooool00ooo003o0000ooooo`3Eooooo`008Oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo04Wooooo00?oo`00ooooooooool0e_ooool0027ooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`17ooooo`03ool00?oooooooooo0=Oooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`3Hooooo`008Oooool00ol0
003oooooooooo`0Rooooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0fOooool0027o
oooo00?o0000ooooooooool08oooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo0=[o
oooo000Qooooo`?o00008oooool00ooo003o0000ooooo`10ooooo`03ool00?oooooooooo0=_ooooo
000Qooooo`03o`000?oooooooooo02Cooooo00?oo`00o`000?ooool0?_ooool00ooo003ooooooooo
o`3Looooo`008Oooool00ol0003oooooooooo`0Uooooo`03ool00?l0003ooooo03cooooo00?oo`00
ooooooooool0gOooool0027ooooo00?o0000ooooooooool09_ooool00ooo003o0000ooooo`0joooo
o`03ool00?oooooooooo0=kooooo000Qooooo`03o`000?oooooooooo02Oooooo00?oo`00o`000?oo
ool0>?ooool00ooo003oooooooooo`3Oooooo`008Oooool00ol0003oooooooooo`0Yooooo`;o0000
=_ooool00ooo003oooooooooo`3Pooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo037ooooo0_l0003Sooooo`008Oooool00ol0003oooooooooo`0/ooooo`;o0000<?ooool0
0ol0003oooooooooo`3Sooooo`008Oooool3o`0002kooooo00?o0000ooooooooool0:oooool2o`00
0>Kooooo000Qooooo`03o`000?oooooooooo02oooooo0_l0000Zooooo`03o`000?oooooooooo0>Ko
oooo000Qooooo`03o`000?oooooooooo033ooooo0_oo000Wooooo`;o0000jOooool0027ooooo00?o
0000ooooooooool0<_ooool2ool002?ooooo0_oo003[ooooo`008Oooool00ol0003oooooooooo`0d
ooooo`03ool00?oooooooooo01kooooo0_oo003]ooooo`008Oooool00ol0003oooooooooo`0eoooo
o`?oo`006oooool2ool00>oooooo000Qooooo`03o`000?oooooooooo03Sooooo0_oo00000ol0003o
ooooooooo`0Booooo`Coo`00lOooool0027ooooo0ol0000jooooo`?oo`000_l0000=ooooo`?oo`00
00?o0000ooooooooool0l_ooool0027ooooo00?o0000ooooooooool0?Oooool2ool000Co00001Ooo
ool01Ol0003oo`00ool00?oo003o00000?Oooooo000Qooooo`03o`000?oooooooooo04?ooooo1Ol0
003looooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`?o0000oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Tooooo`03ogMgMomVIVKooooo01Oooooo00?oIVIVogMgMoooool0
Yoooool008?ooooo0ol0000Dooooo`03ob4Q8OoMgMgooooo00Kooooo00?ogMgMoa0@4?o^k^h06?oo
ool00oo^k^ko410@omgMg@2Wooooo`00Noooool01on7QhOo0000oeEEEOmVIVKo0000oc8b<_o^k^h0
0_ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00onHV9So
EEEEooooo`06ooooo`03oeEEEOnHV9Sooooo00;ooooo1Ol00009ooooo`03oeEEEOnYZJWooooo00;o
oooo00Ko^[ZjodA4A?ooooooooooohN7QomVIVHEooooo`Co000000?o410@ooooooooool00_ooool2
ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07Gooooo
001kooooo`07oa0@4?oMgMgoMgMgob4Q8OooooooQhN7ofIVIP02ooooo`03o`000?oooooooooo00_o
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oMgMgooooo00Gooooo00?o0000oooo
ooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00KoEEEEoiRHV?oooooooooooa0@
4?nj^[X2ooooo`03onk^k_l0003ooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B46ooooo`03oiRHV?l@413ogMgM00Oooooo00?oMgMgoc8b<_ooool0M?ooool007_ooooo00Oo
0000oooooooMgMgo<S8booooooo^k^ko410@00;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`;oMgMg1_ooool00olb<S;oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00co
oooo00Co410@omgMgOoooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00gooooo00?oQhN7oeEEEOooool01oooool00ol0003oooooooooo`1cooooo`00Noooool01?mEEEGo
ZJVYooooool00002ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01_ooool0
0oo^k^ko410@onk^kP05ooooo`03oc8b<_oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02oooool0
1?n7QhOoIVIVooooool00004ooooo`03o`000?oooooooooo00[ooooo1_l00005ooooo`03o`000?oo
oooooooo00[ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000007ooooo`03ogMgMolb<S;ooooo07Cooooo
001kooooo`03omgMgOlQ8B7ok^k^00?ooooo00Co0000ooooool0003o00003Oooool00ol0003ooooo
ooooo`07ooooo`03oeEEEOnHV9Sooooo00Cooooo00?o0000onk^k_ooool01Oooool00omgMgOoIVIV
ooooo`0:ooooo`04omgMgOl@413oooooo`0000?ooooo00?ok^k^o`000?ooool05_ooool00ol0003o
ooooooooo`0:ooooo`05ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07Gooooo001looooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool03?ooool00ol@
413o0000o`000003o`0000Kooooo00?ogMgMoa0@4?ooool01?ooool00omEEEGoMgMgooooo`06oooo
o`03o`000?oooooooooo00Sooooo1ol000000oooooooMgMgoeEEE@0Gooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Oooooo002Boooo
o`03o`000?oooooooooo00Sooooo00?oEEEEoiRHV?ooool00oooool00ooMgMgo410@onk^kP02oooo
o`05o`000?nj^[[ooooooiRHV?l@41004Oooool00oo^k^ko410@omgMg@0Gooooo`03o`000?oooooo
oooo00[ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@04ooooo`03o`000?oooooooooo07Oooooo002B
ooooo`03o`000?oooooooooo00Sooooo00?o^[ZjodA4A?ooool01?ooool02OmgMgOoIVIVoooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`03ofIVI_mgMgOooooo01Gooooo00?oEEEEofIVI_l0
00003?ooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo1?l0001fooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.237705 [
[.2619 .29652 -9 -9 ]
[.2619 .29652 9 0 ]
[.5 .29652 -3 -9 ]
[.5 .29652 3 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .07131 -12 -4.5 ]
[.01131 .07131 0 4.5 ]
[.01131 .19016 -24 -4.5 ]
[.01131 .19016 0 4.5 ]
[.01131 .42787 -18 -4.5 ]
[.01131 .42787 0 4.5 ]
[.01131 .54672 -6 -4.5 ]
[.01131 .54672 0 4.5 ]
[.5 .63053 -43.625 0 ]
[.5 .63053 43.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(1.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07131 m
.03006 .07131 L
s
[(-1)] .01131 .07131 1 0 Mshowa
.02381 .19016 m
.03006 .19016 L
s
[(-0.5)] .01131 .19016 1 0 Mshowa
.02381 .42787 m
.03006 .42787 L
s
[(0.5)] .01131 .42787 1 0 Mshowa
.02381 .54672 m
.03006 .54672 L
s
[(1)] .01131 .54672 1 0 Mshowa
.125 Mabswid
.02381 .09508 m
.02756 .09508 L
s
.02381 .11885 m
.02756 .11885 L
s
.02381 .14262 m
.02756 .14262 L
s
.02381 .16639 m
.02756 .16639 L
s
.02381 .21393 m
.02756 .21393 L
s
.02381 .23771 m
.02756 .23771 L
s
.02381 .26148 m
.02756 .26148 L
s
.02381 .28525 m
.02756 .28525 L
s
.02381 .33279 m
.02756 .33279 L
s
.02381 .35656 m
.02756 .35656 L
s
.02381 .38033 m
.02756 .38033 L
s
.02381 .4041 m
.02756 .4041 L
s
.02381 .45164 m
.02756 .45164 L
s
.02381 .47541 m
.02756 .47541 L
s
.02381 .49918 m
.02756 .49918 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .04754 m
.02756 .04754 L
s
.02381 .02377 m
.02756 .02377 L
s
.02381 .57049 m
.02756 .57049 L
s
.02381 .59426 m
.02756 .59426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -104.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(\\220) show
92.250 13.000 moveto
(H) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
110.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
116.250 13.000 moveto
(L) show
128.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
134.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
146.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .36837 L
.10458 .42854 L
.14415 .47688 L
.18221 .51262 L
.20178 .52611 L
.21267 .53206 L
.22272 .53653 L
.23293 .54006 L
.23832 .5415 L
.24402 .54271 L
.24641 .54311 L
.24897 .54348 L
.25119 .54375 L
.25361 .54399 L
.25507 .5441 L
.25643 .54419 L
.25773 .54425 L
.2584 .54428 L
.25912 .5443 L
.25983 .54432 L
.26048 .54433 L
.26176 .54434 L
.26293 .54433 L
.26416 .54431 L
.26538 .54428 L
.26607 .54425 L
.26671 .54422 L
.26912 .54407 L
.27131 .54388 L
.27364 .54363 L
.27847 .54293 L
.2838 .54187 L
.29326 .53929 L
.30213 .53605 L
.32232 .52577 L
.34082 .51293 L
.38045 .47548 L
.41855 .42874 L
.45912 .37074 L
.49816 .31056 L
.53966 .24641 L
.57964 .1889 L
.61811 .14137 L
.63759 .12121 L
.65902 .1026 L
.67938 .08871 L
.69843 .07927 L
.70884 .07561 L
.71396 .07421 L
Mistroke
.71872 .07315 L
.72301 .07239 L
.72758 .07179 L
.7302 .07154 L
.73148 .07145 L
.73266 .07137 L
.73371 .07132 L
.73487 .07128 L
.73603 .07124 L
.73725 .07123 L
.73856 .07122 L
.73977 .07124 L
.7404 .07125 L
.7411 .07127 L
.74251 .07132 L
.74375 .07139 L
.74508 .07147 L
.74748 .07168 L
.74985 .07193 L
.75235 .07227 L
.7568 .07302 L
.76198 .07416 L
.7668 .07546 L
.77773 .07929 L
.78828 .08411 L
.79823 .08967 L
.81683 .10259 L
.85534 .13899 L
.89632 .18965 L
.93577 .24656 L
.97371 .30514 L
.97619 .30902 L
Mfstroke
1 0 0 r
[ .05 .035 ] 0 setdash
.02381 .30902 m
.06244 .36699 L
.10458 .42815 L
.14415 .47767 L
.18221 .51376 L
.20178 .52707 L
.21274 .53286 L
.22272 .53707 L
.22755 .53875 L
.23267 .54027 L
.2371 .54136 L
.24186 .54231 L
.24453 .54275 L
.24697 .54308 L
.24945 .54335 L
.25175 .54356 L
.25315 .54365 L
.25442 .54372 L
.25583 .54378 L
.25661 .5438 L
.25734 .54382 L
.25798 .54383 L
.25867 .54383 L
.25989 .54383 L
.2612 .54381 L
.26195 .5438 L
.26265 .54377 L
.26391 .54372 L
.26525 .54365 L
.26765 .54347 L
.27024 .54322 L
.2731 .54286 L
.2782 .54203 L
.283 .541 L
.29193 .53851 L
.30156 .53496 L
.3216 .5248 L
.3427 .51023 L
.3808 .47473 L
.42136 .42581 L
.46041 .37054 L
.50191 .30663 L
.54189 .2442 L
.58036 .1876 L
.62127 .13576 L
.64163 .11457 L
.66068 .09807 L
.67894 .08558 L
.68912 .08011 L
.69856 .07603 L
Mistroke
.7087 .07273 L
.71404 .07144 L
.71678 .0709 L
.71974 .07042 L
.72257 .07004 L
.72517 .06977 L
.72766 .06959 L
.72892 .06952 L
.72962 .06949 L
.73029 .06946 L
.73154 .06943 L
.73268 .06942 L
.7339 .06942 L
.73459 .06943 L
.73523 .06944 L
.7363 .06947 L
.73747 .06952 L
.73869 .06958 L
.73984 .06966 L
.74228 .06987 L
.74455 .07013 L
.7497 .07091 L
.75471 .07195 L
.76006 .07336 L
.76977 .07668 L
.77858 .08053 L
.7978 .0916 L
.81862 .10742 L
.85959 .14855 L
.89904 .19783 L
.93698 .25109 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`?o0000oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`003oooool6o`0000Gooooo00?o0000ooooooooool01?ooool3o`000=Gooooo3_oo001Qooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=;ooooo1Ol0000;ooooo`05o`00
0?oo003oo`00ool00?l00000GOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3?ooooo`;oo`0000?o0000ooooooooool04oooool2o`0005_ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0c?ooool3ool000;o00006?ooool3o`0005Sooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool01?oo003oooooo`000?l0
000Mooooo`;o0000E_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`39
ooooo`;oo`000_l0000Qooooo`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo
0<Oooooo0_oo0002o`0002?ooooo0ooo001Cooooo`008Oooool00ol0003oooooooooo`35ooooo`;o
o`0000?oooooo`000?ooool09oooool00ooo003oooooooooo`1@ooooo`008Oooool3o`000<Cooooo
00Coo`00ooooool0003o0000:_ooool2ool0053ooooo000Qooooo`03o`000?oooooooooo0<Cooooo
00?oo`00o`000?ooool0;Oooool00ooo003oooooooooo`1=ooooo`008Oooool00ol0003ooooooooo
o`33ooooo`03ool00?l0003ooooo02oooooo00?oo`00o`000?ooool0C?ooool0027ooooo00?o0000
ooooooooool0`_ooool00ol0003oooooooooo`0aooooo`03ool00?l0003ooooo04_ooooo000Qoooo
o`03o`000?oooooooooo0<7ooooo00?o0000ooooooooool0<_ooool00ooo003oooooo`00001;oooo
o`008Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo03Cooooo00?oo`00ooooool0
0000B_ooool0027ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooo000004Wooooo000Qooooo`?o0000__ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooo000004Sooooo000Qooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool0>_ooool0
0ooo003oooooo`000017ooooo`008Oooool00ol0003oooooooooo`2kooooo`03ool00?l0003ooooo
03oooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0^_ooool00ooo003o
0000ooooo`11ooooo`03o`000?oooooooooo04?ooooo000Qooooo`03o`000?oooooooooo0;Wooooo
00?oo`00o`000?ooool0@oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`2hooooo`03ool00?l0003ooooo04Gooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000
ooooooooool0^?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo000Qoooo
o`?o0000]oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo0;Kooooo00?oo`00o`000?ooool0BOooool00ol0003oooooooooo`0oooooo`00
8Oooool00ol0003oooooooooo`2eooooo`03ool00?l0003ooooo04[ooooo00?oo`00o`000?ooool0
?oooool0027ooooo00?o0000ooooooooool0]?ooool00ooo003o0000ooooo`1;ooooo`03ool00?oo
oooo000003oooooo000Qooooo`03o`000?oooooooooo0;Cooooo00?oo`00ooooooooool0C?ooool0
0ooo003oooooo`00000nooooo`008Oooool00ol0003oooooooooo`2cooooo`03ool00?oooooooooo
04kooooo00?oo`00o`000?ooool0?Oooool0027ooooo00?o0000ooooooooool0/_ooool00ooo003o
0000ooooo`1@ooooo`03ool00?l0003ooooo03cooooo000Qooooo`03o`000?oooooooooo0;7ooooo
00?oo`00o`000?ooool0D_ooool00ooo003o0000ooooo`0kooooo`008Oooool3o`000;7ooooo00?o
0000ooooooooool0Doooool00ooo003o0000ooooo`0jooooo`008Oooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooool00000>_ooool0027ooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo000003Wooooo000Qooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool0Eoooool00ooo003o0000ooooo`0hooooo`00
8Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo05Wooooo00?oo`00o`000?ooool0
=oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`1Kooooo`03
ool00?l0003ooooo03Kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo05go
oooo00?oo`00o`000?ooool0=Oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00_ooool3o`000:_ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0cooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`2Zooooo`03ool00?l0003ooooo067ooooo00?o0000oooooooo
ool0<oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01?ooool00ol0003oooooooooo`2Zooooo`03ool00?oooooooooo06;ooooo00?o0000oooo
ooooool0<_ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo
037ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0:Sooooo00?oo`00ooooooooool0IOooool00ol0003oooooooooo`0aoooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
0:Sooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003o
ooooooooo`2Wooooo`03ool00?oooooooooo06Sooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool0Y_ooool00ooo003oooooooooo`1Yooooo`03o`000?oooooooooo02oooooo
000Qooooo`?o0000YOooool00ooo003o0000ooooo`1Zooooo`03ool00?l0003ooooo02oooooo000Q
ooooo`03o`000?oooooooooo0:Gooooo00?oo`00ooooooooool0J_ooool00ooo003oooooo`00000_
ooooo`008Oooool00ol0003oooooooooo`2Tooooo`03ool00?oooooooooo06cooooo00?oo`00o`00
0?ooool0;_ooool0027ooooo00?o0000ooooooooool0Xoooool00ooo003oooooooooo`1^ooooo`03
ool00?l0003ooooo02gooooo000Qooooo`03o`000?oooooooooo0:?ooooo00?oo`00ooooooooool0
Koooool00ooo003o0000ooooo`0/ooooo`008Oooool00ol0003oooooooooo`2Rooooo`03ool00?oo
oooooooo077ooooo00?oo`00ooooooooool0:oooool0027ooooo00?o0000ooooooooool0XOooool0
0ooo003oooooooooo`1cooooo`03ool00?oooooooooo02[ooooo000Qooooo`?o0000XOooool00ol0
003oooooooooo`1cooooo`03ool00?l0003ooooo02[ooooo000Qooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool0MOooool00ooo003oooooooooo`0Yooooo`008Oooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool0:?ooool0027ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0NOooool00ol0003oo`00ooooo`0W
ooooo`008Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo07_ooooo00?oo`00oooo
ooooool09_ooool0027ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`1looooo`03
ool00?l0003ooooo02Kooooo000Qooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool0
OOooool00ol0003oooooooooo`0Uooooo`008Oooool3o`0009_ooooo00?oo`00ooooooooool0Oooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Co0000
00?o410@ooooooooool01?ooool00ooo003oooooooooo`0dooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0gooooo`03o`000?oooooooooo00?o
oooo1Ol0000Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo03Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool0=_ooool00ol0003oooooooooo`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06oooool0027o
oooo00?o0000ooooooooool0?Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h07?ooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool0?_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`0hooooo`03o`000?oooooooooo
00?ooooo00?oV9RHob4Q8Oo^k^h06oooool0027ooooo00?o0000ooooooooool0?Oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00oooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`0>Oooool00ol0003oooooooooo`04ooooo`03ogMgMomVIVKooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0iooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Wooooo000Qooooo`?o0000?Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0mooooo`07ool00?oooooo0000okZj^_oooooo
V9RHoa0@400Kooooo`008Oooool00ol0003oooooooooo`0mooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0003kooooo00?oEEEEofIVI_l000000oooool00ooo003oooooooooo`0iooooo`03
oeEEEOmVIVKo000000gooooo1?l0000looooo`07ool00?ooooooV9RHoa0@4?l0003o8B4Qolc<c00K
ooooo`008Oooool00ol0003oooooooooo`2Fooooo`03ool00?oooooooooo08[ooooo00?oo`00oooo
ooooool07_ooool0027ooooo00?o0000ooooooooool0UOooool00ooo003oooooooooo`2<ooooo`03
ool00?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo09Gooooo00?oo`00ooooooooool0
S?ooool00ol0003oo`00ooooo`0Mooooo`008Oooool00ol0003oooooooooo`2Dooooo`03ool00?oo
oooooooo08kooooo00?oo`00ooooooooool04_ooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`2Cooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool04Oooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000<_l000000ooo003o0000o`00
0005o`0000cooooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Cok^k^ob4Q8Ol@413ok^k^
1Oooool0027ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Ooo
ool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooo`00002Aooooo`03o`000?oo
oooooooo0:Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooool00000T?ooool0
0ol0003oooooooooo`2aooooo`008Oooool01?l0003ooooooooooooo002?ooooo`03o`000?oooooo
oooo0;7ooooo000Qooooo`04o`000?ooooooooooool008kooooo00?o0000ooooooooool0/_ooool0
027ooooo00Go0000ooooooooooooooooool0002<ooooo`03o`000?oooooooooo0;?ooooo000Qoooo
o`?o00000_ooool00ooo003oooooooooo`28ooooo`03ool00?l0003ooooo0;Cooooo000Qooooo`03
o`000?oooooooooo00;ooooo00?oo`00ooooooooool0R?ooool00ooo003oooooooooo`2dooooo`00
8Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo08Kooooo00?oo`00ooooooooool0
]Oooool0027ooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`24ooooo`03o`000?oo
003ooooo0;Kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?ooool0Q?ooool0
0ooo003oooooooooo`2fooooo`008Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
08;ooooo00?oo`00ooooooooool0]oooool0027ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`20ooooo`03o`000?oo003ooooo0;Sooooo000Qooooo`?o00001_ooool00ol0003oo`00
ooooo`20ooooo`03ool00?oooooooooo0;Sooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0O_ooool00ol0003oo`00ooooo`2iooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oo003ooooo07gooooo00?o0000ool00?ooool0^_ooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oo`00ooooo`1looooo`03ool00?oooooooooo0;[ooooo000Qooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0N_ooool00ol0003oo`00ooooo`2kooooo`00
8Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07Wooooo00?o0000ool00?ooool0
_?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1hooooo`03ool00?oo
oooooooo0;cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`2mooooo`008Oooool3o`0000cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`2nooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0__ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo0;oooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`30ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo06oooooo00?o0000ooooooooool0`?ooool0027ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo0<7ooooo000Qooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0K?ooool00ol0003oooooooooo`32ooooo`00
8Oooool3o`00017ooooo00?oo`00ooooooooool0J_ooool00ooo003o0000ooooo`33ooooo`008Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oo003ooooo06[ooooo00?oo`00ooooooooool0`ooo
ool0027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Xooooo`03ool00?oooooo
oooo0<Cooooo000Qooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0Ioooool00ooo
003oooooooooo`34ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo06Go
oooo00?oo`00ooooooooool0aOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`1Tooooo`03ool00?oooooooooo0<Kooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo06?ooooo00?oo`00ooooooooool0a_ooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`03ool00?oooooooooo
067ooooo00?oo`00ooooooooool0aoooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1Ooooo
o`03o`000?oo003ooooo0<Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`1O
ooooo`03ool00?oooooooooo0<Sooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0GOooool0
0ooo003oooooooooo`39ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?oo`00
ooooooooool0b_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool0boooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo
0<cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`3=ooooo`008Oooool3o`0001cooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`3>ooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0c_ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo0<oooooo000Qooooo`03o`000?oooooooooo01oooooo00?oo`00oooo
ooooool0Coooool00ol0003oooooooooo`3@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
ool00?oooooooooo04kooooo00?o0000ooooooooool0dOooool0027ooooo00?o0000ooooooooool0
8?ooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo0=;ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0B_ooool00ooo003oooooooooo`3Cooooo`008Oooool3
o`0002;ooooo00?oo`00ooooooooool0Aoooool2ool00=Kooooo000Qooooo`03o`000?oooooooooo
02?ooooo00?oo`00o`000?ooool0AOooool00ooo003oooooooooo`3Fooooo`008Oooool00ol0003o
ooooooooo`0Tooooo`03ool00?l0003ooooo04?ooooo00?oo`00ooooooooool0eoooool0027ooooo
00?o0000ooooooooool09Oooool00ooo003o0000ooooo`11ooooo`03ool00?oooooooooo0=Sooooo
000Qooooo`03o`000?oooooooooo02Kooooo00?oo`00o`000?ooool0?oooool00ooo003ooooooooo
o`3Iooooo`008Oooool00ol0003oooooooooo`0Wooooo`03ool00?l0003ooooo03gooooo00?oo`00
ooooooooool0f_ooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003o0000ooooo`0koooo
o`03ool00?oooooooooo0=_ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?oo`00o`000?oo
ool0>Oooool00ooo003oooooooooo`3Looooo`008Oooool3o`0002[ooooo00?oo`00o`000?ooool0
=oooool00ooo003oooooooooo`3Mooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo03Cooooo00?oo`00ooooooooool0g_ooool0027ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0booooo`03ool00?oooooooooo0=oooooo000Qooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3Pooooo`008Oooool00ol0003o
ooooooooo`0_ooooo`;o0000;_ooool2o`000>?ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3Sooooo`008Oooool00ol0003ooooooooo
o`0booooo`;o0000:Oooool00ol0003oooooooooo`3Tooooo`008Oooool3o`0003;ooooo0ooo000W
ooooo`03o`000?oooooooooo0>Gooooo000Qooooo`03o`000?oooooooooo03Gooooo0_oo000Roooo
o`;oo`0000?o0000ooooooooool0i_ooool0027ooooo00?o0000ooooooooool0=oooool00ooo003o
ooooooooo`0Mooooo`;oo`0000?o0000ooooooooool0j?ooool0027ooooo00?o0000ooooooooool0
>?ooool2ool00003o`000?oooooooooo01Sooooo0_oo003]ooooo`008Oooool00ol0003ooooooooo
o`0jooooo`;oo`000ol0000Dooooo`;oo`00koooool001Sooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo03cooooo0ooo00000ol0003oooooooooo`0>ooooo`?oo`00lOooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`;oo`000ol00007oooo
o`Goo`0000?o0000ooooooooool0lOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`14ooooo`So0000n?ooool001[ooooo00?o0000ooooooooool01?ooool3o`000?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l0
00001_ooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool3o`000?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool00omg
MgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo09oooooo002;ooooo`?o00004oooool00olQ8B7o
gMgMooooo`07ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd0Woooool008;ooooo
00OoQhN7o`000?mEEEGoIVIVo`000?lb<S;ok^k^00?ooooo00?o0000ooooooooool02oooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00?oV9RHoeEEEOooool01oooool01?mEEEGoV9RHoooooooo
ool5o`0000Wooooo00?oEEEEojVYZOooool00_ooool00onj^[[oA4A4ooooo`02ooooo`03ohN7QomV
IVKooooo01;ooooo1Ol00005ooooo`;o8B4QP?ooool008;ooooo00Oo410@omgMgOmgMgOo8B4Qoooo
oon7QhOoIVIV00?ooooo00?o0000ooooooooool02oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?o
oooo00?o0000omgMgOooool01_ooool02Ol0003oooooooooooooooooV9RHob4Q8Oo^k^koooooodA4
A00:ooooo`06oeEEEOnHV9Soooooooooool@413o^[Zj0oooool00oo^k^ko0000ooooo`0;ooooo`Ko
000000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4QP?ooool008;ooooo00Oo0000oooo
oooMgMgo<S8booooooo^k^ko410@00?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`;oMgMg1oooool00olb<S;oooooooooo`02ooooo`03oiRHV?lQ8B7ok^k^00cooooo00Co
410@omgMgOoooooo00001Oooool00ol0003oooooooooo`0Booooo`03oiRHV?lQ8B7ok^k^08Sooooo
0022ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?oooooooooo00Gooooo00?ok^k^oa0@4?o^k^h01_ooool00olb<S;oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^00_ooooo00CoQhN7ofIVI_oooooo00001Oooool00ol0003oooooooooo`0:oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP27ooooo`00P_ooool00ooMgMgo8B4Qonk^kP03ooooo`03
o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`06ooooo`03oeEEEOnHV9Sooooo00Go
oooo00?o0000onk^k_ooool01?ooool00omgMgOoIVIVooooo`0:ooooo`04omgMgOl@413oooooo`00
00Cooooo00?ok^k^o`000?ooool05Oooool00omgMgOoIVIVooooo`26ooooo`00Poooool00onHV9So
MgMgooooo`02ooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol00005ooooo`03
omgMgOl@413ooooo00Gooooo00?oEEEEogMgMoooool01Oooool00ol0003oooooooooo`08ooooo`Oo
00000_ooool00omgMgOoEEEEooooo`0Fooooo`03o`000?oooooooooo08Gooooo002Jooooo`03o`00
0?oooooooooo00Oooooo00?oEEEEoiRHV?ooool01?ooool02OoMgMgo410@onk^k_oooooo0000okZj
^_ooooooV9RHoa0@400Booooo`03onk^k_l@413ogMgM01?ooooo00Go0000okZj^_ooooooV9RHoa0@
4027ooooo`00V_ooool00ol0003oooooooooo`07ooooo`03okZj^_m4A4Cooooo00Gooooo00SoMgMg
ofIVI_ooooooV9RHoa0@4?l0003o8B4Qolc<c1;ooooo00?oIVIVogMgMoooool04oooool01OnHV9So
410@o`000?lQ8B7oc<c<08Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.228039, -1.36407, \
0.00840747, 0.0168425}}]
}, Closed]],

Cell[TextData[{
  "Fig. 6.13 (animation). WKB-shooting (solid) and Galerkin (dashed) \
solutions for the oscillations of an inhomogeneous string, with the same \
parameters as in Fig. ",
  ButtonBox["6.12",
    ButtonData:>"Fig. 6.12",
    ButtonStyle->"Hyperlink"],
  "."
}], "Caption",
  CellTags->"Fig. 6.13"],

Cell[TextData[{
  "The accuracy of the numerical eigenmode method has been considerably \
improved by using the shooting method for the low",
  "-order",
  " eigenmodes. (In fact, the small remaining difference between the \
solutions is now due to errors in the ",
  StyleBox["Galerkin",
    FontSlant->"Italic"],
  " solution rather than the WKB/shooting solution.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenvalues in the Presence of Turning Points", "Section",
  CellTags->{"i:44", "c:41"}],

Cell[TextData[{
  "\tWe observed in Sec. ",
  ButtonBox["5.2.2",
    ButtonData:>{"Chapter5.nb", "c:30"},
    ButtonStyle->"Hyperlink"],
  " that the WKB method breaks down at turning points, where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x) \[Rule] \ 0\)]],
  ".   When there are turning points, construction of WKB eigenmodes is more \
difficult.  However, it is still possible to obtain simple approximate \
results for  the eigenvalues using the technique of ",
  StyleBox["asymptotic matching",
    FontSlant->"Italic"],
  " .  The approximate eigenvalues can then be used as an initial guess in \
the shooting method to obtain accurate eigenfunctions and eigenvalues."
}], "Text"],

Cell["\<\
\tTo analyze the turning-point problem, we consider an eigenvalue \
problem of the type encountered when dealing with the 1D \
Schr\[ODoubleDot]dinger equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\([\(-c\) \[PartialD]\^2\/\[PartialD]x\^2 + 
              V(x)]\) \(\(\[Psi]\_n\)(x)\) = \(E\_n\) \(\(\[Psi]\_n\)(
            x)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.21)"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      \(TraditionalForm\`c = \[HBar]\^2/2  m\)]],
  " is a positive constant,  ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is a potential function, and the energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_n\)\(\ \)\)\)]],
  "are  the eigenvalues. We assume that ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " has a single minimum in which classical particles can be trapped, and \
that ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  " is finite  and smooth for finite ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe will determine the energy levels for this potential in the WKB \
approximation. In this kind of potential, the boundary conditions to be \
applied to Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " are that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \[Rule] \ 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \(\[PlusMinus]\[Infinity]\)\)]],
  ".\n\tThe general WKB solution to this ODE is given by Eq. ",
  ButtonBox["(5.2.15)",
    ButtonData:>{"Chapter5.nb", "(5.2.15)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = \ 
        A\/\@\(k(x)\)\ \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \
\(\[Integral]\^x\(\( k\_n\)(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\) + \ 
          B\/\@\(k(x)\)\ \[ExponentialE]\^\(\(\ \)\(\(-\ \[ImaginaryI]\)\ \(\
\[Integral]\^x\(\( k\_n\)(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.22)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(x) = \(c\^\(-1\)\)(E\_n - V(x))\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNow, for some range of values of ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  ", there will be two turning points,  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_R\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_L\)]],
  ",  defined by the solution  of the equation ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = V(x)\)]],
  ". Equation ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  " is valid far from the turning points, but breaks down as ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x) \[Rule] 0\)]],
  ". However, near such a  turning point we already observed in Sec. 5.2.2 \
that we can Taylor-expand ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x)\)]],
  ", allowing us to solve Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " via Airy functions. Let us consider the right turning point,  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_\(\(\ \)\(R\)\)\)]],
  ". Near this turning point,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(
          x) = \(-\(\(\[Alpha]\_\(\(\ \)\(R\)\)\)(
              x - x\_\(\(\ \)\(R\)\))\)\)\  + \ O(\((x - x\_R)\)\^2)\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_\(\(\ \)\(R\)\) = \(c\^\(-1\)\) \
\[PartialD]V/\[PartialD]x\_\(\(\ \)\(R\)\)\)]],
  " >0 (since ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(\(\ \)\(R\)\)\)]],
  " is the right turning point). Equation ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  " then becomes the Airy equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\([\(-\(\[PartialD]\^2\/\[PartialD]x\^2\)\) + \(\
\[Alpha]\_\(\(\ \)\(R\)\)\)(x - x\_\(\(\ \)\(R\)\))]\) \(\(\[Psi]\_n\)(x)\) = 
        0\)]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "with a general solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\  = \ 
        C\_\(1\ R\)\ \(Ai(\[Alpha]\_\(\(\ \)\(R\)\)\^\(1/3\)\ \((x - 
                    x\_R)\))\)\  + \ \(\(C\_\(2\ R\)\)\(\ \)\(Bi(\[Alpha]\_\(\
\(\ \)\(R\)\)\^\(1/3\)\ \((x - x\_\(\(\ \)\(R\)\))\))\)\(\ \)\)\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`Bi\)]],
  " blows up for large positive argument, we must set ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = 0\)]],
  " to keep ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " finite for ",
  Cell[BoxData[
      \(TraditionalForm\`x > x\_\(\(\ \)\(R\)\)\)]],
  ". Thus, the wave function must have the form"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\(C\_\(1\ R\)\)\(\ \)\(Ai(\[Alpha]\_\(\(\ \
\)\(R\)\)\^\(1/3\)\ \((x - x\_\(\(\ \)\(R\)\))\))\)\(\ \)\)\)]]
}], "NE3",
  CellTags->"(6.3.23)"],

Cell[TextData[{
  "near the right turning point. This is the same result as was obtained in \
Sec. 5.2.2 for traveling waves reflecting from a potential. Here however, \
there is also a left turning point, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L\)]],
  ",  near which analogous results apply:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\%2\)(x) = \(\[Alpha]\_L\)(x - x\_L)\  + \ 
          O[\((x - x\_\(\(\ \)\(L\)\))\)\^2]\)]],
  ","
}], "NE3",
  CellTags->"(6.3.24)"],

Cell[TextData[{
  " with ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\[Alpha]\_\(\(\ \)\(L\)\) = \(-c\^\(-1\)\)\
\ \ \[PartialD]V/\[PartialD]x\_R > 0\)]]]], TraditionalForm]]],
  ", and "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\(C\_\(1\ L\)\)\(\ \)\(Ai(\(-\[Alpha]\_L\^\(1/3\)\)\ \
\((x - x\_L)\))\)\(\ \)\)\)]],
  ","
}], "NE3",
  CellTags->"(6.3.25)"],

Cell[TextData[{
  "The wave function near these two turning points is shown schematically in \
Fig. ",
  ButtonBox["6.14",
    ButtonData:>"Fig. 6.14",
    ButtonStyle->"Hyperlink"],
  ". We need to connect these two solutions, and we will do so using the WKB \
wave function, Eq. ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0.273056 0.411038 [
[.18254 .26056 -7.625 -12 ]
[.18254 .26056 7.625 0 ]
[.81746 .26056 -7.625 -12 ]
[.81746 .26056 7.625 0 ]
[1.025 .27306 0 -6 ]
[1.025 .27306 10 6 ]
[.5 .64303 -7.625 0 ]
[.5 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .27306 m
.18254 .27931 L
s
gsave
.18254 .26056 -68.625 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.81746 .27306 m
.81746 .27931 L
s
gsave
.81746 .26056 -68.625 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .27306 m
1 .27306 L
s
gsave
1.025 .27306 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.6746 .1584 m
.68056 .25113 L
.68359 .3075 L
.68684 .36183 L
.68856 .38509 L
.69013 .40162 L
.69089 .40781 L
.69171 .41316 L
.69209 .41511 L
.69249 .41684 L
.69286 .41812 L
.69321 .41904 L
.69341 .41946 L
.69364 .41981 L
.69403 .42014 L
.69425 .42017 L
.69449 .42007 L
.69472 .41987 L
.69492 .41959 L
.69532 .41877 L
.69554 .41815 L
.69575 .41749 L
.69652 .41413 L
.69737 .40902 L
.6983 .40172 L
.70018 .38207 L
.70341 .33586 L
.70636 .28545 L
.7098 .22511 L
.71298 .17578 L
.71449 .15648 L
.71591 .14147 L
.71739 .12939 L
.71818 .12456 L
.71862 .12235 L
.71903 .12062 L
.71944 .11918 L
.71982 .11815 L
.72003 .11771 L
.72024 .11733 L
.72048 .11702 L
.7207 .11682 L
.72091 .11672 L
.72114 .1167 L
.72138 .11679 L
.72161 .11698 L
.72202 .11755 L
.72225 .118 L
.72245 .1185 L
.72323 .12105 L
Mistroke
.72366 .12296 L
.72407 .12503 L
.7256 .13538 L
.72721 .15028 L
.72895 .1704 L
.73211 .21503 L
.73801 .31069 L
.74128 .36043 L
.74433 .39896 L
.746 .41565 L
.74752 .42778 L
.74833 .43298 L
.7492 .43761 L
.74968 .43969 L
.75013 .44133 L
.75056 .44263 L
.75101 .44372 L
.75137 .4444 L
.75178 .44492 L
.75214 .4452 L
.75248 .44529 L
.75288 .44519 L
.75325 .4449 L
.75345 .44466 L
.75367 .44434 L
.75406 .44359 L
.75479 .44168 L
.75556 .4389 L
.75693 .43205 L
.75854 .42116 L
.76004 .40843 L
.76346 .37178 L
.77577 .20173 L
.78204 .12709 L
.78558 .09548 L
.78727 .08348 L
.78886 .07406 L
.79037 .06676 L
.79176 .06147 L
.7933 .05713 L
.79411 .05547 L
.79456 .05474 L
.79497 .05418 L
.79534 .05376 L
.79574 .0534 L
.79597 .05324 L
.79617 .05312 L
.79657 .05296 L
.79692 .05289 L
.7973 .05289 L
Mistroke
.7977 .05299 L
.79807 .05315 L
.79828 .05327 L
.79851 .05343 L
.79892 .0538 L
.79971 .05472 L
.80062 .05617 L
.80146 .05785 L
.80307 .06189 L
.80481 .06736 L
.80797 .07967 L
.81386 .10813 L
.82685 .17499 L
.83332 .20272 L
.83936 .22342 L
.84517 .23869 L
.85139 .25062 L
.85462 .2553 L
.85812 .25941 L
.86115 .26227 L
.8645 .26481 L
.86751 .26662 L
.87076 .26817 L
.8742 .26943 L
.87742 .27034 L
.88045 .271 L
.88377 .27155 L
.88723 .27197 L
.89045 .27226 L
.89379 .27249 L
.89694 .27264 L
.89976 .27275 L
.90282 .27283 L
.90582 .27289 L
.90912 .27294 L
.91078 .27296 L
.91257 .27298 L
.91579 .273 L
.919 .27302 L
.92081 .27303 L
.9225 .27303 L
.92558 .27304 L
.9273 .27304 L
.92886 .27304 L
.93041 .27305 L
.93205 .27305 L
.93498 .27305 L
.93661 .27305 L
.93812 .27305 L
.93978 .27305 L
Mistroke
.94157 .27305 L
.9433 .27305 L
.9449 .27305 L
.94639 .27306 L
.94804 .27306 L
.95089 .27306 L
.95245 .27306 L
.95392 .27306 L
.95549 .27306 L
.9572 .27306 L
.95872 .27306 L
.96033 .27306 L
.96192 .27306 L
.96337 .27306 L
.96474 .27306 L
.96619 .27306 L
.96869 .27306 L
.97099 .27306 L
.97347 .27306 L
.97488 .27306 L
.97619 .27306 L
Mfstroke
.02381 .27306 m
.02725 .27306 L
.03102 .27306 L
.03292 .27306 L
.03495 .27307 L
.03862 .27307 L
.0407 .27307 L
.04297 .27308 L
.04496 .27308 L
.04708 .27308 L
.05108 .2731 L
.05477 .27311 L
.05838 .27314 L
.06226 .27317 L
.06592 .27321 L
.06927 .27326 L
.07305 .27334 L
.07655 .27344 L
.0804 .27358 L
.0845 .27379 L
.08844 .27406 L
.0927 .27446 L
.09673 .27497 L
.10044 .27558 L
.10417 .27638 L
.10765 .27733 L
.11148 .27865 L
.11557 .28048 L
.11947 .2827 L
.12372 .28579 L
.12738 .28912 L
.13143 .29367 L
.13901 .30525 L
.14316 .31365 L
.14706 .3231 L
.1548 .34698 L
.16189 .37555 L
.17708 .45772 L
.19169 .54792 L
.19556 .56844 L
.19921 .58452 L
.20123 .59163 L
.20229 .59478 L
.20341 .59762 L
.20436 .5996 L
.2054 .60131 L
.20586 .6019 L
.20635 .60243 L
.20681 .60281 L
.20724 .60307 L
Mistroke
.20773 .60326 L
.2082 .60332 L
.20862 .60327 L
.20907 .60312 L
.20957 .60282 L
.20981 .60262 L
.21009 .60236 L
.21102 .60115 L
.2119 .59955 L
.21284 .59732 L
.21453 .59194 L
.21667 .58251 L
.21869 .57082 L
.22248 .54152 L
.22619 .50354 L
.23013 .45386 L
.23719 .34538 L
.24476 .21675 L
.25168 .10952 L
.25531 .06544 L
.25715 .04758 L
.25911 .03246 L
.26015 .02625 L
.2611 .02173 L
.26155 .01993 L
.26204 .01829 L
.26251 .01702 L
.26294 .01608 L
.26344 .01529 L
.26371 .01501 L
.26399 .01481 L
.26429 .01472 L
.26458 .01473 L
.26483 .01484 L
.26511 .01506 L
.26562 .01572 L
.26587 .01618 L
.26615 .01679 L
.26711 .01968 L
.26801 .02349 L
.269 .02889 L
.27098 .04365 L
.27281 .06175 L
.27452 .08222 L
.28251 .21409 L
.28969 .35296 L
.29346 .41807 L
.29553 .44805 L
.29747 .47136 L
.29949 .49002 L
Mistroke
.30056 .49732 L
.30112 .50034 L
.30172 .50305 L
.30226 .50496 L
.30277 .50628 L
.30325 .50711 L
.30352 .5074 L
.30377 .50755 L
.30423 .50755 L
.30473 .50711 L
.30521 .50628 L
.30564 .50517 L
.30609 .50367 L
.30657 .50167 L
.30743 .49704 L
.30846 .48983 L
.3094 .48168 L
.31143 .45905 L
.31336 .43189 L
.32035 .30025 L
.32433 .21669 L
.32806 .14523 L
.32984 .11631 L
.33172 .09081 L
.3327 .07978 L
.33377 .06972 L
.33474 .06248 L
.33565 .05746 L
.33615 .0554 L
.33642 .05452 L
.3367 .05376 L
.33695 .05323 L
.33722 .0528 L
.33769 .05241 L
.33815 .05249 L
.33865 .0531 L
.33912 .05415 L
.33955 .05552 L
.34008 .05776 L
.34057 .06037 L
.34168 .06815 L
.34266 .0771 L
.3437 .0887 L
.34766 .14976 L
.35193 .23735 L
.35563 .31913 L
.35967 .40054 L
.36159 .43194 L
.36264 .44652 L
.36364 .4583 L
Mistroke
.36457 .46741 L
.36557 .47514 L
.36602 .47781 L
.36649 .48014 L
.36689 .4817 L
.36734 .48298 L
.36759 .4835 L
.36787 .48389 L
.36814 .48407 L
.36839 .48409 L
.36885 .48373 L
.36935 .48275 L
.36963 .48193 L
.36993 .48083 L
.37048 .47826 L
.37151 .47151 L
.3725 .46267 L
.37354 .45094 L
.37542 .42423 L
.37878 .36123 L
.38238 .28054 L
.38889 .14107 L
Mfstroke
gsave
.56349 .10864 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
(...) show
81.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oZOooool0
0ol0003oooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003o
ooooooooo`2looooo`00ZOooool00ol0003oooooooooo`2looooo`00ZOooool00ol0003ooooooooo
o`2looooo`00GOooool2o`0004[ooooo00?o0000ooooooooool0_?ooool005cooooo0ol0001:oooo
o`03o`000?oooooooooo0;cooooo001Looooo`03o`000?oooooo000004[ooooo00?o0000oooooooo
ool0_?ooool005cooooo00?o0000ooooool00000B_ooool00ol0003oooooooooo`2looooo`00G?oo
ool01?l0003oooooooooool00019ooooo`03o`000?oooooooooo0;cooooo001Looooo`04o`000?oo
ooooooooo`0004Wooooo00?o0000ooooooooool0_?ooool005_ooooo00Go0000oooooooooooooooo
o`000019ooooo`03o`000?oooooooooo0;cooooo001Kooooo`05o`000?ooooooooooooooool00000
BOooool00ol0003oooooooooo`2looooo`00Foooool01Ol0003ooooooooooooooooo000004Wooooo
00?o0000ooooooooool0_?ooool005_ooooo00Go0000ooooooooooooooooo`000019ooooo`03o`00
0?oooooooooo0;cooooo001Kooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooo
ooooo`2looooo`00Foooool01Ol0003ooooooooooooooooo000004Wooooo00?o0000ooooooooool0
_?ooool005_ooooo00Go0000ooooooooooooooooo`00000Dooooo`;o0000<oooool00ol0003ooooo
ooooo`1Kooooo`?o0000G_ooool005_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Aooooo`;o0000<oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo000005kooooo001J
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool2o`0003?ooooo00?o0000
ooooooooool0Foooool00ol0003oooooo`00001Nooooo`00F_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool00000<_ooool00ol0003oooooooooo`1Joooo
o`05o`000?ooooooooooooooool00000GOooool005[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooo000003;ooooo00?o0000ooooooooool0F_ooool01Ol0
003ooooooooooooooooo000005gooooo001Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Jooooo`00F_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo013ooooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0F_ooool005[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo001Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000b
ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1I
ooooo`00F_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00Co0000oooo
oooooooo0000<_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0FOooool005[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05Wooooo001Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo001Iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo001Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo
0000037ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05Wooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool02Oooool2
ob4Q8@Kooooo0_lQ8B46ooooo`;o8B4Q?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05Sooooo001Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo0000037ooooo00?o0000ooooooooool02Oooool2ob4Q8@Kooooo0_lQ8B46
ooooo`;o8B4Q?Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001Ioooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05Sooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0@oooool2o`0001;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Gooooo`00FOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
04?ooooo0_l0000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool005Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo0000017o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`00FOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool000004Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Oooooo001Iooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0@_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0E_ooool005Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`12ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Fooooo`00FOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04;ooooo00Co
0000oooooooooooo00004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Kooooo
001Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`12ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Fooooo`00F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0@_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0EOooool005Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04;ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
EOooool005Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo04;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0EOooool005Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Dooooo`00F?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Cooooo001Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
E?ooool005Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Dooooo`00F?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo001Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0Doooool005Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00F?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05?ooooo
001Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D_ooool005Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Booooo`00F?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo05;ooooo001Gooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0D_ooool005Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Booooo`00Eooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo057ooooo001Gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0DOooool005Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Aooooo`00Eoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo057o
oooo001Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D?ooool005Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1@ooooo`00Eoooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo053ooooo001Gooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Coooool004?ooooo1Ol0000?ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l00002ooooo`04
o`000?ooooooooooo`00057ooooo0014ooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo04oooooo000mooooo`;o
00000_ooool2o`000003ooooool0003ooooo017ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo04oooooo000mooooo`08onk^
k_lQ8B7oQhN7okZj^_l0003ogMgMooooool0000Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00[ok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMgoooooo`000?oooooo00001?ooool00ol0003oooooooooo`1>oooo
o`00?_ooool01?oMgMgo0000oa0@4?o<c<`2ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool01?oMgMgo0000oa0@4?o<c<`2ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool0C_ooool003kooooo00Gok^k^ob4Q8Ol@413ok^k^ooooo`03o`00017ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01oooool01Oo^k^ko8B4Qoa0@4?o^k^kooooo00?o00001Oooool00ol0003ooooooooo
o`1>ooooo`00?_ooool01?lQ8B7oMgMgogMgMolb<S8Dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00Co
8B4QogMgMomgMgOo<S8b2Oooool00ol0003oooooooooo`1>ooooo`00?Oooool2o`0000;ooooo0_l0
000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`;o00002Oooool00ol0003ooooooooo
o`1=ooooo`00E_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo001Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Kooooo0_l0001=ooooo`00E_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04[ooooo001Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
BOooool005Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`18ooooo`00E_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o00003Oooool0
05Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool2o`0003Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd=ooooo`00E_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`Go0000<?ooool01?oMgMgo0000oa0@4?o<
c<`>ooooo`002?ooooooo`0004?o00003?ooool01?o^k^ko8B4Qoa0@4?o^k^h>ooooo`00:Oooool3
o`0001Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo04Cooooo00Co8B4QogMgMomgMgOo<S8b3_ooool002cooooo0ol0000Dooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`13ooooo`;o00000_ooool2
o`0000gooooo000_ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I_ooool0033o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Vooooo`00<Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06Kooooo000booooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0I_ooool003;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1V
ooooo`00<oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Kooooo000dooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool003Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Vooooo`00=Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06Kooooo000fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ioooool0
03Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Wooooo`00=_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06Oooooo000gooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Ioooool003Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Wooooo`00>?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Oooooo000hoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ioooool003Wooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Wooooo`00>Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Oooooo000iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Iooo
ool003Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00>_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo000jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Ioooool003[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Xooooo`00>_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000k
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool003_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Xooooo`00>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0J?ooool003_ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1X
ooooo`00??ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool000003?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Sooooo000looooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03Wooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0J?ooool003cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Xooooo`00??ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo06Sooooo000looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J?ooool0
03gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Xooooo`00?Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0ioooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Wooooo000mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06Wooooo000mooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooool000003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Wo
oooo000mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo06Wooooo000nooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooool000003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Wooooo000n
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Wooooo000nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ool000003oooool01Ol0003ooooooooooooooooo000006_ooooo000nooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooool000003oooool01Ol0003ooooooooooooooooo000006_ooooo000noooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03_ooooo0_l0000?ooooo`05o`000?ooooooooooooooool00000Joooool0
03oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooo
ooooool00000Joooool003oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo
000006_ooooo000oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`00001[
ooooo`00?oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`1<ooooo`04o`000?ooooooooooo`0006cooooo000ooooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo04cooooo00Co0000oooooooooooo0000K?ooool0043ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0C?ooool01?l0003oooooooooool0001/ooooo`00@?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
000006cooooo0010ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`1=ooooo`;o0000KOooool0043ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000Xooooo`03o`000?oooooooooo04gooooo0_l0001]ooooo`00@?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0_?ooool0
047ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooo
oooo0;cooooo0011ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000:?ooool0
0ol0003oooooooooo`2looooo`00@Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`04o`000?oooooooooo
o`0002Sooooo00?o0000ooooooooool0_?ooool0047ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0
000Xooooo`03o`000?oooooooooo0;cooooo0011ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool04oooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo0000
:?ooool00ol0003oooooooooo`2looooo`00@Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01?ooooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0002So
oooo00?o0000ooooooooool0_?ooool004;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000Xoooo
o`03o`000?oooooooooo0;cooooo0012ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`2looooo`00@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?o
oooo00Go0000ooooooooooooooooo`00000Aooooo`;o0000:Oooool00ol0003oooooooooo`2loooo
o`00@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00000Aooooo`;o0000:Oooool00ol0003oooooooooo`2looooo`00@_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Aoooo
o`;o0000:Oooool00ol0003oooooooooo`2looooo`00@_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Dooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0_?ooool004?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`00
03gooooo00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0_?ooool004?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000003gooooo
00?o0000ooooooooool0_?ooool004?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0_?ooool004Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`?o0000?Oooool00ol0003oooooooooo`2l
ooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo0_l0000noooo
o`03o`000?oooooooooo0;cooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`2looooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0_?ooool004Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo0;cooooo0014ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2looooo`00AOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0_?ooool004Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;co
oooo0015ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`2looooo`00AOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0_?ooool004Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo0;cooooo0015ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`2looooo`00A_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0_?ooool004Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo0;cooooo0016ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2looooo`00A_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0_?ooool0
04Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
0;cooooo0016ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`2looooo`00Aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool0_?ooool004Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo0;cooooo0017ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`2looooo`00Aoooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0_?ooool004Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0;cooooo0017ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`2looooo`00B?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0_?oo
ool004Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo0;cooooo0018ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`2looooo`00B?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool0_?ooool004Wooooo00Go0000ooooooooooooooooo`00001Kooooo`03
o`000?oooooooooo0;cooooo0019ooooo`05o`000?ooooooooooooooool00000Foooool00ol0003o
ooooooooo`2looooo`00B_ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo0;co
oooo001:ooooo`?o0000G?ooool00ol0003oooooooooo`2looooo`00Boooool2o`0005cooooo00?o
0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000oooo
ooooool0_?ooool00:Wooooo00?o0000ooooooooool0_?ooool00:Wooooo00?o0000ooooooooool0
_?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:Cooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool0002kooooo`00YOoo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0^Oooool00:?ooooo00Oo
V9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool0^Oooool00:?ooooo
00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`000;cooooo002Sooooo`06oc8b<_o^k^koV9RHoeEE
EOoMgMgo410@_oooool00:?ooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<0;kooooo002S
ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`2nooooo`00Xoooool01?mVIVKoV9RHoooo
oolb<S82okZj^P03o`000?oooooooooo0;cooooo002Vooooo`03ofIVI_n7QhOooooo0;oooooo002V
ooooo`03ojVYZOm4A4Cooooo0;oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-16.6159, -0.664316, \
0.122724, 0.00947847}}],

Cell["\<\
Fig. 6.14  Schematic of the wave function near left and right \
turning points.\
\>", "Caption",
  CellTags->"Fig. 6.14"],

Cell[TextData[{
  "\tWe first match the WKB solution to the Airy solution near the left \
turning point. To do so, we use the following ",
  StyleBox["asymptotic",
    FontSlant->"Italic"],
  " form for the Airy function for large negative argument (see Problem 2 in \
the exercises accompanying Sec. 5.2):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(Ai(\(-y\))\)\ ~\(1\/\(\(\@\[Pi]\) 
                y\^\(1/4\)\)\) \(cos(\(2\/3\) y\^\(3/2\) - \[Pi]/4)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \ \)\(y \[Rule] \ \[Infinity]\)\)\)]]
}], "NE3",
  CellTags->"(6.3.26)"],

Cell[TextData[{
  "This asymptotic form for ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(\(-y\))\)]],
  " is s compared with the exact form of ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(\(-y\))\)]],
  " in Cell ",
  ButtonBox["6.178",
    ButtonData:>"Cell 6.178",
    ButtonStyle->"Hyperlink"],
  ". The match is excellent for ",
  Cell[BoxData[
      \(TraditionalForm\`y\  \[GreaterTilde] 3. \)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[{AiryAi[\(-y\)], \(1\/\(\(\@\[Pi]\) \((y)\)\^\(1/4\)\)\) 
            Cos[\(2\/3\) \((y)\)\^\(3/2\) - \[Pi]/4]}, {y,  .25, 8}, 
        PlotStyle \[Rule] {Red, Blue}, 
        AxesLabel \[Rule] {"\<y\>", "\<Ai(-y)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.178"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.254983 0.571798 [
[.2619 .24248 -3 -9 ]
[.2619 .24248 3 0 ]
[.5 .24248 -3 -9 ]
[.5 .24248 3 0 ]
[.7381 .24248 -3 -9 ]
[.7381 .24248 3 0 ]
[.97619 .24248 -3 -9 ]
[.97619 .24248 3 0 ]
[1.025 .25498 0 -6 ]
[1.025 .25498 10 6 ]
[.01131 .02626 -24 -4.5 ]
[.01131 .02626 0 4.5 ]
[.01131 .14062 -24 -4.5 ]
[.01131 .14062 0 4.5 ]
[.01131 .36934 -18 -4.5 ]
[.01131 .36934 0 4.5 ]
[.01131 .4837 -18 -4.5 ]
[.01131 .4837 0 4.5 ]
[.01131 .59806 -18 -4.5 ]
[.01131 .59806 0 4.5 ]
[.02381 .64303 -20 0 ]
[.02381 .64303 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .25498 m
.2619 .26123 L
s
[(2)] .2619 .24248 0 1 Mshowa
.5 .25498 m
.5 .26123 L
s
[(4)] .5 .24248 0 1 Mshowa
.7381 .25498 m
.7381 .26123 L
s
[(6)] .7381 .24248 0 1 Mshowa
.97619 .25498 m
.97619 .26123 L
s
[(8)] .97619 .24248 0 1 Mshowa
.125 Mabswid
.08333 .25498 m
.08333 .25873 L
s
.14286 .25498 m
.14286 .25873 L
s
.20238 .25498 m
.20238 .25873 L
s
.32143 .25498 m
.32143 .25873 L
s
.38095 .25498 m
.38095 .25873 L
s
.44048 .25498 m
.44048 .25873 L
s
.55952 .25498 m
.55952 .25873 L
s
.61905 .25498 m
.61905 .25873 L
s
.67857 .25498 m
.67857 .25873 L
s
.79762 .25498 m
.79762 .25873 L
s
.85714 .25498 m
.85714 .25873 L
s
.91667 .25498 m
.91667 .25873 L
s
.25 Mabswid
0 .25498 m
1 .25498 L
s
gsave
1.025 .25498 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .02626 m
.03006 .02626 L
s
[(-0.4)] .01131 .02626 1 0 Mshowa
.02381 .14062 m
.03006 .14062 L
s
[(-0.2)] .01131 .14062 1 0 Mshowa
.02381 .36934 m
.03006 .36934 L
s
[(0.2)] .01131 .36934 1 0 Mshowa
.02381 .4837 m
.03006 .4837 L
s
[(0.4)] .01131 .4837 1 0 Mshowa
.02381 .59806 m
.03006 .59806 L
s
[(0.6)] .01131 .59806 1 0 Mshowa
.125 Mabswid
.02381 .05485 m
.02756 .05485 L
s
.02381 .08344 m
.02756 .08344 L
s
.02381 .11203 m
.02756 .11203 L
s
.02381 .16921 m
.02756 .16921 L
s
.02381 .1978 m
.02756 .1978 L
s
.02381 .22639 m
.02756 .22639 L
s
.02381 .28357 m
.02756 .28357 L
s
.02381 .31216 m
.02756 .31216 L
s
.02381 .34075 m
.02756 .34075 L
s
.02381 .39793 m
.02756 .39793 L
s
.02381 .42652 m
.02756 .42652 L
s
.02381 .45511 m
.02756 .45511 L
s
.02381 .51229 m
.02756 .51229 L
s
.02381 .54088 m
.02756 .54088 L
s
.02381 .56947 m
.02756 .56947 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ai) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.05357 .49441 m
.07179 .5151 L
.091 .53422 L
.11048 .54941 L
.11582 .55263 L
.12153 .55557 L
.12688 .55781 L
.13182 .5594 L
.1343 .56003 L
.13662 .5605 L
.13905 .56087 L
.14033 .56102 L
.14105 .56109 L
.14171 .56115 L
.14244 .56119 L
.14309 .56123 L
.14382 .56125 L
.14459 .56127 L
.14527 .56127 L
.146 .56126 L
.14669 .56124 L
.14732 .56122 L
.14851 .56114 L
.14919 .56108 L
.14982 .56102 L
.15108 .56087 L
.15246 .56066 L
.15499 .56017 L
.15738 .55955 L
.16187 .55803 L
.16712 .55563 L
.17197 .55277 L
.18129 .54555 L
.19005 .53663 L
.21001 .5083 L
.22956 .46982 L
.24749 .42577 L
.28587 .30944 L
.32279 .18633 L
.34338 .12301 L
.36208 .07451 L
.37142 .0548 L
.38154 .0375 L
.38618 .03111 L
.3911 .02548 L
.39529 .02163 L
.39991 .01844 L
.40232 .01721 L
.4036 .01669 L
.40496 .01623 L
Mistroke
.40626 .01588 L
.40745 .01565 L
.40863 .01549 L
.40975 .01541 L
.41085 .01539 L
.41201 .01545 L
.41299 .01556 L
.41408 .01574 L
.41524 .01601 L
.41649 .01638 L
.41875 .01727 L
.42136 .01865 L
.42419 .02058 L
.42934 .02523 L
.43435 .03116 L
.43899 .03786 L
.4571 .07475 L
.46741 .10268 L
.47708 .13274 L
.51461 .27092 L
.53368 .34215 L
.54376 .37643 L
.55451 .40879 L
.56496 .43488 L
.57443 .45316 L
.57901 .45993 L
.58396 .46568 L
.58624 .46775 L
.58864 .46953 L
.59069 .47073 L
.59179 .47124 L
.59295 .47169 L
.59421 .47207 L
.59537 .47231 L
.59663 .47246 L
.59734 .4725 L
.59801 .47249 L
.59922 .47241 L
.60032 .47223 L
.60154 .47193 L
.60282 .4715 L
.60504 .47046 L
.60712 .46916 L
.61182 .46503 L
.61695 .45869 L
.62161 .45129 L
.63208 .42926 L
.65064 .37397 L
.67078 .29725 L
.68963 .21937 L
Mistroke
.71039 .13981 L
.71988 .10931 L
.73008 .08257 L
.73502 .07225 L
.73972 .06419 L
.74393 .05846 L
.74633 .05587 L
.74853 .05392 L
.751 .05222 L
.75231 .05155 L
.75368 .05099 L
.75488 .05065 L
.75599 .05044 L
.75722 .05034 L
.75791 .05034 L
.75853 .05038 L
.75969 .05054 L
.76076 .0508 L
.76194 .0512 L
.76319 .05176 L
.76529 .05301 L
.7676 .05484 L
.77265 .06048 L
.77808 .069 L
.78792 .09058 L
.7972 .11754 L
.80735 .15316 L
.8278 .2377 L
.8484 .3262 L
.86711 .39437 L
.87645 .42004 L
.88137 .4307 L
.88658 .43962 L
.89113 .44534 L
.89372 .44769 L
.89496 .44858 L
.89614 .44928 L
.8972 .4498 L
.89836 .45023 L
.89941 .4505 L
.90039 .45065 L
.90155 .45071 L
.9026 .45064 L
.90381 .45043 L
.90495 .45009 L
.90609 .44962 L
.9073 .44897 L
.90948 .44743 L
.91208 .44496 L
.91445 .44213 L
Mistroke
.91959 .43408 L
.92446 .42415 L
.93304 .40151 L
.94237 .37038 L
.97619 .22485 L
Mfstroke
0 0 1 r
.05357 .60332 m
.05807 .59678 L
.06227 .59224 L
.06687 .58855 L
.07179 .58572 L
.07427 .58464 L
.07696 .58368 L
.07933 .58299 L
.08185 .5824 L
.08411 .58197 L
.08661 .58159 L
.08887 .58133 L
.091 .58113 L
.09353 .58095 L
.09622 .58081 L
.09778 .58075 L
.09918 .58071 L
.10193 .58063 L
.10692 .58053 L
.10954 .58046 L
.11232 .58037 L
.11481 .58026 L
.11755 .58011 L
.12003 .57993 L
.12236 .57971 L
.12692 .57916 L
.13182 .57832 L
.13665 .57721 L
.14191 .57564 L
.15146 .57168 L
.16077 .56626 L
.16938 .5597 L
.18746 .54055 L
.19775 .52615 L
.20742 .5102 L
.2449 .42637 L
.28475 .30578 L
.32314 .17885 L
.34248 .12027 L
.36005 .07503 L
.36917 .05567 L
.37905 .03847 L
.38448 .03086 L
.38949 .02508 L
.39428 .02071 L
.39688 .01883 L
.39935 .01736 L
.40163 .01628 L
.40284 .01583 L
.40412 .01543 L
Mistroke
.40531 .01513 L
.40639 .01493 L
.40747 .0148 L
.40849 .01473 L
.40969 .01472 L
.41095 .01479 L
.41203 .01492 L
.41321 .01513 L
.41448 .01545 L
.41585 .01589 L
.41831 .01695 L
.4206 .01823 L
.42308 .01994 L
.42759 .02393 L
.43605 .0344 L
.44518 .04999 L
.45524 .07206 L
.47561 .13046 L
.51461 .27371 L
.53254 .34059 L
.55213 .40403 L
.56155 .42863 L
.57159 .44949 L
.57714 .45836 L
.58219 .46463 L
.58462 .46703 L
.58726 .46916 L
.58975 .47072 L
.59204 .47176 L
.59326 .47216 L
.59441 .47243 L
.59545 .4726 L
.59658 .47269 L
.59781 .47268 L
.59843 .47263 L
.59911 .47255 L
.60032 .47231 L
.60146 .47199 L
.60253 .4716 L
.60366 .4711 L
.60569 .46996 L
.60787 .4684 L
.61025 .46629 L
.61526 .4605 L
.62061 .45233 L
.63026 .43262 L
.64017 .40624 L
.65092 .37155 L
.67043 .29699 L
.68928 .21915 L
Mistroke
.71004 .13966 L
.71953 .10919 L
.72974 .08248 L
.73468 .07217 L
.73937 .06411 L
.74358 .05838 L
.74598 .05579 L
.74818 .05384 L
.75066 .05214 L
.75196 .05146 L
.75333 .05091 L
.75453 .05056 L
.75565 .05035 L
.75687 .05025 L
.75756 .05025 L
.75819 .05028 L
.75935 .05045 L
.76042 .0507 L
.76159 .0511 L
.76284 .05166 L
.76494 .0529 L
.76725 .05473 L
.7723 .06035 L
.77774 .06886 L
.78758 .0904 L
.79686 .11732 L
.807 .15289 L
.82745 .23736 L
.84805 .32585 L
.86676 .3941 L
.87611 .41983 L
.88103 .43054 L
.88623 .43951 L
.89079 .44527 L
.89337 .44765 L
.89462 .44855 L
.89579 .44927 L
.89686 .4498 L
.89802 .45024 L
.89907 .45053 L
.90004 .45069 L
.9012 .45076 L
.90225 .45071 L
.90347 .4505 L
.90461 .45018 L
.90574 .44972 L
.90695 .44909 L
.90914 .44757 L
.91173 .44514 L
.9141 .44234 L
Mistroke
.91924 .43436 L
.92411 .42449 L
.9327 .40194 L
.94202 .37091 L
.97619 .22397 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0Loooool7o`00ol[ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo077ooooo0_l00?l00ooo003oooooooooo`03ooooo`;o003obOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo077ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`36ooooo`001Ol0
0002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0001`ooooo`03o`00
oooooooooooo00Sooooo00?o003oool00?ooool0a_ooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0Koooool00ol00?oo
o`00ooooo`0:ooooo`03o`00oooo003ooooo0<Gooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo06kooooo00?o003oool0
0?ooool03?ooool00ol00?ooo`00ooooo`34ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`1]ooooo`03o`00oooo003ooooo
00kooooo00?o003oooooooooool0`oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0K?ooool00ol00?ooo`00ooooo`0?oooo
o`03o`00oooo003ooooo0<?ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omg
MgOo0000ooooo`05ooooo`03o`000?oooooooooo06cooooo00?o003oool00?ooool04?ooool00ol0
0?ooooooooooo`32ooooo`008Oooool00ol0003oooooooooo`1[ooooo`03o`00oooo003ooooo01;o
oooo00?o003oooooooooool0`Oooool0027ooooo00?o0000ooooooooool0J_ooool00ol00?ooo`00
ooooo`0Cooooo`03o`00oooooooooooo0<7ooooo000Qooooo`03o`000?oooooooooo06[ooooo00?o
003oool00?ooool05?ooool00ol00?ooooooooooo`1Looooo`Ko003oG_ooool0027ooooo0ol0001Y
ooooo`03o`00oooo003ooooo01Gooooo00?o003oooooooooool0Foooool2o`00o`Gooooo00?o003o
ooooooooool0Foooool0027ooooo00?o0000ooooooooool0JOooool00ol00?ooo`00ooooo`0Foooo
o`03o`00oooooooooooo05Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Koooo
o`008Oooool00ol0003oooooooooo`1Xooooo`03o`00oooo003ooooo01Oooooo00?o003oool00?oo
ool0FOooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05[ooooo000Qooooo`03o`00
0?oooooooooo06Sooooo00?o003oool00?ooool06?ooool00ol00?ooooooooooo`1Gooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool0FOooool0027ooooo00?o0000ooooooooool0Iooo
ool00ol00?ooo`00ooooo`0Iooooo`03o`00oooo003ooooo05Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`1Wooooo`03o`00oooo003o
oooo01[ooooo00?o003oooooooooool0E?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo05Sooooo000Qooooo`03o`000?oooooooooo06Kooooo00?o003oool00?ooool06oooool00ol0
0?ooo`00ooooo`1Dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0Eoooool0027o
oooo00?o0000ooooooooool0I_ooool00ol00?ooo`00ooooo`0Kooooo`03o`00oooo003ooooo05Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Gooooo`008Oooool00ol0003ooooo
ooooo`1Uooooo`03o`00oooo003ooooo01gooooo00?o003oool00?ooool0D_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo05Kooooo000Qooooo`?o0000IOooool00ol00?ooo`00oooo
o`0Mooooo`03o`00oooo003ooooo05;ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`1Fooooo`008Oooool00ol0003oooooooooo`1Uooooo`03o`00oooo003ooooo01gooooo00?o003o
ool00?ooool0D_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo05Kooooo000Qoooo
o`03o`000?oooooooooo06Cooooo00?o003oool00?ooool07oooool00ol00?ooo`00ooooo`1@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool0EOooool0027ooooo00?o0000oooooooo
ool0I?ooool00ol00?ooo`00ooooo`0Oooooo`03o`00oooo003ooooo053ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`1Eooooo`008Oooool00ol0003oooooooooo`1Tooooo`03o`00
oooooooooooo01oooooo00?o003oool00?ooool0D?ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo05Cooooo000Qooooo`03o`000?oooooooooo06?ooooo00?o003oool00?ooool08Ooo
ool00ol00?ooo`00ooooo`1>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0E?oo
ool0027ooooo00?o0000ooooooooool0Hoooool00ol00?ooo`00ooooo`0Qooooo`03o`00oooo003o
oooo04kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`1Dooooo`008Oooool00ol0
003oooooooooo`1Sooooo`03o`00oooooooooooo027ooooo00?o003oool00?ooool0C_ooool00ol0
0?ooooooooooo`0Cooooo`03o`00oooooooooooo05?ooooo000Qooooo`03o`000?oooooooooo06;o
oooo00?o003oool00?ooool08oooool00ol00?ooo`00ooooo`1<ooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool0Doooool0027ooooo0ol0001Rooooo`03o`00oooooooooooo02?ooooo
00?o003oool00?ooool0C?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo05?ooooo
000Qooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool08oooool00ol00?ooo`00oooo
o`1<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0D_ooool0027ooooo00?o0000
ooooooooool0HOooool00ol00?ooo`00ooooo`0Uooooo`03o`00oooo003ooooo04[ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`1Booooo`008Oooool00ol0003oooooooooo`1Qoooo
o`03o`00oooooooooooo02Gooooo00?o003oool00?ooool0B_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo05;ooooo000Qooooo`03o`000?oooooooooo067ooooo00?o003ooooooooo
ool09Oooool00ol00?ooo`00ooooo`1:ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool0H?ooool00ol00?ooo`00ooooo`0Wooooo`03o`00
oooo003ooooo04Sooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1Aooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`1Pooooo`03o`00oooooooooooo02Oooooo00?o003oool00?ooool0B?ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo057ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo063o
oooo00?o003oooooooooool09oooool00ol00?ooo`00ooooo`18ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool0DOooool000Go00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`1Oooooo`03o`00oooo003ooooo02So
oooo00?o003oool00?ooool0Aoooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo053o
oooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o
0000Goooool00ol00?ooooooooooo`0Yooooo`03o`00oooo003ooooo04Kooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`1@ooooo`001oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo02Wo
oooo00?o003oool00?ooool0A_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo053o
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05kooooo00?o003oool00?ooool0:_ooool00ol00?ooo`00ooooo`16ooooo`03
o`00oooooooooooo01[ooooo00?o003oooooooooool0D?ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`1Noooo
o`03o`00oooooooooooo02_ooooo00?o003oool00?ooool0A?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo04oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0G_ooool00ol00?ooooooooooo`0[
ooooo`03o`00oooo003ooooo04Cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`1?
ooooo`008Oooool00ol0003oooooooooo`1Mooooo`03o`00oooo003ooooo02cooooo00?o003oool0
0?ooool0A?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo04oooooo000Qooooo`03
o`000?oooooooooo05gooooo00?o003oool00?ooool0;Oooool00ol00?ooooooooooo`12ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool0Coooool0027ooooo00?o0000ooooooooool0
GOooool00ol00?ooooooooooo`0]ooooo`03o`00oooo003ooooo04;ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`1Looooo`03o`00oooo
003ooooo02kooooo00?o003oool00?ooool0@_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooo
oooooooo04kooooo000Qooooo`?o0000G?ooool00ol00?ooo`00ooooo`0^ooooo`03o`00oooo003o
oooo04;ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1>ooooo`008Oooool00ol0
003oooooooooo`1Looooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0@?ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo04kooooo000Qooooo`03o`000?oooooooooo05_o
oooo00?o003oool00?ooool0<?ooool00ol00?ooo`00ooooo`10ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool0COooool0027ooooo00?o0000ooooooooool0Foooool00ol00?ooo`00
ooooo`0`ooooo`03o`00oooo003ooooo043ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`1=ooooo`008Oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool0?_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo04gooooo000Q
ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool0<Oooool00ol00?ooo`00ooooo`0n
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool0COooool0027ooooo00?o0000oooo
ooooool0F_ooool00ol00?ooo`00ooooo`0booooo`03o`00oooo003ooooo03kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`1=ooooo`008Oooool00ol0003oooooooooo`1Jooooo`03
o`00oooo003ooooo03;ooooo00?o003oool00?ooool0?Oooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo04cooooo000Qooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool0
<oooool00ol00?ooooooooooo`0looooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
C?ooool0027ooooo0ol0001Iooooo`03o`00oooo003ooooo03Cooooo00?o003oool00?ooool0??oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo04cooooo000Qooooo`03o`000?oooooo
oooo05Wooooo00?o003oool00?ooool0=?ooool00ol00?ooo`00ooooo`0looooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool0C?ooool0027ooooo00?o0000ooooooooool0FOooool00ol0
0?ooooooooooo`0eooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`1Hooooo`03o`00oooo003ooooo03Ko
oooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo04_o
oooo000Qooooo`03o`000?oooooooooo05Sooooo00?o003oool00?ooool0=_ooool00ol00?ooo`00
ooooo`0jooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0Boooool0027ooooo00?o
0000ooooooooool0AOooool5o`0000kooooo00?o003oooooooooool0=_ooool00ol0003o003ooa0@
400iooooo`03o`00oooooooooooo00Wooooo00Gok^k^oc8b<_l0003o410@olc<c00Hooooo`03o`00
oooooooooooo02_ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Kooooo`008Oooool00ol0003ooooo
ooooo`15ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03Oooool00ol00?ooo`00ooooo`0hooooo`03
o`00oooooooooooo03Sooooo00?o003oooooooooool02Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
01Wooooo00?o003oooooooooool0:_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01_ooooo000Qoooo
o`03o`000?oooooooooo04Kooooo00?oV9RHob4Q8Oo^k^h03_ooool00ol00?ooo`00ooooo`0eoooo
o`?o000000?o003oool00?ooool0>?ooool00ol00?ooooooooooo`09ooooo`05o`000?oooooooooo
ooooool000006Oooool00ol00?ooooooooooo`0Zooooo`05o`000?ooooooooooooooool000006ooo
ool0027ooooo00?o0000ooooooooool0Aoooool00onHV9So8B4Qonk^kP0=ooooo`03o`00oooooooo
oooo03Gooooo00GoA4A4omgMgOoooooo003oool0000iooooo`03o`00oooooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0Iooooo`03o`00oooooooooooo02[ooooo00Go<S8boiRHV?oooooo
003ooc8b<P0Kooooo`008Oooool3o`0004Sooooo00?oMgMgofIVI_ooool03?ooool00ol00?oooooo
ooooo`0eooooo`05omgMgOmEEEGoooooo`000?l00?l0>?ooool00ol00?ooooooooooo`0:ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`06Oooool00ol00?ooooooooooo`0Zooooo`05olc<c?l0003o0000
o`00ooo<c<`06oooool0027ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0:oooo
o`03o`00oooo003ooooo03Oooooo00CoMgMgolc<c?l0003o003o>?ooool00ol00?ooooooooooo`0:
ooooo`03oeEEEOn7QhOooooo01_ooooo00?o003oooooooooool0:_ooool01Ol@413o^[Zjooooool0
0?oo410@01_ooooo000Qooooo`03o`000?oooooooooo04Gooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`00oooo003ooooo03Oooooo00Gok^k^odA4A?l0003o003oool0000gooooo`03o`00
oooooooooooo00[ooooo00?ogMgMoa0@4?nHV9P07?ooool00ol00?ooooooooooo`0Yooooo`05o`00
0?nj^[[o003ookZj^_l000006oooool0027ooooo00?o0000ooooooooool0AOooool01OnHV9So410@
o`000?lQ8B7oc<c<00cooooo00?o003oooooooooool0>?ooool01?mgMgOo0000ooooool00?lgoooo
o`03o`00oooooooooooo00_ooooo00Coc<c<odA4A?l0003o410@6_ooool00ol00?ooooooooooo`0Y
ooooo`05ojVYZOl@413o003ooa0@4?nYZJT04?ooool3o`000003oa0@4?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo05Gooooo00?o003oool00?ooool0??ooool00ol00?ooooooooooo`0d
ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0B
ooooo`03oa0@4?nj^[[ooooo00Kooooo000Qooooo`03o`000?oooooooooo05Gooooo00?o003oool0
0?ooool0??ooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo02[ooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`0Booooo`03oiRHV?lb<S;ooooo00Kooooo000Qooooo`03
o`000?oooooooooo05Gooooo00?o003oooooooooool0??ooool00ol00?ooo`00ooooo`0dooooo`03
o`00oooooooooooo02_ooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0Cooooo`03
omgMgOl0003o^[Zj00Kooooo000Qooooo`03o`000?oooooooooo05Cooooo00?o003oool00?ooool0
?_ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool0
:Oooool00ol00?ooooooooooo`0Cooooo`03oeEEEOmgMgOoA4A400Kooooo000Qooooo`03o`000?oo
oooooooo05Cooooo00?o003oool00?ooool0?_ooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0Booooo`05omgMgOl@
413oooooob4Q8OoMgMd01Oooool001[oooooG_l000000ol00?oo0000o`00000no`000003o`00oooo
003o000003;o000000?o003oo`000?l00000;?l000000ol00?oo0000o`00000Yo`000003o`00ool0
003o000000Oo00002oooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo000Qooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02?ooool00ol00?ooo`00ooooo`04ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooool00?l03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o003oooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
00Co003ooooooooooooo00004Oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?o
oooo000Qooooo`03o`000?oooooooooo05?ooooo00?o003oool00?ooool0@?ooool00ol00?oooooo
ooooo`0aooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`0Booooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool0027ooooo
00?o0000ooooooooool0Doooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo037ooooo
00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01gooooo
000Qooooo`03o`000?oooooooooo05?ooooo00?o003oooooooooool0@Oooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo02kooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`0Mooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`00oooo003ooooo04;ooooo00?o003o
ooooooooool0;oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool07Oooool0027ooooo00?o0000ooooooooool0D_ooool00ol00?ooo`00ooooo`12oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo01kooooo000Qooooo`03o`000?oooooooooo05;ooooo00?o003ooooooooo
ool0@_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo02oooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Nooooo`008Oooool3o`00057ooooo00?o003oool00?ooool0
A?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`1Aooooo`03o`00oooo
003ooooo04Cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo02Cooooo00?o003oooooooooool07_ooool0027ooooo00?o0000ooooooooool0DOooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0<Oooool0
0ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01oooooo000Qooooo`03o`000?oooooooooo
053ooooo00?o003oool00?ooool0AOooool00ol00?ooo`00ooooo`0]ooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Oooooo`008Oooool00ol0003o
ooooooooo`1@ooooo`03o`00oooo003ooooo04Kooooo00?o003oooooooooool0:oooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool07oooool0027ooooo
00?o0000ooooooooool0D?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo02_ooooo
00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01oooooo
000Qooooo`03o`000?oooooooooo04oooooo00?o003oool00?ooool0Aoooool00ol00?oooooooooo
o`0[ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0Pooooo`008Oooool00ol0003oooooooooo`1?ooooo`03o`00oooo003ooooo04Oooooo00?o003o
ool00?ooool0:oooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool08?ooool0027ooooo00?o0000ooooooooool0Coooool00ol00?ooooooooooo`18oooo
o`03o`00oooooooooooo02Wooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo023ooooo000Qooooo`?o0000C_ooool00ol00?ooo`00ooooo`19ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo023ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o003oool00?ooool0
BOooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`1>ooooo`03o`00oooo
oooooooo04Wooooo00?o003oool00?ooool0:Oooool00ol00?ooooooooooo`0eooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08Oooool0027ooooo00?o0000ooooooooool0COooool0
0ol00?ooo`00ooooo`1:ooooo`03o`00oooo003ooooo02Sooooo00?o003oooooooooool0=_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo027ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o003oool00?ooool0Boooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Qooooo`008Oooool00ol0003o
ooooooooo`1=ooooo`03o`00oooooooooooo04_ooooo00?o003oool00?ooool09oooool00ol00?oo
ooooooooo`0gooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool08_ooool0027ooooo
00?o0000ooooooooool0C?ooool00ol00?ooo`00ooooo`1<ooooo`03o`00oooo003ooooo02Oooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo04cooooo00?o003oool00?ooool0C?ooool00ol00?ooo`00oooo
o`0Vooooo`03o`00oooooooooooo03Sooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`0Rooooo`008Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo04gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool08_ooool0027ooooo0ol0001;ooooo`03o`00oooo003ooooo04kooooo00?o003oool0
0?ooool09Oooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool08_ooool0027ooooo00?o0000ooooooooool0Boooool00ol00?ooo`00ooooo`1>ooooo`03
o`00oooo003ooooo02Cooooo00?o003oool00?ooool0>_ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo02?ooooo000Qooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool0
C_ooool00ol00?ooo`00ooooo`0Tooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`1:ooooo`03o`00oooo
003ooooo053ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo01[ooooo00?o003oooooooooool08oooool0027ooooo00?o0000ooooooooool0B_ooool0
0ol00?ooo`00ooooo`1@ooooo`03o`00oooo003ooooo02?ooooo00?o003oooooooooool0>oooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo02?ooooo000Qooooo`03o`000?oooooooooo
04[ooooo00?o003oooooooooool0D?ooool00ol00?ooo`00ooooo`0Rooooo`03o`00oooo003ooooo
03cooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Tooooo`008Oooool00ol0003o
ooooooooo`19ooooo`03o`00oooo003ooooo05;ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0mooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool09?ooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooooooo
ool0BOooool00ol00?ooo`00ooooo`1Booooo`03o`00oooo003ooooo027ooooo00?o003ooooooooo
ool0?Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo02Cooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`03o`000?oooooooooo04Wooooo00?o003oooooooooool0D_ooool00ol00?ooo`00ooooo`0Qoooo
o`03o`00oooooooooooo03gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Toooo
o`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`00
04Sooooo00?o003oool00?ooool0E?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo003ooooo
03oooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Uooooo`001oooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`18oooo
o`03o`00oooo003ooooo05Cooooo00?o003oool00?ooool07oooool00ol00?ooooooooooo`0ooooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool09Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0B?ooool00ol0
0?ooooooooooo`1Dooooo`03o`00oooo003ooooo01oooooo00?o003oooooooooool0?oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo02Gooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Oooooo00?o003oool0
0?ooool0EOooool00ol00?ooo`00ooooo`0Oooooo`03o`00oooooooooooo03oooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Vooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo04Oooooo00?o003o
ool00?ooool0E_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo047ooooo00?o003o
ooooooooool05?ooool00ol00?ooooooooooo`0Vooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo04Oooooo00?o
003oooooooooool0E_ooool00ol00?ooo`00ooooo`0Mooooo`03o`00oooooooooooo047ooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`16
ooooo`03o`00oooo003ooooo05Oooooo00?o003oool00?ooool07Oooool00ol00?ooooooooooo`11
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool09oooool0027ooooo00?o0000oooo
ooooool0A_ooool00ol00?ooo`00ooooo`1Hooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Oooooo000Qooooo`03
o`000?oooooooooo04Kooooo00?o003oooooooooool0F?ooool00ol00?ooo`00ooooo`0Kooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Wooooo`00
8Oooool3o`0004Gooooo00?o003oool00?ooool0FOooool00ol00?ooo`00ooooo`0Kooooo`03o`00
oooooooooooo04?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Xooooo`008Ooo
ool00ol0003oooooooooo`15ooooo`03o`00oooo003ooooo05[ooooo00?o003oooooooooool06Ooo
ool00ooo003o003oooooo`15ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`1Jooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo02Sooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o003oool00?ooool0Foooool00ol0
0?ooo`00ooooo`0Iooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`14ooooo`03o`00oooo003ooooo05co
oooo00?o003oooooooooool05oooool00ooo003o003oooooo`17ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool0:Oooool0027ooooo00?o0000ooooooooool0A?ooool00ol00?oooooo
ooooo`1Looooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0Aoooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02Wooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o
003oool00?ooool0GOooool00ol00?ooo`00ooooo`0Gooooo`03o`00oooooooooooo04Oooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`13
ooooo`03o`00oooo003ooooo05kooooo00?o003oooooooooool05Oooool00ooo003o003oooooo`19
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0:_ooool0027ooooo00?o0000oooo
ooooool0@oooool00ol00?ooooooooooo`1Nooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool0BOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02[ooooo000Qooooo`?o
0000@_ooool00ol00?ooo`00ooooo`1Oooooo`03o`00oooo003ooooo01Gooooo00?o003ooooooooo
ool0B_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02[ooooo000Qooooo`03o`00
0?oooooooooo04;ooooo00?o003oool00?ooool0H?ooool00ol00?ooooooooooo`0Cooooo`03ool0
0?l00?oooooo04_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0[ooooo`008Ooo
ool00ol0003oooooooooo`11ooooo`03o`00oooo003ooooo067ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Wooooo00?oo`00o`00ooooool0;?oo
ool0027ooooo00?o0000ooooooooool0@Oooool00ol00?ooo`00ooooo`1Rooooo`03o`00oooooooo
oooo017ooooo00?oo`00o`00ooooool0COooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo02cooooo000Qooooo`03o`000?oooooooooo047ooooo00?o003oool00?ooool0H_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`10ooooo`03o`00oooo003ooooo06Co
oooo00?o003oooooooooool03oooool00ooo003o003oooooo`1?ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0;_ooool0027ooooo00?o0000ooooooooool0@?ooool00ol00?ooo`00
ooooo`1Tooooo`03o`00oooo003ooooo00oooooo00?o003oooooooooool0D?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo02kooooo000Qooooo`03o`000?oooooooooo03oooooo00?o
003ooooooooo0000I_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo057ooooo0_l0
0?l01?oooooo003oo`00ool00?laooooo`008Oooool00ol0003oooooooooo`0oooooo`03o`00oooo
003ooooo06Kooooo00?o003oool00?ooool03Oooool00ol00?ooooooooooo`1Cooooo`?o003o<ooo
ool0027ooooo0ol0000nooooo`03o`00ooooooooo`0006Sooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`29ooooo`008Oooool00ol0003oooooooooo`0nooooo`03o`00ooooooooo`00
06Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`2:ooooo`008Oooool00ol0003o
ooooooooo`0nooooo`03o`00oooo003ooooo06[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`2;ooooo`008Oooool00ol0003oooooooooo`0mooooo`03o`00ooooooooo`0006cooooo
00?o003oooooooooool01_ooool00ooo003o003oooooo`2<ooooo`008Oooool00ol0003ooooooooo
o`0mooooo`03o`00ooooooooo`0006gooooo00?o003oooooooooool01?ooool2o`00ohkooooo000Q
ooooo`03o`000?oooooooooo03cooooo00?o003ooooooooo0000Koooool6o`00oi3ooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo03cooooo00?o003ooooooooo0000LOooool2o`00oi;ooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0kooooo`03o`00ooooooooo`000?oooooo1oooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`Go00001Oooool00ol0003oooooooooo`0kooooo`03o`00oooooooo
o`000?oooooo1oooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo0ol0000kooooo`03o`00oooo003ooooo0?oooooo1oooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0
>_ooool00ol00?ooooooool0003oooooo`Sooooo0007ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo03[ooooo00?o003oool00?ooool0
ooooool8ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
1_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02oooooo00?o003ooooooooo0000
ooooool9ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02oooooo00?o003oool00?ooool0
ooooool9ooooo`008Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo02gooooo00?o
003ooooooooo0000ooooool:ooooo`008Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo02cooooo00?o003oool00?ooool0ooooool:ooooo`008Oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo02_ooooo00?o003oool00?ooool0ooooool:ooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo02[ooooo00?o003oool00?ooool0ooooool;ooooo`00
8Oooool3o`0000_ooooo00?oo`00ooooooooool0:Oooool00ol00?ooo`00ooooo`3oooooo`_ooooo
000Qooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool09oooool00ol00?ooo`00oooo
o`3oooooo`cooooo000Qooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool09Oooool0
0ol00?ooo`00ooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool09?ooool00ol00?ooooooooooo`3oooooo`gooooo000Qooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool08_ooool00ol00?ooooooooooo`3oooooo`kooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool08?ooool00ooo003o003oooooo`3oooooo`oooooo
000Qooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool07_ooool00ooo003o003ooooo
o`3ooooooa3ooooo000Qooooo`03o`000?oooooooooo01;ooooo0_oo000Mooooo`03ool00?l00?oo
oooo0?oooooo4Oooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Joooo
o`03ool00?l00?oooooo0?oooooo4Oooool0027ooooo0ol0000Eooooo`;oo`006Oooool00ooo003o
003oooooo`3ooooooa;ooooo000Qooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
5Oooool00ooo003o003oooooo`3ooooooa?ooooo000Qooooo`03o`000?oooooooooo01Sooooo0_oo
000Dooooo`03ool00?l00?oooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool06_ooool2
ool0017ooooo00?oo`00o`00ooooool0oooooolEooooo`008Oooool00ol0003oooooooooo`0Loooo
o`;oo`003?ooool3ool00003o`00oooooooooooo0?oooooo5Oooool0027ooooo00?o0000oooooooo
ool07_ooool00ooo003oooooooooo`07ooooo`;oo`000_ooool00ol00?ooooooooooo`3ooooooaKo
oooo000Qooooo`03o`000?oooooooooo01oooooo2Ooo0002ooooo`;o003ooooooolIooooo`008Ooo
ool00ol0003oooooooooo`0Yooooo`03o`00oooooooooooo0?oooooo6Oooool0027ooooo00?o0000
ooooooooool09oooool2o`00oooooooo7?ooool0027ooooo0ol0000Tooooo`?o003ooooooolNoooo
o`008Oooool00ol0003oooooooooo`0Sooooo`03o`00oooooooooooo0?oooooo7oooool0027ooooo
00?o0000ooooooooool07oooool4o`00oooooooo8_ooool0027ooooo00?o0000ooooooooool04_oo
ool=o`00oooooooo9_ooool0027ooooo00?o0000ooooooooool03Oooool5o`00oooooooo<oooool0
027ooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`3oooooocKooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005
ooooo`03o`000?oooooooooo00[ooooo0_l00?ooooooocWooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool0ooooooliooooo`001oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0ooooooljooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`?o00002?ooool00ol00?ooooooooooo`3ooooooc[o
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`3ooooooc_ooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00:Oooool3o`000003oa0@4?oooooooooo
0?oooooo>_ooool001oooooo00?oMgMgofIVI_ooool02Oooool00ol@413o^[Zjooooo`03ooooo`03
ofIVI_mgMgOooooo0?oooooo=Oooool001kooooo00?ogMgMoa0@4?o^k^h02_ooool00onHV9So<S8b
ooooo`03ooooo`03onk^k_l@413ogMgM0?oooooo=Oooool000_ooooo0ol00002ooooo`?o00000_oo
ool5o`0000Cooooo00?oEEEEoiRHV?ooool02_ooool00ooMgMgo0000okZj^P04ooooo`03ohN7QomV
IVKooooo0?oooooo=?ooool000_ooooo00?ok^k^o`000?o^k^h00oooool00ol0003ogMgMooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00omEEEGoMgMgodA4A004
ooooo`03onk^k_l0003ooooo0?oooooo=?ooool000cooooo00?oEEEEo`000?l000000_l000000om4
A4Coooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co<S8boooooooooooooooo1_l00002
ooooo`05omgMgOl@413oooooob4Q8OoMgMd01?ooool00ol0003oooooooooo`3ooooooc?ooooo000<
ooooo`06ojVYZOm4A4Cooooooooooom4A4CoV9RH1Oooool00ol0003oooooooooo`04ooooo`03oc8b
<_oooooooooo00Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@04ooooo`03o`000?oooooooooo0?oo
oooo<oooool000gooooo00Co0000onk^k_o^k^ko00001_ooool00ol0003oooooooooo`04ooooo`03
o`000?o^k^kooooo00Sooooo00?ok^k^o`000?o^k^h00_ooool01_l0003ogMgMooooooooooook^k^
o`000?oooooo=Oooool000gooooo00CoIVIVoiRHV?n7QhOoIVIV1?ooool00ol@413o0000o`000006
ooooo`03oeEEEOmgMgOooooo00Sooooo00Co410@o`000?l0003ooooo0_l000001Ol@413ooooooooo
oomgMgOoEEEE0?oooooo=Oooool000gooooo00Coc<c<odA4A?lQ8B7ogMgM3Oooool00ooMgMgo410@
onk^kP0@ooooo`03onk^k_l@413ogMgM0?oooooo=Oooool000cooooo00Co410@o`000?l0003o<S8b
1oooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00oooooo00?oIVIVogMgMoooool0
ooooooleooooo`005oooool00ol@413oooooooooo`3oooooodoooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.912152, -0.461634, \
0.0336298, 0.00700169}}]
}, Open  ]],

Cell[TextData[{
  "\tAs one moves away from the left turning point  toward increasing ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " values, one can replace the exact Airy function solution, Eq. ",
  ButtonBox["(6.3.25)",
    ButtonData:>"(6.3.25)",
    ButtonStyle->"Hyperlink"],
  " by the asymptotic solution, Eq. ",
  ButtonBox["(6.3.26)",
    ButtonData:>"(6.3.26)",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`y = \[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\)\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
                " "}], \(\(\@\[Pi]\)[\[Alpha]\_L\^\(1/3\)\ \((x - 
                          x\_L)\)]\^\(1/
                    4\)\)]}], \(cos(\(2\/3\) \[Alpha]\_L\^\(1/2\)\ \((x - \
x\_L)\)\^\(3/2\) - \[Pi]/4)\)}], TraditionalForm]]],
  ",    ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\) \[GreaterTilde] 
        3. \)]]
}], "NE3",
  CellTags->"(6.3.27)"],

Cell[TextData[{
  "However, comparing to the form of ",
  Cell[BoxData[
      \(TraditionalForm\`k(x)\)]],
  " near the left turning point, Eq. ",
  ButtonBox["(6.3.24)",
    ButtonData:>"(6.3.24)",
    ButtonStyle->"Hyperlink"],
  ", we see that Eq. ",
  ButtonBox["(6.3.27)",
    ButtonData:>"(6.3.27)",
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
                " ", \(\[Alpha]\_L\^\(1/12\)\)}], \(\(\@\[Pi]\)[\(k\_n\)(
                      x)]\^\(1/
                    4\)\)]}], \(cos(\[Integral]\_\(x\_L\)\%x\(\( k\_n\)(
                    x)\) \[DifferentialD]x - \[Pi]/4)\)}], 
        TraditionalForm]]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_L\^\(1/3\)\ \((x - x\_L)\) \[GreaterTilde] 
        3. \)]]
}], "NE3",
  CellTags->"(6.3.28)"],

Cell[TextData[{
  "Furthermore, this result is identical to the WKB expression for the mode, \
Eq. ",
  ButtonBox["(6.3.22)",
    ButtonData:>"(6.3.22)",
    ButtonStyle->"Hyperlink"],
  ", provided that we set ",
  Cell[BoxData[
      \(TraditionalForm\`A = \(\(B\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`C\_\(1\ L\)\)]]]], 
          " ", \(\[Alpha]\_L\^\(1/12\)/2\), \(\@\[Pi]\)}], 
        TraditionalForm]]],
  ", and take  a lower bound in the integrals to be ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L\)]],
  ". Thus, we have matched the WKB expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ",",
  " valid for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " far from the turning points, to the Airy expression, valid near the left \
turning point."
}], "Text"],

Cell[TextData[{
  "\t On the other hand, we can also match the WKB solution to the Airy \
solution near the right turning point, and this provides us with a criterion \
to determine the eigenvalues. Replacing Eq. ",
  ButtonBox["(6.3.23)",
    ButtonData:>"(6.3.23)",
    ButtonStyle->"Hyperlink"],
  " by its asymptotic form as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " moves away from the right turning point, we obtain "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi]\_n\)(
            x)\)\ ~\(1\/\(\@\[Pi]\)[\[Alpha]\_R\^\(1/3\)\ \((x\_R - \
x)\)]\^\(1/4\)\) \(cos(\(2\/3\) \[Alpha]\_R\^\(1/2\)\ \((x\_R - x)\)\^\(3/2\) \
- \[Pi]/4)\), \ \ \ \ \[Alpha]\_R\^\(1/3\)\ \((x\_R - x)\) \[GreaterTilde] 
        3\)]]
}], "NE3",
  CellTags->"(6.3.29)"],

Cell[TextData[{
  "This expression can also be matched to the WKB form for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\_n\)(x)\), " ", "~", 
            FractionBox[
              RowBox[{Cell[TextData[Cell[BoxData[
                    \(TraditionalForm\`C\_\(1\ R\)\)]]]], 
                " ", \(\[Alpha]\_R\^\(1/12\)\)}], \(\(\@\[Pi]\)[\(k\_n\)(
                      x)]\^\(1/
                    4\)\)]}], \(cos(\(-\(\[Integral]\_\(x\_R\)\%x\(\( k\_n\)(
                      x)\) \[DifferentialD]x\)\) + \[Pi]/4)\)}], 
        TraditionalForm]]],
  ",     ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_R\^\(1/3\)\ \((x\_R - x)\) \[GreaterTilde] 
        3\)]],
  "."
}], "NE3",
  CellTags->"(6.3.30)"],

Cell[TextData[{
  "The regions of validity of Eqs. ",
  ButtonBox["(6.3.29)",
    ButtonData:>"(6.3.29)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.3.30)",
    ButtonData:>"(6.3.30)",
    ButtonStyle->"Hyperlink"],
  " overlap, so these WKB expressions must be identical. This is only \
possible if the arguments of the cosines differ by integer multiples of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`C\_\(1\ R\)\)]]]], 
            " ", \(\[Alpha]\_R\^\(1/12\)\)}], "=", 
          RowBox[{
            RowBox[{"\[PlusMinus]", Cell[TextData[Cell[BoxData[
                  \(TraditionalForm\`C\_\(1\ L\)\)]]]]}], 
            " ", \(\[Alpha]\_L\^\(1/12\)\)}]}], TraditionalForm]]],
  ", with the + sign for ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
          "even", " ", "multiples", " ", "of", " ", "\[Pi]", " ", "and", " ", 
            "the", " ", Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`-\)]]]]}]}], TraditionalForm]]],
  " sign for odd multiples. Therefore, "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(x\_L\)\%x\(\( k\_n\)(
              x)\) \[DifferentialD]x - \[Pi]/
          4 = \(\(-\(\[Integral]\_\(x\_R\)\%x\(\( k\_n\)(
                  x)\) \[DifferentialD]x\)\) + \[Pi]/4 + \ 
          n\ \[Pi] = \(-\(\[Integral]\_\(x\_L\)\%\(x\_R\)\ \(\(k\_n\)(
                  x)\) \[DifferentialD]x\)\)\  + \[Integral]\_\(x\_L\)\%x\(\( 
                    k\_n\)(x)\) \[DifferentialD]x + \[Pi]/4 + \ 
          n\ \[Pi]\)\)]]], "UNNEQ"],

Cell["Rearranging the terms in this equation, we are left with ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(x\_L\)\%\(x\_R\)\ \(\(k\_n\)(
              x)\) \[DifferentialD]x = \ \[Pi](n\  + 1/2), \ \ \ \ n = 0, 1, 
      2,  ... \)]],
  "."
}], "NE3",
  CellTags->"(6.3.31)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " is the expression we have been looking for. It can be used to determine  \
the WKB eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " associated with Eq. ",
  ButtonBox["(6.3.21)",
    ButtonData:>"(6.3.21)",
    ButtonStyle->"Hyperlink"],
  ". Note that the integral on the ",
  "left-hand",
  " side of Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " must be larger than zero, so we require that ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " corresponds to the ground state, ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " to the first excited state, etc."
}], "Text",
  CellTags->"i:45"],

Cell[TextData[{
  " \tIt is instructive to compare Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " to the expression for WKB Dirichlet mode frequencies of a string \
stretched between points ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`0\)]]]]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\(\( k\_n\)(
              x)\) \[DifferentialD]x = \ n\ \[Pi], \ \ n = 1, 2,  ... \)]],
  ". [See Eq. ",
  ButtonBox["(6.3.17)",
    ButtonData:>"(6.3.17)",
    ButtonStyle->"Hyperlink"],
  ".] The ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/2\)]],
  " difference in the ",
  "right-hand",
  " sides of these expressions arises from the difference in the boundary \
conditions in these two cases; for a string the eigenmodes go to zero at the \
ends, but for the quantum particle the eigenmodes  are finite at the turning \
points."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Quantum Harmonic Oscillator Frequencies", "Section",
  CellTags->"c:42"],

Cell[TextData[{
  "\tAs an example of the use of Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  ", let's apply it to determine the eigenmodes of the dimensionless quantum \
harmonic oscillator, Eq. ",
  ButtonBox["(6.3.12)",
    ButtonData:>"(6.3.12)",
    ButtonStyle->"Hyperlink"],
  ". We already know that the energy levels for this system are ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(\(n\)\(\ \)\) = \((n + 1/2)\)\)]],
  ".  In the WKB approximation, we determine these energy levels by \
performing the integral in Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  ". The turning points are determined by solving ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \(V(x) = x\^2/2\)\)]],
  ", which implies that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_L = \ \(\(-\@\(2  E\_n\)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_R\)\(=\)\(\ \)\(\@\(2  E\_n\)\)\(\ \)\)\)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\)(x) = \@\(2 \((E\_n - \ x\^2/2)\)\)\)]],
  ", and Eq. ",
  ButtonBox["(6.3.31)",
    ButtonData:>"(6.3.31)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\@\(2  E\_n\)\)\%\(\@\(2  E\_n\)\)\(\
\@\(2 \((E\_n - \ x\^2/2)\)\)\) \[DifferentialD]x = \ 
        n\ \[Pi]\  + \ \[Pi]/2\)]],
  "."
}], "NE3",
  CellTags->"(6.3.32)"],

Cell[TextData[{
  "The integral on the ",
  "left-hand",
  " side can be performed analytically using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Integrate[\@\(2 \((\[Epsilon]\_n - \ x\^2/2)\)\), {x, \(-\@\(2  \
\[Epsilon]\_n\)\), \@\(2  \[Epsilon]\_n\)}], \ \ \[Epsilon]\_n > \ 
        0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.179"],

Cell[BoxData[
    \(\[Pi]\ \[Epsilon]\_n\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using this result for the integral in Eq. ",
  ButtonBox["(6.3.32)",
    ButtonData:>"(6.3.32)",
    ButtonStyle->"Hyperlink"],
  " we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_n\)\(=\)\((n + 1/2)\)\(\ \)\)\)]],
  ", which precisely matches the exact result for the eigenvalues of the \
harmonic oscillator. However, this is a lucky coincidence. For general \
potentials, the match is not exact, although it is good if the potential is \
slowly varying with respect to the wavelength of the eigenmode."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Shooting Method for Problems with Turning Points", "Section",
  CellTags->{"i:46", "c:43"}],

Cell[TextData[{
  "\tWe now use the WKB eigenvalues as an initial guess in the shooting \
method, in order to determine the eigenmodes.  For a symmetric potential well \
where ",
  Cell[BoxData[
      \(TraditionalForm\`V(\(-x\)) = V(x)\)]],
  ", this task is simplified somewhat, because the modes break into even and \
odd sets. The odd modes correspond to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "odd and vanish at the origin, and this provides a boundary condition in \
the shooting.  For the even modes, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "even, the slope of the eigenmode vanishes at the origin, so this is the \
boundary condition used for even modes. The other boundary condition is that \
",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 0\)]],
  " well beyond the turning point. For general potentials without symmetry, \
one must shoot from a point well to the left of the left turning point to a \
point well beyond the right turning point, setting the eigenmode equal to \
zero at these points. (A slightly more accurate method of setting the \
boundary conditions is discussed in Exercise (7). )"
}], "Text"],

Cell[TextData[{
  "\tBelow, we use the shooting method to determine the eigenmodes of the \
dimensionless quantum harmonic oscillator, Eq. ",
  ButtonBox["(6.3.12)",
    ButtonData:>"(6.3.12)",
    ButtonStyle->"Hyperlink"],
  ", using the symmetry of the modes."
}], "Text"],

Cell["\<\
\tFirst, we define the right-hand turning point as a function of \
the energy:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xR[\[Epsilon]_]\  = \ Sqrt[2\ \[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.180"],

Cell[BoxData[
    \(\@2\ \@\[Epsilon]\)], "Output"]
}, Open  ]],

Cell["The potential is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V[x] = 1/2\ x^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.181"],

Cell[BoxData[
    \(x\^2\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now shoot toward the origin,  starting to the right of the right \
turning point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ x\_1\)]],
  ". We choose ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " sufficiently far to the right of the right turning point so that the \
eigenmode is nearly zero there. "
}], "Text"],

Cell[BoxData[{
    \(\(x1[\[Epsilon]_]\  = \ xR[\[Epsilon]]\  + \ 7;\)\), "\n", 
    \(Sol[\[Epsilon]_] := \(NDSolve[{\(-\ \(1\/2\)\)\ D[\[Psi][x], {x, 2}] + 
                V[x] \[Psi][x] \[Equal] \[Epsilon]\ \[Psi][x], \[Psi][
                x1[\[Epsilon]]] \[Equal] 
              0, \(\[Psi]'\)[
                x1[\[Epsilon]]] \[Equal] \(-10\^\(-11\)\)}, \[Psi], {x, 
            x1[\[Epsilon]], 0}, AccuracyGoal \[Rule] 13, 
          PrecisionGoal \[Rule] \ 13, 
          MaxSteps \[Rule] 10000]\)[\([1]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.182"],

Cell[TextData[{
  "We then define ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Psi]end[\[Epsilon]]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " as the value of the solution at the origin. This function is used for odd \
modes:"
}], "Text"],

Cell[BoxData[
    \(\[Psi]end[\[Epsilon]_] := \ \[Psi][0] /. Sol[\[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.183"],

Cell[TextData[{
  "For even modes, we define the derivative at the origin as ",
  StyleBox["\[Psi]primeend",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi]primeend[\[Epsilon]_] := \ \(\[Psi]'\)[0] /. 
        Sol[\[Epsilon]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.184"],

Cell[TextData[{
  "The energy eigenvalue is then determined by finding the value of \
\[Epsilon] that makes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]end",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  " for odd modes and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]primeend",
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  " for even modes. We use the WKB method eigenvalue as the initial guess in \
",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(\(\[Epsilon]WKB[n_]\  = \ n\  + 1/2\ ;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Epsilon]shooting[
          n_]\  := \ \((\[Epsilon] /. \(FindRoot[\[Psi]primeend[\[Epsilon]] \
\[Equal] 0, {\[Epsilon], 1.01  \[Epsilon]WKB[n], 1.1  \[Epsilon]WKB[n]}, 
                  MaxIterations \[Rule] 40]\)[\([1]\)]\ )\) /; \ 
          n/2\ \  \[Element] Integers;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Epsilon]shooting[
        n_]\  := \ \((\[Epsilon] /. \(FindRoot[\[Psi]end[\[Epsilon]] \[Equal] 
                  0, {\[Epsilon], 1.01  \[Epsilon]WKB[n], 
                  1.1  \[Epsilon]WKB[n]}, 
                MaxIterations \[Rule] 40]\)[\([1]\)]\ )\) /; \ \((n + 1)\)/
            2\ \  \[Element] Integers\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.185"],

Cell["\<\
The first few shooting method energy levels are given by the \
following list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[FullForm[\[Epsilon]shooting[n]], {n, 0, 12, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.186"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frsec" \(\(:\)\(\ \)\) 
      "Secant method failed to converge to the prescribed accuracy after \
\!\(40\) iterations."\)], "Message"],

Cell[BoxData[
    \(FindRoot::"frmp" \(\(:\)\(\ \)\) 
      "Machine precision is insufficient to achieve the accuracy \
\!\(1.0000000000000006`*^-6\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(FindRoot :: \"frmp\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["0.5000000000342457`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["1.4999999999999425`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["2.5000000000004245`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["3.500000000000405`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["4.499999999993332`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["5.499999999995752`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["6.499999999994303`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["7.499999999989863`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["8.499999999996888`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["9.49999999999108`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["10.499999999990823`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["11.49999999999825`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["12.499999999990976`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The error messages occur because the solution is increasing exponentially \
as one shoots toward smaller ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\)\)]],
  " until one hits the turning point, where the solution begins to oscillate. \
This means that the point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "where one starts the numerical integration must be chosen carefully: Too \
far beyond the turning point, and the solution blows up before the turning \
point is reached. Too close to the turning point, and setting the solution \
equal to zero initially is not a good approximation.  "
}], "Text"],

Cell[TextData[{
  "\tThe eigenvalues found using the shooting method are very accurate, \
equaling the exact eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1/2\)]],
  " to 10 significant figures. Such accuracy is difficult to achieve in the \
Galerkin and grid methods, particularly for high",
  "-order",
  " modes."
}], "Text"],

Cell["\<\
\tThe eigenmodes can now be found numerically,  using these \
eigenvalues:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]shooting[
        n_]\  := \(\[Psi]shooting[n]\  = \ \ \[Psi] /. 
          Sol[\[Epsilon]shooting[n]]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.187"],

Cell[TextData[{
  "We use double equal signs so that the eigenmodes are evaluated only once. \
In order to extend the definition to ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  ", we use the symmetry of the modes:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Psi]sh[x_, n_] := \ \(\[Psi]shooting[n]\)[x]\  /; \ 
          x \[GreaterEqual] \ 0;\)\), "\n", 
    \(\(\[Psi]sh[x_, n_] := \ \(-\(\[Psi]shooting[n]\)[\(-x\)]\)\  /; \ 
          x < \ 0\  && \ \((n + 1)\)/2\  \[Element] Integers;\)\), "\n", 
    \(\[Psi]sh[x_, n_] := \ \(\[Psi]shooting[n]\)[\(-x\)]\  /; \ 
        x < \ 0\  && \ n/2\  \[Element] Integers\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.188"],

Cell[TextData[{
  "The eigenmodes can now be evaluated and plotted: see Cell ",
  ButtonBox["6.189",
    ButtonData:>"Cell 6.189",
    ButtonStyle->"Hyperlink"],
  ". One can see that the computed eigenfunctions have very large amplitude \
because we started the numerical integration well beyond the right turning \
point, at ",
  Cell[BoxData[
      \(TraditionalForm\`x\_R + 7\)]],
  ".  The reader is invited to vary this distance, in order to observe the \
effect this has on the accuracy of the eigenvalues and on the eigenmodes \
themselves. See Exercise (7) for a more accurate method of setting the \
bondary conditions. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Evaluate[\[Psi]sh[x, n]], {x, \(-8\), 8}, PlotRange \[Rule] All, 
          PlotLabel \[Rule] \*"\"\<Shooting method \!\(\[Psi]\_n\)(x), \
n=\>\"" <> ToString[n]], {n, 0, 5}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 6.189"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0147151 0.01167 [
[.05357 .00222 -12 -9 ]
[.05357 .00222 12 0 ]
[.20238 .00222 -6 -9 ]
[.20238 .00222 6 0 ]
[.35119 .00222 -12 -9 ]
[.35119 .00222 12 0 ]
[.64881 .00222 -9 -9 ]
[.64881 .00222 9 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.94643 .00222 -9 -9 ]
[.94643 .00222 9 0 ]
[.4875 .13141 -12 -4.5 ]
[.4875 .13141 0 4.5 ]
[.4875 .24811 -12 -4.5 ]
[.4875 .24811 0 4.5 ]
[.4875 .36481 -12 -4.5 ]
[.4875 .36481 0 4.5 ]
[.4875 .48151 -12 -4.5 ]
[.4875 .48151 0 4.5 ]
[.4875 .59821 -12 -4.5 ]
[.4875 .59821 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .01472 m
.05357 .02097 L
s
[(-7.5)] .05357 .00222 0 1 Mshowa
.20238 .01472 m
.20238 .02097 L
s
[(-5)] .20238 .00222 0 1 Mshowa
.35119 .01472 m
.35119 .02097 L
s
[(-2.5)] .35119 .00222 0 1 Mshowa
.64881 .01472 m
.64881 .02097 L
s
[(2.5)] .64881 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(5)] .79762 .00222 0 1 Mshowa
.94643 .01472 m
.94643 .02097 L
s
[(7.5)] .94643 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76786 .01472 m
.76786 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13141 m
.50625 .13141 L
s
[(10)] .4875 .13141 1 0 Mshowa
.5 .24811 m
.50625 .24811 L
s
[(20)] .4875 .24811 1 0 Mshowa
.5 .36481 m
.50625 .36481 L
s
[(30)] .4875 .36481 1 0 Mshowa
.5 .48151 m
.50625 .48151 L
s
[(40)] .4875 .48151 1 0 Mshowa
.5 .59821 m
.50625 .59821 L
s
[(50)] .4875 .59821 1 0 Mshowa
.125 Mabswid
.5 .03806 m
.50375 .03806 L
s
.5 .0614 m
.50375 .0614 L
s
.5 .08473 m
.50375 .08473 L
s
.5 .10807 m
.50375 .10807 L
s
.5 .15475 m
.50375 .15475 L
s
.5 .17809 m
.50375 .17809 L
s
.5 .20143 m
.50375 .20143 L
s
.5 .22477 m
.50375 .22477 L
s
.5 .27145 m
.50375 .27145 L
s
.5 .29479 m
.50375 .29479 L
s
.5 .31813 m
.50375 .31813 L
s
.5 .34147 m
.50375 .34147 L
s
.5 .38815 m
.50375 .38815 L
s
.5 .41149 m
.50375 .41149 L
s
.5 .43483 m
.50375 .43483 L
s
.5 .45817 m
.50375 .45817 L
s
.5 .50485 m
.50375 .50485 L
s
.5 .52819 m
.50375 .52819 L
s
.5 .55153 m
.50375 .55153 L
s
.5 .57487 m
.50375 .57487 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03527 .01472 L
.03754 .01472 L
.04015 .01472 L
.04262 .01472 L
.04502 .01472 L
.04756 .01472 L
.04973 .01472 L
.05212 .01472 L
.05469 .01472 L
.05745 .01472 L
.06006 .01472 L
.06244 .01472 L
.06504 .01472 L
.0678 .01472 L
.07041 .01472 L
.07277 .01472 L
.07556 .01472 L
.07858 .01472 L
.08143 .01472 L
.08405 .01472 L
.08651 .01472 L
.08881 .01472 L
.09133 .01472 L
.09403 .01472 L
.09686 .01472 L
.09955 .01472 L
.10196 .01472 L
.10458 .01472 L
.10691 .01472 L
.10943 .01472 L
.1118 .01472 L
.11398 .01472 L
.11639 .01472 L
.11903 .01472 L
.12179 .01472 L
.12435 .01472 L
.12709 .01472 L
.12968 .01472 L
.132 .01472 L
.13451 .01472 L
.13725 .01472 L
.14016 .01472 L
.14264 .01472 L
.14536 .01472 L
.14786 .01472 L
.15057 .01472 L
.15314 .01472 L
Mistroke
.15552 .01472 L
.16002 .01472 L
.16253 .01472 L
.16481 .01472 L
.16733 .01472 L
.16998 .01472 L
.1729 .01472 L
.17557 .01472 L
.18041 .01472 L
.18315 .01472 L
.1857 .01472 L
.19072 .01472 L
.19356 .01472 L
.19618 .01472 L
.20099 .01472 L
.20342 .01472 L
.20609 .01472 L
.21071 .01472 L
.2133 .01472 L
.21568 .01472 L
.22006 .01472 L
.22466 .01473 L
.22724 .01473 L
.22968 .01473 L
.23423 .01474 L
.23914 .01475 L
.2419 .01476 L
.24444 .01477 L
.2487 .01479 L
.25338 .01483 L
.25826 .01487 L
.26282 .01493 L
.26782 .01501 L
.27326 .01513 L
.27839 .01529 L
.28315 .01549 L
.28742 .01572 L
.29214 .01604 L
.29707 .01648 L
.3017 .017 L
.30639 .01768 L
.31151 .01863 L
.31687 .0199 L
.32186 .0214 L
.3308 .02507 L
.3358 .02782 L
.34035 .03085 L
.35032 .03965 L
.35952 .05105 L
.36961 .06815 L
Mistroke
.3803 .09265 L
.38973 .12053 L
.39985 .15766 L
.41816 .24345 L
.43788 .35619 L
.4594 .48118 L
.46938 .53038 L
.47486 .55308 L
.48001 .57105 L
.48483 .58452 L
.48737 .59021 L
.49004 .59514 L
.4923 .59842 L
.4935 .59982 L
.49478 .60106 L
.49596 .60197 L
.49703 .60259 L
.49811 .60303 L
.49913 .60326 L
.50027 .60332 L
.5015 .60314 L
.50266 .60274 L
.50373 .60217 L
.50491 .60133 L
.5062 .60014 L
.5088 .59693 L
.51137 .59269 L
.51411 .58701 L
.51906 .57392 L
.52871 .53868 L
.53748 .49747 L
.57748 .26699 L
.59582 .17584 L
.60623 .13445 L
.61597 .10294 L
.62556 .07833 L
.63586 .05822 L
.64151 .0496 L
.64686 .04277 L
.65214 .03717 L
.65691 .03295 L
.66653 .02647 L
.67181 .02385 L
.67677 .02187 L
.68562 .01927 L
.6906 .01821 L
.69517 .01744 L
.69989 .01681 L
.70494 .01628 L
.70971 .0159 L
Mistroke
.71405 .01563 L
.71915 .01539 L
.72468 .01519 L
.72991 .01505 L
.73473 .01496 L
.73939 .0149 L
.7444 .01484 L
.74912 .01481 L
.75345 .01478 L
.7585 .01476 L
.76136 .01475 L
.76402 .01475 L
.76888 .01474 L
.7716 .01473 L
.77407 .01473 L
.77894 .01473 L
.7814 .01472 L
.78409 .01472 L
.78639 .01472 L
.78886 .01472 L
.79331 .01472 L
.79599 .01472 L
.7989 .01472 L
.80147 .01472 L
.8042 .01472 L
.80665 .01472 L
.80935 .01472 L
.81413 .01472 L
.81647 .01472 L
.81904 .01472 L
.82154 .01472 L
.82421 .01472 L
.82672 .01472 L
.829 .01472 L
.83346 .01472 L
.83614 .01472 L
.83861 .01472 L
.84132 .01472 L
.84419 .01472 L
.84668 .01472 L
.84901 .01472 L
.85157 .01472 L
.85432 .01472 L
.85686 .01472 L
.85957 .01472 L
.86213 .01472 L
.86444 .01472 L
.86717 .01472 L
.87013 .01472 L
.87292 .01472 L
Mistroke
.87548 .01472 L
.8779 .01472 L
.88015 .01472 L
.88262 .01472 L
.88526 .01472 L
.88804 .01472 L
.89066 .01472 L
.89302 .01472 L
.89558 .01472 L
.89792 .01472 L
.90044 .01472 L
.90282 .01472 L
.905 .01472 L
.90742 .01472 L
.91006 .01472 L
.91282 .01472 L
.91538 .01472 L
.91813 .01472 L
.92071 .01472 L
.92304 .01472 L
.92555 .01472 L
.9283 .01472 L
.9312 .01472 L
.93368 .01472 L
.9364 .01472 L
.93887 .01472 L
.94155 .01472 L
.94409 .01472 L
.94644 .01472 L
.94854 .01472 L
.95087 .01472 L
.95331 .01472 L
.95559 .01472 L
.95811 .01472 L
.96076 .01472 L
.96302 .01472 L
.9655 .01472 L
.96817 .01472 L
.97104 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`008oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM02;ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@12ooooo`Go00001Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Qooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool00ol0003o
k^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo000Sooooo`03
oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Cooooo00?oMgMgoc8b<_oo
ool07oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
047ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0S
ooooo`03ogMgMolb<S;ooooo02;ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool07_ooool001Wooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool05oooool6o`0000Oooooo00?o0000ooooooooool05_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h04Oooool00ol0003oooooooooo`11ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Qooooo`03ojVYZOmEEEGooooo013ooooo00?o0000oooo
ooooool07Oooool002Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0Tooooo`03
ogMgMolb<S;ooooo027ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`13ooooo`03
oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool08oooool00omgMgOo<S8booooo`0Sooooo`03
ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool07_ooool002Cooooo00?oEEEEolc<c?ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c015ooooo`03ogMgMomVIVKo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Qooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
9?ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07oooool002Cooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Vooooo`03ojVYZOmgMgOooooo00_ooooo
00?o0000ooooooooool08Oooool0027ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08_ooool01Ol0003o^[ZjoooooonHV9So410@00co
oooo00?o0000ooooooooool0A?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Sooooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Qooooo`008Oooool5o`0000cooooo1?l0000Sooooo`Co00008Oooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo1?l00013ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0002;ooooo1?l0000Rooooo`Go00003?ooool4o`00023ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo000Hoooooooo0000>?l0000I
ooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool9o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo2?l00007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`00:?ooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo023ooooo1?l00007ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`Go00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02Oooooo001nooooo`;o0000<oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo07gooooo0020ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<?ooool2o`00083ooooo0021ooooo`;o0000<?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo083ooooo0023ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool2o`0008?ooooo0024ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`;o
0000;Oooool00ol0003oooooooooo`23ooooo`00QOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0Q?ooool008Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool008Oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oo
oooo0028ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`28ooooo`00ROooool00ol0003oooooooooo`0Wooooo`;o0000:?ooool00ol0003ooooooooo
o`28ooooo`00R_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0ROooool008_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo08Wooooo002;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`2:ooooo`00S?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool008cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo002=ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2;ooooo`00SOooool00ol0
003oooooooooo`0Sooooo`;o00009?ooool00ol0003oooooooooo`2<ooooo`00SOooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0S?ooool008kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08cooooo
002>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`2=ooooo`00Soooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0SOooool008oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo08gooooo002?ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`2>ooooo`00T?ooool00ol0003oooooooooo`0Pooooo`;o0000
8_ooool00ol0003oooooooooo`2>ooooo`00T?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Soooool0093ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo002Aooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2?ooooo`00TOooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0T?ooool0097ooooo
00?o0000ooooooooool03Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0T?ooool0097ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo093ooooo002Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0ol0000N
ooooo`03o`000?oooooooooo097ooooo002Booooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`2Aooooo`00T_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0TOooool009;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo097ooooo002Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2B
ooooo`00Toooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0T_ooool0
09?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
09;ooooo002Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`2Booooo`00U?ooool00ol0003oooooooooo`0Looooo`;o00007Oooool00ol0003ooooo
ooooo`2Cooooo`00U?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Toooool009Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo09?ooooo002Dooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2Cooooo`00UOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Toooool009Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Dooooo`00UOooool0
0ol0003oooooooooo`0Kooooo`;o00007?ooool00ol0003oooooooooo`2Dooooo`00U_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0U?ooool009Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09Go
oooo002Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0UOooool009Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo09Gooooo002Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2Eooooo`00Uoooool00ol0003oooooooooo`0Iooooo`;o
00006_ooool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09Kooooo002Hooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Fooooo`00V?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool009So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo09Oo
oooo002Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`2Gooooo`00VOooool00ol0003oooooooooo`0Gooooo`;o00006Oooool00ol0003ooooooooo
o`2Gooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Uoooool009Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo09Oooooo002Iooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool00ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool00oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo09Sooooo002Jooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Fooooo`03o`000?oooooooooo09Wo
oooo002Jooooo`03o`000?oooooooooo00Kooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Iooooo`00
Voooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009_ooooo
00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009_o
oooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool0
09_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
09[ooooo002Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`2Jooooo`00Voooool00ol0003oooooooooo`0Eooooo`;o00005_ooool00ol0003ooooo
ooooo`2Jooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0V_ooool009cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo09[ooooo002Looooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`2Kooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Voooool009cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo09_ooooo002Looooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Kooooo`00WOooool0
0ol0003oooooooooo`0Cooooo`;o00005Oooool00ol0003oooooooooo`2Kooooo`00WOooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Voooool009go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09co
oooo002Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`2Looooo`00WOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0W?ooool009kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo09cooooo002Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2Looooo`00W_ooool00ol0003oooooooooo`0Booooo`;o
00005?ooool00ol0003oooooooooo`2Looooo`00W_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0WOooool009kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09gooooo002Nooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Mooooo`00Woooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0WOooool009oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09go
oooo002Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2Mooooo`00Woooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0W_ooool009oooooo00?o0000ooooooooool04Oooool2o`0001;ooooo00?o0000
ooooooooool0W_ooool009oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo09kooooo002Pooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`2Nooooo`00X?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0W_ooool00:3ooooo00Go0000oa0@4?l0003o<S8b
olc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo09kooooo002Pooooo`05o`000?nj^[[oooooogMgMolb<S800oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Ooooo
o`00X?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Woooool00:3ooooo00Go0000oooo
ooooooooZJVYoa0@4003ooooo`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo00?o
0000ooooooooool0Woooool00:7ooooo00Co0000oa0@4?l0003o^[Zj0oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Oooooo`00XOoo
ool01?l0003ooooookZj^_lQ8B43ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo09oooooo002Pooooo`05oa0@4?l0003ooooookZj^_l0
00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`2Oooooo`00X?ooool01OnYZJWo0000o`000?l@413oZJVY00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X?ooool0
0:7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:3ooooo002Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Pooooo`00XOooool00ol0003oooooooooo`0?ooooo`;o00004?ooool00ol0003ooooo
ooooo`2Pooooo`00X_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0X?ooool00:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`2Qooooo`00X_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0XOooool00:;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:7ooooo002Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Qooooo`00Xoooool0
0ol0003oooooooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`2Qooooo`00Xoooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0X_ooool00:?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:;o
oooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2Rooooo`00Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0X_ooool00:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:;ooooo002Sooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2Rooooo`00Y?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0Xoooool00:Cooooo00?o0000ooooooooool0
3?ooool2o`0000gooooo00?o0000ooooooooool0Xoooool00:Cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:?ooooo002Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Sooooo`00Y?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Xoooool00:Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:?o
oooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000
ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0:Cooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Rooooo`;o000000Wo410@
ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0:Gooooo002Sooooo`0:o`000?ooooooooooo`000?ooooooMgMgoiRHV?oooooo
V9RHogMgM`Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`00X?ooool5
o`000004ooooool0003ooooooa0@40?ooooo00?o410@ooooooooool01?ooool3o`0000[ooooo00?o
0000ooooooooool0YOooool00:3ooooo00CoA4A4omgMgOoooooo00000_ooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2Uooooo`00X?ooool01?oMgMgoEEEEooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Gooooo002Q
ooooo`03ogMgMoo<c<co000000?ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Y_ooool00:7ooooo00?ok^k^odA4
A?l000000oooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Vooooo`00X_ooool00omgMgOo0000ooooo`02ooooo`06o`000?o^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo
002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Vooooo`00Yoooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`2V
ooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Yooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00ZOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Wooooo
00?o0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool0Z?ooool00:Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Y
ooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Yooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002/ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002]
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[
ooooo`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0[?ooool00:gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000oooooooo
ool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0:cooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo00000;3ooooo002Qooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo0:kooooo002Tooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002Uoooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@ooooooooooooooooo`000002ooooo`Co0000/Ooo
ool00:Cooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooool0003oooooo`00002booooo`00XOooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`?o0000/oooool00:7ooooo00?o0000ooooooooool0
1?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0/_ooool00:7ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0/_ooool00:7ooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00S?oo
ool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;ooooo03[ooooo00?o
^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomVIVKooooo00Sooooo
00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool00ol0003ooooooooo
o`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`03omgM
gOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001Cooooo`06oa0@4?lQ
8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00;ooooo
00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`00
0008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_ooool01ol0003ooooo
ooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o0000
00KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Kooooo00OoV9RHoa0@
4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool00omEEEGoV9RHoooo
o`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool00on7QhOo0000okZj
^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^05Gooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0oooool01Ol0
003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEE
EOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^
oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGoMgMgooooooo^
k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oooooooooooooo
ool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooook^k^
oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03o`000?oooooo
oooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003ooooo00Gooooo
00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg05Gooooo001Cooooo`06ob4Q8Oooooooooooooooooo^k^ko00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool00oo^k^ko0000ooooo`06ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@
2oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0Cooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000Wooooo00Go410@oooooooooooooooooa0@401E
ooooo`00E?ooool01OoMgMgoV9RHogMgMol@413oIVIV00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Ko0000ooooooooooooooooonk^k_l00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00oo^
k^ko0000ooooo`06ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oo
oooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^1?ooool00ol0003oooooooooo`0Cooooo`06o`00
0?ooooooooooooooool0003ooooo1_l00002ooooo`05o`000?ooooooooooooooool00000EOooool0
05?ooooo00GoIVIVoa0@4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonY
ZJWo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`00
0?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo
00Gooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE
0_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomV
IVKoQhN700[ooooo00?o0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^
k_l0003ooooo01Cooooo00Go0000ohN7QoooooooZJVYo`000009ooooo`05o`000?oooooooooooooo
ool00000EOooool005?ooooo00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo
0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0
003o0000oeEEEOo^k^kooooooa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0
003oMgMg00;o000000[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool0
2ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^
k_oooooo410@1Ol00004ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`00
0?l0003oEEEEonk^kP;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9So
oooooc8b<P;o^[Zj00?o0000ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_oo
ool2o`0000;ooooo00?oMgMgoeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oo
oooooooo00Oooooo00Go410@oooooooooooooooooa0@401Eooooo`00Doooool01_lb<S;oQhN7oooo
ooo^k^koIVIVo`0000?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03
ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@0Sooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0EOooool005?ooooo00Kok^k^odA4A?l0003o0000oc8b<_l@4103
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08
ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`0S
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0EOooool005_ooooo00?o410@o`000?ooool08?ooool0
0ol@413oooooooooo`0]ooooo`03oa0@4?l0003ooooo017ooooo0_l0002Tooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.71045, -4.17515, \
0.0676215, 0.344909}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.30902 0.000199467 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .00982 -30 -4.5 ]
[.4875 .00982 0 4.5 ]
[.4875 .10955 -30 -4.5 ]
[.4875 .10955 0 4.5 ]
[.4875 .20929 -24 -4.5 ]
[.4875 .20929 0 4.5 ]
[.4875 .40875 -18 -4.5 ]
[.4875 .40875 0 4.5 ]
[.4875 .50849 -24 -4.5 ]
[.4875 .50849 0 4.5 ]
[.4875 .60822 -24 -4.5 ]
[.4875 .60822 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .00982 m
.50625 .00982 L
s
[(-1500)] .4875 .00982 1 0 Mshowa
.5 .10955 m
.50625 .10955 L
s
[(-1000)] .4875 .10955 1 0 Mshowa
.5 .20929 m
.50625 .20929 L
s
[(-500)] .4875 .20929 1 0 Mshowa
.5 .40875 m
.50625 .40875 L
s
[(500)] .4875 .40875 1 0 Mshowa
.5 .50849 m
.50625 .50849 L
s
[(1000)] .4875 .50849 1 0 Mshowa
.5 .60822 m
.50625 .60822 L
s
[(1500)] .4875 .60822 1 0 Mshowa
.125 Mabswid
.5 .02977 m
.50375 .02977 L
s
.5 .04971 m
.50375 .04971 L
s
.5 .06966 m
.50375 .06966 L
s
.5 .08961 m
.50375 .08961 L
s
.5 .1295 m
.50375 .1295 L
s
.5 .14945 m
.50375 .14945 L
s
.5 .16939 m
.50375 .16939 L
s
.5 .18934 m
.50375 .18934 L
s
.5 .22923 m
.50375 .22923 L
s
.5 .24918 m
.50375 .24918 L
s
.5 .26913 m
.50375 .26913 L
s
.5 .28907 m
.50375 .28907 L
s
.5 .32897 m
.50375 .32897 L
s
.5 .34891 m
.50375 .34891 L
s
.5 .36886 m
.50375 .36886 L
s
.5 .38881 m
.50375 .38881 L
s
.5 .4287 m
.50375 .4287 L
s
.5 .44865 m
.50375 .44865 L
s
.5 .46859 m
.50375 .46859 L
s
.5 .48854 m
.50375 .48854 L
s
.5 .52843 m
.50375 .52843 L
s
.5 .54838 m
.50375 .54838 L
s
.5 .56833 m
.50375 .56833 L
s
.5 .58827 m
.50375 .58827 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02605 .30902 L
.02846 .30902 L
.03072 .30902 L
.03279 .30902 L
.03521 .30902 L
.03784 .30902 L
.04032 .30902 L
.04262 .30902 L
.04498 .30902 L
.0472 .30902 L
.04963 .30902 L
.05224 .30902 L
.05497 .30902 L
.05757 .30902 L
.0599 .30902 L
.06244 .30902 L
.0653 .30902 L
.06799 .30902 L
.07041 .30902 L
.07302 .30902 L
.07588 .30902 L
.07889 .30902 L
.08147 .30902 L
.08429 .30902 L
.08694 .30902 L
.08936 .30902 L
.09215 .30902 L
.09479 .30902 L
.09722 .30902 L
.09948 .30902 L
.10195 .30902 L
.10458 .30902 L
.10696 .30902 L
.10947 .30902 L
.11161 .30902 L
.11395 .30902 L
.11648 .30902 L
.11918 .30902 L
.12173 .30902 L
.12405 .30902 L
.12856 .30902 L
.13111 .30902 L
.13345 .30902 L
.13777 .30902 L
.13994 .30902 L
.14233 .30902 L
.14482 .30902 L
.14754 .30902 L
.15011 .30902 L
Mistroke
.15249 .30902 L
.15699 .30902 L
.1595 .30902 L
.16178 .30902 L
.16695 .30902 L
.16987 .30902 L
.17254 .30902 L
.17747 .30902 L
.17995 .30902 L
.18267 .30902 L
.18519 .30902 L
.18793 .30902 L
.19034 .30902 L
.1929 .30902 L
.19521 .30901 L
.19774 .30901 L
.20222 .30901 L
.20493 .30901 L
.20742 .30901 L
.2101 .309 L
.21302 .309 L
.21796 .30899 L
.22065 .30898 L
.22315 .30897 L
.22821 .30895 L
.23107 .30894 L
.2337 .30892 L
.23853 .30888 L
.24364 .30882 L
.24823 .30875 L
.25251 .30866 L
.2572 .30854 L
.26224 .30835 L
.26752 .3081 L
.2724 .30778 L
.27776 .30732 L
.28346 .30666 L
.28839 .30591 L
.29302 .30503 L
.29809 .3038 L
.30357 .30211 L
.31313 .29799 L
.31855 .29483 L
.32359 .29122 L
.33378 .28156 L
.34468 .26695 L
.35491 .24839 L
.366 .22234 L
.38615 .16003 L
.40561 .09017 L
Mistroke
.41593 .05623 L
.42162 .0405 L
.42703 .02842 L
.42949 .02403 L
.43211 .02022 L
.43362 .01845 L
.43499 .01712 L
.43636 .01608 L
.43765 .01535 L
.43884 .01492 L
.44008 .01472 L
.44115 .01474 L
.44232 .01499 L
.44358 .01552 L
.44429 .01593 L
.44493 .01639 L
.44611 .01742 L
.44737 .01878 L
.4498 .02225 L
.45205 .02644 L
.45714 .03942 L
.46155 .05458 L
.4664 .07546 L
.47651 .13185 L
.48576 .19624 L
.50663 .36271 L
.51656 .4389 L
.52717 .50859 L
.53232 .53638 L
.53718 .5584 L
.54151 .57437 L
.54397 .58188 L
.54627 .58786 L
.54869 .59308 L
.5509 .59689 L
.55326 .59997 L
.55456 .60124 L
.55579 .60216 L
.55685 .60273 L
.55797 .60314 L
.55903 .60332 L
.55999 .60332 L
.56113 .60313 L
.56235 .60268 L
.56351 .60205 L
.56457 .60128 L
.56695 .59896 L
.56918 .59606 L
.57422 .58711 L
.57914 .5756 L
Mistroke
.5844 .56081 L
.60426 .49232 L
.62583 .41883 L
.6359 .39078 L
.64658 .36663 L
.6557 .35049 L
.66575 .33701 L
.67094 .33157 L
.67588 .32724 L
.68515 .32098 L
.69032 .31837 L
.69513 .3164 L
.70036 .31468 L
.70602 .31322 L
.71152 .31214 L
.71659 .31137 L
.72142 .3108 L
.72654 .31034 L
.73112 .31002 L
.73541 .30979 L
.7401 .30959 L
.74514 .30943 L
.75042 .30931 L
.75531 .30923 L
.76067 .30917 L
.76338 .30914 L
.76637 .30912 L
.77136 .30909 L
.77417 .30908 L
.77675 .30907 L
.78149 .30905 L
.78406 .30905 L
.78649 .30904 L
.78889 .30904 L
.79149 .30903 L
.79603 .30903 L
.7986 .30903 L
.80133 .30903 L
.80369 .30903 L
.80622 .30902 L
.80858 .30902 L
.81074 .30902 L
.81497 .30902 L
.81733 .30902 L
.8199 .30902 L
.82459 .30902 L
.82715 .30902 L
.82991 .30902 L
.83235 .30902 L
.83493 .30902 L
Mistroke
.83725 .30902 L
.8398 .30902 L
.84429 .30902 L
.84703 .30902 L
.84953 .30902 L
.85242 .30902 L
.85515 .30902 L
.85767 .30902 L
.86 .30902 L
.86256 .30902 L
.86527 .30902 L
.86766 .30902 L
.87017 .30902 L
.87234 .30902 L
.87466 .30902 L
.87717 .30902 L
.87949 .30902 L
.88226 .30902 L
.88477 .30902 L
.88713 .30902 L
.88929 .30902 L
.89167 .30902 L
.89419 .30902 L
.89637 .30902 L
.89842 .30902 L
.90066 .30902 L
.90306 .30902 L
.90562 .30902 L
.90833 .30902 L
.91065 .30902 L
.91321 .30902 L
.91595 .30902 L
.91891 .30902 L
.9217 .30902 L
.92427 .30902 L
.92669 .30902 L
.92894 .30902 L
.93141 .30902 L
.93406 .30902 L
.93684 .30902 L
.93946 .30902 L
.94182 .30902 L
.94438 .30902 L
.94621 .30902 L
.94817 .30902 L
.94987 .30902 L
.95173 .30902 L
.9539 .30902 L
.95596 .30902 L
.95796 .30902 L
Mistroke
.95982 .30902 L
.96196 .30902 L
.96398 .30902 L
.96579 .30902 L
.96775 .30902 L
.96988 .30902 L
.97214 .30902 L
.97407 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00TOooool4o`000005oa0@4?oooooooooooooooom4
A4@00_l000002Olb<S;ogMgMooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2booooo`00Toooool00ol0003ooooooooo
o`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0;;ooooo0028ooooo`Ko00001Oooool00ol0
003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo0ol0002booooo`00Toooool00ol0003ooooooooo
o`03ooooo`06o`000?lQ8B7o0000oc8b<_o<c<cooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`000005oa0@4?l0003o0000oooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0/_ooool0
09?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`000006oooooomgMgOo
V9RHo`000?nHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0/_ooool0097ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o
0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2boooo
o`00W?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0/_ooool009_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`;o0000
/oooool009_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo0;;ooooo002Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2booooo`00V_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0/_ooool009[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0;;ooooo002Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2booooo`00VOooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/_ooool009Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`;o0000/oooool009Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;;ooooo002Hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2booooo`00
V?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
/_ooool009Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;;ooooo002Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2booooo`00Uoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Sooooo0_l0002cooooo`00U_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0/_ooool009Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0;;ooooo002Fooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2booooo`00UOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/_ooool009Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0;;ooooo002Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2booooo`00
U?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo0_l0002cooooo`00U?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_oo
ool009Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0;;ooooo002Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2booooo`00TOooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So0000
oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00R?ooool6o`0000Cooooo0_l00004oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@ooooool0003ooooooa0@4006ooooo`?o0000/_ooool009;ooooo0_l00004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0
003oooooo`000006ooooo`03o`000?oooooooooo0;;ooooo002Booooo`;o00001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
0000ooooool000001_ooool00ol0003oooooooooo`2booooo`00T_ooool2o`0000Cooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
o`000?oooooo410@00Kooooo00?o0000ooooooooool0/_ooool0097ooooo00?o0000ooooool00000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9So0000oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00TOooool00ol0
003oIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o0000onk^kP06ooooo`03o`000?oooooooooo0;;ooooo
002Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool2o`000;?ooooo002A
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00T?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0/_ooool0093ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0;;ooooo002@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2booooo`00Soooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0/_ooool008oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01?ooool2o`000;?ooooo002?ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`00S_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo002>
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2b
ooooo`00S_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0/_ooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`;o
0000/oooool008gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0;;ooooo002=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2booooo`00S?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0;;ooooo002<ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00Roooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/_ooool008_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`;o0000/oooool008_ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo002;oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2boooo
o`00R_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0/_ooool008[ooooo00?o0000ooooooooool03?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
0004ooooo`03o`000?oooooooooo0;;ooooo002:ooooo`03o`000?oooooooooo00oooooo00WoMgMg
oc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01omgMgOoV9RHoooooonHV9SoMgMg
ooooool000001?ooool00ol0003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`04oooo
o`Ko00001oooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool00ol@413oooooo`000004ooooo`?o0000/_ooool008Wooooo00?o0000ooooooooool04?ooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0/_ooool008Wooooo00?o0000ooooooooool0
3Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo00000;Cooooo0028
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`05o`000?ooooooooooooooool0
0000]?ooool008Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00Go0000oooo
ooooooooooooo`00002dooooo`00R?ooool00ol0003oooooooooo`0>ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`05o`000?oo
ooooooooooooool00000]?ooool008Oooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooo
oooooooo00000;Cooooo0027ooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooooooo
0_l0002cooooo`00Q_ooool00ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000
]?ooool008Kooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0002dooooo`00Q_oo
ool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`000;Cooooo0025ooooo`03o`000?oo
oooooooo02Sooooo00Co0000oooooooooooo0000]?ooool008Gooooo00?o0000ooooooooool0:?oo
ool01?l0003oooooooooool0002dooooo`00Q?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00;o0000/oooool008Cooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0
002dooooo`00Poooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`000;Cooooo0023
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooool00000]?ooool008;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooo`00002dooooo`00P_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooo00000;Cooooo000Nooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02;ooooo1_l00004oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo00?o0000ooooool000009?ooool5
o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`00
0?lb<S;ogMgM02Cooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Jooooo`007_ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0Uooooo`03ogMgMolb<S;ooooo027ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Nooooo`04o`000?oooooo0000o`0002?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMgMolb
<S;ooooo02?ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06Ooo
ool001Cooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06?ooool6
o`0000Oooooo00?o0000ooooooooool06?ooool6o`0000?ooooo00CoV9RHob4Q8Oo^k^ko00004?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002Gooooo00?oV9RHob4Q8Oo^k^h04Ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0Hooooo`007oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool08oooool00onHV9So0000onk^kP0?ooooo`03ogMgMolb<S;o
oooo01kooooo00?o0000ooooool000009_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;o
oooo02Gooooo00?oMgMgoc8b<_ooool09?ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;o
oooo01Wooooo000Oooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00S
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool00ol0003oMgMgofIVIP0<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`07oooool00ol0003oooooo`00000Wooooo`03ogMgMomVIVKooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Sooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool001oooooo00?oZJVYogMg
Moooool02oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0Rooooo`;o0000:?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09oooool00onYZJWoMgMgooooo`0;
ooooo`03o`000?oooooooooo01cooooo000Looooo`05oa0@4?oooooooooooooooolb<S803?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`000?oooooooooo02;ooooo0_l0000Tooooo`05o`000?nj^[[ooooooiRHV?l@4100
3?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00Go410@oooooooooooo
oooooc8b<P0<ooooo`03o`000?oooooooooo01cooooo000Looooo`Go00003?ooool4o`0002Cooooo
1?l0000Rooooo`06o`000?nHV9So410@o`000?lQ8B7oc<c<3?ooool4o`00027ooooo0ol0000Soooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0002Cooooo1?l0000Sooooo`Go00003?ooool4
o`0001_ooooo001iooooo`;o0000=oooool2o`000;Cooooo001hooooo`03o`000?oooooooooo03Oo
oooo0_l0002dooooo`00MOooool3o`0003[ooooo0_l0002dooooo`00Loooool2o`0003gooooo0_l0
002dooooo`00L?ooool3o`0003oooooo0_l0002dooooo`00FOoooolGo`0004?ooooo00?o0000oooo
ooooool0/_ooool0017oooooool00016o`0001;ooooo000Iooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool5o`0000Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Sooooo000Sooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08_ooool00;?ooooo00?o0000ooooooooool0>?ooool4o`0007Kooooo002coooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0N?ooool00;?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1iooooo`00/oooool2o`0003Kooooo00?o0000ooooooooool0
N_ooool00;?ooooo0_l0000eooooo`03o`000?oooooooooo07_ooooo002cooooo`;o0000=Oooool0
0ol0003oooooooooo`1kooooo`00/oooool2o`0003Cooooo00?o0000ooooooooool0O?ooool00;?o
oooo0_l0000cooooo`03o`000?oooooooooo07gooooo002cooooo`;o0000<_ooool00ol0003ooooo
ooooo`1nooooo`00/oooool2o`00037ooooo00?o0000ooooooooool0Ooooool00;?ooooo0_l0000`
ooooo`03o`000?oooooooooo083ooooo002cooooo`03o`000?oooooo000002oooooo00?o0000oooo
ooooool0P?ooool00;?ooooo00?o0000ooooool00000;_ooool00ol0003oooooooooo`21ooooo`00
/oooool00ol0003oooooo`00000]ooooo`03o`000?oooooooooo08;ooooo002cooooo`03o`000?oo
oooo000002gooooo00?o0000ooooooooool0P_ooool00;?ooooo00?o0000ooooool00000;?ooool0
0ol0003oooooooooo`23ooooo`00/oooool3o`0002cooooo00?o0000ooooooooool0Poooool00;?o
oooo00?o0000ooooool00000:oooool00ol0003oooooooooo`24ooooo`00/oooool00ol0003ooooo
o`00000[ooooo`03o`000?oooooooooo08Cooooo002cooooo`04o`000?ooooooooooo`0002[ooooo
00?o0000ooooooooool0Q?ooool00;?ooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooo
ooooo`25ooooo`00/oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo08Gooooo
002cooooo`;o000000?oooooo`000?ooool0:?ooool00ol0003oooooooooo`25ooooo`00/oooool0
1?l0003oooooooooool0000Xooooo`03o`000?oooooooooo08Kooooo002cooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool0Q_ooool00;?ooooo00Co0000oooooooooooo00009ooo
ool00ol0003oooooooooo`27ooooo`00VOooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003o
ooooooooool0000Wooooo`03o`000?oooooooooo08Oooooo002Looooo`09ogMgMolb<S;ooooooooo
oomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`05o`00
0?ooooooooooooooool000009_ooool00ol0003oooooooooo`27ooooo`00WOooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`28ooooo`00W?ooool01Omg
MgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Cooooo0ol000000ooooooo0000ooooo`0Tooooo`03o`000?oooooooooo08Sooooo002I
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000009Oooool00ol0
003oooooooooo`28ooooo`00VOooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00Go0000ooooooooooooooooo`00
000Tooooo`03o`000?oooooooooo08Wooooo002Iooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool0ROooool009Wooooo1?l00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Go0000oooo
ooooooooooooo`00000Tooooo`03o`000?oooooooooo08Wooooo002cooooo`05o`000?oooooooooo
ooooool000009?ooool00ol0003oooooooooo`29ooooo`00/oooool2o`0000;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`2:ooooo`00/oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0R_ooool00;?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08[ooooo002cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2;ooooo`00/oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Roooool0
0;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
08_ooooo002cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`2;ooooo`00/oooool2o`0000?ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2<ooooo`00/oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0S?ooool00;?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo08cooooo002cooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`2=ooooo`00/oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0SOooool00;?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo08gooooo002cooooo`;o00001Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08kooooo002cooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2>ooooo`00/oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0S_ooool00;?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08ko
oooo002cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2?ooooo`00/oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0Soooool00;?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo08oooooo002cooooo`;o00001_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo093ooooo002cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`2@ooooo`00/oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0T?ooool00;?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo093ooooo002Aooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0TOooool009?ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0TOooool009?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Aoooo
o`00Toooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`2Booooo`00Toooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`2Cooooo`00TOooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2Cooooo`00/oooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`2Cooooo`00/oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0U?ooool00;?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo09Cooooo002cooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2Dooooo`00/oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0UOooool00;?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09Gooooo002cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Eooooo`00/ooo
ool2o`0000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Fooooo`00/oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0U_ooool0
0;?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
09Kooooo002cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2Gooooo`00/oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Uoooool00;?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo09Oooooo002cooooo`;o00002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo09Oooooo002cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`2Hooooo`00/oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0V?ooool00;?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09Sooooo002cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Hooooo`00/oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0VOooool0
0;?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
09[ooooo002cooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09[o
oooo002cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2Kooooo`00/oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0W?ooool00;?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09cooooo002Aooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000o`00002Ooooo
o`00Toooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oooooo
0ol0002Pooooo`00Toooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo0ol0002booooo`00
Toooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2boooo
o`00Toooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0;;ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2kooooo`00
TOooool00omEEEGoIVIVo`000005ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP2kooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;o
oooo03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomV
IVKooooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool0
0ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001C
ooooo`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004
oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^
k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000
o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_oo
ool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05
oiRHV?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?oooooo
k^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Ko
oooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool0
0omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool0
0on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01ooo
ool4o`000003oa0@4?oooooooooo05;ooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2
ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003o
oooo00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko0000
1Oooool00ol0003oooooooooo`1Dooooo`00Doooool01_lQ8B7oooooooooooooooook^k^o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40_ooooo00?o<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo05Cooooo001D
ooooo`05omgMgOnHV9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000005o`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003o
oooo00Kooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Gooooo00?o0000ooooooooool0E?ooool005?ooooo00GoIVIVoa0@
4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko
EEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooo
ooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMg
MoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMg
ooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o
0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo
00Go0000ohN7QoooooooZJVYo`00000<ooooo`03o`000?oooooooooo05Cooooo001Cooooo`06o`00
0?o^k^koooooooooooo<c<co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^
oeEEEOl0003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105
o`0000Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?oooooo
ooooonk^k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40?ooooo00_o410@o`000?lQ8B7o0000ogMgMol@
413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00001?ooool01Ol0
003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06onk^
k_mEEEGo0000oa0@4?o<c<co00001oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooo
oooo00Sooooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomEEEGo
oooo01?ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`0:ooooo`03o`000?oooooo
oooo05Cooooo001Cooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00000oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Sooooo00?oIVIVohN7Qoooool02oooool00ooMgMgo410@onk^
kP09ooooo`03onk^k_l@413ogMgM02Kooooo00?o0000ooooooooool0E?ooool005?ooooo00Kok^k^
odA4A?l0003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool0
2?ooool00omVIVKoMgMgooooo`0Tooooo`03oeEEEOmVIVKo000005Kooooo001Kooooo`03oa0@4?l0
003ooooo023ooooo00?o410@ooooooooool0;Oooool00ol@413o0000ooooo`0Aooooo`;o0000Y?oo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.32419, -1587.21, \
0.0649317, 19.3766}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.289 2.4686e-05 [
[.05357 .2765 -12 -9 ]
[.05357 .2765 12 0 ]
[.20238 .2765 -6 -9 ]
[.20238 .2765 6 0 ]
[.35119 .2765 -12 -9 ]
[.35119 .2765 12 0 ]
[.64881 .2765 -9 -9 ]
[.64881 .2765 9 0 ]
[.79762 .2765 -3 -9 ]
[.79762 .2765 3 0 ]
[.94643 .2765 -9 -9 ]
[.94643 .2765 9 0 ]
[.4875 .04214 -36 -4.5 ]
[.4875 .04214 0 4.5 ]
[.4875 .16557 -30 -4.5 ]
[.4875 .16557 0 4.5 ]
[.4875 .41243 -24 -4.5 ]
[.4875 .41243 0 4.5 ]
[.4875 .53586 -30 -4.5 ]
[.4875 .53586 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .289 m
.05357 .29525 L
s
[(-7.5)] .05357 .2765 0 1 Mshowa
.20238 .289 m
.20238 .29525 L
s
[(-5)] .20238 .2765 0 1 Mshowa
.35119 .289 m
.35119 .29525 L
s
[(-2.5)] .35119 .2765 0 1 Mshowa
.64881 .289 m
.64881 .29525 L
s
[(2.5)] .64881 .2765 0 1 Mshowa
.79762 .289 m
.79762 .29525 L
s
[(5)] .79762 .2765 0 1 Mshowa
.94643 .289 m
.94643 .29525 L
s
[(7.5)] .94643 .2765 0 1 Mshowa
.125 Mabswid
.08333 .289 m
.08333 .29275 L
s
.1131 .289 m
.1131 .29275 L
s
.14286 .289 m
.14286 .29275 L
s
.17262 .289 m
.17262 .29275 L
s
.23214 .289 m
.23214 .29275 L
s
.2619 .289 m
.2619 .29275 L
s
.29167 .289 m
.29167 .29275 L
s
.32143 .289 m
.32143 .29275 L
s
.38095 .289 m
.38095 .29275 L
s
.41071 .289 m
.41071 .29275 L
s
.44048 .289 m
.44048 .29275 L
s
.47024 .289 m
.47024 .29275 L
s
.52976 .289 m
.52976 .29275 L
s
.55952 .289 m
.55952 .29275 L
s
.58929 .289 m
.58929 .29275 L
s
.61905 .289 m
.61905 .29275 L
s
.67857 .289 m
.67857 .29275 L
s
.70833 .289 m
.70833 .29275 L
s
.7381 .289 m
.7381 .29275 L
s
.76786 .289 m
.76786 .29275 L
s
.82738 .289 m
.82738 .29275 L
s
.85714 .289 m
.85714 .29275 L
s
.8869 .289 m
.8869 .29275 L
s
.91667 .289 m
.91667 .29275 L
s
.02381 .289 m
.02381 .29275 L
s
.97619 .289 m
.97619 .29275 L
s
.25 Mabswid
0 .289 m
1 .289 L
s
.5 .04214 m
.50625 .04214 L
s
[(-10000)] .4875 .04214 1 0 Mshowa
.5 .16557 m
.50625 .16557 L
s
[(-5000)] .4875 .16557 1 0 Mshowa
.5 .41243 m
.50625 .41243 L
s
[(5000)] .4875 .41243 1 0 Mshowa
.5 .53586 m
.50625 .53586 L
s
[(10000)] .4875 .53586 1 0 Mshowa
.125 Mabswid
.5 .06683 m
.50375 .06683 L
s
.5 .09151 m
.50375 .09151 L
s
.5 .1162 m
.50375 .1162 L
s
.5 .14088 m
.50375 .14088 L
s
.5 .19026 m
.50375 .19026 L
s
.5 .21494 m
.50375 .21494 L
s
.5 .23963 m
.50375 .23963 L
s
.5 .26431 m
.50375 .26431 L
s
.5 .31369 m
.50375 .31369 L
s
.5 .33837 m
.50375 .33837 L
s
.5 .36306 m
.50375 .36306 L
s
.5 .38774 m
.50375 .38774 L
s
.5 .43712 m
.50375 .43712 L
s
.5 .4618 m
.50375 .4618 L
s
.5 .48649 m
.50375 .48649 L
s
.5 .51117 m
.50375 .51117 L
s
.5 .01745 m
.50375 .01745 L
s
.5 .56055 m
.50375 .56055 L
s
.5 .58523 m
.50375 .58523 L
s
.5 .60992 m
.50375 .60992 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .289 m
.02605 .289 L
.02846 .289 L
.03072 .289 L
.03279 .289 L
.03521 .289 L
.03784 .289 L
.04032 .289 L
.04262 .289 L
.04498 .289 L
.0472 .289 L
.04963 .289 L
.05224 .289 L
.05497 .289 L
.05757 .289 L
.0599 .289 L
.06244 .289 L
.0653 .289 L
.06799 .289 L
.07041 .289 L
.07302 .289 L
.07588 .289 L
.07889 .289 L
.08147 .289 L
.08429 .289 L
.08694 .289 L
.08936 .289 L
.09215 .289 L
.09479 .289 L
.09722 .289 L
.09948 .289 L
.10195 .289 L
.10458 .289 L
.10696 .289 L
.10947 .289 L
.11161 .289 L
.11395 .289 L
.11648 .289 L
.11918 .289 L
.12173 .289 L
.12405 .289 L
.12856 .289 L
.13111 .289 L
.13345 .289 L
.13777 .289 L
.13994 .289 L
.14233 .289 L
.14482 .289 L
.14754 .289 L
.15011 .289 L
Mistroke
.15249 .289 L
.15699 .289 L
.1595 .289 L
.16178 .289 L
.16695 .289 L
.16987 .289 L
.17254 .289 L
.17747 .28901 L
.17995 .28901 L
.18267 .28901 L
.18519 .28901 L
.18793 .28902 L
.19034 .28902 L
.1929 .28902 L
.19774 .28903 L
.20222 .28905 L
.20469 .28906 L
.20736 .28907 L
.21217 .2891 L
.21497 .28913 L
.2179 .28916 L
.22315 .28923 L
.22816 .28933 L
.23272 .28945 L
.23797 .28964 L
.24293 .28989 L
.24752 .29019 L
.25175 .29055 L
.2564 .29106 L
.26131 .29175 L
.26625 .29267 L
.27077 .29373 L
.27598 .2953 L
.28092 .29719 L
.28969 .3018 L
.29465 .30529 L
.29925 .30921 L
.30886 .32003 L
.31789 .33409 L
.32779 .35472 L
.33848 .38382 L
.3585 .4565 L
.36869 .4992 L
.37959 .54368 L
.3849 .56299 L
.38992 .57871 L
.39442 .59008 L
.39674 .59474 L
.39931 .59879 L
.40046 .60022 L
Mistroke
.4017 .60147 L
.40287 .60236 L
.40394 .60294 L
.40515 .60329 L
.40646 .60331 L
.4077 .60298 L
.40885 .60235 L
.41001 .60141 L
.41109 .60024 L
.41312 .59727 L
.4153 .59293 L
.41766 .58686 L
.42259 .56956 L
.42718 .5477 L
.43762 .47854 L
.45869 .28111 L
.46773 .19136 L
.47734 .10783 L
.48235 .07268 L
.48501 .05698 L
.48787 .04264 L
.4905 .03198 L
.4929 .0244 L
.4952 .01915 L
.49635 .01727 L
.49762 .0158 L
.49831 .01526 L
.49905 .01488 L
.49976 .01472 L
.50041 .01474 L
.50164 .01522 L
.50294 .01638 L
.50362 .01723 L
.50434 .01834 L
.50565 .02086 L
.50863 .02898 L
.51138 .03935 L
.51398 .05162 L
.51887 .08059 L
.5285 .15658 L
.539 .25767 L
.55001 .36838 L
.56037 .4624 L
.56967 .5296 L
.57491 .55831 L
.57723 .56879 L
.57971 .57844 L
.58218 .58642 L
.58443 .59231 L
.58669 .59693 L
Mistroke
.58882 .60013 L
.59003 .60144 L
.59131 .60246 L
.5924 .60302 L
.5936 .60332 L
.59489 .60328 L
.59562 .6031 L
.59628 .60284 L
.59757 .60206 L
.5988 .601 L
.60121 .59807 L
.60378 .59376 L
.60841 .58326 L
.61392 .56693 L
.61892 .54934 L
.63977 .46361 L
.64892 .42716 L
.65897 .39182 L
.66801 .36527 L
.67771 .34255 L
.68795 .32454 L
.69751 .31244 L
.70279 .30738 L
.70768 .30356 L
.71293 .30023 L
.71874 .29733 L
.72377 .29538 L
.72849 .29393 L
.73348 .29272 L
.73886 .29173 L
.74381 .29103 L
.74842 .29053 L
.75348 .29012 L
.75889 .28979 L
.76457 .28954 L
.76994 .28938 L
.77476 .28927 L
.77999 .28919 L
.78487 .28913 L
.78944 .28909 L
.79446 .28906 L
.79728 .28905 L
.79985 .28904 L
.80501 .28903 L
.80794 .28902 L
.81064 .28902 L
.81561 .28901 L
.81838 .28901 L
.82089 .28901 L
.82578 .289 L
Mistroke
.82824 .289 L
.83094 .289 L
.83324 .289 L
.83571 .289 L
.84017 .289 L
.84285 .289 L
.84577 .289 L
.84852 .289 L
.85107 .289 L
.85589 .289 L
.85832 .289 L
.861 .289 L
.86355 .289 L
.86593 .289 L
.8684 .289 L
.87111 .289 L
.87559 .289 L
.8781 .289 L
.88037 .289 L
.88306 .289 L
.88553 .289 L
.88824 .289 L
.89111 .289 L
.89361 .289 L
.89594 .289 L
.8985 .289 L
.90124 .289 L
.9038 .289 L
.90651 .289 L
.90883 .289 L
.91139 .289 L
.91413 .289 L
.91709 .289 L
.91988 .289 L
.92245 .289 L
.92487 .289 L
.92712 .289 L
.92959 .289 L
.93224 .289 L
.93502 .289 L
.93764 .289 L
.94 .289 L
.94256 .289 L
.94449 .289 L
.94657 .289 L
.94837 .289 L
.95033 .289 L
.95262 .289 L
.9548 .289 L
.95692 .289 L
Mistroke
.95889 .289 L
.96115 .289 L
.96328 .289 L
.96519 .289 L
.96726 .289 L
.96952 .289 L
.97191 .289 L
.97395 .289 L
.97619 .289 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/_ooool3o`000;?ooooo002aooooo`Co0000/oooool00;7ooooo00Go0000ooooool0
003oooooo`00002booooo`00/Oooool01Ol0003oooooo`000?oooooo00000;;ooooo002aooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool0[oooool00;3ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`2_ooooo`00ROooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0[oooool008_ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`2^ooooo`00P?ooool6o`0000Gooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002;ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0[oooool008_ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0:kooooo002;oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2]oooo
o`00Roooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`07ogMgMonH
V9SooooooiRHV?mgMgOoooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0[Oooool008Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:gooooo002^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2]ooooo`00[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0[Oooool00:kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:gooooo002]ooooo`03o`000?oooooooooo00?o
oooo0_l00003ooooo`03o`000?oooooooooo0:gooooo002]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2/ooooo`00[Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[?ooool00:gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:cooooo002]oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2/oooo
o`00[Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0[?ooool00:gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0:cooooo002]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2/ooooo`00[?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool0
0ol0003oooooooooo`2/ooooo`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0[?ooool00:cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[ooooo`00[?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Zoooool00:cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:_ooooo002/oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2[oooo
o`00[?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Zoooool00:cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
Zoooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:_ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Zooooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002[ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Zoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool00:_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo002Zoooo
o`03o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooooooo0:[ooooo002Zooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00
Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ZOooool00:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0:Wooooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Yooooo`00Z_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0ZOooool0097ooooo00GoA4A4o`000?l0003o<S8bomgMg@02oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
ZOooool009Cooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ZOooool008Sooooo1_l00007ooooo`04o`000?oooooo
oooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`06oa0@4?ooooooooooooooool@
413o00000_ooool00ol@413oooooooooo`04ooooo`?o00001_ooool00ol0003oooooooooo`2Yoooo
o`00U?ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0ZOooool0097ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Xooooo`00TOooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`000?oooooooooooa0@4006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool0097ooooo00?o0000oooo
ooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0:Sooooo002Aooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Xooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Xooooo`00Z?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Z?ooool00:Sooooo00?o
0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0Z?ooool00:Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Sooooo002Xoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Woooo
o`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Yoooool00:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0:Oooooo002Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2Wooooo`00Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Yoooool00:Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0:Oooooo002Wooooo`03o`000?oooooooooo00Wo
oooo0_l00009ooooo`03o`000?oooooooooo0:Oooooo002Wooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Wooooo`00Yoooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Yoooool00:Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Woooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Voooo
o`00Yoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Y_ooool00:Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0:Kooooo002Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Vooooo`00Y_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Y_ooool00:Kooooo00?o0000ooooooooool02_ooool2o`00
00[ooooo00?o0000ooooooooool0Y_ooool00:Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:Kooooo002Vooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Uooooo`007?ooool00ol0003ok^k^oooo
o`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Rooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Sooooo`05odA4A?l0003o
0000oc8b<_oMgMd09Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM01Sooooo000Looooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo02Kooooo00?oMgMgoc8b<_ooool08Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMgMolb<S;ooooo02Cooooo00?oEEEEojVYZOoo
ool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool001;ooooo1_l00004ooooo`03ojVY
ZOmEEEGooooo013ooooo00?o0000ooooooooool06Oooool6o`0000Oooooo00?o0000ooooooooool0
6?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03ojVY
ZOmEEEGooooo013ooooo00?o0000ooooooooool05_ooool001gooooo00?o8B4Qooooooooool03_oo
ool00omgMgOo<S8booooo`0Vooooo`03ogMgMolb<S;ooooo02?ooooo00?oV9RHob4Q8Oo^k^h03ooo
ool00omgMgOo<S8booooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Hooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool09Ooo
ool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05ooo
ool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Uooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Iooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Soooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`09_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06?ooool001gooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?oZJVY
ogMgMoooool02oooool00ol0003oooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`05o`000?nj^[[ooooooiRHV?l@4100
3?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooooooo
oooooc8b<P0<ooooo`03o`000?oooooooooo01[ooooo000Jooooo`Go00003?ooool4o`0002Gooooo
1?l0000Sooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0001Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00009?ooool4o`0002Cooooo1Ol0000<ooooo`Co00006Oooool00:Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:Go
oooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2Tooooo`00YOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Y?ooool00:Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0:Cooooo002Uooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2Tooooo`003oooooooo`0004[o00004?ooool001Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`Go00001Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo1Ol00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Eooooo`?o00005Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo0ol0000Gooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool08?ooool006gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0=?ooool2o`0006kooooo
001^ooooo`;o0000=?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`1^ooooo`00L?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo06oooooo001aooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0L?ooool0077ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1aooooo`00
L_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0LOooool007?ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`1booooo`00M?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo07?ooooo001dooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0M?ooool007Go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1dooooo`00M_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo07Gooooo001gooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0M_ooool007Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1f
ooooo`00N?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo0_l0000=oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Moooool007Sooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1hooooo`00NOooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo07Sooooo001jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0NOoo
ool007[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1iooooo`00Noooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Wooooo001kooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0N_ooool007_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1jooooo`00O?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo0_l0
000>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0N_ooool007cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1kooooo`00O?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo07_ooooo001mooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0O?ooool007gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1looooo`00OOoo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07cooooo001nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1mooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00ko
oooo0_l0000?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0OOooool007kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1nooooo`00Ooooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0O_ooool007oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1ooooo
o`00P?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`00
0?oooooooooo00kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1oooooo`00P?ooool00ol0003oooooooooo`0Aooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0Ooooool0083ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool@4103
ooooo`06oa0@4?ooooooooooooooool@413o00000_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool3o`0000oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`0@ooooo`05ogMgMolb<S;oooooooooool0
00000oooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oooooooooo00gooooo00Go0000ob4Q
8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo083ooooo0021ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@o`000?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0P?ooool008;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOo0000oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`21ooooo`00P_ooool00ol0003oooooooooo`0<ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0POooool008;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`21ooooo`00Pooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo087ooooo0023ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04?ooool2o`00017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`22ooooo`00Poooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
08;ooooo0023ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0P_ooool008Cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`22ooooo`00Q?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo08?ooooo0024ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Poooool008Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`23oooo
o`00QOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08?ooooo0025ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool04?ooool2o`0001;ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`24ooooo`00QOooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo08Cooooo0026ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Q?ooool0
08Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`24ooooo`00Q_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo08Gooooo0026ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0QOooool008Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`25ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo0027oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04Oooool2o`0001?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`26ooooo`00Qoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo08Kooooo0027ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Q_ooool008Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26ooooo`00R?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo0028ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0Qoooool008Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`27ooooo`00R?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Oooooo
0029ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool2o`0001Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`28ooooo`00ROooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo08Sooooo0029ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0R?ooool008[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`28ooooo`00
R_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Wooooo002:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0ROooool008Wooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ROooool008_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
o`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
08Wooooo002;ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`2:ooooo`00Roooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3o`0001Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`0000?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2:ooooo`00Roooool2o`00
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Soooooo`000?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2;ooooo`00
ROooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0Roooool008cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`2;ooooo`00SOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08cooooo002=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0S?ooool008gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Fooooo`;o00005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo08cooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
SOooool008kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2=ooooo`00S_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo08gooooo002>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0S_ooool008oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2>ooooo`00Soooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08kooooo
002?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Soooool0093ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`;o00006Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo08oooooo002@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0T?ooool0093ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`00
TOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo093ooooo002Booooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0TOooool009;ooooo1Ol0000Looooo`03o`000?oooooo
oooo01[ooooo0_l000000ooooooo0000ooooo`2Cooooo`00U?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Toooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?oooo
o`03ogMgMolb<S;ooooo03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008
ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1d
ooooo`00T?ooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`05ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2
oc8b<WGooooo001Cooooo`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`00
0?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2
o`000003oeEEEOo^k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_oo
ool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004
ooooo`;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zj
ooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`00
0004oa0@4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRH
V?l0003o410@00Kooooo00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000oooo
ooooool01Oooool00omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIV
I_ooool01Oooool00on7QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool01_ooool5o`0005Gooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2oooo
o`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oooooo
ooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003ooooo
00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A405Gooooo001Cooooo`06ob4Q8Oooooooooooooooooo^k^ko
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`00
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00oo^k^ko0000ooooo`06ooooo`06oc8b<_o^k^koV9RHoeEEEOoM
gMgo410@2oooool00olb<S;oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0Cooooo00?o0000
ooooooooool04oooool01Ol0003ooooooooooooooooo000000[ooooo00?oV9RHob4Q8Oo^k^h0E_oo
ool005Cooooo00GogMgMoiRHV?mgMgOo410@ofIVIP03ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000Go00000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?ok^k^
o`000?ooool01_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`02_ooool00olb<S;ooooo
ooooo`03ooooo`04onk^k_lQ8B7o410@onk^kPCooooo00?o0000ooooooooool04oooool01_l0003o
oooooooooooooooo0000ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP1Eooooo`00Doooool01OmV
IVKo410@oeEEEOn7QhOo^[Zj00Cooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_oo
ool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Gooooo00ko0000olc<c?o<c<co0000ojVYZOoMgMgo
8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000ooooooooool01Oooool01Ol0
003oMgMgoooooonYZJWo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06ofIV
I_mgMgOoooooonk^k_mEEEGo00001oooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL02_oo
ool00ol0003ok^k^ooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P?ooooo00?ok^k^o`000?ooool0
5?ooool01Ol0003oQhN7oooooonYZJWo000000cooooo00?oMgMgofIVI_ooool0E?ooool005?ooooo
00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool0
1_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^kooooo
oa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000[oV9RH
ooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool02ol@413o0000ob4Q8Ol0003o
MgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00004oooo
o`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000
ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oMgMg
oeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00_ooooo00?o0000
ooooooooool0Doooool005?ooooo00Ko<S8bohN7Qoooooook^k^ofIVI_l00003ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02?ooool00omVIVKoQhN7ooooo`0;ooooo`03omgMgOl@
413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd08oooool01Ol0003o^[ZjoooooonHV9So410@05Gooooo
001Cooooo`06onk^k_m4A4Co0000o`000?lb<S;o410@0oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00onYZJWoA4A4ooooo`0<ooooo`03
ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool08oooool01OnHV9So410@o`000?lQ8B7oc<c<
05Gooooo001Kooooo`03oa0@4?l0003ooooo023ooooo00?o410@ooooooooool0;Oooool00ol@413o
0000ooooo`0Aooooo`;o0000Y?ooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -11707.2, \
0.0641612, 154.708}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.309023 4.39428e-06 [
[.05357 .29652 -12 -9 ]
[.05357 .29652 12 0 ]
[.20238 .29652 -6 -9 ]
[.20238 .29652 6 0 ]
[.35119 .29652 -12 -9 ]
[.35119 .29652 12 0 ]
[.64881 .29652 -9 -9 ]
[.64881 .29652 9 0 ]
[.79762 .29652 -3 -9 ]
[.79762 .29652 3 0 ]
[.94643 .29652 -9 -9 ]
[.94643 .29652 9 0 ]
[.4875 .04537 -36 -4.5 ]
[.4875 .04537 0 4.5 ]
[.4875 .13325 -36 -4.5 ]
[.4875 .13325 0 4.5 ]
[.4875 .22114 -36 -4.5 ]
[.4875 .22114 0 4.5 ]
[.4875 .39691 -30 -4.5 ]
[.4875 .39691 0 4.5 ]
[.4875 .48479 -30 -4.5 ]
[.4875 .48479 0 4.5 ]
[.4875 .57268 -30 -4.5 ]
[.4875 .57268 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30902 m
.05357 .31527 L
s
[(-7.5)] .05357 .29652 0 1 Mshowa
.20238 .30902 m
.20238 .31527 L
s
[(-5)] .20238 .29652 0 1 Mshowa
.35119 .30902 m
.35119 .31527 L
s
[(-2.5)] .35119 .29652 0 1 Mshowa
.64881 .30902 m
.64881 .31527 L
s
[(2.5)] .64881 .29652 0 1 Mshowa
.79762 .30902 m
.79762 .31527 L
s
[(5)] .79762 .29652 0 1 Mshowa
.94643 .30902 m
.94643 .31527 L
s
[(7.5)] .94643 .29652 0 1 Mshowa
.125 Mabswid
.08333 .30902 m
.08333 .31277 L
s
.1131 .30902 m
.1131 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.17262 .30902 m
.17262 .31277 L
s
.23214 .30902 m
.23214 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.32143 .30902 m
.32143 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.41071 .30902 m
.41071 .31277 L
s
.44048 .30902 m
.44048 .31277 L
s
.47024 .30902 m
.47024 .31277 L
s
.52976 .30902 m
.52976 .31277 L
s
.55952 .30902 m
.55952 .31277 L
s
.58929 .30902 m
.58929 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.67857 .30902 m
.67857 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.76786 .30902 m
.76786 .31277 L
s
.82738 .30902 m
.82738 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.8869 .30902 m
.8869 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .04537 m
.50625 .04537 L
s
[(-60000)] .4875 .04537 1 0 Mshowa
.5 .13325 m
.50625 .13325 L
s
[(-40000)] .4875 .13325 1 0 Mshowa
.5 .22114 m
.50625 .22114 L
s
[(-20000)] .4875 .22114 1 0 Mshowa
.5 .39691 m
.50625 .39691 L
s
[(20000)] .4875 .39691 1 0 Mshowa
.5 .48479 m
.50625 .48479 L
s
[(40000)] .4875 .48479 1 0 Mshowa
.5 .57268 m
.50625 .57268 L
s
[(60000)] .4875 .57268 1 0 Mshowa
.125 Mabswid
.5 .06734 m
.50375 .06734 L
s
.5 .08931 m
.50375 .08931 L
s
.5 .11128 m
.50375 .11128 L
s
.5 .15522 m
.50375 .15522 L
s
.5 .17719 m
.50375 .17719 L
s
.5 .19917 m
.50375 .19917 L
s
.5 .24311 m
.50375 .24311 L
s
.5 .26508 m
.50375 .26508 L
s
.5 .28705 m
.50375 .28705 L
s
.5 .33099 m
.50375 .33099 L
s
.5 .35297 m
.50375 .35297 L
s
.5 .37494 m
.50375 .37494 L
s
.5 .41888 m
.50375 .41888 L
s
.5 .44085 m
.50375 .44085 L
s
.5 .46282 m
.50375 .46282 L
s
.5 .50677 m
.50375 .50677 L
s
.5 .52874 m
.50375 .52874 L
s
.5 .55071 m
.50375 .55071 L
s
.5 .0234 m
.50375 .0234 L
s
.5 .00142 m
.50375 .00142 L
s
.5 .59465 m
.50375 .59465 L
s
.5 .61662 m
.50375 .61662 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30902 m
.02605 .30902 L
.02846 .30902 L
.03072 .30902 L
.03279 .30902 L
.03521 .30902 L
.03784 .30902 L
.04032 .30902 L
.04262 .30902 L
.04498 .30902 L
.0472 .30902 L
.04963 .30902 L
.05224 .30902 L
.05497 .30902 L
.05757 .30902 L
.0599 .30902 L
.06244 .30902 L
.0653 .30902 L
.06799 .30902 L
.07041 .30902 L
.07302 .30902 L
.07588 .30902 L
.07889 .30902 L
.08147 .30902 L
.08429 .30902 L
.08694 .30902 L
.08936 .30902 L
.09215 .30902 L
.09479 .30902 L
.09722 .30902 L
.09948 .30902 L
.10195 .30902 L
.10458 .30902 L
.10696 .30902 L
.10947 .30902 L
.11161 .30902 L
.11395 .30902 L
.11648 .30902 L
.11918 .30902 L
.12173 .30902 L
.12405 .30902 L
.12856 .30902 L
.13111 .30902 L
.13345 .30902 L
.13777 .30902 L
.13994 .30902 L
.14233 .30902 L
.14482 .30902 L
.14754 .30902 L
.14994 .30902 L
Mistroke
.15249 .30902 L
.15502 .30902 L
.15731 .30902 L
.16178 .30902 L
.16447 .30901 L
.16695 .30901 L
.16962 .30901 L
.17254 .309 L
.17747 .309 L
.18016 .30899 L
.18267 .30898 L
.18769 .30896 L
.19053 .30895 L
.19315 .30893 L
.19796 .30889 L
.20306 .30882 L
.20762 .30875 L
.21189 .30865 L
.21658 .3085 L
.22163 .30829 L
.22661 .308 L
.23123 .30764 L
.2363 .30712 L
.24171 .30636 L
.24741 .30528 L
.25278 .30392 L
.2576 .30234 L
.26282 .30015 L
.27231 .29452 L
.2777 .29013 L
.28274 .28505 L
.2929 .27135 L
.29859 .2613 L
.30379 .25043 L
.32286 .19557 L
.34361 .11365 L
.35379 .07229 L
.36336 .0395 L
.36816 .0272 L
.37086 .02191 L
.37333 .01825 L
.37466 .01679 L
.3759 .01577 L
.37661 .01534 L
.37725 .01504 L
.378 .01481 L
.3787 .01472 L
.37939 .01473 L
.38011 .01488 L
.38141 .01546 L
Mistroke
.38214 .01597 L
.38281 .01656 L
.38436 .01836 L
.3856 .02028 L
.38693 .02278 L
.38933 .0285 L
.39217 .0374 L
.39475 .04745 L
.39983 .07283 L
.40462 .10327 L
.42315 .26836 L
.44154 .45 L
.44658 .48996 L
.44935 .50865 L
.45198 .52385 L
.45442 .53561 L
.45708 .54561 L
.45825 .54907 L
.45949 .55207 L
.46055 .55409 L
.46172 .55572 L
.46298 .55678 L
.46361 .55703 L
.46431 .55709 L
.46553 .55666 L
.46667 .55563 L
.46737 .5547 L
.46803 .55362 L
.46926 .55106 L
.47058 .54753 L
.47201 .5428 L
.47446 .53264 L
.47704 .5191 L
.48167 .48819 L
.49171 .39771 L
.50274 .27909 L
.51273 .17704 L
.51765 .13506 L
.5222 .10341 L
.52495 .08827 L
.52743 .07732 L
.52876 .07259 L
.53019 .06837 L
.53098 .06644 L
.5317 .06493 L
.53239 .06371 L
.53313 .06266 L
.53433 .06148 L
.53544 .06098 L
.53613 .06097 L
Mistroke
.53677 .06115 L
.53798 .06201 L
.53926 .06365 L
.54044 .06582 L
.54173 .06892 L
.5431 .07301 L
.54562 .08261 L
.54801 .09415 L
.55251 .12165 L
.56263 .2058 L
.58093 .39063 L
.59051 .47774 L
.59576 .51744 L
.60072 .54833 L
.60535 .57102 L
.60779 .5805 L
.61036 .58868 L
.61253 .59413 L
.61368 .59649 L
.61492 .59862 L
.61605 .60022 L
.61708 .60138 L
.61812 .60228 L
.61911 .60287 L
.62024 .60325 L
.62147 .60332 L
.62263 .60305 L
.62369 .60254 L
.62487 .60168 L
.62616 .6004 L
.62875 .59679 L
.63132 .59197 L
.63406 .58558 L
.63901 .57132 L
.65742 .50008 L
.67733 .42184 L
.68781 .38884 L
.69891 .36176 L
.70881 .34404 L
.71443 .33631 L
.7197 .33041 L
.72894 .32264 L
.73413 .31945 L
.73888 .31712 L
.74366 .31526 L
.74874 .3137 L
.75354 .31256 L
.75789 .31175 L
.76303 .31101 L
.76857 .31043 L
Mistroke
.77381 .31002 L
.77863 .30975 L
.78334 .30955 L
.78838 .30939 L
.79314 .30929 L
.79748 .30922 L
.80257 .30915 L
.80544 .30913 L
.8081 .30911 L
.81298 .30908 L
.81544 .30907 L
.81815 .30906 L
.82308 .30905 L
.82556 .30904 L
.82827 .30904 L
.83059 .30904 L
.83307 .30903 L
.83753 .30903 L
.84023 .30903 L
.84316 .30903 L
.84574 .30903 L
.84847 .30903 L
.85093 .30903 L
.85364 .30903 L
.8584 .30902 L
.8609 .30902 L
.86362 .30902 L
.86602 .30902 L
.86858 .30902 L
.87087 .30902 L
.8734 .30902 L
.87787 .30902 L
.88058 .30902 L
.88306 .30902 L
.88578 .30902 L
.88865 .30902 L
.89115 .30902 L
.89348 .30902 L
.89604 .30902 L
.89878 .30902 L
.90136 .30902 L
.90409 .30902 L
.90643 .30902 L
.909 .30902 L
.91176 .30902 L
.91472 .30902 L
.91753 .30902 L
.92009 .30902 L
.92265 .30902 L
.92503 .30902 L
Mistroke
.92763 .30902 L
.93041 .30902 L
.93307 .30902 L
.93556 .30902 L
.9378 .30902 L
.94023 .30902 L
.94231 .30902 L
.94454 .30902 L
.94665 .30902 L
.94857 .30902 L
.95082 .30902 L
.95327 .30902 L
.95558 .30902 L
.95772 .30902 L
.95991 .30902 L
.96198 .30902 L
.96424 .30902 L
.96668 .30902 L
.96909 .30902 L
.97164 .30902 L
.97381 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002:
ooooo`?o00009_ooool00ol0003oooooooooo`2booooo`00R_ooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo0;;ooooo0029ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02;ooooo0_l0002cooooo`00R?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;;ooooo0027ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2booooo`00Qoooool01_l0
003ok^k^oc8b<_l0003o410@olc<c0?ooooo00Go0000oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0;;ooooo0026ooooo`07o`000?ooooooEEEE
ogMgMoooooooV9RHob4Q8@03ooooo`05o`000?nHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00P?ooool7o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool008Kooooo00Oo0000ooooool0003o
V9RHoooooonHV9So8B4Q00?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Cooooo0ol0002booooo`00QOooool02?l0003oooooooooool0003oEEEEo`000?l@
413oc<c<0oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2booooo`00QOooool01Ol0003ooooooooooomEEEGoQhN700Kooooo
00Go410@o`000?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0;;ooooo0025ooooo`06o`000?ooooooooooomgMgOl@413oV9RH1Oooool01OmgMgOo0000
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/_oo
ool008Cooooo00?o0000ooooooooool00_ooool01?o<c<coA4A4o`000?l@4103ooooo`05onk^k_l0
003o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2b
ooooo`00Q?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool2o`000:Sooooo0024ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`07ooooo`;o000000?oooooo`000?ooool0Y_ooool008Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`;o00002?ooool01?l0003ooooo
ooooool0002Wooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo00000:Kooooo0023ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool008?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Tooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0:?ooooo0022ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Xoooool008;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Sooooo`00P_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Xoooool008;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Rooooo`00POooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0021oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_ooool0087ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Rooooo`00POooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0:;ooooo0021ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_oo
ool0083ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Qooooo`00P?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo0_l00005ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0XOooool0083ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`2Qooooo`00P?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo
001oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0XOooool007oooooo00?o0000
ooooooooool02?ooool2o`00000:oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`00
00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0:7ooooo001oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo0:7ooooo001oooooo`Oo00000_ooool5o`0000?ooooo00Ko410@oooooooooooooooooa0@
4?l00002ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Qooooo`00O_ooool00ol0003oooooooooo`07oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0:3ooooo001nooooo`03o`000?oooooooooo00Oooooo00CogMgMoeEEEOoooooo00001?ooool01?l0
003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:3ooooo001nooooo`03o`00
0?oooooooooo00Sooooo00?oMgMgolc<c?l000001?ooool01_l@413ooooooooooooooooo410@o`00
00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0:3ooooo001nooooo`03o`000?oooooooooo00Sooooo00?o
k^k^odA4A?l000001?ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0:3ooooo001mooooo`03o`000?oooooooooo00[ooooo00?oMgMgo`000?ooool00oooool0
3Oo^k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`00OOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:3ooooo001mooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0X?ooool007cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Jooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
09oooooo001looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool007cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Oooooo`00O?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo09oooooo001kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0Wooo
ool007_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`2Oooooo`00Noooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo09oooooo001kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool2
o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo09kooooo001jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool0
07[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`2Nooooo`00N_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo09kooooo001iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool0W_ooool007Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0W_ooool007Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`;o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`2Mooooo`00N?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooooooo`2Mooooo`00N?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00N?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooooooo`2Mooooo`00Moooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00Moooool00ol0003o
ooooooooo`0>ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go0000oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`2Mooooo`00
Moooool00ol0003oooooooooo`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo
00004Oooool00ol0003oooooooooo`2Mooooo`00M_ooool00ol0003oooooooooo`07ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo09gooooo
001fooooo`03o`000?oooooooooo017ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Kooooo1?l0000Aooooo`03o`000?oooooo
oooo09gooooo001fooooo`03o`000?oooooooooo01;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00004_ooool00ol0003oooooooooo`2Looooo`00MOooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool@41000oooool01_l@413ooooooooooooooooo410@o`0000;ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Gooooo
00?o0000ooooooooool04?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo000001?ooooo
00?o0000ooooooooool0W?ooool007Gooooo00?o0000ooooooooool04?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_l0003o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000001?ooooo00?o0000
ooooooooool0W?ooool007Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooo000001?ooooo00?o0000ooooooooool0W?ooool007Cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Gooooo`?o00004oooool00ol0003oooooooooo`2Looooo`00
Loooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000
4oooool00ol0003oooooooooo`2Looooo`00Loooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00Loooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool000004oooool0
0ol0003oooooooooo`2Looooo`00L_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooool000004oooool00ol0003oooooooooo`2Looooo`00L_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004oooool00ol0003o
ooooooooo`2Looooo`00LOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo
0_l0000Eooooo`03o`000?oooooooooo09_ooooo001aooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool05_ooool2o`0001Gooooo00?o0000ooooooooool0Voooool001cooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Tooooo`05odA4A?l0
003o0000oc8b<_oMgMd05oooool00ol0003oooooooooo`08ooooo`Go00001Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@09ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03
o`000?oooooooooo00cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
02?ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Uooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd06?ooool001cooooo00?oEEEEojVYZOooool01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool09_ooool00omgMgOo<S8booooo`0Eooooo`03o`000?oooooo
oooo00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`08ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`03ogMg
Molb<S;ooooo02Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
5oooool001;ooooo1_l00004ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000ooooooooool06Ooo
ool6o`0000Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
0_l0000Eooooo`03o`000?oooooooooo00gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02?ooooo00?oZJVYoeEEEOooool04?ooool00ol0003ooooo
ooooo`0Fooooo`007Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo02Kooooo00?o
MgMgoc8b<_ooool05?ooool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?o
MgMgoc8b<_ooool02?ooool00ol0003oooooooooo`0Fooooo`;o00005Oooool00ol0003ooooooooo
o`0>ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8boooo
o`0Uooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool05oooool001gooooo00?oEEEE
olc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c00Dooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Wooooo00?o0000ooooooooool05_ooool2o`0001Gooooo00?o0000oooooooo
ool03oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<02Kooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<01Sooooo000Mooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo0_l0000Eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Jooooo`006_ooool01Ol@
413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00gooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ooooooooool03?oo
ool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Uooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`00
6_ooool5o`0000cooooo1?l0000Uooooo`Co00004_ooool00ol0003oooooooooo`0>ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000_ooooo00?o0000ooooooooool05Oooool2o`0001Go
oooo00?o0000ooooooooool03?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000Toooo
o`Co00009?ooool5o`0000cooooo1?l0000Iooooo`00JOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01Gooooo0_l0000Eooooo`03o`000?oooooooooo09_ooooo001Wooooo`;o0000
<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Voooool006Gooooo0_l0000dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`2Jooooo`00Hoooool2o`0003Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[ooooo001Nooooo`Go0000>?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0V_ooool000oo
ooooool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooooooool:o`0000Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0027ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool06oooool3o`0000oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Pooooo`00W?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`1Tooooo`00W?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool2o`0006Oooooo002Loooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0_oooo
o`;o0000JOooool009cooooo00?o0000ooooooooool04oooool2o`0001Oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Yooooo`00W?ooool00ol0003oooooooooo`0Cooooo`?o0000
5_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06[ooooo002Looooo`03o`000?oo
oooooooo01?ooooo0_l0000Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Jooo
ool009cooooo00?o0000ooooooooool04oooool2o`0001Oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1/ooooo`00W?ooool00ol0003oooooooooo`0Cooooo`;o00006?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo06cooooo002Looooo`03o`000?oooooooooo01?o
oooo0_l0000Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool009cooooo
00?o0000ooooooooool04oooool2o`0001Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1^ooooo`00WOooool00ol0003oooooooooo`0Booooo`;o00006?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo06kooooo002Mooooo`03o`000?oooooooooo01;ooooo0_l0000H
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool009gooooo00?o0000oooo
ooooool04Oooool01?l0003oooooo`000?l0000Gooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Koooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool009gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0L?ooool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0LOooool009gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0LOoo
ool009gooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0L_ooool009gooooo00?o0000ooooooooool04Oooool00ol0
003oooooo`00000Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool009ko
oooo00?o0000ooooooooool04?ooool01?l0003oooooo`000?l0000Hooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0Loooool009kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`00000Iooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Loooool009kooooo
00?o0000ooooooooool04?ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0M?ooool009kooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool0000Iooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0M?ooool009kooooo00?o
0000ooooooooool03oooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0MOooool008Sooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool03Oo^k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co0000oooooooooooo00006Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07Gooooo0028ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RHogMg
Mooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1eooooo`00ROooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
0oooool02Ol@413ooooooooooooooooo410@ooooool0003ooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo000000;ooooo0ol0000Gooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0M_ooool008[ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000ooooooooooooooooo`000?oooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1fooooo`00Roooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Kooooo002<ooooo`05o`000?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooo0000oa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo07Oooooo0028ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`06o`000?mgMgOoV9RHoooo
oonHV9SoMgMg0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooooooooo0000
6_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Oooooo0028ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Co0000oooooooooooo00006_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo07Oooooo002Oooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00000Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Moooool009oooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`0001Wooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1hooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000006_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07So
oooo002Oooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0N?ooool009oooooo00?o0000ooooooooool0
3Oooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1hooooo`00Woooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Oooooo`03o`00
0?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0NOooool00:3ooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1iooooo`00
X?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o00006_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo07Wooooo002Pooooo`03o`000?oooooooooo00cooooo
00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0N_ooool00:3ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1jooooo`00X?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07[ooooo002Pooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0N_ooool00:3ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1jooooo`00X?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07_o
oooo002Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00:7ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o00006oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo07_ooooo002Qooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Noooool00:7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1loooo
o`00XOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07cooooo002:ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^o`000?l0003o<S8bonk^kP03ooooo`06onk^k_lb<S;o0000oc8b<_o^
k^ko00001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0O?ooool008_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL00ooo
ool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo07cooooo0028ooooo`Go00000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000
ooooool@41000oooool01_l@413ooooooooooooooooo410@o`0000Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo0028ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l0
0005ooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07gooooo0028
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Co0000oooo
oooooooooooo0_l00005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1mooooo`00ROooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@ooooool0003ooooo
oa0@4003ooooo`06oa0@4?ooooooooooooooool@413o00001Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0OOooool008Wooooo00?ok^k^odA4A?l0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07go
oooo002:ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bo`000006ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1nooooo`00X_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo07kooooo002Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0O_ooool00:;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o00007Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo07kooooo002Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Ooooool00:;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1oooooo`00X_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07oooooo002Soooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Ooooool00:?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`20ooooo`00Xoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo083ooooo002Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`20ooooo`00Y?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo002Tooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0POooool00:Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`21ooooo`00Y?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo087ooooo
002Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0P_ooool00:Gooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`22ooooo`00YOooool01Ol0003ooooooooooooooooo000000Wooooo0_l0
000Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0P_ooool00:Kooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0P_ooool00:Kooooo0ol0000:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`23ooooo`00/oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Poooool00;?ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08?ooooo0028ooooo`05onk^
k_lb<S;o0000oa0@4?o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08?ooooo0028ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Cooooo0028ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo08Cooooo0028ooooo`05o`000?nHV9SooooooiRHV?lQ8B400oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Q?ooool008Sooooo00Go0000oeEEEOl0003o410@olc<c003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0QOooool008Sooooo
00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08Gooooo0028ooooo`03omgMgOl@413oV9RH00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`25ooooo`00ROooool01?o<c<coA4A4o`000?l@4103oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Q_ooool00;?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Kooooo
002cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`27ooooo`00/oooool2o`0002?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28
ooooo`00/oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000R_ooool0
0;?ooooo00?o0000ooooooooool08oooool4o`0008_ooooo002cooooo`03o`000?oooooooooo02Co
oooo0_l0002<ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002<ooooo`05
ob4Q8Ol0003o0000odA4A?oMgMd0eoooool008oooooo00?oMgMgoc8b<_ooool0>_ooool00onj^[[o
<S8booooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omV
IVKoMgMgooooo`06ooooo`03o`000?nj^[[ooooo07Cooooo002@ooooo`03o`000?oooooooooo03[o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?ogMgMoa0@
4?o^k^h02Oooool00oo^k^ko410@omgMg@06ooooo`;o<S8bMOooool005?ooooo00Ko410@ob4Q8Ol0
003o0000odA4A?oMgMd2ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE
0_l000001_mEEEGok^k^ooooooooooook^k^oeEEE@;o000000?oEEEEonk^k_ooool00_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So
410@ooooooo^k^koEEEEo`000?l@413oc<c<o`0000Cooooo0_l00002ooooo`07o`000?oooooooooo
o`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4
okZj^P02ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000001_mE
EEGok^k^ooooooooooook^k^oeEEE@;o000000?oV9RHo`000?l@41001_ooool01onHV9So410@o`00
0?l0003oZJVYooooool000000_ooool00ol0003oooooooooo`05ooooo`03oeEEEOnHV9Sooooo00;o
oooo0_l00002ooooo`;o00000_ooool00on7QhOoIVIVooooo`05ooooo`03ohN7Qol0003o^[Zj00_o
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`06ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`0EOooool005?ooooo00Ko0000ohN7QoooooooooooohN7QolQ8B43ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
MoooooooooooogMgMomEEED3ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000Gooooo00Co0000oooooooooooo00000_ooool02?l0003ooooooeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000Oooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3o`0000Sooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?ok^k^o`000?ooool01Oooool00oo<
c<co0000oa0@400<ooooo`06o`000?ooooooooooooooool0003ooooo1_l00002ooooo`05oa0@4?nj
^[[oooooogMgMolb<S80EOooool005?ooooo00Ko8B4Qooooooooooooooooonk^k_l00003ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03onk^k_l0003ooooo00Kooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@410;oooo
o`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<1?ooool00ol0003oooooooooo`0C
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`1Cooooo`00E?ooool0
1OoMgMgoV9RHogMgMol@413oIVIV00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000
ooooooooooooooooonk^k_l00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool0
00001Ol00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00oo^k^ko0000ooooo`06
ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c00:ooooo`03oc8b<_oooooooooo00?ooooo
00Cok^k^ob4Q8Ol@413ok^k^1?ooool00ol0003oooooooooo`0Cooooo`06o`000?oooooooooooooo
ool0003ooooo1_l00005ooooo`03ojVYZOl@413ooooo05Cooooo001Cooooo`05ofIVI_l@413oEEEE
ohN7Qonj^[X01?ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEogMgMooooooooooo
ogMgMomEEED2ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOmg
MgOoooooonk^k_mEEEGo00001Oooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003oooooooooo`05ooooo`05o`000?mgMgOooooo
ojVYZOl000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoIVIVogMgMooooooo
k^k^oeEEEOl00007ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`0:ooooo`03o`000?o^
k^kooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b0oooool00oo^k^ko0000ooooo`0Dooooo`05o`00
0?n7QhOoooooojVYZOl000002oooool00ol@413o0000okZj^P1Eooooo`00Doooool01_l0003ok^k^
ooooooooooooc<c<o`0000?ooooo00Go0000ogMgMol0003o0000oiRHV002ooooo`06onk^k_mEEEGo
0000o`000?mEEEGok^k^0_ooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004
ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000002_nHV9Soooooooooooo^
k^koEEEEo`000?lQ8B7oZJVYo`000?l@4103ooooo`0;oa0@4?l0003o8B4Qo`000?mgMgOo410@o`00
0?nYZJWoooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000Cooooo00Go0000ogMg
Mol0003o0000oiRHV002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_o^k^koEEEE
o`000?l@413oc<c<o`0000Oooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`08
ooooo`03oeEEEOmgMgOooooo00;ooooo0_l00002ooooo`;o00000_ooool00omgMgOoEEEEooooo`0C
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool02_ooool00onj^[[o8B4Qooooo`1D
ooooo`00Doooool01_lb<S;oQhN7ooooooo^k^koIVIVo`0000?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`08ooooo`03ofIVI_n7QhOooooo00_ooooo00?ogMgMoa0@4?o^k^h02Ooo
ool00oo^k^ko410@omgMg@0Sooooo`05oa0@4?nHV9SooooookZj^_l00000EOooool005?ooooo00Ko
k^k^odA4A?l0003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_oo
ool02?ooool00omVIVKoMgMgooooo`0Sooooo`05ojVYZOl@413o0000oa0@4?nYZJT0EOooool005_o
oooo00?o410@o`000?ooool08?ooool00ol@413oooooooooo`0]ooooo`03oa0@4?l0003ooooo017o
oooo0_l0002Tooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -70324.6, \
0.0641612, 869.111}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.281495 1.2108e-06 [
[.05357 .26899 -12 -9 ]
[.05357 .26899 12 0 ]
[.20238 .26899 -6 -9 ]
[.20238 .26899 6 0 ]
[.35119 .26899 -12 -9 ]
[.35119 .26899 12 0 ]
[.64881 .26899 -9 -9 ]
[.64881 .26899 9 0 ]
[.79762 .26899 -3 -9 ]
[.79762 .26899 3 0 ]
[.94643 .26899 -9 -9 ]
[.94643 .26899 9 0 ]
[.4875 .03933 -42 -4.5 ]
[.4875 .03933 0 4.5 ]
[.4875 .16041 -42 -4.5 ]
[.4875 .16041 0 4.5 ]
[.4875 .40258 -36 -4.5 ]
[.4875 .40258 0 4.5 ]
[.4875 .52366 -36 -4.5 ]
[.4875 .52366 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .28149 m
.05357 .28774 L
s
[(-7.5)] .05357 .26899 0 1 Mshowa
.20238 .28149 m
.20238 .28774 L
s
[(-5)] .20238 .26899 0 1 Mshowa
.35119 .28149 m
.35119 .28774 L
s
[(-2.5)] .35119 .26899 0 1 Mshowa
.64881 .28149 m
.64881 .28774 L
s
[(2.5)] .64881 .26899 0 1 Mshowa
.79762 .28149 m
.79762 .28774 L
s
[(5)] .79762 .26899 0 1 Mshowa
.94643 .28149 m
.94643 .28774 L
s
[(7.5)] .94643 .26899 0 1 Mshowa
.125 Mabswid
.08333 .28149 m
.08333 .28524 L
s
.1131 .28149 m
.1131 .28524 L
s
.14286 .28149 m
.14286 .28524 L
s
.17262 .28149 m
.17262 .28524 L
s
.23214 .28149 m
.23214 .28524 L
s
.2619 .28149 m
.2619 .28524 L
s
.29167 .28149 m
.29167 .28524 L
s
.32143 .28149 m
.32143 .28524 L
s
.38095 .28149 m
.38095 .28524 L
s
.41071 .28149 m
.41071 .28524 L
s
.44048 .28149 m
.44048 .28524 L
s
.47024 .28149 m
.47024 .28524 L
s
.52976 .28149 m
.52976 .28524 L
s
.55952 .28149 m
.55952 .28524 L
s
.58929 .28149 m
.58929 .28524 L
s
.61905 .28149 m
.61905 .28524 L
s
.67857 .28149 m
.67857 .28524 L
s
.70833 .28149 m
.70833 .28524 L
s
.7381 .28149 m
.7381 .28524 L
s
.76786 .28149 m
.76786 .28524 L
s
.82738 .28149 m
.82738 .28524 L
s
.85714 .28149 m
.85714 .28524 L
s
.8869 .28149 m
.8869 .28524 L
s
.91667 .28149 m
.91667 .28524 L
s
.02381 .28149 m
.02381 .28524 L
s
.97619 .28149 m
.97619 .28524 L
s
.25 Mabswid
0 .28149 m
1 .28149 L
s
.5 .03933 m
.50625 .03933 L
s
[(-200000)] .4875 .03933 1 0 Mshowa
.5 .16041 m
.50625 .16041 L
s
[(-100000)] .4875 .16041 1 0 Mshowa
.5 .40258 m
.50625 .40258 L
s
[(100000)] .4875 .40258 1 0 Mshowa
.5 .52366 m
.50625 .52366 L
s
[(200000)] .4875 .52366 1 0 Mshowa
.125 Mabswid
.5 .06355 m
.50375 .06355 L
s
.5 .08777 m
.50375 .08777 L
s
.5 .11198 m
.50375 .11198 L
s
.5 .1362 m
.50375 .1362 L
s
.5 .18463 m
.50375 .18463 L
s
.5 .20885 m
.50375 .20885 L
s
.5 .23306 m
.50375 .23306 L
s
.5 .25728 m
.50375 .25728 L
s
.5 .30571 m
.50375 .30571 L
s
.5 .32993 m
.50375 .32993 L
s
.5 .35414 m
.50375 .35414 L
s
.5 .37836 m
.50375 .37836 L
s
.5 .42679 m
.50375 .42679 L
s
.5 .45101 m
.50375 .45101 L
s
.5 .47522 m
.50375 .47522 L
s
.5 .49944 m
.50375 .49944 L
s
.5 .01512 m
.50375 .01512 L
s
.5 .54787 m
.50375 .54787 L
s
.5 .57209 m
.50375 .57209 L
s
.5 .5963 m
.50375 .5963 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .28149 m
.02605 .28149 L
.02846 .28149 L
.03072 .28149 L
.03279 .28149 L
.03521 .28149 L
.03784 .28149 L
.04032 .28149 L
.04262 .28149 L
.04498 .28149 L
.0472 .28149 L
.04963 .28149 L
.05224 .28149 L
.05497 .28149 L
.05757 .28149 L
.0599 .28149 L
.06244 .28149 L
.0653 .28149 L
.06799 .28149 L
.07041 .28149 L
.07302 .28149 L
.07588 .28149 L
.07889 .28149 L
.08147 .28149 L
.08429 .2815 L
.08694 .2815 L
.08936 .2815 L
.09215 .2815 L
.09479 .2815 L
.09722 .2815 L
.09948 .2815 L
.10195 .2815 L
.10458 .2815 L
.10696 .2815 L
.10947 .2815 L
.11395 .2815 L
.11645 .2815 L
.11877 .2815 L
.12133 .2815 L
.12405 .2815 L
.12641 .2815 L
.12898 .2815 L
.13124 .2815 L
.13363 .2815 L
.13578 .2815 L
.13816 .2815 L
.14233 .2815 L
.14482 .2815 L
.14754 .2815 L
.14994 .28151 L
Mistroke
.15249 .28151 L
.15502 .28151 L
.15731 .28152 L
.16178 .28153 L
.16447 .28153 L
.16695 .28154 L
.16962 .28156 L
.17254 .28157 L
.17747 .28161 L
.18016 .28163 L
.18267 .28166 L
.18769 .28174 L
.19053 .2818 L
.19315 .28186 L
.19796 .28201 L
.20306 .28224 L
.20762 .28251 L
.21189 .28284 L
.21658 .28333 L
.22163 .28403 L
.22661 .28495 L
.23123 .28607 L
.2363 .28766 L
.24171 .28988 L
.24741 .29296 L
.25278 .29673 L
.25757 .30095 L
.26282 .30669 L
.27257 .32107 L
.2779 .33135 L
.28288 .34273 L
.30134 .40146 L
.31995 .48382 L
.32978 .53004 L
.34022 .57274 L
.34545 .58872 L
.34843 .59551 L
.3498 .59797 L
.35123 .60009 L
.35245 .60149 L
.3531 .60207 L
.35379 .60258 L
.35501 .60315 L
.35614 .60332 L
.35682 .60324 L
.35756 .603 L
.35827 .60263 L
.35891 .60215 L
.36014 .6009 L
.36143 .59905 L
Mistroke
.36382 .59425 L
.36638 .58699 L
.3688 .57807 L
.37101 .56815 L
.37641 .53676 L
.38155 .49783 L
.40159 .28332 L
.41032 .1811 L
.41976 .08734 L
.42233 .06715 L
.42504 .049 L
.42755 .03537 L
.42878 .0299 L
.4299 .02562 L
.43095 .02222 L
.4321 .01923 L
.43331 .01687 L
.43445 .01542 L
.43571 .01472 L
.43635 .01472 L
.43705 .01499 L
.43829 .01619 L
.43945 .01814 L
.44067 .02106 L
.44201 .02527 L
.44472 .03692 L
.44722 .05136 L
.44954 .06778 L
.46042 .17643 L
.47917 .41028 L
.48431 .46316 L
.48712 .48719 L
.48975 .50596 L
.49217 .51983 L
.49439 .52939 L
.49565 .53347 L
.49685 .5364 L
.49811 .53848 L
.49883 .5392 L
.49949 .53956 L
.50019 .53964 L
.50084 .53942 L
.50154 .53887 L
.50229 .53793 L
.50355 .53554 L
.50426 .53373 L
.50492 .53175 L
.5073 .52239 L
.50984 .50857 L
.5128 .48779 L
Mistroke
.5156 .46393 L
.52085 .40999 L
.53063 .2892 L
.54101 .1597 L
.54558 .11066 L
.55051 .06739 L
.55333 .04792 L
.55591 .03385 L
.55715 .02843 L
.5585 .02352 L
.55978 .01987 L
.56097 .01734 L
.56213 .01568 L
.56338 .01479 L
.56456 .01479 L
.56565 .01552 L
.56663 .01678 L
.56771 .0188 L
.56884 .02163 L
.56989 .02491 L
.5723 .03466 L
.57449 .0462 L
.57941 .08051 L
.58932 .17707 L
.59849 .28426 L
.60919 .40808 L
.61443 .46166 L
.61924 .50436 L
.62353 .53635 L
.62822 .56427 L
.63293 .58465 L
.6355 .59254 L
.6379 .59789 L
.63918 .6 L
.63986 .60089 L
.64058 .60169 L
.6419 .60273 L
.64311 .60323 L
.64428 .6033 L
.64537 .60302 L
.64657 .60233 L
.64786 .60117 L
.64922 .59947 L
.65071 .59711 L
.65341 .59152 L
.6585 .57709 L
.66883 .53629 L
.6782 .49262 L
.68913 .44152 L
.69918 .39944 L
Mistroke
.70838 .36724 L
.71846 .33951 L
.72859 .31907 L
.73413 .31063 L
.73929 .30424 L
.74431 .2992 L
.74976 .29483 L
.75457 .2918 L
.75967 .28925 L
.76426 .28746 L
.76932 .28592 L
.77392 .28484 L
.77824 .28405 L
.78294 .28339 L
.78809 .28285 L
.79346 .28244 L
.79845 .28216 L
.80314 .28197 L
.80741 .28185 L
.81232 .28174 L
.81696 .28167 L
.8216 .28162 L
.82424 .28159 L
.8267 .28158 L
.83167 .28155 L
.83446 .28154 L
.83701 .28153 L
.84154 .28152 L
.84411 .28151 L
.84648 .28151 L
.85084 .28151 L
.85304 .2815 L
.85547 .2815 L
.86037 .2815 L
.86284 .2815 L
.86554 .2815 L
.86785 .2815 L
.87033 .2815 L
.87478 .2815 L
.87748 .2815 L
.8804 .2815 L
.88315 .2815 L
.8857 .2815 L
.88819 .2815 L
.89052 .2815 L
.89295 .2815 L
.89563 .2815 L
.8982 .2815 L
.90059 .2815 L
.90322 .2815 L
Mistroke
.90601 .2815 L
.90868 .2815 L
.91119 .2815 L
.91344 .2815 L
.91588 .2815 L
.91812 .28149 L
.92057 .28149 L
.92314 .28149 L
.92553 .28149 L
.92777 .28149 L
.92982 .28149 L
.93217 .28149 L
.93441 .28149 L
.93678 .28149 L
.939 .28149 L
.94144 .28149 L
.94407 .28149 L
.94667 .28149 L
.94942 .28149 L
.95176 .28149 L
.95432 .28149 L
.95674 .28149 L
.95894 .28149 L
.96147 .28149 L
.96387 .28149 L
.96608 .28149 L
.96813 .28149 L
.97037 .28149 L
.97275 .28149 L
.97453 .28149 L
.97619 .28149 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00W_ooool2o`0001?ooooo0_l0000Booooo`;o0000Woooool009gooooo00?o0000oooo
ool000004oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000009kooooo002Looooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0009gooooo002Looooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0@
ooooo`05o`000?ooooooooooooooool00000WOooool009cooooo00Go0000ooooooooooooooooo`00
000Booooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00002Mooooo`00P?oo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Go0000oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0V_ooool0083ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHo`000003ooooo`05ogMgMol0003ooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo09[ooooo001hooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooo0000oa0@4003ooooo`05oa0@4?l0003oooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09[ooooo0022ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`04ooooo`?o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09[ooooo
0023ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Jooooo`00Q?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`09oa0@4?oooooo
ooooooooool@413oooooo`000?oooooo410@00?ooooo00Go410@ooooool0003ooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0V_ooool0083ooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo09[ooooo0020ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2Jooooo`00V_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
09[ooooo002Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0VOooool009[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Iooooo`00V_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0VOooool009[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2I
ooooo`00V_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Wooooo002Jooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0V?ooool009[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo09Sooooo002Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0V?ooool0
09Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Hooooo`00VOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0V?ooool009Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Hooooo`00VOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Sooooo002I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Uoooool009Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Gooooo`00VOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
Uoooool009Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Gooooo`00V?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo0_l0000=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Oo
oooo002Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Uoooool009Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0U_ooool009Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Fooooo`00
Uoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0U_ooool009Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2Fooooo`00Uoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo09Kooooo002Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0U_ooool009Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Fooooo`00POooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0U_ooool008?ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`06o`00
0?mgMgOoV9RHoooooonHV9SoMgMg0oooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2Fooooo`00N?ooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4002ooooo`03
o`000?l@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003ooooo
ooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Fooooo`00Poooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09Ko
oooo0023ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Eooooo`00Poooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool02Ol@413ooooooooo
oooooooo410@ooooool0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413oooooo`000?oooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0UOooool008?ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RH
ogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00goMgMgoiRHV?ooooooV9RH
ogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo09Gooooo0021ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^ko
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^ko
ooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo09Gooooo002Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0UOooool009Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Eooooo`00
U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0UOooool009Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2Eooooo`00U_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo09Gooooo002Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0UOooool009Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0U?ooool009Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09
ooooo`;o00002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo002Eoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?ooool009Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?oo
ool009Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0U?ooool009Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`09ooooo`;o00002Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09?ooooo
002Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Toooool009Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`2Cooooo`007?ooool00ol0003ok^k^ooooo`05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Rooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02Gooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`007?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Vooooo`03ogMgMolb<S;ooooo
027ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool09?oo
ool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Gooooo`004_ooool6
o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`0Iooooo`Ko00001oooool0
0ol0003oooooooooo`0Hooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Aooooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Sooooo`03ojVYZOmEEEGooooo013ooooo00?o
0000ooooooooool05_ooool001gooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0V
ooooo`03ogMgMolb<S;ooooo02?ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`02
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0?
ooooo`03ogMgMolb<S;ooooo02Gooooo00?oMgMgoc8b<_ooool09Oooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo01Oooooo000Mooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Tooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09Oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Vooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Hooooo`007Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`;o00002Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Jooooo`006_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Tooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Uooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Jooooo`006_oo
ool5o`0000cooooo1?l0000Uooooo`Co00008oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l00004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00cooooo1?l0000Tooooo`Co00009?ooool5o`0000cooooo1?l0000Iooooo`00
U?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09?ooooo002Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0T_ooool009?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`2Booooo`00Toooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
09;ooooo002Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0T_ooool000oooooo
ool0001:o`00013ooooo000Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`[o00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo2_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Fooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo0ol00008ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool08?ooool005kooooo0_l0000cooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0<Oooool2o`0005oooooo001Pooooo`;o0000<Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Goooool0
06;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02kooooo0_l0001Rooooo`00Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`00I?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1Sooooo`00I?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo06Cooooo001Uooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo001Voooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo06Gooooo001Wooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Gooooo001Xooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06Kooooo001Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06Oooooo001Yooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo06Oooooo001Yooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo06Sooooo001Zooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`;o00001oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0J?ooool006[ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0JOooool006[ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0JOooool006_ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0J_ooool006cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J_ooool006cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0Joooool006cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0Joooool006gooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0K?oo
ool006gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo0_l00006ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1/ooooo`00KOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1/ooooo`00K_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1]ooooo`00K_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`00K_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1^ooooo`00Koooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1^ooooo`00Koooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1^oooo
o`00Koooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1_ooooo`00Koooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06oooooo001`ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06oooooo001`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo073ooooo001`ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
073ooooo001aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo073ooooo001aooooo`03o`000?oooooooooo00gooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool01_l0003ok^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o000000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0L?ooool0
077ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
000000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0LOooool007;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`02
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0LOooool007;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool3o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo077ooooo001booooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0LOooool007;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41000_ooool00ol0003o410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0L_ooool007?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool01_l0003oMgMg
oiRHV?ooooooV9RHogMgM`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So000000Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
L_ooool007?ooooo00?o0000ooooooooool02oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool01_l0003ok^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;o000000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0L_ooool007?ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0L_oo
ool007?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0L_ooool007Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Loooool007Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`1cooooo`00M?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1cooooo`00M?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1cooooo`00M?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1cooooo`00MOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1doooo
o`00MOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1dooooo`00MOooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1dooooo`00MOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1dooooo`00M_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo001fooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
07Gooooo001fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo001fooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo
001gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo07Kooooo001gooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07Kooooo001goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo07Kooooo001gooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07Kooooo001gooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
Moooool007Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Moooool007Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Oooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Moooool007Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Moooool007Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
N?ooool007Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0N?ooool007Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0N?ooool007Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Wooooo001i
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1iooooo`00NOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0NOooool007[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool08Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`03
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o000000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo001j
ooooo`03o`000?oooooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonH
V9Soooooo`000?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00Ko0000oooooooooooo0000ooooool0000Tooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0N_ooool007[ooooo00?o0000ooooooooool01?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Ko0000oooooooooooo0000ooooool0000Uoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007_ooooo00?o0000oooooooo
ool01?ooool00onHV9So8B4Qonk^kP03ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool00000
0_l0000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_ooool007_ooooo00?o
0000ooooooooool01Oooool00omgMgOoIVIVooooo`02ooooo`03o`000?oooooooooo00;o00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooool0003oooooo`00000Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0N_oo
ool007_ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo410@00;ooooo00?o
0000oa0@4?ooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00Cooooo00Go0000ooooool0003oooooo`00000Uooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Noooool007_ooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?oooooo0000ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool3o`0002Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1kooooo`00Noooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`?o00009_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo07_ooooo001looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0Noooool007cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1koooo
o`00O?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo0_l0000Wooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0O?ooool007gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1looooo`00OOooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07cooooo001mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0O?ooool0
07gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1mooooo`00O_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo07gooooo001nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0OOooool007kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`1mooooo`00Ooooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l0000Y
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0OOooool007oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1nooooo`00Ooooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07kooooo001oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
O_ooool0083ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`00P?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07oooooo0020ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Ooooool0083ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`20ooooo`00POooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo
0_l0000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0P?ooool008;ooooo00Go
0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooooooo
ooooo`000023ooooo`00P_ooool4o`0002gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
o`000024ooooo`00Q?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Poooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000oooo
ooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0
/_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool008cooooo00Go8B4Qo`000?l0003oA4A4omgMg@3Gooooo`00Soooool00omgMgOo<S8boooo
o`0jooooo`03okZj^_lb<S;ooooo00;ooooo00Co0000oooooooooooo00002?ooool00omgMgOoIVIV
ooooo`08ooooo`03ofIVI_mgMgOooooo00Kooooo00?o0000okZj^_ooool0M?ooool0093ooooo00?o
0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1Oooool00ooMgMgo410@onk^kP09ooooo`03onk^k_l@413ogMgM00Kooooo0_lb<S9eooooo`00Dooo
ool01_l@413o8B4Qo`000?l0003oA4A4omgMg@;ooooo00Co410@o`000?l0003ooooo0_l000001?l@
413oooooonk^k_mEEED2o`000006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000000omEEEGok^k^
ooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000;ooooo00Co410@o`000?l0
003ooooo0_l000002?l@413oooooonk^k_mEEEGo0000oa0@4?o<c<co00001?ooool2o`0000;ooooo
00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^
k_mEEED2o`000006oeEEEOo^k^koooooooooooo^k^koEEEE0_l000000onHV9So0000oa0@4006oooo
o`07oiRHV?l@413o0000o`000?nYZJWoooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o
EEEEoiRHV?ooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7QomVIVKooooo00Gooooo00?o
QhN7o`000?nj^[X02oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00Sooooo
0_l000000ol@413oooooooooo`1Cooooo`00Doooool01_l0003oQhN7ooooooooooooQhN7ob4Q8@?o
oooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_oo
ool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go410@okZj^_o^k^koMgMgoa0@4005oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00001Oooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00001oooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o00002?ooool00ol0
003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo^k^ko0000oooo
o`05ooooo`03olc<c?l0003o410@00cooooo00Ko0000ooooooooooooooooo`000?ooool6o`0000Go
oooo00?o0000ooooooooool0E?ooool005?ooooo00Ko8B4Qooooooooooooooooonk^k_l00003oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`03onk^k_l0003ooooo00Kooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@410;
ooooo`03oc8b<_oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<1?ooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool000002Oooool5o`0005Gooooo001Dooooo`05omgMgOnH
V9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooo
ooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`00
00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003ooooo00Kooooo00Oo
^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool00oooool01?o^k^ko
8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000ooooooooooooooooo`000?oo
ool6o`0000;ooooo00CoA4A4omgMgOoooooo0000E_ooool005?ooooo00GoIVIVoa0@4?mEEEGoQhN7
okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMgMoooooooZJVY
o`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMgooooooo^k^ko
EEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o0000onk^k_oo
ool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo00Go0000ohN7
QoooooooZJVYo`000009ooooo`04omgMgOmEEEGoooooo`0005Kooooo001Cooooo`06o`000?o^k^ko
ooooooooooo<c<co00000oooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`08onk^k_mEEEGo0000o`000?mEEEGok^k^ooooool@4105o`0000Co
oooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`00000:oiRHV?ooooooooooonk^
k_mEEEGo0000ob4Q8OnYZJWo0000oa0@40?ooooo00_o410@o`000?lQ8B7o0000ogMgMol@413o0000
ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00001?ooool01Ol0003oMgMg
o`000?l0003oV9RH00;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06onk^k_mEEEGo
0000oa0@4?o<c<co00001oooool01?mVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00So
oooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomEEEGooooo01?o
oooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`08ooooo`03ogMgMoo<c<co000005Ko
oooo001Cooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00000oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo00?oIVIVohN7Qoooool02oooool00ooMgMgo410@onk^kP09oooo
o`03onk^k_l@413ogMgM02Cooooo00?ok^k^odA4A?l00000E_ooool005?ooooo00Kok^k^odA4A?l0
003o0000oc8b<_l@4103ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`03ojVYZOm4A4Cooooo00cooooo00?oMgMgofIVI_ooool02?ooool0
0omVIVKoMgMgooooo`0Uooooo`03ogMgMol0003ooooo05Gooooo001Kooooo`03oa0@4?l0003ooooo
023ooooo00?o410@ooooooooool0;Oooool00ol@413o0000ooooo`0Aooooo`;o0000Y?ooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -232489, \
0.0641612, 3154.21}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.309032 3.36326e-07 [
[.05357 .29653 -12 -9 ]
[.05357 .29653 12 0 ]
[.20238 .29653 -6 -9 ]
[.20238 .29653 6 0 ]
[.35119 .29653 -12 -9 ]
[.35119 .29653 12 0 ]
[.64881 .29653 -9 -9 ]
[.64881 .29653 9 0 ]
[.79762 .29653 -3 -9 ]
[.79762 .29653 3 0 ]
[.94643 .29653 -9 -9 ]
[.94643 .29653 9 0 ]
[.4875 .05679 -42 -4.5 ]
[.4875 .05679 0 4.5 ]
[.4875 .14087 -42 -4.5 ]
[.4875 .14087 0 4.5 ]
[.4875 .22495 -42 -4.5 ]
[.4875 .22495 0 4.5 ]
[.4875 .39311 -36 -4.5 ]
[.4875 .39311 0 4.5 ]
[.4875 .4772 -36 -4.5 ]
[.4875 .4772 0 4.5 ]
[.4875 .56128 -36 -4.5 ]
[.4875 .56128 0 4.5 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .30903 m
.05357 .31528 L
s
[(-7.5)] .05357 .29653 0 1 Mshowa
.20238 .30903 m
.20238 .31528 L
s
[(-5)] .20238 .29653 0 1 Mshowa
.35119 .30903 m
.35119 .31528 L
s
[(-2.5)] .35119 .29653 0 1 Mshowa
.64881 .30903 m
.64881 .31528 L
s
[(2.5)] .64881 .29653 0 1 Mshowa
.79762 .30903 m
.79762 .31528 L
s
[(5)] .79762 .29653 0 1 Mshowa
.94643 .30903 m
.94643 .31528 L
s
[(7.5)] .94643 .29653 0 1 Mshowa
.125 Mabswid
.08333 .30903 m
.08333 .31278 L
s
.1131 .30903 m
.1131 .31278 L
s
.14286 .30903 m
.14286 .31278 L
s
.17262 .30903 m
.17262 .31278 L
s
.23214 .30903 m
.23214 .31278 L
s
.2619 .30903 m
.2619 .31278 L
s
.29167 .30903 m
.29167 .31278 L
s
.32143 .30903 m
.32143 .31278 L
s
.38095 .30903 m
.38095 .31278 L
s
.41071 .30903 m
.41071 .31278 L
s
.44048 .30903 m
.44048 .31278 L
s
.47024 .30903 m
.47024 .31278 L
s
.52976 .30903 m
.52976 .31278 L
s
.55952 .30903 m
.55952 .31278 L
s
.58929 .30903 m
.58929 .31278 L
s
.61905 .30903 m
.61905 .31278 L
s
.67857 .30903 m
.67857 .31278 L
s
.70833 .30903 m
.70833 .31278 L
s
.7381 .30903 m
.7381 .31278 L
s
.76786 .30903 m
.76786 .31278 L
s
.82738 .30903 m
.82738 .31278 L
s
.85714 .30903 m
.85714 .31278 L
s
.8869 .30903 m
.8869 .31278 L
s
.91667 .30903 m
.91667 .31278 L
s
.02381 .30903 m
.02381 .31278 L
s
.97619 .30903 m
.97619 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.5 .05679 m
.50625 .05679 L
s
[(-750000)] .4875 .05679 1 0 Mshowa
.5 .14087 m
.50625 .14087 L
s
[(-500000)] .4875 .14087 1 0 Mshowa
.5 .22495 m
.50625 .22495 L
s
[(-250000)] .4875 .22495 1 0 Mshowa
.5 .39311 m
.50625 .39311 L
s
[(250000)] .4875 .39311 1 0 Mshowa
.5 .4772 m
.50625 .4772 L
s
[(500000)] .4875 .4772 1 0 Mshowa
.5 .56128 m
.50625 .56128 L
s
[(750000)] .4875 .56128 1 0 Mshowa
.125 Mabswid
.5 .0736 m
.50375 .0736 L
s
.5 .09042 m
.50375 .09042 L
s
.5 .10724 m
.50375 .10724 L
s
.5 .12405 m
.50375 .12405 L
s
.5 .15769 m
.50375 .15769 L
s
.5 .1745 m
.50375 .1745 L
s
.5 .19132 m
.50375 .19132 L
s
.5 .20813 m
.50375 .20813 L
s
.5 .24177 m
.50375 .24177 L
s
.5 .25858 m
.50375 .25858 L
s
.5 .2754 m
.50375 .2754 L
s
.5 .29222 m
.50375 .29222 L
s
.5 .32585 m
.50375 .32585 L
s
.5 .34266 m
.50375 .34266 L
s
.5 .35948 m
.50375 .35948 L
s
.5 .3763 m
.50375 .3763 L
s
.5 .40993 m
.50375 .40993 L
s
.5 .42675 m
.50375 .42675 L
s
.5 .44356 m
.50375 .44356 L
s
.5 .46038 m
.50375 .46038 L
s
.5 .49401 m
.50375 .49401 L
s
.5 .51083 m
.50375 .51083 L
s
.5 .52764 m
.50375 .52764 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .03997 m
.50375 .03997 L
s
.5 .02315 m
.50375 .02315 L
s
.5 .00634 m
.50375 .00634 L
s
.5 .57809 m
.50375 .57809 L
s
.5 .59491 m
.50375 .59491 L
s
.5 .61173 m
.50375 .61173 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Shooting) show
117.000 13.000 moveto
(method) show
159.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
165.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.250 13.000 moveto
(H) show
176.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
182.250 13.000 moveto
(L) show
188.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
200.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
206.250 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
212.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
218.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30903 m
.02605 .30903 L
.02846 .30903 L
.03072 .30903 L
.03279 .30903 L
.03521 .30903 L
.03784 .30903 L
.04032 .30903 L
.04262 .30903 L
.04498 .30903 L
.0472 .30903 L
.04963 .30903 L
.05224 .30903 L
.05497 .30903 L
.05757 .30903 L
.0599 .30903 L
.06244 .30903 L
.0653 .30903 L
.06799 .30903 L
.07041 .30903 L
.07302 .30903 L
.07588 .30903 L
.07889 .30903 L
.08147 .30903 L
.08429 .30903 L
.08694 .30903 L
.08936 .30903 L
.09215 .30903 L
.09479 .30903 L
.09722 .30903 L
.09948 .30903 L
.10195 .30903 L
.10458 .30903 L
.10696 .30903 L
.10947 .30903 L
.11395 .30903 L
.11645 .30903 L
.11877 .30903 L
.12149 .30903 L
.12405 .30903 L
.12627 .30903 L
.12868 .30903 L
.13289 .30902 L
.13527 .30902 L
.1378 .30902 L
.14233 .30901 L
.14486 .30901 L
.14726 .309 L
.15177 .30899 L
.15428 .30898 L
Mistroke
.15662 .30897 L
.15934 .30895 L
.1619 .30893 L
.16656 .30889 L
.17077 .30883 L
.17531 .30875 L
.18022 .30862 L
.18515 .30845 L
.18975 .30822 L
.19479 .30789 L
.2002 .30738 L
.20586 .30664 L
.21123 .30567 L
.21604 .30452 L
.22127 .30286 L
.22614 .30085 L
.2307 .29847 L
.2357 .29517 L
.24109 .29066 L
.24644 .285 L
.25206 .27755 L
.26211 .25965 L
.27168 .23614 L
.28189 .20343 L
.30027 .12754 L
.31054 .0818 L
.31594 .05961 L
.32165 .03941 L
.32666 .02578 L
.32803 .02288 L
.3295 .02022 L
.33077 .01831 L
.33215 .01667 L
.3328 .01606 L
.3335 .01554 L
.33475 .01491 L
.33592 .01472 L
.33721 .01494 L
.33835 .01555 L
.33958 .01665 L
.34075 .01812 L
.34182 .01984 L
.3443 .02526 L
.34655 .03196 L
.35161 .05331 L
.35629 .08094 L
.36072 .11375 L
.38141 .32799 L
.39112 .43334 L
.39643 .4817 L
Mistroke
.39902 .50157 L
.4014 .51714 L
.40342 .52826 L
.40563 .53797 L
.40684 .54217 L
.40796 .54532 L
.40904 .54767 L
.41018 .54943 L
.41143 .55046 L
.41214 .55063 L
.41279 .55053 L
.41399 .54966 L
.41525 .54781 L
.41638 .54532 L
.41744 .5423 L
.41984 .53297 L
.42245 .51909 L
.42486 .50292 L
.43031 .45575 L
.44021 .3431 L
.44915 .2328 L
.45384 .18033 L
.45877 .1341 L
.46117 .11597 L
.4638 .09996 L
.46496 .09428 L
.46619 .08915 L
.46734 .08526 L
.46841 .08248 L
.46958 .08031 L
.47085 .07904 L
.47196 .07885 L
.47315 .0796 L
.47421 .0811 L
.4752 .08321 L
.47628 .0863 L
.47745 .09052 L
.4801 .10342 L
.48298 .12248 L
.48822 .16898 L
.49806 .28425 L
.50823 .41058 L
.51321 .46313 L
.51779 .50112 L
.52036 .51722 L
.52168 .5238 L
.52308 .52959 L
.52382 .53211 L
.5245 .53407 L
.52581 .537 L
Mistroke
.52655 .53812 L
.52735 .5389 L
.52811 .53923 L
.5288 .53918 L
.52999 .53831 L
.53111 .5366 L
.53233 .53374 L
.53364 .52953 L
.53632 .51744 L
.53878 .50243 L
.54354 .4637 L
.54862 .41114 L
.55775 .30034 L
.563 .23589 L
.56854 .17392 L
.57368 .12646 L
.57847 .09363 L
.58084 .0821 L
.58205 .07745 L
.58337 .07338 L
.58412 .07154 L
.58482 .07014 L
.58548 .06907 L
.58619 .06823 L
.58741 .06748 L
.5881 .06745 L
.58875 .06769 L
.5894 .06819 L
.59011 .06901 L
.59085 .07019 L
.59154 .07158 L
.59278 .07475 L
.5941 .0791 L
.59713 .09262 L
.59987 .10895 L
.60485 .14711 L
.61025 .19848 L
.62004 .30667 L
.6303 .4205 L
.63991 .50934 L
.64474 .54383 L
.64993 .57215 L
.65288 .58414 L
.65569 .59275 L
.6582 .59826 L
.65963 .60046 L
.66095 .60194 L
.66224 .60287 L
.66289 .60315 L
.6636 .60332 L
Mistroke
.66486 .60326 L
.66604 .60281 L
.66675 .60235 L
.66743 .6018 L
.66869 .60045 L
.67006 .59856 L
.67154 .59602 L
.67672 .58358 L
.6815 .568 L
.70012 .48879 L
.70988 .44643 L
.7204 .40661 L
.72949 .37869 L
.73942 .35527 L
.74904 .33893 L
.75428 .33223 L
.75915 .32718 L
.76789 .32045 L
.77278 .31773 L
.77722 .31578 L
.78208 .31409 L
.78722 .31273 L
.79161 .31184 L
.79643 .31109 L
.80162 .31049 L
.80718 .31003 L
.81244 .30972 L
.81724 .30952 L
.82203 .30938 L
.82713 .30927 L
.83148 .3092 L
.83629 .30915 L
.83897 .30913 L
.84143 .30911 L
.84408 .30909 L
.84699 .30908 L
.85188 .30906 L
.85455 .30906 L
.85704 .30905 L
.86207 .30905 L
.86491 .30904 L
.86754 .30904 L
.87235 .30904 L
.87478 .30904 L
.87746 .30904 L
.88208 .30903 L
.88468 .30903 L
.88705 .30903 L
.88926 .30903 L
.89166 .30903 L
Mistroke
.89604 .30903 L
.89859 .30903 L
.90135 .30903 L
.90396 .30903 L
.90636 .30903 L
.91091 .30903 L
.9132 .30903 L
.91572 .30903 L
.91846 .30903 L
.92095 .30903 L
.92384 .30903 L
.92657 .30903 L
.92909 .30903 L
.93142 .30903 L
.93397 .30903 L
.93669 .30903 L
.93907 .30903 L
.94158 .30903 L
.94372 .30903 L
.94607 .30903 L
.9486 .30903 L
.9513 .30903 L
.95385 .30903 L
.95617 .30903 L
.95852 .30903 L
.96068 .30903 L
.96306 .30903 L
.96557 .30903 L
.96776 .30903 L
.9698 .30903 L
.97204 .30903 L
.97445 .30903 L
.97619 .30903 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo001l
ooooo`?o0000=?ooool00ol0003oooooooooo`2booooo`00O?ooool01?l0003oooooo`000?l0000c
ooooo`03o`000?oooooooooo0;;ooooo001kooooo`05o`000?ooooooooooooooool00000<oooool0
0ol0003oooooooooo`2booooo`00Noooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
033ooooo0_l0002cooooo`00N_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0/_ooool007[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0;;ooooo001jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2booooo`00NOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0/_ooool007Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0_ooooo`;o0000/oooool007Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;;ooooo001iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2booooo`00N?oo
ool00ol0003oooooooooo`07ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`2booooo`00N?ooool00ol0003oooooooooo`07ooooo`03o`000?nYZJWo
oooo00Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2booooo`00N?ooool6o`0000Cooooo00?o0000
oeEEEOooool02?ooool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool007Oooooo00?o0000oooooooo
ool02?ooool00ol0003o8B4Qooooo`07ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`?o0000/_ooool007Oooooo00?o
0000ooooooooool02?ooool00ol0003oEEEEolc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0/_ooool007Oooooo00?o0000ooooooooool02Oooool00ol0003oMgMgooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo0;;ooooo001gooooo`03o`000?oooooooooo00Ko
oooo00Go410@oooooooooooo0000oc8b<P04ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Wo
oooo0_l0002Gooooo`00M_ooool00ol0003oooooooooo`07ooooo`Go00001?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo01Wooooo0ol0002Fooooo`00M_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02gooooo0_l0000Iooooo`;o000000?oooooo`000?ooool0UOooool007Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00Co0000oooo
oooooooo0000U_ooool007Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Roooo
o`;o00002?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000UOooool0
07Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo0000
00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09?ooooo001eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Cooooo`00MOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0T_ooool007Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000001_ooool2o`0001Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Boooo
o`00M?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Booooo`00M?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Aooooo`00Looo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`;o00005oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo097ooooo001cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
097ooooo001cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo097ooooo001cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo097ooooo
001booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo097ooooo001booooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l0000F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0TOooool007;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0TOooool007;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0T?ooool007;ooooo00?o0000ooooooooool0
3?ooool03?m4A4Co0000o`000?lb<S;ogMgMo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool03_o^
k^ko<S8bo`000?lb<S;ok^k^ooooool0003oooooonk^k_lb<S;o0000oc8b<_o^k^ko00001Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0T?ooool0
077ooooo00?o0000ooooooooool04?ooool02OmgMgOo<S8bo`000?ooooooMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00ooMgMgoiRHV?ooooooV9RHogMgMooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
ooooool000001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0T?ooool0077ooooo00?o0000ooooooooool01?ooool6o`0000Oooooo0_l000000ooo
oooo410@ooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000ooooool@
41000oooool00ol@413oooooo`000004ooooo`?o00005Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo093ooooo001aooooo`03o`000?oooooooooo013ooooo00GoMgMgoc8b<_l0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo0000ooooool00000
0oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2@ooooo`00LOooool00ol0003oooooooooo`0=ooooo`08o`000?lQ
8B7o0000oc8b<_o<c<co0000ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?oooooo0000ooooool000000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2@ooooo`00L?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413o0000oooooooooooo410@00?ooooo00?o410@ooooool000001?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0T?oo
ool0073ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`07o`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`07ogMgMonH
V9SooooooiRHV?mgMgOoooooo`000004ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2@ooooo`00L?ooool00ol0003oooooooooo`0>ooooo`Co0000
00Soooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`00
00;ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo093ooooo001`ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooooooo`;o00005Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo093ooooo001_
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo08oooooo001_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo08oooooo001_ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001_ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001_
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooooooo`;o00005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08oooooo001^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo08oooooo001^ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001^ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08oooooo001^
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08oooooo001]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`2>ooooo`00KOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02o`0001Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`2>ooooo`00KOooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000E
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0S_ooool006gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooo00005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08kooooo001/oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2>
ooooo`00K?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0S_ooool006cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000Cooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0S_ooool006_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00005?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08kooooo001[ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`00Joooool00ol0003o
ooooooooo`0Booooo`Go00000oooool01_l0003oA4A4o`000?l0003o<S8bomgMg@;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?l0003ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2>ooooo`00J_ooool00ol0
003oooooooooo`0Cooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01_l0003ooooooooooooo
ooooMgMgoc8b<P;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHooooool0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2=ooooo`00J_ooool00ol0003oooooooooo`0;ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP05ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000ooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo08gooooo001Yooooo`03o`000?oooooooooo01Kooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooomgMgOo<S8b00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o00004_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08gooooo001Yooooo`03o`000?oooooo
oooo01Oooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00JOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
oooo0000ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooool0
00005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08gooooo001Xooooo`03o`00
0?oooooooooo01Gooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHo`000?nHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03o`00
0?oooooo000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00J?oo
ool00ol0003oooooooooo`0Eooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oo
oooo000001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2=ooooo`00Ioooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool0
1?l0003oooooo`000?l0000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0SOoo
ool006Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo08gooooo001Wooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2=ooooo`00I_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0SOooool006Kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000004oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo08cooooo001Vooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000001?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2<ooooo`00IOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool01?l0003oooooo`000?l0
000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0S?ooool006Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08cooooo001Toooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooo000001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2<oooo
o`007?ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0;ooooo`03o`000?oooooooooo01Cooooo1Ol00005
ooooo`;o8B4Q0oooool00ol0003oooooodA4A002o`000003oc8b<_oMgMgooooo00oooooo00?o0000
ooooooooool03_ooool2o`0001?ooooo00?o0000ooooooooool03oooool5o`0000Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd08oooool01Om4A4Co0000o`000?lb<S;ogMgM02Gooooo
00?o0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`00
7?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Vooooo`03ogMg
Molb<S;ooooo00Wooooo00?o0000ooooooooool05Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo0_lQ8B43ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoc8b<_ooool03oooool00ol0003o
ooooooooo`0>ooooo`;o00004oooool00ol0003oooooooooo`0?ooooo`05o`000?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8booooo`0Toooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Oooooo000Booooo`Ko
00001?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01Wooooo1_l00007ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^
k^h02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool3o`0001;ooooo00?o0000ooooooooool03oooool01?l0003oV9RHob4Q8Oo^k^hAoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08oooool00onYZJWoEEEEooooo`0@oooo
o`03o`000?oooooooooo01Kooooo000Mooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_oo
ool09_ooool00omgMgOo<S8booooo`08ooooo`03o`000?oooooooooo01Sooooo00?oV9RHob4Q8Oo^
k^h02_ooool00ol0003oooooooooo`02ooooo`03ogMgMolb<S;ooooo00oooooo00?o0000oooooooo
ool03_ooool2o`0001?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooiRHV?lQ8B7ok^k^
00oooooo00?oMgMgoc8b<_ooool09Oooool00omgMgOo<S8booooo`0Uooooo`03ob4Q8Ooooooooooo
00kooooo00?oMgMgoc8b<_ooool05oooool001gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`03o`000?oooooo
oooo01[ooooo00?oMgMgofIVI_ooool02Oooool01ol0003oooooo`000?lQ8B7o0000oc8b<_o<c<`0
4?ooool00ol0003oooooooooo`0>ooooo`;o00004oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooogMgMomVIVH03?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<02?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Vooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Hooooo`007Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo0_l0000D
ooooo`03o`000?oooooooooo00kooooo0_l0000Cooooo`03o`000?oooooooooo00oooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0:?oo
ool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01[ooooo000Jooooo`05oa0@4?oooooo
oooooooooolb<S803?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo0_l0000Dooooo`03o`00
0?oooooooooo00kooooo0_l0000Booooo`03o`000?oooooooooo013ooooo00Go0000okZj^_oooooo
V9RHoa0@400<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool01Ol@413o
oooooooooooooooo<S8b00cooooo00?o0000ooooooooool06_ooool001[ooooo1Ol0000<ooooo`Co
00009Oooool4o`0000Kooooo00?o0000ooooooooool06_ooool01OnHV9So410@o`000?lQ8B7oc<c<
00_ooooo1Ol0000@ooooo`03o`000?oooooooooo00oooooo0_l0000Booooo`03o`000?oooooooooo
013ooooo00GoV9RHo`000?l0003o8B4Qolc<c00<ooooo`Co00009?ooool4o`0002Cooooo1Ol0000<
ooooo`Co00006Oooool005gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00oooooo0ol0000Aooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Roooool005cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00oooooo0_l0000Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Roooool005[ooooo0_l0000_ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3oooool2o`0001;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`00Eooo
ool3o`00037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`00D_ooool5
o`0003Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`003oooooooo`00
04[o00004?ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo2Ol00005ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`00
8Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
9_ooool3o`0000Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Pooooo`00S?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0FOoo
ool008cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`;o0000G?ooool0
08cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
05cooooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool2o`00013o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05go
oooo002<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Nooooo`00S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0Goooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`;o00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0Goooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`;o00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0H?ooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o
00004?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0H?ooool008cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o0000
4?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
HOooool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0H_oo
ool008gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Hoooool0
08gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00004?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0I?ooool008go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00003oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0I?ooool008gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`;o00003oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0IOooool008gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`;o00003oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0IOooool008gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Gooooo002=oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00000>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Voooo
o`00SOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooool0
00003_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0I_ooool008gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`?o0000
3_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
I_ooool008gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06Oooooo002>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Wooooo`00P?ooool5o`0000Cooooo00coA4A4o`000?l0003o<S8bomgMgOl0
003oooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`0=onk^k_lb<S;o0000oc8b<_o^k^koooooo`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Xooooo`00P?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMg
oc8b<_l0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool03OmgMgOoV9RHoooooonHV9SoMgMg
ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0J?ooool0087ooooo00?oV9RHob4Q8Oo^k^h02Oooool2o`000003
ooooool@413ooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo0000
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Xooooo`00P_ooool00onHV9So8B4Qonk^kP07ooooo`05ogMgMolb<S;o
0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`?o00003_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0JOooool008?ooooo00?oMgMgofIVI_ooool00oooool02?l0003o8B4Qo`000?lb<S;oc<c<
o`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooool0003o
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo06Wooooo0024ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003ooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413o0000oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0JOooool0083ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool0083o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co000000Soooooo`000?ooooook^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
J_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`;o000000?o
ooooo`000?ooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0J_ooool008kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo06[ooooo002>ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`00Soooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Joooool008oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06_ooooo002?
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0
000<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1[ooooo`00Soooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo0_l00000
0ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1/ooooo`00Soooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0K?ooool008oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06cooooo002?ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1/ooooo`00Soooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000:
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1/
ooooo`00Soooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo0_l00002oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo06gooooo002?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo002@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo002@ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
06gooooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo06kooooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo06kooooo002@ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool2o`0000;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0K_ooool0093ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0K_ooool0093ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0K_ooool0087ooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Ol0003o<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1_ooooo`00Q?ooool02OmgMgOo
<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHooooool0003oMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06oooooo0025
ooooo`04o`000?oooooooooooa0@40?ooooo00Ko410@oooooooooooooooooa0@4?l00002ooooo`05
oa0@4?ooooooooooooooool@41000_ooool00ol0003o410@ooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo06oooooo0024ooooo`05ogMgMolb<S;oooooooooool000000oooool01?l0003ooooooooo
ooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0Koooool0087ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Koooool0087o
oooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@o`00
0?oooooooooooa0@4003ooooo`05oa0@4?ooooooooooo`000?l@41000oooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0L?ooool0087ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
o`000?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0L?ooool0087ooooo1?l0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko0000o`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1`ooooo`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0_l00004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo073ooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo002Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo077ooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo002Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo077ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0L_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0L_ooool009?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0L_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Loooool009?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`;o00001_ooool01?l0003oooooooooool0000Sooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Loooool009?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Cooooo002Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1dooooo`00U?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool3
o`0002Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1dooooo`00U?ooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0M?ooool009Gooooo00Co0000oooo
oooooooo00006_ooool2o`0002gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1e
ooooo`00UOooool01?l0003oooooo`000?l0000Jooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1eooooo`00U_ooool2o`0001_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07Gooooo0022ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool008;ooooo00?oEEEEojVYZOooool0
1oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1fooooo`00P_ooool00onYZJWoEEEEooooo`08ooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0M_ooool008?ooooo00?o8B4Q
ooooooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01?ooool3o`0002gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1fooooo`00Poooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07Oo
oooo0023ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oooooo0020ooooo`05oa0@4?oooooo
oooooooooolb<S801?ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Moooool0083ooooo1Ol00004ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Oooooo002cooooo`;o0000
;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo002cooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1hooooo`00/oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool0
0;?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07Sooooo002cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1iooooo`00/oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0NOooool00;?ooooo0_l0000aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0N_ooool00;?ooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooo
oooo000007cooooo002cooooo`03o`000?oooooooooo037ooooo1?l0001mooooo`00/oooool00ol0
003oooooooooo`0booooo`;o0000O_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo
0_l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00S?ooool01OlQ8B7o0000o`000?m4A4CogMgM0=Oooooo002?ooooo`03ogMgMolb<S;ooooo
03[ooooo00?o^[Zjoc8b<_ooool00_ooool01?l0003oooooooooool00008ooooo`03ogMgMomVIVKo
oooo00Sooooo00?oIVIVogMgMoooool01_ooool00ol0003o^[Zjooooo`1dooooo`00T?ooool00ol0
003oooooooooo`0jooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05
ooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd01_ooool2oc8b<WGooooo001Coooo
o`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0_ooool01?l@413o0000o`000?ooool2o`000004oa0@
4?ooooook^k^oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oeEEEOo^k^ko
oooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000_ooool01?l@413o0000o`00
0?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o410@olc<c?l00004ooooo`;o00000_ooool0
1ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?ooooook^k^
oeEEE@;o000000KoEEEEonk^k_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@00Kooooo
00OoV9RHoa0@4?l0003o0000ojVYZOoooooo000000;ooooo00?o0000ooooooooool01Oooool00omE
EEGoV9RHooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7ofIVI_ooool01Oooool00on7
QhOo0000okZj^P0;ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01oooool0
1Om4A4Co0000o`000?lb<S;ogMgM05Cooooo001Cooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q
0oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2
ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00005ooooo`04o`000?ooooooooooo`0000;ooooo00So0000oooooomEEEGo
MgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00007ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ol00008ooooo`03
o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03onk^k_l0003o
oooo00Gooooo00?oc<c<o`000?l@41003?ooool01_l0003ooooooooooooooooo0000ooooo`Ko0000
1_ooool00omgMgOo<S8booooo`1Cooooo`00Doooool01_lQ8B7oooooooooooooooook^k^o`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00005oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?ok^k^o`000?ooool01_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40_ooooo00?o<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`03o`000?oooooo
oooo01?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo05;ooooo001D
ooooo`05omgMgOnHV9SoMgMgoa0@4?mVIVH00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1_l0003oooooooooooooooook^k^o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000005o`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03onk^k_l0003o
oooo00Kooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00[ooooo00?o<S8booooooooool0
0oooool01?o^k^ko8B4Qoa0@4?o^k^h4ooooo`03o`000?oooooooooo01?ooooo00Ko0000oooooooo
ooooooooo`000?ooool6o`0000Kooooo00?oMgMgoc8b<_ooool0Doooool005?ooooo00GoIVIVoa0@
4?mEEEGoQhN7okZj^P04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoMgMgoooo
ooooooooMgMgoeEEE@;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00Ko
EEEEogMgMoooooook^k^oeEEEOl00005ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooo
ooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Gooooo00Go0000ogMg
MoooooooZJVYo`000002ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMg
ooooooo^k^koEEEEo`0000Oooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700[ooooo00?o
0000onk^k_ooool00oooool01?lQ8B7oMgMgogMgMolb<S83ooooo`03onk^k_l0003ooooo01Cooooo
00Go0000ohN7QoooooooZJVYo`00000:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0E?ooool005?o
oooo00Ko0000onk^k_ooooooooooolc<c?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00_oo
ool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^ko
oooooa0@40Go00001?ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000[o
V9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@0oooool02ol@413o0000ob4Q8Ol0
003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00004
ooooo`05o`000?mgMgOo0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;o
oooo00Kok^k^oeEEEOl0003o410@olc<c?l00007ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00?o
0000ooooooooool02?ooool00omEEEGoMgMgooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
MgMgoeEEEOooool04oooool00ol@413o0000ogMgM`02o`000003oiRHV?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool005?ooooo00Ko<S8bohN7Qoooooook^k^ofIVI_l00003ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool00omVIVKoQhN7ooooo`0;ooooo`03omgM
gOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd09?ooool00ol0003oooooooooo`1Fooooo`00Dooo
ool01_o^k^koA4A4o`000?l0003o<S8boa0@40?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?oZJVYodA4A?ooool03?ooool00omgMgOo
IVIVooooo`08ooooo`03ofIVI_mgMgOooooo02Cooooo1?l0001Eooooo`00Foooool00ol@413o0000
ooooo`0Pooooo`03oa0@4?oooooooooo02gooooo00?o410@o`000?ooool04Oooool2o`000:Cooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-9.21355, -918856, \
0.0641612, 11355.4}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 6.3", "Subsubtitle",
  CellTags->"c:44"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " A rope consists of a thin segment of length ",
  Cell[BoxData[
      \(TraditionalForm\`L/2\)]],
  " and mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1\)]],
  " and a thick segment of equal length and mass ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_2 = 3\ \[Rho]\_1\)]],
  ". The rope is stretched between posts, and is under constant tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". Find and plot the spatial form of the first four eigenmodes, using a \
grid method, and find the corresponding frequencies.  Use a sufficiently fine \
grid so  that all the frequencies are accurate to within 1%. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Perform the analysis using the WKB-shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Find the WKB eigenmodes of a string with fixed ends, and with nonuniform \
mass density but uniform tension and of Length ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  ", with propagation speed ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\  = \ exp(2\ x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < x < 1\)\)\)]],
  ", and find the frequencies of the first 5 modes."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Compare the first two modes and their frequencies with the eigenmodes \
determined via the shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these eigenmodes to solve the following problem: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, 0)\  = \ 0\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \(y(x, 0)\) = \ x(1 - x)\)]],
  ".  Make an animation of the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  " .  "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c) using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c) using the grid method."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  "  A vertically hanging rope has mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = \ 1\)]],
  " kg/m, and is attached between floor and ceiling and given tension ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ 1\)]],
  " newton at the base. (See Fig. ",
  ButtonBox["6.15",
    ButtonData:>"Fig. 6.15",
    ButtonStyle->"Hyperlink"],
  ".) Transverse waves on the rope,  of amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\)]],
  ", satisfy the following differential equation: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(z, 
            t)\) = \(\[PartialD]\/\[PartialD]z\) \((\(\(c(
                    z)\)\^2\) \(\[PartialD]\/\[PartialD]z\) y)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c(z)\  = \ \@\(T/\[Rho]\  + \ g\ z\)\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSince the rope is attached to the ceiling and the floor, the boundary \
conditions on the waves are ",
  Cell[BoxData[
      \(TraditionalForm\`u(0, t)\  = \ \(u(L, t)\  = \ 0\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"3", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is the height of the ceiling."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008b0001GB000`400?l00000o`00003ooooooooo
ooooocCooooo003ooooooooooooo=?ooool00?ooooooooooooldooooo`00ooooooooooooocCooooo
003ooooooooooooo=?ooool00?ooooooooooooldooooo`00ooooooooooooocCooooo003ooooooooo
oooo=?ooool00?ooooooooooooldooooo`003Ooooooo0?ooool0oooo603oool?ooooo`003OoooomL
0?ooo`<000006`3oool2000001X0oooo00<0P8200000000000000P00000I0?ooo`040820P0000000
0000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?ooo`@0
00006P3oool01020P800000000000020P80J0?ooo`<000006P3oool3000001X0oooo00@0P8200000
00000000P8206P3oool00`20P80000000000000J0?ooo`oooooo000=oooooe`0oooo00@0`<300000
00000000@4106P3oool01010@400000000000030`<0I0?ooo`050410@0000000000000000020P800
6@3oool01010@400000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool05`3oool300000003
0820P03oool0oooo01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@00000000000
0820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P82001X0oooo
0`00000J0?ooo`040410@000000000000410@1X0oooo00<0@4100000000000006P3oool01010@400
000000000020P80I0?ooo`040<30`000000000000410@1T0oooo3oooool000goooooG@3oool40000
01X0oooo0`00000J0?ooo`@000006@3oool01@20P8000000000000000000P82001T0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool05`3o
ool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo
0`00000K0?ooo`80000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0
oooo00<0P8200000000000006@3oool?ooooo`003OoooomM0?ooo`050<30`0000000000000000020
P8006@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01020
P800000000000000000J0?ooo`040820P000000000000410@1T0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106P3oool30000
01X0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000000000000410@1T0oooo00D0
`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P82000000000
0000@4106P3oool3000000030<30`03oool0oooo01D0oooo3oooool000goooooG`3oool3000001X0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`050820P0000000000000000020P8006@3oool01020
P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo0`00000J
0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`@000006P3oool01020P80000000000
0000000I0?ooo`@000006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000001L0
oooo3oooool000goooooG`3oool01@20P8000000000000000000`<3001T0oooo00<0@41000000000
00006P3oool01@20P8000000000000000000`<3001P0oooo00D0`<3000000000000000000410@00I
0?ooo`040<30`00000000000000001X0oooo00@0@410000000000000`<306P3oool3000000030<30
`03oool0oooo01L0oooo00@0P820000000000000P8206@3oool01030`<00000000000010@40I0?oo
o`050<30`0000000000000000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0
@410000000000000P8206P3oool2000000030410@03oool0oooo01L0oooo00D0`<30000000000000
00000410@00I0?ooo`030<30`0000000000001L0oooo3oooool000goooooH03oool01020P8000000
00000010@40J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@10@4000000000000000000P820
01T0oooo00@0@410000000000000P8206P3oool01010@400000000000030`<0I0?ooo`040820P000
000000000820P1T0oooo00@0`<3000000000000000006P3oool01010@400000000000030`<0I0?oo
o`040820P00000000000000001T0oooo00<0P8200000000000000P00000J0?ooo`040410@0000000
00000820P1T0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000030`<00
6@3oool01010@400000000000030`<0J0?ooo`030000003oool0oooo01D0oooo3oooool000gooooo
H@3oool01020P800000000000000000J0?ooo`<000006P3oool4000001X0oooo0`00000J0?ooo`04
0820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@20P800000000000000
0000P82001T0oooo00D0P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool0
603oool2000000030820P03oool0oooo01P0oooo0`00000J0?ooo`030820P03oool0oooo01D0oooo
3oooool000goooooH@3oool01@30`<000000000000000000@41001T0oooo00@0`<30000000000000
P8206P3oool01010@400000000000010@40I0?ooo`050820P0000000000000000030`<006@3oool0
1010@400000000000000000I0?ooo`040<30`000000000000410@1X0oooo0`0000000`10@400oooo
0?ooo`0G0?ooo`040820P00000000000000001X0oooo00@0@410000000000000P8206@3oool40000
00030820P03oool0oooo01L0oooo00@0P820000000000000@4106@3oool01030`<00000000000010
@40J0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00`0?ooo`oo
oooo000=ooooof<0oooo0`00000K0?ooo`8000006P3oool00`20P800000000000002000001T0oooo
00@0P82000000000000000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000
000000006P3oool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00
000J0?ooo`<000006P3oool01020P800000000000020P80`0?ooo`oooooo000=ooooof<0oooo00@0
`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050410@000000000000000
0020P8006@3oool01010@400000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool05`3oool3
000000030820P03oool0oooo01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000@410
01X0oooo0`00000J0?ooo`040410@000000000000410@1X0oooo00<0@4100000000000006P3oool0
1010@400000000000020P80_0?ooo`oooooo000=ooooof@0oooo1000000J0?ooo`<000006P3oool4
000001T0oooo00D0P82000000000000000000820P00I0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`@000006P3oool3000000030820P03oool0oooo01L0oooo00@0P820000000000000
P8206P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<000006`3oool200000003
0820P03oool0oooo01L0oooo00D0P82000000000000000000820P00^0?ooo`oooooo000=ooooofD0
oooo00@0@410000000000000P8206@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<30
0?ooo`3oool05P3oool01020P800000000000000000J0?ooo`040820P000000000000410@1T0oooo
00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0P8200000
00000000@4106P3oool3000001X0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000
000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820
P1T0oooo00@0P820000000000000@410;P3oool?ooooo`003OoooomV0?ooo`040410@00000000000
0820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000@41001T0oooo
00D0P82000000000000000000<30`00I0?ooo`040410@000000000000410@1X0oooo0`00000J0?oo
o`040820P000000000000820P1T0oooo00@0`<30000000000000@4106P3oool01010@40000000000
0030`<0I0?ooo`050820P0000000000000000030`<006@3oool01020P800000000000000000I0?oo
o`040820P00000000000000001X0oooo00@0P820000000000000`<306@3oool01@20P80000000000
00000000`<3002`0oooo3oooool000goooooIP3oool01@20P8000000000000000000P82001T0oooo
00<0P8200000000000006`3oool3000000030820P03oool0oooo01L0oooo1000000J0?ooo`<00000
6P3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0
oooo0`00000J0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?oo
o`040820P00000000000000001X0oooo0`00000J0?ooo`@00000;03oool?ooooo`003OoooomW0?oo
o`040820P000000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G0?ooo`050410@0000000
000000000020P8006@3oool01010@400000000000020P80J0?ooo`040410@000000000000<30`1T0
oooo00@0P820000000000000P8206@3oool01030`<00000000000000000J0?ooo`040410@0000000
00000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00000000000002000001X0oooo
00@0@410000000000000P8206@3oool3000000030410@03oool0oooo01L0oooo00D0`<3000000000
000000000<30`00I0?ooo`040410@000000000000<30`2/0oooo3oooool000goooooJ03oool01020
P800000000000000000J0?ooo`<000006P3oool4000001X0oooo0`00000J0?ooo`040820P0000000
0000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0
oooo00D0P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool0603oool20000
00030820P03oool0oooo01P0oooo0`00000[0?ooo`oooooo000=ooooofP0oooo00D0`<3000000000
000000000410@00I0?ooo`040<30`000000000000820P1X0oooo00@0@410000000000000@4106@3o
ool01@20P8000000000000000000`<3001T0oooo00@0@41000000000000000006@3oool01030`<00
000000000010@40J0?ooo`<0000000<0@4100?ooo`3oool05`3oool01030`<00000000000000000J
0?ooo`040410@000000000000820P1T0oooo100000000`20P800oooo0?ooo`0G0?ooo`040820P000
000000000410@1T0oooo00@0`<30000000000000@4106P3oool01020P800000000000030`<0I0?oo
o`050820P0000000000000000030`<00:@3oool?ooooo`003Ooooom?0?ooo`030820P03oool0oooo
01P0oooo0`00000K0?ooo`8000006P3oool00`20P800000000000002000001T0oooo00@0P8200000
0000000000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3o
ool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo
100000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`<0
00006P3oool01020P800000000000020P80Y0?ooo`oooooo000=ooooodl0oooo00<000000?ooo`3o
ool0603oool01030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0@410
00000000000000000820P00I0?ooo`040410@000000000000820P1X0oooo0`0000000`20P800oooo
0?ooo`0G0?ooo`<0000000<0P8200?ooo`3oool05`3oool01@30`<000000000000000000`<3001T0
oooo00@0@410000000000000P8206@3oool01020P800000000000010@40I0?ooo`050<30`0000000
000000000010@4006P3oool3000000030820P03oool0oooo01L0oooo00@0@410000000000000@410
6P3oool00`10@40000000000000J0?ooo`040410@000000000000820P2P0oooo3oooool000gooooo
C`3oool2000000030<30`03oool0oooo01L0oooo00D0P82000000000000000000<30`00I0?ooo`03
0410@0000000000001X0oooo00D0P82000000000000000000820P00H0?ooo`050<30`00000000000
00000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P820
6@3oool01@20P8000000000000000000`<3001T0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`04
0<30`000000000000410@1X0oooo0`0000000`10@400oooo0?ooo`0H0?ooo`040410@00000000000
0<30`1T0oooo00@0@410000000000000P8206P3oool2000000030410@03oool0oooo01L0oooo00D0
`<3000000000000000000820P00W0?ooo`oooooo000=ooooodl0oooo0`00000J0?ooo`040820P000
000000000820P1X0oooo0`00000J0?ooo`@0000000<0P8200?ooo`3oool05`3oool3000001/0oooo
0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000020P80J0?ooo`<0
00006P3oool3000001X0oooo00<0P8200000000000000P00000J0?ooo`<000006P3oool300000003
0820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool3000002L0oooo3oooool000go
ooooC`3oool01030`<00000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820
000000000000@4106@3oool01@30`<000000000000000000@41001T0oooo00D0P820000000000000
00000<30`00I0?ooo`040410@000000000000410@1X0oooo0`00000J0?ooo`040820P00000000000
0820P1T0oooo00@0`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050820
P0000000000000000030`<006@3oool01020P800000000000000000I0?ooo`040820P00000000000
000001X0oooo00@0P820000000000000`<306@3oool01@20P8000000000000000000`<3002D0oooo
3oooool000goooooD@3oool2000000030820P03oool0oooo01L0oooo00D0P8200000000000000000
0820P00I0?ooo`030820P0000000000001/0oooo1000000I0?ooo`@000006P3oool3000001X0oooo
00@0P820000000000000P8206P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<0
00006P3oool01020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020
P800000000000000000J0?ooo`<000006P3oool4000002D0oooo3oooool000goooooD@3oool01010
@400000000000020P80I0?ooo`040820P000000000000410@1X0oooo0`0000000`30`<00oooo0?oo
o`0G0?ooo`050410@0000000000000000010@4006@3oool01010@400000000000020P80J0?ooo`04
0410@000000000000<30`1T0oooo00@0P820000000000000P8206@3oool01030`<00000000000000
000J0?ooo`040410@000000000000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00
000000000002000001X0oooo00@0@410000000000000P8206@3oool3000000030410@03oool0oooo
01L0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000<30`2@0oooo3ooo
ool000goooooDP3oool3000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo1000
000J0?ooo`<000006P3oool01020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0
5`3oool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0
oooo00D0P82000000000000000000820P00I0?ooo`050820P0000000000000000020P8006@3oool4
000001X0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`<00000903oool?ooooo`003OoooomC0?oo
o`80000000<0@4100?ooo`3oool05`3oool01@30`<000000000000000000@41001T0oooo00@0`<30
000000000000P8206P3oool01010@400000000000010@40I0?ooo`050820P0000000000000000030
`<006@3oool01010@400000000000000000I0?ooo`040<30`000000000000410@1X0oooo0`000000
0`10@400oooo0?ooo`0G0?ooo`040<30`00000000000000001X0oooo00@0@410000000000000P820
6@3oool4000000030820P03oool0oooo01L0oooo00@0P820000000000000@4106@3oool01@30`<00
0000000000000000`<3001T0oooo00@0P820000000000000`<306@3oool01@20P800000000000000
0000`<300280oooo3oooool000goooooD`3oool01030`<00000000000010@40J0?ooo`040410@000
000000000<30`1X0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`030<30`0000000000000800000
00<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?ooo`040820P000000000000410
@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00@0
P820000000000000@4106@3oool01@30`<000000000000000000P82001T0oooo00D0@41000000000
000000000820P00I0?ooo`040<30`000000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G
0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000@4108P3oool?ooooo`003Ooo
oomE0?ooo`8000006`3oool3000001X0oooo00@0P820000000000000P8206P3oool3000000030820
P03oool0oooo01L0oooo00@0P82000000000000000006P3oool4000001T0oooo0`0000000`20P800
oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?oo
o`<000006P3oool4000001X0oooo1000000I0?ooo`040820P00000000000000001X0oooo00<0P820
0000000000006P3oool01020P800000000000000000Q0?ooo`oooooo000=oooooeD0oooo00@0P820
000000000000`<306@3oool01@20P8000000000000000000`<3001T0oooo00<0@410000000000000
6P3oool01@30`<000000000000000000P82001P0oooo00D0`<3000000000000000000410@00I0?oo
o`050<30`0000000000000000030`<006@3oool01010@400000000000020P80I0?ooo`050820P000
0000000000000030`<006@3oool3000000030820P03oool0oooo01L0oooo00@0`<30000000000000
@4106P3oool3000000030410@03oool0oooo01P0oooo00@0@410000000000000`<306@3oool01020
P800000000000020P80J0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30`<00000000000000
0000P8200200oooo3oooool000goooooEP3oool3000001X0oooo00@0P820000000000000P8206P3o
ool3000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool3000001X0oooo0`00
00000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`<00000
6P3oool00`20P800000000000002000001X0oooo0`00000J0?ooo`040820P000000000000820P1T0
oooo00@0P82000000000000000006P3oool300000200oooo3oooool000goooooEP3oool01030`<00
000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106@3o
ool01@30`<000000000000000000@41001T0oooo00D0P82000000000000000000<30`00I0?ooo`05
0410@0000000000000000030`<006@3oool3000001X0oooo00@0P820000000000000P8206@3oool0
1030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0P820000000000000
00000<30`00I0?ooo`040820P00000000000000001T0oooo00@0`<3000000000000000006P3oool0
1020P800000000000030`<0I0?ooo`050820P0000000000000000030`<007P3oool?ooooo`003Ooo
oomH0?ooo`80000000<0P8200?ooo`3oool05`3oool01@20P8000000000000000000P82001T0oooo
00<0P8200000000000006`3oool4000001T0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool0
5`3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0
oooo0`00000J0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?ooo`0G0?oo
o`040820P00000000000000001X0oooo0`00000J0?ooo`@000007P3oool?ooooo`003OoooomH0?oo
o`040410@000000000000820P1T0oooo00@0P820000000000000@4106P3oool3000000030<30`03o
ool0oooo01L0oooo00D0@41000000000000000000410@00I0?ooo`040410@000000000000820P1X0
oooo00@0@410000000000000`<306@3oool01020P800000000000020P80I0?ooo`040<30`0000000
0000000001X0oooo00@0@410000000000000`<306@3oool01020P800000000000000000I0?ooo`03
0<30`00000000000008000006P3oool01010@400000000000020P80I0?ooo`<0000000<0@4100?oo
o`3oool05`3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P8207@3o
ool?ooooo`003OoooomI0?ooo`<000006P3oool01020P800000000000000000J0?ooo`<000006P3o
ool4000001X0oooo0`00000J0?ooo`040820P00000000000000001X0oooo00@0P820000000000000
P8206@3oool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo
01L0oooo00D0P82000000000000000000820P00I0?ooo`050820P0000000000000000020P8006@3o
ool4000001X0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool06P3o
ool?ooooo`003OoooomJ0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30`<00000000000000
0000@41001T0oooo00@0`<30000000000000P8206P3oool01010@400000000000010@40I0?ooo`05
0820P0000000000000000030`<006@3oool01020P800000000000000000I0?ooo`040<30`0000000
00000410@1X0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`040<30`00000000000000001X0oooo
00@0@410000000000000P8206@3oool4000000030820P03oool0oooo01L0oooo00@0P82000000000
0000@4106@3oool01@30`<000000000000000000`<3001T0oooo00@0P820000000000000`<306@3o
ool01@20P8000000000000000000`<3001/0oooo3oooool000goooooFP3oool01030`<0000000000
0010@40J0?ooo`040410@000000000000<30`1X0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?oo
o`040<30`000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P820
01T0oooo00D0@41000000000000000000820P00I0?ooo`040<30`000000000000410@1X0oooo0`00
00000`30`<00oooo0?ooo`0G0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000
@4106`3oool?ooooo`003OoooomL0?ooo`8000006`3oool3000001X0oooo00@0P820000000000000
P8206P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool40000
01T0oooo0`0000000`20P800oooo0?ooo`0H0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020
P800000000000000000J0?ooo`<000006P3oool4000001X0oooo1000000I0?ooo`040820P0000000
0000000001X0oooo00<0P8200000000000006`3oool3000001X0oooo3oooool000goooooG03oool0
1020P800000000000030`<0I0?ooo`050820P0000000000000000030`<006@3oool00`10@4000000
0000000J0?ooo`050<30`0000000000000000020P800603oool01@30`<000000000000000000@410
01T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1T0oooo00D0
P82000000000000000000820P00I0?ooo`<0000000<0P8200?ooo`3oool05`3oool01030`<000000
00000010@40J0?ooo`<0000000<0@4100?ooo`3oool0603oool01010@400000000000030`<0I0?oo
o`040820P000000000000820P1X0oooo0P0000000`10@400oooo0?ooo`0H0?ooo`040410@0000000
00000820P1T0oooo3oooool000goooooG@3oool3000001X0oooo00@0P820000000000000P8206P3o
ool3000001X0oooo100000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool3000001X0oooo0`00
00000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`<00000
6P3oool00`20P800000000000002000001X0oooo0`00000J0?ooo`040820P000000000000820P1T0
oooo00@0P82000000000000000006P3oool3000001T0oooo3oooool000goooooG@3oool01030`<00
000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P820000000000000@4106@3o
ool01@30`<000000000000000000@41001T0oooo00D0P82000000000000000000<30`00I0?ooo`05
0410@0000000000000000030`<006@3oool3000001X0oooo00@0P820000000000000@4106@3oool0
1030`<00000000000010@40J0?ooo`040410@000000000000<30`1T0oooo00D0P820000000000000
00000<30`00I0?ooo`050820P0000000000000000030`<00603oool01030`<00000000000000000J
0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00G0?ooo`oooooo
000=oooooel0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`050820P0000000000000000020P800
6@3oool00`20P80000000000000K0?ooo`@000006@3oool4000001X0oooo0`0000000`20P800oooo
0?ooo`0G0?ooo`040820P000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0H0?ooo`<0
00006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000000030820P03oool0oooo
01L0oooo00@0P82000000000000000006P3oool3000001X0oooo1000000G0?ooo`oooooo000=oooo
oel0oooo00@0@410000000000000P8206@3oool01020P800000000000010@40J0?ooo`<0000000<0
`<300?ooo`3oool05`3oool01@10@4000000000000000000@41001T0oooo00@0@410000000000000
P8206P3oool01010@400000000000030`<0I0?ooo`040820P000000000000820P1T0oooo00@0`<30
00000000000000006P3oool01010@400000000000030`<0I0?ooo`040820P00000000000000001T0
oooo00<0`<300000000000000P00000J0?ooo`040410@000000000000820P1T0oooo0`0000000`10
@400oooo0?ooo`0G0?ooo`050<30`0000000000000000030`<006@3oool00`10@40000000000000G
0?ooo`oooooo000=ooooof00oooo00@0P820000000000000`<306@3oool01@20P800000000000000
0000`<3001T0oooo00@0@410000000000000`<306@3oool01@20P8000000000000000000`<3001T0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`050<30`0000000000000000020P8006@3oool01020
P800000000000020P80J0?ooo`040410@000000000000<30`1T0oooo00@0@410000000000000P820
6@3oool01020P800000000000010@40I0?ooo`050<30`0000000000000000010@4006@3oool01@30
`<000000000000000000P82001T0oooo00@0@41000000000000000006P3oool00`10@40000000410
@00J0?ooo`8000005`3oool?ooooo`003OoooomQ0?ooo`<000006P3oool4000001X0oooo0P000000
0`20P800oooo0?ooo`0H0?ooo`040820P00000000000000001X0oooo0`0000000`20P800oooo0?oo
o`0H0?ooo`<000006P3oool3000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo
00@0P82000000000000000006@3oool5000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3o
ool05`3oool01020P800000000000020P80J0?ooo`030000003oool0oooo01D0oooo3oooool000go
ooooH@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000`<306P3oool2
000000030820P03oool0oooo01L0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0F
0?ooo`040<30`00000000000000001X0oooo00@0`<30000000000000@4106@3oool01@30`<000000
000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01020P800000000000010@40I
0?ooo`050<30`0000000000000000020P8006@3oool01@10@4000000000000000000P82001T0oooo
00@0`<30000000000000@4106P3oool3000000030<30`03oool0oooo01L0oooo00@0P82000000000
0000P8206@3oool00`30`<00oooo0?ooo`0E0?ooo`oooooo000=ooooof<0oooo0P0000000`20P800
oooo0?ooo`0H0?ooo`<000006P3oool01020P800000000000020P80J0?ooo`<0000000<0P8200?oo
o`3oool05`3oool01020P800000000000000000J0?ooo`@000006@3oool3000000030820P03oool0
oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo0`00
000J0?ooo`@000006P3oool4000001T0oooo00@0P82000000000000000006P3oool00`20P8000000
0000000a0?ooo`oooooo000=ooooof<0oooo00@0P820000000000000`<306@3oool01@20P8000000
000000000000`<3001T0oooo00<0@4100000000000006P3oool01@30`<000000000000000000P820
01P0oooo00D0`<3000000000000000000410@00I0?ooo`050<30`0000000000000000030`<006@3o
ool01010@400000000000020P80I0?ooo`050820P0000000000000000020P8006@3oool01020P800
000000000020P80I0?ooo`050<30`0000000000000000030`<006@3oool3000000030410@03oool0
oooo01P0oooo00@0@410000000000000`<306@3oool01020P800000000000020P80J0?ooo`800000
00<0@4100?ooo`3oool0;P3oool?ooooo`003OoooomT0?ooo`<000006P3oool01020P80000000000
0020P80J0?ooo`<000006P3oool4000000030820P03oool0oooo01L0oooo0`00000K0?ooo`<00000
6P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000000000006P3oool3000001X0
oooo0`0000000`20P800oooo0?ooo`0G0?ooo`030820P00000000000008000006P3oool3000001X0
oooo00@0P820000000000000P8206@3oool01020P800000000000000000_0?ooo`oooooo000=oooo
ofD0oooo00<0@4100000000000006P3oool01010@400000000000020P80I0?ooo`040820P0000000
00000410@1T0oooo00D0`<3000000000000000000410@00I0?ooo`050820P0000000000000000030
`<006@3oool01@10@4000000000000000000`<3001T0oooo0`00000J0?ooo`040820P00000000000
0410@1T0oooo00@0`<30000000000000@4106P3oool01010@400000000000030`<0I0?ooo`050820
P0000000000000000030`<006@3oool01@20P8000000000000000000`<3001P0oooo00@0`<300000
0000000000006P3oool01020P800000000000030`<0^0?ooo`oooooo000=ooooofH0oooo0P000000
0`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000020P8006@3oool01030`<0000000000
0020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01@20P8000000000000000000`<3001T0
oooo00@0P820000000000000@4106@3oool01030`<00000000000010@40J0?ooo`040410@0000000
00000410@1X0oooo0`00000J0?ooo`040820P000000000000820P1T0oooo00D0P820000000000000
00000820P00I0?ooo`040820P000000000000410@1T0oooo00D0`<3000000000000000000<30`00I
0?ooo`040410@000000000000820P2d0oooo3oooool000goooooIP3oool01020P800000000000000
000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo00<0P8200000000000000P00
000I0?ooo`040820P000000000000820P1X0oooo00@0P820000000000000P8206P3oool3000001X0
oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`00000J0?ooo`@000006P3oool01020
P800000000000000000I0?ooo`@000006P3oool3000000030820P03oool0oooo02X0oooo3oooool0
00goooooI`3oool01020P800000000000030`<0I0?ooo`050820P0000000000000000030`<006@3o
ool01010@400000000000030`<0I0?ooo`050820P0000000000000000030`<006@3oool300000003
0820P03oool0oooo01L0oooo00D0`<3000000000000000000820P00I0?ooo`040820P00000000000
0820P1X0oooo00@0@410000000000000`<306@3oool01010@400000000000020P80I0?ooo`040<30
`000000000000410@1T0oooo00D0`<3000000000000000000410@00I0?ooo`050<30`00000000000
00000020P8006@3oool01010@400000000000000000J0?ooo`030410@0000000@41002`0oooo3ooo
ool000goooooJ03oool3000001X0oooo1000000J0?ooo`80000000<0P8200?ooo`3oool0603oool0
1020P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool0603oool3000001X0oooo0`00
000J0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`040820P00000000000000001T0
oooo1@00000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo00@0P82000000000
0000P820:`3oool?ooooo`003OoooomX0?ooo`050<30`0000000000000000030`<006@3oool01010
@400000000000030`<0J0?ooo`80000000<0P8200?ooo`3oool05`3oool00`30`<00000000000002
000000030<30`03oool0oooo01H0oooo00@0`<3000000000000000006P3oool01030`<0000000000
0010@40I0?ooo`050<30`0000000000000000030`<006@3oool01010@400000000000020P80I0?oo
o`040820P000000000000410@1T0oooo00D0`<3000000000000000000820P00I0?ooo`050410@000
0000000000000020P8006@3oool01030`<00000000000010@40J0?ooo`<0000000<0`<300?ooo`3o
ool05`3oool01020P800000000000020P80Z0?ooo`oooooo000=ooooodl0oooo00<0P8200?ooo`3o
ool0603oool2000000030820P03oool0oooo01P0oooo0`00000J0?ooo`040820P000000000000820
P1X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000000001X0oooo1000000J
0?ooo`80000000<0P8200?ooo`3oool0603oool3000000030820P03oool0oooo01L0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000J0?ooo`@000006@3oool01020P80000000000
0000000J0?ooo`030820P0000000000002X0oooo3oooool000goooooC`3oool00`10@400oooo0?oo
o`0H0?ooo`040820P000000000000<30`1T0oooo00D0P82000000000000000000<30`00I0?ooo`03
0410@0000000000001X0oooo00D0`<3000000000000000000820P00H0?ooo`050<30`00000000000
00000010@4006@3oool01@30`<000000000000000000`<3001T0oooo00@0@410000000000000P820
6@3oool01@20P8000000000000000000P82001T0oooo00@0P820000000000000P8206@3oool01@30
`<000000000000000000`<3001T0oooo0`0000000`10@400oooo0?ooo`0H0?ooo`040410@0000000
00000<30`1T0oooo00@0P820000000000000P8206P3oool2000000030410@03oool0oooo02L0oooo
3oooool000goooooC`3oool2000000030<30`03oool0oooo01L0oooo00@0P820000000000000P820
6@3oool01030`<00000000000010@40J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@10@400
0000000000000000P82001T0oooo00@0@410000000000000P8206P3oool3000000030820P03oool0
oooo01L0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001T0oooo
00@0@410000000000000`<306@3oool01020P800000000000000000I0?ooo`030<30`00000000000
008000006P3oool01010@400000000000020P80I0?ooo`040820P000000000000410@1T0oooo00@0
`<300000000000000000:03oool?ooooo`003Ooooom?0?ooo`<000006P3oool00`20P80000000000
000J0?ooo`040820P00000000000000001X0oooo0`00000J0?ooo`@000006@3oool01@20P8000000
000000000000P82001T0oooo00D0P82000000000000000000820P00I0?ooo`<000006`3oool30000
01X0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0G
0?ooo`050820P0000000000000000020P8006@3oool3000001/0oooo0P0000000`20P800oooo0?oo
o`0U0?ooo`oooooo000=ooooodl0oooo00@0@410000000000000P8206P3oool2000000030410@03o
ool0oooo01L0oooo00D0`<3000000000000000000820P00I0?ooo`040<30`000000000000820P1X0
oooo100000000`30`<00oooo0?ooo`0F0?ooo`050820P0000000000000000030`<006@3oool01020
P800000000000010@40I0?ooo`040<30`000000000000410@1X0oooo00@0@410000000000000@410
6P3oool3000001X0oooo00@0P820000000000000P8206@3oool01@20P8000000000000000000P820
01T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001T0oooo00@0
@410000000000000P8209P3oool?ooooo`003Ooooom@0?ooo`<0000000<0P8200?ooo`3oool05`3o
ool01020P800000000000000000J0?ooo`<000006P3oool3000000030820P03oool0oooo01L0oooo
00<0P8200000000000000P00000I0?ooo`040820P000000000000820P1X0oooo00@0P82000000000
0000P8206P3oool3000001X0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo0`00000J
0?ooo`@000006P3oool01020P800000000000000000I0?ooo`@000006P3oool3000000030820P03o
ool0oooo02<0oooo3oooool000goooooD03oool01020P800000000000000000J0?ooo`040820P000
000000000<30`1T0oooo00D0P82000000000000000000<30`00I0?ooo`040410@000000000000820
P1T0oooo00D0P82000000000000000000<30`00I0?ooo`<0000000<0P8200?ooo`3oool05`3oool0
1@30`<000000000000000000P82001T0oooo00@0P820000000000000P8206P3oool01010@4000000
00000030`<0I0?ooo`040410@000000000000820P1T0oooo00@0`<30000000000000@4106@3oool0
1@30`<000000000000000000@41001T0oooo00D0`<3000000000000000000820P00I0?ooo`040410
@00000000000000001X0oooo00<0@41000000010@4009@3oool?ooooo`003OoooomA0?ooo`040820
P00000000000000001X0oooo0`00000J0?ooo`@000006P3oool3000001X0oooo00@0P82000000000
000000006P3oool3000000030820P03oool0oooo01P0oooo0`00000J0?ooo`<000006P3oool01020
P800000000000000000J0?ooo`<000006P3oool01020P800000000000000000I0?ooo`D000006P3o
ool3000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000820P2@0oooo
3oooool000goooooDP3oool3000000030410@03oool0oooo01L0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000<30`1X0oooo0P0000000`10@400oooo0?ooo`0G0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool05P3oool01030`<00000000000000000J0?oo
o`040<30`000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000
000000000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000P820
01T0oooo00D0@41000000000000000000820P00I0?ooo`050<30`0000000000000000030`<006@3o
ool3000000030<30`03oool0oooo01L0oooo00@0P820000000000000P8208`3oool?ooooo`003Ooo
oomC0?ooo`040410@000000000000820P1X0oooo00<0@41000000010@4006P3oool3000000030820
P03oool0oooo01L0oooo00@0`<30000000000000@4106P3oool01010@400000000000010@40I0?oo
o`050820P0000000000000000030`<006@3oool01010@400000000000000000J0?ooo`80000000<0
@4100?ooo`3oool0603oool3000000030410@03oool0oooo01L0oooo00D0`<300000000000000000
0<30`00I0?ooo`040410@000000000000820P1T0oooo00D0P82000000000000000000<30`00I0?oo
o`040820P00000000000000001T0oooo00@0`<3000000000000000006P3oool01030`<0000000000
0030`<0R0?ooo`oooooo000=oooooe@0oooo0`00000J0?ooo`040820P000000000000820P1X0oooo
0`0000000`20P800oooo0?ooo`0H0?ooo`8000006`3oool4000001T0oooo1000000J0?ooo`<00000
00<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?ooo`@000006P3oool200000003
0820P03oool0oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`@000006P3oool01020P800
000000000020P80J0?ooo`<000006P3oool300000280oooo3oooool000goooooE@3oool300000003
0<30`03oool0oooo01L0oooo00@0P820000000000000P8206@3oool01030`<00000000000010@40J
0?ooo`040820P000000000000<30`1T0oooo00D0@41000000000000000000820P00I0?ooo`040410
@000000000000820P1X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P000000000000410
@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000<30`1T0oooo00@0
P82000000000000000006@3oool00`30`<00000000000002000001X0oooo00@0P820000000000000
P8206@3oool01020P800000000000010@40I0?ooo`040<30`0000000000000000240oooo3oooool0
00goooooE@3oool01020P800000000000000000J0?ooo`030820P0000000000001X0oooo00@0P820
00000000000000006P3oool3000001X0oooo1000000I0?ooo`050820P0000000000000000020P800
6@3oool01@20P8000000000000000000P82001T0oooo0`00000K0?ooo`<000006P3oool3000001X0
oooo00@0P820000000000000P8206P3oool3000000030820P03oool0oooo01P0oooo0`0000000`20
P800oooo0?ooo`0G0?ooo`<000006`3oool2000000030820P03oool0oooo01h0oooo3oooool000go
ooooEP3oool01010@400000000000020P80J0?ooo`80000000<0@4100?ooo`3oool05`3oool01@30
`<000000000000000000P82001T0oooo00@0`<30000000000000P8206P3oool4000000030<30`03o
ool0oooo01H0oooo00D0P82000000000000000000820P00I0?ooo`040820P000000000000410@1T0
oooo00@0`<30000000000000@4106P3oool01010@400000000000010@40J0?ooo`<000006P3oool0
1020P800000000000020P80I0?ooo`050820P0000000000000000020P8006@3oool01030`<000000
00000010@40I0?ooo`050<30`0000000000000000030`<006@3oool01010@400000000000020P80O
0?ooo`oooooo000=oooooeL0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820P00000000000
000001X0oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool00`20P800000000000002
000001T0oooo00@0P82000000000000000006P3oool01020P800000000000020P80J0?ooo`<00000
6P3oool3000001X0oooo00@0P820000000000000P8206P3oool3000001X0oooo1000000J0?ooo`04
0820P00000000000000001T0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool0703oool?oooo
o`003OoooomG0?ooo`040820P00000000000000001X0oooo00@0P820000000000000`<306@3oool0
1@20P8000000000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01@20P8000000
000000000000`<3001T0oooo0`0000000`10@400oooo0?ooo`0G0?ooo`050<30`000000000000000
0020P8006@3oool01020P800000000000020P80J0?ooo`040410@000000000000<30`1T0oooo00@0
@410000000000000P8206@3oool01030`<00000000000010@40I0?ooo`050<30`000000000000000
0010@4006@3oool01@30`<000000000000000000@41001T0oooo00@0@41000000000000000006P3o
ool00`10@40000000410@00N0?ooo`oooooo000=oooooeP0oooo00D0`<3000000000000000000<30
`00I0?ooo`040410@000000000000820P1T0oooo00@0P82000000000000000006P3oool01020P800
000000000030`<0I0?ooo`050820P0000000000000000020P8006@3oool01010@400000000000010
@40J0?ooo`040410@000000000000<30`1T0oooo00@0@410000000000000P8206@3oool01030`<00
000000000000000J0?ooo`<0000000<0`<300?ooo`3oool05`3oool01@20P8000000000000000000
`<3001P0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0G0?ooo`040410@0000000
00000820P1T0oooo00@0P820000000000000@4106@3oool01@30`<000000000000000000`<3001`0
oooo3oooool000goooooF@3oool4000001X0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`040820
P000000000000820P1X0oooo0`00000J0?ooo`@0000000<0P8200?ooo`3oool05`3oool3000001/0
oooo0`00000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000000J0?oo
o`<000006P3oool3000000030820P03oool0oooo01L0oooo00D0P82000000000000000000820P00J
0?ooo`<0000000<0P8200?ooo`3oool05`3oool3000000030820P03oool0oooo01P0oooo0`00000L
0?ooo`oooooo000=oooooeX0oooo00@0@410000000000000P8206P3oool00`10@40000000410@00J
0?ooo`<0000000<0P8200?ooo`3oool05`3oool01030`<00000000000010@40J0?ooo`040410@000
000000000410@1X0oooo0`0000000`30`<00oooo0?ooo`0G0?ooo`040410@00000000000000001X0
oooo0P0000000`10@400oooo0?ooo`0H0?ooo`<0000000<0@4100?ooo`3oool05`3oool01@30`<00
0000000000000000`<3001T0oooo00@0@410000000000000P8206@3oool01@20P800000000000000
0000`<3001T0oooo00@0P82000000000000000006@3oool01030`<00000000000000000J0?ooo`04
0<30`000000000000<30`1/0oooo3oooool000goooooF`3oool3000001X0oooo00@0P82000000000
0000P8206P3oool3000000030820P03oool0oooo01P0oooo0P00000K0?ooo`@000006@3oool01020
P800000000000000000J0?ooo`<0000000<0P8200?ooo`3oool05`3oool01020P800000000000000
000J0?ooo`@000006P3oool2000000030820P03oool0oooo01P0oooo0`0000000`20P800oooo0?oo
o`0G0?ooo`@000006P3oool01020P800000000000020P80J0?ooo`<000006P3oool3000001/0oooo
3oooool000goooooG03oool3000000030<30`03oool0oooo01L0oooo00@0P820000000000000P820
6@3oool01030`<00000000000010@40J0?ooo`040820P000000000000<30`1T0oooo00D0@4100000
0000000000000820P00I0?ooo`040410@000000000000820P1X0oooo0`0000000`20P800oooo0?oo
o`0G0?ooo`040820P000000000000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`04
0410@000000000000<30`1T0oooo00@0P82000000000000000006@3oool00`30`<00000000000002
000001X0oooo00@0P820000000000000P8206@3oool01020P800000000000010@40J0?ooo`030410
@0000000000001X0oooo3oooool000goooooG03oool01020P800000000000000000J0?ooo`030820
P0000000000001X0oooo00@0P82000000000000000006P3oool3000001X0oooo1000000I0?ooo`05
0820P0000000000000000020P8006@3oool01@20P8000000000000000000P82001T0oooo0`00000K
0?ooo`<000006P3oool3000001X0oooo00@0P820000000000000P8206P3oool3000000030820P03o
ool0oooo01P0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`<000006`3oool2000000030820P03o
ool0oooo01L0oooo3oooool000gooooo@03oool01030`<00P8200820P020P80I0?ooo`040410@000
000000000820P1X0oooo0P0000000`10@400oooo0?ooo`0G0?ooo`050<30`0000000000000000020
P8006@3oool01030`<00000000000020P80J0?ooo`@0000000<0`<300?ooo`3oool05P3oool01@20
P8000000000000000000P82001T0oooo00@0P820000000000000@4106@3oool01@30`<0000000000
00000000`<3001T0oooo00@0@410000000000000@4106P3oool00`10@40000000000000J0?ooo`04
0820P000000000000820P1T0oooo00D0P82000000000000000000820P00I0?ooo`040<30`0000000
00000410@1T0oooo00D0`<3000000000000000000<30`00I0?ooo`040410@000000000000820P1P0
oooo3oooool000gooooo4P3oool00`20P80000000000000;000000030820P03oool0oooo01/0oooo
00<0@4100000000000001@0000000`20P800oooo0?ooo`0E0?ooo`<0000000<0@4100?ooo`3oool0
5`3oool01030`<00000000000000000J0?ooo`040410@000000000000820P1T0oooo00@0P8200000
00000000@4106@3oool00`30`<00000000000002000001D0oooo00D0];Bd0=[JfP3oool0oooo0<30
`003000000030<30`03oool0oooo01L0oooo00@0P820000000000000@4106P3oool01010@4000000
00000030`<0I0?ooo`040820P000000000000820P1T0oooo00@0`<30000000000000@4106P3oool0
1010@400000000000020P80I0?ooo`050410@0000000000000000030`<006@3oool01@20P8000000
000000000000`<3001P0oooo00D0P82000000000000000000820P00I0?ooo`040820P00000000000
0820P1L0oooo3oooool000gooooo4P3oool00`20P80000000000000;000000030820P03oool0oooo
01T0oooo00<0P8200000000000002@0000070?ooool00000/`00000E0?ooo`oooooo000=oooooa<0
oooo1000000:0820P1/0oooo00D0@41000000000000000000<30`0030?ooo`050820P00000000000
00000030`<001P3ooooo00000;<000005@3oool?ooooo`003OoooolD0?ooo`<0000000<0P8200?oo
o`3oool08@3oool4000000H0oooo00@0P82000000000000000001P3ooooo00000;<000005@3oool?
ooooo`003OoooolD0?ooo`050<30`0000000000000000020P8008@3oool01@30`<00000000000000
0000`<3000L0oooo00@0P820000000000000P820X03oool606UYJOl0oooo9`3oool?ooooo`003Ooo
oolE0?ooo`050820P0000000000000000020P8002P3ooolA000000D0oooo00@0P820000000000000
00002@3oool300000:00oooo00<0];Bd06UYJ@1YJFT0101YJFWo0?ooobH0oooo3oooool000gooooo
5P3oool01@20P8000000000000000000P82000T0oooo4@0000050?ooo`<0000000<0P8200?ooo`3o
ool01`3oool01010@400000000000020P82P0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd0?oo
o`3oool0oP3oool00`20P800oooo0?ooo`0Q0?ooo`oooooo000=oooooaL0oooo00D0`<3000000000
000000000410@0080?oooa40P8201@3oool3000000X0oooo00@0P820000000000000P820X@3oool0
0`2?Shl0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0?`0oooo00<0`<300000003oool08P3oool?
ooooo`003OoooolI0?ooo`<0000000<0P8200?ooo`3oool06P3oool01020P800000000000020P80;
0?ooo`<00000XP3oool606UYJOh0oooo00<0P82000000020P8008P3oool?ooooo`003OoooolI0?oo
o`050<30`0000000000000000020P8006`3oool01020P800000000000020P80;0?ooo`<00000X`3o
ool506UYJ@030;Bd]03oool0oooo0?/0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`T0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`<0000000<0P8200?ooo`3oool0603oool0
1020P800000000000020P80;0?ooo`<00000X`3oool00`2d];@0JFUY06UYJ@0306UYJO`0oooo00@0
P82000000000000000008P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool03@3o
ool01@30`<000000000000000000P82000@0oooo4@0000040?ooo`040820P000000000000820P0/0
oooo0`00002T0?ooo`0308n?S`1YJFT0JFUY00<0JFUY00<0];Bd0?ooo`3oool0n03oool01020P800
000000000000000R0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`05
0820P0000000000000000020P8000`3ooolA000000@0oooo00@0P820000000000000P8202`3oool3
00000:@0oooo00<0];Bd06UYJ@1YJFT0101YJFWj0?ooo`D000008@3oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool03`3oool01@20P8000000000000000000P8200080oooo4@20P804
0?ooo`040820P000000000000820P0/0oooo0`00002T0?ooo`030=[JfP1YJFT0JFUY00@0JFUY00<0
f][J0?ooo`3oool0m`3oool500000240oooo3oooool000gooooo2@3oool2000000030820P03oool0
oooo0100oooo00D0`<3000000000000000000410@00F0?ooo`040820P000000000000820P0/0oooo
0`00002U0?ooo`030;Bd]01YJFT0JFUY00@0JFUYn03oool6000000030820P03oool0oooo01h0oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0P8200000000000003000
000E0?ooo`040820P000000000000820P0/0oooo0`00002V0?ooo`L0JFUYm`3oool6000000030820
P03oool0oooo01h0oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0
P8200000000000003000000F0?ooo`<000002P3oool01020P800000000000020P82V0?ooo`030;Bd
]01YJFT0JFUY00@0JFUY00<0f][J0?ooo`3oool0l`3oool00`20P80000000000000500000200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo00L0oooo00<0P8200000000000003000
000F0?ooo`<000002P3oool01020P800000000000020P82W0?ooo`L0JFUYm@3oool800000200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo02`0oooo00@0@4100000000000000000
2@3oool3000000030<30`03oool0oooo0:H0oooo1P1YJFT00`2d];@0oooo0?ooo`3b0?ooo`T00000
7`3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0;03oool01020P80000000000
000000090?ooo`<00000Z@3oool00`2d];@0JFUY06UYJ@0406UYJO<0oooo2P00000O0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`0]0?ooo`<0000000<0@4100?ooo`3oool0103o
ool01030`<00000000000000002Z0?ooo`030=[JfP1YJFT0JFUY00@0JFUY00<0];Bd0?ooo`3oool0
l03oool:000000030820P03oool0oooo01`0oooo3oooool000gooooo2@3oool2000000030820P03o
ool0oooo02h0oooo100000050?ooo`<0000000<0P8200?ooo`3oool0Z@3oool606UYJ@030;Bd]03o
ool0oooo0>l0oooo00<0P8200000000000002@00000N0?ooo`oooooo000=ooooo`T0oooo0P000000
0`20P800oooo0?ooo`0^0?ooo`050820P0000000000000000010@4000`20P80400000:d0oooo1P1Y
JFWa0?ooo`030410@0000000000000T000007P3oool?ooooo`003Oooool90?ooo`80000000<0P820
0?ooo`3oool0<03oool00`10@400000000000005000000030820P03oool0oooo0:`0oooo00<0f][J
06UYJ@1YJFT0101YJFW`0?ooo`d000007@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?oo
o`3oool0<P3oool500000;40oooo1P1YJFT00`2d];@0oooo0?ooo`3]0?ooo`d000007@3oool?oooo
o`003Oooool90?ooo`80000000<0P8200?ooo`3oool0j03oool00`2d];@0JFUY06UYJ@0306UYJ@03
08n?S`3oool0oooo0>`0oooo3P0000000`20P800oooo0?ooo`0J0?ooo`oooooo000=ooooo`T0oooo
0P0000000`20P800oooo0?ooo`3Y0?ooo`H0JFUYkP3oool>000000030820P03oool0oooo01X0oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo0>T0oooo00<0];Bd06UYJ@1YJFT00`1Y
JFT00`3Jf]X0oooo0?ooo`3Z0?ooo`030820P0000000000000d00000703oool?ooooo`003Oooool9
0?ooo`80000000<0P8200?ooo`3oool0jP3oool506UYJ@030;Bd]03oool0oooo0>X0oooo00<0P820
0000000000003@00000L0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3Z0?oo
o`030;Bd]01YJFT0JFUY00<0JFUYk03oool@000000030820P03oool0oooo01T0oooo3oooool000go
oooo2@3oool2000000030820P03oool0oooo0>/0oooo1P1YJFWZ0?ooo`030820P0000000000000h0
000000<0@4100?ooo`3oool06@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0
k03oool506UYJNX0oooo00<0P8200000000000003`00000K0?ooo`oooooo000=ooooo`T0oooo0P00
00000`20P800oooo0?ooo`3/0?ooo`0308n?S`1YJFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0i`3o
oolB000000030820P03oool0oooo01P0oooo3oooool000gooooo2@3oool2000000030820P03oool0
oooo0>`0oooo00<0];Bd06UYJ@1YJFT00`1YJFWY0?oooa<000006P3oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool0k@3oool506UYJNP0oooo500000000`30`<00oooo0?ooo`0G0?oo
o`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3]0?ooo`H0JFUYj03oool00`20P800
00000000000@000000030820P03oool0oooo01L0oooo3oooool000gooooo2@3oool2000000030820
P03oool0oooo0>h0oooo1@1YJFT00`3Jf]X0oooo0?ooo`3V0?ooo`030<30`020P800000000`00000
00<0P8200<30`03oool06P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0kP3o
ool00`2?Shl0JFUY06UYJ@0206UYJ@0308n?S`3oool0oooo0>`0oooo00@0P820000000000000P820
8P3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0kP3oool00`2d];@0JFUY06UY
J@0306UYJNl0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P000000
0`20P800oooo0?ooo`3_0?ooo`D0JFUY00<0];Bd0?ooo`3oool0k03oool2000000030820P03oool0
oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0>l0oooo1P1YJFW^0?oo
o`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3o
ool0k`3oool00`2d];@0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0>/0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3_0?ooo`030;Bd
]01YJFT0JFUY00<0JFUY00<0];Bd0?ooo`3oool0j`3oool2000000030820P03oool0oooo0200oooo
3oooool000gooooo2@3oool2000000030820P03oool0oooo0?00oooo1P1YJFW]0?ooo`80000000<0
P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0l03oool0
0`2d];@0JFUY06UYJ@0306UYJNd0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
o`T0oooo0P0000000`20P800oooo0?ooo`3a0?ooo`D0JFUY00<0];Bd0?ooo`3oool0jP3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?40
oooo1@1YJFT00`2d];@0oooo0?ooo`3Z0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`00
3Oooool90?ooo`80000000<0P8200?ooo`3oool0l@3oool00`2d];@0JFUY06UYJ@0306UYJN`0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?oo
o`3a0?ooo`030;Bd]01YJFT0JFUY00<0JFUYk03oool2000000030820P03oool0oooo0200oooo3ooo
ool000gooooo2@3oool2000000030820P03oool0oooo0?80oooo1P1YJFW[0?ooo`80000000<0P820
0?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0lP3oool606UY
JN/0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3c0?ooo`D0JFUY00<0f][J0?ooo`3oool0j03oool2000000030820P03oool0oooo0200
oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?<0oooo1@1YJFT00`2d];@0oooo
0?ooo`3X0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0l`3oool00`2?Shl0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>P0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3c
0?ooo`030;Bd]01YJFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0j03oool2000000030820P03oool0
oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?<0oooo00<0f][J06UY
J@1YJFT00`1YJFWZ0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80
000000<0P8200?ooo`3oool0m03oool506UYJNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3d0?ooo`D0JFUYjP3oool2000000030820
P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?@0oooo1@1Y
JFT00`2d];@0oooo0?ooo`3W0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool9
0?ooo`80000000<0P8200?ooo`3oool0m@3oool506UYJNT0oooo0P0000000`20P800oooo0?ooo`0P
0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3e0?ooo`D0JFUYj@3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?D0
oooo1@1YJFWY0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`800000
00<0P8200?ooo`3oool0m@3oool506UYJ@030=[JfP3oool0oooo0>H0oooo0P0000000`20P800oooo
0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3e0?ooo`030;Bd]01Y
JFT0JFUY0080JFUY00<0];Bd0?ooo`3oool0iP3oool2000000030820P03oool0oooo0200oooo3ooo
ool000gooooo2@3oool2000000030820P03oool0oooo0?D0oooo00<0];Bd06UYJ@1YJFT00P1YJFT0
0`2d];@0oooo0?ooo`3V0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?oo
o`80000000<0P8200?ooo`3oool0m@3oool00`2d];@0JFUY06UYJ@0206UYJ@0308n?S`3oool0oooo
0>H0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3e0?ooo`030;Bd]01YJFT0JFUY00<0JFUYj03oool2000000030820P03oool0oooo0200
oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?D0oooo00<0f][J06UYJ@1YJFT0
0`1YJFWX0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0mP3oool506UYJNP0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i@3oool2
000000030820P03oool0oooo0200oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo
0?H0oooo1P1YJFWW0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80
000000<0P8200?ooo`3oool0mP3oool606UYJNL0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`H0JFUYi`3oool2000000030820
P03oool0oooo00h0oooo3`20P8000`30`<00oooo0?ooo`0?ooooo`003Oooool90?ooo`80000000<0
P8200?ooo`3oool0mP3oool00`2d];@0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0>@0oooo0P00
00000`20P800oooo0?ooo`0>0?ooo`l0000000<0P8200?ooo`3oool03oooool000gooooo2@3oool2
000000030820P03oool0oooo0?H0oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3T
0?ooo`80000000<0P8200?ooo`3oool03P3oool00`20P80000000000000<000000030410@03oool0
oooo00oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY
00<0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?oo
o`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0
JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?ooo`oo
oooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo0`00000>0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3f0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0
];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo00l0oooo00@0P820000000000000P820
3@3oool?ooooo`003Oooool90?ooo`80000000<0P8200?ooo`3oool0mP3oool00`2d];@0JFUY06UY
J@0306UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0?0?ooo`040820P000
000000000820P0d0oooo3oooool000gooooo2@3oool2000000030820P03oool0oooo0?H0oooo00<0
];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool03`3o
ool01020P800000000000020P80=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?oo
o`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0100oooo0`00
000=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd
0?ooo`3oool0i03oool2000000030820P03oool0oooo0100oooo0`00000=0?ooo`oooooo000=oooo
o`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool20000
00030820P03oool0oooo0100oooo0`00000=0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800
oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0140
oooo0`00000<0?ooo`oooooo000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0140oooo0`00000<0?ooo`oooooo
000=ooooo`T0oooo0P0000000`20P800oooo0?ooo`3g0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03o
ool2000000030820P03oool0oooo0140oooo0`00000<0?ooo`oooooo000=ooooo`80oooo0P20P80<
000000030410@020P800P8200?80oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P820
0?ooo`3oool04@3oool01010@400000000000030`<0;0?ooo`oooooo000=ooooo`030410@0000000
000001800000l03oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0A
0?ooo`040820P000000000000820P0/0oooo3oooool000gooooo00<0P8200000000000004@000000
0`20P800oooo0?ooo`3^0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0
oooo0140oooo00@0P820000000000000P8202`3oool?ooooo`003Oooool00`20P80000000000000A
000000030820P03oool0oooo0>h0oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P820
0?ooo`3oool04@3oool01030`<00000000000010@40;0?ooo`oooooo000=ooooo`030?ooo`000000
000001400000l@3oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0B
0?ooo`<000002`3oool?ooooo`003Oooool00`3oool000000000000A00000?40oooo1@1YJFT00`2d
];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool04P3oool3000000/0oooo3oooool000go
oooo0P3ooolA00000?80oooo1@1YJFT00`2d];@0oooo0?ooo`3T0?ooo`80000000<0P8200?ooo`3o
ool04P3oool3000000/0oooo3oooool000gooooo0P3ooolA00000?80oooo1@1YJFT00`2d];@0oooo
0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool04P3oool01020P800000000000000000:0?ooo`oo
oooo000=ooooo`80oooo00<0P8200000000000003@0000000`20P800oooo0?ooo`3`0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0i03oool2000000030820P03oool0oooo0180oooo00@0P820000000000000
00002P3oool?ooooo`003Oooool20?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool0
l03oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0B0?ooo`040820
P00000000000000000X0oooo3oooool000gooooo0`3oool?00000?<0oooo1@1YJFT00`2d];@0oooo
0?ooo`3T0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool30?ooo`h00000m03o
ool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=
ooooo`@0oooo3@00000A0?ooo`030<30`020P800P82000/0P82000<0`<300?ooo`3oool0dP3oool5
06UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
o`@0oooo300000000`20P800oooo0?ooo`0?0?ooo`030820P0000000000000/0000000<0P8200?oo
o`3oool0dP3oool506UYJ@030;Bd]03oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?oo
o`oooooo000=ooooo`@0oooo00<0P8200000000000002@0000000`30`<00oooo0?ooo`0?0?ooo`03
0<30`0000000000000/0000000<0@4100?ooo`3oool0d@3oool00`2d];@0JFUY06UYJ@0306UYJ@03
0=[JfP3oool0oooo0>@0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`@0oooo
00<0`<300000000000002@00000C0?ooo`050820P0000000000000000030`<00g03oool00`2d];@0
JFUY06UYJ@0306UYJNL0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`D0oooo
2P00000E0?ooo`040820P0000000000000000=`0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80
000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`P0000000<0@4100?ooo`3oool0
503oool01@10@4000000000000000000`<300=X0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80
000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`P0000000<0P8200?ooo`3oool0
5@3oool400000=X0oooo00<0];Bd06UYJ@1YJFT00`1YJFWW0?ooo`80000000<0P8200?ooo`3oool0
803oool?ooooo`003Oooool60?ooo`030820P0000000000000D0000000<0`<300?ooo`3oool05P3o
ool01@10@4000000000000000000`<300=P0oooo00<0Shn?06UYJ@1YJFT00`1YJFWW0?ooo`800000
00<0P8200?ooo`3oool0803oool?ooooo`003Oooool60?ooo`030820P0000000000000D000006P3o
ool400000=P0oooo1@1YJFWX0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool7
0?ooo`H0000000<0@4100?ooo`3oool06@3oool01010@400000000000010@43G0?ooo`D0JFUYj03o
ool2000000030820P03oool0oooo0200oooo3oooool000gooooo1`3oool00`10@400000000000003
000000030<30`03oool0oooo01X0oooo00D0P82000000000000000000<30`03E0?ooo`D0JFUYj03o
ool2000000030820P03oool0oooo0200oooo3oooool000gooooo1`3oool00`20P800000000000003
000001h0oooo00@0P8200000000000000000e@3oool506UYJNP0oooo0P0000000`20P800oooo0?oo
o`0P0?ooo`oooooo000=ooooo`L0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0M
0?ooo`050410@0000000000000000030`<00dP3oool00`2d];@0JFUY06UYJ@0206UYJ@0308n?S`3o
ool0oooo0>H0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`P0oooo1000000Q
0?ooo`@00000dP3oool00`2d];@0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>H0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooo`P0oooo00@0P820000000000000@4108P3oool0
1@10@4000000000000000000`<300=00oooo00<0];Bd06UYJ@1YJFT00P1YJFT00`2d];@0oooo0?oo
o`3V0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooool90?ooo`80000000<0P820
0?ooo`3oool08@3oool400000=00oooo1@1YJFT00`2d];@0oooo0?ooo`3V0?ooo`80000000<0P820
0?ooo`3oool0803oool?ooooo`003Oooool90?ooo`030410@0000000P82001T0oooo00<0P8200000
000000002`0000000`20P800oooo0?ooo`3=0?ooo`D0JFUY00<0f][J0?ooo`3oool0iP3oool20000
00030820P03oool0oooo0200oooo3oooool000gooooo2@3oool00`20P80000000?ooo`0I0?ooo`03
0820P0000000000000/0000000<0P8200?ooo`3oool0c@3oool506UYJNT0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooo`X0oooo00<000000?ooo`3oool0mP3oool506UYJNT0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0`3oool606UYJNT0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0`3oool506UYJNX0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool00`3Jf]X0JFUY06UYJ@0306UY
JNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool00`2d];@0
JFUY06UYJ@0306UYJNX0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo
0P3oool00`2d];@0JFUY06UYJ@0206UYJ@030;Bd]03oool0oooo0>P0oooo0P0000000`20P800oooo
0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool506UYJ@030;Bd]03oool0oooo0>P0oooo0P00
00000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0P3oool506UYJN/0oooo0P000000
0`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0@3oool606UYJN/0oooo0P0000000`20
P800oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo0@3oool506UYJN`0oooo0P0000000`20P800
oooo0?ooo`0P0?ooo`oooooo000=ooooool0oooo00<0f][J06UYJ@1YJFT00`1YJFW/0?ooo`800000
00<0P8200?ooo`3oool0803oool?ooooo`003Ooooooo0?ooo`030;Bd]01YJFT0JFUY00<0JFUYk03o
ool2000000030820P03oool0oooo0200oooo3oooool000goooooo`3oool00`2?Shl0JFUY06UYJ@02
06UYJ@030;Bd]03oool0oooo0>X0oooo0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=oooo
ooh0oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`3Jf]X0oooo0?ooo`3Z0?ooo`80000000<0P8200?oo
o`3oool0803oool?ooooo`003Oooooon0?ooo`H0JFUYk@3oool2000000030820P03oool0oooo0200
oooo3oooool000goooooo@3oool00`3Jf]X0JFUY06UYJ@0306UYJ@0308n?S`3oool0oooo0>/0oooo
0P0000000`20P800oooo0?ooo`0P0?ooo`oooooo000=ooooood0oooo00<0];Bd06UYJ@1YJFT00`1Y
JFT00`2d];@0oooo0?ooo`3[0?ooo`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooooom
0?ooo`0308n?S`1YJFT0JFUY00<0JFUY00<0f][J0?ooo`3oool0j`3oool2000000030820P03oool0
oooo0200oooo3oooool000goooooo@3oool606UYJNT0oooo3@00000M0?ooo`oooooo000=oooooo`0
oooo00<0f][J06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3S0?ooo`80P820400000000`10@400
P8200<30`00I0?ooo`oooooo000=oooooo`0oooo00<0Shn?06UYJ@1YJFT00`1YJFWV0?oooa@00000
00<0`<300?ooo`3oool05`3oool?ooooo`003Ooooool0?ooo`D0JFUY00<0];Bd0?ooo`3oool0i@3o
oolC000001X0oooo3oooool000gooooon`3oool00`2d];@0JFUY06UYJ@0306UYJ@030=[JfP3oool0
oooo0>D0oooo4P0000000`20P800oooo0?ooo`0H0?ooo`oooooo000=oooooo/0oooo1P1YJFWX0?oo
o`030820P0000000000000l000006`3oool?ooooo`003Ooooooj0?ooo`030=[JfP1YJFT0JFUY00<0
JFUY00<0];Bd0?ooo`3oool0iP3oool00`30`<0000000000000>000000030410@03oool0oooo01T0
oooo3oooool000gooooonP3oool00`2d];@0JFUY06UYJ@0306UYJNX0oooo400000000`20P800oooo
0?ooo`0I0?ooo`oooooo000=ooooooX0oooo1@1YJFT00`2?Shl0oooo0?ooo`3X0?ooo`030820P000
0000000000d0000000<0`<300?ooo`3oool06@3oool?ooooo`003Ooooooi0?ooo`H0JFUY00<0f][J
0?ooo`3oool0j03oool00`30`<0000000000000=000001`0oooo3oooool000gooooon@3oool606UY
JN`0oooo3P0000000`20P800oooo0?ooo`0J0?ooo`oooooo000=ooooooP0oooo00<0];Bd06UYJ@1Y
JFT00`1YJFW]0?ooo`h0000000<0P8200?ooo`3oool06P3oool?ooooo`003Ooooooh0?ooo`D0JFUY
00<0];Bd0?ooo`3oool0k03oool=000001d0oooo3oooool000gooooom`3oool00`2d];@0JFUY06UY
J@0306UYJ@030=[JfP3oool0oooo0>`0oooo3@00000M0?ooo`oooooo000=ooooooL0oooo1P1YJFW_
0?ooo``000007P3oool?ooooo`003Oooooof0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd0?oo
o`3oool0k@3oool00`20P800000000000009000001h0oooo3oooool000gooooomP3oool606UYJO40
oooo2P0000000`20P800oooo0?ooo`0L0?ooo`oooooo000=ooooooD0oooo00<0];Bd06UYJ@1YJFT0
101YJFWa0?ooo`X0000000<0P8200?ooo`3oool0703oool?ooooo`003Ooooooe0?ooo`0308n?S`1Y
JFT0JFUY00<0JFUYl`3oool9000001l0oooo3oooool000gooooom@3oool506UYJ@030;Bd]03oool0
oooo0?40oooo2000000P0?ooo`oooooo000=oooooo@0oooo1P1YJFT00`3Jf]X0oooo0?ooo`3a0?oo
o`030820P0000000000000D00000803oool?ooooo`003Ooooooc0?ooo`030;Bd]01YJFT0JFUY00@0
JFUYm@3oool6000000030820P03oool0oooo01h0oooo3oooool000goooool`3oool606UYJOH0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`0N0?ooo`oooooo000=oooooo80oooo1P1Y
JFT00`2d];@0oooo0?ooo`3e0?ooo`D000008@3oool?ooooo`003Ooooooa0?ooo`030=[JfP1YJFT0
JFUY00@0JFUY00<0f][J0?ooo`3oool0m@3oool00`10@40000000000000200000240oooo3oooool0
00goooool@3oool00`2?Shl0JFUY06UYJ@0306UYJ@030;Bd]03oool0oooo0?H0oooo00@0P8200000
0000000000008P3oool?ooooo`003Ooooooa0?ooo`H0JFUYn@3oool01020P800000000000000000R
0?ooo`oooooo000=oooooo00oooo00<0];Bd06UYJ@1YJFT00`1YJFT00`2d];@0oooo0?ooo`3h0?oo
o`80000000<0P8200?ooo`3oool0803oool?ooooo`003Oooooo_0?ooo`030;Bd]01YJFT0JFUY00@0
JFUYn`3oool00`20P80000000820P00R0?ooo`oooooo000=ooooonl0oooo1P1YJFWl0?ooo`030<30
`0000000oooo0280oooo3oooool000goooookP3oool00`2d];@0JFUY06UYJ@0306UYJOh0oooo00<0
00000?ooo`3oool08@3oool?ooooo`003Oooooo]0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0];Bd
0?ooo`3oool0o`3ooolQ0?ooo`oooooo000=ooooon`0oooo00<0f][J06UYJ@1YJFT00`1YJFT00`2d
];@0oooo0?ooo`3o0?ooob80oooo3oooool000goooook03oool606UYJOl0oooo9@3oool?ooooo`00
3Oooooo[0?ooo`030;Bd]01YJFT0JFUY00<0JFUY00<0f][J0?ooo`3oool0o`3ooolS0?ooo`oooooo
000=ooooonX0oooo00<0];Bd06UYJ@1YJFT0101YJFWo0?ooobH0oooo3oooool000goooooC`3ooonM
0820P0@0=CDeo`20P80B0820P1D0oooo3oooool000goooooC`3ooooo00000;<000005@3oool?oooo
o`003Ooooom?0?ooool00000/`00000E0?ooo`oooooo000=oooooe40oooo0P0000000`30`<00oooo
0?ooo`0N0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<30
0240oooo00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010
@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<3002D0
oooo3oooool000goooooD@3oool300000280oooo1000000Q0?ooo`040820P0000000000000000280
oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?oo
o`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool0
1@20P8000000000000000000P8200240oooo1000000U0?ooo`oooooo000=oooooe40oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@410803oool01@30`<000000000000000000
@4100240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240oooo00@0
@410000000000000@410903oool?ooooo`003OoooomB0?ooo`@000008P3oool3000000030820P03o
ool0oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo1000000Q0?ooo`050820
P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`04
0820P0000000000000000280oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool4
000002<0oooo3oooool000goooooD`3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20
P8000000000000000000`<300240oooo00@0@410000000000000@4108P3oool?ooooo`003OoooomD
0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool4
00000240oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00008P3oool400000240oooo3oooool000goooooE@3oool01010@400000000000010@40Q0?ooo`05
0<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30
00000000000000000410@00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000
P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000020P800
8@3oool01@20P8000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?oo
o`oooooo000=oooooeH0oooo00D0@41000000000000000000<30`00P0?ooo`050<30`00000000000
00000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@410
8@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10
@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P000
0000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000000000000000
0020P8008@3oool01@10@4000000000000000000`<3001h0oooo3oooool000goooooE`3oool40000
0280oooo1000000Q0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`@000008@3oool0
1@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3o
ool01020P800000000000000000R0?ooo`@000008@3oool01@20P8000000000000000000P8200240
oooo1000000N0?ooo`oooooo000=oooooeP0oooo00D0@41000000000000000000<30`00P0?ooo`05
0<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410
000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050820P0000000000000000020
P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000820P00Q
0?ooo`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo
00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00703oool?oooo
o`003OoooomI0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000
000000008P3oool400000240oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool4
00000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000
000Q0?ooo`050820P0000000000000000020P8008@3oool4000001`0oooo3oooool000goooooFP3o
ool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400
0000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000
000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4106`3oool?ooooo`003OoooomK0?ooo`@000008P3oool3000000030820
P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool400000240oooo00@0P820000000000000
00008P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool30000
00030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool4000001X0oooo3oooool0
00goooooG03oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3o
ool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`05
0<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410
000000000000@4108@3oool01@20P8000000000000000000P8200240oooo00D0@410000000000000
00000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4106@3oool?ooooo`003OoooomM0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820000000000000
00000820P00Q0?ooo`040410@000000000000410@240oooo00@0@410000000000000@4108@3oool0
1@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00G0?ooo`oooooo000=oooooeh0oooo1000000R0?ooo`@000008@3oool01@20P80000000000
00000000P8200240oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240
oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?oo
o`@000008@3oool01@20P8000000000000000000P8200240oooo1000000G0?ooo`oooooo000=oooo
oel0oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01010@400
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000820P00Q0?ooo`050820P0000000000000000030
`<00803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000820P00Q
0?ooo`050410@0000000000000000030`<005@3oool?ooooo`003OoooomP0?ooo`@000008P3oool3
000000030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo1000
000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800oooo
0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`050820P000000000000000
0020P8008@3oool4000001D0oooo3oooool000goooooH@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000820P00Q0?ooo`050820P0000000000000000030`<00803o
ool01@30`<000000000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00Q0?ooo`050820P0000000000000000030`<008@3oool00`10@40000000000000E0?oo
o`oooooo000=ooooof80oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800
000000000000000R0?ooo`@000008@3oool400000240oooo00@0P82000000000000000008P3oool4
00000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool400000240oooo00@0
P82000000000000000008P3oool2000001D0oooo3oooool000goooooH`3oool01010@40000000000
0010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P800
0000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000
000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00<0@4100?ooo`3oool0
4`3oool?ooooo`003OoooomT0?ooo`050820P0000000000000000030`<00803oool01@30`<000000
000000000000@4100240oooo00D0P82000000000000000000820P00Q0?ooo`040410@00000000000
0410@240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20
P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@30`<0000000000
00000000P82003H0oooo3oooool000goooooI@3oool01020P800000000000000000R0?ooo`@00000
8@3oool01@20P8000000000000000000P8200240oooo1000000Q0?ooo`@000008@3oool01@20P800
0000000000000000P8200240oooo1000000R0?ooo`@000008@3oool01020P800000000000000000R
0?ooo`@000008@3oool01@20P8000000000000000000P82003D0oooo3oooool000goooooIP3oool0
1@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820
P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040410@00000000000
0410@240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30`00Q0?oo
o`040410@000000000000410@240oooo00D0P82000000000000000000820P00d0?ooo`oooooo000=
ooooofL0oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000
000R0?ooo`@000008@3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@00000
8P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000000000008P3oool400000240
oooo00D0P82000000000000000000820P00c0?ooo`oooooo000=ooooofP0oooo00D0@41000000000
000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P800000000000000
0000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000010
@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300380oooo3oooool000go
ooooJ@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P000000000000000
0280oooo1000000Q0?ooo`@000008@3oool01020P800000000000000000R0?ooo`@000008P3oool3
000000030820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01020P800000000000000
000b0?ooo`oooooo000=ooooofX0oooo00@0@410000000000000@4108@3oool01@30`<0000000000
00000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000000000000000
0010@400803oool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30
`00Q0?ooo`040410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00`0?ooo`oooooo000=ooooof/0oooo00D0P82000000000000000000<30
`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240
oooo00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q
0?ooo`050<30`0000000000000000020P800;`3oool?ooooo`003Ooooom/0?ooo`040820P0000000
000000000280oooo1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000240oooo
1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo1000000Q0?ooo`04
0820P0000000000000000280oooo1000000Q0?ooo`050820P0000000000000000020P800;P3oool?
ooooo`003Ooooom]0?ooo`050410@0000000000000000030`<00803oool01@30`<00000000000000
0000@4100240oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240
oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000P8200240oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000
000000000000`<300240oooo00@0@410000000000000@4108@3oool01@20P8000000000000000000
P82002d0oooo3oooool000goooooKP3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?oo
o`040820P0000000000000000280oooo1000000Q0?ooo`@000008@3oool01@20P800000000000000
0000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P80000000000
0000000R0?ooo`@000008@3oool01@20P8000000000000000000P82002`0oooo3oooool000gooooo
K`3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000820P00Q0?oo
o`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100200oooo00D0
`<3000000000000000000410@00Q0?ooo`050820P0000000000000000020P8008@3oool01010@400
000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000000000000030
`<00:`3oool?ooooo`003Ooooom`0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo
00@0P82000000000000000008P3oool400000240oooo1000000Q0?ooo`050820P000000000000000
0020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool40000
0240oooo00@0P8200000000000000000:`3oool?ooooo`003Oooooma0?ooo`040410@00000000000
0410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00
803oool01@30`<000000000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`050820P0000000000000000030`<00:@3oool?ooooo`003Ooooomb0?oo
o`050820P0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0
P82000000000000000000820P00Q0?ooo`040410@000000000000410@240oooo00@0@41000000000
0000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30
`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240
oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P82002P0oooo3oooool0
00goooooD@3oool00`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q
0?ooo`050820P0000000000000000020P8008@3oool400000240oooo1000000R0?ooo`<0000000<0
P8200?ooo`3oool07`3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo
1000000Q0?ooo`050820P0000000000000000020P8009`3oool?ooooo`003OoooomA0?ooo`030000
0020P800oooo0200oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000000000000000
0010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3o
ool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@400
0000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000
000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050820P0000000000000000020
P8009P3oool?ooooo`003OoooomA0?ooo`80000000<0P8200?ooo`3oool07`3oool400000280oooo
0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`@0
00008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?oo
o`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool01@20P800000000000000
0000P82002D0oooo3oooool000goooooD@3oool3000000030820P03oool0oooo01l0oooo00D0@410
00000000000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool01@20P8000000
000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`00000000000
00000010@4008@3oool01@20P8000000000000000000P8200240oooo00@0@410000000000000@410
8@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<3002@0oooo3ooo
ool000goooooD@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0
P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool400000240oooo
00D0P82000000000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0
oooo1000000R0?ooo`@000008@3oool01020P800000000000000000T0?ooo`oooooo000=oooooe80
oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo00D0`<30
00000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30`<000000
000000000000@4100200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P00000000000
00000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P800
8@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000030`<008P3oool?ooooo`003OoooomC0?ooo`050<30`00000000000
00000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`050820P0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0
@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P800
0000000000000000`<300240oooo00@0@410000000000000@4108@3oool01@30`<00000000000000
0000P8200240oooo3oooool000goooooE@3oool3000000030820P03oool0oooo01l0oooo00@0P820
00000000000000008P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@00000
8@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool400000240oooo
00@0P82000000000000000008P3oool400000240oooo00D0P82000000000000000000820P00P0?oo
o`oooooo000=oooooeD0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@00000000000
00000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P8200000000000000000
0<30`00Q0?ooo`040410@000000000000410@240oooo00@0@410000000000000@4108@3oool01@30
`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`000
0000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@41000000000
0000@4108@3oool01@20P8000000000000000000P82001l0oooo3oooool000goooooEP3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool0
1020P800000000000000000R0?ooo`@000008@3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00008P3oool400000240oooo00D0P82000000000000000000820P00N0?ooo`oooooo000=oooooeL0
oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool0
1@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00Q0?ooo`040410
@000000000000410@200oooo00D0`<3000000000000000000410@00Q0?ooo`050820P00000000000
00000020P8008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P800
8@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?oo
o`050820P0000000000000000020P8007@3oool?ooooo`003OoooomH0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000
000000000280oooo1000000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo
1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool400000280oooo1000000Q0?ooo`050820
P0000000000000000020P800703oool?ooooo`003OoooomI0?ooo`050820P0000000000000000030
`<008@3oool01010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool0
1@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30
`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<30
01/0oooo3oooool000goooooFP3oool01020P800000000000000000R0?ooo`@000008@3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`@000008@3oool3000000030820P03oool0
oooo01l0oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P820000000000000
00006`3oool?ooooo`003OoooomK0?ooo`050820P0000000000000000030`<008@3oool01010@400
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01@10@400000000000000
0000`<300200oooo00D0`<3000000000000000000410@00P0?ooo`050<30`0000000000000000020
P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q
0?ooo`050820P0000000000000000020P8008@3oool01010@400000000000010@40Q0?ooo`050<30
`0000000000000000020P8008@3oool01@20P8000000000000000000`<3001T0oooo3oooool000go
ooooG03oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4108@3oool01010@400000000000010@40Q0?ooo`050<30`00000000000
00000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?oo
o`050<30`0000000000000000020P800603oool?ooooo`003OoooomM0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo1000
000Q0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<00000
00<0P8200?ooo`3oool07`3oool01020P800000000000000000R0?ooo`@000008@3oool01@20P800
0000000000000000P82001L0oooo3oooool000goooooGP3oool01@20P8000000000000000000P820
0240oooo00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3o
ool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool01020P800
000000000010@40Q0?ooo`050820P0000000000000000020P8008@3oool01010@400000000000010
@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<300200
oooo00D0`<3000000000000000000410@00Q0?ooo`050820P0000000000000000020P8005P3oool?
ooooo`003OoooomO0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`000000
0`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000000Q0?ooo`040820P000
0000000000000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool300000003
0820P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01@20P8000000000000000000P820
01D0oooo3oooool000goooooH03oool01@20P8000000000000000000P8200240oooo00@0@4100000
00000000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@4100000000000000000
0<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01020P800000000000010@40Q0?oo
o`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`000
0000000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000
000000000410@00Q0?ooo`040820P00000000000000001D0oooo3oooool000goooooH@3oool01@20
P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool4
00000280oooo1000000Q0?ooo`040820P000000000000820P240oooo00@0P8200000000000000000
8P3oool400000240oooo00D0P82000000000000000000820P00Q0?ooo`@000008P3oool300000003
0820P03oool0oooo01l0oooo00<0P8200000000000005@3oool?ooooo`003OoooomR0?ooo`050820
P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050<30`00000000000
00000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<300000000000000000
0410@00Q0?ooo`040820P000000000000820P240oooo00D0P82000000000000000000<30`00P0?oo
o`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000P8200240oooo00D0
@41000000000000000000<30`00P0?ooo`050<30`0000000000000000020P8008@3oool00`20P800
00000?ooo`0D0?ooo`oooooo000=ooooof<0oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo00@0`<30000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@4108@3oool00`30`<00oooo0?ooo`0C0?ooo`oooooo000=ooooofD0oooo
0`0000000`20P800oooo0?ooo`0O0?ooo`@000008P3oool400000240oooo00@0P820000000000000
00008P3oool400000240oooo00@0P82000000000000000008@3oool01@20P8000000000000000000
P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000
000R0?ooo`@00000=P3oool?ooooo`003OoooomU0?ooo`050<30`0000000000000000020P8008@3o
ool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040820P0000000
00000410@240oooo00D0P82000000000000000000820P00Q0?ooo`050410@0000000000000000030
`<00803oool01@30`<000000000000000000P8200240oooo00D0P82000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@400=@3oool?ooooo`003OoooomV0?ooo`050820P0000000
000000000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P000
0000000000000280oooo1000000Q0?ooo`040820P0000000000000000240oooo00D0P82000000000
000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P8200000
0000000000008P3oool4000003@0oooo3oooool000goooooI`3oool01@20P8000000000000000000
P8200240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4008@3oool01020
P800000000000010@40Q0?ooo`050820P0000000000000000030`<008@3oool01010@40000000000
0010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000000000000000`<30
0200oooo00D0`<3000000000000000000410@00c0?ooo`oooooo000=ooooofP0oooo00D0P8200000
0000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo1000000R
0?ooo`@000008@3oool01020P800000000000020P80Q0?ooo`040820P0000000000000000280oooo
1000000Q0?ooo`050820P0000000000000000020P8008@3oool400000280oooo0`0000000`20P800
oooo0?ooo`0`0?ooo`oooooo000=ooooofT0oooo00D0P82000000000000000000<30`00Q0?ooo`04
0410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00@0P820000000000000
P8208@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P800<@3oool?ooooo`003OoooomZ0?ooo`050<30`0000000000000000020
P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<3000000000000000000410@00Q
0?ooo`050820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`040<30
`000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@00000000000
00000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P8200000000000000000
0<30`00Q0?ooo`040410@000000000000410@300oooo3oooool000goooooK03oool3000000030820
P03oool0oooo01l0oooo1000000R0?ooo`@000008@3oool01020P800000000000000000R0?ooo`@0
00008@3oool01020P800000000000000000Q0?ooo`050820P0000000000000000020P8008@3oool4
00000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000000000000280oooo1000
000_0?ooo`oooooo000=ooooof`0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@000
0000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P82000000000
000000000<30`00Q0?ooo`040410@000000000000410@240oooo00@0P820000000000000@4108@3o
ool01@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`05
0<30`0000000000000000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<30
00000000000000000410@00^0?ooo`oooooo000=ooooofd0oooo00D0P82000000000000000000820
P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P8200000000000000000
8P3oool400000240oooo00@0P82000000000000000008@3oool01@20P8000000000000000000P820
0240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000000000000R
0?ooo`@00000;@3oool?ooooo`003Ooooom^0?ooo`050820P0000000000000000020P8008@3oool0
1010@400000000000010@40Q0?ooo`050<30`0000000000000000020P8008@3oool01@10@4000000
000000000000`<300200oooo00D0`<3000000000000000000410@00Q0?ooo`040820P00000000000
0410@240oooo00D0P82000000000000000000<30`00Q0?ooo`040410@000000000000410@240oooo
00D0`<3000000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30
`<000000000000000000@41002`0oooo3oooool000goooooK`3oool01@20P8000000000000000000
P8200240oooo1000000R0?ooo`<0000000<0P8200?ooo`3oool07`3oool400000280oooo0`00000R
0?ooo`040820P0000000000000000240oooo00@0P82000000000000000008P3oool400000240oooo
00D0P82000000000000000000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo02T0
oooo3oooool000goooooL03oool01@20P8000000000000000000`<300240oooo00@0@41000000000
0000@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30
`00P0?ooo`050<30`0000000000000000030`<008@3oool01020P800000000000010@40Q0?ooo`05
0820P0000000000000000030`<008@3oool01010@400000000000010@40Q0?ooo`050820P0000000
000000000020P8008@3oool01@10@4000000000000000000`<300200oooo00D0`<30000000000000
00000820P00Z0?ooo`oooooo000=ooooog40oooo00D0`<3000000000000000000820P00Q0?ooo`05
0410@0000000000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820
00000000000000000<30`00Q0?ooo`040410@000000000000<30`240oooo00@0`<30000000000000
@4108@3oool01@30`<000000000000000000P8200240oooo00D0@41000000000000000000<30`00P
0?ooo`050<30`0000000000000000010@4008@3oool01@20P8000000000000000000`<300240oooo
00@0@410000000000000@410:@3oool?ooooo`003Ooooomc0?ooo`<0000000<0P8200?ooo`3oool0
7`3oool400000280oooo1000000Q0?ooo`040820P0000000000000000280oooo0`00000S0?ooo`<0
00008@3oool01@20P8000000000000000000P8200240oooo1000000R0?ooo`<0000000<0P8200?oo
o`3oool07`3oool01020P800000000000000000R0?ooo`@00000:03oool?ooooo`003OoooomA0?oo
o`030410@03oool0oooo01l0oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000@4100240oooo00D0P820000000000000
00000<30`00Q0?ooo`040410@000000000000<30`240oooo00@0`<30000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P8008@3oool01@20P8000000000000000000`<300200oooo00D0`<300000
0000000000000410@00W0?ooo`oooooo000=oooooe40oooo0P00000Q0?ooo`050820P00000000000
00000020P8008@3oool400000280oooo0`0000000`20P800oooo0?ooo`0O0?ooo`040820P0000000
000000000280oooo0`00000R0?ooo`040820P0000000000000000240oooo00D0P820000000000000
00000820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo01l0oooo00@0P82000000000
000000008P3oool4000002H0oooo3oooool000goooooD@3oool2000000030410@03oool0oooo01l0
oooo00D0P82000000000000000000820P00Q0?ooo`040410@000000000000410@240oooo00D0`<30
00000000000000000820P00Q0?ooo`050410@0000000000000000030`<00803oool01@30`<000000
000000000000`<300240oooo00@0P820000000000000@4108@3oool01@20P8000000000000000000
`<300240oooo00@0@410000000000000@4108@3oool01@30`<000000000000000000P8200240oooo
00D0@41000000000000000000<30`00P0?ooo`050<30`0000000000000000010@4009@3oool?oooo
o`003OoooomA0?ooo`@000008@3oool01@20P8000000000000000000P8200240oooo1000000R0?oo
o`<0000000<0P8200?ooo`3oool07`3oool400000280oooo0`00000R0?ooo`040820P00000000000
00000240oooo00@0P82000000000000000008P3oool400000240oooo00D0P8200000000000000000
0820P00Q0?ooo`@000008P3oool3000000030820P03oool0oooo0280oooo3oooool000goooooD@3o
ool01@30`<000000000000000000@4100240oooo00D0P82000000000000000000<30`00Q0?ooo`04
0410@000000000000410@240oooo00D0`<3000000000000000000820P00Q0?ooo`050410@0000000
000000000030`<00803oool01@30`<000000000000000000`<300240oooo00@0P820000000000000
@4108@3oool01@20P8000000000000000000`<300240oooo00@0@410000000000000@4108@3oool0
1@20P8000000000000000000P8200240oooo00D0@41000000000000000000<30`00P0?ooo`050<30
`0000000000000000020P8008`3oool?ooooo`00ooooooooooooocCooooo003ooooooooooooo=?oo
ool00?ooooooooooooldooooo`00ooooooooooooocCooooo003ooooooooooooo=?ooool00?oooooo
ooooooldooooo`00ooooooooooooocCooooo003ooooooooooooo=?ooool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{187.5, 116.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.15", "Caption",
  CellTags->"Fig. 6.15"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the normal modes",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\[Psi]\_n\),
              "TraditionalForm"], "(", "z", ")"}]}], TraditionalForm]]],
  " and the  frequencies  of oscillation of the rope using WKB analysis.  \
What are the lowest three  mode frequencies in units of radians per sec?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the shooting method to find the first three normal modes and their \
frequencies numerically. Compare the frequencies with those found via the WKB \
approximation."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these modes and frequencies to solve the following initial-value \
problem: ",
  Cell[BoxData[
      \(TraditionalForm\`u(z, 0)\  = 
        0, \ \(u\& . \)(z, 0)\  = \ \(\(sin(\[Pi]\ z/L)\)\(.\)\)\)]],
  " Keeping the first 10  modes,  animate  ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0\)\(<\)\(t\)\(<\)\(\ \)\(2\)\(\ \)\)\)]],
  "s."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Perform the analysis of parts (a) and (c)  using the grid method."
}], "Text"],

Cell[TextData[{
  StyleBox["(e) ",
    FontWeight->"Bold"],
  "Perform the analysis of parts (a) and (c)  using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a) ",
    FontWeight->"Bold"],
  "Water fills a long straight ditch with vertical walls. The water depth as \
function of transverse position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " across the ditch is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(h(x)\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {
                      RowBox[{
                        RowBox[{"0.25", " ", 
                          StyleBox["m",
                            FontSlant->"Plain"]}], ",", "      ", 
                        RowBox[{"0", "<", "x", "<", 
                          RowBox[{"1", " ", 
                            StyleBox["m",
                              FontSlant->"Plain"]}]}]}]},
                    {
                      RowBox[{
                        RowBox[{"0.5", " ", 
                          StyleBox["m",
                            FontSlant->"Plain"]}], ",", "         ", 
                        RowBox[{"1", "<", "x", "<", 
                          RowBox[{"2", " ", 
                            StyleBox["m",
                              FontSlant->"Plain"]}]}]}]}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Determine the lowest three mode frequencies for water waves, and plot the \
corresponding wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  "using the grid method. The wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  " satisfies Eq. ",
  ButtonBox["(4.2.51)",
    ButtonData:>{"Chapter4.nb", "(4.2.51)"},
    ButtonStyle->"Hyperlink"],
  ", and is related to the horizontal fluid displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " by Eq. ",
  ButtonBox["(4.2.50)",
    ButtonData:>{"Chapter4.nb", "(4.2.50)"},
    ButtonStyle->"Hyperlink"],
  ". (Hint: You may find it easier to satisfy the boundary conditions by \
rewriting Eq. ",
  ButtonBox["(4.2.51)",
    ButtonData:>{"Chapter4.nb", "(4.2.51)"},
    ButtonStyle->"Hyperlink"],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  ", and solving for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " perform the analysis using the WKB/shooting method."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " An electron  of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is trapped in the following potential structure: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V(x)\), " ", "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->18], 
              StyleBox[GridBox[{
                    {GridBox[{
                          {\(\[Infinity], \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \(\(|\)\(x\)\(|\)\(\(>\)\(a\)\)\), \)},
                          {\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(-a\) < 
                              x < 0, \)}
                          }]},
                    {\(V\_o\ x/a, \ \ \ \ \ \ \ \ \ 0 < x < \(\(a\)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the ground state energy and plot the wave function of the electron \
using the grid method, for "
}], "Text"],

Cell[TextData[{
  "\t\t(i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\^2/\((m\ \(a\^2\) V\_o)\)\  = \ 1/2\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\^2/\((m\ \(a\^2\) V\_o)\)\  = \ 2\)]],
  "\t.\t"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the analysis using the Galerkin method."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Use WKB theory to find the energy levels and corresponding eigenfunctions \
for a quantum particle moving in 1D, and compare the first 3 eigenfunctions \
and energies to those found from the shooting method.  The particle's wave \
function satisfies the dimensionless 1-D  Schr\[ODoubleDot]dinger equation "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
            FractionBox[\(\[PartialD]\(\[Psi](x, t)\)\), \(\[PartialD]t\),
              MultilineFunction->None]}], "=", 
          RowBox[{\(\(V(x)\)\ \(\[Psi](x, t)\)\), "-", 
            RowBox[{\(1\/2\), " ", 
              
              FractionBox[\(\[PartialD]\^2\( \[Psi](x, 
                    t)\)\), \(\[PartialD]x\^2\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  " "
}], "Text"],

Cell["\<\
For the potential, take the following cases. Make sure that you \
properly account for turning points, if any :\
\>", "Text"],

Cell[TextData[{
  "(i) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(V(x)\  = \ x/3, \ 0 < x < 1, \ 
            V(x)\  = \ \ \ \[Infinity]\),
            "TraditionalForm"], \(\(otherwise\)\(.\)\)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ x\^4\)]]
}], "Text"],

Cell[TextData[{
  "(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ x + x\^4\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the shooting \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the grid \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Find the first three energy levels and eigenfunctions using the Galerkin \
method."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " In problems with turning points, the WKB solution decays exponentially \
beyond the turning point. Beyond a right turning point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_R\)]],
  ", this decay is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\  \[Proportional] \ 
        exp[\(-\[Integral]\_\(x\_R\)\%x\) | k(x) | \[DifferentialD]x]\)]],
  ". As a boundary condition on the shooting method, it is more accurate to \
match the shooting solution to this functional form, rather than simply \
setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  "at some point ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1 >> x\_R\)]],
  ". To do so, note that this form  implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Psi]/\[PartialD]x\  = \ \(-\(\(|\)\(k(
                  x)\)\(|\)\(\ \)\(\(\[Psi](x)\)\ for\ x\)\)\)\), ">>", 
          RowBox[{\(x\_R\), 
            RowBox[{Cell[""], "."}]}]}], TraditionalForm]]],
  "Using this mixed boundary condition in the WKB method, redo Exercise \
(6)(b)(iii)."
}], "Text",
  CellTags->"i:56"],

Cell[TextData[{
  StyleBox["(8) ",
    FontWeight->"Bold"],
  "A drumhead has an elliptical shape, with an edge given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 = 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(\(10\)\(\ \)\(cm\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\  = \ 20\ cm\)]],
  ". Waves on the drumhead travel with speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"50", " ", 
            RowBox[{"cm", "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Find the frequencies and plot the forms of the lowest three modes using \
a method of your choice."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A square pool of water with vertical sides has a width and length  of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"5", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ",  and nonuniform water depth, equal to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0.25", " ", 
          RowBox[{
            StyleBox["m",
              FontSlant->"Plain"], " ", "[", \(1 + 3\ \((x/L)\)\^2\), "]"}]}],
         TraditionalForm]]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " measured from one of the sides. Find the frequencies and plot the forms \
of the lowest three eigenmodes for shallow water waves in this pool. The \
waves satisfy the equation for potential flow in water with nonuniform depth, \
Eq. ",
  ButtonBox["(6.2.45)",
    ButtonData:>"(6.2.45)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10) ",
    FontWeight->"Bold"],
  "A resonance chamber has the shape of a spheroid, with walls satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2/a\^2 + z\^2/b\^2 = 1\)]],
  " in cylindrical coordinates, where ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\ cm\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b = 2.5\ cm\)]],
  " . The speed of sound in air is roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], "c"}], "=", 
          RowBox[{"340", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Using the Galerkin method, find the lowest resonant frequency of the \
chamber, in hertz, and plot the form of the associated eigenmode. Hints: \
Sound waves in the chamber satisfy potential flow with a von Neumann  \
condition at the walls; see Eq. ",
  ButtonBox["(4.4.40)",
    ButtonData:>{"Chapter4.nb", "(4.4.40)"},
    ButtonStyle->"Hyperlink"],
  " and surrounding discussion. The following cylindrically symmetric basis \
functions match the required von Neumann  boundary conditions:  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\(i\ j\)\)(r, z) = \(r\^\(\(\ \)\(i\)\)\) 
          z\^j\ \ \ \((\ \((\(b\^2\) i\  + \ \(a\^2\) 
                      j)\) \((r\^2\/\(\(a\^2\)(2\ b\^2 + \(b\^2\) i\  + \ \(a\
\^2\) j)\) + 
                    z\^2\/\(\(\(b\^2\)(2\ a\^2 + \ \(b\^2\) i\  + \ \(a\^2\) \
j)\)\(\ \)\)\ )\) - 1)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i, j \[GreaterEqual] \ 0\)]],
  ".\n",
  StyleBox["(11)",
    FontWeight->"Bold"],
  " In the previous problem, it was assumed that the lowest frequency mode is \
cylindrically symmetric. This  is, in fact, only correct when ",
  Cell[BoxData[
      \(TraditionalForm\`b > a\)]],
  ". Find the form and frequency of the lowest frequency mode in the \
spheroidal cavity  for the case ",
  Cell[BoxData[
      \(TraditionalForm\`b = 1\ cm, \ a = 2\ cm\)]],
  ". Note that cylindrical symmetry of the cavity walls implies that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " dependence of the modes can be written in the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Phi]\)\)]],
  ".  (Hint: for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  ", the eigenmodes must satisfy Eq. ",
  ButtonBox["(6.1.37)",
    ButtonData:>"(6.1.37)",
    ButtonStyle->"Hyperlink"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`r \[Rule] 0\)]],
  ".  This limits the values of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " used in the basis functions.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " A hollow waveguide, with perfectly conducting walls and uniform cross \
section as shown in Fig. ",
  ButtonBox["6.16",
    ButtonData:>"Fig. 6.16",
    ButtonStyle->"Hyperlink"],
  ",  runs in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction. This waveguide supports transverse magnetic (TM) traveling \
waves. These waves satisfy the the following wave equation \
(Fourier-transformed in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "):",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\_ \[UpTee] \%2 E\_z\  \[Congruent] \((\
\[PartialD]\^2\/\[PartialD]x\^2 + \[PartialD]\^2\/\[PartialD]y\^2)\) 
            E\_z = \ \((k\^2 - \[Omega]\^2/c\^2)\) E\_z\)]],
  ",\nwith boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z = 0\)]],
  " on the walls, where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-component of the electric field, and where waves are assumed to have the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ k\ \
z\  - \ \[ImaginaryI]\ \[Omega]\ t\)\)]],
  ". For the waveguide geometry shown in the figure, find the lowest three \
(nondegenerate) modes and the corresponding dispersion relations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  ",  using the grid method on a 20-by-20 grid. Plot  contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " associated with these modes as contour plots in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " plane."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005?0001Cb000`400?l00000o`00003ooooooom@
ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@
ooooo`00oooooom@ooooo`00oooooom@ooooo`00oooooom@ooooo`001ooooolC0?ooo`D00000;P3o
ool5000002/0oooo1@00000^0?ooo`D00000:`3oool00`20P800000000000002000000030820P03o
ool0oooo02/0oooo1@00000[0?ooo`030820P0000000000000Wooooo0007oooooa@0oooo1@00000]
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:@3oool5000002d0oooo00<0P820
0000000000000`00000[0?ooo`D00000;P3oool5000002/0oooo0P000009ooooo`001ooooolE0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool00`20P8000000000000020000
00030820P03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?oo
o`030820P000000000000080000000<0@4100?ooo`3oool0:@3oool00`20P8000000000000020000
00030820P03oool0oooo02X0oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`0Y0?oo
o`030820P?oooooooooo00Oooooo0007oooooaL0oooo1@00000]0?ooo`D00000;03oool5000002d0
oooo1@00000/0?ooo`D00000;@3oool5000002/0oooo2Oooool000Oooooo5`3oool00`20P8000000
00000002000000030820P03oool0oooo02/0oooo1@00000[0?ooo`030820P0000000000000<00000
;@3oool5000002`0oooo1@00000]0?ooo`D00000:P3oool9ooooo`001ooooolH0?ooo`D00000;P3o
ool5000002/0oooo1@0000000`20P800oooo0?ooo`0[0?ooo`D00000:`3oool00`20P80000000000
0002000000030820P03oool0oooo02/0oooo1@00000Y0?ooo`Wooooo0007oooooaT0oooo1@00000]
0?ooo`030820P0000000000000<00000:`3oool5000002h0oooo1@00000[0?ooo`D00000;P3oool5
000002P0oooo2Oooool000Oooooo6P3oool00`20P800000000000002000000030820P03oool0oooo
02X0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`0Y0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0:P3oool00`30`<00000000000002000000030410@03oool0oooo
02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`030<30`00000000000
0080000000<0@4100?ooo`3oool09@3oool9ooooo`001ooooolL0?ooo`D00000;@3oool5000002`0
oooo1@00000]0?ooo`D00000;03oool5000002d0oooo1@00000V0?ooo`Wooooo0007oooooa`0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`0[0?ooo`D00000;03oool5000002d0oooo
1@00000/0?ooo`D00000;@3oool5000002D0oooo2Oooool000Oooooo7@3oool5000002h0oooo1@00
000[0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:`3oool5000002/0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0[0?ooo`D00000903oool9ooooo`001ooooolN
0?ooo`D00000;P3oool5000002/0oooo1@00000^0?ooo`D00000:`3oool5000002h0oooo1@00000S
0?ooo`Wooooo0007oooooal0oooo1@00000]0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:@3oool5000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y0?oo
o`D00000;@3oool00`20P80000000000000300000280oooo2Oooool000Oooooo803oool00`20P800
000000000002000000030820P03oool0oooo02X0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool00`20P800
000000000002000000030820P03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0@4100?ooo`3oool07`3oool9ooooo`00
1ooooolQ0?ooo`030820P0000000000000<00000;@3oool5000002`0oooo1@00000]0?ooo`D00000
;03oool5000002d0oooo1@00000P0?ooo`Wooooo0007ooooob80oooo1@0000000`20P800oooo0?oo
o`0[0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo02/0oooo1@00
000[0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:`3oool5000001l0oooo2Ooo
ool000Oooooo8`3oool5000002h0oooo1@00000[0?ooo`D00000;P3oool5000002/0oooo1@00000^
0?ooo`D000007P3oool9ooooo`001ooooolT0?ooo`D00000;@3oool00`20P8000000000000020000
00030820P03oool0oooo02T0oooo1@00000]0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:@3oool5000002h0oooo1@00000M0?ooo`Wooooo0007oooooa<0ooooo`00000O00000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3ooooo000001l0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooool000007`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0ooooo`00000O000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3ooooo0000
01l0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooool000007`0000000`20P800
oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`030000003oool0oooo0100oooo2000003o0?oooa00oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`8000004@3oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P0000000`20P800oooo0?ooo`0>0?oo
o`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool300000003
0820P03oool0oooo00d0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wo
oooo0007ooooo`D000003P3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo00<0oooo0000000000000`00000=0?ooo`P00000o`3oool@0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`D00000303oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool00`20P8000000000000020000
00030820P03oool0oooo00T0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`<0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`080?ooo`P0
0000o`3oool@0?ooo`L0000000<0@4100?ooo`3oool02`3oool9ooooo`001oooool50?ooo`D00000
2@3oool800000?l0oooo403oool9000000`0oooo2Oooool000Oooooo1P3oool5000000P0oooo2000
003o0?oooa00oooo2P00000;0?ooo`Wooooo0007ooooo`L0oooo1@0000070?ooo`P00000o`3oool@
0?ooo`/000002P3oool9ooooo`001oooool70?ooo`030820P0000000000000<000001P3oool80000
0?l0oooo403oool<000000T0oooo2Oooool000Oooooo203oool5000000030820P03oool0oooo00<0
oooo2000003o0?oooa00oooo3@0000080?ooo`Wooooo0007ooooo`T0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`020?ooo`P00000o`3oool@0?ooo`L000000P20P804000000030410
@03oool0oooo00D0oooo2Oooool000Oooooo2`3oool5000000<0oooo2000003o0?oooa00oooo1`00
00000`20P800oooo0?ooo`05000000H0oooo2Oooool000Oooooo303oool500000080oooo2000003o
0?oooa00oooo1`0000001020P800oooo0?ooo`3oool5000000D0oooo2Oooool000Oooooo3@3oool5
000000030?ooo`000000000000H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool00P3oool5
000000@0oooo2Oooool000Oooooo3@3oool00`20P800000000000002000000030820P00000000000
00H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool00`3oool5000000<0oooo2Oooool000Oo
oooo3P3oool00`20P80000000000000:00000?l0oooo403oool7000000030820P03oool0oooo00<0
oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`09ooooo`001oooool@0?ooo`/00000
L03oool4000000030820P03oool0oooo00<0oooo00<0P8200000000000000`3oool2000000/0oooo
1`0000000`20P800oooo0?ooo`1h0?ooo`L0000000<0P8200?ooo`3oool01@3oool5000000030?oo
oooooooooooo00Oooooo0007oooooa40oooo2P00001_0?ooo`030820P0000000000000@00000103o
ool5000000030?ooo`000000000000T0oooo3000001h0?ooo`L0000000<0P8200?ooo`3oool01P3o
ool5000000Wooooo0007oooooa80oooo2@00001_0?ooo`P000000P3oool6000000030820P0000000
000000T0oooo1@0000060?ooo`<00000MP3oool7000000030820P03oool0oooo00L0oooo10000009
ooooo`001ooooolB0?ooo`030820P0000000000000H00000KP3oool5000000<0oooo1P0000030?oo
o`040820P03oool00000000000P0oooo0`0000000`20P800oooo0?ooo`060?ooo`80000000<0P820
0?ooo`3oool0L`3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooooolC0?oo
o`P00000KP3oool3000000030820P03oool0oooo00@0oooo00@0P82000000000000000001@3oool2
000001D0oooo00<0P82000000020P800M03oool7000000030820P03oool0oooo00P0oooo00<0`<30
0000000000002Oooool000Oooooo4`3oool8000006h0oooo0`0000080?ooo`<000001@3oool30000
01D0oooo00<0P820000000000000L`3oool7000000030820P03oool0oooo00X0oooo00<00000oooo
ooooool01oooool000Oooooo4`3oool8000006h0oooo0`0000080?ooo`<000001P3oool2000001D0
oooo00<0P820000000000000L`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000006l0oooo0P0000080?ooo`<000001P3oool2000001D0oooo00@0P820000000000000
0000LP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000006l0oooo
00<0P8200000000000001`3oool3000000H0oooo0P00000E0?ooo`040820P0000000000000000780
oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001`0?ooo`040820
P000000000000820P0D0oooo0`0000070?ooo`0300000020P800oooo01<0oooo00@0@41000000000
00000000LP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000007@0
oooo00<000000?ooo`3oool00P3oool3000000L0oooo00<000000820P03oool04`3oool400000780
oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001e0?ooo`<00000
00@0oooo0000000000000000203oool00`000000oooo0?ooo`0A0?ooo`@00000L`3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000007P0oooo100000080?ooo`030000
003oool0oooo0100oooo1@00001c0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000N@3oool3000000P0oooo00<000000?ooo`3oool03@3oool00`20P80000000000
0004000007@0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001_
0?ooo`030820P0000000oooo00L0oooo0`0000080?ooo`030000003oool0oooo00P0oooo2`00001e
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000K`3oool30000
00L0oooo0`0000080?ooo`030820P0000000oooo00/0oooo0P20P80300000080P820MP3oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000006l0oooo0`0000070?ooo`80
00002@3oool00`20P80000000?ooo`0>0?ooo`<00000M`3oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool8000006l0oooo00<0P8200000000000001P3oool3000000X0oooo
0P00000?0?ooo`<0000000<0P8200?ooo`3oool0L`3oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool800000700oooo0`0000040?ooo`<0000000<0P8200?ooo`3oool0203o
ool200000100oooo0P0000000`20P800oooo0?ooo`1c0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001ooooolC0?ooo`P00000L`3oool6000000`0oooo0P00000A0?ooo`800000M@3oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008D0oooo00<0P8200000
0020P800403oool3000007@0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000260?ooo`8000000`3oool00`000000oooo0?ooo`0:0?ooo`<00000M03oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008H0oooo0P0000040?ooo`030000
003oool0oooo00T0oooo0`00001d0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000Q`3oool2000000<0oooo0P0000090?ooo`@00000M03oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008L0oooo0P0000040?ooo`0300000020P800
oooo00H0oooo1000001e0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?oo
o`P00000Q`3oool2000000@0oooo00<0P8200410@00000001020P8000`10@4000000000000020000
00030410@03oool0oooo07<0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000280?ooo`0300000020P800oooo00@0oooo2P00001f0?ooo`L0000000<0P8200?ooo`3o
ool02`3oool9ooooo`001ooooolC0?ooo`P00000R03oool00`000000P8200?ooo`060?ooo`H00000
N03oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008P0oooo00<0
00000820P03oool0Q03oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo00<0P8200?oo
o`3oool0403oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo0P00000A0?ooo`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool2000000030820P03oool0oooo00h0oooo2000001`0?ooo`800000:03oool2000007<0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`<00000403oool8000006l0oooo0`00
000X0?ooo`@00000L@3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000000?
0?ooo`P00000JP3oool00`20P800000000000006000002H0oooo00<0P8200000000000001P00001]
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool5000000h0oooo2000001X0?oo
o`/000009P3oool00`20P800000000000008000006/0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`030?ooo`20P800000000<0000000<0P8200?ooo`3oool02P3oool8000006@0
oooo00<0P8200410@00000003000000V0?ooo`030820P0000000000000/000000P20P81V0?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool02@3oool800000680oooo4@00000V0?ooo`030820P0000000000000h00000
I@3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0`3oool5000000/0oooo2000
001P0?oooa@000009@3ooolC000006<0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
ooooo`@0oooo1@00000:0?ooo`P00000GP3ooolF000002D0oooo5@0000000`20P800oooo0?ooo`1N
0?ooo`P000003@3oool9ooooo`001oooool50?ooo`D000002@3oool8000005/0oooo6@00000U0?oo
oaP00000GP3oool9000000`0oooo2Oooool000Oooooo1P3oool00`20P80000000000000200000003
0820P03oool0oooo00D0oooo2000001F0?ooo`030820P0000000000001/000009@20P80L00000080
P820F03oool:000000030820P03oool0oooo00P0oooo2Oooool000Oooooo1`3oool00`20P8000000
00000003000000H0oooo2000001E0?ooof<00000E`3oool<000000T0oooo2Oooool000Oooooo203o
ool5000000030820P03oool0oooo00<0oooo2000001F0?ooof000000F@3oool=000000P0oooo2Ooo
ool000Oooooo2@3oool5000000D0oooo2000001I0?oooeX0000000<0P8200?ooo`3oool0F@3oool7
000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`001oooool:0?oo
o`D00000103oool8000005/0oooo6@00000U0?oooaP00000GP3oool7000000030820P03oool00000
00@000001`3oool9ooooo`001oooool;0?ooo`030820P000000000000080000000<0P8200?ooo`3o
ool02000001N0?ooo`80P8205000000U0?oooa<000000P20P8000`30`<00oooo0?ooo`1N0?ooo`L0
000000@0P8200?ooo`3oool0P820100000000`20P800oooo0?ooo`030?ooo`Wooooo0007ooooo`d0
oooo1@0000000`3oool0000000000006000006<0oooo4@00000U0?oooa00000000<0P8200?ooo`3o
ool0H`3oool7000000030820P03oool0oooo0080oooo1@0000040?ooo`Wooooo0007ooooo`d0oooo
00<0P8200000000000000P0000000`20P800000000000006000006D0oooo00<0P820000000000000
3000000U0?ooo`h00000J03oool7000000030820P03oool0oooo00<0oooo1@0000030?ooo`Wooooo
0007ooooo`h0oooo3@00001X0?ooo``000009@3oool00`20P800000000000008000006/0oooo1`00
00000`20P800oooo0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Ooo
ool000Oooooo3`3oool<000006X0oooo00<0P8200000000000001P00000V0?ooo`030820P0000000
000000H00000K@3oool7000000030820P03oool0oooo00@0oooo1@0000020?ooo`Wooooo0007oooo
oa00oooo00<0P8200000000000002000001]0?ooo`80P82000@0@41000000000000000009P3oool0
1030`<0000000000000000020820P700oooo1`0000000`20P800oooo0?ooo`050?ooo`030820P000
000000000080000000<0P820ooooooooool01oooool000Oooooo4P3oool900000?l0oooo403oool7
000000030820P03oool0oooo00L0oooo10000009ooooo`001ooooolB0?ooo`030820P00000000000
00H00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool0203oool3000000Wooooo0007oooooa<0
oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`080?ooo`030820P0000000000000Wo
oooo0007oooooa<0oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`090?ooo`800000
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00X0oooo00<0
P820ooooooooool01oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool0
00Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3o
ool8000005D0oooo00<0P820000000000000H@00001F0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q000005H0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P00000000000
06400000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0
oooo00<0P820000000000000H@00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000006400000EP3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820
0000000000001@00000B0820P0D00000:`20P805000000h0P8201`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
0180oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y0?ooo`D000003@3oool70000
05H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`03
0820P0000000000000D000004`3oool5000002`0oooo1@00000<0?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000
1@00000D0?ooo`D00000;03oool5000000/0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800000000000005000001D0oooo1@00
000/0?ooo`D000002P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0oooo2000001E0?ooo`030820P0000000000000D000005P3oool00`20P800000000000002
000000030820P03oool0oooo02P0oooo00<0`<300000000000000`0000000`30`<00oooo0?ooo`06
0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
05D0oooo00<0P8200000000000001@00000G0?ooo`030820P0000000000000<00000:`3oool50000
00P0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool00`000000
oooo0?ooo`0@0?ooo`P00000E@3oool00`20P800000000000005000001P0oooo1@0000000`20P800
oooo0?ooo`0Y0?ooo`H000001P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wo
oooo0007ooooo`8000004@3oool8000005D0oooo00<0P8200000000000001@00000I0?ooo`D00000
;03oool6000000D0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
ool2000000030820P03oool0oooo00h0oooo2000001E0?ooo`030820P0000000000000D000006P3o
ool5000002`0oooo1P0000040?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo0`00000@0?ooo`P00000E@3oool00`20P800000000000005000001/0oooo1@00000/
0?ooo`030820P000000000000080000000@0P8200?ooo`3oool0oooo1`00001F0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001oooool4000000030820P03oool0oooo00`0oooo2000001E
0?ooo`030820P0000000000000D00000703oool00`20P800000000000002000000030820P03oool0
oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`07000005H0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`030?ooo`000000000000<000003@3oool80000
05D0oooo00<0P8200000000000001@00000M0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0:P3oool5000000030?ooo`000000000000D00000EP3oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo0P3oool5000000`0oooo2000001E0?ooo`030820P0000000000000D0
00007P3oool5000002d0oooo3000001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool20?ooo`030820P000000000000080000000<0P8200?ooo`3oool02@3oool8000005D0oooo
00<0P8200000000000001@00000O0?ooo`D00000;@3oool;000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`<0oooo1@00000;0?ooo`P00000E@3oool00`20P80000000000
000500000200oooo1@00000/0?ooo`030820P0000000000000P00000EP3oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo103oool00`20P800000000000002000000030820P03oool0
oooo00L0oooo2000001E0?ooo`030820P0000000000000D000008@3oool00`20P800000000000002
000000030820P03oool0oooo02T0oooo00<0P8200000000000001`00001F0?ooo`P0000000<0P820
0?ooo`3oool02P3oool9ooooo`001oooool60?ooo`D00000203oool8000005D0oooo00<0P8200000
000000001@00000R0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3oool80000
05H0oooo2P00000;0?ooo`Wooooo0007ooooo`L0oooo1@0000070?ooo`P00000E@3oool00`20P800
000000000005000002<0oooo1@00000]0?ooo`L00000EP3oool;000000X0oooo2Oooool000Oooooo
1`3oool00`20P800000000000003000000H0oooo2000001E0?ooo`030820P0000000000000D00000
903oool5000002`0oooo1`00001F0?ooo``000002@3oool9ooooo`001oooool80?ooo`D0000000<0
P8200?ooo`3oool00`3oool8000005D0oooo00<0P8200000000000001@00000U0?ooo`D00000:`3o
ool7000005H0oooo3@0000080?ooo`Wooooo0007ooooo`T0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`020?ooo`P00000E@3oool00`20P800000000000005000002H0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0W0?ooo`L00000EP3oool700000080P82010000000
0`10@400oooo0?ooo`050?ooo`Wooooo0007ooooo`/0oooo1@0000030?ooo`P00000E@3oool00`20
P800000000000005000002L0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0V0?oo
o`L00000EP3oool7000000030820P03oool0oooo00D000001P3oool9ooooo`001oooool<0?ooo`D0
00000P3oool8000005D0oooo00<0P8200000000000001@00000X0?ooo`D00000:03oool7000005H0
oooo1`0000001020P800oooo0?ooo`3oool5000000D0oooo2Oooool000Oooooo3@3oool500000003
0?ooo`000000000000H00000E@3oool00`20P800000000000005000002T0oooo1@00000W0?ooo`L0
0000EP3oool7000000030820P03oool0oooo0080oooo1@0000040?ooo`Wooooo0007ooooo`d0oooo
00<0P8200000000000000P0000000`20P800000000000006000005D0oooo00<0P820000000000000
1@00000Z0?ooo`D000009P3oool7000005H0oooo1`0000000`20P800oooo0?ooo`030?ooo`D00000
0`3oool9ooooo`001oooool>0?ooo`030820P0000000000000X00000E@3oool00`20P80000000000
0005000002/0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0R0?ooo`L00000EP3o
ool7000000030820P03oool0oooo00<0oooo00<0`<300000000000000P0000000`10@400oooo0?oo
o`09ooooo`001oooool@0?ooo`/00000E@3oool00`20P800000000000005000002`0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0Q0?ooo`L00000EP3oool7000000030820P03oool0
oooo00D0oooo1@0000000`3oooooooooooooo`07ooooo`001ooooolA0?ooo`X00000E@3oool00`20
P800000000000005000002d0oooo1@00000S0?ooo`L00000EP3oool7000000030820P03oool0oooo
00H0oooo1@000009ooooo`001ooooolB0?ooo`T00000E@3oool00`20P800000000000006000002d0
oooo1@00000R0?ooo`L00000EP3oool7000000030820P03oool0oooo00L0oooo10000009ooooo`00
1ooooolB0?ooo`030820P0000000000000H00000E@3oool00`20P800000000000007000002d0oooo
1@00000Q0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000007000000030820P03oool0oooo02/0oooo1@00
000P0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo00<0P8200000000000002Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P820000000000000200000000`20P800oooo0?ooo`0[
0?ooo`030410@000000000000080000000<0P8200?ooo`3oool0703oool7000005H0oooo1`000000
0`20P800oooo0?ooo`090?ooo`030820P000003ooooo00Sooooo0007oooooa<0oooo2000001E0?oo
o`030820P0000000000000D0000000<0oooo0000000000000P00000]0?ooo`D0000000<0P8200?oo
o`3oool06`3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo2000001E0?ooo`030820P0000000000000D000000P3oool4000002d0oooo1@00000M0?ooo`L0
0000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo
00<0P8200000000000001@0000020?ooo`030820P0000000000000800000;@3oool5000001`0oooo
1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3o
ool00`20P800000000000005000000<0oooo1@00000]0?ooo`D000006`3oool7000005H0oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000
000000D00000103oool01@20P8000000000000000000@41002d0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`0G0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@0000060?ooo`@00000;@3oool0
0`20P800000000000002000000030820P03oool0oooo01H0oooo1`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
00L0oooo1000000]0?ooo`D00000603oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D00000203oool4000002d0
oooo1@00000G0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000005D0oooo00<0P8200000000000001@0000080?ooo`030820P0000000000000800000
;@3oool5000001H0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000005000000T0oooo00D0P8200000000000000000
0410@00]0?ooo`030820P000000000000080000000<0P8200?ooo`3oool04P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P000
0000000000D000002`3oool4000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0A0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
000005D0oooo00<0P8200000000000001@00000<0?ooo`@00000;@3oool5000001<0oooo1`00001F
0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20
P800000000000005000000d0oooo1000000]0?ooo`D000004P3oool7000005H0oooo1`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D0
00003@3oool00`20P800000000000002000002d0oooo1@00000A0?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000
1@00000>0?ooo`050820P0000000000000000010@400;@3oool00`20P80000000000000200000003
0820P03oool0oooo00d0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1ooooolC0?ooo`P00000E@3oool00`20P80000000000000500000100oooo1000000]0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0303oool7000005H0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P0000000000000D000004@3o
ool4000002d0oooo1@00000>0?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Ooo
ool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@00000B0?ooo`@00000;@3oool5
000000d0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?oo
o`P00000E@3oool00`20P80000000000000500000180oooo00<0P8200000000000000P00000]0?oo
o`D00000303oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo2000001E0?ooo`030820P0000000000000D000004`3oool01@20P8000000000000000000@410
02d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`080?ooo`L00000EP3oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P82000000000
00001@00000E0?ooo`@00000;@3oool00`20P800000000000003000000T0oooo1`00001F0?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000
00000005000001H0oooo1000000]0?ooo`D0000000<0P8200?ooo`3oool01P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?ooo`030820P000
0000000000D000005`3oool4000002d0oooo1@0000080?ooo`L00000EP3oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@00000G
0?ooo`030820P0000000000000800000;@3oool5000000L0oooo1`00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P8000000000000050000
01P0oooo1@0000000`20P800oooo0?ooo`0Z0?ooo`D000001P3oool7000005H0oooo1`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`0300000020P800oooo0100oooo2000001E0?ooo`03
0820P0000000000000D000006@3oool00`20P800000000000002000000030820P03oool0oooo02X0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`020?ooo`L00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo0P0000000`20P800oooo0?ooo`0>0?ooo`P00000
E@3oool00`20P800000000000005000001/0oooo1@00000/0?ooo`030820P0000000000000800000
00@0P8200?ooo`3oool0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`00
1oooool300000100oooo2000001E0?ooo`030820P0000000000000D00000703oool5000002`0oooo
1@0000030?ooo`L00000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000
000?0?ooo`P00000E@3oool00`20P800000000000005000001d0oooo1@00000/0?ooo`D000000P3o
ool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`030?ooo`000000
0000008000003P3oool8000005D0oooo00<0P8200000000000001@00000M0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0:P3oool5000000030?ooo`000000000000D00000EP3oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool01@10@4000000000000000000
P82000`0oooo2000001E0?ooo`030820P0000000000000D000007P3oool00`20P800000000000002
000000030820P03oool0oooo02X0oooo00<0P8200000000000002@00001F0?ooo`L0000000<0P820
0?ooo`3oool02`3oool9ooooo`001oooool30?ooo`@0000000<0P8200?ooo`3oool02@3oool80000
05D0oooo00<0P8200000000000001@00000P0?ooo`D00000;03oool00`20P8000000000000080000
05H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`@0oooo1000000;0?ooo`P0
0000E@3oool00`20P80000000000000500000240oooo1@00000/0?ooo`X00000EP3oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo1@3oool4000000X0oooo2000001E0?ooo`030820
P0000000000000D000008P3oool5000002`0oooo2@00001F0?ooo`P000003@3oool9ooooo`001ooo
ool60?ooo`@000002@3oool8000005D0oooo00<0P8200000000000001@00000R0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0:P3oool8000005H0oooo2@00000<0?ooo`Wooooo0007
ooooo`L0oooo00D0@41000000000000000000820P0070?ooo`P00000E@3oool00`20P80000000000
0005000002<0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`L00000EP3o
ool:000000030820P03oool0oooo00P0oooo2Oooool000Oooooo203oool5000000H0oooo2000001E
0?ooo`030820P0000000000000D000009@3oool5000002/0oooo1`00001F0?ooo``000002@3oool9
ooooo`001oooool90?ooo`@0000000<0P8200?ooo`3oool00`3oool8000005D0oooo00<0P8200000
000000001@00000V0?ooo`D00000:P3oool7000005H0oooo3@0000080?ooo`Wooooo0007ooooo`X0
oooo100000050?ooo`P00000E@3oool00`20P800000000000005000002L0oooo1@00000Y0?ooo`L0
0000EP3oool7000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`00
1oooool;0?ooo`@00000103oool8000005D0oooo00<0P8200000000000001@00000W0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool09P3oool7000005H0oooo1`0000000`20P800oooo
00000004000000L0oooo2Oooool000Oooooo303oool01@20P8000000000000000000P8200080oooo
2000001E0?ooo`030820P0000000000000D00000:03oool00`20P800000000000002000000030820
P03oool0oooo02D0oooo1`00001F0?ooo`L0000000@0P8200?ooo`3oool0P820100000000`20P800
oooo0?ooo`030?ooo`Wooooo0007ooooo`d0oooo00<0P8200000000000000P0000000`3oool00000
00000006000005D0oooo00<0P8200000000000001@00000Z0?ooo`D000009P3oool7000005H0oooo
1`0000000`20P800oooo0?ooo`020?ooo`D00000103oool9ooooo`001oooool>0?ooo`@0000000<0
P8200000000000001P00001E0?ooo`030820P0000000000000D00000:`3oool5000002D0oooo1`00
001F0?ooo`L0000000<0P8200?ooo`3oool00`3oool5000000<0oooo2Oooool000Oooooo3`3oool<
000005D0oooo00<0P8200000000000001@00000/0?ooo`D00000903oool7000005H0oooo1`000000
0`20P800oooo0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Oooool0
00Oooooo403oool;000005D0oooo00<0P8200000000000001@00000/0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool08@3oool7000005H0oooo1`0000000`20P800oooo0?ooo`040?oo
o`D000000P3oool9ooooo`001ooooolA0?ooo`X00000E@3oool00`20P800000000000006000002`0
oooo1@00000S0?ooo`L00000EP3oool7000000030820P03oool0oooo00D0oooo1@0000000`3ooooo
ooooooooo`07ooooo`001ooooolB0?ooo`030410@0000000000000H00000E@3oool00`20P8000000
00000007000000030<30`03oool0oooo02T0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`0O0?ooo`L00000EP3oool7000000030820P03oool0oooo00H0oooo00<0P820000000000000
0P000009ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800000000000008000002d0oooo1@00
000P0?ooo`L00000EP3oool7000000030820P03oool0oooo00P0oooo0`000009ooooo`001ooooolC
0?ooo`P00000E@3oool00`20P800000000000009000002d0oooo1@00000O0?ooo`L00000EP3oool7
000000030820P03oool0oooo00P0oooo00<0P8200000000000002Oooool000Oooooo4`3oool80000
05D0oooo00<0P8200000000000002P00000/0?ooo`030820P0000000000000<000007P3oool70000
05H0oooo1`0000000`20P800oooo0?ooo`090?ooo`8000002Oooool000Oooooo4`3oool8000005D0
oooo00<0P8200000000000001@0000000`3oool0000000000003000002`0oooo1@0000000`20P800
oooo0?ooo`0K0?ooo`L00000EP3oool7000000030820P03oool0oooo00X0oooo00<00000oooooooo
ool01oooool000Oooooo4`3oool8000005D0oooo00<0P8200000000000001@0000020?ooo`030410
@000000000000080000000<0P8200?ooo`3oool0:@3oool00`20P800000000000002000000030820
P03oool0oooo01X0oooo1`00001F0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolC0?ooo`P00000E@3oool00`20P800000000000005000000<0oooo1@0000000`20P800oooo0?oo
o`0Z0?ooo`D000006`3oool7000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007
oooooa<0oooo2000001E0?ooo`030820P0000000000006400000EP3oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000H@00001F0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P800
00000000001Q000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo
2000001E0?ooo`030820P0000000000006400000EP3oool7000000030820P03oool0oooo00/0oooo
2Oooool000Oooooo4`3oool8000005D0oooo00<0P820000000000000H@00001F0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000E@3oool00`20P80000000000001Q
000005H0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000001E0?oo
o`030820P0000000000006400000EP3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3o
ool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
0?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0
oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo
403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool700000003
0820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820
P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03o
ool0oooo00/0oooo2Oooool000Oooooo00<000000?ooo`3oool0403oool800000?l0oooo403oool7
000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P00000A0?ooo`P00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool2000000030820P03oool0oooo00h0
oooo2000003o0?oooa00oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`<00000
403oool800000?l0oooo403oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1000
00000`20P800oooo0?ooo`0<0?ooo`P00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool02`3o
ool9ooooo`001oooool00`3oool0000000000003000000d0oooo2000003o0?oooa00oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007ooooo`80oooo1@00000<0?ooo`P00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20?ooo`030820P000000000000080
000000<0P8200?ooo`3oool02@3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo0`3oool5000000/0oooo2000003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007ooooo`@0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`070?ooo`P00000o`3oool@0?ooo`P0000000<0P8200?ooo`3oool02P3oool9ooooo`001oooool6
0?ooo`D00000203oool800000?l0oooo403oool:000000/0oooo2Oooool000Oooooo1`3oool50000
00L0oooo2000003o0?oooa00oooo2`00000:0?ooo`Wooooo0007ooooo`L0oooo00<0P82000000000
00000`0000060?ooo`P00000o`3oool@0?ooo``000002@3oool9ooooo`001oooool80?ooo`D00000
00<0P8200?ooo`3oool00`3oool800000?l0oooo403oool=000000P0oooo2Oooool000Oooooo2@3o
ool00`20P800000000000002000000030820P03oool0oooo0080oooo2000003o0?oooa00oooo1`00
00020820P0@0000000<0@4100?ooo`3oool01@3oool9ooooo`001oooool;0?ooo`D000000`3oool8
00000?l0oooo403oool7000000030820P03oool0oooo00D000001P3oool9ooooo`001oooool<0?oo
o`D000000P3oool800000?l0oooo403oool7000000040820P03oool0oooo0?ooo`D000001@3oool9
ooooo`001oooool=0?ooo`D0000000<0oooo0000000000001P00003o0?oooa00oooo1`0000000`20
P800oooo0?ooo`020?ooo`D00000103oool9ooooo`001oooool=0?ooo`030820P000000000000080
000000<0P8200000000000001P00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`030?ooo`D0
00000`3oool9ooooo`001oooool>0?ooo`d00000o`3oool@0?ooo`L0000000<0P8200?ooo`3oool0
0`3oool00`20P800000000000002000000030820P03oool0oooo00Wooooo0007ooooo`l0oooo00<0
P8200000000000002@00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`040?ooo`030820P000
000000000080000000<0P8200?ooooooool02?ooool000Oooooo4@3oool:00000?l0oooo403oool7
000000030820P03oool0oooo00H0oooo1@000009ooooo`001ooooolB0?ooo`T00000o`3oool@0?oo
o`L0000000<0P8200?ooo`3oool01`3oool4000000Wooooo0007oooooa80oooo00<0P82000000000
00001P00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`080?ooo`<000002Oooool000Oooooo
4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00P0oooo00<0P820000000000000
2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00T0oooo00<0
P82000000?ooool02?ooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0
oooo00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo4`3oool800000?l0oooo403oool7000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3oool8000008@0oooo00<0P8200000000000000P0000050?ooo`030820
P0000000000007h0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo2000
00230?ooo`030820P0000000000000@0000000@0P8200?ooo`3oool0P8201@0000000`20P800oooo
0?ooo`1i0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000PP3o
ool5000000<0oooo1P0000030?ooo`030000003oool0oooo07T0oooo1`0000000`20P800oooo0?oo
o`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`@000001P3oool4000007l0oooo1`000000
0`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`<00000203oool30000
07l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000220?ooo`<0
0000203oool3000007l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo
200000220?ooo`030820P0000000000000P0oooo0`00001o0?ooo`L0000000<0P8200?ooo`3oool0
2`3oool9ooooo`001ooooolC0?ooo`P00000Q03oool2000000L0oooo0`00001o0?ooo`L0000000<0
P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P00000Q03oool00`20P800000000000006
0?ooo`<00000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool80000
08D0oooo0`0000050?ooo`<00000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oo
oooo4`3oool8000008P0oooo00<000000820P03oool00P3oool3000007l0oooo1`0000000`20P800
oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000290?ooo`040820P000000000000?ooo`<0
0000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008`0oooo
00@0P8200000000000000000O`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo
4`3oool8000008@0oooo00<000000?ooo`3oool01P3oool3000007l0oooo1`0000000`20P800oooo
0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?ooo`<000001`3oool3000007l0oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?ooo`<000001`3oool3
000007l0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0oooo200000230?oo
o`<000001`3oool200000800oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0
oooo200000240?ooo`030410@0000000P82000@0oooo00@0P820000000000000@410P03oool70000
00030820P03oool0oooo00/0oooo2Oooool000Oooooo4`3oool8000008L0oooo1P0000220?ooo`L0
000000<0P8200?ooo`3oool02`3oool9ooooo`001ooooolC0?ooo`P000008@3oool200000<X0oooo
00<0P8200000000000007`3oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo00<0
00000?ooo`3oool0403oool8000001l0oooo1@0000390?ooo`D0000000<0P8200?ooo`3oool06P3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P00000A0?ooo`P00000703oool8
00000<T0oooo2000000J0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool20000
00030410@03oool0oooo00h0oooo2000000G0?ooo`<0P8202P0000000`20P800oooo0?ooo`350?oo
o`030820P0000000000000P0000000<0@4100820P03oool05@3oool7000000030820P03oool0oooo
00/0oooo2Oooool000Oooooo1000000?0?ooo`P000005@3oool@00000<L0oooo400000000`20P800
oooo0?ooo`0@0?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001oooool5000000h0oooo
2000000B0?oooa<00000a`3ooolC00000100oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo
0007ooooo`030?ooo`000000000000<000003@3oool800000100oooo5P0000350?oooaL000003@3o
ool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo0P3oool5000000`0oooo2000000=
0?oooaT00000a@3ooolH000000`0oooo1`0000000`20P800oooo0?ooo`0;0?ooo`Wooooo0007oooo
o`80oooo00<0`<300000000000000P0000000`10@400oooo0?ooo`090?ooo`P000002@3oool30820
P1X00000a@20P80K000000030820P030`<00oooo00H0oooo1`0000000`20P800oooo0?ooo`0;0?oo
o`Wooooo0007ooooo`@0oooo1@00000:0?ooo`P000001P3oool00`20P80000000000003o000000<0
0000103oool7000000030820P03oool0oooo00/0oooo2Oooool000Oooooo1@3oool5000000T0oooo
200000050?ooool00000200000030?ooo`L0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
ool60?ooo`D00000203oool8000000L0ooooo`000003000000H0oooo2000000=0?ooo`Wooooo0007
ooooo`L0oooo1@0000070?ooo`P000002P3oooom000000P0oooo2@00000<0?ooo`Wooooo0007oooo
o`L0oooo00<0P8200000000000000`0000060?ooo`P00000303oool00`20P80000000000000G0000
0<H0oooo6000000;0?ooo`X000002`3oool9ooooo`001oooool80?ooo`030820P000000000000080
000000<0@4100?ooo`3oool00`3oool8000000l0oooo0P20P8000`10@40000000000000B00000<H0
oooo4`0000030820P0d0oooo2`0000000`20P800oooo0?ooo`070?ooo`Wooooo0007ooooo`X0oooo
1@0000040?ooo`P000005@3oool@00000<L0oooo400000000`20P800oooo0?ooo`0@0?ooo`d00000
203oool9ooooo`001oooool;0?ooo`D000000`3oool8000001L0oooo3P0000380?ooo`d000005@3o
ool7000000030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool9ooooo`001oooool<
0?ooo`D000000P3oool8000001X0oooo2`0000380?ooo`X0000000<0P8200?ooo`3oool05@3oool7
000000030820P03oool0000000@000001`3oool9ooooo`001oooool=0?ooo`D0000000<0oooo0000
000000001P00000L0?ooo`P00000b@3oool8000001X0oooo1`0000000`20P800oooo0?ooo`050000
00H0oooo2Oooool000Oooooo3@3oool00`30`<00000000000002000000030410@0000000000000H0
00007`3oool20820P0030410@000000000000<T0oooo00<0@4100000000000000P20P8000`30`<00
oooo0?ooo`0J0?ooo`L0000000D0P8200?ooo`3oool0oooo0820P004000000030820P03oool0oooo
0080oooo2Oooool000Oooooo3`3oool<00000?l0oooo403oool7000000030820P03oool0oooo00<0
oooo1@0000030?ooo`Wooooo0007oooooa00oooo2`00003o0?oooa00oooo1`0000000`20P800oooo
0?ooo`030?ooo`030820P000000000000080000000<0P8200?ooo`3oool02Oooool000Oooooo4@3o
ool:00000?l0oooo403oool7000000030820P03oool0oooo00@0oooo1@0000020?ooo`Wooooo0007
oooooa80oooo2@00003o0?oooa00oooo1`0000000`20P800oooo0?ooo`050?ooo`D0000000<0oooo
ooooooooool01oooool000Oooooo4P3oool00`30`<0000000000000600000?l0oooo403oool70000
00030820P03oool0oooo00H0oooo00<0P8200000000000000P000009ooooo`001ooooolC0?ooool0
00007`0000000`20P800oooo0?ooo`080?ooo`<000002Oooool000Oooooo4`3ooooo000001l00000
00<0P8200?ooo`3oool0203oool00`20P800000000000009ooooo`001ooooolC0?ooool000007`00
00000`20P800oooo0?ooo`090?ooo`8000002Oooool000Oooooo4`3ooooo000001l0000000<0P820
0?ooo`3oool02P3oool00`00003oooooooooo`07ooooo`001ooooolC0?ooool000007`0000000`20
P800oooo0?ooo`0;0?ooo`Wooooo0007oooooa<0ooooo`00000O000000030820P03oool0oooo00/0
oooo2Oooool000Oooooo4`3ooooo000001l0000000<0P8200?ooo`3oool02`3oool9ooooo`001ooo
oolK0?ooo`D00000:`3oool00`20P800000000000003000002`0oooo1000000^0?ooo`D00000:`3o
ool5000002h0oooo1@00000X0?ooo`Wooooo0007oooooa`0oooo1@00000[0?ooo`D0000000<0P820
0?ooo`3oool0:P3oool4000002d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Y
0?ooo`D00000;@3oool00`20P800000000000002000000030820P03oool0oooo02D0oooo2Oooool0
00Oooooo703oool00`30`<00000000000002000000030410@03oool0oooo02T0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0Z0?ooo`050820P0000000000000000020P800;03oool0
0`20P800000000000002000000030820P03oool0oooo02T0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0903oool9
ooooo`001ooooolN0?ooo`D00000;03oool5000002`0oooo00<0P8200000000000000P00000]0?oo
o`D00000;03oool5000002d0oooo1@00000U0?ooo`Wooooo0007oooooal0oooo1@00000/0?ooo`D0
0000;03oool4000000030820P03oool0oooo02/0oooo1@00000[0?ooo`030820P000000000000080
000000<0P8200?ooo`3oool0:`3oool5000002@0oooo2Oooool000Oooooo803oool5000002`0oooo
1@00000/0?ooo`@00000;P3oool5000002/0oooo1@00000^0?ooo`D000008`3oool9ooooo`001ooo
oolQ0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo02X0oooo1000
000]0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:@3oool5000002d0oooo00<0
P8200000000000000`00000R0?ooo`Wooooo0007ooooob40oooo00<0P8200000000000000`00000[
0?ooo`D00000;@3oool4000002d0oooo1@00000/0?ooo`D00000;@3oool5000000030820P03oool0
oooo01l0oooo2Oooool000Oooooo8P3oool00`20P800000000000002000000030410@03oool0oooo
02T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`050410@00000000000
00000020P800;03oool00`20P800000000000002000000030820P03oool0oooo02T0oooo00<0P820
0000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool07P3oool9ooooo`001ooooolT0?ooo`D00000;03oool5000002`0oooo100000000`20
P800oooo0?ooo`0[0?ooo`D00000:`3oool00`20P800000000000002000000030820P03oool0oooo
02/0oooo1@00000O0?ooo`Wooooo0007ooooobD0oooo1@00000/0?ooo`D00000;03oool4000002h0
oooo1@00000[0?ooo`D00000;P3oool5000001h0oooo2Oooool000Oooooo9P3oool5000002/0oooo
00<0P8200000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`@00000;@3oool00`20P8000000
00000002000000030820P03oool0oooo02T0oooo1@00000^0?ooo`D000007@3oool9ooooo`001ooo
oolW0?ooo`D00000:`3oool5000002d0oooo1000000]0?ooo`D00000;03oool5000002d0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0J0?ooo`Wooooo0007ooooobL0oooo00<0`<30
0000000000000P0000000`10@400oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0:P3oool01@10@4000000000000000000P82002`0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`0Y0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0:P3o
ool00`20P800000000000002000000030820P03oool0oooo01T0oooo2Oooool000Oooooo:@3oool5
000002`0oooo1@00000/0?ooo`@0000000<0P8200?ooo`3oool0:`3oool5000002/0oooo00<0P820
0000000000000`00000]0?ooo`D000006P3oool9ooooo`001ooooolZ0?ooo`D00000;03oool50000
02`0oooo1000000^0?ooo`D00000:`3oool5000000030820P03oool0oooo02/0oooo1@00000I0?oo
o`Wooooo003ooooooe3ooooo003ooooooe3ooooo003ooooooe3ooooo003ooooooe3ooooo003ooooo
oe3ooooo003ooooooe3ooooo003ooooooe3ooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{111.875, 111.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 6.16 Exercise (12).", "Caption",
  CellTags->"Fig. 6.16"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " Redo the previous problem but now calculate the first three nondegenerate \
transverse electric (TE) modes for the waveguide using the grid method . \
These modes satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\_ \[UpTee] \%2 B\_z\  = \ \((k\^2 - \
\[Omega]\^2/c\^2)\) B\_z\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`B\_z\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-component of the magnetic field, subject to von Neumann boundary \
conditions at the surface of the waveguide,",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              FormBox[
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                "TraditionalForm"], "\[CenterDot]", \(\[Del]B\_z\)}], "=", 
            "0"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " A hydrogen atom is placed in a uniform electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{"E", "  ", 
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The electron eigenfunction  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](r, \[Theta])\)]],
  " (in spherical coordinates) satisfies Schr\[ODoubleDot]dinger's equation,  \
Eq. ",
  ButtonBox["(4.4.35)",
    ButtonData:>{"Chapter4.nb", "(4.4.35)"},
    ButtonStyle->"Hyperlink"],
  ",   with Hamiltonian operator"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = \(-\(1\/2\)\) \[Del]\^2\(-\(1\/r\)\) + \ 
          V(r, \[Theta])\)]],
  ", "
}], "NE3",
  CellTags->"(6.3.33)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          r, \[Theta])\  = \ \[Epsilon]\ r\ cos\ \[Theta]\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\  = \ m\ E\ a\^3/\[HBar]\^2\)]],
  ", and where distances are measured in units of the Bohr radius ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`a = 
              4\ \[Pi]\ \(\[Epsilon]\_\(\(o\)\(\ \)\)\) \[HBar]\^2/
                  m\ e\^2\)]]]], TraditionalForm]]],
  ", and energies are measured in units of ",
  Cell[BoxData[
      \(TraditionalForm\`e\^2/\((4\ \[Pi]\ \[Epsilon]\_o\ a)\)\)]],
  ". Use a 20 by 20 grid in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " plane with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 5\ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < \[Pi]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that for cylindrically symmetric modes the correct boundary \
conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Psi]/\[PartialD]r = \(-\[Psi]\)/2\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Psi]/\[PartialD]\[Theta] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0, \[Pi]\)]],
  ". Use a Dirichlet condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 5  a\)]],
  ", and set up the proper grid so that the solution has second-order \
accuracy in the grid spacing."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Determine the change in ground-state energy of the atom as a function of \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " by taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = n/10\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3\)]],
  ". (This energy shift is called the Stark effect).  For each case plot the \
ground state eigenfunction vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta] = 0\)\(,\)\(\[Pi]/2\)\(,\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ". Plot the energies vs. ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and compare with the theoretical result from perturbation theory (see \
below),"
}], "Text",
  CellTags->"i:49"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\_1 = E\_1\^\((0)\) - \ 9\ \ \[Epsilon]\^2/4\)]],
  ","
}], "NE3",
  CellTags->"(6.3.34)"],

Cell[TextData[{
  " correct only for small ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\) = \(-1\)/\((2\ n\^2)\)\)]],
  " is the unperturbed energy of the hydrogen atom. (Hint: You will have to \
ignore the great many positive unphysical eigenvalues, and pick out the \
ground state eigenvalue from the list by hand as it varies with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". )"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " What is happening to the electron wave function as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases? What do you think would happen to the electron if there were \
no boundary at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 5  a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " were increased even further?"
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A hydrogen atom is placed in a uniform ",
  StyleBox["magnetic",
    FontSlant->"Italic"],
  " field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(B\ z\&^\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Neglecting spin effects, the electron eigenfunction for the ground \
state,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](r, \[Theta])\)]],
  " (in spherical coordinates), still satisfies Eqs. ",
  ButtonBox["(4.4.35)",
    ButtonData:>{"Chapter4.nb", "(4.4.35)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.4.33)",
    ButtonData:>"(6.4.33)",
    ButtonStyle->"Hyperlink"],
  ", but now the perturbation potential is ",
  Cell[BoxData[
      \(TraditionalForm\`V(
          r, \[Theta])\  = \ \(\(1\/8\) \(\((\[Beta]\ \ r\ sin\ \
\[Theta])\)\^2\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \(\@\(\(4\ \[Pi]\ \[Epsilon]\_o\ \
a\^3\)\/\(m\ c\^2\)\)\) B\)]],
  " is a scaled magnetic field, and we are using the same energy and length \
scales as in the previous exercise. Using a 20-by-20 grid in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " plane with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 5\ a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < \[Pi]\)]],
  ", determine the ground-state energy of the atom as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " by taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = \(\(n\ /5\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3\)]],
  ". (This effect is called the Zeemann shift.)  For each case plot the \
ground-state eigenfunction vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " along the lines ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta] = 0\)\(,\)\(\[Pi]/2\)\(,\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ". Compare your energies with the perturbation theory result (see below), "
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_\(\(1\)\(\ \)\) = \ 
        E\_1\^\((0)\)\  + \ \ \[Beta]\^2\)]],
  "."
}], "NE3",
  CellTags->"(6.3.35)"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " Eigenmode problems involving Hamiltonian operators of the type given by \
Eq. ",
  ButtonBox["(6.3.33)",
    ButtonData:>"(6.3.33)",
    ButtonStyle->"Hyperlink"],
  " are also amenable to the Galerkin method. Consider an operator ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = H\&^\_o + V\&^\)]],
  " . The eigenstates  of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\)]],
  " are assumed  to be known, and ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is some perturbation that changes the eigenstates. We will use the \
Galerkin method to determine the new eigenstates for the problem, choosing \
for basis functions the eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\)]],
  ". These eigenmodes satisfy"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\_o\ v\_n\  = \ \(E\_n\^\((0)\)\) v\_n\)]],
  ",\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\)\)]],
  " is the unperturbed energy of the system."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that with this choice, the matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontWeight->"Bold"], "\[Congruent]", 
          RowBox[{
            StyleBox[
              SuperscriptBox["S", 
                StyleBox[\(-1\),
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "\[CenterDot]", 
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " of the associated eigenvalue problem [see  Eq. ",
  ButtonBox["(6.3.11)",
    ButtonData:>"(6.3.11)",
    ButtonStyle->"Hyperlink"],
  "] has the following form:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_\(m\ n\) = \(\[Delta]\_\(m\ n\)\) 
            E\_n\^\((0)\) + \((v\_m, V\&^\ v\_n)\)\/\((v\_m, v\_m)\)\)]],
  "."
}], "NE3",
  CellTags->"(6.3.36)"],

Cell[TextData[{
  "            ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat Exercise (14), but this time use the Galerkin method, along with \
Eq. ",
  ButtonBox["(6.3.36)",
    ButtonData:>"(6.3.36)",
    ButtonStyle->"Hyperlink"],
  ". For basis functions take the eigenfunctions of the unperturbed hydrogen \
atom, Eq. ",
  ButtonBox["(4.4.37)",
    ButtonData:>{"Chapter4.nb", "(4.4.37)"},
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n \[LessEqual] \ 4\)]],
  ", and use the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\[DifferentialD]\^3 r\ \(f\^*\)\ g\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "            ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat Exercise (15) using the Galerkin method, using the same basis \
functions and inner product as in (b)."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Perturbation theory. ",
    FontSlant->"Italic"],
  "Equation ",
  ButtonBox["(6.3.36)",
    ButtonData:>"(6.3.36)",
    ButtonStyle->"Hyperlink"],
  " can be used to obtain analytic results for the shift in the eigenstates \
in the limit that the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is weak. ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "We will assume for simplicity that the set  of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  " is ",
  StyleBox["orthonormal,",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_m, v\_n)\) = \[Delta]\_\(m\ n\)\)]],
  ". Recall that eigenvectors ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["c",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  " are used to determine the eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^\)]],
  " according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n = \[Sum]\+m\( c\_m\%n\) v\_n\)]],
  ". Let us assume that these eigenvectors are normalized so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["c",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "n"], ")"}], "*"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", "1"}], TraditionalForm]]],
  ".  Also, choose the phase of the eigenfunctions so that ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\%n\)]],
  " is real. Then if the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " is weak,  we can write the components of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["c",
              FontWeight->"Bold",
              FontSlant->"Plain"], "n"], " "}], TraditionalForm]]],
  "as"
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_m\%n\), " ", "=", " ", 
          RowBox[{\(\[Delta]\_\(m\ n\)\), " ", "+", " ", 
            SubsuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["c",
                    FontSlant->"Italic"]}]], "m", "n"]}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(6.3.37)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["c",
                FontSlant->"Italic"]}]], "m", "n"], TraditionalForm]]],
  " is a small correction, of order ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ".  Equation ",
  ButtonBox["(6.3.37)",
    ButtonData:>"(6.3.37)",
    ButtonStyle->"Hyperlink"],
  "  is merely a statement that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\  \[Rule] \ v\_n\)]],
  "in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^ \[Rule] \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(6.3.37)",
    ButtonData:>"(6.3.37)",
    ButtonStyle->"Hyperlink"],
  "  together with the normalization condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox["c",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "n"], ")"}], "*"], "\[CenterDot]", 
              
              SuperscriptBox[
                StyleBox["c",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"]}], "=", "1"}]}], 
        TraditionalForm]]],
  ",  show that ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["c",
                FontSlant->"Italic"]}]], "n", "n"], TraditionalForm]]],
  " is ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-",
  StyleBox["order",
    FontSlant->"Italic"],
  " in the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ", and in particular,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["c",
                  FontSlant->"Italic"]}]], "n", "n"], "=", 
          RowBox[{\(-\(1\/2\)\), 
            RowBox[{\(\[Sum]\+\(k \[NotEqual] \ n\)\), 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{"|", 
                    SubsuperscriptBox[
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["c",
                            FontSlant->"Italic"]}]], "k", "n"], "|"}], ")"}], 
                "2"]}]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(6.3.38)"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " are the eigenvalues corresponding to ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              SuperscriptBox[
                StyleBox["c",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"], TraditionalForm]]]]], 
        TraditionalForm]]],
  "; that is,   ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[ScriptCapitalL]",
              FontWeight->"Bold"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", 
          RowBox[{\(E\_n\), 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}]}], TraditionalForm]]],
  ". Taking the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["n",
                FontSlant->"Italic"], "th"}]], " "}], TraditionalForm]]],
  "component of this vector equation, and using Eqs. ",
  ButtonBox["(6.3.6)",
    ButtonData:>"(6.3.6)",
    ButtonStyle->"Hyperlink"],
  " - ",
  ButtonBox["(6.3.8)",
    ButtonData:>"(6.3.8)",
    ButtonStyle->"Hyperlink"],
  ", show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(E\_n - E\_n\^\((0)\)\), "=", 
          FractionBox[
            RowBox[{\(V\_\(n\ n\)\), " ", "+", 
              RowBox[{\(\[Sum]\+k\), 
                RowBox[{\(V\_\(n\ k\)\), 
                  SubsuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["c",
                          FontSlant->"Italic"]}]], "k", "n"]}]}]}], 
            RowBox[{"1", " ", "+", " ", 
              SubsuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["c",
                      FontSlant->"Italic"]}]], "n", "n"]}]]}], 
        TraditionalForm]]],
  ", "
}], "NE3",
  CellTags->"(6.3.39)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(m\ n\) \[Congruent] \((v\_m, V\&^\ v\_n)\)\)]],
  ". Working only to first",
  "-order",
  " in the perturbation ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ", use this equation to show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_n = 
        E\_n\^\((0)\) + V\_\(n\ n\) + 0 \((V\&^\^2)\)\)]],
  "."
}], "NE3",
  CellTags->{"i:53", "(6.3.40)"}],

Cell[TextData[{
  "\t",
  StyleBox["(c) ",
    FontWeight->"Bold"],
  "Use Eq. ",
  ButtonBox["(6.3.40)",
    ButtonData:>"(6.3.40)",
    ButtonStyle->"Hyperlink"],
  " to derive Eq. ",
  ButtonBox["(6.3.35)",
    ButtonData:>"(6.3.35)",
    ButtonStyle->"Hyperlink"],
  ". (Remember to use ",
  StyleBox["orthonormal",
    FontSlant->"Italic"],
  " basis functions.)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Use Eq. ",
  ButtonBox["(6.3.40)",
    ButtonData:>"(6.3.40)",
    ButtonStyle->"Hyperlink"],
  " to show that the Stark shift must be second-order in the applied electric \
field \[Epsilon]. [In order to derive Eq. ",
  ButtonBox["(6.3.34)",
    ButtonData:>"(6.3.34)",
    ButtonStyle->"Hyperlink"],
  "  second-order perturbation theory must be applied. See below.]"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Taking the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["j",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " component of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[ScriptCapitalL]",
              FontWeight->"Bold"], "\[CenterDot]", 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}], "=", 
          RowBox[{\(E\_n\), 
            SuperscriptBox[
              StyleBox["c",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  ", show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\((E\_n - E\_j\^\((0)\))\), 
            SubsuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["c",
                    FontSlant->"Italic"]}]], "j", "n"]}], "=", 
          RowBox[{\(V\_\(j\ n\)\), "+", 
            RowBox[{\(\[Sum]\+k\), 
              RowBox[{\(V\_\(j\ k\)\), 
                SubsuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["c",
                        FontSlant->"Italic"]}]], "k", "n"], " "}]}]}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  "."
}], "NE3",
  CellTags->"(6.3.41)"],

Cell[TextData[{
  "\t",
  StyleBox["(f)",
    FontWeight->"Bold"],
  " To first-order in ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  " this equation implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["c",
                  FontSlant->"Italic"]}]], "j", "n"], 
          "=", \(\(V\_\(j\ n\)\)\(/\)\)}], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\((E\_n\^\((0)\) - E\_j\^\((0)\))\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] \ n\)]],
  ". This provides us with the first-order shift in the eigenfunction. Use \
this result in Eq. ",
  ButtonBox["(6.3.39)",
    ButtonData:>"(6.3.39)",
    ButtonStyle->"Hyperlink"],
  " to show that, to ",
  StyleBox["second",
    FontSlant->"Italic"],
  "-order",
  StyleBox[" in ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(V\&^\)\(\ \)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = 
        E\_n\^\((0)\) + 
          V\_\(n\ n\) + \[Sum]\+\(k \[NotEqual] \ n\)\(\(V\_\(n\ k\)\) V\_\(k\
\ n\)\)\/\(E\_n\^\((0)\) - E\_k\^\((0)\)\) + \ 0 \((V\&^\^3)\)\)]],
  "."
}], "NE3",
  CellTags->{"i:54", "(6.3.42)"}],

Cell[TextData[{
  "\t",
  StyleBox["(g)",
    FontWeight->"Bold"],
  " Use Eq. ",
  ButtonBox["(6.3.42)",
    ButtonData:>"(6.3.42)",
    ButtonStyle->"Hyperlink"],
  " to derive the Stark shift, Eq. ",
  ButtonBox["(6.3.34)",
    ButtonData:>"(6.3.34)",
    ButtonStyle->"Hyperlink"],
  ". [Hint: Note that ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ \[Theta]\)]],
  " is proportional to the spherical harmonic ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(1\ 0\)\)(\[Theta], \[Phi])\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  "[Note: Equations ",
  ButtonBox["(6.3.38)",
    ButtonData:>"(6.3.38)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(6.3.39)",
    ButtonData:>"(6.3.39)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(6.3.41)",
    ButtonData:>"(6.3.41)",
    ButtonStyle->"Hyperlink"],
  " are exact and can be employed to create  a recursive procedure for \
finding the shift in energy levels and eigenvalues to ",
  StyleBox["any order",
    FontSlant->"Italic"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`V\&^\)]],
  ".  This is left as an exercise for the interested reader. The method is \
analogous to that used to solve a nonlinear equation in one variable, \
outlined in Exercise (4), Sec. ",
  ButtonBox["5.2",
    ButtonData:>{"Chapter5.nb", "i:97"},
    ButtonStyle->"Hyperlink"],
  ".  However, in most cases it is easier to simply solve directly for the \
eigenvalues and eigenvectors of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  ",  as in  the previous problem. Also, note that in Eq. ",
  ButtonBox["(6.3.42)",
    ButtonData:>"(6.3.42)",
    ButtonStyle->"Hyperlink"],
  " we assumed that the energy levels are not degenerate; ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\^\((0)\) \[NotEqual] \ E\_k\^\((0)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ \(\(k\)\(.\)\)\)]],
  " Degenerate cases can also be handled, but will not be discussed here. \
See, for example, ",
  ButtonBox["Landau and Lifshitz (1981)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text",
  CellTags->"i:55"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"c:45", "refs"}],

Cell[TextData[{
  "Klaus-Jurgen Bathe, ",
  StyleBox["Finite Element Procedures",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(Prentice Hall, Englwood Cliffs NJ, 1996)"
}], "Text"],

Cell[TextData[{
  "P. Hunter and A. Pullan, ",
  StyleBox["FEM/BEM Notes",
    FontSlant->"Italic"],
  ", at ",
  "http://www.esc.auckland.ac.nz/Academic/Texts/FEM-BEM-notes.html",
  ". "
}], "Text"],

Cell[TextData[{
  "L.D. Landau and E. M. Lifshitz, ",
  StyleBox["Quantum Mechanics (Nonrelativistic Theory) ",
    FontSlant->"Italic"],
  "(Pergamon Press, Oxford,  1981) "
}], "Text"],

Cell[TextData[{
  "W.H. Press, S.A. Teukolsky, W. T. Vetterling, and B. P. Flannery, ",
  StyleBox["Numerical Recipes",
    FontSlant->"Italic"],
  ", 2nd ed. (Cambridge Press,  Cambridge, 1992)."
}], "Text"],

Cell[TextData[{
  "H. G. Winful, ",
  StyleBox["Nature of \"superluminal\" barrier tunneling",
    FontSlant->"Italic"],
  ", Phys. Rev. Lett. ",
  StyleBox["90",
    FontWeight->"Bold"],
  ", 023901-1 (2003)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 6, Section 6.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 71, "IndexEntries" -> {{"i:17", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}}, {"i:2", "Galerkin method"}, \
{"i:49", "Stark effect"}, {"i:50", "Zeeman shift"}, {"i:52", "Perturbation \
theory"}, {"i:57", "Galerkin, Boris G."}, {"i:58", "Von Neumann, John"}, \
{"i:59", 
  StyleBox[ 
  "Do", FontWeight -> 
    "Bold"]}, {"i:61", "Jacobi, Carl Gustav Jacob"}, {"i:64", 
  StyleBox[ 
  "Boole", FontWeight -> 
    "Bold"]}, {"i:65", "Courant condition"}, {"i:66", "Courant condition"}, \
{"i:68", "Finite element methods"}, {"i:70", "Unset"}, {"i:1", "Partial \
differential equations", {"numerical solution (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Numerical solution of partial differential equations)"}}, \
{"i:13", "Galerkin method", "module, for time-dependent problems"}, {"i:15", \
"Velocity", "superluminal"}, {"i:16", "Shroedinger's equation", "tunneling"}, \
{"i:17", "Numerical solution of PDEs", {"grid methods (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods)"}}, {"i:17", "Recursion relation", {"used to \
solve PDEs (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Relaxation methods, Grid methods)"}}, {"i:18", {"Grid methods \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "FTCS method"}, {"i:19", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "von Neumann stability \
analysis"}, {"i:20", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "CTCS method"}, {"i:21", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Lax method"}, {"i:22", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "implicit methods"}, {"i:23", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Crank-Nicholson method"}, \
{"i:24", "Boundary conditions", {"in grid methods (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods)"}}, {"i:25", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "explicit methods"}, {"i:26", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "CTCS for wave equation in 2 \
dimensions"}, {"i:27", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "operator splitting"}, {"i:29", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "for boundary value problems"}, \
{"i:3", "Differential operators", "matrix form by projection onto basis \
functions"}, {"i:30", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "direct soluton of BVP's"}, \
{"i:32", "Recursion relation", {"used to solve PDEs (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Relaxation methods, Grid methods)"}}, {"i:32", "Relaxation \
methods", {
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Grid methods"}}, {"i:32", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "relaxation methods for \
BVP's"}, {"i:33", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "Jacobi method"}, {"i:34", \
{"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "simultaneous overrelaxation"}, \
{"i:36", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "FFT method"}, {"i:38", {"Grid \
methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "boundary condition at \
origin"}, {"i:39", "Eigenmodes", "numerical"}, {"i:39", "Numerical solution \
of PDEs", {"numerical eigenmodes (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Eigenmodes, numerical)"}}, {"i:4", "Galerkin method", "for \
time-independent boundary value problems"}, {"i:40", "Eigenmodes", \
"numerical, via shooting method"}, {"i:40", "Shooting method", "for numerical \
eigenmodes"}, {"i:41", "Eigenmodes", "numerical, via Galerkin method"}, \
{"i:41", "Galerkin method", "numerical eigenmodes"}, {"i:42", "Eigenmodes", \
"numerical, via grid method"}, {"i:42", "Grid method", "numerical \
eigenmodes"}, {"i:43", "Eigenmodes", "WKB method"}, {"i:43", "WKB method", \
"for eigenmodes"}, {"i:44", "WKB method", {"near turning points (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Turning points)"}}, {"i:45", "Turning points", "effect on WKB \
eigenvalues"}, {"i:46", "Shooting method", "for problems with turning \
points"}, {"i:47", "Eigenmodes", "of drumheads with arbitrary shape"}, \
{"i:48", "Eigenmodes", "of drumheads with arbitrary shape"}, {"i:5", \
"Galerkin method", "basis functions"}, {"i:52", "Eigenmodes", {"perturbed \
quantum (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}}, {"i:52", "Shroedinger's equation", \
{"eigenmodes, perturbed (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}}, {"i:53", "Perturbation theory", \
"first order energy shift"}, {"i:54", "Perturbation theory", "second order \
energy shift"}, {"i:55", "Perturbation theory", "degenerate"}, {"i:55", \
"Recursion relation", "for perturbed energy levels"}, {"i:56", "Shooting \
method", "for problems with turning points"}, {"i:6", "Inner product", \
"choice of, in Galerkin method"}, {"i:60", "Shroedinger's equation", \
"numerical solution"}, {"i:62", {"Grid methods ", "(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Numerical solution of ODEs)"}, "non-rectangular \
boundaries"}, {"i:63", "Integration", {"over arbitrary regions (using ", 
  StyleBox[ "Boole", FontWeight -> "Bold"], ")"}}, {"i:67", 
  StyleBox[ 
  "Plot3D", FontWeight -> "Bold"], {"over arbitrary regions (using ", 
  StyleBox[ 
  "Boole", FontWeight -> 
    "Bold"], ")"}}, {"i:69", "Grid methods", "alternating direction implicit \
method"}, {"i:7", "Galerkin method", "boundary curves, smooth vs. cusps"}, \
{"i:1", "Numerical solution of PDEs", "", ""}, {"i:11", "Galerkin method", \
"for time-dependent PDEs", ""}, {"i:12", {"Basis functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "for mixed boundary conditions", ""}, \
{"i:14", {"Wavefunction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Shroedinger's equation, Eigenmodes)"}, "behavior of, in \
reflection from a barrier", ""}, {"i:2", "Numerical solution of PDEs", \
{"Galerkin method (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Galerkin method)"}, ""}, {"i:24", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "boundary conditions, von \
Neumann and mixed", ""}, {"i:28", {"Snell's law (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories)"}, "and lensing effect", ""}, \
{"i:31", {"Grid methods (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "non-rectangular boundaries", \
""}, {"i:36", "FFTs", "for boundary value problems", ""}, {"i:37", {"Basis \
functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "boundary condition at origin", ""}, \
{"i:5", "Function(s)", {"basis (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Basis functions, Galerkin method)"}, ""}, {"i:5", {"Basis \
functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "", ""}, {"i:51", "Galerkin method", {"for \
perturbed quantum systems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Perturbation theory)"}, ""}, {"i:52", "Energy", {"levels, \
perturbed (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Perturbation theory)"}, ""}, {"i:8", "Galerkin method", \
"module, for time-independent problems", ""}, {"i:9", {"Basis functions (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Galerkin method)"}, "in presence of a convex cusp", ""}}},
CellLabelAutoDelete->True,
LineSpacing->{1.1, 0},
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(6.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UNNEQ"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, None}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["UNNEQ", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:1"->{
    Cell[1727, 52, 117, 4, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "c:1"->{
    Cell[1727, 52, 117, 4, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "i:2"->{
    Cell[1888, 62, 71, 1, 39, "Subtitle",
      CellTags->{"i:2", "c:2"}]},
  "c:2"->{
    Cell[1888, 62, 71, 1, 39, "Subtitle",
      CellTags->{"i:2", "c:2"}]},
  "c:3"->{
    Cell[2003, 69, 60, 1, 41, "Subsubtitle",
      CellTags->"c:3"]},
  "i:57"->{
    Cell[2066, 72, 1257, 28, 146, "Text",
      CellTags->"i:57"]},
  "Fig. 6.1"->{
    Cell[46491, 640, 233, 5, 29, "Caption",
      CellTags->"Fig. 6.1"]},
  "i:4"->{
    Cell[46761, 650, 80, 1, 30, "Subsubtitle",
      CellTags->{"i:4", "c:4"}]},
  "c:4"->{
    Cell[46761, 650, 80, 1, 30, "Subsubtitle",
      CellTags->{"i:4", "c:4"}]},
  "c:5"->{
    Cell[46866, 655, 44, 1, 42, "Section",
      CellTags->"c:5"]},
  "(6.1.1)"->{
    Cell[47016, 663, 159, 5, 33, "NumberedEquation",
      CellTags->"(6.1.1)"]},
  "(6.1.2)"->{
    Cell[47742, 691, 161, 5, 29, "NumberedEquation",
      CellTags->"(6.1.2)"]},
  "(6.1.3)"->{
    Cell[48375, 713, 154, 5, 29, "NumberedEquation",
      CellTags->"(6.1.3)"]},
  "i:5"->{
    Cell[48711, 728, 463, 16, 44, "Text",
      CellTags->"i:5"]},
  "(6.1.4)"->{
    Cell[49177, 746, 148, 5, 29, "NumberedEquation",
      CellTags->"(6.1.4)"]},
  "(6.1.5)"->{
    Cell[49427, 758, 232, 7, 29, "NumberedEquation",
      CellTags->"(6.1.5)"]},
  "(6.1.6)"->{
    Cell[50299, 789, 250, 7, 38, "NumberedEquation",
      CellTags->"(6.1.6)"]},
  "(6.1.7)"->{
    Cell[50729, 806, 249, 7, 38, "NumberedEquation",
      CellTags->"(6.1.7)"]},
  "(6.1.8)"->{
    Cell[52387, 862, 300, 8, 33, "NumberedEquation",
      CellTags->"(6.1.8)"]},
  "(6.1.9)"->{
    Cell[52759, 874, 148, 5, 30, "NumberedEquation",
      CellTags->"(6.1.9)"]},
  "i:6"->{
    Cell[53560, 904, 80, 1, 27, "Text",
      CellTags->"i:6"]},
  "(6.1.10)"->{
    Cell[53643, 907, 240, 7, 44, "NumberedEquation",
      CellTags->"(6.1.10)"]},
  "(6.1.11)"->{
    Cell[56480, 996, 399, 11, 40, "NumberedEquation",
      CellTags->"(6.1.11)"]},
  "i:3"->{
    Cell[57395, 1027, 903, 27, 92, "Text",
      CellTags->"i:3"]},
  "(6.1.12)"->{
    Cell[58301, 1056, 208, 6, 32, "NumberedEquation",
      CellTags->"(6.1.12)"]},
  "i:7"->{
    Cell[60370, 1118, 1132, 30, 116, "Text",
      CellTags->"i:7"]},
  "c:6"->{
    Cell[63125, 1192, 47, 1, 31, "Section",
      CellTags->"c:6"]},
  "(6.1.13)"->{
    Cell[63993, 1217, 213, 6, 39, "NumberedEquation",
      CellTags->"(6.1.13)"]},
  "Cell 6.1"->{
    Cell[64487, 1236, 169, 4, 72, "Input",
      CellTags->"Cell 6.1"]},
  "Cell 6.2"->{
    Cell[65274, 1258, 154, 4, 67, "Input",
      CellTags->"Cell 6.2"]},
  "Cell 6.3"->{
    Cell[65853, 1282, 125, 3, 67, "Input",
      CellTags->"Cell 6.3"]},
  "Cell 6.4"->{
    Cell[66519, 1310, 123, 3, 67, "Input",
      CellTags->"Cell 6.4"]},
  "Cell 6.5"->{
    Cell[66844, 1323, 153, 4, 67, "Input",
      CellTags->"Cell 6.5"]},
  "Cell 6.6"->{
    Cell[67201, 1337, 156, 4, 67, "Input",
      CellTags->"Cell 6.6"]},
  "Cell 6.7"->{
    Cell[69157, 1401, 220, 5, 86, "Input",
      CellTags->"Cell 6.7"]},
  "i:59"->{
    Cell[69380, 1408, 699, 22, 62, "Text",
      CellTags->"i:59"]},
  "Cell 6.8"->{
    Cell[70082, 1432, 216, 6, 86, "Input",
      CellTags->"Cell 6.8"]},
  "Cell 6.9"->{
    Cell[71314, 1476, 152, 4, 67, "Input",
      CellTags->"Cell 6.9"]},
  "Cell 6.10"->{
    Cell[71919, 1502, 138, 3, 67, "Input",
      CellTags->"Cell 6.10"]},
  "Cell 6.11"->{
    Cell[72412, 1522, 129, 3, 67, "Input",
      CellTags->"Cell 6.11"]},
  "Cell 6.12"->{
    Cell[73590, 1556, 207, 5, 86, "Input",
      CellTags->"Cell 6.12"]},
  "Cell 6.13"->{
    Cell[73974, 1573, 188, 4, 67, "Input",
      CellTags->"Cell 6.13"]},
  "Cell 6.14"->{
    Cell[176699, 3553, 321, 6, 105, "Input",
      CellTags->"Cell 6.14"]},
  "Cell 6.15"->{
    Cell[578502, 11442, 182, 4, 86, "Input",
      CellTags->"Cell 6.15"]},
  "c:7"->{
    Cell[582847, 11538, 47, 1, 31, "Section",
      CellTags->"c:7"]},
  "Cell 6.16"->{
    Cell[583323, 11555, 92, 3, 67, "Input",
      CellTags->"Cell 6.16"]},
  "Cell 6.17"->{
    Cell[583440, 11562, 251, 6, 97, "Input",
      CellTags->"Cell 6.17"]},
  "i:64"->{
    Cell[732346, 19500, 587, 14, 78, "Text",
      CellTags->"i:64"]},
  "i:8"->{
    Cell[733209, 19526, 121, 4, 27, "Text",
      CellTags->"i:8"]},
  "Cell 6.18"->{
    Cell[733333, 19532, 3019, 76, 298, "Input",
      CellTags->"Cell 6.18"]},
  "Cell 6.19"->{
    Cell[736355, 19610, 3348, 67, 480, "Input",
      CellTags->"Cell 6.19"]},
  "Cell 6.20"->{
    Cell[739866, 19688, 97, 3, 67, "Input",
      CellTags->"Cell 6.20"]},
  "Cell 6.21"->{
    Cell[816204, 21537, 386, 8, 105, "Input",
      CellTags->"Cell 6.21"]},
  "Cell 6.22"->{
    Cell[927677, 25077, 106, 3, 67, "Input",
      CellTags->"Cell 6.22"]},
  "Cell 6.23"->{
    Cell[927992, 25092, 265, 7, 86, "Input",
      CellTags->"Cell 6.23"]},
  "c:8"->{
    Cell[1306112, 32526, 47, 1, 31, "Section",
      CellTags->"c:8"]},
  "Cell 6.24"->{
    Cell[1306947, 32559, 493, 10, 184, "Input",
      CellTags->"Cell 6.24"]},
  "(6.1.14)"->{
    Cell[1450639, 40194, 517, 13, 42, "NumberedEquation",
      CellTags->"(6.1.14)"]},
  "Cell 6.25"->{
    Cell[1452224, 40244, 360, 10, 116, "Input",
      CellTags->"Cell 6.25"]},
  "Cell 6.26"->{
    Cell[1452818, 40262, 601, 13, 162, "Input",
      CellTags->"Cell 6.26"]},
  "Cell 6.27"->{
    Cell[1453929, 40296, 303, 6, 86, "Input",
      CellTags->"Cell 6.27"]},
  "Cell 6.28"->{
    Cell[1486572, 41199, 174, 4, 67, "Input",
      CellTags->"Cell 6.28"]},
  "i:9"->{
    Cell[1509281, 41697, 422, 11, 61, "Text",
      CellTags->"i:9"]},
  "Cell 6.29"->{
    Cell[1510804, 41744, 3392, 82, 295, "Input",
      CellTags->"Cell 6.29"]},
  "Cell 6.30"->{
    Cell[1514755, 41845, 102, 3, 67, "Input",
      CellTags->"Cell 6.30"]},
  "Cell 6.31"->{
    Cell[1547212, 42645, 437, 9, 97, "Input",
      CellTags->"Cell 6.31"]},
  "Fig. 6.2"->{
    Cell[1913170, 49852, 640, 18, 17, "Caption",
      CellTags->"Fig. 6.2"]},
  "Fig. 6.3"->{
    Cell[1943390, 50675, 651, 18, 30, "Caption",
      CellTags->"Fig. 6.3"]},
  "i:11"->{
    Cell[1945033, 50722, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:11", "c:9"}]},
  "c:9"->{
    Cell[1945033, 50722, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:11", "c:9"}]},
  "c:10"->{
    Cell[1945139, 50727, 56, 1, 42, "Section",
      CellTags->"c:10"]},
  "(6.1.15)"->{
    Cell[1945505, 50739, 248, 7, 42, "NumberedEquation",
      CellTags->"(6.1.15)"]},
  "(6.1.16)"->{
    Cell[1945812, 50750, 206, 4, 57, "NumberedEquation",
      CellTags->"(6.1.16)"]},
  "(6.1.17)"->{
    Cell[1946065, 50758, 137, 5, 29, "NumberedEquation",
      CellTags->"(6.1.17)"]},
  "(6.1.18)"->{
    Cell[1946269, 50767, 211, 7, 33, "NumberedEquation",
      CellTags->"(6.1.18)"]},
  "(6.1.19)"->{
    Cell[1946677, 50784, 180, 6, 29, "NumberedEquation",
      CellTags->"(6.1.19)"]},
  "i:12"->{
    Cell[1946890, 50794, 570, 16, 61, "Text",
      CellTags->"i:12"]},
  "(6.1.20)"->{
    Cell[1948208, 50838, 215, 7, 35, "NumberedEquation",
      CellTags->"(6.1.20)"]},
  "Cell 6.32"->{
    Cell[1948675, 50860, 227, 5, 116, "Input",
      CellTags->"Cell 6.32"]},
  "(6.1.21)"->{
    Cell[1976789, 51612, 191, 6, 34, "NumberedEquation",
      CellTags->"(6.1.21)"]},
  "(6.1.22)"->{
    Cell[1977464, 51639, 399, 9, 42, "NumberedEquation",
      CellTags->"(6.1.22)"]},
  "(6.1.23)"->{
    Cell[1978007, 51657, 264, 5, 42, "NumberedEquation",
      CellTags->"(6.1.23)"]},
  "(6.1.24)"->{
    Cell[1978526, 51675, 455, 11, 42, "NumberedEquation",
      CellTags->"(6.1.24)"]},
  "(6.1.25)"->{
    Cell[1979702, 51714, 210, 6, 33, "NumberedEquation",
      CellTags->"(6.1.25)"]},
  "(6.1.26)"->{
    Cell[1980173, 51731, 289, 9, 33, "NumberedEquation",
      CellTags->"(6.1.26)"]},
  "Cell 6.33"->{
    Cell[1985538, 51914, 236, 5, 124, "Input",
      CellTags->"Cell 6.33"]},
  "Cell 6.34"->{
    Cell[1986212, 51938, 106, 3, 67, "Input",
      CellTags->"Cell 6.34"]},
  "Cell 6.35"->{
    Cell[1986726, 51957, 163, 4, 67, "Input",
      CellTags->"Cell 6.35"]},
  "Cell 6.36"->{
    Cell[1987089, 51971, 120, 3, 67, "Input",
      CellTags->"Cell 6.36"]},
  "Cell 6.37"->{
    Cell[1987407, 51983, 127, 3, 67, "Input",
      CellTags->"Cell 6.37"]},
  "Cell 6.38"->{
    Cell[1988099, 52004, 275, 6, 86, "Input",
      CellTags->"Cell 6.38"]},
  "Cell 6.39"->{
    Cell[1988607, 52022, 178, 5, 67, "Input",
      CellTags->"Cell 6.39"]},
  "Cell 6.40"->{
    Cell[1988898, 52034, 262, 6, 86, "Input",
      CellTags->"Cell 6.40"]},
  "Cell 6.41"->{
    Cell[1989255, 52046, 137, 3, 67, "Input",
      CellTags->"Cell 6.41"]},
  "Cell 6.42"->{
    Cell[2020600, 52951, 315, 6, 124, "Input",
      CellTags->"Cell 6.42"]},
  "Cell 6.43"->{
    Cell[2030399, 53253, 161, 5, 67, "Input",
      CellTags->"Cell 6.43"]},
  "Cell 6.44"->{
    Cell[2030657, 53265, 125, 3, 67, "Input",
      CellTags->"Cell 6.44"]},
  "Cell 6.45"->{
    Cell[2030962, 53277, 401, 9, 124, "Input",
      CellTags->"Cell 6.45"]},
  "Cell 6.46"->{
    Cell[2031515, 53296, 299, 7, 105, "Input",
      CellTags->"Cell 6.46"]},
  "i:13"->{
    Cell[2032222, 53316, 109, 4, 27, "Text",
      CellTags->"i:13"]},
  "Cell 6.47"->{
    Cell[2032334, 53322, 5708, 118, 850, "Input",
      CellTags->"Cell 6.47"]},
  "i:14"->{
    Cell[2038079, 53445, 97, 1, 31, "Section",
      CellTags->{"i:14", "c:11"}]},
  "c:11"->{
    Cell[2038079, 53445, 97, 1, 31, "Section",
      CellTags->{"i:14", "c:11"}]},
  "(6.1.27)"->{
    Cell[2038814, 53467, 334, 9, 42, "NumberedEquation",
      CellTags->"(6.1.27)"]},
  "(6.1.28)"->{
    Cell[2039215, 53480, 147, 5, 29, "NumberedEquation",
      CellTags->"(6.1.28)"]},
  "(6.1.29)"->{
    Cell[2039523, 53496, 553, 15, 45, "NumberedEquation",
      CellTags->"(6.1.29)"]},
  "(6.1.30)"->{
    Cell[2040544, 53527, 337, 11, 38, "NumberedEquation",
      CellTags->"(6.1.30)"]},
  "(6.1.31)"->{
    Cell[2041053, 53548, 492, 11, 42, "NumberedEquation",
      CellTags->"(6.1.31)"]},
  "(6.1.32)"->{
    Cell[2041835, 53572, 195, 6, 34, "NumberedEquation",
      CellTags->"(6.1.32)"]},
  "(6.1.33)"->{
    Cell[2042457, 53594, 337, 9, 42, "NumberedEquation",
      CellTags->"(6.1.33)"]},
  "(6.1.34)"->{
    Cell[2042965, 53612, 351, 9, 37, "NumberedEquation",
      CellTags->"(6.1.34)"]},
  "(6.1.35)"->{
    Cell[2043520, 53631, 200, 6, 42, "NumberedEquation",
      CellTags->"(6.1.35)"]},
  "(6.1.36)"->{
    Cell[2044295, 53659, 472, 10, 38, "NumberedEquation",
      CellTags->"(6.1.36)"]},
  "Cell 6.48"->{
    Cell[2044975, 53678, 104, 3, 67, "Input",
      CellTags->"Cell 6.48"]},
  "Cell 6.49"->{
    Cell[2047374, 53761, 3458, 69, 626, "Input",
      CellTags->"Cell 6.49"]},
  "Cell 6.50"->{
    Cell[2051420, 53855, 123, 3, 67, "Input",
      CellTags->"Cell 6.50"]},
  "Cell 6.51"->{
    Cell[3969033, 101231, 342, 7, 112, "Input",
      CellTags->"Cell 6.51"]},
  "i:16"->{
    Cell[4451348, 118122, 1019, 24, 112, "Text",
      CellTags->"i:16"]},
  "i:15"->{
    Cell[4453587, 118182, 650, 13, 95, "Text",
      CellTags->"i:15"]},
  "c:12"->{
    Cell[4455225, 118222, 65, 1, 30, "Subsubtitle",
      CellTags->"c:12"]},
  "Fig. 6.4"->{
    Cell[4477537, 118514, 65, 1, 16, "Caption",
      CellTags->"Fig. 6.4"]},
  "Fig. 6.5"->{
    Cell[4513513, 119014, 65, 1, 16, "Caption",
      CellTags->"Fig. 6.5"]},
  "i:37"->{
    Cell[4527533, 119472, 222, 6, 42, "NumberedEquation",
      CellTags->{"i:37", "(6.1.37)"}]},
  "(6.1.37)"->{
    Cell[4527533, 119472, 222, 6, 42, "NumberedEquation",
      CellTags->{"i:37", "(6.1.37)"}]},
  "i:17"->{
    Cell[4528689, 119519, 66, 1, 40, "Subtitle",
      CellTags->{"i:17", "c:13"}]},
  "c:13"->{
    Cell[4528689, 119519, 66, 1, 40, "Subtitle",
      CellTags->{"i:17", "c:13"}]},
  "c:14"->{
    Cell[4528799, 119526, 72, 1, 41, "Subsubtitle",
      CellTags->"c:14"]},
  "i:18"->{
    Cell[4528896, 119531, 82, 1, 42, "Section",
      CellTags->{"i:18", "c:15"}]},
  "c:15"->{
    Cell[4528896, 119531, 82, 1, 42, "Section",
      CellTags->{"i:18", "c:15"}]},
  "(6.2.1)"->{
    Cell[4529716, 119557, 234, 7, 42, "NE2",
      CellTags->"(6.2.1)"]},
  "(6.2.2)"->{
    Cell[4530436, 119582, 775, 24, 45, "NE2",
      CellTags->"(6.2.2)"]},
  "(6.2.3)"->{
    Cell[4532677, 119651, 651, 19, 48, "NE2",
      CellTags->"(6.2.3)"]},
  "(6.2.4)"->{
    Cell[4533380, 119674, 835, 24, 45, "NE2",
      CellTags->"(6.2.4)"]},
  "(6.2.5)"->{
    Cell[4534701, 119718, 909, 25, 39, "NE2",
      CellTags->"(6.2.5)"]},
  "Cell 6.52"->{
    Cell[4537395, 119807, 397, 9, 172, "Input",
      CellTags->"Cell 6.52"]},
  "Cell 6.53"->{
    Cell[4538881, 119854, 225, 5, 86, "Input",
      CellTags->"Cell 6.53"]},
  "Cell 6.54"->{
    Cell[4539499, 119875, 136, 3, 67, "Input",
      CellTags->"Cell 6.54"]},
  "Cell 6.55"->{
    Cell[4540768, 119922, 359, 7, 146, "Input",
      CellTags->"Cell 6.55"]},
  "Cell 6.56"->{
    Cell[4541369, 119942, 386, 9, 105, "Input",
      CellTags->"Cell 6.56"]},
  "i:70"->{
    Cell[5120163, 133924, 2261, 70, 95, "Text",
      CellTags->"i:70"]},
  "Cell 6.57"->{
    Cell[5122449, 133998, 644, 14, 181, "Input",
      CellTags->"Cell 6.57"]},
  "i:19"->{
    Cell[5424578, 139751, 79, 1, 31, "Section",
      CellTags->{"i:19", "c:16"}]},
  "c:16"->{
    Cell[5424578, 139751, 79, 1, 31, "Section",
      CellTags->{"i:19", "c:16"}]},
  "i:58"->{
    Cell[5424660, 139754, 1708, 44, 157, "Text",
      CellTags->"i:58"]},
  "(6.2.6)"->{
    Cell[5427903, 139843, 1025, 28, 39, "NE2",
      CellTags->"(6.2.6)"]},
  "(6.2.7)"->{
    Cell[5429049, 139878, 121, 5, 29, "NE2",
      CellTags->"(6.2.7)"]},
  "(6.2.8)"->{
    Cell[5429795, 139907, 872, 24, 39, "NE2",
      CellTags->"(6.2.8)"]},
  "Fig. 6.6"->{
    Cell[5481924, 141294, 114, 4, 16, "Caption",
      CellTags->"Fig. 6.6"]},
  "(6.2.9)"->{
    Cell[5483283, 141340, 554, 18, 39, "NE2",
      CellTags->"(6.2.9)"]},
  "i:65"->{
    Cell[5483840, 141360, 1996, 63, 97, "Text",
      CellTags->"i:65"]},
  "i:20"->{
    Cell[5485873, 141428, 60, 1, 31, "Section",
      CellTags->{"i:20", "c:17"}]},
  "c:17"->{
    Cell[5485873, 141428, 60, 1, 31, "Section",
      CellTags->{"i:20", "c:17"}]},
  "(6.2.10)"->{
    Cell[5486537, 141446, 928, 25, 39, "NE2",
      CellTags->"(6.2.10)"]},
  "(6.2.11)"->{
    Cell[5487953, 141488, 144, 5, 32, "NE2",
      CellTags->"(6.2.11)"]},
  "Cell 6.58"->{
    Cell[5489116, 141529, 316, 7, 92, "Input",
      CellTags->"Cell 6.58"]},
  "i:21"->{
    Cell[5511437, 142120, 59, 1, 31, "Section",
      CellTags->{"i:21", "c:18"}]},
  "c:18"->{
    Cell[5511437, 142120, 59, 1, 31, "Section",
      CellTags->{"i:21", "c:18"}]},
  "(6.2.12)"->{
    Cell[5512897, 142158, 969, 25, 39, "NE2",
      CellTags->"(6.2.12)"]},
  "Cell 6.59"->{
    Cell[5516026, 142258, 506, 11, 122, "Input",
      CellTags->"Cell 6.59"]},
  "(6.2.13)"->{
    Cell[5569427, 143506, 527, 15, 33, "NE2",
      CellTags->"(6.2.13)"]},
  "i:22"->{
    Cell[5570713, 143545, 96, 1, 31, "Section",
      CellTags->{"i:22", "c:19"}]},
  "c:19"->{
    Cell[5570713, 143545, 96, 1, 31, "Section",
      CellTags->{"i:22", "c:19"}]},
  "(6.2.14)"->{
    Cell[5571670, 143573, 902, 25, 39, "NE2",
      CellTags->"(6.2.14)"]},
  "i:25"->{
    Cell[5572575, 143600, 1194, 36, 107, "Text",
      CellTags->"i:25"]},
  "(6.2.15)"->{
    Cell[5574156, 143651, 638, 18, 35, "NE2",
      CellTags->"(6.2.15)"]},
  "(6.2.16)"->{
    Cell[5576448, 143731, 1146, 30, 39, "NE2",
      CellTags->"(6.2.16)"]},
  "i:23"->{
    Cell[5577597, 143763, 1147, 39, 61, "Text",
      CellTags->"i:23"]},
  "(6.2.17)"->{
    Cell[5578747, 143804, 979, 27, 44, "NE2",
      CellTags->"(6.2.17)"]},
  "Cell 6.60"->{
    Cell[5580304, 143853, 218, 6, 86, "Input",
      CellTags->"Cell 6.60"]},
  "Cell 6.61"->{
    Cell[5581331, 143891, 234, 6, 124, "Input",
      CellTags->"Cell 6.61"]},
  "(6.2.18)"->{
    Cell[5581708, 143904, 226, 7, 36, "NE2",
      CellTags->"(6.2.18)"]},
  "Cell 6.62"->{
    Cell[5583856, 143974, 174, 5, 67, "Input",
      CellTags->"Cell 6.62"]},
  "Cell 6.63"->{
    Cell[5585170, 144015, 1954, 41, 406, "Input",
      CellTags->"Cell 6.63"]},
  "Cell 6.64"->{
    Cell[5588677, 144113, 988, 20, 258, "Input",
      CellTags->"Cell 6.64"]},
  "Cell 6.65"->{
    Cell[5823040, 150097, 264, 7, 124, "Input",
      CellTags->"Cell 6.65"]},
  "Cell 6.66"->{
    Cell[5824640, 150157, 189, 4, 86, "Input",
      CellTags->"Cell 6.66"]},
  "i:24"->{
    Cell[5922612, 152106, 91, 1, 31, "Section",
      CellTags->{"i:24", "c:20"}]},
  "c:20"->{
    Cell[5922612, 152106, 91, 1, 31, "Section",
      CellTags->{"i:24", "c:20"}]},
  "(6.2.19)"->{
    Cell[5923292, 152125, 361, 12, 43, "NE2",
      CellTags->"(6.2.19)"]},
  "(6.2.20)"->{
    Cell[5923781, 152144, 433, 15, 30, "NE2",
      CellTags->"(6.2.20)"]},
  "(6.2.21)"->{
    Cell[5926522, 152233, 407, 15, 30, "NE2",
      CellTags->"(6.2.21)"]},
  "Cell 6.67"->{
    Cell[5929796, 152348, 366, 9, 181, "Input",
      CellTags->"Cell 6.67"]},
  "Cell 6.68"->{
    Cell[5930363, 152367, 157, 4, 86, "Input",
      CellTags->"Cell 6.68"]},
  "Cell 6.69"->{
    Cell[5930709, 152379, 114, 3, 67, "Input",
      CellTags->"Cell 6.69"]},
  "Cell 6.70"->{
    Cell[5931307, 152399, 148, 4, 67, "Input",
      CellTags->"Cell 6.70"]},
  "Cell 6.71"->{
    Cell[5931940, 152419, 1007, 20, 277, "Input",
      CellTags->"Cell 6.71"]},
  "(6.2.22)"->{
    Cell[6176121, 158864, 400, 14, 43, "NE2",
      CellTags->"(6.2.22)"]},
  "(6.2.23)"->{
    Cell[6176677, 158888, 1012, 28, 43, "NE2",
      CellTags->"(6.2.23)"]},
  "(6.2.24)"->{
    Cell[6178435, 158942, 537, 14, 43, "NE2",
      CellTags->"(6.2.24)"]},
  "(6.2.25)"->{
    Cell[6179009, 158960, 1034, 27, 43, "NE2",
      CellTags->"(6.2.25)"]},
  "c:21"->{
    Cell[6180235, 158997, 66, 1, 31, "Section",
      CellTags->"c:21"]},
  "(6.2.26)"->{
    Cell[6180588, 159010, 272, 7, 45, "NE2",
      CellTags->"(6.2.26)"]},
  "(6.2.27)"->{
    Cell[6181270, 159035, 791, 24, 48, "NE2",
      CellTags->"(6.2.27)"]},
  "(6.2.28)"->{
    Cell[6182877, 159092, 1567, 41, 42, "NE2",
      CellTags->"(6.2.28)"]},
  "(6.2.29)"->{
    Cell[6185168, 159153, 1111, 32, 46, "NE2",
      CellTags->"(6.2.29)"]},
  "i:26"->{
    Cell[6186484, 159196, 94, 1, 29, "Subsubsection",
      CellTags->"i:26"]},
  "Cell 6.72"->{
    Cell[6188130, 159258, 455, 10, 168, "Input",
      CellTags->"Cell 6.72"]},
  "Cell 6.73"->{
    Cell[6302334, 161338, 1652, 31, 493, "Input",
      CellTags->"Cell 6.73"]},
  "Cell 6.74"->{
    Cell[6305687, 161417, 612, 13, 246, "Input",
      CellTags->"Cell 6.74"]},
  "Cell 6.75"->{
    Cell[6309341, 161525, 106, 3, 67, "Input",
      CellTags->"Cell 6.75"]},
  "Cell 6.76"->{
    Cell[6309758, 161542, 267, 6, 126, "Input",
      CellTags->"Cell 6.76"]},
  "Cell 6.77"->{
    Cell[6310201, 161560, 354, 8, 105, "Input",
      CellTags->"Cell 6.77"]},
  "i:28"->{
    Cell[8074790, 199007, 932, 22, 89, "Text",
      CellTags->"i:28"]},
  "i:27"->{
    Cell[8075759, 199034, 84, 1, 29, "Subsubsection",
      CellTags->"i:27"]},
  "(6.2.30)"->{
    Cell[8076056, 199043, 737, 18, 38, "NE2",
      CellTags->"(6.2.30)"]},
  "i:69"->{
    Cell[8079832, 199155, 1914, 49, 140, "Text",
      CellTags->"i:69"]},
  "(6.2.31)"->{
    Cell[8081749, 199206, 1121, 29, 83, "NE2",
      CellTags->"(6.2.31)"]},
  "Cell 6.78"->{
    Cell[8084836, 199286, 242, 6, 88, "Input",
      CellTags->"Cell 6.78"]},
  "Cell 6.79"->{
    Cell[8085424, 199304, 862, 17, 261, "Input",
      CellTags->"Cell 6.79"]},
  "(6.2.32)"->{
    Cell[8086361, 199325, 302, 8, 38, "NE2",
      CellTags->"(6.2.32)"]},
  "Cell 6.80"->{
    Cell[8087733, 199373, 267, 7, 88, "Input",
      CellTags->"Cell 6.80"]},
  "Cell 6.81"->{
    Cell[8088116, 199387, 434, 9, 146, "Input",
      CellTags->"Cell 6.81"]},
  "Cell 6.82"->{
    Cell[8088584, 199400, 3653, 77, 652, "Input",
      CellTags->"Cell 6.82"]},
  "Cell 6.83"->{
    Cell[8092818, 199502, 326, 8, 145, "Input",
      CellTags->"Cell 6.83"]},
  "Cell 6.84"->{
    Cell[8093336, 199521, 381, 8, 128, "Input",
      CellTags->"Cell 6.84"]},
  "Cell 6.85"->{
    Cell[9377861, 224020, 1003, 21, 309, "Input",
      CellTags->"Cell 6.85"]},
  "i:29"->{
    Cell[9463472, 226240, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:29", "c:22"}]},
  "c:22"->{
    Cell[9463472, 226240, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:29", "c:22"}]},
  "i:30"->{
    Cell[9463579, 226245, 64, 1, 42, "Section",
      CellTags->{"i:30", "c:23"}]},
  "c:23"->{
    Cell[9463579, 226245, 64, 1, 42, "Section",
      CellTags->{"i:30", "c:23"}]},
  "(6.2.33)"->{
    Cell[9463850, 226254, 208, 6, 45, "NE2",
      CellTags->"(6.2.33)"]},
  "(6.2.34)"->{
    Cell[9466012, 226334, 1086, 31, 45, "NE2",
      CellTags->"(6.2.34)"]},
  "Cell 6.86"->{
    Cell[9468217, 226407, 263, 7, 130, "Input",
      CellTags->"Cell 6.86"]},
  "Cell 6.87"->{
    Cell[9468595, 226421, 245, 6, 126, "Input",
      CellTags->"Cell 6.87"]},
  "Cell 6.88"->{
    Cell[9468992, 226436, 107, 3, 67, "Input",
      CellTags->"Cell 6.88"]},
  "Cell 6.89"->{
    Cell[9469310, 226449, 2818, 62, 192, "Input",
      CellTags->"Cell 6.89"]},
  "Cell 6.90"->{
    Cell[9472241, 226518, 184, 5, 69, "Input",
      CellTags->"Cell 6.90"]},
  "Cell 6.91"->{
    Cell[9472479, 226527, 125, 3, 67, "Input",
      CellTags->"Cell 6.91"]},
  "Cell 6.92"->{
    Cell[9472841, 226541, 271, 7, 107, "Input",
      CellTags->"Cell 6.92"]},
  "Cell 6.93"->{
    Cell[9473453, 226566, 263, 6, 86, "Input",
      CellTags->"Cell 6.93"]},
  "i:31"->{
    Cell[9629992, 229617, 74, 1, 31, "Section",
      CellTags->{"i:31", "c:24"}]},
  "c:24"->{
    Cell[9629992, 229617, 74, 1, 31, "Section",
      CellTags->{"i:31", "c:24"}]},
  "(6.2.35)"->{
    Cell[9630360, 229627, 843, 29, 48, "NE2",
      CellTags->"(6.2.35)"]},
  "(6.2.36)"->{
    Cell[9632443, 229703, 1115, 32, 57, "NE2",
      CellTags->"(6.2.36)"]},
  "Cell 6.94"->{
    Cell[9634458, 229767, 470, 10, 206, "Input",
      CellTags->"Cell 6.94"]},
  "Cell 6.95"->{
    Cell[9635027, 229784, 523, 11, 145, "Input",
      CellTags->"Cell 6.95"]},
  "Cell 6.96"->{
    Cell[9637251, 229855, 337, 9, 86, "Input",
      CellTags->"Cell 6.96"]},
  "(6.2.37)"->{
    Cell[9639972, 229948, 379, 12, 40, "NE2",
      CellTags->"(6.2.37)"]},
  "(6.2.38)"->{
    Cell[9640409, 229964, 426, 14, 40, "NE2",
      CellTags->"(6.2.38)"]},
  "Cell 6.97"->{
    Cell[9641085, 229991, 548, 13, 190, "Input",
      CellTags->"Cell 6.97"]},
  "Cell 6.98"->{
    Cell[9641822, 230016, 369, 8, 128, "Input",
      CellTags->"Cell 6.98"]},
  "i:68"->{
    Cell[9666323, 230564, 1142, 22, 146, "Text",
      CellTags->"i:68"]},
  "Cell 6.99"->{
    Cell[9668594, 230623, 109, 3, 67, "Input",
      CellTags->"Cell 6.99"]},
  "Cell 6.100"->{
    Cell[9668906, 230636, 3221, 68, 241, "Input",
      CellTags->"Cell 6.100"]},
  "Cell 6.101"->{
    Cell[9672177, 230708, 212, 6, 69, "Input",
      CellTags->"Cell 6.101"]},
  "Cell 6.102"->{
    Cell[9672443, 230718, 126, 3, 67, "Input",
      CellTags->"Cell 6.102"]},
  "Cell 6.103"->{
    Cell[9672688, 230730, 225, 6, 107, "Input",
      CellTags->"Cell 6.103"]},
  "Cell 6.104"->{
    Cell[9673253, 230753, 93, 3, 67, "Input",
      CellTags->"Cell 6.104"]},
  "Cell 6.105"->{
    Cell[9673371, 230760, 394, 8, 105, "Input",
      CellTags->"Cell 6.105"]},
  "Fig. 6.7"->{
    Cell[9827390, 235682, 52, 1, 16, "Caption",
      CellTags->"Fig. 6.7"]},
  "i:32"->{
    Cell[9827930, 235702, 67, 1, 31, "Section",
      CellTags->{"i:32", "c:25"}]},
  "c:25"->{
    Cell[9827930, 235702, 67, 1, 31, "Section",
      CellTags->{"i:32", "c:25"}]},
  "i:33"->{
    Cell[9828022, 235707, 60, 1, 27, "Subsubsection",
      CellTags->"i:33"]},
  "(6.2.39)"->{
    Cell[9832229, 235825, 1985, 51, 46, "NE2",
      CellTags->"(6.2.39)"]},
  "i:61"->{
    Cell[9834217, 235878, 1069, 34, 81, "Text",
      CellTags->"i:61"]},
  "Cell 6.106"->{
    Cell[9835406, 235919, 312, 8, 168, "Input",
      CellTags->"Cell 6.106"]},
  "Cell 6.107"->{
    Cell[9835829, 235934, 312, 6, 126, "Input",
      CellTags->"Cell 6.107"]},
  "Cell 6.108"->{
    Cell[9836333, 235950, 571, 11, 247, "Input",
      CellTags->"Cell 6.108"]},
  "Cell 6.109"->{
    Cell[9837194, 235972, 111, 3, 67, "Input",
      CellTags->"Cell 6.109"]},
  "Cell 6.110"->{
    Cell[9837606, 235988, 235, 6, 107, "Input",
      CellTags->"Cell 6.110"]},
  "Cell 6.111"->{
    Cell[9838144, 236008, 396, 8, 164, "Input",
      CellTags->"Cell 6.111"]},
  "Cell 6.112"->{
    Cell[9838882, 236033, 91, 3, 67, "Input",
      CellTags->"Cell 6.112"]},
  "Cell 6.113"->{
    Cell[9839069, 236044, 225, 5, 105, "Input",
      CellTags->"Cell 6.113"]},
  "Cell 6.114"->{
    Cell[9892874, 237620, 266, 7, 107, "Input",
      CellTags->"Cell 6.114"]},
  "Cell 6.115"->{
    Cell[9893484, 237645, 318, 6, 105, "Input",
      CellTags->"Cell 6.115"]},
  "i:34"->{
    Cell[10146113, 242685, 72, 1, 29, "Subsubsection",
      CellTags->"i:34"]},
  "(6.2.40)"->{
    Cell[10149191, 242778, 2810, 66, 46, "NE2",
      CellTags->"(6.2.40)"]},
  "Cell 6.116"->{
    Cell[10154762, 242917, 4177, 78, 934, "Input",
      CellTags->"Cell 6.116"]},
  "Cell 6.117"->{
    Cell[10158964, 242999, 93, 3, 67, "Input",
      CellTags->"Cell 6.117"]},
  "Cell 6.118"->{
    Cell[10159790, 243028, 256, 6, 124, "Input",
      CellTags->"Cell 6.118"]},
  "i:36"->{
    Cell[10196291, 244123, 59, 1, 31, "Section",
      CellTags->{"i:36", "c:26"}]},
  "c:26"->{
    Cell[10196291, 244123, 59, 1, 31, "Section",
      CellTags->{"i:36", "c:26"}]},
  "(6.2.41)"->{
    Cell[10199512, 244224, 369, 6, 40, "NE2",
      CellTags->"(6.2.41)"]},
  "(6.2.42)"->{
    Cell[10199906, 244234, 417, 9, 40, "NE2",
      CellTags->"(6.2.42)"]},
  "(6.2.43)"->{
    Cell[10201842, 244291, 179, 3, 44, "NE2",
      CellTags->"(6.2.43)"]},
  "Cell 6.119"->{
    Cell[10206274, 244440, 285, 8, 149, "Input",
      CellTags->"Cell 6.119"]},
  "Cell 6.120"->{
    Cell[10206992, 244461, 154, 4, 67, "Input",
      CellTags->"Cell 6.120"]},
  "Cell 6.121"->{
    Cell[10207346, 244475, 134, 3, 69, "Input",
      CellTags->"Cell 6.121"]},
  "Cell 6.122"->{
    Cell[10207717, 244494, 229, 5, 86, "Input",
      CellTags->"Cell 6.122"]},
  "Cell 6.123"->{
    Cell[10325616, 246651, 223, 5, 69, "Input",
      CellTags->"Cell 6.123"]},
  "Cell 6.124"->{
    Cell[10326020, 246666, 118, 3, 67, "Input",
      CellTags->"Cell 6.124"]},
  "Cell 6.125"->{
    Cell[10326341, 246680, 101, 3, 67, "Input",
      CellTags->"Cell 6.125"]},
  "Cell 6.126"->{
    Cell[10326990, 246702, 110, 3, 67, "Input",
      CellTags->"Cell 6.126"]},
  "Cell 6.127"->{
    Cell[10327363, 246718, 303, 7, 117, "Input",
      CellTags->"Cell 6.127"]},
  "Cell 6.128"->{
    Cell[10327861, 246735, 204, 5, 75, "Input",
      CellTags->"Cell 6.128"]},
  "Cell 6.129"->{
    Cell[10328422, 246755, 130, 3, 73, "Input",
      CellTags->"Cell 6.129"]},
  "Cell 6.130"->{
    Cell[10329349, 246783, 325, 7, 88, "Input",
      CellTags->"Cell 6.130"]},
  "Cell 6.131"->{
    Cell[10330318, 246817, 238, 5, 86, "Input",
      CellTags->"Cell 6.131"]},
  "c:27"->{
    Cell[10446766, 248956, 65, 1, 30, "Subsubtitle",
      CellTags->"c:27"]},
  "i:66"->{
    Cell[10450402, 249092, 207, 5, 44, "Text",
      CellTags->"i:66"]},
  "(6.2.44)"->{
    Cell[10450612, 249099, 519, 17, 29, "NE2",
      CellTags->"(6.2.44)"]},
  "i:38"->{
    Cell[10461768, 249481, 355, 11, 40, "Text",
      CellTags->"i:38"]},
  "(6.2.45)"->{
    Cell[10468233, 249700, 1091, 31, 46, "NE2",
      CellTags->"(6.2.45)"]},
  "Fig. 6.8"->{
    Cell[10507612, 250289, 66, 1, 16, "Caption",
      CellTags->"Fig. 6.8"]},
  "Fig. 6.9"->{
    Cell[10548113, 250834, 66, 1, 16, "Caption",
      CellTags->"Fig. 6.9"]},
  "Fig. 6.10"->{
    Cell[10862606, 257555, 68, 1, 16, "Caption",
      CellTags->"Fig. 6.10"]},
  "i:62"->{
    Cell[10865146, 257633, 2571, 80, 136, "Text",
      CellTags->"i:62"]},
  "Fig. 6.11"->{
    Cell[14414591, 306523, 459, 16, 29, "Caption",
      CellTags->"Fig. 6.11"]},
  "i:39"->{
    Cell[14416942, 306604, 113, 2, 40, "Subtitle",
      CellTags->{"i:39", "c:28"}]},
  "c:28"->{
    Cell[14416942, 306604, 113, 2, 40, "Subtitle",
      CellTags->{"i:39", "c:28"}]},
  "c:29"->{
    Cell[14417099, 306612, 61, 1, 41, "Subsubtitle",
      CellTags->"c:29"]},
  "i:42"->{
    Cell[14419248, 306661, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:30"}]},
  "c:30"->{
    Cell[14419248, 306661, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:42", "c:30"}]},
  "c:31"->{
    Cell[14419354, 306666, 53, 1, 42, "Section",
      CellTags->"c:31"]},
  "(6.3.1)"->{
    Cell[14419476, 306671, 150, 5, 33, "NE3",
      CellTags->"(6.3.1)"]},
  "(6.3.2)"->{
    Cell[14423352, 306801, 298, 9, 35, "NE3",
      CellTags->"(6.3.2)"]},
  "(6.3.3)"->{
    Cell[14425350, 306870, 305, 9, 35, "NE3",
      CellTags->"(6.3.3)"]},
  "(6.3.4)"->{
    Cell[14425737, 306883, 1507, 42, 93, "NE3",
      CellTags->"(6.3.4)"]},
  "(6.3.5)"->{
    Cell[14427684, 306943, 1534, 35, 93, "NE3",
      CellTags->"(6.3.5)"]},
  "c:32"->{
    Cell[14429856, 307005, 97, 1, 31, "Section",
      CellTags->"c:32"]},
  "(2.4.49)"->{
    Cell[14432188, 307091, 653, 18, 34, "NE3",
      CellTags->{"(2.4.49)", "(6.3.6)"}]},
  "(6.3.6)"->{
    Cell[14432188, 307091, 653, 18, 34, "NE3",
      CellTags->{"(2.4.49)", "(6.3.6)"}]},
  "Cell 6.132"->{
    Cell[14433541, 307140, 1070, 22, 328, "Input",
      CellTags->"Cell 6.132"]},
  "Cell 6.133"->{
    Cell[14434897, 307176, 136, 4, 86, "Input",
      CellTags->"Cell 6.133"]},
  "Cell 6.134"->{
    Cell[14436225, 307218, 278, 7, 124, "Input",
      CellTags->"Cell 6.134"]},
  "Cell 6.135"->{
    Cell[14439518, 307277, 583, 13, 162, "Input",
      CellTags->"Cell 6.135"]},
  "Cell 6.136"->{
    Cell[14473083, 308057, 170, 5, 67, "Input",
      CellTags->"Cell 6.136"]},
  "Cell 6.137"->{
    Cell[14474478, 308100, 121, 3, 67, "Input",
      CellTags->"Cell 6.137"]},
  "Cell 6.138"->{
    Cell[14475042, 308116, 331, 7, 124, "Input",
      CellTags->"Cell 6.138"]},
  "Cell 6.139"->{
    Cell[14475589, 308133, 231, 6, 67, "Input",
      CellTags->"Cell 6.139"]},
  "Cell 6.140"->{
    Cell[14476204, 308158, 468, 10, 124, "Input",
      CellTags->"Cell 6.140"]},
  "Cell 6.141"->{
    Cell[14915810, 317273, 1179, 23, 276, "Input",
      CellTags->"Cell 6.141"]},
  "i:47"->{
    Cell[15018897, 319902, 82, 1, 31, "Section",
      CellTags->{"i:47", "c:33"}]},
  "c:33"->{
    Cell[15018897, 319902, 82, 1, 31, "Section",
      CellTags->{"i:47", "c:33"}]},
  "(6.3.7)"->{
    Cell[15020346, 319952, 540, 16, 65, "NE3",
      CellTags->"(6.3.7)"]},
  "Cell 6.142"->{
    Cell[15021341, 319985, 488, 11, 225, "Input",
      CellTags->"Cell 6.142"]},
  "Cell 6.143"->{
    Cell[15021940, 320003, 468, 11, 183, "Input",
      CellTags->"Cell 6.143"]},
  "Cell 6.144"->{
    Cell[15022612, 320026, 384, 8, 128, "Input",
      CellTags->"Cell 6.144"]},
  "Cell 6.145"->{
    Cell[15051360, 320686, 386, 8, 267, "Input",
      CellTags->"Cell 6.145"]},
  "Cell 6.146"->{
    Cell[15052042, 320706, 212, 6, 69, "Input",
      CellTags->"Cell 6.146"]},
  "Cell 6.147"->{
    Cell[15053021, 320740, 224, 6, 105, "Input",
      CellTags->"Cell 6.147"]},
  "Cell 6.148"->{
    Cell[15054176, 320780, 118, 3, 67, "Input",
      CellTags->"Cell 6.148"]},
  "Cell 6.149"->{
    Cell[15054373, 320789, 110, 3, 67, "Input",
      CellTags->"Cell 6.149"]},
  "Cell 6.150"->{
    Cell[15059135, 320862, 112, 3, 67, "Input",
      CellTags->"Cell 6.150"]},
  "Cell 6.151"->{
    Cell[15060469, 320904, 120, 3, 67, "Input",
      CellTags->"Cell 6.151"]},
  "Cell 6.152"->{
    Cell[15061513, 320941, 105, 3, 67, "Input",
      CellTags->"Cell 6.152"]},
  "Cell 6.153"->{
    Cell[15067914, 321068, 575, 11, 147, "Input",
      CellTags->"Cell 6.153"]},
  "Cell 6.154"->{
    Cell[15069628, 321117, 503, 10, 162, "Input",
      CellTags->"Cell 6.154"]},
  "i:41"->{
    Cell[15625979, 339346, 85, 1, 30, "Subsubtitle",
      CellTags->{"i:41", "c:34"}]},
  "c:34"->{
    Cell[15625979, 339346, 85, 1, 30, "Subsubtitle",
      CellTags->{"i:41", "c:34"}]},
  "c:35"->{
    Cell[15626089, 339351, 53, 1, 42, "Section",
      CellTags->"c:35"]},
  "(6.3.8)"->{
    Cell[15627213, 339378, 149, 5, 33, "NE3",
      CellTags->"(6.3.8)"]},
  "(6.3.9)"->{
    Cell[15627748, 339398, 145, 5, 38, "NE3",
      CellTags->"(6.3.9)"]},
  "(6.3.10)"->{
    Cell[15628501, 339431, 222, 4, 38, "NE3",
      CellTags->"(6.3.10)"]},
  "(6.3.11)"->{
    Cell[15630679, 339505, 985, 31, 32, "NE3",
      CellTags->"(6.3.11)"]},
  "c:36"->{
    Cell[15632474, 339568, 91, 1, 31, "Section",
      CellTags->"c:36"]},
  "(6.3.12)"->{
    Cell[15632715, 339576, 222, 6, 42, "NE3",
      CellTags->"(6.3.12)"]},
  "Cell 6.155"->{
    Cell[15635651, 339659, 861, 17, 205, "Input",
      CellTags->"Cell 6.155"]},
  "Cell 6.156"->{
    Cell[15636777, 339688, 180, 5, 74, "Input",
      CellTags->"Cell 6.156"]},
  "Cell 6.157"->{
    Cell[15637743, 339718, 111, 3, 67, "Input",
      CellTags->"Cell 6.157"]},
  "Cell 6.158"->{
    Cell[15638119, 339735, 152, 4, 67, "Input",
      CellTags->"Cell 6.158"]},
  "Cell 6.159"->{
    Cell[15638636, 339754, 945, 19, 257, "Input",
      CellTags->"Cell 6.159"]},
  "Cell 6.160"->{
    Cell[15639768, 339784, 95, 3, 67, "Input",
      CellTags->"Cell 6.160"]},
  "Cell 6.161"->{
    Cell[15640183, 339798, 93, 3, 67, "Input",
      CellTags->"Cell 6.161"]},
  "Cell 6.162"->{
    Cell[15640857, 339823, 171, 5, 67, "Input",
      CellTags->"Cell 6.162"]},
  "Cell 6.163"->{
    Cell[15641537, 339847, 284, 6, 86, "Input",
      CellTags->"Cell 6.163"]},
  "i:48"->{
    Cell[15797621, 343646, 82, 1, 31, "Section",
      CellTags->{"i:48", "c:37"}]},
  "c:37"->{
    Cell[15797621, 343646, 82, 1, 31, "Section",
      CellTags->{"i:48", "c:37"}]},
  "Cell 6.164"->{
    Cell[15810464, 344053, 470, 12, 207, "Input",
      CellTags->"Cell 6.164"]},
  "Cell 6.165"->{
    Cell[15813670, 344112, 3913, 81, 583, "Input",
      CellTags->"Cell 6.165"]},
  "Cell 6.166"->{
    Cell[15817707, 344202, 97, 3, 67, "Input",
      CellTags->"Cell 6.166"]},
  "Cell 6.167"->{
    Cell[15817867, 344211, 90, 3, 67, "Input",
      CellTags->"Cell 6.167"]},
  "Cell 6.168"->{
    Cell[15819078, 344244, 162, 5, 105, "Input",
      CellTags->"Cell 6.168"]},
  "i:67"->{
    Cell[15820233, 344267, 485, 15, 44, "Text",
      CellTags->"i:67"]},
  "Cell 6.169"->{
    Cell[15820743, 344286, 916, 19, 279, "Input",
      CellTags->"Cell 6.169"]},
  "c:38"->{
    Cell[17227372, 373240, 63, 1, 30, "Subsubtitle",
      CellTags->"c:38"]},
  "c:39"->{
    Cell[17227479, 373247, 56, 1, 42, "Section",
      CellTags->"c:39"]},
  "i:43"->{
    Cell[17227538, 373250, 268, 6, 44, "Text",
      CellTags->"i:43"]},
  "(3.1.7)"->{
    Cell[17228070, 373269, 336, 8, 45, "NE3",
      CellTags->{"(3.1.7)", "(6.3.13)"}]},
  "(6.3.13)"->{
    Cell[17228070, 373269, 336, 8, 45, "NE3",
      CellTags->{"(3.1.7)", "(6.3.13)"}]},
  "(6.3.14)"->{
    Cell[17228746, 373292, 274, 8, 41, "NE3",
      CellTags->"(6.3.14)"]},
  "(6.3.15)"->{
    Cell[17229044, 373304, 494, 12, 44, "NE3",
      CellTags->"(6.3.15)"]},
  "(6.3.16)"->{
    Cell[17230328, 373342, 275, 6, 43, "NE3",
      CellTags->"(6.3.16)"]},
  "(6.3.17)"->{
    Cell[17230759, 373357, 258, 9, 34, "NE3",
      CellTags->"(6.3.17)"]},
  "(6.3.18)"->{
    Cell[17231273, 373379, 140, 5, 29, "NE3",
      CellTags->"(6.3.18)"]},
  "(6.3.19)"->{
    Cell[17232108, 373405, 242, 7, 42, "NE3",
      CellTags->"(6.3.19)"]},
  "(6.3.20)"->{
    Cell[17234613, 373493, 347, 8, 53, "NE3",
      CellTags->"(6.3.20)"]},
  "Cell 6.170"->{
    Cell[17235154, 373511, 948, 22, 352, "Input",
      CellTags->"Cell 6.170"]},
  "Fig. 6.12"->{
    Cell[18431018, 405752, 165, 4, 17, "Caption",
      CellTags->"Fig. 6.12"]},
  "i:40"->{
    Cell[18432220, 405783, 95, 1, 31, "Section",
      CellTags->{"i:40", "c:40"}]},
  "c:40"->{
    Cell[18432220, 405783, 95, 1, 31, "Section",
      CellTags->{"i:40", "c:40"}]},
  "Cell 6.171"->{
    Cell[18434074, 405832, 389, 8, 116, "Input",
      CellTags->"Cell 6.171"]},
  "Cell 6.172"->{
    Cell[18434643, 405851, 143, 4, 67, "Input",
      CellTags->"Cell 6.172"]},
  "Cell 6.173"->{
    Cell[18435320, 405877, 323, 7, 86, "Input",
      CellTags->"Cell 6.173"]},
  "Cell 6.174"->{
    Cell[18435770, 405893, 396, 9, 107, "Input",
      CellTags->"Cell 6.174"]},
  "Cell 6.175"->{
    Cell[18437962, 405949, 158, 4, 67, "Input",
      CellTags->"Cell 6.175"]},
  "Cell 6.176"->{
    Cell[18438423, 405966, 620, 13, 181, "Input",
      CellTags->"Cell 6.176"]},
  "Cell 6.177"->{
    Cell[18643573, 410578, 853, 20, 295, "Input",
      CellTags->"Cell 6.177"]},
  "Fig. 6.13"->{
    Cell[19829890, 442705, 312, 9, 30, "Caption",
      CellTags->"Fig. 6.13"]},
  "i:44"->{
    Cell[19830622, 442730, 94, 1, 31, "Section",
      CellTags->{"i:44", "c:41"}]},
  "c:41"->{
    Cell[19830622, 442730, 94, 1, 31, "Section",
      CellTags->{"i:44", "c:41"}]},
  "(6.3.21)"->{
    Cell[19831600, 442756, 235, 7, 42, "NE3",
      CellTags->"(6.3.21)"]},
  "(6.3.22)"->{
    Cell[19833097, 442808, 414, 9, 44, "NE3",
      CellTags->"(6.3.22)"]},
  "(6.3.23)"->{
    Cell[19836319, 442913, 242, 7, 33, "NE3",
      CellTags->"(6.3.23)"]},
  "(6.3.24)"->{
    Cell[19836881, 442931, 197, 6, 33, "NE3",
      CellTags->"(6.3.24)"]},
  "(6.3.25)"->{
    Cell[19837331, 442948, 219, 7, 33, "NE3",
      CellTags->"(6.3.25)"]},
  "Fig. 6.14"->{
    Cell[19891988, 444139, 131, 4, 16, "Caption",
      CellTags->"Fig. 6.14"]},
  "(6.3.26)"->{
    Cell[19892444, 444154, 297, 8, 43, "NE3",
      CellTags->"(6.3.26)"]},
  "Cell 6.178"->{
    Cell[19893186, 444182, 345, 7, 149, "Input",
      CellTags->"Cell 6.178"]},
  "(6.3.27)"->{
    Cell[19935438, 445198, 642, 17, 48, "NE3",
      CellTags->"(6.3.27)"]},
  "(6.3.28)"->{
    Cell[19936457, 445232, 671, 18, 51, "NE3",
      CellTags->"(6.3.28)"]},
  "(6.3.29)"->{
    Cell[19938487, 445294, 355, 9, 45, "NE3",
      CellTags->"(6.3.29)"]},
  "(6.3.30)"->{
    Cell[19938996, 445312, 689, 19, 51, "NE3",
      CellTags->"(6.3.30)"]},
  "(6.3.31)"->{
    Cell[19941476, 445380, 240, 7, 35, "NE3",
      CellTags->"(6.3.31)"]},
  "i:45"->{
    Cell[19941719, 445389, 877, 30, 61, "Text",
      CellTags->"i:45"]},
  "c:42"->{
    Cell[19943696, 445457, 87, 1, 31, "Section",
      CellTags->"c:42"]},
  "(6.3.32)"->{
    Cell[19945018, 445497, 242, 7, 58, "NE3",
      CellTags->"(6.3.32)"]},
  "Cell 6.179"->{
    Cell[19945462, 445517, 245, 6, 106, "Input",
      CellTags->"Cell 6.179"]},
  "i:46"->{
    Cell[19946365, 445546, 97, 1, 31, "Section",
      CellTags->{"i:46", "c:43"}]},
  "c:43"->{
    Cell[19946365, 445546, 97, 1, 31, "Section",
      CellTags->{"i:46", "c:43"}]},
  "Cell 6.180"->{
    Cell[19948064, 445591, 122, 3, 67, "Input",
      CellTags->"Cell 6.180"]},
  "Cell 6.181"->{
    Cell[19948312, 445604, 96, 3, 67, "Input",
      CellTags->"Cell 6.181"]},
  "Cell 6.182"->{
    Cell[19948825, 445625, 578, 11, 184, "Input",
      CellTags->"Cell 6.182"]},
  "Cell 6.183"->{
    Cell[19949704, 445649, 137, 3, 67, "Input",
      CellTags->"Cell 6.183"]},
  "Cell 6.184"->{
    Cell[19950025, 445662, 156, 4, 67, "Input",
      CellTags->"Cell 6.184"]},
  "Cell 6.185"->{
    Cell[19950863, 445692, 815, 16, 219, "Input",
      CellTags->"Cell 6.185"]},
  "Cell 6.186"->{
    Cell[19951808, 445717, 134, 3, 67, "Input",
      CellTags->"Cell 6.186"]},
  "Cell 6.187"->{
    Cell[19956542, 445861, 191, 5, 67, "Input",
      CellTags->"Cell 6.187"]},
  "Cell 6.188"->{
    Cell[19956977, 445876, 446, 8, 105, "Input",
      CellTags->"Cell 6.188"]},
  "Cell 6.189"->{
    Cell[19958094, 445904, 280, 6, 86, "Input",
      CellTags->"Cell 6.189"]},
  "c:44"->{
    Cell[20251637, 452684, 65, 1, 30, "Subsubtitle",
      CellTags->"c:44"]},
  "Fig. 6.15"->{
    Cell[20344420, 453929, 53, 1, 16, "Caption",
      CellTags->"Fig. 6.15"]},
  "i:56"->{
    Cell[20352309, 454211, 1167, 29, 103, "Text",
      CellTags->"i:56"]},
  "Fig. 6.16"->{
    Cell[20403723, 454980, 68, 1, 16, "Caption",
      CellTags->"Fig. 6.16"]},
  "(6.3.33)"->{
    Cell[20405714, 455045, 184, 7, 38, "NE3",
      CellTags->"(6.3.33)"]},
  "i:49"->{
    Cell[20407507, 455106, 883, 29, 78, "Text",
      CellTags->"i:49"]},
  "(6.3.34)"->{
    Cell[20408393, 455137, 155, 6, 33, "NE3",
      CellTags->"(6.3.34)"]},
  "i:50"->{
    Cell[20409482, 455176, 2262, 69, 158, "Text",
      CellTags->"i:50"]},
  "(6.3.35)"->{
    Cell[20411747, 455247, 167, 6, 32, "NE3",
      CellTags->"(6.3.35)"]},
  "i:51"->{
    Cell[20411917, 455255, 902, 27, 86, "Text",
      CellTags->"i:51"]},
  "(6.3.36)"->{
    Cell[20413825, 455320, 225, 6, 49, "NE3",
      CellTags->"(6.3.36)"]},
  "i:52"->{
    Cell[20415007, 455363, 2311, 76, 107, "Text",
      CellTags->"i:52"]},
  "(6.3.37)"->{
    Cell[20417321, 455441, 410, 13, 29, "NE3",
      CellTags->"(6.3.37)"]},
  "(6.3.38)"->{
    Cell[20419614, 455527, 760, 22, 39, "NE3",
      CellTags->"(6.3.38)"]},
  "(6.3.39)"->{
    Cell[20421816, 455602, 783, 22, 48, "NE3",
      CellTags->"(6.3.39)"]},
  "i:53"->{
    Cell[20422895, 455638, 174, 6, 35, "NE3",
      CellTags->{"i:53", "(6.3.40)"}]},
  "(6.3.40)"->{
    Cell[20422895, 455638, 174, 6, 35, "NE3",
      CellTags->{"i:53", "(6.3.40)"}]},
  "(6.3.41)"->{
    Cell[20424769, 455713, 784, 24, 35, "NE3",
      CellTags->"(6.3.41)"]},
  "i:54"->{
    Cell[20426571, 455777, 294, 9, 49, "NE3",
      CellTags->{"i:54", "(6.3.42)"}]},
  "(6.3.42)"->{
    Cell[20426571, 455777, 294, 9, 49, "NE3",
      CellTags->{"i:54", "(6.3.42)"}]},
  "i:55"->{
    Cell[20427389, 455809, 1610, 47, 136, "Text",
      CellTags->"i:55"]},
  "c:45"->{
    Cell[20429048, 455862, 60, 1, 40, "Subtitle",
      CellTags->{"c:45", "refs"}]},
  "refs"->{
    Cell[20429048, 455862, 60, 1, 40, "Subtitle",
      CellTags->{"c:45", "refs"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:1", 20471829, 457207},
  {"c:1", 20471915, 457210},
  {"i:2", 20472001, 457213},
  {"c:2", 20472088, 457216},
  {"c:3", 20472175, 457219},
  {"i:57", 20472257, 457222},
  {"Fig. 6.1", 20472341, 457225},
  {"i:4", 20472426, 457228},
  {"c:4", 20472518, 457231},
  {"c:5", 20472610, 457234},
  {"(6.1.1)", 20472693, 457237},
  {"(6.1.2)", 20472790, 457240},
  {"(6.1.3)", 20472887, 457243},
  {"i:5", 20472980, 457246},
  {"(6.1.4)", 20473062, 457249},
  {"(6.1.5)", 20473159, 457252},
  {"(6.1.6)", 20473256, 457255},
  {"(6.1.7)", 20473353, 457258},
  {"(6.1.8)", 20473450, 457261},
  {"(6.1.9)", 20473547, 457264},
  {"i:6", 20473640, 457267},
  {"(6.1.10)", 20473721, 457270},
  {"(6.1.11)", 20473820, 457273},
  {"i:3", 20473915, 457276},
  {"(6.1.12)", 20473999, 457279},
  {"i:7", 20474094, 457282},
  {"c:6", 20474175, 457285},
  {"(6.1.13)", 20474260, 457288},
  {"Cell 6.1", 20474360, 457291},
  {"Cell 6.2", 20474449, 457294},
  {"Cell 6.3", 20474538, 457297},
  {"Cell 6.4", 20474627, 457300},
  {"Cell 6.5", 20474716, 457303},
  {"Cell 6.6", 20474805, 457306},
  {"Cell 6.7", 20474894, 457309},
  {"i:59", 20474979, 457312},
  {"Cell 6.8", 20475064, 457315},
  {"Cell 6.9", 20475153, 457318},
  {"Cell 6.10", 20475243, 457321},
  {"Cell 6.11", 20475334, 457324},
  {"Cell 6.12", 20475425, 457327},
  {"Cell 6.13", 20475516, 457330},
  {"Cell 6.14", 20475607, 457333},
  {"Cell 6.15", 20475700, 457336},
  {"c:7", 20475787, 457339},
  {"Cell 6.16", 20475875, 457342},
  {"Cell 6.17", 20475967, 457345},
  {"i:64", 20476055, 457348},
  {"i:8", 20476137, 457351},
  {"Cell 6.18", 20476223, 457354},
  {"Cell 6.19", 20476319, 457357},
  {"Cell 6.20", 20476415, 457360},
  {"Cell 6.21", 20476507, 457363},
  {"Cell 6.22", 20476601, 457366},
  {"Cell 6.23", 20476694, 457369},
  {"c:8", 20476781, 457372},
  {"Cell 6.24", 20476870, 457375},
  {"(6.1.14)", 20476965, 457378},
  {"Cell 6.25", 20477070, 457381},
  {"Cell 6.26", 20477166, 457384},
  {"Cell 6.27", 20477262, 457387},
  {"Cell 6.28", 20477356, 457390},
  {"i:9", 20477444, 457393},
  {"Cell 6.29", 20477532, 457396},
  {"Cell 6.30", 20477629, 457399},
  {"Cell 6.31", 20477723, 457402},
  {"Fig. 6.2", 20477816, 457405},
  {"Fig. 6.3", 20477911, 457408},
  {"i:11", 20478002, 457411},
  {"c:9", 20478099, 457414},
  {"c:10", 20478197, 457417},
  {"(6.1.15)", 20478286, 457420},
  {"(6.1.16)", 20478389, 457423},
  {"(6.1.17)", 20478492, 457426},
  {"(6.1.18)", 20478595, 457429},
  {"(6.1.19)", 20478698, 457432},
  {"i:12", 20478797, 457435},
  {"(6.1.20)", 20478885, 457438},
  {"Cell 6.32", 20478989, 457441},
  {"(6.1.21)", 20479083, 457444},
  {"(6.1.22)", 20479186, 457447},
  {"(6.1.23)", 20479289, 457450},
  {"(6.1.24)", 20479392, 457453},
  {"(6.1.25)", 20479496, 457456},
  {"(6.1.26)", 20479599, 457459},
  {"Cell 6.33", 20479703, 457462},
  {"Cell 6.34", 20479798, 457465},
  {"Cell 6.35", 20479892, 457468},
  {"Cell 6.36", 20479986, 457471},
  {"Cell 6.37", 20480080, 457474},
  {"Cell 6.38", 20480174, 457477},
  {"Cell 6.39", 20480268, 457480},
  {"Cell 6.40", 20480362, 457483},
  {"Cell 6.41", 20480456, 457486},
  {"Cell 6.42", 20480550, 457489},
  {"Cell 6.43", 20480645, 457492},
  {"Cell 6.44", 20480739, 457495},
  {"Cell 6.45", 20480833, 457498},
  {"Cell 6.46", 20480928, 457501},
  {"i:13", 20481018, 457504},
  {"Cell 6.47", 20481106, 457507},
  {"i:14", 20481199, 457510},
  {"c:11", 20481294, 457513},
  {"(6.1.27)", 20481393, 457516},
  {"(6.1.28)", 20481496, 457519},
  {"(6.1.29)", 20481599, 457522},
  {"(6.1.30)", 20481703, 457525},
  {"(6.1.31)", 20481807, 457528},
  {"(6.1.32)", 20481911, 457531},
  {"(6.1.33)", 20482014, 457534},
  {"(6.1.34)", 20482117, 457537},
  {"(6.1.35)", 20482220, 457540},
  {"(6.1.36)", 20482323, 457543},
  {"Cell 6.48", 20482428, 457546},
  {"Cell 6.49", 20482522, 457549},
  {"Cell 6.50", 20482619, 457552},
  {"Cell 6.51", 20482713, 457555},
  {"i:16", 20482804, 457558},
  {"i:15", 20482891, 457561},
  {"c:12", 20482976, 457564},
  {"Fig. 6.4", 20483070, 457567},
  {"Fig. 6.5", 20483164, 457570},
  {"i:37", 20483254, 457573},
  {"(6.1.37)", 20483368, 457576},
  {"i:17", 20483478, 457579},
  {"c:13", 20483575, 457582},
  {"c:14", 20483672, 457585},
  {"i:18", 20483762, 457588},
  {"c:15", 20483858, 457591},
  {"(6.2.1)", 20483957, 457594},
  {"(6.2.2)", 20484046, 457597},
  {"(6.2.3)", 20484136, 457600},
  {"(6.2.4)", 20484226, 457603},
  {"(6.2.5)", 20484316, 457606},
  {"Cell 6.52", 20484408, 457609},
  {"Cell 6.53", 20484504, 457612},
  {"Cell 6.54", 20484599, 457615},
  {"Cell 6.55", 20484694, 457618},
  {"Cell 6.56", 20484790, 457621},
  {"i:70", 20484881, 457624},
  {"Cell 6.57", 20484972, 457627},
  {"i:19", 20485064, 457630},
  {"c:16", 20485160, 457633},
  {"i:58", 20485256, 457636},
  {"(6.2.6)", 20485346, 457639},
  {"(6.2.7)", 20485437, 457642},
  {"(6.2.8)", 20485526, 457645},
  {"Fig. 6.6", 20485617, 457648},
  {"(6.2.9)", 20485711, 457651},
  {"i:65", 20485798, 457654},
  {"i:20", 20485884, 457657},
  {"c:17", 20485980, 457660},
  {"(6.2.10)", 20486080, 457663},
  {"(6.2.11)", 20486172, 457666},
  {"Cell 6.58", 20486264, 457669},
  {"i:21", 20486354, 457672},
  {"c:18", 20486450, 457675},
  {"(6.2.12)", 20486550, 457678},
  {"Cell 6.59", 20486643, 457681},
  {"(6.2.13)", 20486739, 457684},
  {"i:22", 20486827, 457687},
  {"c:19", 20486923, 457690},
  {"(6.2.14)", 20487023, 457693},
  {"i:25", 20487111, 457696},
  {"(6.2.15)", 20487202, 457699},
  {"(6.2.16)", 20487294, 457702},
  {"i:23", 20487383, 457705},
  {"(6.2.17)", 20487473, 457708},
  {"Cell 6.60", 20487566, 457711},
  {"Cell 6.61", 20487661, 457714},
  {"(6.2.18)", 20487756, 457717},
  {"Cell 6.62", 20487848, 457720},
  {"Cell 6.63", 20487943, 457723},
  {"Cell 6.64", 20488041, 457726},
  {"Cell 6.65", 20488138, 457729},
  {"Cell 6.66", 20488234, 457732},
  {"i:24", 20488324, 457735},
  {"c:20", 20488420, 457738},
  {"(6.2.19)", 20488520, 457741},
  {"(6.2.20)", 20488612, 457744},
  {"(6.2.21)", 20488704, 457747},
  {"Cell 6.67", 20488797, 457750},
  {"Cell 6.68", 20488893, 457753},
  {"Cell 6.69", 20488988, 457756},
  {"Cell 6.70", 20489083, 457759},
  {"Cell 6.71", 20489178, 457762},
  {"(6.2.22)", 20489275, 457765},
  {"(6.2.23)", 20489367, 457768},
  {"(6.2.24)", 20489460, 457771},
  {"(6.2.25)", 20489552, 457774},
  {"c:21", 20489641, 457777},
  {"(6.2.26)", 20489731, 457780},
  {"(6.2.27)", 20489822, 457783},
  {"(6.2.28)", 20489914, 457786},
  {"(6.2.29)", 20490007, 457789},
  {"i:26", 20490096, 457792},
  {"Cell 6.72", 20490193, 457795},
  {"Cell 6.73", 20490290, 457798},
  {"Cell 6.74", 20490388, 457801},
  {"Cell 6.75", 20490485, 457804},
  {"Cell 6.76", 20490580, 457807},
  {"Cell 6.77", 20490676, 457810},
  {"i:28", 20490767, 457813},
  {"i:27", 20490852, 457816},
  {"(6.2.30)", 20490948, 457819},
  {"i:69", 20491036, 457822},
  {"(6.2.31)", 20491127, 457825},
  {"Cell 6.78", 20491221, 457828},
  {"Cell 6.79", 20491316, 457831},
  {"(6.2.32)", 20491412, 457834},
  {"Cell 6.80", 20491504, 457837},
  {"Cell 6.81", 20491599, 457840},
  {"Cell 6.82", 20491695, 457843},
  {"Cell 6.83", 20491793, 457846},
  {"Cell 6.84", 20491889, 457849},
  {"Cell 6.85", 20491985, 457852},
  {"i:29", 20492078, 457855},
  {"c:22", 20492178, 457858},
  {"i:30", 20492278, 457861},
  {"c:23", 20492374, 457864},
  {"(6.2.33)", 20492474, 457867},
  {"(6.2.34)", 20492565, 457870},
  {"Cell 6.86", 20492659, 457873},
  {"Cell 6.87", 20492755, 457876},
  {"Cell 6.88", 20492851, 457879},
  {"Cell 6.89", 20492946, 457882},
  {"Cell 6.90", 20493044, 457885},
  {"Cell 6.91", 20493139, 457888},
  {"Cell 6.92", 20493234, 457891},
  {"Cell 6.93", 20493330, 457894},
  {"i:31", 20493420, 457897},
  {"c:24", 20493516, 457900},
  {"(6.2.35)", 20493616, 457903},
  {"(6.2.36)", 20493708, 457906},
  {"Cell 6.94", 20493802, 457909},
  {"Cell 6.95", 20493899, 457912},
  {"Cell 6.96", 20493996, 457915},
  {"(6.2.37)", 20494090, 457918},
  {"(6.2.38)", 20494182, 457921},
  {"Cell 6.97", 20494275, 457924},
  {"Cell 6.98", 20494372, 457927},
  {"i:68", 20494463, 457930},
  {"Cell 6.99", 20494555, 457933},
  {"Cell 6.100", 20494651, 457936},
  {"Cell 6.101", 20494751, 457939},
  {"Cell 6.102", 20494848, 457942},
  {"Cell 6.103", 20494945, 457945},
  {"Cell 6.104", 20495043, 457948},
  {"Cell 6.105", 20495139, 457951},
  {"Fig. 6.7", 20495235, 457954},
  {"i:32", 20495325, 457957},
  {"c:25", 20495421, 457960},
  {"i:33", 20495517, 457963},
  {"(6.2.39)", 20495613, 457966},
  {"i:61", 20495702, 457969},
  {"Cell 6.106", 20495794, 457972},
  {"Cell 6.107", 20495892, 457975},
  {"Cell 6.108", 20495990, 457978},
  {"Cell 6.109", 20496089, 457981},
  {"Cell 6.110", 20496186, 457984},
  {"Cell 6.111", 20496284, 457987},
  {"Cell 6.112", 20496382, 457990},
  {"Cell 6.113", 20496478, 457993},
  {"Cell 6.114", 20496576, 457996},
  {"Cell 6.115", 20496674, 457999},
  {"i:34", 20496766, 458002},
  {"(6.2.40)", 20496863, 458005},
  {"Cell 6.116", 20496959, 458008},
  {"Cell 6.117", 20497060, 458011},
  {"Cell 6.118", 20497157, 458014},
  {"i:36", 20497250, 458017},
  {"c:26", 20497347, 458020},
  {"(6.2.41)", 20497448, 458023},
  {"(6.2.42)", 20497540, 458026},
  {"(6.2.43)", 20497632, 458029},
  {"Cell 6.119", 20497726, 458032},
  {"Cell 6.120", 20497825, 458035},
  {"Cell 6.121", 20497923, 458038},
  {"Cell 6.122", 20498021, 458041},
  {"Cell 6.123", 20498119, 458044},
  {"Cell 6.124", 20498217, 458047},
  {"Cell 6.125", 20498315, 458050},
  {"Cell 6.126", 20498413, 458053},
  {"Cell 6.127", 20498511, 458056},
  {"Cell 6.128", 20498610, 458059},
  {"Cell 6.129", 20498708, 458062},
  {"Cell 6.130", 20498806, 458065},
  {"Cell 6.131", 20498904, 458068},
  {"c:27", 20498996, 458071},
  {"i:66", 20499087, 458074},
  {"(6.2.44)", 20499176, 458077},
  {"i:38", 20499265, 458080},
  {"(6.2.45)", 20499355, 458083},
  {"Fig. 6.8", 20499449, 458086},
  {"Fig. 6.9", 20499544, 458089},
  {"Fig. 6.10", 20499640, 458092},
  {"i:62", 20499732, 458095},
  {"Fig. 6.11", 20499825, 458098},
  {"i:39", 20499919, 458101},
  {"c:28", 20500018, 458104},
  {"c:29", 20500117, 458107},
  {"i:42", 20500208, 458110},
  {"c:30", 20500309, 458113},
  {"c:31", 20500410, 458116},
  {"(6.3.1)", 20500500, 458119},
  {"(6.3.2)", 20500590, 458122},
  {"(6.3.3)", 20500680, 458125},
  {"(6.3.4)", 20500770, 458128},
  {"(6.3.5)", 20500862, 458131},
  {"c:32", 20500951, 458134},
  {"(2.4.49)", 20501042, 458137},
  {"(6.3.6)", 20501147, 458140},
  {"Cell 6.132", 20501255, 458143},
  {"Cell 6.133", 20501356, 458146},
  {"Cell 6.134", 20501454, 458149},
  {"Cell 6.135", 20501553, 458152},
  {"Cell 6.136", 20501653, 458155},
  {"Cell 6.137", 20501751, 458158},
  {"Cell 6.138", 20501849, 458161},
  {"Cell 6.139", 20501948, 458164},
  {"Cell 6.140", 20502046, 458167},
  {"Cell 6.141", 20502146, 458170},
  {"i:47", 20502241, 458173},
  {"c:33", 20502338, 458176},
  {"(6.3.7)", 20502438, 458179},
  {"Cell 6.142", 20502532, 458182},
  {"Cell 6.143", 20502632, 458185},
  {"Cell 6.144", 20502732, 458188},
  {"Cell 6.145", 20502831, 458191},
  {"Cell 6.146", 20502930, 458194},
  {"Cell 6.147", 20503028, 458197},
  {"Cell 6.148", 20503127, 458200},
  {"Cell 6.149", 20503225, 458203},
  {"Cell 6.150", 20503323, 458206},
  {"Cell 6.151", 20503421, 458209},
  {"Cell 6.152", 20503519, 458212},
  {"Cell 6.153", 20503617, 458215},
  {"Cell 6.154", 20503717, 458218},
  {"i:41", 20503811, 458221},
  {"c:34", 20503912, 458224},
  {"c:35", 20504013, 458227},
  {"(6.3.8)", 20504103, 458230},
  {"(6.3.9)", 20504193, 458233},
  {"(6.3.10)", 20504284, 458236},
  {"(6.3.11)", 20504376, 458239},
  {"c:36", 20504465, 458242},
  {"(6.3.12)", 20504556, 458245},
  {"Cell 6.155", 20504650, 458248},
  {"Cell 6.156", 20504750, 458251},
  {"Cell 6.157", 20504848, 458254},
  {"Cell 6.158", 20504946, 458257},
  {"Cell 6.159", 20505044, 458260},
  {"Cell 6.160", 20505144, 458263},
  {"Cell 6.161", 20505241, 458266},
  {"Cell 6.162", 20505338, 458269},
  {"Cell 6.163", 20505436, 458272},
  {"i:48", 20505528, 458275},
  {"c:37", 20505625, 458278},
  {"Cell 6.164", 20505728, 458281},
  {"Cell 6.165", 20505828, 458284},
  {"Cell 6.166", 20505929, 458287},
  {"Cell 6.167", 20506026, 458290},
  {"Cell 6.168", 20506123, 458293},
  {"i:67", 20506216, 458296},
  {"Cell 6.169", 20506308, 458299},
  {"c:38", 20506402, 458302},
  {"c:39", 20506493, 458305},
  {"i:43", 20506580, 458308},
  {"(3.1.7)", 20506668, 458311},
  {"(6.3.13)", 20506773, 458314},
  {"(6.3.14)", 20506878, 458317},
  {"(6.3.15)", 20506970, 458320},
  {"(6.3.16)", 20507063, 458323},
  {"(6.3.17)", 20507155, 458326},
  {"(6.3.18)", 20507247, 458329},
  {"(6.3.19)", 20507339, 458332},
  {"(6.3.20)", 20507431, 458335},
  {"Cell 6.170", 20507525, 458338},
  {"Fig. 6.12", 20507624, 458341},
  {"i:40", 20507717, 458344},
  {"c:40", 20507814, 458347},
  {"Cell 6.171", 20507917, 458350},
  {"Cell 6.172", 20508016, 458353},
  {"Cell 6.173", 20508114, 458356},
  {"Cell 6.174", 20508212, 458359},
  {"Cell 6.175", 20508311, 458362},
  {"Cell 6.176", 20508409, 458365},
  {"Cell 6.177", 20508509, 458368},
  {"Fig. 6.13", 20508608, 458371},
  {"i:44", 20508701, 458374},
  {"c:41", 20508798, 458377},
  {"(6.3.21)", 20508899, 458380},
  {"(6.3.22)", 20508991, 458383},
  {"(6.3.23)", 20509083, 458386},
  {"(6.3.24)", 20509175, 458389},
  {"(6.3.25)", 20509267, 458392},
  {"Fig. 6.14", 20509360, 458395},
  {"(6.3.26)", 20509457, 458398},
  {"Cell 6.178", 20509551, 458401},
  {"(6.3.27)", 20509648, 458404},
  {"(6.3.28)", 20509741, 458407},
  {"(6.3.29)", 20509834, 458410},
  {"(6.3.30)", 20509926, 458413},
  {"(6.3.31)", 20510019, 458416},
  {"i:45", 20510107, 458419},
  {"c:42", 20510193, 458422},
  {"(6.3.32)", 20510284, 458425},
  {"Cell 6.179", 20510378, 458428},
  {"i:46", 20510471, 458431},
  {"c:43", 20510568, 458434},
  {"Cell 6.180", 20510671, 458437},
  {"Cell 6.181", 20510769, 458440},
  {"Cell 6.182", 20510866, 458443},
  {"Cell 6.183", 20510966, 458446},
  {"Cell 6.184", 20511064, 458449},
  {"Cell 6.185", 20511162, 458452},
  {"Cell 6.186", 20511262, 458455},
  {"Cell 6.187", 20511360, 458458},
  {"Cell 6.188", 20511458, 458461},
  {"Cell 6.189", 20511557, 458464},
  {"c:44", 20511649, 458467},
  {"Fig. 6.15", 20511745, 458470},
  {"i:56", 20511837, 458473},
  {"Fig. 6.16", 20511930, 458476},
  {"(6.3.33)", 20512026, 458479},
  {"i:49", 20512114, 458482},
  {"(6.3.34)", 20512204, 458485},
  {"i:50", 20512292, 458488},
  {"(6.3.35)", 20512384, 458491},
  {"i:51", 20512472, 458494},
  {"(6.3.36)", 20512562, 458497},
  {"i:52", 20512650, 458500},
  {"(6.3.37)", 20512742, 458503},
  {"(6.3.38)", 20512835, 458506},
  {"(6.3.39)", 20512928, 458509},
  {"i:53", 20513017, 458512},
  {"(6.3.40)", 20513119, 458515},
  {"(6.3.41)", 20513221, 458518},
  {"i:54", 20513310, 458521},
  {"(6.3.42)", 20513412, 458524},
  {"i:55", 20513510, 458527},
  {"c:45", 20513598, 458530},
  {"refs", 20513696, 458533}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 117, 4, 111, "Title",
  CellTags->{"i:1", "c:1"}],
Cell[1847, 58, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1888, 62, 71, 1, 39, "Subtitle",
  CellTags->{"i:2", "c:2"}],
Cell[1962, 65, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2003, 69, 60, 1, 41, "Subsubtitle",
  CellTags->"c:3"],
Cell[2066, 72, 1257, 28, 146, "Text",
  CellTags->"i:57"],
Cell[3326, 102, 43162, 536, 168, 43045, 532, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[46491, 640, 233, 5, 29, "Caption",
  CellTags->"Fig. 6.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[46761, 650, 80, 1, 30, "Subsubtitle",
  CellTags->{"i:4", "c:4"}],

Cell[CellGroupData[{
Cell[46866, 655, 44, 1, 42, "Section",
  CellTags->"c:5"],
Cell[46913, 658, 100, 3, 27, "Text"],
Cell[47016, 663, 159, 5, 33, "NumberedEquation",
  CellTags->"(6.1.1)"],
Cell[47178, 670, 561, 19, 48, "Text"],
Cell[47742, 691, 161, 5, 29, "NumberedEquation",
  CellTags->"(6.1.2)"],
Cell[47906, 698, 236, 6, 44, "Text"],
Cell[48145, 706, 227, 5, 44, "Text"],
Cell[48375, 713, 154, 5, 29, "NumberedEquation",
  CellTags->"(6.1.3)"],
Cell[48532, 720, 176, 6, 27, "Text"],
Cell[48711, 728, 463, 16, 44, "Text",
  CellTags->"i:5"],
Cell[49177, 746, 148, 5, 29, "NumberedEquation",
  CellTags->"(6.1.4)"],
Cell[49328, 753, 96, 3, 27, "Text"],
Cell[49427, 758, 232, 7, 29, "NumberedEquation",
  CellTags->"(6.1.5)"],
Cell[49662, 767, 634, 20, 61, "Text"],
Cell[50299, 789, 250, 7, 38, "NumberedEquation",
  CellTags->"(6.1.6)"],
Cell[50552, 798, 174, 6, 29, "Text"],
Cell[50729, 806, 249, 7, 38, "NumberedEquation",
  CellTags->"(6.1.7)"],
Cell[50981, 815, 762, 21, 82, "Text"],
Cell[51746, 838, 297, 9, 44, "Text"],
Cell[52046, 849, 338, 11, 44, "Text"],
Cell[52387, 862, 300, 8, 33, "NumberedEquation",
  CellTags->"(6.1.8)"],
Cell[52690, 872, 66, 0, 27, "Text"],
Cell[52759, 874, 148, 5, 30, "NumberedEquation",
  CellTags->"(6.1.9)"],
Cell[52910, 881, 647, 21, 64, "Text"],
Cell[53560, 904, 80, 1, 27, "Text",
  CellTags->"i:6"],
Cell[53643, 907, 240, 7, 44, "NumberedEquation",
  CellTags->"(6.1.10)"],
Cell[53886, 916, 739, 18, 93, "Text"],
Cell[54628, 936, 645, 14, 78, "Text"],
Cell[55276, 952, 190, 4, 44, "Text"],
Cell[55469, 958, 1008, 36, 68, "Text"],
Cell[56480, 996, 399, 11, 40, "NumberedEquation",
  CellTags->"(6.1.11)"],
Cell[56882, 1009, 510, 16, 44, "Text"],
Cell[57395, 1027, 903, 27, 92, "Text",
  CellTags->"i:3"],
Cell[58301, 1056, 208, 6, 32, "NumberedEquation",
  CellTags->"(6.1.12)"],
Cell[58512, 1064, 922, 27, 71, "Text"],
Cell[59437, 1093, 930, 23, 95, "Text"],
Cell[60370, 1118, 1132, 30, 116, "Text",
  CellTags->"i:7"],
Cell[61505, 1150, 736, 13, 112, "Text"],
Cell[62244, 1165, 543, 12, 78, "Text"],
Cell[62790, 1179, 298, 8, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[63125, 1192, 47, 1, 31, "Section",
  CellTags->"c:6"],
Cell[63175, 1195, 815, 20, 83, "Text"],
Cell[63993, 1217, 213, 6, 39, "NumberedEquation",
  CellTags->"(6.1.13)"],
Cell[64209, 1225, 275, 9, 28, "Text"],
Cell[64487, 1236, 169, 4, 72, "Input",
  CellTags->"Cell 6.1"],
Cell[64659, 1242, 612, 14, 78, "Text"],
Cell[65274, 1258, 154, 4, 67, "Input",
  CellTags->"Cell 6.2"],
Cell[65431, 1264, 257, 9, 27, "Text"],
Cell[65691, 1275, 159, 5, 27, "Text"],
Cell[65853, 1282, 125, 3, 67, "Input",
  CellTags->"Cell 6.3"],
Cell[65981, 1287, 387, 14, 44, "Text"],
Cell[66371, 1303, 145, 5, 31, "Text"],
Cell[66519, 1310, 123, 3, 67, "Input",
  CellTags->"Cell 6.4"],
Cell[66645, 1315, 196, 6, 33, "Text"],
Cell[66844, 1323, 153, 4, 67, "Input",
  CellTags->"Cell 6.5"],
Cell[67000, 1329, 198, 6, 34, "Text"],
Cell[67201, 1337, 156, 4, 67, "Input",
  CellTags->"Cell 6.6"],
Cell[67360, 1343, 1794, 56, 44, "Text"],
Cell[69157, 1401, 220, 5, 86, "Input",
  CellTags->"Cell 6.7"],
Cell[69380, 1408, 699, 22, 62, "Text",
  CellTags->"i:59"],
Cell[70082, 1432, 216, 6, 86, "Input",
  CellTags->"Cell 6.8"],
Cell[70301, 1440, 1010, 34, 78, "Text"],
Cell[71314, 1476, 152, 4, 67, "Input",
  CellTags->"Cell 6.9"],
Cell[71469, 1482, 334, 11, 44, "Text"],
Cell[71806, 1495, 88, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[71919, 1502, 138, 3, 67, "Input",
  CellTags->"Cell 6.10"],
Cell[72060, 1507, 192, 3, 65, "Output"]
}, Open  ]],
Cell[72267, 1513, 120, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[72412, 1522, 129, 3, 67, "Input",
  CellTags->"Cell 6.11"],
Cell[72544, 1527, 779, 16, 135, "Output"]
}, Open  ]],
Cell[73338, 1546, 249, 8, 27, "Text"],
Cell[73590, 1556, 207, 5, 86, "Input",
  CellTags->"Cell 6.12"],
Cell[73800, 1563, 149, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[73974, 1573, 188, 4, 67, "Input",
  CellTags->"Cell 6.13"],
Cell[74165, 1579, 102065, 1954, 326, 25826, 1009, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[176245, 3536, 429, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[176699, 3553, 321, 6, 105, "Input",
  CellTags->"Cell 6.14"],
Cell[177023, 3561, 400683, 7850, 342, 199024, 5356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[577721, 11414, 301, 9, 45, "Text"],
Cell[578025, 11425, 452, 13, 61, "Text"],

Cell[CellGroupData[{
Cell[578502, 11442, 182, 4, 86, "Input",
  CellTags->"Cell 6.15"],
Cell[578687, 11448, 2724, 39, 70, "Output"]
}, Closed]],
Cell[581426, 11490, 962, 28, 74, "Text"],
Cell[582391, 11520, 419, 13, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[582847, 11538, 47, 1, 31, "Section",
  CellTags->"c:7"],
Cell[582897, 11541, 423, 12, 47, "Text"],
Cell[583323, 11555, 92, 3, 67, "Input",
  CellTags->"Cell 6.16"],

Cell[CellGroupData[{
Cell[583440, 11562, 251, 6, 97, "Input",
  CellTags->"Cell 6.17"],
Cell[583694, 11570, 148637, 7927, 370, 116862, 7531, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[732346, 19500, 587, 14, 78, "Text",
  CellTags->"i:64"],
Cell[732936, 19516, 270, 8, 30, "Text"],
Cell[733209, 19526, 121, 4, 27, "Text",
  CellTags->"i:8"],
Cell[733333, 19532, 3019, 76, 298, "Input",
  CellTags->"Cell 6.18"],
Cell[736355, 19610, 3348, 67, 480, "Input",
  CellTags->"Cell 6.19"],
Cell[739706, 19679, 135, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[739866, 19688, 97, 3, 67, "Input",
  CellTags->"Cell 6.20"],
Cell[739966, 19693, 2994, 70, 70, "Print"],
Cell[742963, 19765, 2992, 70, 70, "Print"],
Cell[745958, 19837, 2995, 70, 70, "Print"],
Cell[748956, 19909, 3002, 70, 70, "Print"],
Cell[751961, 19981, 2991, 69, 70, "Print"],
Cell[754955, 20052, 3001, 70, 70, "Print"],
Cell[757959, 20124, 3017, 71, 70, "Print"],
Cell[760979, 20197, 2996, 69, 70, "Print"],
Cell[763978, 20268, 3017, 70, 70, "Print"],
Cell[766998, 20340, 3008, 69, 70, "Print"],
Cell[770009, 20411, 3012, 70, 70, "Print"],
Cell[773024, 20483, 3028, 71, 70, "Print"],
Cell[776055, 20556, 3026, 71, 70, "Print"],
Cell[779084, 20629, 3034, 71, 70, "Print"],
Cell[782121, 20702, 3035, 71, 70, "Print"],
Cell[785159, 20775, 3029, 71, 70, "Print"],
Cell[788191, 20848, 3037, 71, 70, "Print"],
Cell[791231, 20921, 3058, 72, 70, "Print"],
Cell[794292, 20995, 3079, 73, 70, "Print"],
Cell[797374, 21070, 3058, 72, 70, "Print"],
Cell[800435, 21144, 3029, 70, 70, "Print"],
Cell[803467, 21216, 3098, 75, 70, "Print"],
Cell[806568, 21293, 3094, 74, 70, "Print"],
Cell[809665, 21369, 3101, 75, 70, "Print"],
Cell[812769, 21446, 3100, 75, 70, "Print"]
}, Closed]],
Cell[815884, 21524, 295, 9, 21, "Text"],

Cell[CellGroupData[{
Cell[816204, 21537, 386, 8, 105, "Input",
  CellTags->"Cell 6.21"],
Cell[816593, 21547, 110933, 3522, 370, 40683, 2651, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[927541, 25072, 133, 3, 27, "Text"],
Cell[927677, 25077, 106, 3, 67, "Input",
  CellTags->"Cell 6.22"],
Cell[927786, 25082, 181, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[927992, 25092, 265, 7, 86, "Input",
  CellTags->"Cell 6.23"],
Cell[928260, 25101, 377586, 7413, 302, 196266, 5171, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1305861, 32517, 214, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1306112, 32526, 47, 1, 31, "Section",
  CellTags->"c:8"],
Cell[1306162, 32529, 403, 10, 47, "Text"],
Cell[1306568, 32541, 203, 6, 48, "Text"],
Cell[1306774, 32549, 148, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[1306947, 32559, 493, 10, 184, "Input",
  CellTags->"Cell 6.24"],
Cell[1307443, 32571, 142458, 7599, 370, 111484, 7213, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1449916, 40173, 421, 10, 47, "Text"],
Cell[1450340, 40185, 296, 7, 44, "Text"],
Cell[1450639, 40194, 517, 13, 42, "NumberedEquation",
  CellTags->"(6.1.14)"],
Cell[1451159, 40209, 509, 17, 44, "Text"],
Cell[1451671, 40228, 465, 10, 48, "Text"],
Cell[1452139, 40240, 60, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1452224, 40244, 360, 10, 116, "Input",
  CellTags->"Cell 6.25"],
Cell[1452587, 40256, 216, 3, 72, "Output"]
}, Open  ]],
Cell[1452818, 40262, 601, 13, 162, "Input",
  CellTags->"Cell 6.26"],
Cell[1453422, 40277, 482, 15, 47, "Text"],

Cell[CellGroupData[{
Cell[1453929, 40296, 303, 6, 86, "Input",
  CellTags->"Cell 6.27"],
Cell[1454235, 40304, 31936, 875, 233, 9893, 598, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1486186, 41182, 361, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[1486572, 41199, 174, 4, 67, "Input",
  CellTags->"Cell 6.28"],
Cell[1486749, 41205, 21277, 455, 233, 3338, 230, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1508041, 41663, 462, 11, 61, "Text"],
Cell[1508506, 41676, 772, 19, 78, "Text"],
Cell[1509281, 41697, 422, 11, 61, "Text",
  CellTags->"i:9"],
Cell[1509706, 41710, 226, 9, 36, "Text"],
Cell[1509935, 41721, 866, 21, 95, "Text"],
Cell[1510804, 41744, 3392, 82, 295, "Input",
  CellTags->"Cell 6.29"],
Cell[1514199, 41828, 531, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[1514755, 41845, 102, 3, 67, "Input",
  CellTags->"Cell 6.30"],
Cell[1514860, 41850, 1961, 46, 70, "Print"],
Cell[1516824, 41898, 1998, 47, 70, "Print"],
Cell[1518825, 41947, 1974, 46, 70, "Print"],
Cell[1520802, 41995, 2011, 47, 70, "Print"],
Cell[1522816, 42044, 1972, 46, 70, "Print"],
Cell[1524791, 42092, 2013, 47, 70, "Print"],
Cell[1526807, 42141, 2017, 48, 70, "Print"],
Cell[1528827, 42191, 2037, 48, 70, "Print"],
Cell[1530867, 42241, 1980, 46, 70, "Print"],
Cell[1532850, 42289, 2023, 47, 70, "Print"],
Cell[1534876, 42338, 2013, 47, 70, "Print"],
Cell[1536892, 42387, 2075, 50, 70, "Print"],
Cell[1538970, 42439, 1987, 46, 70, "Print"],
Cell[1540960, 42487, 2049, 49, 70, "Print"],
Cell[1543012, 42538, 2052, 49, 70, "Print"],
Cell[1545067, 42589, 2108, 51, 70, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[1547212, 42645, 437, 9, 97, "Input",
  CellTags->"Cell 6.31"],
Cell[1547652, 42656, 331817, 6400, 302, 246553, 5343, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1879484, 49059, 555, 15, 62, "Text"],
Cell[1880042, 49076, 33125, 774, 233, 8539, 466, "GraphicsData", \
"PostScript", "Picture"],
Cell[1913170, 49852, 640, 18, 17, "Caption",
  CellTags->"Fig. 6.2"],
Cell[1913813, 49872, 597, 13, 78, "Text"],
Cell[1914413, 49887, 28974, 786, 233, 9722, 544, "GraphicsData", \
"PostScript", "Picture"],
Cell[1943390, 50675, 651, 18, 30, "Caption",
  CellTags->"Fig. 6.3"],
Cell[1944044, 50695, 655, 11, 95, "Text"],
Cell[1944702, 50708, 282, 8, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1945033, 50722, 81, 1, 30, "Subsubtitle",
  CellTags->{"i:11", "c:9"}],

Cell[CellGroupData[{
Cell[1945139, 50727, 56, 1, 42, "Section",
  CellTags->"c:10"],
Cell[1945198, 50730, 304, 7, 44, "Text"],
Cell[1945505, 50739, 248, 7, 42, "NumberedEquation",
  CellTags->"(6.1.15)"],
Cell[1945756, 50748, 53, 0, 27, "Text"],
Cell[1945812, 50750, 206, 4, 57, "NumberedEquation",
  CellTags->"(6.1.16)"],
Cell[1946021, 50756, 41, 0, 27, "Text"],
Cell[1946065, 50758, 137, 5, 29, "NumberedEquation",
  CellTags->"(6.1.17)"],
Cell[1946205, 50765, 61, 0, 27, "Text"],
Cell[1946269, 50767, 211, 7, 33, "NumberedEquation",
  CellTags->"(6.1.18)"],
Cell[1946483, 50776, 191, 6, 27, "Text"],
Cell[1946677, 50784, 180, 6, 29, "NumberedEquation",
  CellTags->"(6.1.19)"],
Cell[1946860, 50792, 27, 0, 27, "Text"],
Cell[1946890, 50794, 570, 16, 61, "Text",
  CellTags->"i:12"],
Cell[1947463, 50812, 164, 6, 37, "Text"],
Cell[1947630, 50820, 575, 16, 74, "Text"],
Cell[1948208, 50838, 215, 7, 35, "NumberedEquation",
  CellTags->"(6.1.20)"],
Cell[1948426, 50847, 224, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[1948675, 50860, 227, 5, 116, "Input",
  CellTags->"Cell 6.32"],
Cell[1948905, 50867, 27772, 737, 233, 7010, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1976692, 51607, 94, 3, 27, "Text"],
Cell[1976789, 51612, 191, 6, 34, "NumberedEquation",
  CellTags->"(6.1.21)"],
Cell[1976983, 51620, 478, 17, 44, "Text"],
Cell[1977464, 51639, 399, 9, 42, "NumberedEquation",
  CellTags->"(6.1.22)"],
Cell[1977866, 51650, 138, 5, 29, "Text"],
Cell[1978007, 51657, 264, 5, 42, "NumberedEquation",
  CellTags->"(6.1.23)"],
Cell[1978274, 51664, 249, 9, 27, "Text"],
Cell[1978526, 51675, 455, 11, 42, "NumberedEquation",
  CellTags->"(6.1.24)"],
Cell[1978984, 51688, 715, 24, 61, "Text"],
Cell[1979702, 51714, 210, 6, 33, "NumberedEquation",
  CellTags->"(6.1.25)"],
Cell[1979915, 51722, 255, 7, 44, "Text"],
Cell[1980173, 51731, 289, 9, 33, "NumberedEquation",
  CellTags->"(6.1.26)"],
Cell[1980465, 51742, 391, 17, 27, "Text"],
Cell[1980859, 51761, 4013, 132, 112, "Text"],
Cell[1984875, 51895, 660, 17, 78, "Text"],
Cell[1985538, 51914, 236, 5, 124, "Input",
  CellTags->"Cell 6.33"],
Cell[1985777, 51921, 143, 3, 27, "Text"],
Cell[1985923, 51926, 286, 10, 44, "Text"],
Cell[1986212, 51938, 106, 3, 67, "Input",
  CellTags->"Cell 6.34"],
Cell[1986321, 51943, 402, 12, 44, "Text"],
Cell[1986726, 51957, 163, 4, 67, "Input",
  CellTags->"Cell 6.35"],
Cell[1986892, 51963, 194, 6, 32, "Text"],
Cell[1987089, 51971, 120, 3, 67, "Input",
  CellTags->"Cell 6.36"],
Cell[1987212, 51976, 192, 5, 32, "Text"],
Cell[1987407, 51983, 127, 3, 67, "Input",
  CellTags->"Cell 6.37"],
Cell[1987537, 51988, 559, 14, 78, "Text"],
Cell[1988099, 52004, 275, 6, 86, "Input",
  CellTags->"Cell 6.38"],
Cell[1988377, 52012, 227, 8, 29, "Text"],
Cell[1988607, 52022, 178, 5, 67, "Input",
  CellTags->"Cell 6.39"],
Cell[1988788, 52029, 107, 3, 27, "Text"],
Cell[1988898, 52034, 262, 6, 86, "Input",
  CellTags->"Cell 6.40"],
Cell[1989163, 52042, 67, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1989255, 52046, 137, 3, 67, "Input",
  CellTags->"Cell 6.41"],
Cell[1989395, 52051, 3750, 106, 70, "Print"],
Cell[1993148, 52159, 3813, 108, 70, "Print"],
Cell[1996964, 52269, 3722, 105, 70, "Print"],
Cell[2000689, 52376, 3906, 110, 70, "Print"],
Cell[2004598, 52488, 3809, 107, 70, "Print"],
Cell[2008410, 52597, 3961, 112, 70, "Print"],
Cell[2012374, 52711, 3829, 107, 70, "Print"],
Cell[2016206, 52820, 4120, 117, 70, "Print"]
}, Closed]],
Cell[2020341, 52940, 234, 7, 21, "Text"],

Cell[CellGroupData[{
Cell[2020600, 52951, 315, 6, 124, "Input",
  CellTags->"Cell 6.42"],
Cell[2020918, 52959, 1122, 33, 70, "Print"],
Cell[2022043, 52994, 1124, 33, 70, "Print"],
Cell[2023170, 53029, 1114, 33, 70, "Print"],
Cell[2024287, 53064, 1169, 34, 70, "Print"],
Cell[2025459, 53100, 1149, 34, 70, "Print"],
Cell[2026611, 53136, 1172, 33, 70, "Print"],
Cell[2027786, 53171, 1146, 33, 70, "Print"],
Cell[2028935, 53206, 1208, 35, 70, "Print"]
}, Closed]],
Cell[2030158, 53244, 238, 7, 38, "Text"],
Cell[2030399, 53253, 161, 5, 67, "Input",
  CellTags->"Cell 6.43"],
Cell[2030563, 53260, 91, 3, 27, "Text"],
Cell[2030657, 53265, 125, 3, 67, "Input",
  CellTags->"Cell 6.44"],
Cell[2030785, 53270, 174, 5, 27, "Text"],
Cell[2030962, 53277, 401, 9, 124, "Input",
  CellTags->"Cell 6.45"],
Cell[2031366, 53288, 146, 6, 27, "Text"],
Cell[2031515, 53296, 299, 7, 105, "Input",
  CellTags->"Cell 6.46"],
Cell[2031817, 53305, 402, 9, 61, "Text"],
Cell[2032222, 53316, 109, 4, 27, "Text",
  CellTags->"i:13"],
Cell[2032334, 53322, 5708, 118, 850, "Input",
  CellTags->"Cell 6.47"]
}, Closed]],

Cell[CellGroupData[{
Cell[2038079, 53445, 97, 1, 31, "Section",
  CellTags->{"i:14", "c:11"}],
Cell[2038179, 53448, 282, 5, 61, "Text"],
Cell[2038464, 53455, 347, 10, 44, "Text"],
Cell[2038814, 53467, 334, 9, 42, "NumberedEquation",
  CellTags->"(6.1.27)"],
Cell[2039151, 53478, 61, 0, 27, "Text"],
Cell[2039215, 53480, 147, 5, 29, "NumberedEquation",
  CellTags->"(6.1.28)"],
Cell[2039365, 53487, 155, 7, 27, "Text"],
Cell[2039523, 53496, 553, 15, 45, "NumberedEquation",
  CellTags->"(6.1.29)"],
Cell[2040079, 53513, 462, 12, 61, "Text"],
Cell[2040544, 53527, 337, 11, 38, "NumberedEquation",
  CellTags->"(6.1.30)"],
Cell[2040884, 53540, 166, 6, 27, "Text"],
Cell[2041053, 53548, 492, 11, 42, "NumberedEquation",
  CellTags->"(6.1.31)"],
Cell[2041548, 53561, 284, 9, 46, "Text"],
Cell[2041835, 53572, 195, 6, 34, "NumberedEquation",
  CellTags->"(6.1.32)"],
Cell[2042033, 53580, 421, 12, 47, "Text"],
Cell[2042457, 53594, 337, 9, 42, "NumberedEquation",
  CellTags->"(6.1.33)"],
Cell[2042797, 53605, 165, 5, 29, "Text"],
Cell[2042965, 53612, 351, 9, 37, "NumberedEquation",
  CellTags->"(6.1.34)"],
Cell[2043319, 53623, 198, 6, 27, "Text"],
Cell[2043520, 53631, 200, 6, 42, "NumberedEquation",
  CellTags->"(6.1.35)"],
Cell[2043723, 53639, 569, 18, 44, "Text"],
Cell[2044295, 53659, 472, 10, 38, "NumberedEquation",
  CellTags->"(6.1.36)"],
Cell[2044770, 53671, 202, 5, 52, "Text"],
Cell[2044975, 53678, 104, 3, 67, "Input",
  CellTags->"Cell 6.48"],
Cell[2045082, 53683, 302, 10, 44, "Text"],
Cell[2045387, 53695, 216, 6, 36, "UNNEQ"],
Cell[2045606, 53703, 370, 10, 48, "Text"],
Cell[2045979, 53715, 170, 6, 27, "Text"],
Cell[2046152, 53723, 220, 6, 55, "UNNEQ"],
Cell[2046375, 53731, 996, 28, 97, "Text"],
Cell[2047374, 53761, 3458, 69, 626, "Input",
  CellTags->"Cell 6.49"],
Cell[2050835, 53832, 560, 19, 44, "Text"],

Cell[CellGroupData[{
Cell[2051420, 53855, 123, 3, 67, "Input",
  CellTags->"Cell 6.50"],
Cell[2051546, 53860, 408, 9, 35, "Print"],
Cell[2051957, 53871, 409, 9, 35, "Print"],
Cell[2052369, 53882, 404, 8, 35, "Print"],
Cell[2052776, 53892, 406, 8, 35, "Print"],
Cell[2053185, 53902, 404, 8, 35, "Print"],
Cell[2053592, 53912, 409, 9, 35, "Print"],
Cell[2054004, 53923, 407, 9, 35, "Print"],
Cell[2054414, 53934, 410, 9, 35, "Print"],
Cell[2054827, 53945, 403, 8, 35, "Print"],
Cell[2055233, 53955, 404, 8, 35, "Print"],
Cell[2055640, 53965, 406, 8, 35, "Print"],
Cell[2056049, 53975, 409, 9, 35, "Print"],
Cell[2056461, 53986, 409, 9, 35, "Print"],
Cell[2056873, 53997, 410, 9, 35, "Print"],
Cell[2057286, 54008, 403, 8, 35, "Print"],
Cell[2057692, 54018, 403, 8, 35, "Print"],
Cell[2058098, 54028, 405, 8, 35, "Print"],
Cell[2058506, 54038, 408, 9, 70, "Print"],
Cell[2058917, 54049, 410, 9, 70, "Print"],
Cell[2059330, 54060, 409, 9, 70, "Print"],
Cell[2059742, 54071, 403, 8, 70, "Print"],
Cell[2060148, 54081, 406, 8, 70, "Print"],
Cell[2060557, 54091, 405, 8, 70, "Print"],
Cell[2060965, 54101, 402, 9, 70, "Print"],
Cell[2061370, 54112, 410, 9, 70, "Print"],
Cell[2061783, 54123, 408, 9, 70, "Print"],
Cell[2062194, 54134, 405, 8, 70, "Print"],
Cell[2062602, 54144, 405, 8, 70, "Print"],
Cell[2063010, 54154, 404, 8, 70, "Print"],
Cell[2063417, 54164, 401, 9, 70, "Print"],
Cell[2063821, 54175, 400, 9, 70, "Print"],
Cell[2064224, 54186, 401, 9, 70, "Print"],
Cell[2064628, 54197, 400, 8, 70, "Print"],
Cell[2065031, 54207, 402, 8, 70, "Print"],
Cell[2065436, 54217, 403, 8, 70, "Print"],
Cell[2065842, 54227, 394, 8, 70, "Print"],
Cell[2066239, 54237, 401, 9, 70, "Print"],
Cell[2066643, 54248, 393, 8, 70, "Print"],
Cell[2067039, 54258, 401, 8, 70, "Print"],
Cell[2067443, 54268, 402, 8, 70, "Print"],
Cell[2067848, 54278, 400, 8, 70, "Print"],
Cell[2068251, 54288, 402, 9, 70, "Print"],
Cell[2068656, 54299, 401, 9, 70, "Print"],
Cell[2069060, 54310, 392, 8, 70, "Print"],
Cell[2069455, 54320, 400, 8, 70, "Print"],
Cell[2069858, 54330, 405, 8, 70, "Print"],
Cell[2070266, 54340, 404, 8, 70, "Print"],
Cell[2070673, 54350, 442, 9, 70, "Print"],
Cell[2071118, 54361, 438, 9, 70, "Print"],
Cell[2071559, 54372, 441, 9, 70, "Print"],
Cell[2072003, 54383, 402, 8, 70, "Print"],
Cell[2072408, 54393, 399, 8, 70, "Print"],
Cell[2072810, 54403, 399, 8, 70, "Print"],
Cell[2073212, 54413, 434, 9, 70, "Print"],
Cell[2073649, 54424, 434, 9, 70, "Print"],
Cell[2074086, 54435, 429, 9, 70, "Print"],
Cell[2074518, 54446, 396, 8, 70, "Print"],
Cell[2074917, 54456, 397, 8, 70, "Print"],
Cell[2075317, 54466, 396, 8, 70, "Print"],
Cell[2075716, 54476, 431, 9, 70, "Print"],
Cell[2076150, 54487, 419, 9, 70, "Print"],
Cell[2076572, 54498, 418, 9, 70, "Print"],
Cell[2076993, 54509, 380, 8, 70, "Print"],
Cell[2077376, 54519, 383, 8, 70, "Print"],
Cell[2077762, 54529, 380, 8, 70, "Print"],
Cell[2078145, 54539, 417, 9, 70, "Print"],
Cell[2078565, 54550, 414, 9, 70, "Print"],
Cell[2078982, 54561, 415, 9, 70, "Print"],
Cell[2079400, 54572, 377, 8, 70, "Print"],
Cell[2079780, 54582, 379, 8, 70, "Print"],
Cell[2080162, 54592, 383, 8, 70, "Print"],
Cell[2080548, 54602, 418, 9, 70, "Print"],
Cell[2080969, 54613, 419, 9, 70, "Print"],
Cell[2081391, 54624, 415, 9, 70, "Print"],
Cell[2081809, 54635, 377, 8, 70, "Print"],
Cell[2082189, 54645, 384, 8, 70, "Print"],
Cell[2082576, 54655, 382, 8, 70, "Print"],
Cell[2082961, 54665, 418, 9, 70, "Print"],
Cell[2083382, 54676, 418, 9, 70, "Print"],
Cell[2083803, 54687, 416, 9, 70, "Print"],
Cell[2084222, 54698, 381, 8, 70, "Print"],
Cell[2084606, 54708, 381, 8, 70, "Print"],
Cell[2084990, 54718, 382, 8, 70, "Print"],
Cell[2085375, 54728, 417, 9, 70, "Print"],
Cell[2085795, 54739, 418, 9, 70, "Print"],
Cell[2086216, 54750, 415, 9, 70, "Print"],
Cell[2086634, 54761, 380, 8, 70, "Print"],
Cell[2087017, 54771, 383, 8, 70, "Print"],
Cell[2087403, 54781, 381, 8, 70, "Print"],
Cell[2087787, 54791, 415, 9, 70, "Print"],
Cell[2088205, 54802, 418, 9, 70, "Print"],
Cell[2088626, 54813, 417, 9, 70, "Print"],
Cell[2089046, 54824, 377, 8, 70, "Print"],
Cell[2089426, 54834, 384, 8, 70, "Print"],
Cell[2089813, 54844, 383, 8, 70, "Print"],
Cell[2090199, 54854, 416, 9, 70, "Print"],
Cell[2090618, 54865, 419, 9, 70, "Print"],
Cell[2091040, 54876, 418, 9, 31, "Print"],
Cell[2091461, 54887, 381, 8, 31, "Print"],
Cell[2091845, 54897, 384, 8, 31, "Print"],
Cell[2092232, 54907, 384, 8, 31, "Print"],
Cell[2092619, 54917, 419, 9, 31, "Print"],
Cell[2093041, 54928, 422, 9, 31, "Print"],
Cell[2093466, 54939, 420, 9, 31, "Print"],
Cell[2093889, 54950, 385, 8, 31, "Print"],
Cell[2094277, 54960, 385, 8, 31, "Print"],
Cell[2094665, 54970, 385, 8, 31, "Print"],
Cell[2095053, 54980, 422, 9, 31, "Print"],
Cell[2095478, 54991, 423, 9, 31, "Print"],
Cell[2095904, 55002, 422, 9, 31, "Print"],
Cell[2096329, 55013, 386, 8, 31, "Print"],
Cell[2096718, 55023, 390, 8, 31, "Print"],
Cell[2097111, 55033, 388, 8, 31, "Print"],
Cell[2097502, 55043, 423, 9, 31, "Print"],
Cell[2097928, 55054, 424, 9, 31, "Print"],
Cell[2098355, 55065, 425, 9, 31, "Print"],
Cell[2098783, 55076, 388, 8, 31, "Print"],
Cell[2099174, 55086, 392, 8, 31, "Print"],
Cell[2099569, 55096, 391, 8, 31, "Print"],
Cell[2099963, 55106, 430, 9, 31, "Print"],
Cell[2100396, 55117, 425, 9, 35, "Print"],
Cell[2100824, 55128, 15511, 379, 777, "Print"],
Cell[2116338, 55509, 15493, 379, 70, "Print"],
Cell[2131834, 55890, 15486, 379, 70, "Print"],
Cell[2147323, 56271, 15493, 379, 70, "Print"],
Cell[2162819, 56652, 15482, 379, 70, "Print"],
Cell[2178304, 57033, 15476, 379, 70, "Print"],
Cell[2193783, 57414, 15482, 379, 755, "Print"],
Cell[2209268, 57795, 15469, 379, 70, "Print"],
Cell[2224740, 58176, 15466, 379, 70, "Print"],
Cell[2240209, 58557, 15470, 379, 70, "Print"],
Cell[2255682, 58938, 15457, 379, 70, "Print"],
Cell[2271142, 59319, 15454, 379, 70, "Print"],
Cell[2286599, 59700, 15457, 379, 70, "Print"],
Cell[2302059, 60081, 15451, 379, 70, "Print"],
Cell[2317513, 60462, 15447, 379, 70, "Print"],
Cell[2332963, 60843, 15457, 379, 70, "Print"],
Cell[2348423, 61224, 15451, 379, 70, "Print"],
Cell[2363877, 61605, 15451, 379, 70, "Print"],
Cell[2379331, 61986, 15452, 379, 70, "Print"],
Cell[2394786, 62367, 15449, 379, 70, "Print"],
Cell[2410238, 62748, 15445, 379, 70, "Print"],
Cell[2425686, 63129, 15452, 379, 70, "Print"],
Cell[2441141, 63510, 15443, 379, 70, "Print"],
Cell[2456587, 63891, 15447, 379, 70, "Print"],
Cell[2472037, 64272, 15451, 379, 70, "Print"],
Cell[2487491, 64653, 15442, 379, 70, "Print"],
Cell[2502936, 65034, 15449, 379, 70, "Print"],
Cell[2518388, 65415, 15451, 379, 70, "Print"],
Cell[2533842, 65796, 15440, 379, 70, "Print"],
Cell[2549285, 66177, 15449, 379, 70, "Print"],
Cell[2564737, 66558, 15458, 379, 70, "Print"],
Cell[2580198, 66939, 15433, 379, 70, "Print"],
Cell[2595634, 67320, 15442, 379, 70, "Print"],
Cell[2611079, 67701, 15438, 379, 70, "Print"],
Cell[2626520, 68082, 15428, 379, 70, "Print"],
Cell[2641951, 68463, 15430, 379, 70, "Print"],
Cell[2657384, 68844, 15432, 379, 70, "Print"],
Cell[2672819, 69225, 15423, 379, 70, "Print"],
Cell[2688245, 69606, 15426, 379, 70, "Print"],
Cell[2703674, 69987, 15421, 379, 70, "Print"],
Cell[2719098, 70368, 15415, 379, 70, "Print"],
Cell[2734516, 70749, 15420, 379, 70, "Print"],
Cell[2749939, 71130, 15415, 379, 70, "Print"],
Cell[2765357, 71511, 15416, 379, 70, "Print"],
Cell[2780776, 71892, 15418, 379, 70, "Print"],
Cell[2796197, 72273, 15415, 379, 70, "Print"],
Cell[2811615, 72654, 15421, 379, 70, "Print"],
Cell[2827039, 73035, 15421, 379, 70, "Print"],
Cell[2842463, 73416, 15413, 379, 70, "Print"],
Cell[2857879, 73797, 15425, 379, 70, "Print"],
Cell[2873307, 74178, 15422, 379, 70, "Print"],
Cell[2888732, 74559, 15410, 379, 70, "Print"],
Cell[2904145, 74940, 15420, 379, 70, "Print"],
Cell[2919568, 75321, 15419, 379, 70, "Print"],
Cell[2934990, 75702, 15415, 379, 70, "Print"],
Cell[2950408, 76083, 15420, 379, 70, "Print"],
Cell[2965831, 76464, 15420, 379, 70, "Print"],
Cell[2981254, 76845, 15418, 379, 70, "Print"],
Cell[2996675, 77226, 15420, 379, 70, "Print"],
Cell[3012098, 77607, 15422, 379, 70, "Print"],
Cell[3027523, 77988, 15369, 378, 70, "Print"],
Cell[3042895, 78368, 15407, 379, 70, "Print"],
Cell[3058305, 78749, 15405, 379, 70, "Print"],
Cell[3073713, 79130, 15403, 379, 70, "Print"],
Cell[3089119, 79511, 15405, 379, 70, "Print"],
Cell[3104527, 79892, 15405, 379, 70, "Print"],
Cell[3119935, 80273, 15400, 379, 70, "Print"],
Cell[3135338, 80654, 15404, 379, 70, "Print"],
Cell[3150745, 81035, 15405, 379, 70, "Print"],
Cell[3166153, 81416, 15395, 379, 70, "Print"],
Cell[3181551, 81797, 15407, 379, 70, "Print"],
Cell[3196961, 82178, 15410, 379, 70, "Print"],
Cell[3212374, 82559, 15398, 379, 70, "Print"],
Cell[3227775, 82940, 15406, 379, 70, "Print"],
Cell[3243184, 83321, 15406, 379, 70, "Print"],
Cell[3258593, 83702, 15405, 379, 70, "Print"],
Cell[3274001, 84083, 15413, 379, 70, "Print"],
Cell[3289417, 84464, 15411, 379, 70, "Print"],
Cell[3304831, 84845, 15410, 379, 70, "Print"],
Cell[3320244, 85226, 15415, 379, 70, "Print"],
Cell[3335662, 85607, 15410, 379, 70, "Print"],
Cell[3351075, 85988, 15416, 379, 70, "Print"],
Cell[3366494, 86369, 15421, 379, 70, "Print"],
Cell[3381918, 86750, 15418, 379, 70, "Print"],
Cell[3397339, 87131, 15427, 379, 70, "Print"],
Cell[3412769, 87512, 15425, 379, 70, "Print"],
Cell[3428197, 87893, 15423, 379, 70, "Print"],
Cell[3443623, 88274, 15433, 379, 70, "Print"],
Cell[3459059, 88655, 15437, 379, 70, "Print"],
Cell[3474499, 89036, 15428, 379, 70, "Print"],
Cell[3489930, 89417, 15448, 379, 70, "Print"],
Cell[3505381, 89798, 15434, 379, 70, "Print"],
Cell[3520818, 90179, 15425, 379, 70, "Print"],
Cell[3536246, 90560, 15436, 379, 70, "Print"],
Cell[3551685, 90941, 15434, 379, 70, "Print"],
Cell[3567122, 91322, 15427, 379, 70, "Print"],
Cell[3582552, 91703, 15436, 379, 70, "Print"],
Cell[3597991, 92084, 15432, 379, 70, "Print"],
Cell[3613426, 92465, 15428, 379, 70, "Print"],
Cell[3628857, 92846, 15437, 379, 70, "Print"],
Cell[3644297, 93227, 15430, 379, 70, "Print"],
Cell[3659730, 93608, 15434, 379, 70, "Print"],
Cell[3675167, 93989, 15437, 379, 70, "Print"],
Cell[3690607, 94370, 15436, 379, 70, "Print"],
Cell[3706046, 94751, 15436, 379, 70, "Print"],
Cell[3721485, 95132, 15447, 379, 70, "Print"],
Cell[3736935, 95513, 15442, 379, 70, "Print"],
Cell[3752380, 95894, 15446, 379, 70, "Print"],
Cell[3767829, 96275, 15452, 379, 70, "Print"],
Cell[3783284, 96656, 15449, 379, 70, "Print"],
Cell[3798736, 97037, 15452, 379, 70, "Print"],
Cell[3814191, 97418, 15465, 379, 70, "Print"],
Cell[3829659, 97799, 15461, 379, 70, "Print"],
Cell[3845123, 98180, 15464, 379, 70, "Print"],
Cell[3860590, 98561, 15477, 379, 70, "Print"],
Cell[3876070, 98942, 15471, 379, 70, "Print"],
Cell[3891544, 99323, 15477, 379, 70, "Print"],
Cell[3907024, 99704, 15488, 379, 70, "Print"],
Cell[3922515, 100085, 15481, 379, 70, "Print"],
Cell[3937999, 100466, 15488, 379, 70, "Print"],
Cell[3953490, 100847, 15506, 379, 759, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[3969033, 101231, 342, 7, 112, "Input",
  CellTags->"Cell 6.51"],

Cell[CellGroupData[{
Cell[3969400, 101242, 35792, 946, 233, 9930, 621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4005195, 102190, 40869, 1533, 233, 16546, 1227, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4046067, 103725, 38342, 1494, 70, 16497, 1218, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4084412, 105221, 37781, 1502, 70, 16921, 1239, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4122196, 106725, 40905, 1552, 70, 17558, 1258, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4163104, 108279, 41473, 1530, 70, 17441, 1227, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4204580, 109811, 40744, 1462, 70, 17093, 1164, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4245327, 111275, 36774, 1240, 70, 14634, 961, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4282104, 112517, 34117, 1120, 70, 13722, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4316224, 113639, 33145, 1055, 70, 13257, 804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4349372, 114696, 33025, 1068, 70, 13741, 823, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4382400, 115766, 33052, 1097, 70, 14315, 859, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4415455, 116865, 35866, 1253, 70, 16708, 1010, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[4451348, 118122, 1019, 24, 112, "Text",
  CellTags->"i:16"],
Cell[4452370, 118148, 1214, 32, 129, "Text"],
Cell[4453587, 118182, 650, 13, 95, "Text",
  CellTags->"i:15"],
Cell[4454240, 118197, 345, 8, 61, "Text"],
Cell[4454588, 118207, 588, 9, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4455225, 118222, 65, 1, 30, "Subsubtitle",
  CellTags->"c:12"],
Cell[4455293, 118225, 507, 13, 64, "Text"],
Cell[4455803, 118240, 21731, 272, 73, 21609, 268, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[4477537, 118514, 65, 1, 16, "Caption",
  CellTags->"Fig. 6.4"],
Cell[4477605, 118517, 1268, 36, 101, "Text"],
Cell[4478876, 118555, 1451, 42, 116, "Text"],
Cell[4480330, 118599, 33180, 413, 174, 33062, 409, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[4513513, 119014, 65, 1, 16, "Caption",
  CellTags->"Fig. 6.5"],
Cell[4513581, 119017, 865, 24, 82, "Text"],
Cell[4514449, 119043, 432, 12, 61, "Text"],
Cell[4514884, 119057, 804, 25, 86, "Text"],
Cell[4515691, 119084, 621, 20, 44, "Text"],
Cell[4516315, 119106, 530, 15, 41, "Text"],
Cell[4516848, 119123, 995, 32, 86, "Text"],
Cell[4517846, 119157, 1481, 46, 95, "Text"],
Cell[4519330, 119205, 1389, 43, 44, "Text"],
Cell[4520722, 119250, 218, 5, 44, "Text"],
Cell[4520943, 119257, 1599, 49, 86, "Text"],
Cell[4522545, 119308, 293, 8, 43, "Text"],
Cell[4522841, 119318, 567, 17, 72, "Text"],
Cell[4523411, 119337, 936, 29, 90, "Text"],
Cell[4524350, 119368, 602, 18, 40, "Text"],
Cell[4524955, 119388, 1430, 44, 50, "Text"],
Cell[4526388, 119434, 711, 21, 65, "Text"],
Cell[4527102, 119457, 428, 13, 64, "Text"],
Cell[4527533, 119472, 222, 6, 42, "NumberedEquation",
  CellTags->{"i:37", "(6.1.37)"}],
Cell[4527758, 119480, 228, 8, 27, "Text"],
Cell[4527989, 119490, 651, 23, 47, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4528689, 119519, 66, 1, 40, "Subtitle",
  CellTags->{"i:17", "c:13"}],
Cell[4528758, 119522, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[4528799, 119526, 72, 1, 41, "Subsubtitle",
  CellTags->"c:14"],

Cell[CellGroupData[{
Cell[4528896, 119531, 82, 1, 42, "Section",
  CellTags->{"i:18", "c:15"}],
Cell[4528981, 119534, 518, 13, 61, "Text"],
Cell[4529502, 119549, 211, 6, 44, "Text"],
Cell[4529716, 119557, 234, 7, 42, "NE2",
  CellTags->"(6.2.1)"],
Cell[4529953, 119566, 480, 14, 44, "Text"],
Cell[4530436, 119582, 775, 24, 45, "NE2",
  CellTags->"(6.2.2)"],
Cell[4531214, 119608, 948, 29, 64, "Text"],
Cell[4532165, 119639, 509, 10, 78, "Text"],
Cell[4532677, 119651, 651, 19, 48, "NE2",
  CellTags->"(6.2.3)"],
Cell[4533331, 119672, 46, 0, 27, "Text"],
Cell[4533380, 119674, 835, 24, 45, "NE2",
  CellTags->"(6.2.4)"],
Cell[4534218, 119700, 480, 16, 50, "Text"],
Cell[4534701, 119718, 909, 25, 39, "NE2",
  CellTags->"(6.2.5)"],
Cell[4535613, 119745, 1779, 60, 84, "Text"],
Cell[4537395, 119807, 397, 9, 172, "Input",
  CellTags->"Cell 6.52"],
Cell[4537795, 119818, 1083, 34, 106, "Text"],
Cell[4538881, 119854, 225, 5, 86, "Input",
  CellTags->"Cell 6.53"],
Cell[4539109, 119861, 282, 7, 64, "Text"],
Cell[4539394, 119870, 102, 3, 27, "Text"],
Cell[4539499, 119875, 136, 3, 67, "Input",
  CellTags->"Cell 6.54"],
Cell[4539638, 119880, 1127, 40, 61, "Text"],
Cell[4540768, 119922, 359, 7, 146, "Input",
  CellTags->"Cell 6.55"],
Cell[4541130, 119931, 214, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[4541369, 119942, 386, 9, 105, "Input",
  CellTags->"Cell 6.56"],

Cell[CellGroupData[{
Cell[4541780, 119955, 28292, 671, 233, 6999, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4570075, 120628, 27512, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4597590, 121293, 27105, 658, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4624698, 121953, 27232, 659, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4651933, 122614, 27293, 660, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4679229, 123276, 27398, 662, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4706630, 123940, 27538, 663, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4734171, 124605, 27504, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4761678, 125270, 27632, 664, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4789313, 125936, 27637, 664, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4816953, 126602, 27303, 660, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4844259, 127264, 27539, 663, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4871801, 127929, 27529, 663, 70, 7003, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4899333, 128594, 27611, 664, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4926947, 129260, 27548, 663, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4954498, 129925, 27585, 664, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4982086, 130591, 27665, 665, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5009754, 131258, 27583, 664, 70, 7004, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5037340, 131924, 27693, 665, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5065036, 132591, 27674, 665, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5092713, 133258, 27423, 662, 70, 7005, 404, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[5120163, 133924, 2261, 70, 95, "Text",
  CellTags->"i:70"],

Cell[CellGroupData[{
Cell[5122449, 133998, 644, 14, 181, "Input",
  CellTags->"Cell 6.57"],

Cell[CellGroupData[{
Cell[5123118, 134016, 28325, 672, 233, 6999, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5151446, 134690, 27798, 666, 70, 7006, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5179247, 135358, 34996, 758, 70, 7032, 408, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5214246, 136118, 69135, 1194, 70, 7151, 424, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5283384, 137314, 70244, 1208, 70, 7162, 424, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5353631, 138524, 70783, 1215, 70, 7158, 424, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[5424441, 139743, 100, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5424578, 139751, 79, 1, 31, "Section",
  CellTags->{"i:19", "c:16"}],
Cell[5424660, 139754, 1708, 44, 157, "Text",
  CellTags->"i:58"],
Cell[5426371, 139800, 1435, 36, 39, "UNNEQ"],
Cell[5427809, 139838, 91, 3, 27, "Text"],
Cell[5427903, 139843, 1025, 28, 39, "NE2",
  CellTags->"(6.2.6)"],
Cell[5428931, 139873, 115, 3, 27, "Text"],
Cell[5429049, 139878, 121, 5, 29, "NE2",
  CellTags->"(6.2.7)"],
Cell[5429173, 139885, 619, 20, 61, "Text"],
Cell[5429795, 139907, 872, 24, 39, "NE2",
  CellTags->"(6.2.8)"],
Cell[5430670, 139933, 1377, 33, 150, "Text"],
Cell[5432050, 139968, 1035, 34, 54, "Text"],
Cell[5433088, 140004, 48833, 1288, 233, 17077, 891, "GraphicsData", \
"PostScript", "Picture"],
Cell[5481924, 141294, 114, 4, 16, "Caption",
  CellTags->"Fig. 6.6"],
Cell[5482041, 141300, 1239, 38, 54, "Text"],
Cell[5483283, 141340, 554, 18, 39, "NE2",
  CellTags->"(6.2.9)"],
Cell[5483840, 141360, 1996, 63, 97, "Text",
  CellTags->"i:65"]
}, Closed]],

Cell[CellGroupData[{
Cell[5485873, 141428, 60, 1, 31, "Section",
  CellTags->{"i:20", "c:17"}],
Cell[5485936, 141431, 598, 13, 78, "Text"],
Cell[5486537, 141446, 928, 25, 39, "NE2",
  CellTags->"(6.2.10)"],
Cell[5487468, 141473, 482, 13, 68, "Text"],
Cell[5487953, 141488, 144, 5, 32, "NE2",
  CellTags->"(6.2.11)"],
Cell[5488100, 141495, 991, 30, 37, "Text"],

Cell[CellGroupData[{
Cell[5489116, 141529, 316, 7, 92, "Input",
  CellTags->"Cell 6.58"],
Cell[5489435, 141538, 21154, 552, 233, 5939, 360, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5510604, 142093, 654, 17, 61, "Text"],
Cell[5511261, 142112, 139, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5511437, 142120, 59, 1, 31, "Section",
  CellTags->{"i:21", "c:18"}],
Cell[5511499, 142123, 1395, 33, 139, "Text"],
Cell[5512897, 142158, 969, 25, 39, "NE2",
  CellTags->"(6.2.12)"],
Cell[5513869, 142185, 212, 6, 44, "Text"],
Cell[5514084, 142193, 725, 21, 33, "UNNEQ"],
Cell[5514812, 142216, 1189, 38, 48, "Text"],

Cell[CellGroupData[{
Cell[5516026, 142258, 506, 11, 122, "Input",
  CellTags->"Cell 6.59"],
Cell[5516535, 142271, 52333, 1215, 233, 13241, 728, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5568883, 143489, 541, 15, 44, "Text"],
Cell[5569427, 143506, 527, 15, 33, "NE2",
  CellTags->"(6.2.13)"],
Cell[5569957, 143523, 719, 17, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5570713, 143545, 96, 1, 31, "Section",
  CellTags->{"i:22", "c:19"}],
Cell[5570812, 143548, 855, 23, 92, "Text"],
Cell[5571670, 143573, 902, 25, 39, "NE2",
  CellTags->"(6.2.14)"],
Cell[5572575, 143600, 1194, 36, 107, "Text",
  CellTags->"i:25"],
Cell[5573772, 143638, 381, 11, 44, "Text"],
Cell[5574156, 143651, 638, 18, 35, "NE2",
  CellTags->"(6.2.15)"],
Cell[5574797, 143671, 990, 34, 31, "Text"],
Cell[5575790, 143707, 655, 22, 61, "Text"],
Cell[5576448, 143731, 1146, 30, 39, "NE2",
  CellTags->"(6.2.16)"],
Cell[5577597, 143763, 1147, 39, 61, "Text",
  CellTags->"i:23"],
Cell[5578747, 143804, 979, 27, 44, "NE2",
  CellTags->"(6.2.17)"],
Cell[5579729, 143833, 508, 16, 61, "Text"],
Cell[5580240, 143851, 61, 0, 27, "Text"],
Cell[5580304, 143853, 218, 6, 86, "Input",
  CellTags->"Cell 6.60"],
Cell[5580525, 143861, 705, 23, 44, "Text"],
Cell[5581233, 143886, 95, 3, 27, "Text"],
Cell[5581331, 143891, 234, 6, 124, "Input",
  CellTags->"Cell 6.61"],
Cell[5581568, 143899, 137, 3, 27, "Text"],
Cell[5581708, 143904, 226, 7, 36, "NE2",
  CellTags->"(6.2.18)"],
Cell[5581937, 143913, 1059, 30, 98, "Text"],
Cell[5582999, 143945, 832, 25, 64, "Text"],

Cell[CellGroupData[{
Cell[5583856, 143974, 174, 5, 67, "Input",
  CellTags->"Cell 6.62"],
Cell[5584033, 143981, 402, 8, 84, "Output"]
}, Open  ]],
Cell[5584450, 143992, 717, 21, 44, "Text"],
Cell[5585170, 144015, 1954, 41, 406, "Input",
  CellTags->"Cell 6.63"],
Cell[5587127, 144058, 1525, 51, 61, "Text"],

Cell[CellGroupData[{
Cell[5588677, 144113, 988, 20, 258, "Input",
  CellTags->"Cell 6.64"],

Cell[CellGroupData[{
Cell[5589690, 144137, 32685, 743, 233, 7134, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5622378, 144882, 28721, 693, 70, 7148, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5651102, 145577, 26067, 661, 70, 7138, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5677172, 146240, 25414, 653, 70, 7141, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5702589, 146895, 24309, 639, 70, 7142, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5726901, 147536, 24466, 641, 70, 7149, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5751370, 148179, 23958, 635, 70, 7147, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5775331, 148816, 24004, 635, 70, 7149, 422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5799338, 149453, 23303, 627, 70, 7144, 422, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[5822668, 150084, 146, 3, 44, "Text"],
Cell[5822817, 150089, 198, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[5823040, 150097, 264, 7, 124, "Input",
  CellTags->"Cell 6.65"],
Cell[5823307, 150106, 133, 3, 46, "Output"]
}, Open  ]],
Cell[5823455, 150112, 1160, 41, 44, "Text"],

Cell[CellGroupData[{
Cell[5824640, 150157, 189, 4, 86, "Input",
  CellTags->"Cell 6.66"],
Cell[5824832, 150163, 97731, 1937, 344, 26949, 1059, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5922612, 152106, 91, 1, 31, "Section",
  CellTags->{"i:24", "c:20"}],
Cell[5922706, 152109, 583, 14, 61, "Text"],
Cell[5923292, 152125, 361, 12, 43, "NE2",
  CellTags->"(6.2.19)"],
Cell[5923656, 152139, 122, 3, 27, "Text"],
Cell[5923781, 152144, 433, 15, 30, "NE2",
  CellTags->"(6.2.20)"],
Cell[5924217, 152161, 1208, 35, 79, "Text"],
Cell[5925428, 152198, 1091, 33, 80, "Text"],
Cell[5926522, 152233, 407, 15, 30, "NE2",
  CellTags->"(6.2.21)"],
Cell[5926932, 152250, 1660, 56, 78, "Text"],
Cell[5928595, 152308, 1198, 38, 61, "Text"],
Cell[5929796, 152348, 366, 9, 181, "Input",
  CellTags->"Cell 6.67"],
Cell[5930165, 152359, 195, 6, 27, "Text"],
Cell[5930363, 152367, 157, 4, 86, "Input",
  CellTags->"Cell 6.68"],
Cell[5930523, 152373, 183, 4, 44, "Text"],
Cell[5930709, 152379, 114, 3, 67, "Input",
  CellTags->"Cell 6.69"],
Cell[5930826, 152384, 456, 11, 64, "Text"],

Cell[CellGroupData[{
Cell[5931307, 152399, 148, 4, 67, "Input",
  CellTags->"Cell 6.70"],
Cell[5931458, 152405, 445, 9, 97, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5931940, 152419, 1007, 20, 277, "Input",
  CellTags->"Cell 6.71"],

Cell[CellGroupData[{
Cell[5932972, 152443, 29318, 736, 233, 7570, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5962293, 153181, 27748, 716, 70, 7592, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5990044, 153899, 26887, 706, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6016934, 154607, 26725, 704, 70, 7589, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6043662, 155313, 26012, 695, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6069677, 156010, 26514, 701, 70, 7589, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6096194, 156713, 26151, 697, 70, 7590, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6122348, 157412, 26230, 698, 70, 7584, 463, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6148581, 158112, 25777, 692, 70, 7585, 463, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6174385, 158808, 133, 3, 27, "Text"],
Cell[6174521, 158813, 752, 20, 78, "Text"],
Cell[6175276, 158835, 842, 27, 70, "Text"],
Cell[6176121, 158864, 400, 14, 43, "NE2",
  CellTags->"(6.2.22)"],
Cell[6176524, 158880, 150, 6, 29, "Text"],
Cell[6176677, 158888, 1012, 28, 43, "NE2",
  CellTags->"(6.2.23)"],
Cell[6177692, 158918, 740, 22, 70, "Text"],
Cell[6178435, 158942, 537, 14, 43, "NE2",
  CellTags->"(6.2.24)"],
Cell[6178975, 158958, 31, 0, 27, "Text"],
Cell[6179009, 158960, 1034, 27, 43, "NE2",
  CellTags->"(6.2.25)"],
Cell[6180046, 158989, 152, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6180235, 158997, 66, 1, 31, "Section",
  CellTags->"c:21"],

Cell[CellGroupData[{
Cell[6180326, 159002, 41, 0, 27, "Subsubsection"],
Cell[6180370, 159004, 215, 4, 44, "Text"],
Cell[6180588, 159010, 272, 7, 45, "NE2",
  CellTags->"(6.2.26)"],
Cell[6180863, 159019, 404, 14, 45, "Text"],
Cell[6181270, 159035, 791, 24, 48, "NE2",
  CellTags->"(6.2.27)"],
Cell[6182064, 159061, 695, 24, 28, "Text"],
Cell[6182762, 159087, 112, 3, 27, "Text"],
Cell[6182877, 159092, 1567, 41, 42, "NE2",
  CellTags->"(6.2.28)"],
Cell[6184447, 159135, 718, 16, 89, "Text"],
Cell[6185168, 159153, 1111, 32, 46, "NE2",
  CellTags->"(6.2.29)"],
Cell[6186282, 159187, 165, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6186484, 159196, 94, 1, 29, "Subsubsection",
  CellTags->"i:26"],
Cell[6186581, 159199, 185, 4, 44, "Text"],
Cell[6186769, 159205, 281, 8, 43, "Text"],
Cell[6187053, 159215, 416, 12, 44, "Text"],
Cell[6187472, 159229, 185, 6, 27, "Text"],
Cell[6187660, 159237, 48, 0, 27, "Text"],
Cell[6187711, 159239, 199, 7, 36, "Text"],
Cell[6187913, 159248, 192, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[6188130, 159258, 455, 10, 168, "Input",
  CellTags->"Cell 6.72"],
Cell[6188588, 159270, 111809, 2005, 302, 24367, 921, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6300412, 161278, 1919, 58, 86, "Text"],
Cell[6302334, 161338, 1652, 31, 493, "Input",
  CellTags->"Cell 6.73"],
Cell[6303989, 161371, 56, 0, 27, "Text"],
Cell[6304048, 161373, 1559, 40, 48, "Text"],
Cell[6305610, 161415, 74, 0, 27, "Text"],
Cell[6305687, 161417, 612, 13, 246, "Input",
  CellTags->"Cell 6.74"],
Cell[6306302, 161432, 653, 20, 61, "Text"],
Cell[6306958, 161454, 939, 27, 85, "Text"],
Cell[6307900, 161483, 1231, 32, 48, "Text"],
Cell[6309134, 161517, 204, 6, 34, "Text"],
Cell[6309341, 161525, 106, 3, 67, "Input",
  CellTags->"Cell 6.75"],
Cell[6309450, 161530, 305, 10, 44, "Text"],
Cell[6309758, 161542, 267, 6, 126, "Input",
  CellTags->"Cell 6.76"],
Cell[6310028, 161550, 148, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[6310201, 161560, 354, 8, 105, "Input",
  CellTags->"Cell 6.77"],

Cell[CellGroupData[{
Cell[6310580, 161572, 257363, 4385, 302, 223328, 3960, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6567946, 165959, 333352, 6817, 302, 253329, 5824, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6901301, 172778, 387697, 8664, 302, 277623, 7300, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7289001, 181444, 386620, 8684, 302, 277891, 7337, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7675624, 190130, 399139, 8873, 302, 278948, 7384, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],
Cell[8074790, 199007, 932, 22, 89, "Text",
  CellTags->"i:28"]
}, Closed]],

Cell[CellGroupData[{
Cell[8075759, 199034, 84, 1, 29, "Subsubsection",
  CellTags->"i:27"],
Cell[8075846, 199037, 207, 4, 44, "Text"],
Cell[8076056, 199043, 737, 18, 38, "NE2",
  CellTags->"(6.2.30)"],
Cell[8076796, 199063, 69, 0, 27, "Text"],
Cell[8076868, 199065, 1368, 37, 86, "UNNEQ"],
Cell[8078239, 199104, 638, 23, 45, "Text"],
Cell[8078880, 199129, 949, 24, 117, "Text"],
Cell[8079832, 199155, 1914, 49, 140, "Text",
  CellTags->"i:69"],
Cell[8081749, 199206, 1121, 29, 83, "NE2",
  CellTags->"(6.2.31)"],
Cell[8082873, 199237, 1960, 47, 179, "Text"],
Cell[8084836, 199286, 242, 6, 88, "Input",
  CellTags->"Cell 6.78"],
Cell[8085081, 199294, 340, 8, 64, "Text"],
Cell[8085424, 199304, 862, 17, 261, "Input",
  CellTags->"Cell 6.79"],
Cell[8086289, 199323, 69, 0, 27, "Text"],
Cell[8086361, 199325, 302, 8, 38, "NE2",
  CellTags->"(6.2.32)"],
Cell[8086666, 199335, 1064, 36, 48, "Text"],
Cell[8087733, 199373, 267, 7, 88, "Input",
  CellTags->"Cell 6.80"],
Cell[8088003, 199382, 110, 3, 27, "Text"],
Cell[8088116, 199387, 434, 9, 146, "Input",
  CellTags->"Cell 6.81"],
Cell[8088553, 199398, 28, 0, 27, "Text"],
Cell[8088584, 199400, 3653, 77, 652, "Input",
  CellTags->"Cell 6.82"],
Cell[8092240, 199479, 553, 19, 27, "Text"],

Cell[CellGroupData[{
Cell[8092818, 199502, 326, 8, 145, "Input",
  CellTags->"Cell 6.83"],
Cell[8093147, 199512, 152, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8093336, 199521, 381, 8, 128, "Input",
  CellTags->"Cell 6.84"],

Cell[CellGroupData[{
Cell[8093742, 199533, 151810, 2655, 404, 28339, 1126, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8245555, 202190, 141266, 2527, 70, 28220, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8386824, 204719, 28412, 1130, 70, 28287, 1126, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8415239, 205851, 28605, 1134, 70, 28480, 1130, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8443847, 206987, 134495, 2443, 70, 28532, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8578345, 209432, 134347, 2440, 70, 28555, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8712695, 211874, 133455, 2430, 70, 28533, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8846153, 214306, 133797, 2433, 70, 28588, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8979953, 216741, 132855, 2423, 70, 28504, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9112811, 219166, 132605, 2419, 70, 28542, 1130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9245419, 221587, 132027, 2412, 70, 28515, 1130, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9377473, 224003, 363, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[9377861, 224020, 1003, 21, 309, "Input",
  CellTags->"Cell 6.85"],

Cell[CellGroupData[{
Cell[9378889, 224045, 32855, 784, 233, 8982, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9411747, 224831, 26306, 703, 233, 8986, 484, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9438056, 225536, 25171, 689, 233, 8989, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9463254, 226229, 157, 4, 38, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9463472, 226240, 82, 1, 30, "Subsubtitle",
  CellTags->{"i:29", "c:22"}],

Cell[CellGroupData[{
Cell[9463579, 226245, 64, 1, 42, "Section",
  CellTags->{"i:30", "c:23"}],
Cell[9463646, 226248, 201, 4, 44, "Text"],
Cell[9463850, 226254, 208, 6, 45, "NE2",
  CellTags->"(6.2.33)"],
Cell[9464061, 226262, 428, 12, 45, "Text"],
Cell[9464492, 226276, 712, 25, 48, "UNNEQ"],
Cell[9465207, 226303, 511, 20, 28, "Text"],
Cell[9465721, 226325, 288, 7, 44, "Text"],
Cell[9466012, 226334, 1086, 31, 45, "NE2",
  CellTags->"(6.2.34)"],
Cell[9467101, 226367, 519, 19, 46, "Text"],
Cell[9467623, 226388, 591, 17, 62, "Text"],
Cell[9468217, 226407, 263, 7, 130, "Input",
  CellTags->"Cell 6.86"],
Cell[9468483, 226416, 109, 3, 27, "Text"],
Cell[9468595, 226421, 245, 6, 126, "Input",
  CellTags->"Cell 6.87"],
Cell[9468843, 226429, 146, 5, 27, "Text"],
Cell[9468992, 226436, 107, 3, 67, "Input",
  CellTags->"Cell 6.88"],
Cell[9469102, 226441, 205, 6, 27, "Text"],
Cell[9469310, 226449, 2818, 62, 192, "Input",
  CellTags->"Cell 6.89"],
Cell[9472131, 226513, 107, 3, 27, "Text"],
Cell[9472241, 226518, 184, 5, 69, "Input",
  CellTags->"Cell 6.90"],
Cell[9472428, 226525, 48, 0, 27, "Text"],
Cell[9472479, 226527, 125, 3, 67, "Input",
  CellTags->"Cell 6.91"],
Cell[9472607, 226532, 209, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[9472841, 226541, 271, 7, 107, "Input",
  CellTags->"Cell 6.92"],
Cell[9473115, 226550, 131, 3, 46, "Output"]
}, Open  ]],
Cell[9473261, 226556, 167, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[9473453, 226566, 263, 6, 86, "Input",
  CellTags->"Cell 6.93"],
Cell[9473719, 226574, 156224, 3037, 370, 20450, 1356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9629992, 229617, 74, 1, 31, "Section",
  CellTags->{"i:31", "c:24"}],
Cell[9630069, 229620, 288, 5, 61, "Text"],
Cell[9630360, 229627, 843, 29, 48, "NE2",
  CellTags->"(6.2.35)"],
Cell[9631206, 229658, 1049, 35, 80, "Text"],
Cell[9632258, 229695, 182, 6, 27, "Text"],
Cell[9632443, 229703, 1115, 32, 57, "NE2",
  CellTags->"(6.2.36)"],
Cell[9633561, 229737, 277, 7, 46, "Text"],
Cell[9633841, 229746, 614, 19, 47, "Text"],
Cell[9634458, 229767, 470, 10, 206, "Input",
  CellTags->"Cell 6.94"],
Cell[9634931, 229779, 93, 3, 27, "Text"],
Cell[9635027, 229784, 523, 11, 145, "Input",
  CellTags->"Cell 6.95"],
Cell[9635553, 229797, 540, 16, 47, "Text"],
Cell[9636096, 229815, 1152, 38, 47, "Text"],
Cell[9637251, 229855, 337, 9, 86, "Input",
  CellTags->"Cell 6.96"],
Cell[9637591, 229866, 512, 13, 61, "Text"],
Cell[9638106, 229881, 143, 5, 36, "Text"],
Cell[9638252, 229888, 187, 6, 37, "Text"],
Cell[9638442, 229896, 200, 7, 32, "Text"],
Cell[9638645, 229905, 1324, 41, 78, "Text"],
Cell[9639972, 229948, 379, 12, 40, "NE2",
  CellTags->"(6.2.37)"],
Cell[9640354, 229962, 52, 0, 27, "Text"],
Cell[9640409, 229964, 426, 14, 40, "NE2",
  CellTags->"(6.2.38)"],
Cell[9640838, 229980, 244, 9, 27, "Text"],
Cell[9641085, 229991, 548, 13, 190, "Input",
  CellTags->"Cell 6.97"],
Cell[9641636, 230006, 161, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[9641822, 230016, 369, 8, 128, "Input",
  CellTags->"Cell 6.98"],
Cell[9642194, 230026, 24114, 535, 370, 3856, 280, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9666323, 230564, 1142, 22, 146, "Text",
  CellTags->"i:68"],
Cell[9667468, 230588, 969, 26, 78, "Text"],
Cell[9668440, 230616, 151, 5, 27, "Text"],
Cell[9668594, 230623, 109, 3, 67, "Input",
  CellTags->"Cell 6.99"],
Cell[9668706, 230628, 197, 6, 27, "Text"],
Cell[9668906, 230636, 3221, 68, 241, "Input",
  CellTags->"Cell 6.100"],
Cell[9672130, 230706, 44, 0, 27, "Text"],
Cell[9672177, 230708, 212, 6, 69, "Input",
  CellTags->"Cell 6.101"],
Cell[9672392, 230716, 48, 0, 27, "Text"],
Cell[9672443, 230718, 126, 3, 67, "Input",
  CellTags->"Cell 6.102"],
Cell[9672572, 230723, 91, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[9672688, 230730, 225, 6, 107, "Input",
  CellTags->"Cell 6.103"],
Cell[9672916, 230738, 150, 4, 46, "Output"]
}, Open  ]],
Cell[9673081, 230745, 169, 6, 27, "Text"],
Cell[9673253, 230753, 93, 3, 67, "Input",
  CellTags->"Cell 6.104"],

Cell[CellGroupData[{
Cell[9673371, 230760, 394, 8, 105, "Input",
  CellTags->"Cell 6.105"],
Cell[9673768, 230770, 123900, 4172, 426, 51005, 3268, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9797683, 234945, 742, 25, 62, "Text"],
Cell[9798428, 234972, 28959, 708, 244, 7771, 442, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9827390, 235682, 52, 1, 16, "Caption",
  CellTags->"Fig. 6.7"],
Cell[9827445, 235685, 448, 12, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9827930, 235702, 67, 1, 31, "Section",
  CellTags->{"i:32", "c:25"}],

Cell[CellGroupData[{
Cell[9828022, 235707, 60, 1, 27, "Subsubsection",
  CellTags->"i:33"],
Cell[9828085, 235710, 718, 16, 95, "Text"],
Cell[9828806, 235728, 439, 9, 61, "Text"],
Cell[9829248, 235739, 641, 23, 44, "Text"],
Cell[9829892, 235764, 2141, 52, 46, "UNNEQ"],
Cell[9832036, 235818, 190, 5, 31, "Text"],
Cell[9832229, 235825, 1985, 51, 46, "NE2",
  CellTags->"(6.2.39)"],
Cell[9834217, 235878, 1069, 34, 81, "Text",
  CellTags->"i:61"],
Cell[9835289, 235914, 114, 3, 27, "Text"],
Cell[9835406, 235919, 312, 8, 168, "Input",
  CellTags->"Cell 6.106"],
Cell[9835721, 235929, 105, 3, 27, "Text"],
Cell[9835829, 235934, 312, 6, 126, "Input",
  CellTags->"Cell 6.107"],
Cell[9836144, 235942, 186, 6, 27, "Text"],
Cell[9836333, 235950, 571, 11, 247, "Input",
  CellTags->"Cell 6.108"],
Cell[9836907, 235963, 284, 7, 44, "Text"],
Cell[9837194, 235972, 111, 3, 67, "Input",
  CellTags->"Cell 6.109"],
Cell[9837308, 235977, 295, 9, 44, "Text"],
Cell[9837606, 235988, 235, 6, 107, "Input",
  CellTags->"Cell 6.110"],
Cell[9837844, 235996, 114, 3, 27, "Text"],
Cell[9837961, 236001, 180, 5, 30, "Text"],
Cell[9838144, 236008, 396, 8, 164, "Input",
  CellTags->"Cell 6.111"],
Cell[9838543, 236018, 314, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[9838882, 236033, 91, 3, 67, "Input",
  CellTags->"Cell 6.112"],
Cell[9838976, 236038, 56, 1, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9839069, 236044, 225, 5, 105, "Input",
  CellTags->"Cell 6.113"],
Cell[9839297, 236051, 53413, 1559, 233, 24749, 1201, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9892725, 237613, 124, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[9892874, 237620, 266, 7, 107, "Input",
  CellTags->"Cell 6.114"],
Cell[9893143, 237629, 132, 3, 46, "Output"]
}, Open  ]],
Cell[9893290, 237635, 169, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[9893484, 237645, 318, 6, 105, "Input",
  CellTags->"Cell 6.115"],
Cell[9893805, 237653, 252259, 5026, 536, 36755, 2361, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10146113, 242685, 72, 1, 29, "Subsubsection",
  CellTags->"i:34"],
Cell[10146188, 242688, 1702, 48, 103, "Text"],
Cell[10147893, 242738, 717, 19, 31, "UNNEQ"],
Cell[10148613, 242759, 161, 4, 44, "Text"],
Cell[10148777, 242765, 411, 11, 61, "Text"],
Cell[10149191, 242778, 2810, 66, 46, "NE2",
  CellTags->"(6.2.40)"],
Cell[10152004, 242846, 1460, 40, 143, "Text"],
Cell[10153467, 242888, 1292, 27, 163, "Text"],
Cell[10154762, 242917, 4177, 78, 934, "Input",
  CellTags->"Cell 6.116"],

Cell[CellGroupData[{
Cell[10158964, 242999, 93, 3, 67, "Input",
  CellTags->"Cell 6.117"],
Cell[10159060, 243004, 213, 4, 35, "Print"],
Cell[10159276, 243010, 132, 3, 46, "Output"]
}, Open  ]],
Cell[10159423, 243016, 342, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[10159790, 243028, 256, 6, 124, "Input",
  CellTags->"Cell 6.118"],
Cell[10160049, 243036, 35794, 1069, 233, 16768, 830, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[10195858, 244108, 384, 9, 61, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10196291, 244123, 59, 1, 31, "Section",
  CellTags->{"i:36", "c:26"}],
Cell[10196353, 244126, 828, 17, 112, "Text"],
Cell[10197184, 244145, 426, 12, 48, "Text"],
Cell[10197613, 244159, 715, 25, 48, "UNNEQ"],
Cell[10198331, 244186, 1178, 36, 62, "Text"],
Cell[10199512, 244224, 369, 6, 40, "NE2",
  CellTags->"(6.2.41)"],
Cell[10199884, 244232, 19, 0, 27, "Text"],
Cell[10199906, 244234, 417, 9, 40, "NE2",
  CellTags->"(6.2.42)"],
Cell[10200326, 244245, 466, 14, 47, "Text"],
Cell[10200795, 244261, 1007, 26, 46, "UNNEQ"],
Cell[10201805, 244289, 34, 0, 27, "Text"],
Cell[10201842, 244291, 179, 3, 44, "NE2",
  CellTags->"(6.2.43)"],
Cell[10202024, 244296, 21, 0, 27, "Text"],
Cell[10202048, 244298, 797, 23, 41, "UNNEQ"],
Cell[10202848, 244323, 240, 7, 44, "Text"],
Cell[10203091, 244332, 151, 5, 27, "Text"],
Cell[10203245, 244339, 185, 6, 27, "Text"],
Cell[10203433, 244347, 350, 11, 46, "Text"],
Cell[10203786, 244360, 1230, 37, 105, "Text"],
Cell[10205019, 244399, 990, 28, 97, "Text"],
Cell[10206012, 244429, 259, 9, 44, "Text"],
Cell[10206274, 244440, 285, 8, 149, "Input",
  CellTags->"Cell 6.119"],
Cell[10206562, 244450, 371, 7, 61, "Text"],
Cell[10206936, 244459, 53, 0, 27, "Text"],
Cell[10206992, 244461, 154, 4, 67, "Input",
  CellTags->"Cell 6.120"],
Cell[10207149, 244467, 172, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[10207346, 244475, 134, 3, 69, "Input",
  CellTags->"Cell 6.121"],
Cell[10207483, 244480, 35, 1, 46, "Output"]
}, Open  ]],
Cell[10207533, 244484, 159, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[10207717, 244494, 229, 5, 86, "Input",
  CellTags->"Cell 6.122"],
Cell[10207949, 244501, 117386, 2139, 302, 26136, 1008, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[10325350, 246643, 263, 6, 46, "Text"],
Cell[10325616, 246651, 223, 5, 69, "Input",
  CellTags->"Cell 6.123"],
Cell[10325842, 246658, 175, 6, 27, "Text"],
Cell[10326020, 246666, 118, 3, 67, "Input",
  CellTags->"Cell 6.124"],
Cell[10326141, 246671, 175, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[10326341, 246680, 101, 3, 67, "Input",
  CellTags->"Cell 6.125"],
Cell[10326445, 246685, 81, 1, 46, "Output"]
}, Open  ]],
Cell[10326541, 246689, 446, 11, 62, "Text"],
Cell[10326990, 246702, 110, 3, 67, "Input",
  CellTags->"Cell 6.126"],
Cell[10327103, 246707, 257, 9, 27, "Text"],
Cell[10327363, 246718, 303, 7, 117, "Input",
  CellTags->"Cell 6.127"],
Cell[10327669, 246727, 189, 6, 27, "Text"],
Cell[10327861, 246735, 204, 5, 75, "Input",
  CellTags->"Cell 6.128"],
Cell[10328068, 246742, 351, 11, 29, "Text"],
Cell[10328422, 246755, 130, 3, 73, "Input",
  CellTags->"Cell 6.129"],
Cell[10328555, 246760, 366, 6, 61, "Text"],
Cell[10328924, 246768, 400, 11, 44, "Text"],

Cell[CellGroupData[{
Cell[10329349, 246783, 325, 7, 88, "Input",
  CellTags->"Cell 6.130"],
Cell[10329677, 246792, 135, 3, 46, "Output"]
}, Open  ]],
Cell[10329827, 246798, 310, 7, 44, "Text"],
Cell[10330140, 246807, 153, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[10330318, 246817, 238, 5, 86, "Input",
  CellTags->"Cell 6.131"],
Cell[10330559, 246824, 116146, 2125, 302, 26186, 1010, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10446766, 248956, 65, 1, 30, "Subsubtitle",
  CellTags->"c:27"],
Cell[10446834, 248959, 219, 6, 27, "Text"],
Cell[10447056, 248967, 613, 22, 40, "Text"],
Cell[10447672, 248991, 271, 11, 27, "Text"],
Cell[10447946, 249004, 270, 8, 44, "Text"],
Cell[10448219, 249014, 288, 8, 44, "Text"],
Cell[10448510, 249024, 300, 9, 44, "Text"],
Cell[10448813, 249035, 632, 19, 36, "Text"],
Cell[10449448, 249056, 428, 14, 44, "Text"],
Cell[10449879, 249072, 115, 4, 27, "Text"],
Cell[10449997, 249078, 402, 12, 37, "Text"],
Cell[10450402, 249092, 207, 5, 44, "Text",
  CellTags->"i:66"],
Cell[10450612, 249099, 519, 17, 29, "NE2",
  CellTags->"(6.2.44)"],
Cell[10451134, 249118, 1562, 43, 65, "Text"],
Cell[10452699, 249163, 813, 22, 49, "Text"],
Cell[10453515, 249187, 1451, 49, 58, "Text"],
Cell[10454969, 249238, 640, 22, 39, "Text"],
Cell[10455612, 249262, 367, 9, 52, "Text"],
Cell[10455982, 249273, 663, 20, 31, "Text"],
Cell[10456648, 249295, 337, 12, 29, "Text"],
Cell[10456988, 249309, 395, 13, 41, "Text"],
Cell[10457386, 249324, 179, 8, 27, "Text"],
Cell[10457568, 249334, 176, 8, 27, "Text"],
Cell[10457747, 249344, 506, 17, 44, "Text"],
Cell[10458256, 249363, 367, 11, 44, "Text"],
Cell[10458626, 249376, 1042, 34, 88, "Text"],
Cell[10459671, 249412, 284, 10, 27, "Text"],
Cell[10459958, 249424, 1257, 35, 40, "Text"],
Cell[10461218, 249461, 547, 18, 44, "Text"],
Cell[10461768, 249481, 355, 11, 40, "Text",
  CellTags->"i:38"],
Cell[10462126, 249494, 1967, 69, 89, "Text"],
Cell[10464096, 249565, 977, 34, 44, "Text"],
Cell[10465076, 249601, 2188, 65, 147, "Text"],
Cell[10467267, 249668, 963, 30, 61, "Text"],
Cell[10468233, 249700, 1091, 31, 46, "NE2",
  CellTags->"(6.2.45)"],
Cell[10469327, 249733, 761, 23, 66, "Text"],
Cell[10470091, 249758, 773, 23, 63, "Text"],
Cell[10470867, 249783, 2605, 77, 214, "Text"],
Cell[10473475, 249862, 34134, 425, 136, 34014, 421, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[10507612, 250289, 66, 1, 16, "Caption",
  CellTags->"Fig. 6.8"],
Cell[10507681, 250292, 875, 27, 66, "Text"],
Cell[10508559, 250321, 1210, 32, 95, "Text"],
Cell[10509772, 250355, 38338, 477, 151, 38218, 473, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[10548113, 250834, 66, 1, 16, "Caption",
  CellTags->"Fig. 6.9"],
Cell[10548182, 250837, 1224, 36, 95, "Text"],
Cell[10549409, 250875, 313194, 6678, 302, 194036, 5202, "GraphicsData", \
"PostScript", "Picture"],
Cell[10862606, 257555, 68, 1, 16, "Caption",
  CellTags->"Fig. 6.10"],
Cell[10862677, 257558, 1519, 48, 78, "Text"],
Cell[10864199, 257608, 944, 23, 95, "Text"],
Cell[10865146, 257633, 2571, 80, 136, "Text",
  CellTags->"i:62"],
Cell[10867720, 257715, 2539, 80, 119, "Text"],
Cell[10870262, 257797, 363, 11, 46, "Text"],
Cell[10870628, 257810, 744, 23, 29, "Text"],
Cell[10871375, 257835, 336, 11, 45, "Text"],
Cell[10871714, 257848, 3542874, 48673, 152, 3504985, 48201, "GraphicsData", \
"PostScript", "Picture"],
Cell[14414591, 306523, 459, 16, 29, "Caption",
  CellTags->"Fig. 6.11"],
Cell[14415053, 306541, 1181, 34, 95, "Text"],
Cell[14416237, 306577, 340, 9, 44, "Text"],
Cell[14416580, 306588, 313, 10, 36, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14416942, 306604, 113, 2, 40, "Subtitle",
  CellTags->{"i:39", "c:28"}],
Cell[14417058, 306608, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[14417099, 306612, 61, 1, 41, "Subsubtitle",
  CellTags->"c:29"],
Cell[14417163, 306615, 1047, 21, 146, "Text"],
Cell[14418213, 306638, 221, 4, 44, "Text"],
Cell[14418437, 306644, 774, 12, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14419248, 306661, 81, 1, 30, "Subsubtitle",
  CellTags->{"i:42", "c:30"}],

Cell[CellGroupData[{
Cell[14419354, 306666, 53, 1, 42, "Section",
  CellTags->"c:31"],
Cell[14419410, 306669, 63, 0, 27, "Text"],
Cell[14419476, 306671, 150, 5, 33, "NE3",
  CellTags->"(6.3.1)"],
Cell[14419629, 306678, 1957, 62, 78, "Text"],
Cell[14421589, 306742, 1760, 57, 80, "Text"],
Cell[14423352, 306801, 298, 9, 35, "NE3",
  CellTags->"(6.3.2)"],
Cell[14423653, 306812, 468, 17, 50, "Text"],
Cell[14424124, 306831, 860, 25, 78, "Text"],
Cell[14424987, 306858, 360, 10, 44, "Text"],
Cell[14425350, 306870, 305, 9, 35, "NE3",
  CellTags->"(6.3.3)"],
Cell[14425658, 306881, 76, 0, 27, "Text"],
Cell[14425737, 306883, 1507, 42, 93, "NE3",
  CellTags->"(6.3.4)"],
Cell[14427247, 306927, 434, 14, 44, "Text"],
Cell[14427684, 306943, 1534, 35, 93, "NE3",
  CellTags->"(6.3.5)"],
Cell[14429221, 306980, 294, 9, 44, "Text"],
Cell[14429518, 306991, 301, 9, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14429856, 307005, 97, 1, 31, "Section",
  CellTags->"c:32"],
Cell[14429956, 307008, 111, 3, 27, "Text"],
Cell[14430070, 307013, 126, 4, 42, "UNNEQ"],
Cell[14430199, 307019, 898, 30, 65, "Text"],
Cell[14431100, 307051, 953, 33, 45, "Text"],
Cell[14432056, 307086, 129, 3, 27, "Text"],
Cell[14432188, 307091, 653, 18, 34, "NE3",
  CellTags->{"(2.4.49)", "(6.3.6)"}],
Cell[14432844, 307111, 359, 13, 44, "Text"],
Cell[14433206, 307126, 332, 12, 29, "Text"],
Cell[14433541, 307140, 1070, 22, 328, "Input",
  CellTags->"Cell 6.132"],
Cell[14434614, 307164, 258, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[14434897, 307176, 136, 4, 86, "Input",
  CellTags->"Cell 6.133"],
Cell[14435036, 307182, 846, 18, 178, "Output"]
}, Open  ]],
Cell[14435897, 307203, 303, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[14436225, 307218, 278, 7, 124, "Input",
  CellTags->"Cell 6.134"],
Cell[14436506, 307227, 2619, 34, 312, "Output"]
}, Open  ]],
Cell[14439140, 307264, 353, 9, 47, "Text"],

Cell[CellGroupData[{
Cell[14439518, 307277, 583, 13, 162, "Input",
  CellTags->"Cell 6.135"],
Cell[14440104, 307292, 32469, 747, 233, 7652, 436, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[14472588, 308042, 298, 5, 61, "Text"],
Cell[14472889, 308049, 169, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[14473083, 308057, 170, 5, 67, "Input",
  CellTags->"Cell 6.136"],
Cell[14473256, 308064, 276, 4, 65, "Output"]
}, Open  ]],
Cell[14473547, 308071, 579, 15, 64, "Text"],
Cell[14474129, 308088, 346, 10, 44, "Text"],
Cell[14474478, 308100, 121, 3, 67, "Input",
  CellTags->"Cell 6.137"],
Cell[14474602, 308105, 437, 9, 61, "Text"],
Cell[14475042, 308116, 331, 7, 124, "Input",
  CellTags->"Cell 6.138"],
Cell[14475376, 308125, 210, 6, 44, "Text"],
Cell[14475589, 308133, 231, 6, 67, "Input",
  CellTags->"Cell 6.139"],
Cell[14475823, 308141, 356, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[14476204, 308158, 468, 10, 124, "Input",
  CellTags->"Cell 6.140"],

Cell[CellGroupData[{
Cell[14476697, 308172, 27854, 703, 233, 7775, 450, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14504554, 308877, 58073, 1314, 233, 12371, 745, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14562630, 310193, 89663, 1878, 233, 15715, 960, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14652296, 312073, 117900, 2354, 233, 18210, 1118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14770199, 314429, 144643, 2811, 233, 20677, 1275, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[14914869, 317244, 418, 11, 44, "Text"],
Cell[14915290, 317257, 495, 12, 64, "Text"],

Cell[CellGroupData[{
Cell[14915810, 317273, 1179, 23, 276, "Input",
  CellTags->"Cell 6.141"],

Cell[CellGroupData[{
Cell[14917014, 317300, 27047, 671, 233, 6793, 416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14944064, 317973, 25094, 639, 233, 6658, 406, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14969161, 318614, 24774, 636, 233, 6691, 408, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14993938, 319252, 24569, 634, 233, 6688, 408, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[15018534, 319890, 326, 7, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15018897, 319902, 82, 1, 31, "Section",
  CellTags->{"i:47", "c:33"}],
Cell[15018982, 319905, 329, 7, 61, "Text"],
Cell[15019314, 319914, 99, 3, 27, "Text"],
Cell[15019416, 319919, 280, 9, 30, "Text"],
Cell[15019699, 319930, 644, 20, 61, "Text"],
Cell[15020346, 319952, 540, 16, 65, "NE3",
  CellTags->"(6.3.7)"],
Cell[15020889, 319970, 449, 13, 45, "Text"],
Cell[15021341, 319985, 488, 11, 225, "Input",
  CellTags->"Cell 6.142"],
Cell[15021832, 319998, 105, 3, 27, "Text"],
Cell[15021940, 320003, 468, 11, 183, "Input",
  CellTags->"Cell 6.143"],
Cell[15022411, 320016, 176, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[15022612, 320026, 384, 8, 128, "Input",
  CellTags->"Cell 6.144"],
Cell[15022999, 320036, 26659, 591, 370, 4354, 311, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15049673, 320630, 1622, 52, 98, "Text"],
Cell[15051298, 320684, 59, 0, 27, "Text"],
Cell[15051360, 320686, 386, 8, 267, "Input",
  CellTags->"Cell 6.145"],
Cell[15051749, 320696, 290, 8, 44, "Text"],
Cell[15052042, 320706, 212, 6, 69, "Input",
  CellTags->"Cell 6.146"],
Cell[15052257, 320714, 761, 24, 44, "Text"],
Cell[15053021, 320740, 224, 6, 105, "Input",
  CellTags->"Cell 6.147"],
Cell[15053248, 320748, 925, 30, 61, "Text"],
Cell[15054176, 320780, 118, 3, 67, "Input",
  CellTags->"Cell 6.148"],
Cell[15054297, 320785, 51, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[15054373, 320789, 110, 3, 67, "Input",
  CellTags->"Cell 6.149"],
Cell[15054486, 320794, 4492, 58, 502, "Output"]
}, Open  ]],
Cell[15058993, 320855, 117, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[15059135, 320862, 112, 3, 67, "Input",
  CellTags->"Cell 6.150"],
Cell[15059250, 320867, 37, 1, 46, "Output"]
}, Open  ]],
Cell[15059302, 320871, 1062, 26, 104, "Text"],
Cell[15060367, 320899, 99, 3, 27, "Text"],
Cell[15060469, 320904, 120, 3, 67, "Input",
  CellTags->"Cell 6.151"],
Cell[15060592, 320909, 896, 28, 64, "Text"],

Cell[CellGroupData[{
Cell[15061513, 320941, 105, 3, 67, "Input",
  CellTags->"Cell 6.152"],
Cell[15061621, 320946, 4834, 76, 578, "Output"]
}, Open  ]],
Cell[15066470, 321025, 1441, 41, 95, "Text"],
Cell[15067914, 321068, 575, 11, 147, "Input",
  CellTags->"Cell 6.153"],
Cell[15068492, 321081, 1111, 32, 78, "Text"],

Cell[CellGroupData[{
Cell[15069628, 321117, 503, 10, 162, "Input",
  CellTags->"Cell 6.154"],

Cell[CellGroupData[{
Cell[15070156, 321131, 184818, 5864, 320, 89804, 4686, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15254977, 326997, 191731, 6398, 320, 105023, 5323, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15446711, 333397, 179195, 5941, 320, 93990, 4885, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15625979, 339346, 85, 1, 30, "Subsubtitle",
  CellTags->{"i:41", "c:34"}],

Cell[CellGroupData[{
Cell[15626089, 339351, 53, 1, 42, "Section",
  CellTags->"c:35"],
Cell[15626145, 339354, 404, 7, 78, "Text"],
Cell[15626552, 339363, 524, 8, 95, "Text"],
Cell[15627079, 339373, 131, 3, 27, "Text"],
Cell[15627213, 339378, 149, 5, 33, "NE3",
  CellTags->"(6.3.8)"],
Cell[15627365, 339385, 380, 11, 48, "Text"],
Cell[15627748, 339398, 145, 5, 38, "NE3",
  CellTags->"(6.3.9)"],
Cell[15627896, 339405, 249, 9, 30, "Text"],
Cell[15628148, 339416, 195, 6, 36, "Text"],
Cell[15628346, 339424, 152, 5, 27, "Text"],
Cell[15628501, 339431, 222, 4, 38, "NE3",
  CellTags->"(6.3.10)"],
Cell[15628726, 339437, 390, 13, 32, "Text"],
Cell[15629119, 339452, 879, 28, 30, "Text"],
Cell[15630001, 339482, 675, 21, 65, "Text"],
Cell[15630679, 339505, 985, 31, 32, "NE3",
  CellTags->"(6.3.11)"],
Cell[15631667, 339538, 770, 25, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15632474, 339568, 91, 1, 31, "Section",
  CellTags->"c:36"],
Cell[15632568, 339571, 144, 3, 44, "Text"],
Cell[15632715, 339576, 222, 6, 42, "NE3",
  CellTags->"(6.3.12)"],
Cell[15632940, 339584, 305, 9, 44, "Text"],
Cell[15633248, 339595, 1956, 52, 181, "Text"],
Cell[15635207, 339649, 441, 8, 78, "Text"],
Cell[15635651, 339659, 861, 17, 205, "Input",
  CellTags->"Cell 6.155"],
Cell[15636515, 339678, 237, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[15636777, 339688, 180, 5, 74, "Input",
  CellTags->"Cell 6.156"],
Cell[15636960, 339695, 383, 6, 148, "Output"]
}, Open  ]],
Cell[15637358, 339704, 382, 12, 46, "Text"],
Cell[15637743, 339718, 111, 3, 67, "Input",
  CellTags->"Cell 6.157"],
Cell[15637857, 339723, 237, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[15638119, 339735, 152, 4, 67, "Input",
  CellTags->"Cell 6.158"],
Cell[15638274, 339741, 163, 2, 84, "Output"]
}, Open  ]],
Cell[15638452, 339746, 181, 6, 27, "Text"],
Cell[15638636, 339754, 945, 19, 257, "Input",
  CellTags->"Cell 6.159"],
Cell[15639584, 339775, 159, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[15639768, 339784, 95, 3, 67, "Input",
  CellTags->"Cell 6.160"],
Cell[15639866, 339789, 280, 4, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15640183, 339798, 93, 3, 67, "Input",
  CellTags->"Cell 6.161"],
Cell[15640279, 339803, 246, 5, 104, "Output"]
}, Open  ]],
Cell[15640540, 339811, 314, 10, 44, "Text"],
Cell[15640857, 339823, 171, 5, 67, "Input",
  CellTags->"Cell 6.162"],
Cell[15641031, 339830, 481, 13, 61, "Text"],

Cell[CellGroupData[{
Cell[15641537, 339847, 284, 6, 86, "Input",
  CellTags->"Cell 6.163"],

Cell[CellGroupData[{
Cell[15641846, 339857, 35183, 862, 233, 8891, 533, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15677032, 340721, 35798, 915, 233, 9731, 589, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15712833, 341638, 41167, 963, 233, 9411, 566, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15754003, 342603, 43557, 1036, 233, 9939, 616, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15797621, 343646, 82, 1, 31, "Section",
  CellTags->{"i:48", "c:37"}],
Cell[15797706, 343649, 903, 25, 98, "Text"],
Cell[15798612, 343676, 181, 6, 30, "Text"],
Cell[15798796, 343684, 268, 11, 30, "Text"],
Cell[15799067, 343697, 4709, 152, 121, "Text"],
Cell[15803779, 343851, 6660, 198, 85, "Text"],

Cell[CellGroupData[{
Cell[15810464, 344053, 470, 12, 207, "Input",
  CellTags->"Cell 6.164"],
Cell[15810937, 344067, 2643, 40, 222, "Output"]
}, Open  ]],
Cell[15813595, 344110, 72, 0, 27, "Text"],
Cell[15813670, 344112, 3913, 81, 583, "Input",
  CellTags->"Cell 6.165"],
Cell[15817586, 344195, 118, 5, 27, "Text"],
Cell[15817707, 344202, 97, 3, 67, "Input",
  CellTags->"Cell 6.166"],
Cell[15817807, 344207, 35, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[15817867, 344211, 90, 3, 67, "Input",
  CellTags->"Cell 6.167"],
Cell[15817960, 344216, 682, 9, 103, "Output"]
}, Open  ]],
Cell[15818657, 344228, 396, 12, 47, "Text"],

Cell[CellGroupData[{
Cell[15819078, 344244, 162, 5, 105, "Input",
  CellTags->"Cell 6.168"],
Cell[15819243, 344251, 975, 13, 141, "Output"]
}, Open  ]],
Cell[15820233, 344267, 485, 15, 44, "Text",
  CellTags->"i:67"],

Cell[CellGroupData[{
Cell[15820743, 344286, 916, 19, 279, "Input",
  CellTags->"Cell 6.169"],

Cell[CellGroupData[{
Cell[15821684, 344309, 352565, 7245, 302, 201354, 5374, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16174252, 351556, 349818, 7231, 302, 200008, 5377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16524073, 358789, 351887, 7222, 302, 201159, 5357, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16875963, 366013, 351336, 7219, 302, 200858, 5357, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17227372, 373240, 63, 1, 30, "Subsubtitle",
  CellTags->"c:38"],
Cell[17227438, 373243, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[17227479, 373247, 56, 1, 42, "Section",
  CellTags->"c:39"],
Cell[17227538, 373250, 268, 6, 44, "Text",
  CellTags->"i:43"],
Cell[17227809, 373258, 258, 9, 44, "Text"],
Cell[17228070, 373269, 336, 8, 45, "NE3",
  CellTags->{"(3.1.7)", "(6.3.13)"}],
Cell[17228409, 373279, 166, 5, 27, "Text"],
Cell[17228578, 373286, 165, 4, 44, "Text"],
Cell[17228746, 373292, 274, 8, 41, "NE3",
  CellTags->"(6.3.14)"],
Cell[17229023, 373302, 18, 0, 27, "Text"],
Cell[17229044, 373304, 494, 12, 44, "NE3",
  CellTags->"(6.3.15)"],
Cell[17229541, 373318, 784, 22, 69, "Text"],
Cell[17230328, 373342, 275, 6, 43, "NE3",
  CellTags->"(6.3.16)"],
Cell[17230606, 373350, 150, 5, 27, "Text"],
Cell[17230759, 373357, 258, 9, 34, "NE3",
  CellTags->"(6.3.17)"],
Cell[17231020, 373368, 250, 9, 27, "Text"],
Cell[17231273, 373379, 140, 5, 29, "NE3",
  CellTags->"(6.3.18)"],
Cell[17231416, 373386, 689, 17, 82, "Text"],
Cell[17232108, 373405, 242, 7, 42, "NE3",
  CellTags->"(6.3.19)"],
Cell[17232353, 373414, 684, 22, 61, "Text"],
Cell[17233040, 373438, 1067, 35, 86, "Text"],
Cell[17234110, 373475, 500, 16, 54, "Text"],
Cell[17234613, 373493, 347, 8, 53, "NE3",
  CellTags->"(6.3.20)"],
Cell[17234963, 373503, 188, 6, 27, "Text"],
Cell[17235154, 373511, 948, 22, 352, "Input",
  CellTags->"Cell 6.170"],
Cell[17236105, 373535, 464, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[17236594, 373550, 30787, 788, 233, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17267384, 374340, 29382, 770, 233, 9035, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17296769, 375112, 27148, 787, 233, 9904, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17323920, 375901, 28378, 802, 233, 9898, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17352301, 376705, 29426, 772, 233, 9079, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17381730, 377479, 30198, 780, 233, 9062, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17411931, 378261, 28637, 759, 233, 9015, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17440571, 379022, 27943, 797, 233, 9921, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17468517, 379821, 27510, 786, 70, 9812, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17496030, 380609, 29459, 770, 70, 9027, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17525492, 381381, 30463, 780, 70, 8982, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17555958, 382163, 29464, 769, 70, 9012, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17585425, 382934, 27388, 785, 70, 9795, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17612816, 383721, 28015, 802, 70, 9993, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17640834, 384525, 28905, 761, 70, 8996, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17669742, 385288, 30439, 784, 70, 9076, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17700184, 386074, 29761, 773, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17729948, 386849, 28804, 809, 70, 9940, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17758755, 387660, 27530, 790, 70, 9881, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17786288, 388452, 29905, 776, 70, 9044, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17816196, 389230, 30850, 789, 70, 9070, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17847049, 390021, 29773, 773, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17876825, 390796, 27345, 792, 70, 9955, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17904173, 391590, 28690, 808, 70, 9947, 572, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17932866, 392400, 29566, 771, 70, 9037, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17962435, 393173, 30827, 786, 70, 9014, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17993265, 393961, 28757, 760, 70, 9010, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18022025, 394723, 27997, 796, 70, 9886, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18050025, 395521, 27599, 786, 70, 9775, 561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18077627, 396309, 29727, 772, 70, 9008, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18107357, 397083, 30432, 778, 70, 8947, 508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18137792, 397863, 29627, 772, 70, 9025, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18167422, 398637, 27344, 784, 70, 9804, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18194769, 399423, 28056, 797, 70, 9884, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18222828, 400222, 29295, 770, 70, 9074, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18252126, 400994, 31353, 795, 70, 9083, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18283482, 401791, 29792, 772, 70, 9000, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18313277, 402565, 28933, 813, 233, 9975, 574, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18342213, 403380, 27818, 798, 233, 9958, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18370034, 404180, 30132, 779, 233, 9044, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18400169, 404961, 30834, 788, 233, 9050, 515, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[18431018, 405752, 165, 4, 17, "Caption",
  CellTags->"Fig. 6.12"],
Cell[18431186, 405758, 625, 12, 78, "Text"],
Cell[18431814, 405772, 369, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[18432220, 405783, 95, 1, 31, "Section",
  CellTags->{"i:40", "c:40"}],
Cell[18432318, 405786, 688, 15, 95, "Text"],
Cell[18433009, 405803, 1062, 27, 95, "Text"],
Cell[18434074, 405832, 389, 8, 116, "Input",
  CellTags->"Cell 6.171"],
Cell[18434466, 405842, 174, 7, 27, "Text"],
Cell[18434643, 405851, 143, 4, 67, "Input",
  CellTags->"Cell 6.172"],
Cell[18434789, 405857, 528, 18, 44, "Text"],
Cell[18435320, 405877, 323, 7, 86, "Input",
  CellTags->"Cell 6.173"],
Cell[18435646, 405886, 99, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[18435770, 405893, 396, 9, 107, "Input",
  CellTags->"Cell 6.174"],
Cell[18436169, 405904, 1409, 31, 248, "Output"]
}, Open  ]],
Cell[18437593, 405938, 214, 4, 44, "Text"],
Cell[18437810, 405944, 149, 3, 44, "Text"],
Cell[18437962, 405949, 158, 4, 67, "Input",
  CellTags->"Cell 6.175"],
Cell[18438123, 405955, 275, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[18438423, 405966, 620, 13, 181, "Input",
  CellTags->"Cell 6.176"],

Cell[CellGroupData[{
Cell[18439068, 405983, 36604, 803, 233, 6879, 431, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18475675, 406788, 37206, 857, 233, 7762, 488, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18512884, 407647, 38930, 873, 233, 7724, 483, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18551817, 408522, 43462, 971, 233, 8575, 535, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18595282, 409495, 47903, 1071, 233, 9475, 591, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[18643212, 410570, 358, 6, 55, "Text"],
Cell[18643573, 410578, 853, 20, 295, "Input",
  CellTags->"Cell 6.177"],
Cell[18644429, 410600, 225, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[18644679, 410611, 30787, 788, 233, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18675469, 411401, 29408, 770, 70, 9033, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18704880, 412173, 26976, 785, 70, 9881, 569, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18731859, 412960, 28376, 798, 70, 9832, 565, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18760238, 413760, 29288, 768, 70, 9043, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18789529, 414530, 30091, 779, 70, 9064, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18819623, 415311, 28590, 760, 70, 9041, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18848216, 416073, 28029, 797, 70, 9885, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18876248, 416872, 27170, 782, 70, 9808, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18903421, 417656, 29505, 770, 70, 9029, 513, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18932929, 418428, 30467, 780, 70, 8986, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18963399, 419210, 29141, 765, 70, 9005, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18992543, 419977, 27162, 785, 70, 9849, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19019708, 420764, 28115, 803, 70, 9988, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19047826, 421569, 28695, 758, 70, 8976, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19076524, 422329, 30111, 780, 70, 9064, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19106638, 423111, 29428, 771, 70, 9061, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19136069, 423884, 28588, 803, 70, 9857, 567, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19164660, 424689, 27411, 789, 70, 9879, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19192074, 425480, 29859, 776, 70, 9059, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19221936, 426258, 30847, 789, 70, 9075, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19252786, 427049, 29267, 769, 70, 9054, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19282056, 427820, 27172, 792, 70, 9984, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19309231, 428614, 28426, 800, 70, 9845, 566, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19337660, 429416, 29421, 771, 70, 9058, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19367084, 430189, 29987, 775, 70, 9013, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19397074, 430966, 28379, 757, 70, 9037, 514, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19425456, 431725, 28042, 798, 70, 9915, 570, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19453501, 432525, 27332, 783, 70, 9780, 562, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19480836, 433310, 29560, 770, 70, 9007, 512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19510399, 434082, 30536, 779, 70, 8946, 508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19540938, 434863, 29135, 768, 70, 9072, 516, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19570076, 435633, 26938, 780, 70, 9807, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19597017, 436415, 28129, 798, 70, 9880, 568, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19625149, 437215, 28998, 770, 70, 9141, 520, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19654150, 437987, 30128, 780, 70, 9068, 515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19684281, 438769, 29095, 764, 70, 8995, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19713379, 439535, 28461, 806, 70, 9957, 573, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19741843, 440343, 27511, 796, 70, 9971, 575, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19769357, 441141, 29750, 771, 70, 8982, 510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19799110, 441914, 30765, 788, 70, 9057, 515, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[19829890, 442705, 312, 9, 30, "Caption",
  CellTags->"Fig. 6.13"],
Cell[19830205, 442716, 380, 9, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19830622, 442730, 94, 1, 31, "Section",
  CellTags->{"i:44", "c:41"}],
Cell[19830719, 442733, 691, 15, 78, "Text"],
Cell[19831413, 442750, 184, 4, 44, "Text"],
Cell[19831600, 442756, 235, 7, 42, "NE3",
  CellTags->"(6.3.21)"],
Cell[19831838, 442765, 631, 21, 65, "Text"],
Cell[19832472, 442788, 622, 18, 69, "Text"],
Cell[19833097, 442808, 414, 9, 44, "NE3",
  CellTags->"(6.3.22)"],
Cell[19833514, 442819, 137, 5, 30, "Text"],
Cell[19833654, 442826, 1078, 32, 95, "Text"],
Cell[19834735, 442860, 213, 6, 33, "UNNEQ"],
Cell[19834951, 442868, 418, 13, 30, "Text"],
Cell[19835372, 442883, 219, 6, 42, "UNNEQ"],
Cell[19835594, 442891, 722, 20, 48, "Text"],
Cell[19836319, 442913, 242, 7, 33, "NE3",
  CellTags->"(6.3.23)"],
Cell[19836564, 442922, 314, 7, 44, "Text"],
Cell[19836881, 442931, 197, 6, 33, "NE3",
  CellTags->"(6.3.24)"],
Cell[19837081, 442939, 247, 7, 30, "Text"],
Cell[19837331, 442948, 219, 7, 33, "NE3",
  CellTags->"(6.3.25)"],
Cell[19837553, 442957, 384, 12, 44, "Text"],
Cell[19837940, 442971, 54045, 1166, 233, 11597, 637, "GraphicsData", \
"PostScript", "Picture"],
Cell[19891988, 444139, 131, 4, 16, "Caption",
  CellTags->"Fig. 6.14"],
Cell[19892122, 444145, 319, 7, 61, "Text"],
Cell[19892444, 444154, 297, 8, 43, "NE3",
  CellTags->"(6.3.26)"],
Cell[19892744, 444164, 417, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[19893186, 444182, 345, 7, 149, "Input",
  CellTags->"Cell 6.178"],
Cell[19893534, 444191, 41355, 986, 233, 9866, 593, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19934904, 445180, 531, 16, 47, "Text"],
Cell[19935438, 445198, 642, 17, 48, "NE3",
  CellTags->"(6.3.27)"],
Cell[19936083, 445217, 371, 13, 44, "Text"],
Cell[19936457, 445232, 671, 18, 51, "NE3",
  CellTags->"(6.3.28)"],
Cell[19937131, 445252, 902, 27, 66, "Text"],
Cell[19938036, 445281, 448, 11, 61, "Text"],
Cell[19938487, 445294, 355, 9, 45, "NE3",
  CellTags->"(6.3.29)"],
Cell[19938845, 445305, 148, 5, 27, "Text"],
Cell[19938996, 445312, 689, 19, 51, "NE3",
  CellTags->"(6.3.30)"],
Cell[19939688, 445333, 1204, 33, 64, "Text"],
Cell[19940895, 445368, 502, 8, 35, "UNNEQ"],
Cell[19941400, 445378, 73, 0, 27, "Text"],
Cell[19941476, 445380, 240, 7, 35, "NE3",
  CellTags->"(6.3.31)"],
Cell[19941719, 445389, 877, 30, 61, "Text",
  CellTags->"i:45"],
Cell[19942599, 445421, 1060, 31, 83, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19943696, 445457, 87, 1, 31, "Section",
  CellTags->"c:42"],
Cell[19943786, 445460, 1229, 35, 109, "Text"],
Cell[19945018, 445497, 242, 7, 58, "NE3",
  CellTags->"(6.3.32)"],
Cell[19945263, 445506, 174, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[19945462, 445517, 245, 6, 106, "Input",
  CellTags->"Cell 6.179"],
Cell[19945710, 445525, 54, 1, 46, "Output"]
}, Open  ]],
Cell[19945779, 445529, 549, 12, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19946365, 445546, 97, 1, 31, "Section",
  CellTags->{"i:46", "c:43"}],
Cell[19946465, 445549, 1191, 24, 146, "Text"],
Cell[19947659, 445575, 275, 7, 44, "Text"],
Cell[19947937, 445584, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[19948064, 445591, 122, 3, 67, "Input",
  CellTags->"Cell 6.180"],
Cell[19948189, 445596, 51, 1, 51, "Output"]
}, Open  ]],
Cell[19948255, 445600, 32, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[19948312, 445604, 96, 3, 67, "Input",
  CellTags->"Cell 6.181"],
Cell[19948411, 445609, 41, 1, 69, "Output"]
}, Open  ]],
Cell[19948467, 445613, 355, 10, 44, "Text"],
Cell[19948825, 445625, 578, 11, 184, "Input",
  CellTags->"Cell 6.182"],
Cell[19949406, 445638, 295, 9, 27, "Text"],
Cell[19949704, 445649, 137, 3, 67, "Input",
  CellTags->"Cell 6.183"],
Cell[19949844, 445654, 178, 6, 27, "Text"],
Cell[19950025, 445662, 156, 4, 67, "Input",
  CellTags->"Cell 6.184"],
Cell[19950184, 445668, 676, 22, 44, "Text"],
Cell[19950863, 445692, 815, 16, 219, "Input",
  CellTags->"Cell 6.185"],
Cell[19951681, 445710, 102, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[19951808, 445717, 134, 3, 67, "Input",
  CellTags->"Cell 6.186"],
Cell[19951945, 445722, 167, 3, 50, "Message"],
Cell[19952115, 445727, 167, 3, 50, "Message"],
Cell[19952285, 445732, 166, 3, 50, "Message"],
Cell[19952454, 445737, 167, 3, 50, "Message"],
Cell[19952624, 445742, 166, 3, 50, "Message"],
Cell[19952793, 445747, 2638, 80, 122, "Output"]
}, Open  ]],
Cell[19955446, 445830, 647, 13, 95, "Text"],
Cell[19956096, 445845, 342, 9, 61, "Text"],
Cell[19956441, 445856, 98, 3, 27, "Text"],
Cell[19956542, 445861, 191, 5, 67, "Input",
  CellTags->"Cell 6.187"],
Cell[19956736, 445868, 238, 6, 44, "Text"],
Cell[19956977, 445876, 446, 8, 105, "Input",
  CellTags->"Cell 6.188"],
Cell[19957426, 445886, 643, 14, 95, "Text"],

Cell[CellGroupData[{
Cell[19958094, 445904, 280, 6, 86, "Input",
  CellTags->"Cell 6.189"],

Cell[CellGroupData[{
Cell[19958399, 445914, 38505, 968, 233, 10300, 615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19996907, 446884, 40702, 1026, 233, 10858, 653, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20037612, 447912, 46301, 1079, 233, 10192, 629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20083916, 448993, 51396, 1163, 233, 11010, 660, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20135315, 450158, 57017, 1226, 233, 10820, 651, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20192335, 451386, 59229, 1290, 233, 11408, 695, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20251637, 452684, 65, 1, 30, "Subsubtitle",
  CellTags->"c:44"],
Cell[20251705, 452687, 727, 18, 78, "Text"],
Cell[20252435, 452707, 123, 4, 27, "Text"],
Cell[20252561, 452713, 127, 4, 27, "Text"],
Cell[20252691, 452719, 483, 14, 44, "Text"],
Cell[20253177, 452735, 183, 5, 27, "Text"],
Cell[20253363, 452742, 411, 13, 44, "Text"],
Cell[20253777, 452757, 144, 4, 27, "Text"],
Cell[20253924, 452763, 140, 4, 27, "Text"],
Cell[20254067, 452769, 593, 17, 61, "Text"],
Cell[20254663, 452788, 257, 7, 41, "Text"],
Cell[20254923, 452797, 453, 16, 32, "Text"],
Cell[20255379, 452815, 431, 13, 44, "Text"],
Cell[20255813, 452830, 88604, 1097, 156, 88486, 1093, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[20344420, 453929, 53, 1, 16, "Caption",
  CellTags->"Fig. 6.15"],
Cell[20344476, 453932, 428, 12, 44, "Text"],
Cell[20344907, 453946, 243, 6, 44, "Text"],
Cell[20345153, 453954, 487, 15, 44, "Text"],
Cell[20345643, 453971, 141, 4, 27, "Text"],
Cell[20345787, 453977, 145, 4, 27, "Text"],
Cell[20345935, 453983, 261, 8, 44, "Text"],
Cell[20346199, 453993, 1190, 32, 43, "Text"],
Cell[20347392, 454027, 1050, 34, 78, "Text"],
Cell[20348445, 454063, 123, 4, 27, "Text"],
Cell[20348571, 454069, 127, 4, 27, "Text"],
Cell[20348701, 454075, 201, 7, 27, "Text"],
Cell[20348905, 454084, 782, 22, 63, "Text"],
Cell[20349690, 454108, 177, 5, 27, "Text"],
Cell[20349870, 454115, 137, 5, 31, "Text"],
Cell[20350010, 454122, 140, 5, 31, "Text"],
Cell[20350153, 454129, 123, 4, 27, "Text"],
Cell[20350279, 454135, 385, 7, 61, "Text"],
Cell[20350667, 454144, 535, 15, 41, "Text"],
Cell[20351205, 454161, 135, 3, 27, "Text"],
Cell[20351343, 454166, 267, 9, 27, "Text"],
Cell[20351613, 454177, 99, 4, 30, "Text"],
Cell[20351715, 454183, 112, 5, 30, "Text"],
Cell[20351830, 454190, 158, 5, 27, "Text"],
Cell[20351991, 454197, 154, 5, 27, "Text"],
Cell[20352148, 454204, 158, 5, 27, "Text"],
Cell[20352309, 454211, 1167, 29, 103, "Text",
  CellTags->"i:56"],
Cell[20353479, 454242, 749, 22, 65, "Text"],
Cell[20354231, 454266, 969, 29, 82, "Text"],
Cell[20355203, 454297, 1235, 32, 118, "Text"],
Cell[20356441, 454331, 1557, 43, 139, "Text"],
Cell[20358001, 454376, 662, 22, 63, "Text"],
Cell[20358666, 454400, 1175, 31, 122, "Text"],
Cell[20359844, 454433, 43876, 545, 150, 43754, 541, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[20403723, 454980, 68, 1, 16, "Caption",
  CellTags->"Fig. 6.16"],
Cell[20403794, 454983, 1010, 30, 66, "Text"],
Cell[20404807, 455015, 904, 28, 45, "Text"],
Cell[20405714, 455045, 184, 7, 38, "NE3",
  CellTags->"(6.3.33)"],
Cell[20405901, 455054, 915, 27, 69, "Text"],
Cell[20406819, 455083, 685, 21, 61, "Text"],
Cell[20407507, 455106, 883, 29, 78, "Text",
  CellTags->"i:49"],
Cell[20408393, 455137, 155, 6, 33, "NE3",
  CellTags->"(6.3.34)"],
Cell[20408551, 455145, 495, 13, 65, "Text"],
Cell[20409049, 455160, 430, 14, 44, "Text"],
Cell[20409482, 455176, 2262, 69, 158, "Text",
  CellTags->"i:50"],
Cell[20411747, 455247, 167, 6, 32, "NE3",
  CellTags->"(6.3.35)"],
Cell[20411917, 455255, 902, 27, 86, "Text",
  CellTags->"i:51"],
Cell[20412822, 455284, 247, 8, 56, "Text"],
Cell[20413072, 455294, 750, 24, 47, "Text"],
Cell[20413825, 455320, 225, 6, 49, "NE3",
  CellTags->"(6.3.36)"],
Cell[20414053, 455328, 745, 25, 65, "Text"],
Cell[20414801, 455355, 203, 6, 27, "Text"],
Cell[20415007, 455363, 2311, 76, 107, "Text",
  CellTags->"i:52"],
Cell[20417321, 455441, 410, 13, 29, "NE3",
  CellTags->"(6.3.37)"],
Cell[20417734, 455456, 651, 23, 52, "Text"],
Cell[20418388, 455481, 1223, 44, 48, "Text"],
Cell[20419614, 455527, 760, 22, 39, "NE3",
  CellTags->"(6.3.38)"],
Cell[20420377, 455551, 1436, 49, 44, "Text"],
Cell[20421816, 455602, 783, 22, 48, "NE3",
  CellTags->"(6.3.39)"],
Cell[20422602, 455626, 290, 10, 32, "Text"],
Cell[20422895, 455638, 174, 6, 35, "NE3",
  CellTags->{"i:53", "(6.3.40)"}],
Cell[20423072, 455646, 380, 16, 27, "Text"],
Cell[20423455, 455664, 452, 14, 44, "Text"],
Cell[20423910, 455680, 856, 31, 27, "Text"],
Cell[20424769, 455713, 784, 24, 35, "NE3",
  CellTags->"(6.3.41)"],
Cell[20425556, 455739, 1012, 36, 55, "Text"],
Cell[20426571, 455777, 294, 9, 49, "NE3",
  CellTags->{"i:54", "(6.3.42)"}],
Cell[20426868, 455788, 518, 19, 44, "Text"],
Cell[20427389, 455809, 1610, 47, 136, "Text",
  CellTags->"i:55"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20429048, 455862, 60, 1, 40, "Subtitle",
  CellTags->{"c:45", "refs"}],
Cell[20429111, 455865, 231, 8, 27, "Text"],
Cell[20429345, 455875, 199, 7, 27, "Text"],
Cell[20429547, 455884, 186, 5, 27, "Text"],
Cell[20429736, 455891, 208, 5, 44, "Text"],
Cell[20429947, 455898, 222, 8, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

